      SUBROUTINE A_MORPH(NBINSIN,XMININ,XMAXIN,DIST1IN,DIST2IN,
     &                   PAR1,PAR2,PARN,X3VALUES,DISTN)
*--------------------------------------------------------------------------
* Original code    : D_PVMORPH
* Original author  : Alex Read 11-FEB-1998
*
*......Do a linear interpolation between two probability distributions
*      as a function of the characteristic parameter of the distribution.
*
*      Original code from phmorph, same functionality but operated
*      on HBOOK histograms.
*
*      I can't recall reading or hearing about this way of interpolating
*      between two probability distributions!
*
* Takes two input histograms (1 and 2) in the form of vectors and
* binning constants and compute the linearly interpolated or morphed
* distribution (n) and its binning constants.

* dist1,dist2,distn  : Bin contents of histograms
* par1,par2,parn     : Values of the linear parameters that characterise the
*                      histograms (e.g. the Higgs mass).
*
* Inputs: nb1,nb2,xmin1,xmin2,xmax1,xmax2
* Output: nbn,xminn,xmaxn,distn
*
* The histograms are limited in size to 100 bins, this is the limit
* of temporary arrays used to manipulate copies of the input histograms.

* Modified by J. Nielsen -- 1 June 2000
* Changed algorithm to sample the tails with higher precision.
* Essentially, build the list of y-values by scanning the x1 values.
* Then the algorithm proceeds as described above.
* The outputs are the new X3VALUES and the new DISTN
C (Before 3 July 2000, the outputs were X3VALUES and YVALUES)
*------------------------------------------------------------------------
      IMPLICIT NONE
*
*......Arguments
*
      INTEGER nbinsin
      REAL*8 xminin,xmaxin
      REAL*8 dist1in(nbinsin),dist2in(nbinsin),distn(nbinsin)
      REAL*8 par1,par2,parn
      REAL*8 yvalues(nbinsin)
      REAL*8 x1values(nbinsin), x2values(nbinsin), x3values(nbinsin)
*
*......Local variables
*
      INTEGER idebug,nb_max,i, j
      PARAMETER (nb_max=1000)
      REAL*8 dxin,slope,sigdis(nbinsin,3),wta,wtb
*
*......Debugging on=1.
*
      idebug = 0
*
*......Check that input histograms are not too large.
*
      IF(nbinsin.GT.nb_max) THEN
         PRINT *,'%%%%%%-F-pvmorph Too many bins in input histograms.'
         GOTO 999
      ENDIF
*
*......The weights (a,b) are the "distances" between the values of the
*      parameters at the histograms and the desired interpolation point.
*      Check that they make sense. If par1=par2 then we can choose any
*      valid set of wta,wtb so why not take the average?
*
      IF(par2.NE.par1) THEN
         wta = 1. - (parn-par1)/(par2-par1)
         wtb = 1. + (parn-par2)/(par2-par1)
      ELSE
         wta = 0.5
         wtb = 0.5
      ENDIF
      IF(wta.LT.0. .OR. wta.GT.1. .OR. wtb.LT.0. .OR.wtb.GT.1.
     &           .OR. ABS(1.0-(wta+wtb)).GT.1.0E-4) THEN
         PRINT *,'%%%%%%-W-pvmorph Invalid weights:',wta,wtb
     &          ,' (sum=',wta+wtb,')'
      ENDIF
*
*......Determine the resulting binning constants.
*
      dxin = (xmaxin-xminin)/REAL(nbinsin-1)
*
*......Copy the two histograms to temporary locations and
*      overwrite the contents with the normalized, cummulative
*      probability distribution.
*
      DO I = 1, NBINSIN
         SIGDIS(I,1) = DIST1IN(I)
         SIGDIS(I,2) = DIST2IN(I)
      ENDDO
      CALL a_acnvec(sigdis(1,1),nbinsin)
      CALL a_acnvec(sigdis(1,2),nbinsin)
      IF(idebug.GE.1) print *,'PVMORPH: temp cumm. dists. computed.'
*
*......Determine the yvalues to be used in the
*      probability inversions.  Get these by scanning over the X axis
*      of the first function.
*
      do i = 1, nbinsin
         x1values(i) = xminin + dxin*(i-1)
         yvalues(i) = sigdis(i,1)
      enddo
*
*       Now find the x values in the second distribution which correspond
*       to these y values (linear interpolation)
*
C     Yvalues runs from (0,1] so begin by assigning x2values to the lower
C     boundary
C
      do i = 1, nbinsin
         x2values(i) = x1values(1)
         do j = 1, nbinsin-1
            if ( yvalues(i).gt.sigdis(j,2) .and.
     $           yvalues(i).le.sigdis(j+1,2) ) then
               slope = dxin/(sigdis(j+1,2)-sigdis(j,2))
               x2values(i) = x1values(j) +slope*(yvalues(i)-sigdis(j,2))
            endif
         enddo
      enddo
      do i = 1, nbinsin
         x3values(i) = x1values(i)*wta + x2values(i)*wtb
      enddo
*
*......Differentiate to get distribution from cumulative distribution.
*
      DO i=2,nbinsin
         distn(i) =
     $        (yvalues(i)-yvalues(i-1))/(x3values(i)-x3values(i-1))
         if (distn(i).lt.0.d0) then
            write(*,*) 'a_morph: Warning: shape less than zero in bin, '
     $           , i
            distn(i) = 1d-15
         endif
      ENDDO
      distn(1) = (yvalues(2)-yvalues(1))/(x3values(2)-x3values(1))
*
 999  END
      DOUBLE PRECISION FUNCTION A_INTERP_VECARRAY(VECSIZE,
     $     XVEC, YVEC, XIN)
C     Interpolates a function defined by the X-vector and Y-vector,
C     each of size VECSIZE, at X-value XIN.
C     Author: Jason Nielsen                Date: 1 June 2000
C     Inputs: 
C               VecSize          size of the two input vectors
C               Xvec             vector of known X values
C               Yvec             vector of corresponding Y values
C               Xin              value at which to interpolate
C     Note: The function tries to extrapolate if necessary at the 
C           endpoints.
C
      IMPLICIT NONE
      INTEGER VECSIZE, I
      DOUBLE PRECISION XVEC(VECSIZE), YVEC(VECSIZE), XIN

c      write(*,*) 'Entered A_interp_vecarray'

      I = 0
      A_INTERP_VECARRAY = 0.d0
      DO WHILE (A_INTERP_VECARRAY.EQ.0.d0 .AND. I.LT.VECSIZE)
         I = I + 1
c         write(*,*) 'I = ',i
c         write(*,*) 'Xin : ',xin
c         write(*,*) 'Xvec : ',xvec(i)
c         write(*,*) 'xvec+1 : ',xvec(i+1)
C     Interpolation
         IF (XIN.GE.XVEC(VECSIZE)) THEN
c            write(*,*) 'Extrapolating up'
c            write(*,*) 'XVEC(-1) : ',xvec(vecsize-1)
c            write(*,*) 'XVEC(top) : ',xvec(vecsize)
c            write(*,*) 'Yvec(-1) : ',yvec(vecsize-1)
c            write(*,*) 'Yvec(top) : ',yvec(vecsize)
            A_INTERP_VECARRAY = YVEC(VECSIZE) +
     $           (YVEC(VECSIZE)-YVEC(VECSIZE-1))/
     $           (XVEC(VECSIZE)-XVEC(VECSIZE-1))*(XIN-XVEC(VECSIZE))
            i = vecsize
         ELSE IF (XVEC(I).LE.XIN .AND. XVEC(I+1).GT.XIN) THEN
c            write(*,*) 'Interpolating'
c            write(*,*) 'Yvec : ',yvec(i)
c            write(*,*) 'Yvec+1 : ',yvec(i+1)
            A_INTERP_VECARRAY = YVEC(I) +
     $           (YVEC(I+1)-YVEC(I))/(XVEC(I+1)-XVEC(I))*
     $           (XIN-XVEC(I))
            i = vecsize
C     Extrapolation
         ELSE IF (XIN.LT.XVEC(1)) THEN
c            write(*,*) 'Extrapolating down'
c            write(*,*) 'Yvec(1) : ',Yvec(1)
c            write(*,*) 'Yvec(2) : ',Yvec(2)
            A_INTERP_VECARRAY = YVEC(1) +
     $           (YVEC(2)-YVEC(1))/(XVEC(2)-XVEC(1))*(XIN-XVEC(1)) 
            i = vecsize
         ENDIF
      ENDDO
      A_INTERP_VECARRAY = MAX(A_INTERP_VECARRAY,1.D-15)
c      write(*,*) 'Output : ',A_interp_vecarray
      RETURN
      END
      SUBROUTINE a_acnvec(vec,n)
*---------------------------------------------------------------
* (Original subroutine was d_acnvec from Alex Read.)
* Integrate the probability distribution in array vec and normalize
* the integral to 1.0
*---------------------------------------------------------------
*
      INTEGER n
      REAL*8 vec(n)
*
*......Integrate the probability distribution.
*
      DO i=2,n
         vec(i) = vec(i) + vec(i-1)
      ENDDO
*
      IF (vec(n) .eq. 0.d0) THEN
c         WRITE (6,*) 'a_acnvec: total is zero'
         RETURN
      ENDIF
*
*......Normalize the cumulative probability distribution to 1.
*
      DO i=1,n
         vec(i) = vec(i)/vec(n)
      ENDDO
*
      END
      DOUBLE PRECISION FUNCTION A1995N_TT_SIGNAL_MASS(MHIGGSHYP,
     $     IBRANCH, ISIG, X)
C     
      IMPLICIT NONE
      DOUBLE PRECISION MHIGGSHYP, X
C     
      INTEGER IBRANCH, ISIG, NMORPH_BINS, I
      PARAMETER (NMORPH_BINS=100)
      DOUBLE PRECISION LAST_MHIGGSHYP_CALLED
      INTEGER LAST_IBRANCH_CALLED, LAST_ISIG_CALLED
      DOUBLE PRECISION XINVALS(NMORPH_BINS), Y1INVALS(NMORPH_BINS),
     $     Y2INVALS(NMORPH_BINS)
      DOUBLE PRECISION PAR1, PAR2
      DOUBLE PRECISION XMORPHVALS(NMORPH_BINS), YMORPHVALS(NMORPH_BINS)
      DOUBLE PRECISION XMAX, XMIN, DX, TEMPX
      PARAMETER (XMAX=120.D0, XMIN=50.D0)
      DOUBLE PRECISION A_INTERP_VECARRAY
C     
      DOUBLE PRECISION A1995N_TT_ASHA_HTT60, A1995N_TT_ASHA_HTT65,
     $     A1995N_TT_ASHA_HTT70, A1995N_TT_ASHA_HTT75,
     $     A1995N_TT_ASHA_HTT80, A1995N_TT_ASHA_HTT85,
     $     A1995N_TT_ASHA_HTT90, A1995N_TT_ASHA_HTT95,
     $     A1995N_TT_ASHA_HTT100, A1995N_TT_ASHA_HTT105,
     $     A1995N_TT_ASHA_HTT107, A1995N_TT_ASHA_HTT110,
     $     A1995N_TT_ASHA_HTT115, A1995N_TT_ASHA_HTT120
      DOUBLE PRECISION A1995N_TT_ASHZ_HTT60, A1995N_TT_ASHZ_HTT65,
     $     A1995N_TT_ASHZ_HTT70, A1995N_TT_ASHZ_HTT75,
     $     A1995N_TT_ASHZ_HTT80, A1995N_TT_ASHZ_HTT85,
     $     A1995N_TT_ASHZ_HTT90, A1995N_TT_ASHZ_HTT95,
     $     A1995N_TT_ASHZ_HTT100, A1995N_TT_ASHZ_HTT105,
     $     A1995N_TT_ASHZ_HTT107, A1995N_TT_ASHZ_HTT110,
     $     A1995N_TT_ASHZ_HTT115, A1995N_TT_ASHZ_HTT120
      DOUBLE PRECISION A1995N_TT_HAONLY_HTT60, A1995N_TT_HAONLY_HTT65,
     $     A1995N_TT_HAONLY_HTT70, A1995N_TT_HAONLY_HTT75,
     $     A1995N_TT_HAONLY_HTT80, A1995N_TT_HAONLY_HTT85,
     $     A1995N_TT_HAONLY_HTT90, A1995N_TT_HAONLY_HTT95,
     $     A1995N_TT_HAONLY_HTT100, A1995N_TT_HAONLY_HTT105,
     $     A1995N_TT_HAONLY_HTT107, A1995N_TT_HAONLY_HTT110,
     $     A1995N_TT_HAONLY_HTT115, A1995N_TT_HAONLY_HTT120
      DOUBLE PRECISION A1995N_TT_HZONLY_HTT60, A1995N_TT_HZONLY_HTT65,
     $     A1995N_TT_HZONLY_HTT70, A1995N_TT_HZONLY_HTT75,
     $     A1995N_TT_HZONLY_HTT80, A1995N_TT_HZONLY_HTT85,
     $     A1995N_TT_HZONLY_HTT90, A1995N_TT_HZONLY_HTT95,
     $     A1995N_TT_HZONLY_HTT100, A1995N_TT_HZONLY_HTT105,
     $     A1995N_TT_HZONLY_HTT107, A1995N_TT_HZONLY_HTT110,
     $     A1995N_TT_HZONLY_HTT115, A1995N_TT_HZONLY_HTT120
C     
      DOUBLE PRECISION A1995N_TT_ASHA_TTZ60, A1995N_TT_ASHA_TTZ65,
     $     A1995N_TT_ASHA_TTZ70, A1995N_TT_ASHA_TTZ75,
     $     A1995N_TT_ASHA_TTZ80, A1995N_TT_ASHA_TTZ85,
     $     A1995N_TT_ASHA_TTZ90, A1995N_TT_ASHA_TTZ95,
     $     A1995N_TT_ASHA_TTZ100, A1995N_TT_ASHA_TTZ105,
     $     A1995N_TT_ASHA_TTZ107, A1995N_TT_ASHA_TTZ110,
     $     A1995N_TT_ASHA_TTZ115, A1995N_TT_ASHA_TTZ120
      DOUBLE PRECISION A1995N_TT_ASHZ_TTZ60, A1995N_TT_ASHZ_TTZ65,
     $     A1995N_TT_ASHZ_TTZ70, A1995N_TT_ASHZ_TTZ75,
     $     A1995N_TT_ASHZ_TTZ80, A1995N_TT_ASHZ_TTZ85,
     $     A1995N_TT_ASHZ_TTZ90, A1995N_TT_ASHZ_TTZ95,
     $     A1995N_TT_ASHZ_TTZ100, A1995N_TT_ASHZ_TTZ105,
     $     A1995N_TT_ASHZ_TTZ107, A1995N_TT_ASHZ_TTZ110,
     $     A1995N_TT_ASHZ_TTZ115, A1995N_TT_ASHZ_TTZ120
      DOUBLE PRECISION A1995N_TT_HAONLY_TTZ60, A1995N_TT_HAONLY_TTZ65,
     $     A1995N_TT_HAONLY_TTZ70, A1995N_TT_HAONLY_TTZ75,
     $     A1995N_TT_HAONLY_TTZ80, A1995N_TT_HAONLY_TTZ85,
     $     A1995N_TT_HAONLY_TTZ90, A1995N_TT_HAONLY_TTZ95,
     $     A1995N_TT_HAONLY_TTZ100, A1995N_TT_HAONLY_TTZ105,
     $     A1995N_TT_HAONLY_TTZ107, A1995N_TT_HAONLY_TTZ110,
     $     A1995N_TT_HAONLY_TTZ115, A1995N_TT_HAONLY_TTZ120
      DOUBLE PRECISION A1995N_TT_HZONLY_TTZ60, A1995N_TT_HZONLY_TTZ65,
     $     A1995N_TT_HZONLY_TTZ70, A1995N_TT_HZONLY_TTZ75,
     $     A1995N_TT_HZONLY_TTZ80, A1995N_TT_HZONLY_TTZ85,
     $     A1995N_TT_HZONLY_TTZ90, A1995N_TT_HZONLY_TTZ95,
     $     A1995N_TT_HZONLY_TTZ100, A1995N_TT_HZONLY_TTZ105,
     $     A1995N_TT_HZONLY_TTZ107, A1995N_TT_HZONLY_TTZ110,
     $     A1995N_TT_HZONLY_TTZ115, A1995N_TT_HZONLY_TTZ120
C     
      DOUBLE PRECISION A1995N_TT_ASHA_HATT60, A1995N_TT_ASHA_HATT65,
     $     A1995N_TT_ASHA_HATT70, A1995N_TT_ASHA_HATT75,
     $     A1995N_TT_ASHA_HATT80, A1995N_TT_ASHA_HATT85,
     $     A1995N_TT_ASHA_HATT90, A1995N_TT_ASHA_HATT95,
     $     A1995N_TT_ASHA_HATT100, A1995N_TT_ASHA_HATT105,
     $     A1995N_TT_ASHA_HATT107, A1995N_TT_ASHA_HATT110,
     $     A1995N_TT_ASHA_HATT115, A1995N_TT_ASHA_HATT120
      DOUBLE PRECISION A1995N_TT_ASHZ_HATT60, A1995N_TT_ASHZ_HATT65,
     $     A1995N_TT_ASHZ_HATT70, A1995N_TT_ASHZ_HATT75,
     $     A1995N_TT_ASHZ_HATT80, A1995N_TT_ASHZ_HATT85,
     $     A1995N_TT_ASHZ_HATT90, A1995N_TT_ASHZ_HATT95,
     $     A1995N_TT_ASHZ_HATT100, A1995N_TT_ASHZ_HATT105,
     $     A1995N_TT_ASHZ_HATT107, A1995N_TT_ASHZ_HATT110,
     $     A1995N_TT_ASHZ_HATT115, A1995N_TT_ASHZ_HATT120
      DOUBLE PRECISION A1995N_TT_HAONLY_HATT60, A1995N_TT_HAONLY_HATT65,
     $     A1995N_TT_HAONLY_HATT70, A1995N_TT_HAONLY_HATT75,
     $     A1995N_TT_HAONLY_HATT80, A1995N_TT_HAONLY_HATT85,
     $     A1995N_TT_HAONLY_HATT90, A1995N_TT_HAONLY_HATT95,
     $     A1995N_TT_HAONLY_HATT100, A1995N_TT_HAONLY_HATT105,
     $     A1995N_TT_HAONLY_HATT107, A1995N_TT_HAONLY_HATT110,
     $     A1995N_TT_HAONLY_HATT115, A1995N_TT_HAONLY_HATT120
      DOUBLE PRECISION A1995N_TT_HZONLY_HATT60, A1995N_TT_HZONLY_HATT65,
     $     A1995N_TT_HZONLY_HATT70, A1995N_TT_HZONLY_HATT75,
     $     A1995N_TT_HZONLY_HATT80, A1995N_TT_HZONLY_HATT85,
     $     A1995N_TT_HZONLY_HATT90, A1995N_TT_HZONLY_HATT95,
     $     A1995N_TT_HZONLY_HATT100, A1995N_TT_HZONLY_HATT105,
     $     A1995N_TT_HZONLY_HATT107, A1995N_TT_HZONLY_HATT110,
     $     A1995N_TT_HZONLY_HATT115, A1995N_TT_HZONLY_HATT120
C     
      IF (MHIGGSHYP.NE.LAST_MHIGGSHYP_CALLED .OR.
     $     IBRANCH.NE.LAST_IBRANCH_CALLED .OR.
     $     ISIG.NE.LAST_ISIG_CALLED) THEN
C     
C     Calculate the new morphed (interpolated) vectors         
C     only if some parameter has changed.
C     
C     TEMPX is the reconstructed mass used to build up the 
C     distributions to be morphed
C     

c         write(*,*) 'Entered 199.5 shape'
c         write(*,*) 'I think mh is : ',mhiggshyp
c         write(*,*) 'I think mreco is : ',x
c         write(*,*) 'I think ibranch is : ',ibranch
c         write(*,*) 'I think isig is : ',isig
         DX = (XMAX-XMIN)/(NMORPH_BINS-1)
         DO I = 1, NMORPH_BINS
c            write(*,*) 'Bin : ',i
            XINVALS(I) = XMIN + DX*(I-1)
            TEMPX= XMIN + DX*(I-1)
            IF (ISIG.EQ.1) THEN
               IF (MHIGGSHYP.GE.60. .AND. MHIGGSHYP.LT.65.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.65. .AND. MHIGGSHYP.LT.70.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.70. .AND. MHIGGSHYP.LT.75.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.105.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.105. .AND. MHIGGSHYP.LT.107.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.107. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.115.) THEN
c                  write(*,*) 'Got into 110.le.mh.lt.115'
                  IF (IBRANCH.EQ.1) THEN
c                     write(*,*) 'Got into branch 1'
c                     write(*,*) 'Temp x is : ',tempx
                     Y1INVALS(I) = A1995N_tt_haonly_htt110(TEMPX)
c                     write(*,*) 'Y1INVALS : ',y1invals(i)
                     Y2INVALS(I) = A1995N_tt_haonly_htt115(TEMPX)
c                     write(*,*) 'Y2INVALS : ',y2invals(i)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_htt120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_htt120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_htt120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_htt120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A1995N_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.2) THEN
               IF (MHIGGSHYP.GE.60. .AND. MHIGGSHYP.LT.65.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.65. .AND. MHIGGSHYP.LT.70.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.70. .AND. MHIGGSHYP.LT.75.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.105.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.105. .AND. MHIGGSHYP.LT.107.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.107. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_ttz120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_ttz120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_ttz120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_ttz120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A1995N_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.3) THEN
               IF (MHIGGSHYP.GE.60. .AND. MHIGGSHYP.LT.65.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt60(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.65. .AND. MHIGGSHYP.LT.70.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt65(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.70. .AND. MHIGGSHYP.LT.75.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt70(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt75(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt80(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt85(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt90(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt95(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.105.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt100(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.105. .AND. MHIGGSHYP.LT.107.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt105(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.107. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt107(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt110(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt115(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A1995N_tt_haonly_hatt120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_haonly_hatt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A1995N_tt_asha_hatt120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_asha_hatt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A1995N_tt_ashz_hatt120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_ashz_hatt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A1995N_tt_hzonly_hatt120(TEMPX)
                     Y2INVALS(I) = A1995N_tt_hzonly_hatt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A1995N_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ENDIF
         ENDDO
c         write(*,*) 'Got through main loop'
         CALL A_MORPH(NMORPH_BINS, XMIN, XMAX, Y1INVALS, Y2INVALS,
     $        PAR1, PAR2, MHIGGSHYP, XMORPHVALS, YMORPHVALS)  
c         write(*,*) 'Called A_morph'
      ENDIF                     ! End of the new roots loop
C     Otherwise the left-over morphed vectors are used.
      A1995N_TT_SIGNAL_MASS = A_INTERP_VECARRAY(NMORPH_BINS,
     $     XMORPHVALS, YMORPHVALS, X)
C     
c      write(*,*) A1995n_tt_signal_mass
      LAST_MHIGGSHYP_CALLED = MHIGGSHYP
      LAST_IBRANCH_CALLED = IBRANCH
      LAST_ISIG_CALLED = ISIG
      RETURN
      END
C

      DOUBLE PRECISION FUNCTION A2016N_TT_SIGNAL_MASS(MHIGGSHYP,
     $     IBRANCH, ISIG, X)
C     
      IMPLICIT NONE
      DOUBLE PRECISION MHIGGSHYP, X
C     
      INTEGER IBRANCH, ISIG, NMORPH_BINS, I
      PARAMETER (NMORPH_BINS=100)
      DOUBLE PRECISION LAST_MHIGGSHYP_CALLED
      INTEGER LAST_IBRANCH_CALLED, LAST_ISIG_CALLED
      DOUBLE PRECISION XINVALS(NMORPH_BINS), Y1INVALS(NMORPH_BINS),
     $     Y2INVALS(NMORPH_BINS)
      DOUBLE PRECISION PAR1, PAR2
      DOUBLE PRECISION XMORPHVALS(NMORPH_BINS), YMORPHVALS(NMORPH_BINS)
      DOUBLE PRECISION XMAX, XMIN, DX, TEMPX
      PARAMETER (XMAX=120.D0, XMIN=50.D0)
      DOUBLE PRECISION A_INTERP_VECARRAY
C     
      DOUBLE PRECISION A2016N_TT_ASHA_HTT60, A2016N_TT_ASHA_HTT65,
     $     A2016N_TT_ASHA_HTT70, A2016N_TT_ASHA_HTT75,
     $     A2016N_TT_ASHA_HTT80, A2016N_TT_ASHA_HTT85,
     $     A2016N_TT_ASHA_HTT90, A2016N_TT_ASHA_HTT95,
     $     A2016N_TT_ASHA_HTT100, A2016N_TT_ASHA_HTT105,
     $     A2016N_TT_ASHA_HTT107, A2016N_TT_ASHA_HTT110,
     $     A2016N_TT_ASHA_HTT115, A2016N_TT_ASHA_HTT120
      DOUBLE PRECISION A2016N_TT_ASHZ_HTT60, A2016N_TT_ASHZ_HTT65,
     $     A2016N_TT_ASHZ_HTT70, A2016N_TT_ASHZ_HTT75,
     $     A2016N_TT_ASHZ_HTT80, A2016N_TT_ASHZ_HTT85,
     $     A2016N_TT_ASHZ_HTT90, A2016N_TT_ASHZ_HTT95,
     $     A2016N_TT_ASHZ_HTT100, A2016N_TT_ASHZ_HTT105,
     $     A2016N_TT_ASHZ_HTT107, A2016N_TT_ASHZ_HTT110,
     $     A2016N_TT_ASHZ_HTT115, A2016N_TT_ASHZ_HTT120
      DOUBLE PRECISION A2016N_TT_HAONLY_HTT60, A2016N_TT_HAONLY_HTT65,
     $     A2016N_TT_HAONLY_HTT70, A2016N_TT_HAONLY_HTT75,
     $     A2016N_TT_HAONLY_HTT80, A2016N_TT_HAONLY_HTT85,
     $     A2016N_TT_HAONLY_HTT90, A2016N_TT_HAONLY_HTT95,
     $     A2016N_TT_HAONLY_HTT100, A2016N_TT_HAONLY_HTT105,
     $     A2016N_TT_HAONLY_HTT107, A2016N_TT_HAONLY_HTT110,
     $     A2016N_TT_HAONLY_HTT115, A2016N_TT_HAONLY_HTT120
      DOUBLE PRECISION A2016N_TT_HZONLY_HTT60, A2016N_TT_HZONLY_HTT65,
     $     A2016N_TT_HZONLY_HTT70, A2016N_TT_HZONLY_HTT75,
     $     A2016N_TT_HZONLY_HTT80, A2016N_TT_HZONLY_HTT85,
     $     A2016N_TT_HZONLY_HTT90, A2016N_TT_HZONLY_HTT95,
     $     A2016N_TT_HZONLY_HTT100, A2016N_TT_HZONLY_HTT105,
     $     A2016N_TT_HZONLY_HTT107, A2016N_TT_HZONLY_HTT110,
     $     A2016N_TT_HZONLY_HTT115, A2016N_TT_HZONLY_HTT120
C     
      DOUBLE PRECISION A2016N_TT_ASHA_TTZ60, A2016N_TT_ASHA_TTZ65,
     $     A2016N_TT_ASHA_TTZ70, A2016N_TT_ASHA_TTZ75,
     $     A2016N_TT_ASHA_TTZ80, A2016N_TT_ASHA_TTZ85,
     $     A2016N_TT_ASHA_TTZ90, A2016N_TT_ASHA_TTZ95,
     $     A2016N_TT_ASHA_TTZ100, A2016N_TT_ASHA_TTZ105,
     $     A2016N_TT_ASHA_TTZ107, A2016N_TT_ASHA_TTZ110,
     $     A2016N_TT_ASHA_TTZ115, A2016N_TT_ASHA_TTZ120
      DOUBLE PRECISION A2016N_TT_ASHZ_TTZ60, A2016N_TT_ASHZ_TTZ65,
     $     A2016N_TT_ASHZ_TTZ70, A2016N_TT_ASHZ_TTZ75,
     $     A2016N_TT_ASHZ_TTZ80, A2016N_TT_ASHZ_TTZ85,
     $     A2016N_TT_ASHZ_TTZ90, A2016N_TT_ASHZ_TTZ95,
     $     A2016N_TT_ASHZ_TTZ100, A2016N_TT_ASHZ_TTZ105,
     $     A2016N_TT_ASHZ_TTZ107, A2016N_TT_ASHZ_TTZ110,
     $     A2016N_TT_ASHZ_TTZ115, A2016N_TT_ASHZ_TTZ120
      DOUBLE PRECISION A2016N_TT_HAONLY_TTZ60, A2016N_TT_HAONLY_TTZ65,
     $     A2016N_TT_HAONLY_TTZ70, A2016N_TT_HAONLY_TTZ75,
     $     A2016N_TT_HAONLY_TTZ80, A2016N_TT_HAONLY_TTZ85,
     $     A2016N_TT_HAONLY_TTZ90, A2016N_TT_HAONLY_TTZ95,
     $     A2016N_TT_HAONLY_TTZ100, A2016N_TT_HAONLY_TTZ105,
     $     A2016N_TT_HAONLY_TTZ107, A2016N_TT_HAONLY_TTZ110,
     $     A2016N_TT_HAONLY_TTZ115, A2016N_TT_HAONLY_TTZ120
      DOUBLE PRECISION A2016N_TT_HZONLY_TTZ60, A2016N_TT_HZONLY_TTZ65,
     $     A2016N_TT_HZONLY_TTZ70, A2016N_TT_HZONLY_TTZ75,
     $     A2016N_TT_HZONLY_TTZ80, A2016N_TT_HZONLY_TTZ85,
     $     A2016N_TT_HZONLY_TTZ90, A2016N_TT_HZONLY_TTZ95,
     $     A2016N_TT_HZONLY_TTZ100, A2016N_TT_HZONLY_TTZ105,
     $     A2016N_TT_HZONLY_TTZ107, A2016N_TT_HZONLY_TTZ110,
     $     A2016N_TT_HZONLY_TTZ115, A2016N_TT_HZONLY_TTZ120
C     
      DOUBLE PRECISION A2016N_TT_ASHA_HATT60, A2016N_TT_ASHA_HATT65,
     $     A2016N_TT_ASHA_HATT70, A2016N_TT_ASHA_HATT75,
     $     A2016N_TT_ASHA_HATT80, A2016N_TT_ASHA_HATT85,
     $     A2016N_TT_ASHA_HATT90, A2016N_TT_ASHA_HATT95,
     $     A2016N_TT_ASHA_HATT100, A2016N_TT_ASHA_HATT105,
     $     A2016N_TT_ASHA_HATT107, A2016N_TT_ASHA_HATT110,
     $     A2016N_TT_ASHA_HATT115, A2016N_TT_ASHA_HATT120
      DOUBLE PRECISION A2016N_TT_ASHZ_HATT60, A2016N_TT_ASHZ_HATT65,
     $     A2016N_TT_ASHZ_HATT70, A2016N_TT_ASHZ_HATT75,
     $     A2016N_TT_ASHZ_HATT80, A2016N_TT_ASHZ_HATT85,
     $     A2016N_TT_ASHZ_HATT90, A2016N_TT_ASHZ_HATT95,
     $     A2016N_TT_ASHZ_HATT100, A2016N_TT_ASHZ_HATT105,
     $     A2016N_TT_ASHZ_HATT107, A2016N_TT_ASHZ_HATT110,
     $     A2016N_TT_ASHZ_HATT115, A2016N_TT_ASHZ_HATT120
      DOUBLE PRECISION A2016N_TT_HAONLY_HATT60, A2016N_TT_HAONLY_HATT65,
     $     A2016N_TT_HAONLY_HATT70, A2016N_TT_HAONLY_HATT75,
     $     A2016N_TT_HAONLY_HATT80, A2016N_TT_HAONLY_HATT85,
     $     A2016N_TT_HAONLY_HATT90, A2016N_TT_HAONLY_HATT95,
     $     A2016N_TT_HAONLY_HATT100, A2016N_TT_HAONLY_HATT105,
     $     A2016N_TT_HAONLY_HATT107, A2016N_TT_HAONLY_HATT110,
     $     A2016N_TT_HAONLY_HATT115, A2016N_TT_HAONLY_HATT120
      DOUBLE PRECISION A2016N_TT_HZONLY_HATT60, A2016N_TT_HZONLY_HATT65,
     $     A2016N_TT_HZONLY_HATT70, A2016N_TT_HZONLY_HATT75,
     $     A2016N_TT_HZONLY_HATT80, A2016N_TT_HZONLY_HATT85,
     $     A2016N_TT_HZONLY_HATT90, A2016N_TT_HZONLY_HATT95,
     $     A2016N_TT_HZONLY_HATT100, A2016N_TT_HZONLY_HATT105,
     $     A2016N_TT_HZONLY_HATT107, A2016N_TT_HZONLY_HATT110,
     $     A2016N_TT_HZONLY_HATT115, A2016N_TT_HZONLY_HATT120
C     
      IF (MHIGGSHYP.NE.LAST_MHIGGSHYP_CALLED .OR.
     $     IBRANCH.NE.LAST_IBRANCH_CALLED .OR.
     $     ISIG.NE.LAST_ISIG_CALLED) THEN
C     
C     Calculate the new morphed (interpolated) vectors         
C     only if some parameter has changed.
C     
         DX = (XMAX-XMIN)/(NMORPH_BINS-1)
         DO I = 1, NMORPH_BINS
            XINVALS(I) = XMIN + DX*(I-1)
            TEMPX = XMIN + DX*(I-1)
            IF (ISIG.EQ.1) THEN
               IF (MHIGGSHYP.GE.60. .AND. MHIGGSHYP.LT.65.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.65. .AND. MHIGGSHYP.LT.70.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.70. .AND. MHIGGSHYP.LT.75.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.105.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.105. .AND. MHIGGSHYP.LT.107.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.107. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_htt120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_htt120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_htt120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_htt120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A2016N_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.2) THEN
               IF (MHIGGSHYP.GE.60. .AND. MHIGGSHYP.LT.65.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.65. .AND. MHIGGSHYP.LT.70.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.70. .AND. MHIGGSHYP.LT.75.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.105.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.105. .AND. MHIGGSHYP.LT.107.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.107. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_ttz120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_ttz120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_ttz120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_ttz120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A2016N_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.3) THEN
               IF (MHIGGSHYP.GE.60. .AND. MHIGGSHYP.LT.65.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt60(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt65(TEMPX)
                     PAR1 = 60.
                     PAR2 = 65.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.65. .AND. MHIGGSHYP.LT.70.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt65(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt70(TEMPX)
                     PAR1 = 65.
                     PAR2 = 70.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.70. .AND. MHIGGSHYP.LT.75.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt70(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt75(TEMPX)
                     PAR1 = 70.
                     PAR2 = 75.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt75(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt80(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt85(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt90(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt95(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.105.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt100(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.105. .AND. MHIGGSHYP.LT.107.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt105(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt107(TEMPX)
                     PAR1 = 105.
                     PAR2 = 107.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.107. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt107(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt110(TEMPX)
                     PAR1 = 107.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt110(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt115(TEMPX)
                     PAR1 = 110.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt115(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt120(TEMPX)
                     PAR1 = 115.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A2016N_tt_haonly_hatt120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_haonly_hatt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A2016N_tt_asha_hatt120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_asha_hatt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A2016N_tt_ashz_hatt120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_ashz_hatt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A2016N_tt_hzonly_hatt120(TEMPX)
                     Y2INVALS(I) = A2016N_tt_hzonly_hatt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A2016N_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ENDIF
         ENDDO
         CALL A_MORPH(NMORPH_BINS, XMIN, XMAX, Y1INVALS, Y2INVALS,
     $        PAR1, PAR2, MHIGGSHYP, XMORPHVALS, YMORPHVALS)  
      ENDIF                     ! End of the new roots loop
C     Otherwise the left-over morphed vectors are used.
      A2016N_TT_SIGNAL_MASS = A_INTERP_VECARRAY(NMORPH_BINS,
     $     XMORPHVALS, YMORPHVALS, X)
C     
      LAST_MHIGGSHYP_CALLED = MHIGGSHYP
      LAST_IBRANCH_CALLED = IBRANCH
      LAST_ISIG_CALLED = ISIG
      RETURN
      END
C

      DOUBLE PRECISION FUNCTION A204_TT_SIGNAL_MASS(MHIGGSHYP,
     $     IBRANCH, ISIG, X)
C     
      IMPLICIT NONE
      DOUBLE PRECISION MHIGGSHYP, X
C     
      INTEGER IBRANCH, ISIG, NMORPH_BINS, I
      PARAMETER (NMORPH_BINS=100)
      DOUBLE PRECISION LAST_MHIGGSHYP_CALLED
      INTEGER LAST_IBRANCH_CALLED, LAST_ISIG_CALLED
      DOUBLE PRECISION XINVALS(NMORPH_BINS), Y1INVALS(NMORPH_BINS),
     $     Y2INVALS(NMORPH_BINS)
      DOUBLE PRECISION PAR1, PAR2
      DOUBLE PRECISION XMORPHVALS(NMORPH_BINS), YMORPHVALS(NMORPH_BINS)
      DOUBLE PRECISION XMAX, XMIN, DX, TEMPX
      PARAMETER (XMAX=120.D0, XMIN=50.D0)
      DOUBLE PRECISION A_INTERP_VECARRAY
C     
      DOUBLE PRECISION A204_TT_ASHA_HTT75,
     $     A204_TT_ASHA_HTT80, A204_TT_ASHA_HTT85,
     $     A204_TT_ASHA_HTT90, A204_TT_ASHA_HTT95,
     $     A204_TT_ASHA_HTT100, A204_TT_ASHA_HTT102,
     $     A204_TT_ASHA_HTT104, A204_TT_ASHA_HTT106,
     $     A204_TT_ASHA_HTT108, A204_TT_ASHA_HTT110,
     $     A204_TT_ASHA_HTT111, A204_TT_ASHA_HTT112,
     $     A204_TT_ASHA_HTT1128, A204_TT_ASHA_HTT114,
     $     A204_TT_ASHA_HTT115, A204_TT_ASHA_HTT116,
     $     A204_TT_ASHA_HTT118, A204_TT_ASHA_HTT120
      DOUBLE PRECISION A204_TT_ASHZ_HTT75,
     $     A204_TT_ASHZ_HTT80, A204_TT_ASHZ_HTT85,
     $     A204_TT_ASHZ_HTT90, A204_TT_ASHZ_HTT95,
     $     A204_TT_ASHZ_HTT100, A204_TT_ASHZ_HTT102,
     $     A204_TT_ASHZ_HTT104, A204_TT_ASHZ_HTT106,
     $     A204_TT_ASHZ_HTT108, A204_TT_ASHZ_HTT110,
     $     A204_TT_ASHZ_HTT111, A204_TT_ASHZ_HTT112,
     $     A204_TT_ASHZ_HTT1128, A204_TT_ASHZ_HTT114,
     $     A204_TT_ASHZ_HTT115, A204_TT_ASHZ_HTT116,
     $     A204_TT_ASHZ_HTT118, A204_TT_ASHZ_HTT120
      DOUBLE PRECISION A204_TT_HAONLY_HTT75,
     $     A204_TT_HAONLY_HTT80, A204_TT_HAONLY_HTT85,
     $     A204_TT_HAONLY_HTT90, A204_TT_HAONLY_HTT95,
     $     A204_TT_HAONLY_HTT100, A204_TT_HAONLY_HTT102,
     $     A204_TT_HAONLY_HTT104, A204_TT_HAONLY_HTT106,
     $     A204_TT_HAONLY_HTT108, A204_TT_HAONLY_HTT110,
     $     A204_TT_HAONLY_HTT111, A204_TT_HAONLY_HTT112,
     $     A204_TT_HAONLY_HTT1128, A204_TT_HAONLY_HTT114,
     $     A204_TT_HAONLY_HTT115, A204_TT_HAONLY_HTT116,
     $     A204_TT_HAONLY_HTT118, A204_TT_HAONLY_HTT120
      DOUBLE PRECISION A204_TT_HZONLY_HTT75,
     $     A204_TT_HZONLY_HTT80, A204_TT_HZONLY_HTT85,
     $     A204_TT_HZONLY_HTT90, A204_TT_HZONLY_HTT95,
     $     A204_TT_HZONLY_HTT100, A204_TT_HZONLY_HTT102,
     $     A204_TT_HZONLY_HTT104, A204_TT_HZONLY_HTT106,
     $     A204_TT_HZONLY_HTT108, A204_TT_HZONLY_HTT110,
     $     A204_TT_HZONLY_HTT111, A204_TT_HZONLY_HTT112,
     $     A204_TT_HZONLY_HTT1128, A204_TT_HZONLY_HTT114,
     $     A204_TT_HZONLY_HTT115, A204_TT_HZONLY_HTT116,
     $     A204_TT_HZONLY_HTT118, A204_TT_HZONLY_HTT120
C     
      DOUBLE PRECISION A204_TT_ASHA_TTZ75,
     $     A204_TT_ASHA_TTZ80, A204_TT_ASHA_TTZ85,
     $     A204_TT_ASHA_TTZ90, A204_TT_ASHA_TTZ95,
     $     A204_TT_ASHA_TTZ100, A204_TT_ASHA_TTZ102,
     $     A204_TT_ASHA_TTZ104, A204_TT_ASHA_TTZ106,
     $     A204_TT_ASHA_TTZ108, A204_TT_ASHA_TTZ110,
     $     A204_TT_ASHA_TTZ111, A204_TT_ASHA_TTZ112,
     $     A204_TT_ASHA_TTZ1128, A204_TT_ASHA_TTZ114,
     $     A204_TT_ASHA_TTZ115, A204_TT_ASHA_TTZ116,
     $     A204_TT_ASHA_TTZ118, A204_TT_ASHA_TTZ120
      DOUBLE PRECISION A204_TT_ASHZ_TTZ75,
     $     A204_TT_ASHZ_TTZ80, A204_TT_ASHZ_TTZ85,
     $     A204_TT_ASHZ_TTZ90, A204_TT_ASHZ_TTZ95,
     $     A204_TT_ASHZ_TTZ100, A204_TT_ASHZ_TTZ102,
     $     A204_TT_ASHZ_TTZ104, A204_TT_ASHZ_TTZ106,
     $     A204_TT_ASHZ_TTZ108, A204_TT_ASHZ_TTZ110,
     $     A204_TT_ASHZ_TTZ111, A204_TT_ASHZ_TTZ112,
     $     A204_TT_ASHZ_TTZ1128, A204_TT_ASHZ_TTZ114,
     $     A204_TT_ASHZ_TTZ115, A204_TT_ASHZ_TTZ116,
     $     A204_TT_ASHZ_TTZ118, A204_TT_ASHZ_TTZ120
      DOUBLE PRECISION A204_TT_HAONLY_TTZ75,
     $     A204_TT_HAONLY_TTZ80, A204_TT_HAONLY_TTZ85,
     $     A204_TT_HAONLY_TTZ90, A204_TT_HAONLY_TTZ95,
     $     A204_TT_HAONLY_TTZ100, A204_TT_HAONLY_TTZ102,
     $     A204_TT_HAONLY_TTZ104, A204_TT_HAONLY_TTZ106,
     $     A204_TT_HAONLY_TTZ108, A204_TT_HAONLY_TTZ110,
     $     A204_TT_HAONLY_TTZ111, A204_TT_HAONLY_TTZ112,
     $     A204_TT_HAONLY_TTZ1128, A204_TT_HAONLY_TTZ114,
     $     A204_TT_HAONLY_TTZ115, A204_TT_HAONLY_TTZ116,
     $     A204_TT_HAONLY_TTZ118, A204_TT_HAONLY_TTZ120
      DOUBLE PRECISION A204_TT_HZONLY_TTZ75,
     $     A204_TT_HZONLY_TTZ80, A204_TT_HZONLY_TTZ85,
     $     A204_TT_HZONLY_TTZ90, A204_TT_HZONLY_TTZ95,
     $     A204_TT_HZONLY_TTZ100, A204_TT_HZONLY_TTZ102,
     $     A204_TT_HZONLY_TTZ104, A204_TT_HZONLY_TTZ106,
     $     A204_TT_HZONLY_TTZ108, A204_TT_HZONLY_TTZ110,
     $     A204_TT_HZONLY_TTZ111, A204_TT_HZONLY_TTZ112,
     $     A204_TT_HZONLY_TTZ1128, A204_TT_HZONLY_TTZ114,
     $     A204_TT_HZONLY_TTZ115, A204_TT_HZONLY_TTZ116,
     $     A204_TT_HZONLY_TTZ118, A204_TT_HZONLY_TTZ120
C     
      DOUBLE PRECISION A204_TT_ASHA_HATT75,
     $     A204_TT_ASHA_HATT80, A204_TT_ASHA_HATT85,
     $     A204_TT_ASHA_HATT90, A204_TT_ASHA_HATT95,
     $     A204_TT_ASHA_HATT100, A204_TT_ASHA_HATT102
      DOUBLE PRECISION A204_TT_ASHZ_HATT75,
     $     A204_TT_ASHZ_HATT80, A204_TT_ASHZ_HATT85,
     $     A204_TT_ASHZ_HATT90, A204_TT_ASHZ_HATT95,
     $     A204_TT_ASHZ_HATT100, A204_TT_ASHZ_HATT102
      DOUBLE PRECISION A204_TT_HAONLY_HATT75,
     $     A204_TT_HAONLY_HATT80, A204_TT_HAONLY_HATT85,
     $     A204_TT_HAONLY_HATT90, A204_TT_HAONLY_HATT95,
     $     A204_TT_HAONLY_HATT100, A204_TT_HAONLY_HATT102
      DOUBLE PRECISION A204_TT_HZONLY_HATT75,
     $     A204_TT_HZONLY_HATT80, A204_TT_HZONLY_HATT85,
     $     A204_TT_HZONLY_HATT90, A204_TT_HZONLY_HATT95,
     $     A204_TT_HZONLY_HATT100, A204_TT_HZONLY_HATT102
C     
      IF (MHIGGSHYP.NE.LAST_MHIGGSHYP_CALLED .OR.
     $     IBRANCH.NE.LAST_IBRANCH_CALLED .OR.
     $     ISIG.NE.LAST_ISIG_CALLED) THEN
C     
C     Calculate the new morphed (interpolated) vectors         
C     only if some parameter has changed.
C     
         DX = (XMAX-XMIN)/(NMORPH_BINS-1)
         DO I = 1, NMORPH_BINS
            XINVALS(I) = XMIN + DX*(I-1)
            TEMPX = XMIN + DX*(I-1)
            IF (ISIG.EQ.1) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt75(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt75(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt75(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt75(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt80(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt80(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt80(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt80(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt85(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt85(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt85(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt85(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt90(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt90(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt90(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt90(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt95(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt95(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt95(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt95(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.102.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt100(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt100(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt100(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt100(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.102. .AND. MHIGGSHYP.LT.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt102(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt104(TEMPX)
                     PAR1 = 102.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt102(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt104(TEMPX)
                     PAR1 = 102.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt102(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt104(TEMPX)
                     PAR1 = 102.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt102(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt104(TEMPX)
                     PAR1 = 102.
                     PAR2 = 104.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.104. .AND. MHIGGSHYP.LT.106.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt104(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt104(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt104(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt104(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.106. .AND. MHIGGSHYP.LT.108.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt106(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt106(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt106(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt106(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.108. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt108(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt108(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt108(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt108(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.112.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt110(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt110(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt110(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt110(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112. .AND. MHIGGSHYP.LT.112.8) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt112(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt1128(TEMPX)
                     PAR1 = 112.
                     PAR2 = 112.8
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt112(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt1128(TEMPX)
                     PAR1 = 112.
                     PAR2 = 112.8
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt112(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt1128(TEMPX)
                     PAR1 = 112.
                     PAR2 = 112.8
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt112(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt1128(TEMPX)
                     PAR1 = 112.
                     PAR2 = 112.8
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112.8 .AND. MHIGGSHYP.LT.114.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt1128(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt114(TEMPX)
                     PAR1 = 112.8
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt1128(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt114(TEMPX)
                     PAR1 = 112.8
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt1128(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt114(TEMPX)
                     PAR1 = 112.8
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt1128(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt114(TEMPX)
                     PAR1 = 112.8
                     PAR2 = 114.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt114(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt114(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt114(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt114(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.116.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt115(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt115(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt115(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt115(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116. .AND. MHIGGSHYP.LT.118.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt116(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt118(TEMPX)
                     PAR1 = 116.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt116(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt118(TEMPX)
                     PAR1 = 116.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt116(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt118(TEMPX)
                     PAR1 = 116.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt116(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt118(TEMPX)
                     PAR1 = 116.
                     PAR2 = 118.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt118(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt120(TEMPX)
                     PAR1 = 118.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt118(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt120(TEMPX)
                     PAR1 = 118.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt118(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt120(TEMPX)
                     PAR1 = 118.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt118(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt120(TEMPX)
                     PAR1 = 118.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_htt120(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_htt120(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_htt120(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_htt120(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A204_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.2) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz75(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz75(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz75(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz75(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz80(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz80(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz80(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz80(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz85(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz85(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz85(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz85(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz90(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz90(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz90(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz90(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz95(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz95(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz95(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz95(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.102.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz100(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz100(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz100(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz100(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.102. .AND. MHIGGSHYP.LT.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz102(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz104(TEMPX)
                     PAR1 = 102.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz102(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz104(TEMPX)
                     PAR1 = 102.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz102(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz104(TEMPX)
                     PAR1 = 102.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz102(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz104(TEMPX)
                     PAR1 = 102.
                     PAR2 = 104.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.104. .AND. MHIGGSHYP.LT.106.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz104(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz104(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz104(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz104(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.106. .AND. MHIGGSHYP.LT.108.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz106(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz106(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz106(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz106(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.108. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz108(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz108(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz108(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz108(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.112.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz110(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz110(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz110(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz110(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112. .AND. MHIGGSHYP.LT.112.8) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz112(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz1128(TEMPX)
                     PAR1 = 112.
                     PAR2 = 112.8
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz112(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz1128(TEMPX)
                     PAR1 = 112.
                     PAR2 = 112.8
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz112(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz1128(TEMPX)
                     PAR1 = 112.
                     PAR2 = 112.8
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz112(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz1128(TEMPX)
                     PAR1 = 112.
                     PAR2 = 112.8
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112.8 .AND. MHIGGSHYP.LT.114.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz1128(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz114(TEMPX)
                     PAR1 = 112.8
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz1128(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz114(TEMPX)
                     PAR1 = 112.8
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz1128(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz114(TEMPX)
                     PAR1 = 112.8
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz1128(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz114(TEMPX)
                     PAR1 = 112.8
                     PAR2 = 114.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz114(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz114(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz114(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz114(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.116.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz115(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz115(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz115(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz115(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116. .AND. MHIGGSHYP.LT.118.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz116(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz118(TEMPX)
                     PAR1 = 116.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz116(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz118(TEMPX)
                     PAR1 = 116.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz116(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz118(TEMPX)
                     PAR1 = 116.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz116(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz118(TEMPX)
                     PAR1 = 116.
                     PAR2 = 118.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz118(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz120(TEMPX)
                     PAR1 = 118.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz118(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz120(TEMPX)
                     PAR1 = 118.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz118(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz120(TEMPX)
                     PAR1 = 118.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz118(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 118.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_ttz120(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_ttz120(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_ttz120(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_ttz120(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A204_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.3) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_hatt75(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_hatt75(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_hatt75(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_hatt75(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_hatt80(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_hatt80(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_hatt80(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_hatt80(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_hatt85(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_hatt85(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_hatt85(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_hatt85(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_hatt90(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_hatt90(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_hatt90(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_hatt90(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_hatt95(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_hatt95(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_hatt95(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_hatt95(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LE.102.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A204_tt_haonly_hatt100(TEMPX)
                     Y2INVALS(I) = A204_tt_haonly_hatt102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A204_tt_asha_hatt100(TEMPX)
                     Y2INVALS(I) = A204_tt_asha_hatt102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A204_tt_ashz_hatt100(TEMPX)
                     Y2INVALS(I) = A204_tt_ashz_hatt102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A204_tt_hzonly_hatt100(TEMPX)
                     Y2INVALS(I) = A204_tt_hzonly_hatt102(TEMPX)
                     PAR1 = 100.
                     PAR2 = 102.
                  ENDIF
               ELSE
                 A204_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ENDIF
         ENDDO
         CALL A_MORPH(NMORPH_BINS, XMIN, XMAX, Y1INVALS, Y2INVALS,
     $        PAR1, PAR2, MHIGGSHYP, XMORPHVALS, YMORPHVALS)  
      ENDIF                     ! End of the new roots loop
C     Otherwise the left-over morphed vectors are used.
      A204_TT_SIGNAL_MASS = A_INTERP_VECARRAY(NMORPH_BINS,
     $     XMORPHVALS, YMORPHVALS, X)
C     
      LAST_MHIGGSHYP_CALLED = MHIGGSHYP
      LAST_IBRANCH_CALLED = IBRANCH
      LAST_ISIG_CALLED = ISIG
      RETURN
      END
C

      DOUBLE PRECISION FUNCTION A206_TT_SIGNAL_MASS(MHIGGSHYP,
     $     IBRANCH, ISIG, X)
C     
      IMPLICIT NONE
      DOUBLE PRECISION MHIGGSHYP, X
C     
      INTEGER IBRANCH, ISIG, NMORPH_BINS, I
      PARAMETER (NMORPH_BINS=100)
      DOUBLE PRECISION LAST_MHIGGSHYP_CALLED
      INTEGER LAST_IBRANCH_CALLED, LAST_ISIG_CALLED
      DOUBLE PRECISION XINVALS(NMORPH_BINS), Y1INVALS(NMORPH_BINS),
     $     Y2INVALS(NMORPH_BINS)
      DOUBLE PRECISION PAR1, PAR2
      DOUBLE PRECISION XMORPHVALS(NMORPH_BINS), YMORPHVALS(NMORPH_BINS)
      DOUBLE PRECISION XMAX, XMIN, DX, TEMPX
      PARAMETER (XMAX=120.D0, XMIN=50.D0)
      DOUBLE PRECISION A_INTERP_VECARRAY
C     
      DOUBLE PRECISION A206_TT_ASHA_HTT75,
     $     A206_TT_ASHA_HTT80, A206_TT_ASHA_HTT85,
     $     A206_TT_ASHA_HTT90, A206_TT_ASHA_HTT95,
     $     A206_TT_ASHA_HTT100, A206_TT_ASHA_HTT104,
     $     A206_TT_ASHA_HTT106, A206_TT_ASHA_HTT108,
     $     A206_TT_ASHA_HTT110, A206_TT_ASHA_HTT112,
     $     A206_TT_ASHA_HTT113, A206_TT_ASHA_HTT114,
     $     A206_TT_ASHA_HTT1148, A206_TT_ASHA_HTT116,
     $     A206_TT_ASHA_HTT117, A206_TT_ASHA_HTT118,
     $     A206_TT_ASHA_HTT119, A206_TT_ASHA_HTT120
      DOUBLE PRECISION A206_TT_ASHZ_HTT75,
     $     A206_TT_ASHZ_HTT80, A206_TT_ASHZ_HTT85,
     $     A206_TT_ASHZ_HTT90, A206_TT_ASHZ_HTT95,
     $     A206_TT_ASHZ_HTT100, A206_TT_ASHZ_HTT104,
     $     A206_TT_ASHZ_HTT106, A206_TT_ASHZ_HTT108,
     $     A206_TT_ASHZ_HTT110, A206_TT_ASHZ_HTT112,
     $     A206_TT_ASHZ_HTT113, A206_TT_ASHZ_HTT114,
     $     A206_TT_ASHZ_HTT1148, A206_TT_ASHZ_HTT116,
     $     A206_TT_ASHZ_HTT117, A206_TT_ASHZ_HTT118,
     $     A206_TT_ASHZ_HTT119, A206_TT_ASHZ_HTT120
      DOUBLE PRECISION A206_TT_HAONLY_HTT75,
     $     A206_TT_HAONLY_HTT80, A206_TT_HAONLY_HTT85,
     $     A206_TT_HAONLY_HTT90, A206_TT_HAONLY_HTT95,
     $     A206_TT_HAONLY_HTT100, A206_TT_HAONLY_HTT104,
     $     A206_TT_HAONLY_HTT106, A206_TT_HAONLY_HTT108,
     $     A206_TT_HAONLY_HTT110, A206_TT_HAONLY_HTT112,
     $     A206_TT_HAONLY_HTT113, A206_TT_HAONLY_HTT114,
     $     A206_TT_HAONLY_HTT1148, A206_TT_HAONLY_HTT116,
     $     A206_TT_HAONLY_HTT117, A206_TT_HAONLY_HTT118,
     $     A206_TT_HAONLY_HTT119, A206_TT_HAONLY_HTT120
      DOUBLE PRECISION A206_TT_HZONLY_HTT75,
     $     A206_TT_HZONLY_HTT80, A206_TT_HZONLY_HTT85,
     $     A206_TT_HZONLY_HTT90, A206_TT_HZONLY_HTT95,
     $     A206_TT_HZONLY_HTT100, A206_TT_HZONLY_HTT104,
     $     A206_TT_HZONLY_HTT106, A206_TT_HZONLY_HTT108,
     $     A206_TT_HZONLY_HTT110, A206_TT_HZONLY_HTT112,
     $     A206_TT_HZONLY_HTT113, A206_TT_HZONLY_HTT114,
     $     A206_TT_HZONLY_HTT1148, A206_TT_HZONLY_HTT116,
     $     A206_TT_HZONLY_HTT117, A206_TT_HZONLY_HTT118,
     $     A206_TT_HZONLY_HTT119, A206_TT_HZONLY_HTT120
C     
      DOUBLE PRECISION A206_TT_ASHA_TTZ75,
     $     A206_TT_ASHA_TTZ80, A206_TT_ASHA_TTZ85,
     $     A206_TT_ASHA_TTZ90, A206_TT_ASHA_TTZ95,
     $     A206_TT_ASHA_TTZ100, A206_TT_ASHA_TTZ104,
     $     A206_TT_ASHA_TTZ106, A206_TT_ASHA_TTZ108,
     $     A206_TT_ASHA_TTZ110, A206_TT_ASHA_TTZ112,
     $     A206_TT_ASHA_TTZ113, A206_TT_ASHA_TTZ114,
     $     A206_TT_ASHA_TTZ1148, A206_TT_ASHA_TTZ116,
     $     A206_TT_ASHA_TTZ117, A206_TT_ASHA_TTZ118,
     $     A206_TT_ASHA_TTZ119, A206_TT_ASHA_TTZ120
      DOUBLE PRECISION A206_TT_ASHZ_TTZ75,
     $     A206_TT_ASHZ_TTZ80, A206_TT_ASHZ_TTZ85,
     $     A206_TT_ASHZ_TTZ90, A206_TT_ASHZ_TTZ95,
     $     A206_TT_ASHZ_TTZ100, A206_TT_ASHZ_TTZ104,
     $     A206_TT_ASHZ_TTZ106, A206_TT_ASHZ_TTZ108,
     $     A206_TT_ASHZ_TTZ110, A206_TT_ASHZ_TTZ112,
     $     A206_TT_ASHZ_TTZ113, A206_TT_ASHZ_TTZ114,
     $     A206_TT_ASHZ_TTZ1148, A206_TT_ASHZ_TTZ116,
     $     A206_TT_ASHZ_TTZ117, A206_TT_ASHZ_TTZ118,
     $     A206_TT_ASHZ_TTZ119, A206_TT_ASHZ_TTZ120
      DOUBLE PRECISION A206_TT_HAONLY_TTZ75,
     $     A206_TT_HAONLY_TTZ80, A206_TT_HAONLY_TTZ85,
     $     A206_TT_HAONLY_TTZ90, A206_TT_HAONLY_TTZ95,
     $     A206_TT_HAONLY_TTZ100, A206_TT_HAONLY_TTZ104,
     $     A206_TT_HAONLY_TTZ106, A206_TT_HAONLY_TTZ108,
     $     A206_TT_HAONLY_TTZ110, A206_TT_HAONLY_TTZ112,
     $     A206_TT_HAONLY_TTZ113, A206_TT_HAONLY_TTZ114,
     $     A206_TT_HAONLY_TTZ1148, A206_TT_HAONLY_TTZ116,
     $     A206_TT_HAONLY_TTZ117, A206_TT_HAONLY_TTZ118,
     $     A206_TT_HAONLY_TTZ119, A206_TT_HAONLY_TTZ120
      DOUBLE PRECISION A206_TT_HZONLY_TTZ75,
     $     A206_TT_HZONLY_TTZ80, A206_TT_HZONLY_TTZ85,
     $     A206_TT_HZONLY_TTZ90, A206_TT_HZONLY_TTZ95,
     $     A206_TT_HZONLY_TTZ100, A206_TT_HZONLY_TTZ104,
     $     A206_TT_HZONLY_TTZ106, A206_TT_HZONLY_TTZ108,
     $     A206_TT_HZONLY_TTZ110, A206_TT_HZONLY_TTZ112,
     $     A206_TT_HZONLY_TTZ113, A206_TT_HZONLY_TTZ114,
     $     A206_TT_HZONLY_TTZ1148, A206_TT_HZONLY_TTZ116,
     $     A206_TT_HZONLY_TTZ117, A206_TT_HZONLY_TTZ118,
     $     A206_TT_HZONLY_TTZ119, A206_TT_HZONLY_TTZ120
C     
      DOUBLE PRECISION A206_TT_ASHA_HATT75,
     $     A206_TT_ASHA_HATT80, A206_TT_ASHA_HATT85,
     $     A206_TT_ASHA_HATT90, A206_TT_ASHA_HATT95,
     $     A206_TT_ASHA_HATT100, A206_TT_ASHA_HATT103
      DOUBLE PRECISION A206_TT_ASHZ_HATT75,
     $     A206_TT_ASHZ_HATT80, A206_TT_ASHZ_HATT85,
     $     A206_TT_ASHZ_HATT90, A206_TT_ASHZ_HATT95,
     $     A206_TT_ASHZ_HATT100, A206_TT_ASHZ_HATT103
      DOUBLE PRECISION A206_TT_HAONLY_HATT75,
     $     A206_TT_HAONLY_HATT80, A206_TT_HAONLY_HATT85,
     $     A206_TT_HAONLY_HATT90, A206_TT_HAONLY_HATT95,
     $     A206_TT_HAONLY_HATT100, A206_TT_HAONLY_HATT103
      DOUBLE PRECISION A206_TT_HZONLY_HATT75,
     $     A206_TT_HZONLY_HATT80, A206_TT_HZONLY_HATT85,
     $     A206_TT_HZONLY_HATT90, A206_TT_HZONLY_HATT95,
     $     A206_TT_HZONLY_HATT100, A206_TT_HZONLY_HATT103
C     
      IF (MHIGGSHYP.NE.LAST_MHIGGSHYP_CALLED .OR.
     $     IBRANCH.NE.LAST_IBRANCH_CALLED .OR.
     $     ISIG.NE.LAST_ISIG_CALLED) THEN
C     
C     Calculate the new morphed (interpolated) vectors         
C     only if some parameter has changed.
C     
         DX = (XMAX-XMIN)/(NMORPH_BINS-1)
         DO I = 1, NMORPH_BINS
            XINVALS(I) = XMIN + DX*(I-1)
            TEMPX = XMIN + DX*(I-1)
            IF (ISIG.EQ.1) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt75(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt75(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt75(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt75(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt80(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt80(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt80(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt80(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt85(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt85(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt85(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt85(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt90(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt90(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt90(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt90(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt95(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt95(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt95(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt95(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt100(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt100(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt100(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt100(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.104. .AND. MHIGGSHYP.LT.106.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt104(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt104(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt104(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt104(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.106. .AND. MHIGGSHYP.LT.108.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt106(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt106(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt106(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt106(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.108. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt108(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt108(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt108(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt108(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.112.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt110(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt110(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt110(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt110(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112. .AND. MHIGGSHYP.LT.113.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt112(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt112(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt112(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt112(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.113. .AND. MHIGGSHYP.LT.114.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt113(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt113(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt113(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt113(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114. .AND. MHIGGSHYP.LT.114.8) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt114(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt1148(TEMPX)
                     PAR1 = 114.
                     PAR2 = 114.8
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt114(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt1148(TEMPX)
                     PAR1 = 114.
                     PAR2 = 114.8
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt114(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt1148(TEMPX)
                     PAR1 = 114.
                     PAR2 = 114.8
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt114(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt1148(TEMPX)
                     PAR1 = 114.
                     PAR2 = 114.8
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114.8 .AND. MHIGGSHYP.LT.116.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt1148(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt116(TEMPX)
                     PAR1 = 114.8
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt1148(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt116(TEMPX)
                     PAR1 = 114.8
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt1148(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt116(TEMPX)
                     PAR1 = 114.8
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt1148(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt116(TEMPX)
                     PAR1 = 114.8
                     PAR2 = 116.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116. .AND. MHIGGSHYP.LT.117.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt116(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt116(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt116(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt116(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.117. .AND. MHIGGSHYP.LT.118.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt117(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt117(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt117(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt117(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118. .AND. MHIGGSHYP.LT.119.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt118(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt118(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt118(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt118(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.119. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt119(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt119(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt119(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt119(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_htt120(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_htt120(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_htt120(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_htt120(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A206_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.2) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz75(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz75(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz75(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz75(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz80(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz80(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz80(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz80(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz85(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz85(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz85(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz85(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz90(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz90(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz90(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz90(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz95(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz95(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz95(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz95(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz100(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz100(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz100(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz100(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.104. .AND. MHIGGSHYP.LT.106.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz104(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz104(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz104(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz104(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.106. .AND. MHIGGSHYP.LT.108.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz106(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz106(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz106(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz106(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.108. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz108(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz108(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz108(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz108(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.112.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz110(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz110(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz110(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz110(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112. .AND. MHIGGSHYP.LT.113.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz112(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz112(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz112(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz112(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.113. .AND. MHIGGSHYP.LT.114.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz113(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz113(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz113(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz113(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114. .AND. MHIGGSHYP.LT.114.8) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz114(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz1148(TEMPX)
                     PAR1 = 114.
                     PAR2 = 114.8
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz114(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz1148(TEMPX)
                     PAR1 = 114.
                     PAR2 = 114.8
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz114(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz1148(TEMPX)
                     PAR1 = 114.
                     PAR2 = 114.8
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz114(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz1148(TEMPX)
                     PAR1 = 114.
                     PAR2 = 114.8
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114.8 .AND. MHIGGSHYP.LT.116.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz1148(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz116(TEMPX)
                     PAR1 = 114.8
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz1148(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz116(TEMPX)
                     PAR1 = 114.8
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz1148(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz116(TEMPX)
                     PAR1 = 114.8
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz1148(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz116(TEMPX)
                     PAR1 = 114.8
                     PAR2 = 116.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116. .AND. MHIGGSHYP.LT.117.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz116(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz116(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz116(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz116(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.117. .AND. MHIGGSHYP.LT.118.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz117(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz117(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz117(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz117(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118. .AND. MHIGGSHYP.LT.119.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz118(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz118(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz118(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz118(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.119. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz119(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz119(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz119(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz119(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_ttz120(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_ttz120(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_ttz120(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_ttz120(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A206_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.3) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_hatt75(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_hatt75(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_hatt75(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_hatt75(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_hatt80(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_hatt80(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_hatt80(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_hatt80(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_hatt85(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_hatt85(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_hatt85(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_hatt85(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_hatt90(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_hatt90(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_hatt90(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_hatt90(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_hatt95(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_hatt95(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_hatt95(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_hatt95(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LE.103.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A206_tt_haonly_hatt100(TEMPX)
                     Y2INVALS(I) = A206_tt_haonly_hatt103(TEMPX)
                     PAR1 = 100.
                     PAR2 = 103.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A206_tt_asha_hatt100(TEMPX)
                     Y2INVALS(I) = A206_tt_asha_hatt103(TEMPX)
                     PAR1 = 100.
                     PAR2 = 103.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A206_tt_ashz_hatt100(TEMPX)
                     Y2INVALS(I) = A206_tt_ashz_hatt103(TEMPX)
                     PAR1 = 100.
                     PAR2 = 103.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A206_tt_hzonly_hatt100(TEMPX)
                     Y2INVALS(I) = A206_tt_hzonly_hatt103(TEMPX)
                     PAR1 = 100.
                     PAR2 = 103.
                  ENDIF
               ELSE
                 A206_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ENDIF
         ENDDO
         CALL A_MORPH(NMORPH_BINS, XMIN, XMAX, Y1INVALS, Y2INVALS,
     $        PAR1, PAR2, MHIGGSHYP, XMORPHVALS, YMORPHVALS)  
      ENDIF                     ! End of the new roots loop
C     Otherwise the left-over morphed vectors are used.
      A206_TT_SIGNAL_MASS = A_INTERP_VECARRAY(NMORPH_BINS,
     $     XMORPHVALS, YMORPHVALS, X)
C     
      LAST_MHIGGSHYP_CALLED = MHIGGSHYP
      LAST_IBRANCH_CALLED = IBRANCH
      LAST_ISIG_CALLED = ISIG
      RETURN
      END
C

      DOUBLE PRECISION FUNCTION A208_TT_SIGNAL_MASS(MHIGGSHYP,
     $     IBRANCH, ISIG, X)
C     
      IMPLICIT NONE
      DOUBLE PRECISION MHIGGSHYP, X
C     
      INTEGER IBRANCH, ISIG, NMORPH_BINS, I
      PARAMETER (NMORPH_BINS=100)
      DOUBLE PRECISION LAST_MHIGGSHYP_CALLED
      INTEGER LAST_IBRANCH_CALLED, LAST_ISIG_CALLED
      DOUBLE PRECISION XINVALS(NMORPH_BINS), Y1INVALS(NMORPH_BINS),
     $     Y2INVALS(NMORPH_BINS)
      DOUBLE PRECISION PAR1, PAR2
      DOUBLE PRECISION XMORPHVALS(NMORPH_BINS), YMORPHVALS(NMORPH_BINS)
      DOUBLE PRECISION XMAX, XMIN, DX, TEMPX
      PARAMETER (XMAX=120.D0, XMIN=50.D0)
      DOUBLE PRECISION A_INTERP_VECARRAY
C     
      DOUBLE PRECISION A208_TT_ASHA_HTT75,
     $     A208_TT_ASHA_HTT80, A208_TT_ASHA_HTT85,
     $     A208_TT_ASHA_HTT90, A208_TT_ASHA_HTT95,
     $     A208_TT_ASHA_HTT100, A208_TT_ASHA_HTT104,
     $     A208_TT_ASHA_HTT106, A208_TT_ASHA_HTT108,
     $     A208_TT_ASHA_HTT110, A208_TT_ASHA_HTT112,
     $     A208_TT_ASHA_HTT113, A208_TT_ASHA_HTT114,
     $     A208_TT_ASHA_HTT115, A208_TT_ASHA_HTT116,
     $     A208_TT_ASHA_HTT1168, A208_TT_ASHA_HTT118,
     $     A208_TT_ASHA_HTT119, A208_TT_ASHA_HTT120
      DOUBLE PRECISION A208_TT_ASHZ_HTT75,
     $     A208_TT_ASHZ_HTT80, A208_TT_ASHZ_HTT85,
     $     A208_TT_ASHZ_HTT90, A208_TT_ASHZ_HTT95,
     $     A208_TT_ASHZ_HTT100, A208_TT_ASHZ_HTT104,
     $     A208_TT_ASHZ_HTT106, A208_TT_ASHZ_HTT108,
     $     A208_TT_ASHZ_HTT110, A208_TT_ASHZ_HTT112,
     $     A208_TT_ASHZ_HTT113, A208_TT_ASHZ_HTT114,
     $     A208_TT_ASHZ_HTT115, A208_TT_ASHZ_HTT116,
     $     A208_TT_ASHZ_HTT1168, A208_TT_ASHZ_HTT118,
     $     A208_TT_ASHZ_HTT119, A208_TT_ASHZ_HTT120
      DOUBLE PRECISION A208_TT_HAONLY_HTT75,
     $     A208_TT_HAONLY_HTT80, A208_TT_HAONLY_HTT85,
     $     A208_TT_HAONLY_HTT90, A208_TT_HAONLY_HTT95,
     $     A208_TT_HAONLY_HTT100, A208_TT_HAONLY_HTT104,
     $     A208_TT_HAONLY_HTT106, A208_TT_HAONLY_HTT108,
     $     A208_TT_HAONLY_HTT110, A208_TT_HAONLY_HTT112,
     $     A208_TT_HAONLY_HTT113, A208_TT_HAONLY_HTT114,
     $     A208_TT_HAONLY_HTT115, A208_TT_HAONLY_HTT116,
     $     A208_TT_HAONLY_HTT1168, A208_TT_HAONLY_HTT118,
     $     A208_TT_HAONLY_HTT119, A208_TT_HAONLY_HTT120
      DOUBLE PRECISION A208_TT_HZONLY_HTT75,
     $     A208_TT_HZONLY_HTT80, A208_TT_HZONLY_HTT85,
     $     A208_TT_HZONLY_HTT90, A208_TT_HZONLY_HTT95,
     $     A208_TT_HZONLY_HTT100, A208_TT_HZONLY_HTT104,
     $     A208_TT_HZONLY_HTT106, A208_TT_HZONLY_HTT108,
     $     A208_TT_HZONLY_HTT110, A208_TT_HZONLY_HTT112,
     $     A208_TT_HZONLY_HTT113, A208_TT_HZONLY_HTT114,
     $     A208_TT_HZONLY_HTT115, A208_TT_HZONLY_HTT116,
     $     A208_TT_HZONLY_HTT1168, A208_TT_HZONLY_HTT118,
     $     A208_TT_HZONLY_HTT119, A208_TT_HZONLY_HTT120
C     
      DOUBLE PRECISION A208_TT_ASHA_TTZ75,
     $     A208_TT_ASHA_TTZ80, A208_TT_ASHA_TTZ85,
     $     A208_TT_ASHA_TTZ90, A208_TT_ASHA_TTZ95,
     $     A208_TT_ASHA_TTZ100, A208_TT_ASHA_TTZ104,
     $     A208_TT_ASHA_TTZ106, A208_TT_ASHA_TTZ108,
     $     A208_TT_ASHA_TTZ110, A208_TT_ASHA_TTZ112,
     $     A208_TT_ASHA_TTZ113, A208_TT_ASHA_TTZ114,
     $     A208_TT_ASHA_TTZ115, A208_TT_ASHA_TTZ116,
     $     A208_TT_ASHA_TTZ1168, A208_TT_ASHA_TTZ118,
     $     A208_TT_ASHA_TTZ119, A208_TT_ASHA_TTZ120
      DOUBLE PRECISION A208_TT_ASHZ_TTZ75,
     $     A208_TT_ASHZ_TTZ80, A208_TT_ASHZ_TTZ85,
     $     A208_TT_ASHZ_TTZ90, A208_TT_ASHZ_TTZ95,
     $     A208_TT_ASHZ_TTZ100, A208_TT_ASHZ_TTZ104,
     $     A208_TT_ASHZ_TTZ106, A208_TT_ASHZ_TTZ108,
     $     A208_TT_ASHZ_TTZ110, A208_TT_ASHZ_TTZ112,
     $     A208_TT_ASHZ_TTZ113, A208_TT_ASHZ_TTZ114,
     $     A208_TT_ASHZ_TTZ115, A208_TT_ASHZ_TTZ116,
     $     A208_TT_ASHZ_TTZ1168, A208_TT_ASHZ_TTZ118,
     $     A208_TT_ASHZ_TTZ119, A208_TT_ASHZ_TTZ120
      DOUBLE PRECISION A208_TT_HAONLY_TTZ75,
     $     A208_TT_HAONLY_TTZ80, A208_TT_HAONLY_TTZ85,
     $     A208_TT_HAONLY_TTZ90, A208_TT_HAONLY_TTZ95,
     $     A208_TT_HAONLY_TTZ100, A208_TT_HAONLY_TTZ104,
     $     A208_TT_HAONLY_TTZ106, A208_TT_HAONLY_TTZ108,
     $     A208_TT_HAONLY_TTZ110, A208_TT_HAONLY_TTZ112,
     $     A208_TT_HAONLY_TTZ113, A208_TT_HAONLY_TTZ114,
     $     A208_TT_HAONLY_TTZ115, A208_TT_HAONLY_TTZ116,
     $     A208_TT_HAONLY_TTZ1168, A208_TT_HAONLY_TTZ118,
     $     A208_TT_HAONLY_TTZ119, A208_TT_HAONLY_TTZ120
      DOUBLE PRECISION A208_TT_HZONLY_TTZ75,
     $     A208_TT_HZONLY_TTZ80, A208_TT_HZONLY_TTZ85,
     $     A208_TT_HZONLY_TTZ90, A208_TT_HZONLY_TTZ95,
     $     A208_TT_HZONLY_TTZ100, A208_TT_HZONLY_TTZ104,
     $     A208_TT_HZONLY_TTZ106, A208_TT_HZONLY_TTZ108,
     $     A208_TT_HZONLY_TTZ110, A208_TT_HZONLY_TTZ112,
     $     A208_TT_HZONLY_TTZ113, A208_TT_HZONLY_TTZ114,
     $     A208_TT_HZONLY_TTZ115, A208_TT_HZONLY_TTZ116,
     $     A208_TT_HZONLY_TTZ1168, A208_TT_HZONLY_TTZ118,
     $     A208_TT_HZONLY_TTZ119, A208_TT_HZONLY_TTZ120
C     
      DOUBLE PRECISION A208_TT_ASHA_HATT75,
     $     A208_TT_ASHA_HATT80, A208_TT_ASHA_HATT85,
     $     A208_TT_ASHA_HATT90, A208_TT_ASHA_HATT95,
     $     A208_TT_ASHA_HATT100, A208_TT_ASHA_HATT104
      DOUBLE PRECISION A208_TT_ASHZ_HATT75,
     $     A208_TT_ASHZ_HATT80, A208_TT_ASHZ_HATT85,
     $     A208_TT_ASHZ_HATT90, A208_TT_ASHZ_HATT95,
     $     A208_TT_ASHZ_HATT100, A208_TT_ASHZ_HATT104
      DOUBLE PRECISION A208_TT_HAONLY_HATT75,
     $     A208_TT_HAONLY_HATT80, A208_TT_HAONLY_HATT85,
     $     A208_TT_HAONLY_HATT90, A208_TT_HAONLY_HATT95,
     $     A208_TT_HAONLY_HATT100, A208_TT_HAONLY_HATT104
      DOUBLE PRECISION A208_TT_HZONLY_HATT75,
     $     A208_TT_HZONLY_HATT80, A208_TT_HZONLY_HATT85,
     $     A208_TT_HZONLY_HATT90, A208_TT_HZONLY_HATT95,
     $     A208_TT_HZONLY_HATT100, A208_TT_HZONLY_HATT104
C     
      IF (MHIGGSHYP.NE.LAST_MHIGGSHYP_CALLED .OR.
     $     IBRANCH.NE.LAST_IBRANCH_CALLED .OR.
     $     ISIG.NE.LAST_ISIG_CALLED) THEN
C     
C     Calculate the new morphed (interpolated) vectors         
C     only if some parameter has changed.
C     
         DX = (XMAX-XMIN)/(NMORPH_BINS-1)
         DO I = 1, NMORPH_BINS
            XINVALS(I) = XMIN + DX*(I-1)
            TEMPX = XMIN + DX*(I-1)
            IF (ISIG.EQ.1) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt75(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt75(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt75(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt75(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt80(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt80(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt80(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt80(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt85(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt85(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt85(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt85(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt90(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt90(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt90(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt90(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt95(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt95(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt95(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt95(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt100(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt100(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt100(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt100(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.104. .AND. MHIGGSHYP.LT.106.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt104(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt104(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt104(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt104(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.106. .AND. MHIGGSHYP.LT.108.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt106(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt106(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt106(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt106(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.108. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt108(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt108(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt108(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt108(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.112.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt110(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt110(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt110(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt110(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112. .AND. MHIGGSHYP.LT.113.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt112(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt112(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt112(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt112(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.113. .AND. MHIGGSHYP.LT.114.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt113(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt113(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt113(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt113(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt114(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt114(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt114(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt114(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.116.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt115(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt115(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt115(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt115(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116. .AND. MHIGGSHYP.LT.116.8) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt116(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt1168(TEMPX)
                     PAR1 = 116.
                     PAR2 = 116.8
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt116(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt1168(TEMPX)
                     PAR1 = 116.
                     PAR2 = 116.8
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt116(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt1168(TEMPX)
                     PAR1 = 116.
                     PAR2 = 116.8
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt116(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt1168(TEMPX)
                     PAR1 = 116.
                     PAR2 = 116.8
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116.8 .AND. MHIGGSHYP.LT.118.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt1168(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt118(TEMPX)
                     PAR1 = 116.8
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt1168(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt118(TEMPX)
                     PAR1 = 116.8
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt1168(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt118(TEMPX)
                     PAR1 = 116.8
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt1168(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt118(TEMPX)
                     PAR1 = 116.8
                     PAR2 = 118.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118. .AND. MHIGGSHYP.LT.119.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt118(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt118(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt118(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt118(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.119. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt119(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt119(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt119(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt119(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_htt120(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_htt120(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_htt120(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_htt120(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A208_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.2) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz75(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz75(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz75(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz75(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz80(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz80(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz80(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz80(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz85(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz85(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz85(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz85(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz90(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz90(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz90(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz90(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz95(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz95(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz95(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz95(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz100(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz100(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz100(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz100(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.104. .AND. MHIGGSHYP.LT.106.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz104(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz104(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz104(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz104(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.106. .AND. MHIGGSHYP.LT.108.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz106(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz106(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz106(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz106(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.108. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz108(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz108(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz108(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz108(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.112.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz110(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz110(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz110(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz110(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112. .AND. MHIGGSHYP.LT.113.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz112(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz112(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz112(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz112(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.113. .AND. MHIGGSHYP.LT.114.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz113(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz113(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz113(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz113(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz114(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz114(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz114(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz114(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.116.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz115(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz115(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz115(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz115(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116. .AND. MHIGGSHYP.LT.116.8) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz116(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz1168(TEMPX)
                     PAR1 = 116.
                     PAR2 = 116.8
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz116(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz1168(TEMPX)
                     PAR1 = 116.
                     PAR2 = 116.8
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz116(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz1168(TEMPX)
                     PAR1 = 116.
                     PAR2 = 116.8
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz116(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz1168(TEMPX)
                     PAR1 = 116.
                     PAR2 = 116.8
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116.8 .AND. MHIGGSHYP.LT.118.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz1168(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz118(TEMPX)
                     PAR1 = 116.8
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz1168(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz118(TEMPX)
                     PAR1 = 116.8
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz1168(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz118(TEMPX)
                     PAR1 = 116.8
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz1168(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz118(TEMPX)
                     PAR1 = 116.8
                     PAR2 = 118.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118. .AND. MHIGGSHYP.LT.119.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz118(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz118(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz118(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz118(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz119(TEMPX)
                     PAR1 = 118.
                     PAR2 = 119.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.119. .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz119(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz119(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz119(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz119(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 119.
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_ttz120(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_ttz120(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_ttz120(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_ttz120(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A208_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.3) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_hatt75(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_hatt75(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_hatt75(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_hatt75(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_hatt80(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_hatt80(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_hatt80(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_hatt80(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_hatt85(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_hatt85(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_hatt85(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_hatt85(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_hatt90(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_hatt90(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_hatt90(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_hatt90(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_hatt95(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_hatt95(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_hatt95(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_hatt95(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LE.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A208_tt_haonly_hatt100(TEMPX)
                     Y2INVALS(I) = A208_tt_haonly_hatt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A208_tt_asha_hatt100(TEMPX)
                     Y2INVALS(I) = A208_tt_asha_hatt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A208_tt_ashz_hatt100(TEMPX)
                     Y2INVALS(I) = A208_tt_ashz_hatt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A208_tt_hzonly_hatt100(TEMPX)
                     Y2INVALS(I) = A208_tt_hzonly_hatt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ENDIF
               ELSE
                 A208_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ENDIF
         ENDDO
         CALL A_MORPH(NMORPH_BINS, XMIN, XMAX, Y1INVALS, Y2INVALS,
     $        PAR1, PAR2, MHIGGSHYP, XMORPHVALS, YMORPHVALS)  
      ENDIF                     ! End of the new roots loop
C     Otherwise the left-over morphed vectors are used.
      A208_TT_SIGNAL_MASS = A_INTERP_VECARRAY(NMORPH_BINS,
     $     XMORPHVALS, YMORPHVALS, X)
C     
      LAST_MHIGGSHYP_CALLED = MHIGGSHYP
      LAST_IBRANCH_CALLED = IBRANCH
      LAST_ISIG_CALLED = ISIG
      RETURN
      END
C

      DOUBLE PRECISION FUNCTION A210_TT_SIGNAL_MASS(MHIGGSHYP,
     $     IBRANCH, ISIG, X)
C     
      IMPLICIT NONE
      DOUBLE PRECISION MHIGGSHYP, X
C     
      INTEGER IBRANCH, ISIG, NMORPH_BINS, I
      PARAMETER (NMORPH_BINS=100)
      DOUBLE PRECISION LAST_MHIGGSHYP_CALLED
      INTEGER LAST_IBRANCH_CALLED, LAST_ISIG_CALLED
      DOUBLE PRECISION XINVALS(NMORPH_BINS), Y1INVALS(NMORPH_BINS),
     $     Y2INVALS(NMORPH_BINS)
      DOUBLE PRECISION PAR1, PAR2
      DOUBLE PRECISION XMORPHVALS(NMORPH_BINS), YMORPHVALS(NMORPH_BINS)
      DOUBLE PRECISION XMAX, XMIN, DX, TEMPX
      PARAMETER (XMAX=120.D0, XMIN=50.D0)
      DOUBLE PRECISION A_INTERP_VECARRAY
C     
      DOUBLE PRECISION A210_TT_ASHA_HTT75,
     $     A210_TT_ASHA_HTT80, A210_TT_ASHA_HTT85,
     $     A210_TT_ASHA_HTT90, A210_TT_ASHA_HTT95,
     $     A210_TT_ASHA_HTT100, A210_TT_ASHA_HTT104,
     $     A210_TT_ASHA_HTT106, A210_TT_ASHA_HTT108,
     $     A210_TT_ASHA_HTT110, A210_TT_ASHA_HTT112,
     $     A210_TT_ASHA_HTT113, A210_TT_ASHA_HTT114,
     $     A210_TT_ASHA_HTT115, A210_TT_ASHA_HTT116,
     $     A210_TT_ASHA_HTT117, A210_TT_ASHA_HTT118,
     $     A210_TT_ASHA_HTT1188, A210_TT_ASHA_HTT120
      DOUBLE PRECISION A210_TT_ASHZ_HTT75,
     $     A210_TT_ASHZ_HTT80, A210_TT_ASHZ_HTT85,
     $     A210_TT_ASHZ_HTT90, A210_TT_ASHZ_HTT95,
     $     A210_TT_ASHZ_HTT100, A210_TT_ASHZ_HTT104,
     $     A210_TT_ASHZ_HTT106, A210_TT_ASHZ_HTT108,
     $     A210_TT_ASHZ_HTT110, A210_TT_ASHZ_HTT112,
     $     A210_TT_ASHZ_HTT113, A210_TT_ASHZ_HTT114,
     $     A210_TT_ASHZ_HTT115, A210_TT_ASHZ_HTT116,
     $     A210_TT_ASHZ_HTT117, A210_TT_ASHZ_HTT118,
     $     A210_TT_ASHZ_HTT1188, A210_TT_ASHZ_HTT120
      DOUBLE PRECISION A210_TT_HAONLY_HTT75,
     $     A210_TT_HAONLY_HTT80, A210_TT_HAONLY_HTT85,
     $     A210_TT_HAONLY_HTT90, A210_TT_HAONLY_HTT95,
     $     A210_TT_HAONLY_HTT100, A210_TT_HAONLY_HTT104,
     $     A210_TT_HAONLY_HTT106, A210_TT_HAONLY_HTT108,
     $     A210_TT_HAONLY_HTT110, A210_TT_HAONLY_HTT112,
     $     A210_TT_HAONLY_HTT113, A210_TT_HAONLY_HTT114,
     $     A210_TT_HAONLY_HTT115, A210_TT_HAONLY_HTT116,
     $     A210_TT_HAONLY_HTT117, A210_TT_HAONLY_HTT118,
     $     A210_TT_HAONLY_HTT1188, A210_TT_HAONLY_HTT120
      DOUBLE PRECISION A210_TT_HZONLY_HTT75,
     $     A210_TT_HZONLY_HTT80, A210_TT_HZONLY_HTT85,
     $     A210_TT_HZONLY_HTT90, A210_TT_HZONLY_HTT95,
     $     A210_TT_HZONLY_HTT100, A210_TT_HZONLY_HTT104,
     $     A210_TT_HZONLY_HTT106, A210_TT_HZONLY_HTT108,
     $     A210_TT_HZONLY_HTT110, A210_TT_HZONLY_HTT112,
     $     A210_TT_HZONLY_HTT113, A210_TT_HZONLY_HTT114,
     $     A210_TT_HZONLY_HTT115, A210_TT_HZONLY_HTT116,
     $     A210_TT_HZONLY_HTT117, A210_TT_HZONLY_HTT118,
     $     A210_TT_HZONLY_HTT1188, A210_TT_HZONLY_HTT120
C     
      DOUBLE PRECISION A210_TT_ASHA_TTZ75,
     $     A210_TT_ASHA_TTZ80, A210_TT_ASHA_TTZ85,
     $     A210_TT_ASHA_TTZ90, A210_TT_ASHA_TTZ95,
     $     A210_TT_ASHA_TTZ100, A210_TT_ASHA_TTZ104,
     $     A210_TT_ASHA_TTZ106, A210_TT_ASHA_TTZ108,
     $     A210_TT_ASHA_TTZ110, A210_TT_ASHA_TTZ112,
     $     A210_TT_ASHA_TTZ113, A210_TT_ASHA_TTZ114,
     $     A210_TT_ASHA_TTZ115, A210_TT_ASHA_TTZ116,
     $     A210_TT_ASHA_TTZ117, A210_TT_ASHA_TTZ118,
     $     A210_TT_ASHA_TTZ1188, A210_TT_ASHA_TTZ120
      DOUBLE PRECISION A210_TT_ASHZ_TTZ75,
     $     A210_TT_ASHZ_TTZ80, A210_TT_ASHZ_TTZ85,
     $     A210_TT_ASHZ_TTZ90, A210_TT_ASHZ_TTZ95,
     $     A210_TT_ASHZ_TTZ100, A210_TT_ASHZ_TTZ104,
     $     A210_TT_ASHZ_TTZ106, A210_TT_ASHZ_TTZ108,
     $     A210_TT_ASHZ_TTZ110, A210_TT_ASHZ_TTZ112,
     $     A210_TT_ASHZ_TTZ113, A210_TT_ASHZ_TTZ114,
     $     A210_TT_ASHZ_TTZ115, A210_TT_ASHZ_TTZ116,
     $     A210_TT_ASHZ_TTZ117, A210_TT_ASHZ_TTZ118,
     $     A210_TT_ASHZ_TTZ1188, A210_TT_ASHZ_TTZ120
      DOUBLE PRECISION A210_TT_HAONLY_TTZ75,
     $     A210_TT_HAONLY_TTZ80, A210_TT_HAONLY_TTZ85,
     $     A210_TT_HAONLY_TTZ90, A210_TT_HAONLY_TTZ95,
     $     A210_TT_HAONLY_TTZ100, A210_TT_HAONLY_TTZ104,
     $     A210_TT_HAONLY_TTZ106, A210_TT_HAONLY_TTZ108,
     $     A210_TT_HAONLY_TTZ110, A210_TT_HAONLY_TTZ112,
     $     A210_TT_HAONLY_TTZ113, A210_TT_HAONLY_TTZ114,
     $     A210_TT_HAONLY_TTZ115, A210_TT_HAONLY_TTZ116,
     $     A210_TT_HAONLY_TTZ117, A210_TT_HAONLY_TTZ118,
     $     A210_TT_HAONLY_TTZ1188, A210_TT_HAONLY_TTZ120
      DOUBLE PRECISION A210_TT_HZONLY_TTZ75,
     $     A210_TT_HZONLY_TTZ80, A210_TT_HZONLY_TTZ85,
     $     A210_TT_HZONLY_TTZ90, A210_TT_HZONLY_TTZ95,
     $     A210_TT_HZONLY_TTZ100, A210_TT_HZONLY_TTZ104,
     $     A210_TT_HZONLY_TTZ106, A210_TT_HZONLY_TTZ108,
     $     A210_TT_HZONLY_TTZ110, A210_TT_HZONLY_TTZ112,
     $     A210_TT_HZONLY_TTZ113, A210_TT_HZONLY_TTZ114,
     $     A210_TT_HZONLY_TTZ115, A210_TT_HZONLY_TTZ116,
     $     A210_TT_HZONLY_TTZ117, A210_TT_HZONLY_TTZ118,
     $     A210_TT_HZONLY_TTZ1188, A210_TT_HZONLY_TTZ120
C     
      DOUBLE PRECISION A210_TT_ASHA_HATT75,
     $     A210_TT_ASHA_HATT80, A210_TT_ASHA_HATT85,
     $     A210_TT_ASHA_HATT90, A210_TT_ASHA_HATT95,
     $     A210_TT_ASHA_HATT100, A210_TT_ASHA_HATT105
      DOUBLE PRECISION A210_TT_ASHZ_HATT75,
     $     A210_TT_ASHZ_HATT80, A210_TT_ASHZ_HATT85,
     $     A210_TT_ASHZ_HATT90, A210_TT_ASHZ_HATT95,
     $     A210_TT_ASHZ_HATT100, A210_TT_ASHZ_HATT105
      DOUBLE PRECISION A210_TT_HAONLY_HATT75,
     $     A210_TT_HAONLY_HATT80, A210_TT_HAONLY_HATT85,
     $     A210_TT_HAONLY_HATT90, A210_TT_HAONLY_HATT95,
     $     A210_TT_HAONLY_HATT100, A210_TT_HAONLY_HATT105
      DOUBLE PRECISION A210_TT_HZONLY_HATT75,
     $     A210_TT_HZONLY_HATT80, A210_TT_HZONLY_HATT85,
     $     A210_TT_HZONLY_HATT90, A210_TT_HZONLY_HATT95,
     $     A210_TT_HZONLY_HATT100, A210_TT_HZONLY_HATT105
C     
      IF (MHIGGSHYP.NE.LAST_MHIGGSHYP_CALLED .OR.
     $     IBRANCH.NE.LAST_IBRANCH_CALLED .OR.
     $     ISIG.NE.LAST_ISIG_CALLED) THEN
C     
C     Calculate the new morphed (interpolated) vectors         
C     only if some parameter has changed.
C     
         DX = (XMAX-XMIN)/(NMORPH_BINS-1)
         DO I = 1, NMORPH_BINS
            XINVALS(I) = XMIN + DX*(I-1)
            TEMPX = XMIN + DX*(I-1)
            IF (ISIG.EQ.1) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt75(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt75(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt75(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt75(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt80(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt80(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt80(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt80(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt85(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt85(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt85(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt85(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt90(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt90(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt90(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt90(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt95(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt95(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt95(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt95(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt100(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt100(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt100(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt100(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.104. .AND. MHIGGSHYP.LT.106.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt104(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt104(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt104(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt104(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.106. .AND. MHIGGSHYP.LT.108.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt106(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt106(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt106(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt106(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.108. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt108(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt108(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt108(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt108(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.112.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt110(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt110(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt110(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt110(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112. .AND. MHIGGSHYP.LT.113.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt112(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt112(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt112(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt112(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.113. .AND. MHIGGSHYP.LT.114.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt113(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt113(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt113(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt113(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt114(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt114(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt114(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt114(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.116.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt115(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt115(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt115(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt115(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116. .AND. MHIGGSHYP.LT.117.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt116(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt116(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt116(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt116(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.117. .AND. MHIGGSHYP.LT.118.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt117(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt117(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt117(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt117(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118. .AND. MHIGGSHYP.LT.118.8) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt118(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt1188(TEMPX)
                     PAR1 = 118.
                     PAR2 = 118.8
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt118(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt1188(TEMPX)
                     PAR1 = 118.
                     PAR2 = 118.8
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt118(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt1188(TEMPX)
                     PAR1 = 118.
                     PAR2 = 118.8
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt118(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt1188(TEMPX)
                     PAR1 = 118.
                     PAR2 = 118.8
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118.8 .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt1188(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt120(TEMPX)
                     PAR1 = 118.8
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt1188(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt120(TEMPX)
                     PAR1 = 118.8
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt1188(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt120(TEMPX)
                     PAR1 = 118.8
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt1188(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt120(TEMPX)
                     PAR1 = 118.8
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_htt120(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_htt120(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_htt120(TEMPX)
                     PAR1 = 120
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_htt120(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_htt120(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_htt120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A210_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.2) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz75(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz75(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz75(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz75(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz80(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz80(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz80(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz80(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz85(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz85(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz85(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz85(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz90(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz90(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz90(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz90(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz95(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz95(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz95(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz95(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LT.104.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz100(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz100(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz100(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz100(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz104(TEMPX)
                     PAR1 = 100.
                     PAR2 = 104.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.104. .AND. MHIGGSHYP.LT.106.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz104(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz104(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz104(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz104(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz106(TEMPX)
                     PAR1 = 104.
                     PAR2 = 106.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.106. .AND. MHIGGSHYP.LT.108.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz106(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz106(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz106(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz106(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz108(TEMPX)
                     PAR1 = 106.
                     PAR2 = 108.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.108. .AND. MHIGGSHYP.LT.110.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz108(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz108(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz108(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz108(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz110(TEMPX)
                     PAR1 = 108.
                     PAR2 = 110.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.110. .AND. MHIGGSHYP.LT.112.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz110(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz110(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz110(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz110(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz112(TEMPX)
                     PAR1 = 110.
                     PAR2 = 112.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.112. .AND. MHIGGSHYP.LT.113.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz112(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz112(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz112(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz112(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz113(TEMPX)
                     PAR1 = 112.
                     PAR2 = 113.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.113. .AND. MHIGGSHYP.LT.114.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz113(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz113(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz113(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz113(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz114(TEMPX)
                     PAR1 = 113.
                     PAR2 = 114.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.114. .AND. MHIGGSHYP.LT.115.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz114(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz114(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz114(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz114(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz115(TEMPX)
                     PAR1 = 114.
                     PAR2 = 115.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.115. .AND. MHIGGSHYP.LT.116.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz115(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz115(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz115(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz115(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz116(TEMPX)
                     PAR1 = 115.
                     PAR2 = 116.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.116. .AND. MHIGGSHYP.LT.117.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz116(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz116(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz116(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz116(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz117(TEMPX)
                     PAR1 = 116.
                     PAR2 = 117.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.117. .AND. MHIGGSHYP.LT.118.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz117(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz117(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz117(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz117(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz118(TEMPX)
                     PAR1 = 117.
                     PAR2 = 118.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118. .AND. MHIGGSHYP.LT.118.8) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz118(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz1188(TEMPX)
                     PAR1 = 118.
                     PAR2 = 118.8
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz118(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz1188(TEMPX)
                     PAR1 = 118.
                     PAR2 = 118.8
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz118(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz1188(TEMPX)
                     PAR1 = 118.
                     PAR2 = 118.8
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz118(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz1188(TEMPX)
                     PAR1 = 118.
                     PAR2 = 118.8
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.118.8 .AND. MHIGGSHYP.LT.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz1188(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz120(TEMPX)
                     PAR1 = 118.8
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz1188(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz120(TEMPX)
                     PAR1 = 118.8
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz1188(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz120(TEMPX)
                     PAR1 = 118.8
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz1188(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 118.8
                     PAR2 = 120.
                  ENDIF
               ELSE IF (MHIGGSHYP.EQ.120.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_ttz120(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_ttz120(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_ttz120(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_ttz120(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_ttz120(TEMPX)
                     PAR1 = 120.
                     PAR2 = 120.
                  ENDIF
               ELSE
                 A210_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ELSE IF (ISIG.EQ.3) THEN
               IF (MHIGGSHYP.GE.75. .AND. MHIGGSHYP.LT.80.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_hatt75(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_hatt75(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_hatt75(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_hatt75(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_hatt80(TEMPX)
                     PAR1 = 75.
                     PAR2 = 80.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.80. .AND. MHIGGSHYP.LT.85.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_hatt80(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_hatt80(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_hatt80(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_hatt80(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_hatt85(TEMPX)
                     PAR1 = 80.
                     PAR2 = 85.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.85. .AND. MHIGGSHYP.LT.90.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_hatt85(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_hatt85(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_hatt85(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_hatt85(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_hatt90(TEMPX)
                     PAR1 = 85.
                     PAR2 = 90.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.90. .AND. MHIGGSHYP.LT.95.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_hatt90(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_hatt90(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_hatt90(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_hatt90(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_hatt95(TEMPX)
                     PAR1 = 90.
                     PAR2 = 95.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.95. .AND. MHIGGSHYP.LT.100.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_hatt95(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_hatt95(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_hatt95(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_hatt95(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_hatt100(TEMPX)
                     PAR1 = 95.
                     PAR2 = 100.
                  ENDIF
               ELSE IF (MHIGGSHYP.GE.100. .AND. MHIGGSHYP.LE.105.) THEN
                  IF (IBRANCH.EQ.1) THEN
                     Y1INVALS(I) = A210_tt_haonly_hatt100(TEMPX)
                     Y2INVALS(I) = A210_tt_haonly_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.2) THEN
                     Y1INVALS(I) = A210_tt_asha_hatt100(TEMPX)
                     Y2INVALS(I) = A210_tt_asha_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.3) THEN
                     Y1INVALS(I) = A210_tt_ashz_hatt100(TEMPX)
                     Y2INVALS(I) = A210_tt_ashz_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ELSE IF (IBRANCH.EQ.4) THEN
                     Y1INVALS(I) = A210_tt_hzonly_hatt100(TEMPX)
                     Y2INVALS(I) = A210_tt_hzonly_hatt105(TEMPX)
                     PAR1 = 100.
                     PAR2 = 105.
                  ENDIF
               ELSE
                 A210_TT_SIGNAL_MASS = 1D-15
                 RETURN
               ENDIF
            ENDIF
         ENDDO
         CALL A_MORPH(NMORPH_BINS, XMIN, XMAX, Y1INVALS, Y2INVALS,
     $        PAR1, PAR2, MHIGGSHYP, XMORPHVALS, YMORPHVALS)  
      ENDIF                     ! End of the new roots loop
C     Otherwise the left-over morphed vectors are used.
      A210_TT_SIGNAL_MASS = A_INTERP_VECARRAY(NMORPH_BINS,
     $     XMORPHVALS, YMORPHVALS, X)
C     
      LAST_MHIGGSHYP_CALLED = MHIGGSHYP
      LAST_IBRANCH_CALLED = IBRANCH
      LAST_ISIG_CALLED = ISIG
      RETURN
      END
C

      DOUBLE PRECISION FUNCTION A_2000_TT_SIGNAL_MASS(ROOTS,
     $     MHIGGSHYP, RECOMH, IBRANCH, ISIG)
C     Signal mass function for ALEPH tau tau channels in 2000.
C     Author: Jason Nielsen                 Date: 20 June 2000
C     Inputs: RootS      the center of mass energy   
C             MHiggsHyp  Higgs mass hypothesis (75->120 GeV/c2)
C             RecoMH     reconstructed Higgs mass
C             IBranch    analysis branch in overlap scheme
C                        1=hAonly, 2=ashA, 3=ashZ, 4=hZonly
C             ISig       1=HZ->Htau tau signal, 2=HZ->tau tau Z signal
C                        3=hA->tau tau bb signal
      IMPLICIT NONE
      REAL*8 ROOTS, MHIGGSHYP, RECOMH
      INTEGER IBRANCH, ISIG
C
      INTEGER NMORPH_BINS, I
      PARAMETER (NMORPH_BINS=100)
      DOUBLE PRECISION LAST_ROOTS_CALLED, LAST_MHIGGSHYP_CALLED
      INTEGER LAST_IBRANCH_CALLED, LAST_ISIG_CALLED
      DOUBLE PRECISION XINVALS(NMORPH_BINS), Y1INVALS(NMORPH_BINS),
     $     Y2INVALS(NMORPH_BINS)
      DOUBLE PRECISION PAR1, PAR2
      DOUBLE PRECISION XMORPHVALS(NMORPH_BINS), YMORPHVALS(NMORPH_BINS)
C Warning: hard-coded number of overlap branches and signal types
      DOUBLE PRECISION XMORPHARRAY(NMORPH_BINS, 4, 5),
     $     YMORPHARRAY(NMORPH_BINS, 4, 5)
      INTEGER ALREADY_MORPHED_SIG(4, 5), J, K
      DOUBLE PRECISION XMAX, XMIN, DX
      PARAMETER (XMAX=120.D0, XMIN=50.D0)
      DOUBLE PRECISION A_INTERP_VECARRAY
C
      DOUBLE PRECISION A1995N_TT_SIGNAL_MASS,
     $     A2016N_TT_SIGNAL_MASS, A204_TT_SIGNAL_MASS,
     $     A206_TT_SIGNAL_MASS, A208_TT_SIGNAL_MASS,
     $     A210_TT_SIGNAL_MASS
C
C     Use a hash table to see if the functions have already been
C     interpolated.
C

c      write(*,*) 'Entered signal mass function'
c      write(*,*) 'I think mh is : ',mhiggshyp
c      write(*,*) 'I think ecm is : ',roots
c      write(*,*) 'I think mh reco is : ',recomh
c      write(*,*) 'I think ibranch is : ',ibranch
c      write(*,*) 'I think isig is : ',isig

      IF (ROOTS.NE.LAST_ROOTS_CALLED .OR.
     $     MHIGGSHYP.NE.LAST_MHIGGSHYP_CALLED) THEN
         DO J = 1, 4
            DO K = 1, 5
               ALREADY_MORPHED_SIG(J, K) = 0
            ENDDO
         ENDDO
      ENDIF
      IF (ALREADY_MORPHED_SIG(IBRANCH, ISIG) .EQ. 0) THEN
C
C   Calculate the new morphed (interpolated) vectors         
C   only if some parameter has changed.
C
c         write(*,*) 'New morphing'
         DX = (XMAX-XMIN)/(NMORPH_BINS-1)
         DO I = 1, NMORPH_BINS
            XINVALS(I) = XMIN + DX*(I-1)
         ENDDO
c         write(*,*) 'Set up xinvals for ',nmorph_bins
         IF (ROOTS.GE.199.5 .AND. ROOTS.LT.201.6) THEN
            PAR1 = 199.5
            PAR2 = 201.6
c            write(*,*) 'Energy between ',par1,par2
            DO I = 1, NMORPH_BINS
c               write(*,*) 'Bin ',i,xinvals(i)
               Y1INVALS(I) =
     $              A1995N_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
c               write(*,*) '    Shape 1995 : ',Y1INVALS(i)
               Y2INVALS(I) =
     $              A2016N_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
c               write(*,*) '    Shape 2016 : ',Y1INVALS(i)
            ENDDO
         ELSEIF (ROOTS.GE.201.6 .AND. ROOTS.LT.204.) THEN
            PAR1 = 201.6
            PAR2 = 204.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A2016N_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
               Y2INVALS(I) =
     $              A204_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
            ENDDO
         ELSEIF (ROOTS.GE.204. .AND. ROOTS.LT.206.) THEN
            PAR1 = 204.
            PAR2 = 206.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A204_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
               Y2INVALS(I) =
     $              A206_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
            ENDDO
         ELSEIF (ROOTS.GE.206. .AND. ROOTS.LT.208.) THEN
            PAR1 = 206.
            PAR2 = 208.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A206_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
               Y2INVALS(I) =
     $              A208_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
            ENDDO
         ELSEIF (ROOTS.GE.208. .AND. ROOTS.LT.210.) THEN
            PAR1 = 208.
            PAR2 = 210.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A208_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
               Y2INVALS(I) =
     $              A210_TT_SIGNAL_MASS(MHIGGSHYP,IBRANCH,ISIG,
     $              XINVALS(I))
            ENDDO
         ENDIF
c         write(*,*) 'Finished getting Y values'
         CALL A_MORPH(NMORPH_BINS, XMIN, XMAX, Y1INVALS, Y2INVALS,
     $        PAR1, PAR2, ROOTS, XMORPHVALS, YMORPHVALS)  
c         write(*,*) 'Called A_morph'
         DO I = 1, NMORPH_BINS
            XMORPHARRAY(I, IBRANCH, ISIG) = XMORPHVALS(I)
            YMORPHARRAY(I, IBRANCH, ISIG) = YMORPHVALS(I)
c            write(*,*) 'Bin : ',i,xmorpharray(i,ibranch,isig),
c     &                            ymorpharray(i,ibranch,isig)
         ENDDO
         ALREADY_MORPHED_SIG(IBRANCH, ISIG) = 1
      ENDIF ! End of the loop if not ALREADY_MORPHED_SIG
C   Otherwise the left-over morphed vectors are used.
      DO I = 1, NMORPH_BINS
         XMORPHVALS(I) = XMORPHARRAY(I, IBRANCH, ISIG)
         YMORPHVALS(I) = YMORPHARRAY(I, IBRANCH, ISIG)
      ENDDO
      A_2000_TT_SIGNAL_MASS = A_INTERP_VECARRAY(NMORPH_BINS,
     $     XMORPHVALS, YMORPHVALS, RECOMH)
c      write(*,*) A_2000_tt_signal_mass
C
      LAST_ROOTS_CALLED = ROOTS
      LAST_MHIGGSHYP_CALLED = MHIGGSHYP
      RETURN
      END
C

      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1911812E-05,   1.2214506E-05
     +,   1.2521794E-05,   1.2833720E-05,   1.3150336E-05
     +,   1.3471704E-05,   1.3797887E-05,   1.4128951E-05
     +,   1.4464965E-05,   1.4806030E-05,   1.5152229E-05
     +,   1.5503660E-05,   1.5860427E-05,   1.6222655E-05
     +,   1.6590458E-05,   1.6963981E-05,   1.7343364E-05
     +,   1.7728760E-05,   1.8120349E-05,   1.8518303E-05
     +,   1.8922814E-05,   1.9334100E-05,   1.9752377E-05
     +,   2.0177906E-05,   2.0610927E-05,   2.1051741E-05
     +,   2.1500642E-05,   2.1957969E-05,   2.2424087E-05
     +,   2.2899372E-05,   2.3384257E-05,   2.3879202E-05
     +,   2.4384704E-05,   2.4901317E-05,   2.5429634E-05
     +,   2.5970317E-05,   2.6524067E-05,   2.7091666E-05
     +,   2.7673994E-05,   2.8271945E-05,   2.8886585E-05
     +,   2.9519018E-05,   3.0170495E-05,   3.0842359E-05
     +,   3.1536085E-05,   3.2253323E-05,   3.2995838E-05
     +,   3.3765577E-05,   3.4564691E-05,   3.5395500E-05
     +,   3.6260579E-05,   3.7162721E-05,   3.8104939E-05
     +,   3.9090632E-05,   4.0123348E-05,   4.1207091E-05
     +,   4.2346164E-05,   4.3545209E-05,   4.4809331E-05
     +,   4.6144014E-05,   4.7555262E-05,   4.9049569E-05
     +,   5.0633880E-05,   5.2315812E-05,   5.4103642E-05
     +,   5.6006131E-05,   5.8033002E-05,   6.0194459E-05
     +,   6.2501844E-05,   6.4967091E-05,   6.7603396E-05
     +,   7.0424678E-05,   7.3446448E-05,   7.6684912E-05
     +,   8.0158112E-05,   8.3885498E-05,   8.7888016E-05
     +,   9.2188340E-05,   9.6811469E-05,   1.0178460E-04
     +,   1.0713698E-04,   1.1290092E-04,   1.1911105E-04
     +,   1.2580569E-04,   1.3302558E-04,   1.4081548E-04
     +,   1.4922247E-04,   1.5829763E-04,   1.6809373E-04
     +,   1.7866628E-04,   1.9007224E-04,   2.0236801E-04
     +,   2.1560829E-04,   2.2984536E-04,   2.4512611E-04
     +,   2.6148793E-04,   2.7895937E-04,   2.9755299E-04
     +,   3.1726700E-04,   3.3807795E-04,   3.5994346E-04
     +,   3.8279503E-04,   4.0654393E-04,   4.3107572E-04
     +,   4.5625807E-04,   4.8194363E-04,   5.0797459E-04
     +,   5.3419301E-04,   5.6045398E-04,   5.8663689E-04
     +,   6.1265758E-04,   6.3848990E-04,   6.6417438E-04
     +,   6.8983907E-04,   7.1570551E-04,   7.4210111E-04
     +,   7.6945539E-04,   7.9829968E-04,   8.2924351E-04
     +,   8.6295704E-04,   9.0012961E-04,   9.4142265E-04
     +,   9.8741695E-04,   1.0385573E-03,   1.0950969E-03
     +,   1.1570365E-03,   1.2241070E-03,   1.2957323E-03
     +,   1.3710621E-03,   1.4489845E-03,   1.5282178E-03
     +,   1.6073773E-03,   1.6851015E-03,   1.7601488E-03
     +,   1.8315093E-03,   1.8984954E-03,   1.9607784E-03
     +,   2.0184135E-03,   2.0718172E-03,   2.1217058E-03
     +,   2.1690128E-03,   2.2147971E-03,   2.2601811E-03
     +,   2.3062746E-03,   2.3541648E-03,   2.4049424E-03
     +,   2.4597514E-03,   2.5198760E-03,   2.5868388E-03
     +,   2.6624792E-03,   2.7489960E-03,   2.8488708E-03
     +,   2.9647108E-03,   3.0989358E-03,   3.2533137E-03
     +,   3.4284154E-03,   3.6230846E-03,   3.8341112E-03
     +,   4.0562367E-03,   4.2826207E-03,   4.5059328E-03
     +,   4.7198073E-03,   4.9204137E-03,   5.1077255E-03
     +,   5.2859974E-03,   5.4629794E-03,   5.6479271E-03
     +,   5.8486960E-03,   6.0687019E-03,   6.3046422E-03
     +,   6.5459786E-03,   6.7764535E-03,   6.9774487E-03
     +,   7.1321363E-03,   7.2292383E-03,   7.2652963E-03
     +,   7.2450885E-03,   7.1805026E-03,   7.0887790E-03
     +,   6.9908299E-03,   6.9102729E-03,   6.8725506E-03
     +,   6.9035636E-03,   7.0269718E-03,   7.2599263E-03
     +,   7.6079234E-03,   8.0607804E-03,   8.5920803E-03
     +,   9.1640353E-03,   9.7376835E-03,   1.0284878E-02
     +,   1.0795432E-02,   1.1274344E-02,   1.1730567E-02
     +,   1.2167162E-02,   1.2586643E-02,   1.3021658E-02
     +,   1.3591634E-02,   1.4565155E-02,   1.6355241E-02
     +,   1.9322349E-02,   2.3366572E-02,   2.7834147E-02
     +,   3.2845039E-02,   4.1328810E-02,   5.8832716E-02
     +,   9.2496395E-02,   0.1475850    ,   0.2126530    
     +,   0.2461801    ,   0.2090244    ,   0.1245265    
     +,   5.1846150E-02,   1.5571531E-02,   3.6185312E-03
     +,   7.9844682E-04,   2.9271541E-04,   1.8902066E-04
     +,   1.3369029E-04,   9.1300484E-05,   6.0539172E-05
     +,   3.9961789E-05,   2.7762320E-05,   2.1608821E-05
     +,   1.9018855E-05,   1.8112834E-05,   1.7842569E-05
     +,   1.7757160E-05,   1.7702296E-05,   1.7635237E-05
     +,   1.7546447E-05,   1.7434431E-05,   1.7299355E-05
     +,   1.7141720E-05,   1.6962180E-05,   1.6761443E-05
     +,   1.6540316E-05,   1.6299678E-05,   1.6040492E-05
     +,   1.5763759E-05,   1.5470532E-05,   1.5161940E-05
     +,   1.4839145E-05,   1.4503333E-05,   1.4155706E-05
     +,   1.3797518E-05,   1.3430024E-05,   1.3054469E-05
     +,   1.2672093E-05,   1.2284167E-05,   1.1891902E-05
     +,   1.1496493E-05,   1.1099130E-05,   1.0700973E-05
     +,   1.0303113E-05,   9.9066019E-06,   9.5124724E-06
     +,   9.1216989E-06,   8.7351827E-06,   8.3537689E-06
     +,   7.9782658E-06,   7.6094211E-06,   7.2478988E-06
     +,   6.8942991E-06,   6.5491968E-06,   6.2130680E-06
     +,   5.8863302E-06,   5.5693586E-06,   5.2624705E-06
     +,   4.9659047E-06,   4.6798455E-06,   4.4044423E-06
     +,   4.1397934E-06,   3.8859293E-06,   3.6428389E-06
     +,   3.4104908E-06,   3.1887816E-06,   2.9776036E-06
     +,   2.7767858E-06,   2.5861548E-06,   2.4054843E-06
     +,   2.2345480E-06,   2.0730758E-06,   1.9208010E-06
     +,   1.7774220E-06,   1.6426422E-06,   1.5161423E-06
     +,   1.3975962E-06,   1.2866836E-06,   1.1830668E-06
     +,   1.0864197E-06,   9.9640567E-07,   9.1270084E-07
     +,   8.3497486E-07,   7.6291263E-07,   6.9619597E-07
     +,   6.3452313E-07,   5.7759217E-07,   5.2511837E-07
     +,   4.7681920E-07,   4.3242912E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt100 = Yx/0.40726
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6846362E-05,   3.7626145E-05
     +,   3.8407943E-05,   3.9191531E-05,   3.9976723E-05
     +,   4.0763425E-05,   4.1551601E-05,   4.2341344E-05
     +,   4.3132819E-05,   4.3926357E-05,   4.4722361E-05
     +,   4.5521414E-05,   4.6324240E-05,   4.7131736E-05
     +,   4.7944970E-05,   4.8765236E-05,   4.9593997E-05
     +,   5.0432966E-05,   5.1284089E-05,   5.2149557E-05
     +,   5.3031825E-05,   5.3933614E-05,   5.4857926E-05
     +,   5.5808101E-05,   5.6787660E-05,   5.7800546E-05
     +,   5.8850910E-05,   5.9943253E-05,   6.1082341E-05
     +,   6.2273197E-05,   6.3521125E-05,   6.4831722E-05
     +,   6.6210734E-05,   6.7664128E-05,   6.9198075E-05
     +,   7.0818838E-05,   7.2532843E-05,   7.4346455E-05
     +,   7.6266304E-05,   7.8298690E-05,   8.0450147E-05
     +,   8.2727005E-05,   8.5135507E-05,   8.7681750E-05
     +,   9.0371766E-05,   9.3211471E-05,   9.6206582E-05
     +,   9.9362907E-05,   1.0268616E-04,   1.0618225E-04
     +,   1.0985728E-04,   1.1371772E-04,   1.1777065E-04
     +,   1.2202420E-04,   1.2648710E-04,   1.3117005E-04
     +,   1.3608525E-04,   1.4124723E-04,   1.4667318E-04
     +,   1.5238325E-04,   1.5840183E-04,   1.6475731E-04
     +,   1.7148256E-04,   1.7861671E-04,   1.8620490E-04
     +,   1.9429829E-04,   2.0295616E-04,   2.1224459E-04
     +,   2.2223862E-04,   2.3302033E-04,   2.4468135E-04
     +,   2.5731995E-04,   2.7104287E-04,   2.8596207E-04
     +,   3.0219599E-04,   3.1986690E-04,   3.3909729E-04
     +,   3.6000859E-04,   3.8271965E-04,   4.0734230E-04
     +,   4.3397499E-04,   4.6270437E-04,   4.9359427E-04
     +,   5.2668992E-04,   5.6200317E-04,   5.9951894E-04
     +,   6.3918228E-04,   6.8090222E-04,   7.2454149E-04
     +,   7.6992234E-04,   8.1682228E-04,   8.6497096E-04
     +,   9.1405853E-04,   9.6374034E-04,   1.0136447E-03
     +,   1.0633795E-03,   1.1125555E-03,   1.1607967E-03
     +,   1.2077695E-03,   1.2532009E-03,   1.2969146E-03
     +,   1.3388513E-03,   1.3791048E-03,   1.4179359E-03
     +,   1.4558065E-03,   1.4933784E-03,   1.5315161E-03
     +,   1.5712704E-03,   1.6138403E-03,   1.6605241E-03
     +,   1.7126319E-03,   1.7714029E-03,   1.8378829E-03
     +,   1.9128266E-03,   1.9965635E-03,   2.0889291E-03
     +,   2.1891824E-03,   2.2960037E-03,   2.4075203E-03
     +,   2.5214278E-03,   2.6351362E-03,   2.7459797E-03
     +,   2.8514655E-03,   2.9495275E-03,   3.0387414E-03
     +,   3.1184938E-03,   3.1890913E-03,   3.2517598E-03
     +,   3.3085721E-03,   3.3622696E-03,   3.4160425E-03
     +,   3.4732246E-03,   3.5370071E-03,   3.6101069E-03
     +,   3.6945094E-03,   3.7912936E-03,   3.9005517E-03
     +,   4.0215719E-03,   4.1531697E-03,   4.2942101E-03
     +,   4.4441693E-03,   4.6036099E-03,   4.7743409E-03
     +,   4.9591255E-03,   5.1609315E-03,   5.3821350E-03
     +,   5.6237793E-03,   5.8855130E-03,   6.1661904E-03
     +,   6.4649242E-03,   6.7817573E-03,   7.1173231E-03
     +,   7.4714446E-03,   7.8409771E-03,   8.2183825E-03
     +,   8.5920766E-03,   8.9490423E-03,   9.2790220E-03
     +,   9.5785316E-03,   9.8532289E-03,   1.0117902E-02
     +,   1.0393844E-02,   1.0704377E-02,   1.1069302E-02
     +,   1.1500151E-02,   1.1998261E-02,   1.2556700E-02
     +,   1.3163626E-02,   1.3802832E-02,   1.4449039E-02
     +,   1.5062931E-02,   1.5594434E-02,   1.5996784E-02
     +,   1.6243642E-02,   1.6337451E-02,   1.6305937E-02
     +,   1.6194372E-02,   1.6059935E-02,   1.5964365E-02
     +,   1.5958857E-02,   1.6065719E-02,   1.6269291E-02
     +,   1.6521145E-02,   1.6752295E-02,   1.6884940E-02
     +,   1.6848093E-02,   1.6602751E-02,   1.6168378E-02
     +,   1.5629293E-02,   1.5106491E-02,   1.4705504E-02
     +,   1.4470973E-02,   1.4375516E-02,   1.4346998E-02
     +,   1.4312383E-02,   1.4227578E-02,   1.4077818E-02
     +,   1.3856844E-02,   1.3547143E-02,   1.3117075E-02
     +,   1.2534183E-02,   1.1782452E-02,   1.0871787E-02
     +,   9.8364595E-03,   8.7260865E-03,   7.5945794E-03
     +,   6.4915488E-03,   5.4569668E-03,   4.5186309E-03
     +,   3.6919080E-03,   2.9812688E-03,   2.3828456E-03
     +,   1.8872739E-03,   1.4823191E-03,   1.1549520E-03
     +,   8.9266693E-04,   6.8415375E-04,   5.1957177E-04
     +,   3.9060324E-04,   2.9034627E-04,   2.1311537E-04
     +,   1.5425723E-04,   1.0996551E-04,   7.7117380E-05
     +,   5.3149848E-05,   3.5971545E-05,   2.3893199E-05
     +,   1.5569827E-05,   9.9515155E-06,   6.2382092E-06
     +,   3.8356407E-06,   2.3137404E-06,   1.3696330E-06
     +,   7.9587250E-07,   4.5415476E-07,   2.5458476E-07
     +,   1.4023713E-07,   7.5932633E-08,   4.0424389E-08
     +,   2.1164110E-08,   1.0899694E-08,   5.5247744E-09
     +,   2.7590323E-09,   1.3603995E-09,   6.6520284E-10
     +,   3.2541222E-10,   1.6188689E-10,   8.4165397E-11
     +,   4.7451942E-11,   2.9995870E-11,   2.1440771E-11
     +,   1.6954996E-11,   1.4328052E-11,   1.2566609E-11
     +,   1.1230662E-11,   1.0126617E-11,   9.1683987E-12
     +,   8.3160024E-12,   7.5488713E-12,   6.8548635E-12
     +,   6.2255786E-12,   5.6543875E-12,   5.1356337E-12
     +,   4.6643561E-12,   4.2361626E-12,   3.8470555E-12
     +,   3.4934197E-12,   3.1720119E-12,   2.8798942E-12
     +,   2.6143822E-12,   2.3730427E-12,   2.1536883E-12
     +,   1.9543254E-12,   1.7731375E-12,   1.6084721E-12
     +,   1.4588457E-12,   1.3228874E-12,   1.1993713E-12
     +,   1.0871636E-12,   9.8525192E-13,   8.9269781E-13
     +,   8.0866097E-13,   7.3236545E-13,   6.6311529E-13
     +,   6.0026804E-13,   5.4324579E-13,   4.9151818E-13
     +,   4.4460052E-13,   4.0206087E-13,   3.6349491E-13
     +,   3.2854229E-13,   2.9686979E-13,   2.6817930E-13
     +,   2.4219369E-13,   2.1866664E-13,   1.9736910E-13
     +,   1.7809671E-13,   1.6065965E-13,   1.4488950E-13
     +,   1.3062897E-13,   1.1773841E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt105 = Yx/0.220804347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1663643E-05,   3.2720767E-05
     +,   3.3824050E-05,   3.4975816E-05,   3.6178440E-05
     +,   3.7434369E-05,   3.8746079E-05,   4.0116083E-05
     +,   4.1546897E-05,   4.3041138E-05,   4.4601329E-05
     +,   4.6230016E-05,   4.7929723E-05,   4.9702932E-05
     +,   5.1552077E-05,   5.3479514E-05,   5.5487511E-05
     +,   5.7578254E-05,   5.9753787E-05,   6.2016028E-05
     +,   6.4366774E-05,   6.6807639E-05,   6.9340043E-05
     +,   7.1965398E-05,   7.4684598E-05,   7.7498727E-05
     +,   8.0408441E-05,   8.3414350E-05,   8.6516797E-05
     +,   8.9716057E-05,   9.3012262E-05,   9.6405405E-05
     +,   9.9895486E-05,   1.0348241E-04,   1.0716613E-04
     +,   1.1094673E-04,   1.1482430E-04,   1.1879919E-04
     +,   1.2287202E-04,   1.2704350E-04,   1.3131509E-04
     +,   1.3568826E-04,   1.4016520E-04,   1.4474840E-04
     +,   1.4944104E-04,   1.5424685E-04,   1.5917016E-04
     +,   1.6421579E-04,   1.6938933E-04,   1.7469692E-04
     +,   1.8014522E-04,   1.8574166E-04,   1.9149408E-04
     +,   1.9741146E-04,   2.0350266E-04,   2.0977821E-04
     +,   2.1624906E-04,   2.2292726E-04,   2.2982627E-04
     +,   2.3696113E-04,   2.4434863E-04,   2.5200815E-04
     +,   2.5996106E-04,   2.6823304E-04,   2.7685289E-04
     +,   2.8585337E-04,   2.9527285E-04,   3.0515352E-04
     +,   3.1554457E-04,   3.2649978E-04,   3.3807973E-04
     +,   3.5034929E-04,   3.6338065E-04,   3.7724874E-04
     +,   3.9203328E-04,   4.0781751E-04,   4.2468411E-04
     +,   4.4271533E-04,   4.6199237E-04,   4.8259218E-04
     +,   5.0458283E-04,   5.2802725E-04,   5.5297493E-04
     +,   5.7946757E-04,   6.0753064E-04,   6.3718064E-04
     +,   6.6841824E-04,   7.0123619E-04,   7.3561404E-04
     +,   7.7152619E-04,   8.0894225E-04,   8.4782636E-04
     +,   8.8814262E-04,   9.2985557E-04,   9.7293186E-04
     +,   1.0173303E-03,   1.0630114E-03,   1.1099185E-03
     +,   1.1579848E-03,   1.2071133E-03,   1.2571850E-03
     +,   1.3080407E-03,   1.3594932E-03,   1.4113177E-03
     +,   1.4632763E-03,   1.5151222E-03,   1.5666223E-03
     +,   1.6175845E-03,   1.6678881E-03,   1.7175080E-03
     +,   1.7665323E-03,   1.8151995E-03,   1.8638815E-03
     +,   1.9131029E-03,   1.9635179E-03,   2.0158847E-03
     +,   2.0710137E-03,   2.1297259E-03,   2.1927631E-03
     +,   2.2607185E-03,   2.3339447E-03,   2.4124731E-03
     +,   2.4959820E-03,   2.5838146E-03,   2.6750830E-03
     +,   2.7688646E-03,   2.8645347E-03,   2.9621355E-03
     +,   3.0627698E-03,   3.1688968E-03,   3.2844283E-03
     +,   3.4144835E-03,   3.5648041E-03,   3.7407656E-03
     +,   3.9462033E-03,   4.1821869E-03,   4.4460567E-03
     +,   4.7310134E-03,   5.0264830E-03,   5.3192498E-03
     +,   5.5952030E-03,   5.8414899E-03,   6.0484977E-03
     +,   6.2112617E-03,   6.3299779E-03,   6.4096889E-03
     +,   6.4591384E-03,   6.4893831E-03,   6.5124622E-03
     +,   6.5405015E-03,   6.5851780E-03,   6.6575161E-03
     +,   6.7675053E-03,   6.9233412E-03,   7.1300901E-03
     +,   7.3877536E-03,   7.6894676E-03,   8.0205537E-03
     +,   8.3596557E-03,   8.6824540E-03,   8.9678615E-03
     +,   9.2050843E-03,   9.3991896E-03,   9.5731318E-03
     +,   9.7651733E-03,   1.0022140E-02,   1.0389454E-02
     +,   1.0899330E-02,   1.1558520E-02,   1.2338755E-02
     +,   1.3175063E-02,   1.3976981E-02,   1.4651828E-02
     +,   1.5131650E-02,   1.5391001E-02,   1.5448192E-02
     +,   1.5351740E-02,   1.5162382E-02,   1.4938639E-02
     +,   1.4727364E-02,   1.4557864E-02,   1.4440597E-02
     +,   1.4371510E-02,   1.4340750E-02,   1.4340254E-02
     +,   1.4366935E-02,   1.4423489E-02,   1.4518615E-02
     +,   1.4663748E-02,   1.4861319E-02,   1.5087958E-02
     +,   1.5286005E-02,   1.5376337E-02,   1.5290318E-02
     +,   1.5002255E-02,   1.4540092E-02,   1.3967499E-02
     +,   1.3349043E-02,   1.2720665E-02,   1.2080582E-02
     +,   1.1401517E-02,   1.0652925E-02,   9.8198764E-03
     +,   8.9103840E-03,   7.9513136E-03,   6.9778948E-03
     +,   6.0239248E-03,   5.1161568E-03,   4.2732563E-03
     +,   3.5073573E-03,   2.8261077E-03,   2.2338065E-03
     +,   1.7314443E-03,   1.3164642E-03,   9.8287314E-04
     +,   7.2186522E-04,   5.2284601E-04,   3.7463559E-04
     +,   2.6654545E-04,   1.8911286E-04,   1.3444328E-04
     +,   9.6282994E-05,   6.9874164E-05,   5.1707517E-05
     +,   3.9256240E-05,   3.0734594E-05,   2.4896884E-05
     +,   2.0881576E-05,   1.8096664E-05,   1.6137721E-05
     +,   1.4729659E-05,   1.3685921E-05,   1.2880444E-05
     +,   1.2228432E-05,   1.1673272E-05,   1.1177406E-05
     +,   1.0716361E-05,   1.0274609E-05,   9.8426663E-06
     +,   9.4151419E-06,   8.9893811E-06,   8.5645470E-06
     +,   8.1409462E-06,   7.7195427E-06,   7.3016781E-06
     +,   6.8889040E-06,   6.4828123E-06,   6.0849220E-06
     +,   5.6966560E-06,   5.3193417E-06,   4.9541231E-06
     +,   4.6019813E-06,   4.2637603E-06,   3.9401380E-06
     +,   3.6316144E-06,   3.3385381E-06,   3.0611352E-06
     +,   2.7994927E-06,   2.5535580E-06,   2.3231662E-06
     +,   2.1080666E-06,   1.9079159E-06,   1.7222795E-06
     +,   1.5506580E-06,   1.3925142E-06,   1.2472472E-06
     +,   1.1142261E-06,   9.9280442E-07,   8.8231803E-07
     +,   7.8208922E-07,   6.9144079E-07,   6.0970979E-07
     +,   5.3624444E-07,   4.7040487E-07,   4.1157472E-07
     +,   3.5916727E-07,   3.1261689E-07,   2.7139362E-07
     +,   2.3499265E-07,   2.0294597E-07,   1.7481320E-07
     +,   1.5018951E-07,   1.2869810E-07,   1.0999595E-07
     +,   9.3766687E-08,   7.9724551E-08,   6.7609136E-08
     +,   5.7185485E-08,   4.8243422E-08,   4.0593598E-08
     +,   3.4068211E-08,   2.8517263E-08,   2.3808884E-08
     +,   1.9826084E-08,   1.6466728E-08,   1.3640956E-08
     +,   1.1270799E-08,   9.2882049E-09,   7.6345144E-09
     +,   6.2588992E-09,   5.1178519E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt107 = Yx/0.208911111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1449181E-05,   3.2262255E-05
     +,   3.3102933E-05,   3.3972443E-05,   3.4872071E-05
     +,   3.5803165E-05,   3.6767142E-05,   3.7765411E-05
     +,   3.8799451E-05,   3.9870829E-05,   4.0981064E-05
     +,   4.2131764E-05,   4.3324533E-05,   4.4561013E-05
     +,   4.5842844E-05,   4.7171659E-05,   4.8549100E-05
     +,   4.9976818E-05,   5.1456398E-05,   5.2989435E-05
     +,   5.4577489E-05,   5.6222041E-05,   5.7924539E-05
     +,   5.9686481E-05,   6.1509112E-05,   6.3393840E-05
     +,   6.5341861E-05,   6.7354420E-05,   6.9432681E-05
     +,   7.1577779E-05,   7.3790892E-05,   7.6073142E-05
     +,   7.8425735E-05,   8.0849881E-05,   8.3346917E-05
     +,   8.5918335E-05,   8.8565677E-05,   9.1290807E-05
     +,   9.4095878E-05,   9.6983116E-05,   9.9955316E-05
     +,   1.0301561E-04,   1.0616745E-04,   1.0941490E-04
     +,   1.1276245E-04,   1.1621515E-04,   1.1977855E-04
     +,   1.2345878E-04,   1.2726252E-04,   1.3119692E-04
     +,   1.3526953E-04,   1.3948834E-04,   1.4386143E-04
     +,   1.4839745E-04,   1.5310428E-04,   1.5799027E-04
     +,   1.6306303E-04,   1.6832942E-04,   1.7379544E-04
     +,   1.7946585E-04,   1.8534387E-04,   1.9143095E-04
     +,   1.9772600E-04,   2.0422575E-04,   2.1092470E-04
     +,   2.1781323E-04,   2.2487968E-04,   2.3210818E-04
     +,   2.3948039E-04,   2.4697385E-04,   2.5456405E-04
     +,   2.6222243E-04,   2.6991963E-04,   2.7762330E-04
     +,   2.8530095E-04,   2.9292051E-04,   3.0045069E-04
     +,   3.0786259E-04,   3.1513235E-04,   3.2224198E-04
     +,   3.2918030E-04,   3.3594682E-04,   3.4255165E-04
     +,   3.4901925E-04,   3.5538853E-04,   3.6171669E-04
     +,   3.6807856E-04,   3.7456988E-04,   3.8130666E-04
     +,   3.8842717E-04,   3.9609146E-04,   4.0448108E-04
     +,   4.1379753E-04,   4.2426327E-04,   4.3611749E-04
     +,   4.4961376E-04,   4.6501972E-04,   4.8260915E-04
     +,   5.0266390E-04,   5.2546331E-04,   5.5128598E-04
     +,   5.8039883E-04,   6.1305880E-04,   6.4949924E-04
     +,   6.8993249E-04,   7.3453924E-04,   7.8345957E-04
     +,   8.3678897E-04,   8.9457247E-04,   9.5679588E-04
     +,   1.0233759E-03,   1.0941711E-03,   1.1689711E-03
     +,   1.2475257E-03,   1.3295512E-03,   1.4147818E-03
     +,   1.5029941E-03,   1.5940742E-03,   1.6880397E-03
     +,   1.7850924E-03,   1.8856040E-03,   1.9900787E-03
     +,   2.0990695E-03,   2.2130401E-03,   2.3321928E-03
     +,   2.4562429E-03,   2.5842653E-03,   2.7145350E-03
     +,   2.8445257E-03,   2.9709917E-03,   3.0902785E-03
     +,   3.1987356E-03,   3.2932821E-03,   3.3720084E-03
     +,   3.4347184E-03,   3.4832738E-03,   3.5216459E-03
     +,   3.5556271E-03,   3.5921794E-03,   3.6385264E-03
     +,   3.7011274E-03,   3.7847441E-03,   3.8917554E-03
     +,   4.0218714E-03,   4.1722618E-03,   4.3381150E-03
     +,   4.5134309E-03,   4.6918946E-03,   4.8676436E-03
     +,   5.0357156E-03,   5.1921359E-03,   5.3337235E-03
     +,   5.4579447E-03,   5.5630491E-03,   5.6487634E-03
     +,   5.7174917E-03,   5.7756645E-03,   5.8347606E-03
     +,   5.9112916E-03,   6.0254820E-03,   6.1985473E-03
     +,   6.4490936E-03,   6.7891767E-03,   7.2211190E-03
     +,   7.7359271E-03,   8.3143478E-03,   8.9312214E-03
     +,   9.5627159E-03,   1.0193638E-02,   1.0820395E-02
     +,   1.1446952E-02,   1.2075572E-02,   1.2698392E-02
     +,   1.3295524E-02,   1.3839656E-02,   1.4302026E-02
     +,   1.4654460E-02,   1.4869458E-02,   1.4923884E-02
     +,   1.4808211E-02,   1.4537355E-02,   1.4154124E-02
     +,   1.3721098E-02,   1.3303185E-02,   1.2948915E-02
     +,   1.2677599E-02,   1.2477873E-02,   1.2316633E-02
     +,   1.2153606E-02,   1.1954589E-02,   1.1699650E-02
     +,   1.1385853E-02,   1.1025122E-02,   1.0637763E-02
     +,   1.0243139E-02,   9.8510329E-03,   9.4578471E-03
     +,   9.0492759E-03,   8.6076688E-03,   8.1199249E-03
     +,   7.5821704E-03,   7.0000677E-03,   6.3859723E-03
     +,   5.7553989E-03,   5.1242933E-03,   4.5074369E-03
     +,   3.9177528E-03,   3.3658503E-03,   2.8595224E-03
     +,   2.4034546E-03,   1.9993782E-03,   1.6466122E-03
     +,   1.3427279E-03,   1.0841979E-03,   8.6691946E-04
     +,   6.8653753E-04,   5.3862098E-04,   4.1879964E-04
     +,   3.2289841E-04,   2.4704999E-04,   1.8775428E-04
     +,   1.4193391E-04,   1.0694319E-04,   8.0545513E-05
     +,   6.0877614E-05,   4.6410336E-05,   3.5905734E-05
     +,   2.8374126E-05,   2.3036017E-05,   1.9288245E-05
     +,   1.6672384E-05,   1.4846365E-05,   1.3559901E-05
     +,   1.2633743E-05,   1.1942251E-05,   1.1399150E-05
     +,   1.0946638E-05,   1.0546953E-05,   1.0176138E-05
     +,   9.8195014E-06,   9.4684847E-06,   9.1185038E-06
     +,   8.7674543E-06,   8.4147405E-06,   8.0606651E-06
     +,   7.7060677E-06,   7.3520546E-06,   6.9998291E-06
     +,   6.6506236E-06,   6.3056764E-06,   5.9661302E-06
     +,   5.6330541E-06,   5.3074427E-06,   4.9901978E-06
     +,   4.6820942E-06,   4.3838077E-06,   4.0959312E-06
     +,   3.8189564E-06,   3.5532571E-06,   3.2991140E-06
     +,   3.0567353E-06,   2.8262409E-06,   2.6076571E-06
     +,   2.4009360E-06,   2.2059792E-06,   2.0226107E-06
     +,   1.8505963E-06,   1.6896664E-06,   1.5395059E-06
     +,   1.3997534E-06,   1.2700193E-06,   1.1498963E-06
     +,   1.0389592E-06,   9.3675959E-07,   8.4284159E-07
     +,   7.5675507E-07,   6.7803620E-07,   6.0623643E-07
     +,   5.4090276E-07,   4.8160166E-07,   4.2790245E-07
     +,   3.7939628E-07,   3.3568324E-07,   2.9638599E-07
     +,   2.6114026E-07,   2.2960512E-07,   2.0145555E-07
     +,   1.7638634E-07,   1.5411402E-07,   1.3437153E-07
     +,   1.1691343E-07,   1.0151011E-07,   8.7952067E-08
     +,   7.6044962E-08,   6.5612554E-08,   5.6492524E-08
     +,   4.8538570E-08,   4.1616993E-08,   3.5607922E-08
     +,   3.0402539E-08,   2.5903917E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt110 = Yx/0.164906976744186
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2207307E-05,   2.3019111E-05
     +,   2.3862816E-05,   2.4738925E-05,   2.5647862E-05
     +,   2.6589983E-05,   2.7565557E-05,   2.8574772E-05
     +,   2.9617717E-05,   3.0694442E-05,   3.1804862E-05
     +,   3.2948825E-05,   3.4126097E-05,   3.5336365E-05
     +,   3.6579277E-05,   3.7854410E-05,   3.9161307E-05
     +,   4.0499512E-05,   4.1868556E-05,   4.3268043E-05
     +,   4.4697637E-05,   4.6157107E-05,   4.7646390E-05
     +,   4.9165712E-05,   5.0715436E-05,   5.2296422E-05
     +,   5.3909876E-05,   5.5557506E-05,   5.7241672E-05
     +,   5.8965376E-05,   6.0732451E-05,   6.2547653E-05
     +,   6.4416708E-05,   6.6346562E-05,   6.8345340E-05
     +,   7.0422568E-05,   7.2589246E-05,   7.4857904E-05
     +,   7.7242890E-05,   7.9760008E-05,   8.2427126E-05
     +,   8.5263688E-05,   8.8291061E-05,   9.1532238E-05
     +,   9.5011928E-05,   9.8756347E-05,   1.0279295E-04
     +,   1.0715036E-04,   1.1185796E-04,   1.1694543E-04
     +,   1.2244268E-04,   1.2837892E-04,   1.3478246E-04
     +,   1.4168033E-04,   1.4909681E-04,   1.5705403E-04
     +,   1.6557040E-04,   1.7466032E-04,   1.8433350E-04
     +,   1.9459447E-04,   2.0544187E-04,   2.1686843E-04
     +,   2.2885943E-04,   2.4139421E-04,   2.5444527E-04
     +,   2.6797678E-04,   2.8194784E-04,   2.9630936E-04
     +,   3.1100772E-04,   3.2598231E-04,   3.4116959E-04
     +,   3.5650015E-04,   3.7190376E-04,   3.8730656E-04
     +,   4.0263514E-04,   4.1781680E-04,   4.3277934E-04
     +,   4.4745326E-04,   4.6177354E-04,   4.7567958E-04
     +,   4.8911548E-04,   5.0203211E-04,   5.1438599E-04
     +,   5.2614248E-04,   5.3727202E-04,   5.4775446E-04
     +,   5.5757596E-04,   5.6673074E-04,   5.7522015E-04
     +,   5.8305287E-04,   5.9024553E-04,   5.9682026E-04
     +,   6.0280721E-04,   6.0824200E-04,   6.1316887E-04
     +,   6.1763579E-04,   6.2169950E-04,   6.2542205E-04
     +,   6.2887365E-04,   6.3213048E-04,   6.3527917E-04
     +,   6.3841406E-04,   6.4164237E-04,   6.4508407E-04
     +,   6.4887496E-04,   6.5317075E-04,   6.5814838E-04
     +,   6.6401117E-04,   6.7099161E-04,   6.7935366E-04
     +,   6.8939442E-04,   7.0144923E-04,   7.1588519E-04
     +,   7.3310547E-04,   7.5354346E-04,   7.7765953E-04
     +,   8.0593216E-04,   8.3885499E-04,   8.7691896E-04
     +,   9.2060753E-04,   9.7037724E-04,   1.0266374E-03
     +,   1.0897245E-03,   1.1598855E-03,   1.2372403E-03
     +,   1.3217406E-03,   1.4131612E-03,   1.5110434E-03
     +,   1.6147040E-03,   1.7232029E-03,   1.8353835E-03
     +,   1.9498838E-03,   2.0652236E-03,   2.1798746E-03
     +,   2.2923851E-03,   2.4014977E-03,   2.5062475E-03
     +,   2.6060431E-03,   2.7007060E-03,   2.7903884E-03
     +,   2.8754391E-03,   2.9561741E-03,   3.0326247E-03
     +,   3.1042725E-03,   3.1698684E-03,   3.2274227E-03
     +,   3.2743756E-03,   3.3080208E-03,   3.3261480E-03
     +,   3.3278170E-03,   3.3141703E-03,   3.2890823E-03
     +,   3.2594600E-03,   3.2350251E-03,   3.2274725E-03
     +,   3.2490799E-03,   3.3108999E-03,   3.4210014E-03
     +,   3.5830287E-03,   3.7954862E-03,   4.0519275E-03
     +,   4.3419371E-03,   4.6526655E-03,   4.9706618E-03
     +,   5.2836468E-03,   5.5819275E-03,   5.8594593E-03
     +,   6.1144382E-03,   6.3494267E-03,   6.5708123E-03
     +,   6.7874389E-03,   7.0085665E-03,   7.2413390E-03
     +,   7.4885432E-03,   7.7475617E-03,   8.0108298E-03
     +,   8.2673533E-03,   8.5045481E-03,   8.7097492E-03
     +,   8.8714799E-03,   8.9809578E-03,   9.0342117E-03
     +,   9.0337638E-03,   8.9885360E-03,   8.9108758E-03
     +,   8.8117728E-03,   8.6965337E-03,   8.5638156E-03
     +,   8.4086545E-03,   8.2276734E-03,   8.0230813E-03
     +,   7.8029153E-03,   7.5776447E-03,   7.3554111E-03
     +,   7.1390020E-03,   6.9258399E-03,   6.7104464E-03
     +,   6.4872392E-03,   6.2521538E-03,   6.0026599E-03
     +,   5.7367650E-03,   5.4522054E-03,   5.1464061E-03
     +,   4.8174625E-03,   4.4653593E-03,   4.0928163E-03
     +,   3.7054729E-03,   3.3112688E-03,   2.9193296E-03
     +,   2.5387597E-03,   2.1777025E-03,   1.8427677E-03
     +,   1.5387122E-03,   1.2683830E-03,   1.0328500E-03
     +,   8.3161792E-04,   6.6287635E-04,   5.2382215E-04
     +,   4.1102470E-04,   3.2077788E-04,   2.4937885E-04
     +,   1.9337072E-04,   1.4969111E-04,   1.1573605E-04
     +,   8.9366942E-05,   6.8878566E-05,   5.2940730E-05
     +,   4.0529492E-05,   3.0862047E-05,   2.3341061E-05
     +,   1.7508441E-05,   1.3008649E-05,   9.5619725E-06
     +,   6.9458952E-06,   4.9818095E-06,   3.5252101E-06
     +,   2.4594615E-06,   1.6909477E-06,   1.1451943E-06
     +,   7.6372629E-07,   5.0140392E-07,   3.2400303E-07
     +,   2.0604720E-07,   1.2894110E-07,   7.9394674E-08
     +,   4.8102486E-08,   2.8677574E-08,   1.6824895E-08
     +,   9.7157358E-09,   5.5243889E-09,   3.0948917E-09
     +,   1.7101441E-09,   9.3390307E-10,   5.0576637E-10
     +,   2.7324312E-10,   1.4874184E-10,   8.2880251E-11
     +,   4.8321024E-11,   3.0205498E-11,   2.0604362E-11
     +,   1.5360015E-11,   1.2328970E-11,   1.0423730E-11
     +,   9.1008572E-12,   8.0917729E-12,   7.2642747E-12
     +,   6.5531014E-12,   5.9251154E-12,   5.3625823E-12
     +,   4.8549558E-12,   4.3953582E-12,   3.9786143E-12
     +,   3.6005450E-12,   3.2574895E-12,   2.9462583E-12
     +,   2.6639791E-12,   2.4079974E-12,   2.1759419E-12
     +,   1.9656408E-12,   1.7751220E-12,   1.6025592E-12
     +,   1.4463130E-12,   1.3048914E-12,   1.1769322E-12
     +,   1.0611763E-12,   9.5650029E-13,   8.6187784E-13
     +,   7.7636275E-13,   6.9910516E-13,   6.2933279E-13
     +,   5.6634390E-13,   5.0949040E-13,   4.5819446E-13
     +,   4.1192790E-13,   3.7021498E-13,   3.3261322E-13
     +,   2.9873310E-13,   2.6821519E-13,   2.4073690E-13
     +,   2.1599988E-13,   1.9374094E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt115 = Yx/0.112853658536585
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8971523E-05,   7.1128430E-05
     +,   7.3290059E-05,   7.5453347E-05,   7.7615128E-05
     +,   7.9772341E-05,   8.1921964E-05,   8.4061037E-05
     +,   8.6186716E-05,   8.8296336E-05,   9.0387388E-05
     +,   9.2457529E-05,   9.4504634E-05,   9.6526986E-05
     +,   9.8523014E-05,   1.0049160E-04,   1.0243194E-04
     +,   1.0434367E-04,   1.0622683E-04,   1.0808199E-04
     +,   1.0991017E-04,   1.1171299E-04,   1.1349258E-04
     +,   1.1525172E-04,   1.1699371E-04,   1.1872255E-04
     +,   1.2044289E-04,   1.2215994E-04,   1.2387964E-04
     +,   1.2560855E-04,   1.2735388E-04,   1.2912345E-04
     +,   1.3092568E-04,   1.3276946E-04,   1.3466430E-04
     +,   1.3662013E-04,   1.3864716E-04,   1.4075592E-04
     +,   1.4295732E-04,   1.4526206E-04,   1.4768104E-04
     +,   1.5022488E-04,   1.5290405E-04,   1.5572840E-04
     +,   1.5870731E-04,   1.6184940E-04,   1.6516238E-04
     +,   1.6865294E-04,   1.7232659E-04,   1.7618747E-04
     +,   1.8023845E-04,   1.8448071E-04,   1.8891403E-04
     +,   1.9353675E-04,   1.9834535E-04,   2.0333522E-04
     +,   2.0850038E-04,   2.1383355E-04,   2.1932696E-04
     +,   2.2497207E-04,   2.3076055E-04,   2.3668438E-04
     +,   2.4273609E-04,   2.4891060E-04,   2.5520471E-04
     +,   2.6161791E-04,   2.6815385E-04,   2.7482005E-04
     +,   2.8162988E-04,   2.8860153E-04,   2.9576060E-04
     +,   3.0313816E-04,   3.1077347E-04,   3.1871142E-04
     +,   3.2700435E-04,   3.3571073E-04,   3.4489343E-04
     +,   3.5461909E-04,   3.6495700E-04,   3.7597673E-04
     +,   3.8774451E-04,   4.0032322E-04,   4.1376657E-04
     +,   4.2811930E-04,   4.4341147E-04,   4.5965883E-04
     +,   4.7685718E-04,   4.9498392E-04,   5.1399303E-04
     +,   5.3381821E-04,   5.5437122E-04,   5.7554140E-04
     +,   5.9719943E-04,   6.1920047E-04,   6.4138690E-04
     +,   6.6359015E-04,   6.8564096E-04,   7.0736668E-04
     +,   7.2860497E-04,   7.4920116E-04,   7.6902070E-04
     +,   7.8794622E-04,   8.0588908E-04,   8.2278671E-04
     +,   8.3860900E-04,   8.5335952E-04,   8.6707348E-04
     +,   8.7982026E-04,   8.9170295E-04,   9.0285431E-04
     +,   9.1343326E-04,   9.2362589E-04,   9.3363703E-04
     +,   9.4368897E-04,   9.5401431E-04,   9.6485286E-04
     +,   9.7644510E-04,   9.8902558E-04,   1.0028176E-03
     +,   1.0180278E-03,   1.0348377E-03,   1.0533996E-03
     +,   1.0738291E-03,   1.0962060E-03,   1.1205683E-03
     +,   1.1469129E-03,   1.1752018E-03,   1.2053602E-03
     +,   1.2372930E-03,   1.2708880E-03,   1.3060314E-03
     +,   1.3426158E-03,   1.3805613E-03,   1.4198187E-03
     +,   1.4603933E-03,   1.5023465E-03,   1.5458064E-03
     +,   1.5909754E-03,   1.6381308E-03,   1.6876176E-03
     +,   1.7398205E-03,   1.7951427E-03,   1.8539608E-03
     +,   1.9165642E-03,   1.9830838E-03,   2.0534424E-03
     +,   2.1273047E-03,   2.2040589E-03,   2.2828719E-03
     +,   2.3627882E-03,   2.4428910E-03,   2.5224907E-03
     +,   2.6013099E-03,   2.6796132E-03,   2.7582073E-03
     +,   2.8382959E-03,   2.9212111E-03,   3.0080914E-03
     +,   3.0995423E-03,   3.1954830E-03,   3.2952165E-03
     +,   3.3977288E-03,   3.5021792E-03,   3.6083886E-03
     +,   3.7172295E-03,   3.8306271E-03,   3.9512264E-03
     +,   4.0817768E-03,   4.2243791E-03,   4.3799398E-03
     +,   4.5479611E-03,   4.7268714E-03,   4.9147205E-03
     +,   5.1098973E-03,   5.3115557E-03,   5.5194455E-03
     +,   5.7330467E-03,   5.9504211E-03,   6.1672791E-03
     +,   6.3768635E-03,   6.5708128E-03,   6.7409351E-03
     +,   6.8812505E-03,   6.9895214E-03,   7.0676566E-03
     +,   7.1208007E-03,   7.1553150E-03,   7.1763187E-03
     +,   7.1856142E-03,   7.1806344E-03,   7.1548568E-03
     +,   7.0994510E-03,   7.0056827E-03,   6.8672625E-03
     +,   6.6819638E-03,   6.4520757E-03,   6.1836597E-03
     +,   5.8850679E-03,   5.5651553E-03,   5.2319048E-03
     +,   4.8916317E-03,   4.5488658E-03,   4.2066723E-03
     +,   3.8671901E-03,   3.5322090E-03,   3.2034349E-03
     +,   2.8827416E-03,   2.5722545E-03,   2.2743295E-03
     +,   1.9914403E-03,   1.7260629E-03,   1.4804839E-03
     +,   1.2565640E-03,   1.0555240E-03,   8.7784237E-04
     +,   7.2323228E-04,   5.9069018E-04,   4.7863097E-04
     +,   3.8508212E-04,   3.0787627E-04,   2.4479712E-04
     +,   1.9371873E-04,   1.5269054E-04,   1.1997914E-04
     +,   9.4080802E-05,   7.3718984E-05,   5.7825975E-05
     +,   4.5516008E-05,   3.6059348E-05,   2.8859000E-05
     +,   2.3429238E-05,   1.9376388E-05,   1.6383212E-05
     +,   1.4196330E-05,   1.2615347E-05,   1.1483180E-05
     +,   1.0678411E-05,   1.0108528E-05,   9.7040129E-06
     +,   9.4134566E-06,   9.1994789E-06,   9.0353724E-06
     +,   8.9023797E-06,   8.7875533E-06,   8.6821474E-06
     +,   8.5803749E-06,   8.4785070E-06,   8.3742116E-06
     +,   8.2660972E-06,   8.1534045E-06,   8.0357731E-06
     +,   7.9131032E-06,   7.7854684E-06,   7.6530514E-06
     +,   7.5160924E-06,   7.3748683E-06,   7.2296975E-06
     +,   7.0809119E-06,   6.9288426E-06,   6.7738270E-06
     +,   6.6162124E-06,   6.4563519E-06,   6.2945828E-06
     +,   6.1312376E-06,   5.9666659E-06,   5.8011915E-06
     +,   5.6351337E-06,   5.4688130E-06,   5.3025451E-06
     +,   5.1366205E-06,   4.9713244E-06,   4.8069392E-06
     +,   4.6437358E-06,   4.4819640E-06,   4.3218593E-06
     +,   4.1636595E-06,   4.0075715E-06,   3.8538055E-06
     +,   3.7025393E-06,   3.5539554E-06,   3.4082043E-06
     +,   3.2654414E-06,   3.1257866E-06,   2.9893677E-06
     +,   2.8562786E-06,   2.7266192E-06,   2.6004604E-06
     +,   2.4778628E-06,   2.3588855E-06,   2.2435602E-06
     +,   2.1319211E-06,   2.0239777E-06,   1.9197425E-06
     +,   1.8192043E-06,   1.7223545E-06,   1.6291640E-06
     +,   1.5396067E-06,   1.4536364E-06,   1.3712119E-06
     +,   1.2922735E-06,   1.2167661E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt120 = Yx/0.091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3740933E-04,   1.4806486E-04
     +,   1.6020397E-04,   1.7413177E-04,   1.9020664E-04
     +,   2.0884525E-04,   2.3053044E-04,   2.5582366E-04
     +,   2.8538614E-04,   3.2001792E-04,   3.6071546E-04
     +,   4.0876825E-04,   4.6589697E-04,   5.3444720E-04
     +,   6.1763212E-04,   7.1981124E-04,   8.4675790E-04
     +,   1.0058356E-03,   1.2059761E-03,   1.4573046E-03
     +,   1.7702845E-03,   2.1543056E-03,   2.6159291E-03
     +,   3.1576140E-03,   3.7781999E-03,   4.4772555E-03
     +,   5.2633770E-03,   6.1644875E-03,   7.2342539E-03
     +,   8.5480781E-03,   1.0185668E-02,   1.2205282E-02
     +,   1.4623257E-02,   1.7415667E-02,   2.0549882E-02
     +,   2.4030633E-02,   2.7917204E-02,   3.2246564E-02
     +,   3.6840074E-02,   4.1154739E-02,   4.4495303E-02
     +,   4.6540771E-02,   4.7511034E-02,   4.7637973E-02
     +,   4.6737213E-02,   4.4531196E-02,   4.1112889E-02
     +,   3.6905676E-02,   3.2410435E-02,   2.8121118E-02
     +,   2.4464414E-02,   2.1640398E-02,   1.9563692E-02
     +,   1.8006753E-02,   1.6758116E-02,   1.5657330E-02
     +,   1.4581395E-02,   1.3461804E-02,   1.2304044E-02
     +,   1.1166649E-02,   1.0112607E-02,   9.1728354E-03
     +,   8.3418647E-03,   7.5961598E-03,   6.9147213E-03
     +,   6.2885787E-03,   5.7187956E-03,   5.2099228E-03
     +,   4.7640391E-03,   4.3785423E-03,   4.0464802E-03
     +,   3.7585620E-03,   3.5050428E-03,   3.2773046E-03
     +,   3.0687025E-03,   2.8749756E-03,   2.6941691E-03
     +,   2.5261508E-03,   2.3719310E-03,   2.2329011E-03
     +,   2.1102070E-03,   2.0043147E-03,   1.9148878E-03
     +,   1.8408265E-03,   1.7804963E-03,   1.7319591E-03
     +,   1.6932195E-03,   1.6623874E-03,   1.6377942E-03
     +,   1.6180280E-03,   1.6019341E-03,   1.5885802E-03
     +,   1.5772041E-03,   1.5671584E-03,   1.5578609E-03
     +,   1.5487542E-03,   1.5392783E-03,   1.5288630E-03
     +,   1.5169255E-03,   1.5028964E-03,   1.4862327E-03
     +,   1.4664613E-03,   1.4432007E-03,   1.4161970E-03
     +,   1.3853421E-03,   1.3506820E-03,   1.3124266E-03
     +,   1.2709349E-03,   1.2266936E-03,   1.1802877E-03
     +,   1.1323775E-03,   1.0836491E-03,   1.0347923E-03
     +,   9.8645396E-04,   9.3922712E-04,   8.9361350E-04
     +,   8.5002481E-04,   8.0876570E-04,   7.7004312E-04
     +,   7.3396304E-04,   7.0054777E-04,   6.6974992E-04
     +,   6.4146536E-04,   6.1554828E-04,   5.9182668E-04
     +,   5.7012012E-04,   5.5024400E-04,   5.3202547E-04
     +,   5.1530340E-04,   4.9993844E-04,   4.8581031E-04
     +,   4.7282164E-04,   4.6089294E-04,   4.4996437E-04
     +,   4.3998970E-04,   4.3093303E-04,   4.2276731E-04
     +,   4.1547019E-04,   4.0901938E-04,   4.0339187E-04
     +,   3.9856136E-04,   3.9449634E-04,   3.9115865E-04
     +,   3.8850334E-04,   3.8647829E-04,   3.8502482E-04
     +,   3.8407717E-04,   3.8356474E-04,   3.8341194E-04
     +,   3.8354041E-04,   3.8386934E-04,   3.8431821E-04
     +,   3.8480703E-04,   3.8525843E-04,   3.8559889E-04
     +,   3.8575931E-04,   3.8567718E-04,   3.8529636E-04
     +,   3.8456873E-04,   3.8345394E-04,   3.8191999E-04
     +,   3.7994367E-04,   3.7751000E-04,   3.7461251E-04
     +,   3.7125233E-04,   3.6743778E-04,   3.6318420E-04
     +,   3.5851277E-04,   3.5344929E-04,   3.4802416E-04
     +,   3.4227074E-04,   3.3622570E-04,   3.2992603E-04
     +,   3.2341009E-04,   3.1671624E-04,   3.0988199E-04
     +,   3.0294314E-04,   2.9593401E-04,   2.8888666E-04
     +,   2.8183009E-04,   2.7479025E-04,   2.6779037E-04
     +,   2.6085071E-04,   2.5398779E-04,   2.4721507E-04
     +,   2.4054352E-04,   2.3398147E-04,   2.2753399E-04
     +,   2.2120426E-04,   2.1499394E-04,   2.0890243E-04
     +,   2.0292781E-04,   1.9706736E-04,   1.9131765E-04
     +,   1.8567427E-04,   1.8013266E-04,   1.7468829E-04
     +,   1.6933700E-04,   1.6407433E-04,   1.5889632E-04
     +,   1.5379983E-04,   1.4878230E-04,   1.4384139E-04
     +,   1.3897542E-04,   1.3418385E-04,   1.2946619E-04
     +,   1.2482255E-04,   1.2025391E-04,   1.1576169E-04
     +,   1.1134736E-04,   1.0701278E-04,   1.0276030E-04
     +,   9.8592463E-05,   9.4511604E-05,   9.0520152E-05
     +,   8.6620712E-05,   8.2815859E-05,   7.9107667E-05
     +,   7.5498116E-05,   7.1989285E-05,   6.8582631E-05
     +,   6.5279339E-05,   6.2080537E-05,   5.8986978E-05
     +,   5.5998946E-05,   5.3116382E-05,   5.0339135E-05
     +,   4.7666716E-05,   4.5098201E-05,   4.2632371E-05
     +,   4.0267962E-05,   3.8003429E-05,   3.5836892E-05
     +,   3.3766282E-05,   3.1789568E-05,   2.9904393E-05
     +,   2.8108265E-05,   2.6398726E-05,   2.4773233E-05
     +,   2.3229062E-05,   2.1763473E-05,   2.0373782E-05
     +,   1.9057303E-05,   1.7811242E-05,   1.6632855E-05
     +,   1.5519472E-05,   1.4468469E-05,   1.3477184E-05
     +,   1.2543015E-05,   1.1663500E-05,   1.0836142E-05
     +,   1.0058518E-05,   9.3283143E-06,   8.6432810E-06
     +,   8.0011878E-06,   7.3998826E-06,   6.8373192E-06
     +,   6.3115176E-06,   5.8205333E-06,   5.3624908E-06
     +,   4.9356213E-06,   4.5382135E-06,   4.1685989E-06
     +,   3.8251792E-06,   3.5064522E-06,   3.2109481E-06
     +,   2.9372591E-06,   2.6840612E-06,   2.4500855E-06
     +,   2.2341062E-06,   2.0349580E-06,   1.8515451E-06
     +,   1.6828230E-06,   1.5277901E-06,   1.3854981E-06
     +,   1.2550628E-06,   1.1356303E-06,   1.0264097E-06
     +,   9.2664254E-07,   8.3562645E-07,   7.5268917E-07
     +,   6.7721140E-07,   6.0860174E-07,   5.4631602E-07
     +,   4.8983799E-07,   4.3869261E-07,   3.9243255E-07
     +,   3.5064187E-07,   3.1293851E-07,   2.7896297E-07
     +,   2.4838710E-07,   2.2090347E-07,   1.9623185E-07
     +,   1.7411105E-07,   1.5430349E-07,   1.3658838E-07
     +,   1.2076582E-07,   1.0665033E-07,   9.4074416E-08
     +,   8.2883588E-08,   7.2938413E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt60 = Yx/0.248652173913044
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9238712E-05,   4.0223269E-05
     +,   4.1254287E-05,   4.2345218E-05,   4.3511955E-05
     +,   4.4773180E-05,   4.6150668E-05,   4.7669699E-05
     +,   4.9359391E-05,   5.1253322E-05,   5.3389824E-05
     +,   5.5812645E-05,   5.8571495E-05,   6.1722647E-05
     +,   6.5329565E-05,   6.9463436E-05,   7.4203876E-05
     +,   7.9639423E-05,   8.5868094E-05,   9.2997914E-05
     +,   1.0114731E-04,   1.1044566E-04,   1.2103355E-04
     +,   1.3306460E-04,   1.4670506E-04,   1.6214016E-04
     +,   1.7957996E-04,   1.9927567E-04,   2.2155003E-04
     +,   2.4684778E-04,   2.7581988E-04,   3.0945003E-04
     +,   3.4923226E-04,   3.9740285E-04,   4.5722182E-04
     +,   5.3327571E-04,   6.3176430E-04,   7.6070137E-04
     +,   9.2997088E-04,   1.1511126E-03,   1.4369255E-03
     +,   1.8007640E-03,   2.2557192E-03,   2.8136452E-03
     +,   3.4839998E-03,   4.2725462E-03,   5.1806634E-03
     +,   6.2073632E-03,   7.3563647E-03,   8.6462405E-03
     +,   1.0114699E-02,   1.1813456E-02,   1.3811536E-02
     +,   1.6221957E-02,   1.9205609E-02,   2.2879118E-02
     +,   2.7180795E-02,   3.1906255E-02,   3.6932524E-02
     +,   4.2259060E-02,   4.7746159E-02,   5.2982520E-02
     +,   5.7313278E-02,   5.9868351E-02,   5.9842572E-02
     +,   5.7049125E-02,   5.2556522E-02,   4.8452295E-02
     +,   4.5999933E-02,   4.4367488E-02,   4.1991100E-02
     +,   3.8411230E-02,   3.4095775E-02,   2.9558452E-02
     +,   2.5287582E-02,   2.1795115E-02,   1.9289687E-02
     +,   1.7506918E-02,   1.5968421E-02,   1.4352749E-02
     +,   1.2641852E-02,   1.1013053E-02,   9.6487012E-03
     +,   8.6199827E-03,   7.8863949E-03,   7.3562297E-03
     +,   6.9428161E-03,   6.5875249E-03,   6.2574036E-03
     +,   5.9345975E-03,   5.6087119E-03,   5.2742157E-03
     +,   4.9304403E-03,   4.5818444E-03,   4.2372798E-03
     +,   3.9082952E-03,   3.6068729E-03,   3.3433682E-03
     +,   3.1248226E-03,   2.9541063E-03,   2.8297319E-03
     +,   2.7464349E-03,   2.6961484E-03,   2.6692760E-03
     +,   2.6559089E-03,   2.6468863E-03,   2.6345407E-03
     +,   2.6131361E-03,   2.5789810E-03,   2.5303192E-03
     +,   2.4670523E-03,   2.3903593E-03,   2.3023041E-03
     +,   2.2054329E-03,   2.1024714E-03,   1.9960289E-03
     +,   1.8884738E-03,   1.7817979E-03,   1.6776248E-03
     +,   1.5772003E-03,   1.4814598E-03,   1.3910925E-03
     +,   1.3065899E-03,   1.2282920E-03,   1.1564310E-03
     +,   1.0911543E-03,   1.0325250E-03,   9.8054111E-04
     +,   9.3512022E-04,   8.9611474E-04,   8.6329808E-04
     +,   8.3637540E-04,   8.1497838E-04,   7.9867645E-04
     +,   7.8697520E-04,   7.7933085E-04,   7.7515689E-04
     +,   7.7383593E-04,   7.7473168E-04,   7.7720638E-04
     +,   7.8063319E-04,   7.8441395E-04,   7.8799383E-04
     +,   7.9087558E-04,   7.9263042E-04,   7.9290936E-04
     +,   7.9144730E-04,   7.8806863E-04,   7.8268361E-04
     +,   7.7528699E-04,   7.6594850E-04,   7.5480482E-04
     +,   7.4204733E-04,   7.2790729E-04,   7.1264419E-04
     +,   6.9653057E-04,   6.7984144E-04,   6.6283729E-04
     +,   6.4575957E-04,   6.2882132E-04,   6.1219971E-04
     +,   5.9603440E-04,   5.8042700E-04,   5.6544197E-04
     +,   5.5110658E-04,   5.3741748E-04,   5.2434561E-04
     +,   5.1184063E-04,   4.9983629E-04,   4.8825593E-04
     +,   4.7701958E-04,   4.6604621E-04,   4.5525818E-04
     +,   4.4458444E-04,   4.3396346E-04,   4.2334359E-04
     +,   4.1268364E-04,   4.0195478E-04,   3.9113939E-04
     +,   3.8022877E-04,   3.6922385E-04,   3.5813407E-04
     +,   3.4697587E-04,   3.3577005E-04,   3.2454205E-04
     +,   3.1332069E-04,   3.0213682E-04,   2.9102163E-04
     +,   2.8000594E-04,   2.6912164E-04,   2.5839781E-04
     +,   2.4786222E-04,   2.3754097E-04,   2.2745764E-04
     +,   2.1763287E-04,   2.0808424E-04,   1.9882702E-04
     +,   1.8987371E-04,   1.8123322E-04,   1.7291150E-04
     +,   1.6491242E-04,   1.5723718E-04,   1.4988384E-04
     +,   1.4284848E-04,   1.3612564E-04,   1.2970746E-04
     +,   1.2358461E-04,   1.1774671E-04,   1.1218260E-04
     +,   1.0687983E-04,   1.0182552E-04,   9.7006916E-05
     +,   9.2411166E-05,   8.8025256E-05,   8.3836632E-05
     +,   7.9833408E-05,   7.6004326E-05,   7.2338597E-05
     +,   6.8826128E-05,   6.5458094E-05,   6.2226092E-05
     +,   5.9122551E-05,   5.6140922E-05,   5.3275395E-05
     +,   5.0520674E-05,   4.7872174E-05,   4.5325996E-05
     +,   4.2878841E-05,   4.0527601E-05,   3.8269591E-05
     +,   3.6102596E-05,   3.4024630E-05,   3.2033702E-05
     +,   3.0128011E-05,   2.8305989E-05,   2.6565918E-05
     +,   2.4906107E-05,   2.3324932E-05,   2.1820719E-05
     +,   2.0391624E-05,   1.9035746E-05,   1.7751183E-05
     +,   1.6535954E-05,   1.5387908E-05,   1.4304848E-05
     +,   1.3284563E-05,   1.2324789E-05,   1.1423155E-05
     +,   1.0577262E-05,   9.7847724E-06,   9.0432632E-06
     +,   8.3503164E-06,   7.7035802E-06,   7.1007271E-06
     +,   6.5394238E-06,   6.0173893E-06,   5.5324340E-06
     +,   5.0824251E-06,   4.6652667E-06,   4.2789429E-06
     +,   3.9215392E-06,   3.5912167E-06,   3.2861960E-06
     +,   3.0047854E-06,   2.7454012E-06,   2.5065167E-06
     +,   2.2866882E-06,   2.0845687E-06,   1.8988866E-06
     +,   1.7284342E-06,   1.5720797E-06,   1.4287726E-06
     +,   1.2975290E-06,   1.1774217E-06,   1.0675858E-06
     +,   9.6722670E-07,   8.7559062E-07,   7.9198975E-07
     +,   7.1577415E-07,   6.4635066E-07,   5.8316033E-07
     +,   5.2569374E-07,   4.7347214E-07,   4.2605950E-07
     +,   3.8304668E-07,   3.4406156E-07,   3.0875722E-07
     +,   2.7681335E-07,   2.4793854E-07,   2.2186029E-07
     +,   1.9833158E-07,   1.7712205E-07,   1.5802310E-07
     +,   1.4084044E-07,   1.2539849E-07,   1.1153398E-07
     +,   9.9099594E-08,   8.7958668E-08,   7.7987941E-08
     +,   6.9073479E-08,   6.1112466E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt65 = Yx/0.301893617021277
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7878931E-05,   1.9253586E-05
     +,   2.0695761E-05,   2.2205279E-05,   2.3781664E-05
     +,   2.5424115E-05,   2.7131535E-05,   2.8902528E-05
     +,   3.0735366E-05,   3.2628137E-05,   3.4578610E-05
     +,   3.6584344E-05,   3.8642735E-05,   4.0751016E-05
     +,   4.2906362E-05,   4.5105870E-05,   4.7346733E-05
     +,   4.9626211E-05,   5.1941784E-05,   5.4291217E-05
     +,   5.6672729E-05,   5.9085043E-05,   6.1527593E-05
     +,   6.4000858E-05,   6.6506145E-05,   6.9046429E-05
     +,   7.1626193E-05,   7.4251999E-05,   7.6932862E-05
     +,   7.9680787E-05,   8.2511266E-05,   8.5443928E-05
     +,   8.8503337E-05,   9.1719718E-05,   9.5129908E-05
     +,   9.8778291E-05,   1.0271790E-04,   1.0701157E-04
     +,   1.1173365E-04,   1.1697086E-04,   1.2282538E-04
     +,   1.2941705E-04,   1.3688733E-04,   1.4540479E-04
     +,   1.5517230E-04,   1.6643728E-04,   1.7950506E-04
     +,   1.9475630E-04,   2.1266937E-04,   2.3384849E-04
     +,   2.5905913E-04,   2.8927147E-04,   3.2571380E-04
     +,   3.6993934E-04,   4.2389269E-04,   4.8999971E-04
     +,   5.7123631E-04,   6.7119894E-04,   7.9414586E-04
     +,   9.4501657E-04,   1.1294570E-03,   1.3539257E-03
     +,   1.6259737E-03,   1.9548379E-03,   2.3520398E-03
     +,   2.8314108E-03,   3.4081324E-03,   4.0971059E-03
     +,   4.9143573E-03,   5.8854269E-03,   7.0639085E-03
     +,   8.5576056E-03,   1.0554279E-02,   1.3307273E-02
     +,   1.7007384E-02,   2.1571364E-02,   2.6680367E-02
     +,   3.2310549E-02,   3.9046519E-02,   4.7159627E-02
     +,   5.5459719E-02,   6.2250413E-02,   6.7121767E-02
     +,   7.0300117E-02,   7.1577325E-02,   7.1518473E-02
     +,   7.1176440E-02,   6.9663361E-02,   6.5928258E-02
     +,   6.0937438E-02,   5.5468965E-02,   4.9395233E-02
     +,   4.3016020E-02,   3.7197798E-02,   3.2565139E-02
     +,   2.8939163E-02,   2.5717055E-02,   2.2625387E-02
     +,   1.9818569E-02,   1.7441370E-02,   1.5413824E-02
     +,   1.3594217E-02,   1.1951313E-02,   1.0550513E-02
     +,   9.4461059E-03,   8.6187618E-03,   7.9899626E-03
     +,   7.4695023E-03,   6.9906926E-03,   6.5202946E-03
     +,   6.0520195E-03,   5.5950009E-03,   5.1642386E-03
     +,   4.7742818E-03,   4.4360221E-03,   4.1552079E-03
     +,   3.9321729E-03,   3.7621772E-03,   3.6364566E-03
     +,   3.5436230E-03,   3.4713901E-03,   3.4081636E-03
     +,   3.3443230E-03,   3.2729376E-03,   3.1899970E-03
     +,   3.0941516E-03,   2.9861797E-03,   2.8683329E-03
     +,   2.7436663E-03,   2.6155019E-03,   2.4869882E-03
     +,   2.3608627E-03,   2.2393023E-03,   2.1239540E-03
     +,   2.0159732E-03,   1.9161580E-03,   1.8250649E-03
     +,   1.7431041E-03,   1.6705808E-03,   1.6077257E-03
     +,   1.5546699E-03,   1.5113918E-03,   1.4776658E-03
     +,   1.4530239E-03,   1.4367236E-03,   1.4277550E-03
     +,   1.4248580E-03,   1.4265812E-03,   1.4313398E-03
     +,   1.4374959E-03,   1.4434364E-03,   1.4476443E-03
     +,   1.4487653E-03,   1.4456596E-03,   1.4374413E-03
     +,   1.4235023E-03,   1.4035197E-03,   1.3774475E-03
     +,   1.3455041E-03,   1.3081405E-03,   1.2660008E-03
     +,   1.2198797E-03,   1.1706763E-03,   1.1193476E-03
     +,   1.0668524E-03,   1.0141166E-03,   9.6199586E-04
     +,   9.1124349E-04,   8.6248515E-04,   8.1620994E-04
     +,   7.7276671E-04,   7.3236728E-04,   6.9509068E-04
     +,   6.6090137E-04,   6.2967354E-04,   6.0120272E-04
     +,   5.7523284E-04,   5.5147702E-04,   5.2963558E-04
     +,   5.0941046E-04,   4.9052044E-04,   4.7271300E-04
     +,   4.5576826E-04,   4.3950221E-04,   4.2376926E-04
     +,   4.0846138E-04,   3.9350477E-04,   3.7885373E-04
     +,   3.6448799E-04,   3.5040811E-04,   3.3662777E-04
     +,   3.2317039E-04,   3.1006537E-04,   2.9734339E-04
     +,   2.8503311E-04,   2.7315901E-04,   2.6174053E-04
     +,   2.5079073E-04,   2.4031461E-04,   2.3031025E-04
     +,   2.2076958E-04,   2.1167855E-04,   2.0301731E-04
     +,   1.9476234E-04,   1.8688779E-04,   1.7936529E-04
     +,   1.7216563E-04,   1.6526032E-04,   1.5862181E-04
     +,   1.5222355E-04,   1.4604138E-04,   1.4005386E-04
     +,   1.3424244E-04,   1.2859091E-04,   1.2308591E-04
     +,   1.1771733E-04,   1.1247742E-04,   1.0736056E-04
     +,   1.0236316E-04,   9.7483899E-05,   9.2722410E-05
     +,   8.8079592E-05,   8.3557439E-05,   7.9158635E-05
     +,   7.4885909E-05,   7.0742135E-05,   6.6730485E-05
     +,   6.2853891E-05,   5.9114715E-05,   5.5514942E-05
     +,   5.2056293E-05,   4.8739930E-05,   4.5566241E-05
     +,   4.2535044E-05,   3.9645885E-05,   3.6897472E-05
     +,   3.4287968E-05,   3.1815256E-05,   2.9476734E-05
     +,   2.7269245E-05,   2.5189282E-05,   2.3233180E-05
     +,   2.1396983E-05,   1.9676412E-05,   1.8067023E-05
     +,   1.6564349E-05,   1.5163828E-05,   1.3860755E-05
     +,   1.2650407E-05,   1.1528205E-05,   1.0489477E-05
     +,   9.5296336E-06,   8.6442269E-06,   7.8289067E-06
     +,   7.0793840E-06,   6.3915013E-06,   5.7612974E-06
     +,   5.1849424E-06,   4.6587297E-06,   4.1791145E-06
     +,   3.7427455E-06,   3.3464319E-06,   2.9871167E-06
     +,   2.6619148E-06,   2.3681309E-06,   2.1031967E-06
     +,   1.8647039E-06,   1.6504106E-06,   1.4582204E-06
     +,   1.2861644E-06,   1.1324149E-06,   9.9528461E-07
     +,   8.7321081E-07,   7.6474157E-07,   6.6854108E-07
     +,   5.8338975E-07,   5.0815839E-07,   4.4182420E-07
     +,   3.8344399E-07,   3.3216773E-07,   2.8721584E-07
     +,   2.4788829E-07,   2.1354684E-07,   1.8362060E-07
     +,   1.5759180E-07,   1.3499935E-07,   1.1542808E-07
     +,   9.8507250E-08,   8.3908176E-08,   7.1336757E-08
     +,   6.0533843E-08,   5.1268731E-08,   4.3339046E-08
     +,   3.6565574E-08,   3.0791828E-08,   2.5879842E-08
     +,   2.1709772E-08,   1.8176499E-08,   1.5189036E-08
     +,   1.2668031E-08,   1.0545126E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt70 = Yx/0.352714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7702856E-05,   1.8378843E-05
     +,   1.9089432E-05,   1.9835559E-05,   2.0618063E-05
     +,   2.1437660E-05,   2.2294942E-05,   2.3190367E-05
     +,   2.4124218E-05,   2.5096660E-05,   2.6107638E-05
     +,   2.7156926E-05,   2.8244101E-05,   2.9368548E-05
     +,   3.0529423E-05,   3.1725693E-05,   3.2956079E-05
     +,   3.4219120E-05,   3.5513127E-05,   3.6836198E-05
     +,   3.8186266E-05,   3.9561066E-05,   4.0958173E-05
     +,   4.2375090E-05,   4.3809105E-05,   4.5257566E-05
     +,   4.6717749E-05,   4.8186965E-05,   4.9662620E-05
     +,   5.1142313E-05,   5.2623829E-05,   5.4105323E-05
     +,   5.5585348E-05,   5.7062960E-05,   5.8537833E-05
     +,   6.0010378E-05,   6.1481820E-05,   6.2954379E-05
     +,   6.4431450E-05,   6.5917506E-05,   6.7418550E-05
     +,   6.8942107E-05,   7.0497423E-05,   7.2095601E-05
     +,   7.3750081E-05,   7.5476572E-05,   7.7293771E-05
     +,   7.9223457E-05,   8.1291320E-05,   8.3527513E-05
     +,   8.5967666E-05,   8.8653927E-05,   9.1636444E-05
     +,   9.4975505E-05,   9.8743236E-05,   1.0302721E-04
     +,   1.0793342E-04,   1.1359053E-04,   1.2015494E-04
     +,   1.2781635E-04,   1.3680420E-04,   1.4739476E-04
     +,   1.5991765E-04,   1.7476569E-04,   1.9240241E-04
     +,   2.1336856E-04,   2.3829493E-04,   2.6790594E-04
     +,   3.0303415E-04,   3.4462102E-04,   3.9372998E-04
     +,   4.5153894E-04,   5.1935069E-04,   5.9857458E-04
     +,   6.9075014E-04,   7.9758448E-04,   9.2106091E-04
     +,   1.0636718E-03,   1.2287954E-03,   1.4211466E-03
     +,   1.6471582E-03,   1.9151209E-03,   2.2346424E-03
     +,   2.6155936E-03,   3.0665323E-03,   3.5937552E-03
     +,   4.2013559E-03,   4.8929737E-03,   5.6737610E-03
     +,   6.5521337E-03,   7.5413492E-03,   8.6654844E-03
     +,   9.9803107E-03,   1.1624565E-02,   1.3911536E-02
     +,   1.7441960E-02,   2.3108859E-02,   3.1615395E-02
     +,   4.2368036E-02,   5.3283077E-02,   6.2970579E-02
     +,   7.1939550E-02,   8.0607861E-02,   8.8971160E-02
     +,   9.7660333E-02,   0.1041946    ,   0.1056257    
     +,   0.1033222    ,   9.4773516E-02,   8.2716942E-02
     +,   7.3913760E-02,   6.6104248E-02,   5.7535741E-02
     +,   5.0186209E-02,   4.5099910E-02,   4.1337829E-02
     +,   3.7712444E-02,   3.3778396E-02,   2.9518975E-02
     +,   2.5094446E-02,   2.0951195E-02,   1.7565509E-02
     +,   1.5062159E-02,   1.3257240E-02,   1.1926117E-02
     +,   1.0931240E-02,   1.0193084E-02,   9.6396264E-03
     +,   9.1949366E-03,   8.7922700E-03,   8.3852299E-03
     +,   7.9498840E-03,   7.4817473E-03,   6.9914423E-03
     +,   6.4988397E-03,   6.0256859E-03,   5.5886018E-03
     +,   5.1948521E-03,   4.8426250E-03,   4.5247814E-03
     +,   4.2337333E-03,   3.9649350E-03,   3.7178404E-03
     +,   3.4946855E-03,   3.2982659E-03,   3.1298837E-03
     +,   2.9883529E-03,   2.8700414E-03,   2.7696805E-03
     +,   2.6814579E-03,   2.6000629E-03,   2.5214183E-03
     +,   2.4430004E-03,   2.3638171E-03,   2.2840914E-03
     +,   2.2048161E-03,   2.1272474E-03,   2.0524538E-03
     +,   1.9810316E-03,   1.9129729E-03,   1.8476786E-03
     +,   1.7841120E-03,   1.7210130E-03,   1.6571278E-03
     +,   1.5914062E-03,   1.5231514E-03,   1.4520978E-03
     +,   1.3784172E-03,   1.3026628E-03,   1.2256884E-03
     +,   1.1485430E-03,   1.0723604E-03,   9.9824730E-04
     +,   9.2720916E-04,   8.6009386E-04,   7.9754426E-04
     +,   7.3998951E-04,   6.8765448E-04,   6.4057123E-04
     +,   5.9860578E-04,   5.6149438E-04,   5.2887772E-04
     +,   5.0033093E-04,   4.7539046E-04,   4.5358067E-04
     +,   4.3443518E-04,   4.1750789E-04,   4.0238502E-04
     +,   3.8869132E-04,   3.7609716E-04,   3.6431535E-04
     +,   3.5310374E-04,   3.4226384E-04,   3.3163777E-04
     +,   3.2110320E-04,   3.1057213E-04,   2.9998581E-04
     +,   2.8931123E-04,   2.7853559E-04,   2.6766356E-04
     +,   2.5671418E-04,   2.4571651E-04,   2.3470641E-04
     +,   2.2372411E-04,   2.1281344E-04,   2.0201740E-04
     +,   1.9137804E-04,   1.8093587E-04,   1.7072813E-04
     +,   1.6078768E-04,   1.5114329E-04,   1.4182000E-04
     +,   1.3283842E-04,   1.2421435E-04,   1.1595948E-04
     +,   1.0808212E-04,   1.0058698E-04,   9.3475042E-05
     +,   8.6744360E-05,   8.0391088E-05,   7.4408410E-05
     +,   6.8787675E-05,   6.3518935E-05,   5.8590878E-05
     +,   5.3990796E-05,   4.9705126E-05,   4.5720095E-05
     +,   4.2021376E-05,   3.8594226E-05,   3.5423822E-05
     +,   3.2495616E-05,   2.9795227E-05,   2.7308348E-05
     +,   2.5021056E-05,   2.2920089E-05,   2.0992436E-05
     +,   1.9225628E-05,   1.7607874E-05,   1.6127955E-05
     +,   1.4775133E-05,   1.3539293E-05,   1.2411003E-05
     +,   1.1381407E-05,   1.0442167E-05,   9.5855239E-06
     +,   8.8043253E-06,   8.0919399E-06,   7.4421946E-06
     +,   6.8494155E-06,   6.3084349E-06,   5.8144633E-06
     +,   5.3631279E-06,   4.9504642E-06,   4.5728616E-06
     +,   4.2270135E-06,   3.9099209E-06,   3.6188962E-06
     +,   3.3515032E-06,   3.1055301E-06,   2.8789830E-06
     +,   2.6700843E-06,   2.4772341E-06,   2.2989839E-06
     +,   2.1340331E-06,   1.9812326E-06,   1.8395341E-06
     +,   1.7080007E-06,   1.5857969E-06,   1.4721744E-06
     +,   1.3664511E-06,   1.2680142E-06,   1.1763179E-06
     +,   1.0908678E-06,   1.0112112E-06,   9.3693700E-07
     +,   8.6767869E-07,   8.0309195E-07,   7.4287033E-07
     +,   6.8672421E-07,   6.3439444E-07,   5.8563427E-07
     +,   5.4022138E-07,   4.9794329E-07,   4.5860716E-07
     +,   4.2202794E-07,   3.8803660E-07,   3.5647133E-07
     +,   3.2718015E-07,   3.0002258E-07,   2.7486251E-07
     +,   2.5157493E-07,   2.3003854E-07,   2.1014159E-07
     +,   1.9177570E-07,   1.7484095E-07,   1.5924050E-07
     +,   1.4488499E-07,   1.3168800E-07,   1.1956976E-07
     +,   1.0845337E-07,   9.8267783E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt75 = Yx/0.44464
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2275259E-05,   1.2892458E-05
     +,   1.3530972E-05,   1.4190975E-05,   1.4872628E-05
     +,   1.5576075E-05,   1.6301452E-05,   1.7048889E-05
     +,   1.7818496E-05,   1.8610423E-05,   1.9424782E-05
     +,   2.0261708E-05,   2.1121346E-05,   2.2003851E-05
     +,   2.2909408E-05,   2.3838214E-05,   2.4790503E-05
     +,   2.5766536E-05,   2.6766620E-05,   2.7791093E-05
     +,   2.8840359E-05,   2.9914851E-05,   3.1015064E-05
     +,   3.2141637E-05,   3.3295124E-05,   3.4476314E-05
     +,   3.5685985E-05,   3.6925048E-05,   3.8194503E-05
     +,   3.9495448E-05,   4.0829109E-05,   4.2196829E-05
     +,   4.3600056E-05,   4.5040390E-05,   4.6519537E-05
     +,   4.8039368E-05,   4.9601855E-05,   5.1209096E-05
     +,   5.2863412E-05,   5.4567045E-05,   5.6322548E-05
     +,   5.8132471E-05,   5.9999471E-05,   6.1926272E-05
     +,   6.3915744E-05,   6.5970722E-05,   6.8094239E-05
     +,   7.0289323E-05,   7.2559182E-05,   7.4907170E-05
     +,   7.7336852E-05,   7.9852194E-05,   8.2457394E-05
     +,   8.5157502E-05,   8.7957895E-05,   9.0865229E-05
     +,   9.3887029E-05,   9.7032229E-05,   1.0031139E-04
     +,   1.0373683E-04,   1.0732302E-04,   1.1108680E-04
     +,   1.1504734E-04,   1.1922677E-04,   1.2365026E-04
     +,   1.2834548E-04,   1.3334375E-04,   1.3867888E-04
     +,   1.4438845E-04,   1.5051228E-04,   1.5709399E-04
     +,   1.6417934E-04,   1.7181777E-04,   1.8006084E-04
     +,   1.8896394E-04,   1.9858574E-04,   2.0898809E-04
     +,   2.2023682E-04,   2.3240327E-04,   2.4556424E-04
     +,   2.5980175E-04,   2.7520684E-04,   2.9187748E-04
     +,   3.0992410E-04,   3.2946805E-04,   3.5065081E-04
     +,   3.7363591E-04,   3.9862652E-04,   4.2587778E-04
     +,   4.5572946E-04,   4.8864266E-04,   5.2524841E-04
     +,   5.6641275E-04,   6.1331259E-04,   6.6750892E-04
     +,   7.3100807E-04,   8.0630934E-04,   8.9636719E-04
     +,   1.0044939E-03,   1.1340885E-03,   1.2882723E-03
     +,   1.4693645E-03,   1.6785297E-03,   1.9158587E-03
     +,   2.1817491E-03,   2.4803672E-03,   2.8261563E-03
     +,   3.2537142E-03,   3.8294378E-03,   4.6591391E-03
     +,   5.8804611E-03,   7.6302518E-03,   9.9944947E-03
     +,   1.2982942E-02,   1.6587265E-02,   2.0968344E-02
     +,   2.6664812E-02,   3.4302145E-02,   4.3550067E-02
     +,   5.3158309E-02,   6.3086517E-02,   7.4733399E-02
     +,   8.7843925E-02,   0.1007157    ,   0.1092142    
     +,   0.1161851    ,   0.1254466    ,   0.1270933    
     +,   0.1197197    ,   0.1072062    ,   9.4554000E-02
     +,   8.5037552E-02,   7.6002583E-02,   6.5557308E-02
     +,   5.4063503E-02,   4.4295210E-02,   3.7495654E-02
     +,   3.2699864E-02,   2.8650295E-02,   2.4885152E-02
     +,   2.1640612E-02,   1.9180877E-02,   1.7380493E-02
     +,   1.5897324E-02,   1.4517444E-02,   1.3224600E-02
     +,   1.2051814E-02,   1.0981423E-02,   9.9670086E-03
     +,   8.9880656E-03,   8.0669634E-03,   7.2476305E-03
     +,   6.5650297E-03,   6.0280291E-03,   5.6197667E-03
     +,   5.3080223E-03,   5.0569726E-03,   4.8358240E-03
     +,   4.6234378E-03,   4.4094590E-03,   4.1927886E-03
     +,   3.9785141E-03,   3.7742436E-03,   3.5868122E-03
     +,   3.4200440E-03,   3.2739104E-03,   3.1448998E-03
     +,   3.0272030E-03,   2.9142664E-03,   2.8002530E-03
     +,   2.6810919E-03,   2.5549491E-03,   2.4221460E-03
     +,   2.2846824E-03,   2.1455351E-03,   2.0078956E-03
     +,   1.8745937E-03,   1.7477279E-03,   1.6285236E-03
     +,   1.5173823E-03,   1.4140747E-03,   1.3179862E-03
     +,   1.2283289E-03,   1.1443172E-03,   1.0652961E-03
     +,   9.9079648E-04,   9.2053897E-04,   8.5440231E-04
     +,   7.9238095E-04,   7.3453854E-04,   6.8094203E-04
     +,   6.3162704E-04,   5.8656919E-04,   5.4566242E-04
     +,   5.0871202E-04,   4.7544585E-04,   4.4553020E-04
     +,   4.1858765E-04,   3.9421883E-04,   3.7202577E-04
     +,   3.5163187E-04,   3.3269488E-04,   3.1491657E-04
     +,   2.9804785E-04,   2.8189245E-04,   2.6630110E-04
     +,   2.5116818E-04,   2.3642732E-04,   2.2204328E-04
     +,   2.0800428E-04,   1.9431692E-04,   1.8100167E-04
     +,   1.6808670E-04,   1.5560361E-04,   1.4358503E-04
     +,   1.3206316E-04,   1.2106682E-04,   1.1061988E-04
     +,   1.0074107E-04,   9.1444366E-05,   8.2736893E-05
     +,   7.4620068E-05,   6.7090077E-05,   6.0137831E-05
     +,   5.3748903E-05,   4.7904639E-05,   4.2583120E-05
     +,   3.7759335E-05,   3.3405526E-05,   2.9492292E-05
     +,   2.5989390E-05,   2.2865990E-05,   2.0091067E-05
     +,   1.7634098E-05,   1.5465674E-05,   1.3557353E-05
     +,   1.1882193E-05,   1.0415026E-05,   9.1324528E-06
     +,   8.0128539E-06,   7.0365254E-06,   6.1856981E-06
     +,   5.4444122E-06,   4.7983890E-06,   4.2350025E-06
     +,   3.7431807E-06,   3.3132358E-06,   2.9367147E-06
     +,   2.6063096E-06,   2.3157493E-06,   2.0596233E-06
     +,   1.8333052E-06,   1.6328582E-06,   1.4549249E-06
     +,   1.2966351E-06,   1.1555446E-06,   1.0295785E-06
     +,   9.1696188E-07,   8.1616662E-07,   7.2587795E-07
     +,   6.4496567E-07,   5.7244597E-07,   5.0745354E-07
     +,   4.4922825E-07,   3.9710264E-07,   3.5047688E-07
     +,   3.0881432E-07,   2.7163526E-07,   2.3850563E-07
     +,   2.0902959E-07,   1.8284803E-07,   1.5963533E-07
     +,   1.3909464E-07,   1.2095354E-07,   1.0496387E-07
     +,   9.0900862E-08,   7.8558131E-08,   6.7749440E-08
     +,   5.8304451E-08,   5.0070152E-08,   4.2906965E-08
     +,   3.6690221E-08,   3.1306797E-08,   2.6655998E-08
     +,   2.2647098E-08,   1.9199717E-08,   1.6241927E-08
     +,   1.3710013E-08,   1.1547810E-08,   9.7054675E-09
     +,   8.1394278E-09,   6.8112276E-09,   5.6874314E-09
     +,   4.7387179E-09,   3.9397112E-09,   3.2682925E-09
     +,   2.7054305E-09,   2.2346234E-09,   1.8417505E-09
     +,   1.5146415E-09,   1.2429316E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt80 = Yx/0.496039215686275
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0268253E-05,   1.0558795E-05
     +,   1.0852864E-05,   1.1151084E-05,   1.1454207E-05
     +,   1.1763125E-05,   1.2078898E-05,   1.2402747E-05
     +,   1.2736066E-05,   1.3080459E-05,   1.3437739E-05
     +,   1.3809917E-05,   1.4199232E-05,   1.4608180E-05
     +,   1.5039480E-05,   1.5496114E-05,   1.5981323E-05
     +,   1.6498596E-05,   1.7051696E-05,   1.7644628E-05
     +,   1.8281662E-05,   1.8967296E-05,   1.9706258E-05
     +,   2.0503508E-05,   2.1364127E-05,   2.2293452E-05
     +,   2.3296876E-05,   2.4379917E-05,   2.5548143E-05
     +,   2.6807120E-05,   2.8162407E-05,   2.9619441E-05
     +,   3.1183547E-05,   3.2859825E-05,   3.4653138E-05
     +,   3.6568039E-05,   3.8608687E-05,   4.0778825E-05
     +,   4.3081789E-05,   4.5520192E-05,   4.8096317E-05
     +,   5.0811665E-05,   5.3667132E-05,   5.6662946E-05
     +,   5.9798615E-05,   6.3072963E-05,   6.6484085E-05
     +,   7.0029368E-05,   7.3705502E-05,   7.7508514E-05
     +,   8.1433762E-05,   8.5475978E-05,   8.9629226E-05
     +,   9.3887313E-05,   9.8243050E-05,   1.0268920E-04
     +,   1.0721783E-04,   1.1182066E-04,   1.1648893E-04
     +,   1.2121357E-04,   1.2598503E-04,   1.3079353E-04
     +,   1.3562851E-04,   1.4047933E-04,   1.4533503E-04
     +,   1.5018356E-04,   1.5501321E-04,   1.5981114E-04
     +,   1.6456467E-04,   1.6926024E-04,   1.7388484E-04
     +,   1.7842476E-04,   1.8286736E-04,   1.8720001E-04
     +,   1.9141189E-04,   1.9549405E-04,   1.9943985E-04
     +,   2.0324616E-04,   2.0691486E-04,   2.1045336E-04
     +,   2.1387555E-04,   2.1720391E-04,   2.2046968E-04
     +,   2.2371451E-04,   2.2699086E-04,   2.3036260E-04
     +,   2.3390462E-04,   2.3770262E-04,   2.4185101E-04
     +,   2.4645182E-04,   2.5161129E-04,   2.5743595E-04
     +,   2.6402925E-04,   2.7148737E-04,   2.7989459E-04
     +,   2.8931853E-04,   2.9980965E-04,   3.1139690E-04
     +,   3.2409170E-04,   3.3788808E-04,   3.5277271E-04
     +,   3.6873121E-04,   3.8576490E-04,   4.0390308E-04
     +,   4.2322488E-04,   4.4387626E-04,   4.6608777E-04
     +,   4.9019064E-04,   5.1663339E-04,   5.4598838E-04
     +,   5.7895709E-04,   6.1638118E-04,   6.5923773E-04
     +,   7.0865359E-04,   7.6588930E-04,   8.3234295E-04
     +,   9.0952311E-04,   9.9908980E-04,   1.1029583E-03
     +,   1.2236553E-03,   1.3649720E-03,   1.5328981E-03
     +,   1.7366144E-03,   1.9889155E-03,   2.3053449E-03
     +,   2.7017859E-03,   3.1915200E-03,   3.7833562E-03
     +,   4.4825599E-03,   5.2928990E-03,   6.2185512E-03
     +,   7.2704707E-03,   8.4967948E-03,   1.0050668E-02
     +,   1.2260895E-02,   1.5598308E-02,   2.0491850E-02
     +,   2.7179137E-02,   3.5584718E-02,   4.5200162E-02
     +,   5.6440089E-02,   7.0816964E-02,   8.7252401E-02
     +,   0.1016797    ,   0.1158898    ,   0.1356536    
     +,   0.1492427    ,   0.1543709    ,   0.1472986    
     +,   0.1384603    ,   0.1262953    ,   0.1086502    
     +,   9.2007078E-02,   7.7242233E-02,   6.5470584E-02
     +,   5.6761149E-02,   4.8663612E-02,   3.9553128E-02
     +,   3.1521760E-02,   2.6044883E-02,   2.2322819E-02
     +,   1.9301217E-02,   1.6728269E-02,   1.4743011E-02
     +,   1.3374897E-02,   1.2398514E-02,   1.1491805E-02
     +,   1.0449254E-02,   9.2554446E-03,   8.0183921E-03
     +,   6.8634208E-03,   5.8673723E-03,   5.0493143E-03
     +,   4.3923589E-03,   3.8678227E-03,   3.4491445E-03
     +,   3.1163245E-03,   2.8551375E-03,   2.6547518E-03
     +,   2.5055008E-03,   2.3975328E-03,   2.3202605E-03
     +,   2.2625949E-03,   2.2136855E-03,   2.1639003E-03
     +,   2.1057301E-03,   2.0343822E-03,   1.9479555E-03
     +,   1.8471783E-03,   1.7348257E-03,   1.6149093E-03
     +,   1.4918756E-03,   1.3699257E-03,   1.2525138E-03
     +,   1.1420872E-03,   1.0400546E-03,   9.4691187E-04
     +,   8.6245209E-04,   7.8600569E-04,   7.1667659E-04
     +,   6.5352506E-04,   5.9568643E-04,   5.4243038E-04
     +,   4.9318752E-04,   4.4754308E-04,   4.0519892E-04
     +,   3.6594737E-04,   3.2964093E-04,   2.9616395E-04
     +,   2.6541107E-04,   2.3727717E-04,   2.1165180E-04
     +,   1.8841398E-04,   1.6743013E-04,   1.4855826E-04
     +,   1.3165092E-04,   1.1655705E-04,   1.0312385E-04
     +,   9.1200971E-05,   8.0644037E-05,   7.1314222E-05
     +,   6.3081185E-05,   5.5824541E-05,   4.9433838E-05
     +,   4.3808395E-05,   3.8857739E-05,   3.4501430E-05
     +,   3.0668041E-05,   2.7294253E-05,   2.4324367E-05
     +,   2.1709631E-05,   1.9407218E-05,   1.7379376E-05
     +,   1.5592921E-05,   1.4018840E-05,   1.2631377E-05
     +,   1.1407804E-05,   1.0328123E-05,   9.3746203E-06
     +,   8.5315660E-06,   7.7850509E-06,   7.1228378E-06
     +,   6.5341260E-06,   6.0093635E-06,   5.5401742E-06
     +,   5.1192596E-06,   4.7402477E-06,   4.3975829E-06
     +,   4.0864575E-06,   3.8027636E-06,   3.5429480E-06
     +,   3.3039760E-06,   3.0832866E-06,   2.8787083E-06
     +,   2.6883963E-06,   2.5108002E-06,   2.3446310E-06
     +,   2.1888056E-06,   2.0424111E-06,   1.9046785E-06
     +,   1.7749703E-06,   1.6527456E-06,   1.5375346E-06
     +,   1.4289332E-06,   1.3265958E-06,   1.2302074E-06
     +,   1.1394832E-06,   1.0541681E-06,   9.7402403E-07
     +,   8.9882070E-07,   8.2833873E-07,   7.6237120E-07
     +,   7.0071633E-07,   6.4317334E-07,   5.8954578E-07
     +,   5.3964629E-07,   4.9328412E-07,   4.5027846E-07
     +,   4.1044660E-07,   3.7361519E-07,   3.3961007E-07
     +,   3.0826669E-07,   2.7942082E-07,   2.5291774E-07
     +,   2.2860459E-07,   2.0633745E-07,   1.8597599E-07
     +,   1.6738619E-07,   1.5044208E-07,   1.3502128E-07
     +,   1.2101020E-07,   1.0829910E-07,   9.6786437E-08
     +,   8.6374804E-08,   7.6974345E-08,   6.8499588E-08
     +,   6.0871841E-08,   5.4016667E-08,   4.7865825E-08
     +,   4.2355172E-08,   3.7426013E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt85 = Yx/0.53378431372549
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.5606944E-06,   8.7431354E-06
     +,   8.9153164E-06,   9.0766935E-06,   9.2268283E-06
     +,   9.3653962E-06,   9.4921907E-06,   9.6071562E-06
     +,   9.7104012E-06,   9.8022165E-06,   9.8830915E-06
     +,   9.9537483E-06,   1.0015149E-05,   1.0068548E-05
     +,   1.0115486E-05,   1.0157838E-05,   1.0197835E-05
     +,   1.0238094E-05,   1.0281638E-05,   1.0331936E-05
     +,   1.0392901E-05,   1.0468942E-05,   1.0564939E-05
     +,   1.0686295E-05,   1.0838887E-05,   1.1029096E-05
     +,   1.1263755E-05,   1.1550144E-05,   1.1895894E-05
     +,   1.2308979E-05,   1.2797584E-05,   1.3370033E-05
     +,   1.4034668E-05,   1.4799716E-05,   1.5673137E-05
     +,   1.6662480E-05,   1.7774701E-05,   1.9015984E-05
     +,   2.0391670E-05,   2.1905851E-05,   2.3561524E-05
     +,   2.5360208E-05,   2.7301952E-05,   2.9385204E-05
     +,   3.1606800E-05,   3.3961915E-05,   3.6444111E-05
     +,   3.9045466E-05,   4.1756633E-05,   4.4567041E-05
     +,   4.7465146E-05,   5.0438637E-05,   5.3474709E-05
     +,   5.6560591E-05,   5.9683312E-05,   6.2830753E-05
     +,   6.5991342E-05,   6.9154587E-05,   7.2311275E-05
     +,   7.5453623E-05,   7.8575358E-05,   8.1671897E-05
     +,   8.4739964E-05,   8.7778062E-05,   9.0785819E-05
     +,   9.3763774E-05,   9.6713455E-05,   9.9636418E-05
     +,   1.0253470E-04,   1.0540957E-04,   1.0826200E-04
     +,   1.1109161E-04,   1.1389711E-04,   1.1667539E-04
     +,   1.1942214E-04,   1.2213150E-04,   1.2479600E-04
     +,   1.2740705E-04,   1.2995538E-04,   1.3243131E-04
     +,   1.3482507E-04,   1.3712788E-04,   1.3933217E-04
     +,   1.4143241E-04,   1.4342563E-04,   1.4531234E-04
     +,   1.4709643E-04,   1.4878639E-04,   1.5039486E-04
     +,   1.5193931E-04,   1.5344194E-04,   1.5492953E-04
     +,   1.5643310E-04,   1.5798780E-04,   1.5963246E-04
     +,   1.6140893E-04,   1.6336185E-04,   1.6553806E-04
     +,   1.6798690E-04,   1.7075951E-04,   1.7390978E-04
     +,   1.7749424E-04,   1.8157371E-04,   1.8621339E-04
     +,   1.9148499E-04,   1.9746776E-04,   2.0424882E-04
     +,   2.1192433E-04,   2.2059974E-04,   2.3038842E-04
     +,   2.4140847E-04,   2.5378168E-04,   2.6762669E-04
     +,   2.8305728E-04,   3.0017379E-04,   3.1906401E-04
     +,   3.3979566E-04,   3.6242319E-04,   3.8698580E-04
     +,   4.1352090E-04,   4.4207383E-04,   4.7271003E-04
     +,   5.0553068E-04,   5.4068846E-04,   5.7839294E-04
     +,   6.1890529E-04,   6.6253473E-04,   7.0960034E-04
     +,   7.6040247E-04,   8.1515574E-04,   8.7393966E-04
     +,   9.3662145E-04,   1.0028210E-03,   1.0718709E-03
     +,   1.1428636E-03,   1.2147544E-03,   1.2865700E-03
     +,   1.3577634E-03,   1.4286825E-03,   1.5011251E-03
     +,   1.5788467E-03,   1.6678660E-03,   1.7762741E-03
     +,   1.9133141E-03,   2.0876059E-03,   2.3048506E-03
     +,   2.5657271E-03,   2.8653247E-03,   3.1955217E-03
     +,   3.5508396E-03,   3.9370265E-03,   4.3814471E-03
     +,   4.9454775E-03,   5.7359640E-03,   6.9042887E-03
     +,   8.6300056E-03,   1.1133403E-02,   1.4778295E-02
     +,   2.0140003E-02,   2.7683344E-02,   3.7422232E-02
     +,   4.9403999E-02,   6.5105557E-02,   8.4459417E-02
     +,   0.1054323    ,   0.1320087    ,   0.1507004    
     +,   0.1635760    ,   0.1749159    ,   0.1662486    
     +,   0.1515641    ,   0.1354037    ,   0.1130339    
     +,   9.2241853E-02,   7.3492013E-02,   5.8209516E-02
     +,   4.5241013E-02,   3.5373569E-02,   3.0000696E-02
     +,   2.7227407E-02,   2.4650631E-02,   2.1472950E-02
     +,   1.8031094E-02,   1.4865025E-02,   1.2294066E-02
     +,   1.0337886E-02,   8.8323271E-03,   7.6003978E-03
     +,   6.5350221E-03,   5.5964007E-03,   4.7827782E-03
     +,   4.1030045E-03,   3.5580494E-03,   3.1346201E-03
     +,   2.8087676E-03,   2.5532737E-03,   2.3434921E-03
     +,   2.1600609E-03,   1.9893080E-03,   1.8226354E-03
     +,   1.6556710E-03,   1.4873598E-03,   1.3190358E-03
     +,   1.1535113E-03,   9.9424471E-04,   8.4460992E-04
     +,   7.0741924E-04,   5.8465154E-04,   4.7733873E-04
     +,   3.8560497E-04,   3.0881673E-04,   2.4577780E-04
     +,   1.9493021E-04,   1.5454424E-04,   1.2288216E-04
     +,   9.8314864E-05,   7.9391182E-05,   6.4871972E-05
     +,   5.3737458E-05,   4.5173205E-05,   3.8542599E-05
     +,   3.3358530E-05,   2.9254159E-05,   2.5955978E-05
     +,   2.3261518E-05,   2.1021800E-05,   1.9127519E-05
     +,   1.7498340E-05,   1.6075041E-05,   1.4813889E-05
     +,   1.3682541E-05,   1.2656895E-05,   1.1718850E-05
     +,   1.0854795E-05,   1.0054510E-05,   9.3101407E-06
     +,   8.6156679E-06,   7.9664633E-06,   7.3588903E-06
     +,   6.7899960E-06,   6.2573549E-06,   5.7589546E-06
     +,   5.2930327E-06,   4.8579727E-06,   4.4522808E-06
     +,   4.0745640E-06,   3.7234745E-06,   3.3976751E-06
     +,   3.0958518E-06,   2.8167410E-06,   2.5590691E-06
     +,   2.3215860E-06,   2.1030864E-06,   1.9023925E-06
     +,   1.7183473E-06,   1.5498362E-06,   1.3957977E-06
     +,   1.2552150E-06,   1.1271077E-06,   1.0105466E-06
     +,   9.0465880E-07,   8.0861957E-07,   7.2164579E-07
     +,   6.4300320E-07,   5.7201123E-07,   5.0802709E-07
     +,   4.5045087E-07,   3.9872856E-07,   3.5234481E-07
     +,   3.1081856E-07,   2.7370461E-07,   2.4059409E-07
     +,   2.1110957E-07,   1.8490095E-07,   1.6164705E-07
     +,   1.4105515E-07,   1.2285432E-07,   1.0679924E-07
     +,   9.2663946E-08,   8.0244519E-08,   6.9353973E-08
     +,   5.9824188E-08,   5.1501708E-08,   4.4249205E-08
     +,   3.7941852E-08,   3.2468400E-08,   2.7728516E-08
     +,   2.3632495E-08,   2.0100691E-08,   1.7061733E-08
     +,   1.4452655E-08,   1.2217374E-08,   1.0306604E-08
     +,   8.6766994E-09,   7.2894957E-09,   6.1113670E-09
     +,   5.1130482E-09,   4.2689017E-09,   3.5567316E-09
     +,   2.9571861E-09,   2.4535964E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt90 = Yx/0.518823529411765
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.3618174E-07,   6.2013737E-07
     +,   7.1532179E-07,   8.2291115E-07,   9.4415282E-07
     +,   1.0803631E-06,   1.2329220E-06,   1.4032687E-06
     +,   1.5928878E-06,   1.8033135E-06,   2.0361017E-06
     +,   2.2928252E-06,   2.5750605E-06,   2.8843669E-06
     +,   3.2222702E-06,   3.5902472E-06,   3.9896972E-06
     +,   4.4219287E-06,   4.8881307E-06,   5.3893514E-06
     +,   5.9264817E-06,   6.5002246E-06,   7.1110708E-06
     +,   7.7593286E-06,   8.4449921E-06,   9.1678785E-06
     +,   9.9274957E-06,   1.0723094E-05,   1.1553647E-05
     +,   1.2417860E-05,   1.3314182E-05,   1.4240814E-05
     +,   1.5195729E-05,   1.6176711E-05,   1.7181366E-05
     +,   1.8207207E-05,   1.9251645E-05,   2.0312067E-05
     +,   2.1385966E-05,   2.2470815E-05,   2.3564387E-05
     +,   2.4664630E-05,   2.5769812E-05,   2.6878603E-05
     +,   2.7990136E-05,   2.9104076E-05,   3.0220690E-05
     +,   3.1340904E-05,   3.2466360E-05,   3.3599466E-05
     +,   3.4743400E-05,   3.5902151E-05,   3.7080514E-05
     +,   3.8284143E-05,   3.9519342E-05,   4.0793271E-05
     +,   4.2113679E-05,   4.3488912E-05,   4.4927787E-05
     +,   4.6439534E-05,   4.8033591E-05,   4.9719529E-05
     +,   5.1506751E-05,   5.3404630E-05,   5.5422141E-05
     +,   5.7567580E-05,   5.9848786E-05,   6.2272498E-05
     +,   6.4844811E-05,   6.7570414E-05,   7.0453134E-05
     +,   7.3495205E-05,   7.6698001E-05,   8.0061109E-05
     +,   8.3583174E-05,   8.7261637E-05,   9.1092625E-05
     +,   9.5071213E-05,   9.9191864E-05,   1.0344844E-04
     +,   1.0783404E-04,   1.1234204E-04,   1.1696544E-04
     +,   1.2169829E-04,   1.2653474E-04,   1.3147066E-04
     +,   1.3650273E-04,   1.4162995E-04,   1.4685281E-04
     +,   1.5217460E-04,   1.5760136E-04,   1.6314157E-04
     +,   1.6880671E-04,   1.7461169E-04,   1.8057457E-04
     +,   1.8671555E-04,   1.9305813E-04,   1.9962722E-04
     +,   2.0644972E-04,   2.1355214E-04,   2.2096114E-04
     +,   2.2870052E-04,   2.3679159E-04,   2.4524954E-04
     +,   2.5408357E-04,   2.6329493E-04,   2.7287396E-04
     +,   2.8280044E-04,   2.9304263E-04,   3.0355642E-04
     +,   3.1428496E-04,   3.2516112E-04,   3.3610751E-04
     +,   3.4704138E-04,   3.5787516E-04,   3.6852484E-04
     +,   3.7891322E-04,   3.8897895E-04,   3.9868493E-04
     +,   4.0803032E-04,   4.1706441E-04,   4.2590199E-04
     +,   4.3474216E-04,   4.4389069E-04,   4.5377921E-04
     +,   4.6498276E-04,   4.7823309E-04,   4.9441389E-04
     +,   5.1454530E-04,   5.3973257E-04,   5.7109812E-04
     +,   6.0966780E-04,   6.5624865E-04,   7.1126845E-04
     +,   7.7463954E-04,   8.4563135E-04,   9.2278514E-04
     +,   1.0039145E-03,   1.0861894E-03,   1.1663008E-03
     +,   1.2407044E-03,   1.3059414E-03,   1.3589737E-03
     +,   1.3974973E-03,   1.4202053E-03,   1.4269655E-03
     +,   1.4188824E-03,   1.3982421E-03,   1.3683478E-03
     +,   1.3332538E-03,   1.2974396E-03,   1.2654549E-03
     +,   1.2415600E-03,   1.2294138E-03,   1.2318419E-03
     +,   1.2507116E-03,   1.2869332E-03,   1.3405911E-03
     +,   1.4111808E-03,   1.4979097E-03,   1.6000130E-03
     +,   1.7169975E-03,   1.8487696E-03,   1.9956899E-03
     +,   2.1587063E-03,   2.3398676E-03,   2.5435688E-03
     +,   2.7786233E-03,   3.0603139E-03,   3.4105415E-03
     +,   3.8539511E-03,   4.4098822E-03,   5.0841011E-03
     +,   5.8675087E-03,   6.7488812E-03,   7.7452539E-03
     +,   8.9454511E-03,   1.0540561E-02,   1.2801186E-02
     +,   1.6105087E-02,   2.1129923E-02,   2.8479882E-02
     +,   3.8508467E-02,   5.4139744E-02,   7.7586956E-02
     +,   0.1135262    ,   0.1530923    ,   0.1728731    
     +,   0.2082729    ,   0.2268958    ,   0.1973233    
     +,   0.1600759    ,   0.1290538    ,   9.7609222E-02
     +,   6.7666411E-02,   4.9002513E-02,   3.9001893E-02
     +,   2.9904874E-02,   2.1577153E-02,   1.5402691E-02
     +,   1.1259226E-02,   8.4292777E-03,   6.3716755E-03
     +,   4.7977697E-03,   3.5671780E-03,   2.6166055E-03
     +,   1.9078465E-03,   1.3990968E-03,   1.0425466E-03
     +,   7.9301873E-04,   6.1472470E-04,   4.8290781E-04
     +,   3.8207145E-04,   3.0307868E-04,   2.4054202E-04
     +,   1.9102295E-04,   1.5201746E-04,   1.2149444E-04
     +,   9.7733784E-05,   7.9283993E-05,   6.4945263E-05
     +,   5.3755699E-05,   4.4963996E-05,   3.7994116E-05
     +,   3.2410124E-05,   2.7885173E-05,   2.4175108E-05
     +,   2.1097241E-05,   1.8514353E-05,   1.6323105E-05
     +,   1.4445443E-05,   1.2821916E-05,   1.1406871E-05
     +,   1.0165052E-05,   9.0690637E-06,   8.0971868E-06
     +,   7.2320709E-06,   6.4597152E-06,   5.7686102E-06
     +,   5.1491220E-06,   4.5931220E-06,   4.0937111E-06
     +,   3.6449244E-06,   3.2415417E-06,   2.8789859E-06
     +,   2.5532402E-06,   2.2607346E-06,   1.9982667E-06
     +,   1.7629711E-06,   1.5522943E-06,   1.3639112E-06
     +,   1.1957209E-06,   1.0458265E-06,   9.1250132E-07
     +,   7.9415992E-07,   6.8935509E-07,   5.9676756E-07
     +,   5.1518714E-07,   4.4349787E-07,   3.8067739E-07
     +,   3.2579200E-07,   2.7798674E-07,   2.3647648E-07
     +,   2.0054627E-07,   1.6954895E-07,   1.4289465E-07
     +,   1.2005079E-07,   1.0053947E-07,   8.3931631E-08
     +,   6.9843317E-08,   5.7933029E-08,   4.7899192E-08
     +,   3.9475772E-08,   3.2428588E-08,   2.6553092E-08
     +,   2.1671852E-08,   1.7630454E-08,   1.4296246E-08
     +,   1.1554880E-08,   9.3088923E-09,   7.4750490E-09
     +,   5.9829950E-09,   4.7731552E-09,   3.7955985E-09
     +,   3.0084106E-09,   2.3767377E-09,   1.8715893E-09
     +,   1.4689966E-09,   1.1492615E-09,   8.9618429E-10
     +,   6.9656875E-10,   5.3964888E-10,   4.1672155E-10
     +,   3.2074604E-10,   2.4607369E-10,   1.8816933E-10
     +,   1.4342345E-10,   1.0896138E-10,   8.2511074E-11
     +,   6.2277759E-11,   4.6853424E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_hatt95 = Yx/0.490823529411765
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6900753E-07,   3.1057820E-07
     +,   3.5775139E-07,   4.1114544E-07,   4.7142660E-07
     +,   5.3930893E-07,   6.1555460E-07,   7.0097258E-07
     +,   7.9641802E-07,   9.0279389E-07,   1.0210412E-06
     +,   1.1521411E-06,   1.2971078E-06,   1.4569845E-06
     +,   1.6328368E-06,   1.8257446E-06,   2.0367936E-06
     +,   2.2670677E-06,   2.5176341E-06,   2.7895353E-06
     +,   3.0837746E-06,   3.4013046E-06,   3.7430034E-06
     +,   4.1096905E-06,   4.5020470E-06,   4.9206819E-06
     +,   5.3660492E-06,   5.8384644E-06,   6.3380762E-06
     +,   6.8648596E-06,   7.4185959E-06,   7.9988549E-06
     +,   8.6049949E-06,   9.2361352E-06,   9.8911623E-06
     +,   1.0568714E-05,   1.1267180E-05,   1.1984677E-05
     +,   1.2719129E-05,   1.3468120E-05,   1.4229086E-05
     +,   1.4999171E-05,   1.5775329E-05,   1.6554304E-05
     +,   1.7332666E-05,   1.8106824E-05,   1.8873066E-05
     +,   1.9627571E-05,   2.0366449E-05,   2.1085783E-05
     +,   2.1781654E-05,   2.2450184E-05,   2.3087548E-05
     +,   2.3690105E-05,   2.4254274E-05,   2.4776760E-05
     +,   2.5254449E-05,   2.5684505E-05,   2.6064410E-05
     +,   2.6391979E-05,   2.6665391E-05,   2.6883235E-05
     +,   2.7044493E-05,   2.7148622E-05,   2.7195527E-05
     +,   2.7185564E-05,   2.7119599E-05,   2.6998965E-05
     +,   2.6825484E-05,   2.6601485E-05,   2.6329732E-05
     +,   2.6013528E-05,   2.5656569E-05,   2.5263074E-05
     +,   2.4837645E-05,   2.4385317E-05,   2.3911545E-05
     +,   2.3422199E-05,   2.2923470E-05,   2.2421935E-05
     +,   2.1924541E-05,   2.1438525E-05,   2.0971494E-05
     +,   2.0531297E-05,   2.0126141E-05,   1.9764446E-05
     +,   1.9454950E-05,   1.9206567E-05,   1.9028485E-05
     +,   1.8930026E-05,   1.8920673E-05,   1.9010000E-05
     +,   1.9207604E-05,   1.9523055E-05,   1.9965799E-05
     +,   2.0545031E-05,   2.1269660E-05,   2.2148037E-05
     +,   2.3188013E-05,   2.4396546E-05,   2.5779793E-05
     +,   2.7342638E-05,   2.9088871E-05,   3.1020594E-05
     +,   3.3138451E-05,   3.5441306E-05,   3.7925940E-05
     +,   4.0587074E-05,   4.3417433E-05,   4.6407582E-05
     +,   4.9545564E-05,   5.2817679E-05,   5.6207678E-05
     +,   5.9697792E-05,   6.3268017E-05,   6.6897213E-05
     +,   7.0562506E-05,   7.4240481E-05,   7.7906610E-05
     +,   8.1536462E-05,   8.5105690E-05,   8.8590277E-05
     +,   9.1967253E-05,   9.5215182E-05,   9.8314697E-05
     +,   1.0124846E-04,   1.0400252E-04,   1.0656628E-04
     +,   1.0893390E-04,   1.1110457E-04,   1.1308441E-04
     +,   1.1488712E-04,   1.1653660E-04,   1.1806859E-04
     +,   1.1953383E-04,   1.2100110E-04,   1.2256094E-04
     +,   1.2432958E-04,   1.2645312E-04,   1.2911105E-04
     +,   1.3251863E-04,   1.3692744E-04,   1.4262367E-04
     +,   1.4992217E-04,   1.5915485E-04,   1.7065620E-04
     +,   1.8474205E-04,   2.0168268E-04,   2.2167481E-04
     +,   2.4481452E-04,   2.7107107E-04,   3.0026768E-04
     +,   3.3207703E-04,   3.6603556E-04,   4.0157043E-04
     +,   4.3804783E-04,   4.7484154E-04,   5.1141385E-04
     +,   5.4739346E-04,   5.8264122E-04,   6.1730109E-04
     +,   6.5179996E-04,   6.8680133E-04,   7.2310952E-04
     +,   7.6153717E-04,   8.0275309E-04,   8.4715843E-04
     +,   8.9483592E-04,   9.4561104E-04,   9.9921762E-04
     +,   1.0555519E-03,   1.1149549E-03,   1.1784426E-03
     +,   1.2478357E-03,   1.3258116E-03,   1.4160551E-03
     +,   1.5237195E-03,   1.6563290E-03,   1.8246602E-03
     +,   2.0423196E-03,   2.3237439E-03,   2.6857525E-03
     +,   3.1627822E-03,   3.8319738E-03,   4.8065144E-03
     +,   6.1592828E-03,   7.8461664E-03,   9.7563304E-03
     +,   1.1865943E-02,   1.4363536E-02,   1.7552353E-02
     +,   2.1397844E-02,   2.5341673E-02,   2.9181587E-02
     +,   3.4496538E-02,   4.1778494E-02,   4.7647841E-02
     +,   4.9608011E-02,   4.5612767E-02,   3.7671067E-02
     +,   3.0687515E-02,   2.5742570E-02,   2.1631023E-02
     +,   1.7922092E-02,   1.4555375E-02,   1.1216114E-02
     +,   8.1858002E-03,   5.8701839E-03,   4.2501022E-03
     +,   3.1049333E-03,   2.2724087E-03,   1.6693742E-03
     +,   1.2373946E-03,   9.2551566E-04,   6.9574756E-04
     +,   5.2374165E-04,   3.9388711E-04,   2.9527608E-04
     +,   2.2004168E-04,   1.6266132E-04,   1.1927187E-04
     +,   8.7005144E-05,   6.3516527E-05,   4.6771671E-05
     +,   3.5013345E-05,   2.6792351E-05,   2.0985486E-05
     +,   1.6776747E-05,   1.3609845E-05,   1.1127635E-05
     +,   9.1126731E-06,   7.4375575E-06,   6.0284833E-06
     +,   4.8411075E-06,   3.8458770E-06,   3.0197016E-06
     +,   2.3421683E-06,   1.7940396E-06,   1.3568745E-06
     +,   1.0132117E-06,   7.4694742E-07,   5.4362999E-07
     +,   3.9060754E-07,   2.7707361E-07,   1.9402641E-07
     +,   1.3413485E-07,   9.1546788E-08,   6.1682236E-08
     +,   4.1028596E-08,   2.6942276E-08,   1.7466153E-08
     +,   1.1178135E-08,   7.0624702E-09,   4.4052006E-09
     +,   2.7126275E-09,   1.6490086E-09,   9.8962527E-10
     +,   5.8632998E-10,   3.4294831E-10,   1.9802655E-10
     +,   1.1288422E-10,   6.3528315E-11,   3.5295405E-11
     +,   1.9358728E-11,   1.0482394E-11,   5.6035471E-12
     +,   2.9571532E-12,   1.5406538E-12,   7.9244077E-13
     +,   4.0239394E-13,   2.0172271E-13,   9.9836270E-14
     +,   4.8783314E-14,   2.3534395E-14,   1.1209531E-14
     +,   5.2719077E-15,   2.4482445E-15,   1.1228417E-15
     +,   5.0863894E-16,   2.2764715E-16,   1.0069841E-16
     +,   4.4052827E-17,   1.9076193E-17,   8.1887043E-18
     +,   3.4918788E-18,   1.4841103E-18,   6.3170713E-19
     +,   2.7111842E-19,   1.1839609E-19,   5.3174404E-20
     +,   2.4829038E-20,   1.2150398E-20,   6.2483083E-21
     +,   3.3642001E-21,   1.8810105E-21,   1.0813288E-21
     +,   6.3326755E-22,   3.7504702E-22,   2.2345332E-22
     +,   1.3345754E-22,   7.9723640E-23
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz100 = Yx/0.1405
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0900428E-05,   1.1330233E-05
     +,   1.1766779E-05,   1.2209661E-05,   1.2658453E-05
     +,   1.3112705E-05,   1.3571957E-05,   1.4035724E-05
     +,   1.4503504E-05,   1.4974792E-05,   1.5449059E-05
     +,   1.5925762E-05,   1.6404345E-05,   1.6884247E-05
     +,   1.7364893E-05,   1.7845699E-05,   1.8326076E-05
     +,   1.8805425E-05,   1.9283149E-05,   1.9758631E-05
     +,   2.0231269E-05,   2.0700443E-05,   2.1165533E-05
     +,   2.1625949E-05,   2.2081038E-05,   2.2530210E-05
     +,   2.2972850E-05,   2.3408345E-05,   2.3836084E-05
     +,   2.4255474E-05,   2.4665920E-05,   2.5066836E-05
     +,   2.5457633E-05,   2.5837757E-05,   2.6206639E-05
     +,   2.6563743E-05,   2.6908525E-05,   2.7240481E-05
     +,   2.7559126E-05,   2.7863969E-05,   2.8154564E-05
     +,   2.8430501E-05,   2.8691382E-05,   2.8936855E-05
     +,   2.9166611E-05,   2.9380386E-05,   2.9577968E-05
     +,   2.9759216E-05,   2.9924042E-05,   3.0072462E-05
     +,   3.0204579E-05,   3.0320589E-05,   3.0420821E-05
     +,   3.0505747E-05,   3.0575997E-05,   3.0632367E-05
     +,   3.0675877E-05,   3.0707761E-05,   3.0729516E-05
     +,   3.0742947E-05,   3.0750154E-05,   3.0753617E-05
     +,   3.0756208E-05,   3.0761243E-05,   3.0772499E-05
     +,   3.0794294E-05,   3.0831488E-05,   3.0889529E-05
     +,   3.0974519E-05,   3.1093197E-05,   3.1253003E-05
     +,   3.1462059E-05,   3.1729211E-05,   3.2063981E-05
     +,   3.2476579E-05,   3.2977860E-05,   3.3579250E-05
     +,   3.4292643E-05,   3.5130401E-05,   3.6105142E-05
     +,   3.7229576E-05,   3.8516453E-05,   3.9978146E-05
     +,   4.1626765E-05,   4.3473483E-05,   4.5528770E-05
     +,   4.7801597E-05,   5.0299695E-05,   5.3028671E-05
     +,   5.5992306E-05,   5.9192058E-05,   6.2626503E-05
     +,   6.6291417E-05,   7.0179718E-05,   7.4281146E-05
     +,   7.8581761E-05,   8.3064799E-05,   8.7709588E-05
     +,   9.2492788E-05,   9.7387361E-05,   1.0236397E-04
     +,   1.0739005E-04,   1.1243146E-04,   1.1745156E-04
     +,   1.2241288E-04,   1.2727703E-04,   1.3200511E-04
     +,   1.3655843E-04,   1.4089957E-04,   1.4499253E-04
     +,   1.4880289E-04,   1.5229934E-04,   1.5545316E-04
     +,   1.5823952E-04,   1.6063709E-04,   1.6262909E-04
     +,   1.6420281E-04,   1.6535027E-04,   1.6606803E-04
     +,   1.6635723E-04,   1.6622356E-04,   1.6567699E-04
     +,   1.6473168E-04,   1.6340560E-04,   1.6172019E-04
     +,   1.5970043E-04,   1.5737383E-04,   1.5477081E-04
     +,   1.5192380E-04,   1.4886753E-04,   1.4563817E-04
     +,   1.4227396E-04,   1.3881401E-04,   1.3529947E-04
     +,   1.3177255E-04,   1.2827704E-04,   1.2485859E-04
     +,   1.2156468E-04,   1.1844467E-04,   1.1555025E-04
     +,   1.1293584E-04,   1.1065848E-04,   1.0877803E-04
     +,   1.0735713E-04,   1.0646118E-04,   1.0615804E-04
     +,   1.0651733E-04,   1.0760997E-04,   1.0950679E-04
     +,   1.1227774E-04,   1.1599001E-04,   1.2070631E-04
     +,   1.2648277E-04,   1.3336759E-04,   1.4139853E-04
     +,   1.5060131E-04,   1.6098819E-04,   1.7255913E-04
     +,   1.8530252E-04,   1.9919682E-04,   2.1421861E-04
     +,   2.3035074E-04,   2.4759260E-04,   2.6597790E-04
     +,   2.8559630E-04,   3.0661668E-04,   3.2931368E-04
     +,   3.5409880E-04,   3.8154927E-04,   4.1243224E-04
     +,   4.4771767E-04,   4.8858253E-04,   5.3640030E-04
     +,   5.9270806E-04,   6.5914565E-04,   7.3738740E-04
     +,   8.2902639E-04,   9.3541230E-04,   1.0574497E-03
     +,   1.1953523E-03,   1.3483489E-03,   1.5144370E-03
     +,   1.6903270E-03,   1.8717975E-03,   2.0546869E-03
     +,   2.2366396E-03,   2.4193828E-03,   2.6106613E-03
     +,   2.8246481E-03,   3.0798567E-03,   3.3942882E-03
     +,   3.7788746E-03,   4.2335857E-03,   4.7536031E-03
     +,   5.3454381E-03,   6.0334220E-03,   6.8477448E-03
     +,   7.8548351E-03,   9.2760455E-03,   1.1508055E-02
     +,   1.4874373E-02,   1.9478153E-02,   2.5266029E-02
     +,   3.1859096E-02,   3.8644426E-02,   4.4878475E-02
     +,   4.8888475E-02,   4.8636582E-02,   4.4001207E-02
     +,   3.6720004E-02,   2.8501511E-02,   2.0200856E-02
     +,   1.2515428E-02,   6.5368656E-03,   2.8872851E-03
     +,   1.1495048E-03,   4.7650645E-04,   2.4398070E-04
     +,   1.5804877E-04,   1.1593506E-04,   8.8629553E-05
     +,   6.8688714E-05,   5.3937969E-05,   4.3402830E-05
     +,   3.6244761E-05,   3.1533640E-05,   2.8363225E-05
     +,   2.6014517E-05,   2.4020508E-05,   2.2133772E-05
     +,   2.0254487E-05,   1.8363940E-05,   1.6479969E-05
     +,   1.4632730E-05,   1.2853416E-05,   1.1169033E-05
     +,   9.6008198E-06,   8.1638937E-06,   6.8672721E-06
     +,   5.7143534E-06,   4.7037402E-06,   3.8301537E-06
     +,   3.0852450E-06,   2.4584549E-06,   1.9379031E-06
     +,   1.5111400E-06,   1.1656997E-06,   8.8956608E-07
     +,   6.7155230E-07,   5.0153994E-07,   3.7056057E-07
     +,   2.7086045E-07,   1.9587634E-07,   1.4014881E-07
     +,   9.9216628E-08,   6.9500814E-08,   4.8177814E-08
     +,   3.3052949E-08,   2.2445937E-08,   1.5090757E-08
     +,   1.0047312E-08,   6.6269923E-09,   4.3322559E-09
     +,   2.8087956E-09,   1.8077119E-09,   1.1562457E-09
     +,   7.3614115E-10,   4.6749021E-10,   2.9693120E-10
     +,   1.8926154E-10,   1.2154298E-10,   7.8999904E-11
     +,   5.2212550E-11,   3.5236133E-11,   2.4354966E-11
     +,   1.7265163E-11,   1.2545366E-11,   9.3230449E-12
     +,   7.0619391E-12,   5.4316508E-12,   4.2263294E-12
     +,   3.3159948E-12,   2.6165259E-12,   2.0721159E-12
     +,   1.6444219E-12,   1.3063317E-12,   1.0379985E-12
     +,   8.2453006E-13,   6.5453627E-13,   5.1911486E-13
     +,   4.1127361E-13,   3.2544765E-13,   2.5721097E-13
     +,   2.0301386E-13,   1.6002339E-13,   1.2596315E-13
     +,   9.9015766E-14,   7.7723608E-14,   6.0924315E-14
     +,   4.7687806E-14,   3.7273908E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz105 = Yx/0.1245
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8202056E-08,   7.7817994E-08
     +,   8.8641528E-08,   1.0080238E-07,   1.1444129E-07
     +,   1.2971080E-07,   1.4677549E-07,   1.6581301E-07
     +,   1.8701384E-07,   2.1058409E-07,   2.3674319E-07
     +,   2.6572661E-07,   2.9778607E-07,   3.3319034E-07
     +,   3.7222597E-07,   4.1519837E-07,   4.6243275E-07
     +,   5.1427628E-07,   5.7109764E-07,   6.3329071E-07
     +,   7.0127578E-07,   7.7550141E-07,   8.5644672E-07
     +,   9.4463081E-07,   1.0406019E-06,   1.1449615E-06
     +,   1.2583524E-06,   1.3814735E-06,   1.5150843E-06
     +,   1.6600117E-06,   1.8171585E-06,   1.9875138E-06
     +,   2.1721617E-06,   2.3722914E-06,   2.5892111E-06
     +,   2.8243564E-06,   3.0793071E-06,   3.3557908E-06
     +,   3.6557219E-06,   3.9811589E-06,   4.3343857E-06
     +,   4.7178646E-06,   5.1342690E-06,   5.5864884E-06
     +,   6.0776229E-06,   6.6109897E-06,   7.1901100E-06
     +,   7.8187040E-06,   8.5006723E-06,   9.2400724E-06
     +,   1.0041089E-05,   1.0907997E-05,   1.1845103E-05
     +,   1.2856774E-05,   1.3947198E-05,   1.5120540E-05
     +,   1.6380702E-05,   1.7731305E-05,   1.9175608E-05
     +,   2.0716401E-05,   2.2355918E-05,   2.4095782E-05
     +,   2.5936744E-05,   2.7878887E-05,   2.9921375E-05
     +,   3.2062184E-05,   3.4298511E-05,   3.6626152E-05
     +,   3.9040038E-05,   4.1533614E-05,   4.4099477E-05
     +,   4.6728692E-05,   4.9411537E-05,   5.2136857E-05
     +,   5.4892742E-05,   5.7666351E-05,   6.0443868E-05
     +,   6.3210806E-05,   6.5952321E-05,   6.8653149E-05
     +,   7.1297633E-05,   7.3870404E-05,   7.6355907E-05
     +,   7.8739278E-05,   8.1005863E-05,   8.3142004E-05
     +,   8.5134670E-05,   8.6972090E-05,   8.8643501E-05
     +,   9.0139620E-05,   9.1452668E-05,   9.2576309E-05
     +,   9.3505994E-05,   9.4238996E-05,   9.4774550E-05
     +,   9.5113821E-05,   9.5260191E-05,   9.5219184E-05
     +,   9.4998810E-05,   9.4609532E-05,   9.4064504E-05
     +,   9.3379807E-05,   9.2574468E-05,   9.1671027E-05
     +,   9.0695357E-05,   8.9677233E-05,   8.8650355E-05
     +,   8.7652727E-05,   8.6726577E-05,   8.5918560E-05
     +,   8.5279695E-05,   8.4865045E-05,   8.4733532E-05
     +,   8.4947103E-05,   8.5570049E-05,   8.6667882E-05
     +,   8.8305773E-05,   9.0547248E-05,   9.3451745E-05
     +,   9.7073011E-05,   1.0145667E-04,   1.0663740E-04
     +,   1.1263682E-04,   1.1946166E-04,   1.2710148E-04
     +,   1.3552602E-04,   1.4468611E-04,   1.5451061E-04
     +,   1.6490911E-04,   1.7577020E-04,   1.8696583E-04
     +,   1.9835080E-04,   2.0976899E-04,   2.2105391E-04
     +,   2.3203592E-04,   2.4254525E-04,   2.5241639E-04
     +,   2.6149346E-04,   2.6963517E-04,   2.7671835E-04
     +,   2.8264080E-04,   2.8732535E-04,   2.9072165E-04
     +,   2.9280741E-04,   2.9358864E-04,   2.9310051E-04
     +,   2.9140594E-04,   2.8859457E-04,   2.8478156E-04
     +,   2.8010557E-04,   2.7472747E-04,   2.6882920E-04
     +,   2.6261286E-04,   2.5630032E-04,   2.5013406E-04
     +,   2.4437928E-04,   2.3932601E-04,   2.3529236E-04
     +,   2.3262914E-04,   2.3172361E-04,   2.3300249E-04
     +,   2.3693408E-04,   2.4402555E-04,   2.5481574E-04
     +,   2.6986210E-04,   2.8971795E-04,   3.1489838E-04
     +,   3.4583895E-04,   3.8284881E-04,   4.2605799E-04
     +,   4.7536517E-04,   5.3040433E-04,   5.9053797E-04
     +,   6.5487495E-04,   7.2232407E-04,   7.9170812E-04
     +,   8.6189900E-04,   9.3198742E-04,   1.0014855E-03
     +,   1.0705543E-03,   1.1402256E-03,   1.2126202E-03
     +,   1.2911336E-03,   1.3805310E-03,   1.4868793E-03
     +,   1.6172248E-03,   1.7789199E-03,   1.9784290E-03
     +,   2.2194574E-03,   2.5004698E-03,   2.8125038E-03
     +,   3.1390658E-03,   3.4609628E-03,   3.7673356E-03
     +,   4.0692692E-03,   4.4079535E-03,   4.8505566E-03
     +,   5.4683690E-03,   6.2881331E-03,   7.2327610E-03
     +,   8.1542656E-03,   9.0668323E-03,   1.0381961E-02
     +,   1.2706305E-02,   1.6463224E-02,   2.2157196E-02
     +,   3.0108765E-02,   3.8765583E-02,   4.6047032E-02
     +,   5.1811766E-02,   5.4137569E-02,   4.8535418E-02
     +,   3.5063136E-02,   1.9911155E-02,   8.9343414E-03
     +,   3.3991062E-03,   1.3648508E-03,   7.4344012E-04
     +,   5.2693766E-04,   4.1321357E-04,   3.2859453E-04
     +,   2.5733071E-04,   1.9975846E-04,   1.5734008E-04
     +,   1.2832062E-04,   1.0899197E-04,   9.5773670E-05
     +,   8.6150736E-05,   7.8656369E-05,   7.2532486E-05
     +,   6.7412249E-05,   6.3107182E-05,   5.9488895E-05
     +,   5.6437362E-05,   5.3828822E-05,   5.1541363E-05
     +,   4.9465682E-05,   4.7512935E-05,   4.5617588E-05
     +,   4.3736312E-05,   4.1844596E-05,   3.9932456E-05
     +,   3.7999915E-05,   3.6053258E-05,   3.4102348E-05
     +,   3.2158750E-05,   3.0234341E-05,   2.8340370E-05
     +,   2.6487109E-05,   2.4683814E-05,   2.2938244E-05
     +,   2.1256845E-05,   1.9644878E-05,   1.8106366E-05
     +,   1.6644099E-05,   1.5259831E-05,   1.3954478E-05
     +,   1.2728106E-05,   1.1579985E-05,   1.0508762E-05
     +,   9.5126343E-06,   8.5893580E-06,   7.7362674E-06
     +,   6.9504326E-06,   6.2287945E-06,   5.5680630E-06
     +,   4.9648670E-06,   4.4158260E-06,   3.9175484E-06
     +,   3.4666357E-06,   3.0597510E-06,   2.6936675E-06
     +,   2.3652563E-06,   2.0714817E-06,   1.8094439E-06
     +,   1.5764070E-06,   1.3697522E-06,   1.1870383E-06
     +,   1.0259539E-06,   8.8436457E-07,   7.6026828E-07
     +,   6.5183144E-07,   5.5735097E-07,   4.7527948E-07
     +,   4.0419300E-07,   3.4280768E-07,   2.8995453E-07
     +,   2.4458103E-07,   2.0574650E-07,   1.7260462E-07
     +,   1.4440654E-07,   1.2048402E-07,   1.0024997E-07
     +,   8.3185071E-08,   6.8836229E-08,   5.6805877E-08
     +,   4.6749651E-08,   3.8367752E-08,   3.1402326E-08
     +,   2.5630534E-08,   2.0862151E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz107 = Yx/0.118487804878049
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8267018E-06,   3.0016129E-06
     +,   3.1854051E-06,   3.3784636E-06,   3.5811909E-06
     +,   3.7940076E-06,   4.0173591E-06,   4.2517058E-06
     +,   4.4975277E-06,   4.7553394E-06,   5.0256635E-06
     +,   5.3090480E-06,   5.6060635E-06,   5.9172962E-06
     +,   6.2433560E-06,   6.5848653E-06,   6.9424650E-06
     +,   7.3168044E-06,   7.7085451E-06,   8.1183498E-06
     +,   8.5468864E-06,   8.9948126E-06,   9.4627776E-06
     +,   9.9514382E-06,   1.0461376E-05,   1.0993200E-05
     +,   1.1547450E-05,   1.2124627E-05,   1.2725179E-05
     +,   1.3349491E-05,   1.3997877E-05,   1.4670567E-05
     +,   1.5367701E-05,   1.6089320E-05,   1.6835356E-05
     +,   1.7605624E-05,   1.8399809E-05,   1.9217450E-05
     +,   2.0057996E-05,   2.0920657E-05,   2.1804584E-05
     +,   2.2708713E-05,   2.3631841E-05,   2.4572591E-05
     +,   2.5529444E-05,   2.6500700E-05,   2.7484517E-05
     +,   2.8478895E-05,   2.9481695E-05,   3.0490635E-05
     +,   3.1503321E-05,   3.2517237E-05,   3.3529741E-05
     +,   3.4538203E-05,   3.5539779E-05,   3.6531721E-05
     +,   3.7511167E-05,   3.8475271E-05,   3.9421215E-05
     +,   4.0346193E-05,   4.1247476E-05,   4.2122425E-05
     +,   4.2968466E-05,   4.3783199E-05,   4.4564382E-05
     +,   4.5309884E-05,   4.6017816E-05,   4.6686484E-05
     +,   4.7314425E-05,   4.7900390E-05,   4.8443468E-05
     +,   4.8942915E-05,   4.9398343E-05,   4.9809612E-05
     +,   5.0176895E-05,   5.0500668E-05,   5.0781702E-05
     +,   5.1021045E-05,   5.1220086E-05,   5.1380499E-05
     +,   5.1504241E-05,   5.1593623E-05,   5.1651201E-05
     +,   5.1679875E-05,   5.1682862E-05,   5.1663705E-05
     +,   5.1626328E-05,   5.1575022E-05,   5.1514533E-05
     +,   5.1450126E-05,   5.1387600E-05,   5.1333438E-05
     +,   5.1294897E-05,   5.1280113E-05,   5.1298259E-05
     +,   5.1359719E-05,   5.1476200E-05,   5.1660965E-05
     +,   5.1928946E-05,   5.2296935E-05,   5.2783740E-05
     +,   5.3410186E-05,   5.4199318E-05,   5.5176213E-05
     +,   5.6368030E-05,   5.7803773E-05,   5.9513841E-05
     +,   6.1529725E-05,   6.3883490E-05,   6.6607092E-05
     +,   6.9731163E-05,   7.3284820E-05,   7.7293742E-05
     +,   8.1780112E-05,   8.6760367E-05,   9.2245435E-05
     +,   9.8238357E-05,   1.0473492E-04,   1.1172156E-04
     +,   1.1917629E-04,   1.2706821E-04,   1.3535722E-04
     +,   1.4399501E-04,   1.5292691E-04,   1.6209259E-04
     +,   1.7142697E-04,   1.8086418E-04,   1.9033729E-04
     +,   1.9978310E-04,   2.0914173E-04,   2.1836102E-04
     +,   2.2739606E-04,   2.3621306E-04,   2.4478743E-04
     +,   2.5310720E-04,   2.6117140E-04,   2.6898918E-04
     +,   2.7657996E-04,   2.8397230E-04,   2.9120233E-04
     +,   2.9831158E-04,   3.0534662E-04,   3.1235887E-04
     +,   3.1940281E-04,   3.2653581E-04,   3.3382064E-04
     +,   3.4132524E-04,   3.4912431E-04,   3.5730214E-04
     +,   3.6595573E-04,   3.7519622E-04,   3.8515188E-04
     +,   3.9596952E-04,   4.0781579E-04,   4.2087759E-04
     +,   4.3535724E-04,   4.5146784E-04,   4.6942566E-04
     +,   4.8943696E-04,   5.1167805E-04,   5.3627975E-04
     +,   5.6330260E-04,   5.9271476E-04,   6.2437821E-04
     +,   6.5804733E-04,   6.9338171E-04,   7.2998030E-04
     +,   7.6744170E-04,   8.0544612E-04,   8.4383949E-04
     +,   8.8271307E-04,   9.2246610E-04,   9.6384186E-04
     +,   1.0079329E-03,   1.0561763E-03,   1.1103847E-03
     +,   1.1727916E-03,   1.2460996E-03,   1.3334544E-03
     +,   1.4382260E-03,   1.5634974E-03,   1.7113300E-03
     +,   1.8821061E-03,   2.0744766E-03,   2.2863797E-03
     +,   2.5172106E-03,   2.7703671E-03,   3.0541681E-03
     +,   3.3789256E-03,   3.7499089E-03,   4.1606920E-03
     +,   4.5949635E-03,   5.0421488E-03,   5.5185473E-03
     +,   6.0709072E-03,   6.7451969E-03,   7.5392569E-03
     +,   8.3901240E-03,   9.2254290E-03,   1.0045341E-02
     +,   1.0968911E-02,   1.2196288E-02,   1.3864007E-02
     +,   1.5837543E-02,   1.7661499E-02,   1.8929629E-02
     +,   1.9807646E-02,   2.0942600E-02,   2.2672763E-02
     +,   2.4445677E-02,   2.5050161E-02,   2.3405761E-02
     +,   1.9346882E-02,   1.3855426E-02,   8.4955581E-03
     +,   4.4696024E-03,   2.0852648E-03,   9.5329667E-04
     +,   5.1019748E-04,   3.5667131E-04,   3.0213120E-04
     +,   2.7916435E-04,   2.6768612E-04,   2.6063589E-04
     +,   2.5420432E-04,   2.4612277E-04,   2.3538969E-04
     +,   2.2195783E-04,   2.0634830E-04,   1.8932566E-04
     +,   1.7168408E-04,   1.5412654E-04,   1.3720932E-04
     +,   1.2132963E-04,   1.0673718E-04,   9.3554598E-05
     +,   8.1807397E-05,   7.1452778E-05,   6.2402927E-05
     +,   5.4544020E-05,   4.7751313E-05,   4.1899260E-05
     +,   3.6867292E-05,   3.2543259E-05,   2.8825796E-05
     +,   2.5625204E-05,   2.2863036E-05,   2.0471374E-05
     +,   1.8392211E-05,   1.6576569E-05,   1.4983038E-05
     +,   1.3576960E-05,   1.2329544E-05,   1.1216843E-05
     +,   1.0218938E-05,   9.3193530E-06,   8.5045294E-06
     +,   7.7632712E-06,   7.0862898E-06,   6.4659334E-06
     +,   5.8959208E-06,   5.3710592E-06,   4.8870115E-06
     +,   4.4401618E-06,   4.0275163E-06,   3.6464942E-06
     +,   3.2948747E-06,   2.9707389E-06,   2.6723760E-06
     +,   2.3982116E-06,   2.1467959E-06,   1.9167810E-06
     +,   1.7068828E-06,   1.5158516E-06,   1.3424807E-06
     +,   1.1856131E-06,   1.0441020E-06,   9.1685195E-07
     +,   8.0278244E-07,   7.0086548E-07,   6.1009735E-07
     +,   5.2952896E-07,   4.5824567E-07,   3.9538997E-07
     +,   3.4014590E-07,   2.9175530E-07,   2.4950705E-07
     +,   2.1274232E-07,   1.8085706E-07,   1.5329303E-07
     +,   1.2954440E-07,   1.0914892E-07,   9.1691398E-08
     +,   7.6796525E-08,   6.4130255E-08,   5.3393393E-08
     +,   4.4322114E-08,   3.6682298E-08,   3.0269188E-08
     +,   2.4902782E-08,   2.0426944E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz110 = Yx/0.09485
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3115712E-06,   7.6004444E-06
     +,   7.9037445E-06,   8.2223714E-06,   8.5572556E-06
     +,   8.9093601E-06,   9.2796708E-06,   9.6692011E-06
     +,   1.0078972E-05,   1.0510037E-05,   1.0963444E-05
     +,   1.1440239E-05,   1.1941470E-05,   1.2468163E-05
     +,   1.3021332E-05,   1.3601949E-05,   1.4210961E-05
     +,   1.4849253E-05,   1.5517653E-05,   1.6216934E-05
     +,   1.6947770E-05,   1.7710758E-05,   1.8506382E-05
     +,   1.9335064E-05,   2.0197007E-05,   2.1092399E-05
     +,   2.2021215E-05,   2.2983304E-05,   2.3978357E-05
     +,   2.5005913E-05,   2.6065329E-05,   2.7155804E-05
     +,   2.8276352E-05,   2.9425821E-05,   3.0602874E-05
     +,   3.1806008E-05,   3.3033546E-05,   3.4283617E-05
     +,   3.5554287E-05,   3.6843328E-05,   3.8148508E-05
     +,   3.9467399E-05,   4.0797499E-05,   4.2136176E-05
     +,   4.3480766E-05,   4.4828546E-05,   4.6176738E-05
     +,   4.7522597E-05,   4.8863392E-05,   5.0196428E-05
     +,   5.1519091E-05,   5.2828887E-05,   5.4123426E-05
     +,   5.5400567E-05,   5.6658246E-05,   5.7894722E-05
     +,   5.9108461E-05,   6.0298251E-05,   6.1463164E-05
     +,   6.2602638E-05,   6.3716456E-05,   6.4804859E-05
     +,   6.5868393E-05,   6.6908193E-05,   6.7925816E-05
     +,   6.8923218E-05,   6.9902992E-05,   7.0868133E-05
     +,   7.1822302E-05,   7.2769573E-05,   7.3714698E-05
     +,   7.4662887E-05,   7.5620010E-05,   7.6592398E-05
     +,   7.7587021E-05,   7.8611425E-05,   7.9673613E-05
     +,   8.0782098E-05,   8.1946018E-05,   8.3174877E-05
     +,   8.4478583E-05,   8.5867563E-05,   8.7352448E-05
     +,   8.8944304E-05,   9.0654270E-05,   9.2493879E-05
     +,   9.4474475E-05,   9.6607851E-05,   9.8905351E-05
     +,   1.0137854E-04,   1.0403887E-04,   1.0689734E-04
     +,   1.0996484E-04,   1.1325209E-04,   1.1676953E-04
     +,   1.2052699E-04,   1.2453445E-04,   1.2880101E-04
     +,   1.3333604E-04,   1.3814805E-04,   1.4324574E-04
     +,   1.4863686E-04,   1.5432943E-04,   1.6033030E-04
     +,   1.6664607E-04,   1.7328278E-04,   1.8024478E-04
     +,   1.8753509E-04,   1.9515546E-04,   2.0310540E-04
     +,   2.1138098E-04,   2.1997611E-04,   2.2887971E-04
     +,   2.3807770E-04,   2.4754999E-04,   2.5727239E-04
     +,   2.6721423E-04,   2.7734062E-04,   2.8760996E-04
     +,   2.9797695E-04,   3.0839202E-04,   3.1880243E-04
     +,   3.2915355E-04,   3.3939211E-04,   3.4946753E-04
     +,   3.5933295E-04,   3.6895098E-04,   3.7829261E-04
     +,   3.8734390E-04,   3.9610450E-04,   4.0459304E-04
     +,   4.1284555E-04,   4.2091883E-04,   4.2888720E-04
     +,   4.3684305E-04,   4.4489431E-04,   4.5315779E-04
     +,   4.6175680E-04,   4.7081397E-04,   4.8044475E-04
     +,   4.9075013E-04,   5.0180953E-04,   5.1367795E-04
     +,   5.2637979E-04,   5.3990801E-04,   5.5422704E-04
     +,   5.6927843E-04,   5.8498752E-04,   6.0127594E-04
     +,   6.1807799E-04,   6.3535391E-04,   6.5310259E-04
     +,   6.7137391E-04,   6.9027470E-04,   7.0996571E-04
     +,   7.3064712E-04,   7.5254007E-04,   7.7585556E-04
     +,   8.0076308E-04,   8.2735030E-04,   8.5560279E-04
     +,   8.8538975E-04,   9.1646792E-04,   9.4851351E-04
     +,   9.8117650E-04,   1.0141426E-03,   1.0472016E-03
     +,   1.0803103E-03,   1.1136341E-03,   1.1475588E-03
     +,   1.1826778E-03,   1.2197765E-03,   1.2598297E-03
     +,   1.3040093E-03,   1.3537384E-03,   1.4107643E-03
     +,   1.4772211E-03,   1.5556398E-03,   1.6488885E-03
     +,   1.7600254E-03,   1.8920525E-03,   2.0475576E-03
     +,   2.2282545E-03,   2.4343438E-03,   2.6637039E-03
     +,   2.9111323E-03,   3.1681852E-03,   3.4242300E-03
     +,   3.6690494E-03,   3.8966846E-03,   4.1093845E-03
     +,   4.3199835E-03,   4.5515303E-03,   4.8334645E-03
     +,   5.1942882E-03,   5.6518847E-03,   6.2052771E-03
     +,   6.8339258E-03,   7.5086127E-03,   8.2094241E-03
     +,   8.9375172E-03,   9.7069293E-03,   1.0516559E-02
     +,   1.1321292E-02,   1.2027776E-02,   1.2524379E-02
     +,   1.2725699E-02,   1.2599533E-02,   1.2158775E-02
     +,   1.1431864E-02,   1.0442934E-02,   9.2198225E-03
     +,   7.8190751E-03,   6.3400576E-03,   4.9102874E-03
     +,   3.6486094E-03,   2.6296806E-03,   1.8701375E-03
     +,   1.3395242E-03,   9.8401902E-04,   7.4849068E-04
     +,   5.8917608E-04,   4.7665593E-04,   3.9326976E-04
     +,   3.2905219E-04,   2.7839074E-04,   2.3792760E-04
     +,   2.0543668E-04,   1.7928010E-04,   1.5815455E-04
     +,   1.4097382E-04,   1.2681748E-04,   1.1491557E-04
     +,   1.0464872E-04,   9.5547017E-05,   8.7278633E-05
     +,   7.9631900E-05,   7.2489944E-05,   6.5802087E-05
     +,   5.9557369E-05,   5.3763913E-05,   4.8434114E-05
     +,   4.3575030E-05,   3.9183662E-05,   3.5246387E-05
     +,   3.1740361E-05,   2.8635421E-05,   2.5896554E-05
     +,   2.3486569E-05,   2.1368318E-05,   1.9505767E-05
     +,   1.7865326E-05,   1.6416530E-05,   1.5132196E-05
     +,   1.3988376E-05,   1.2964315E-05,   1.2042276E-05
     +,   1.1207146E-05,   1.0446096E-05,   9.7483553E-06
     +,   9.1049569E-06,   8.5084457E-06,   7.9526280E-06
     +,   7.4324148E-06,   6.9437074E-06,   6.4831415E-06
     +,   6.0480120E-06,   5.6361896E-06,   5.2459814E-06
     +,   4.8760280E-06,   4.5252527E-06,   4.1928129E-06
     +,   3.8780281E-06,   3.5803091E-06,   3.2991441E-06
     +,   3.0340943E-06,   2.7847079E-06,   2.5505717E-06
     +,   2.3312327E-06,   2.1262517E-06,   1.9351407E-06
     +,   1.7574151E-06,   1.5925443E-06,   1.4399988E-06
     +,   1.2992112E-06,   1.1696189E-06,   1.0506367E-06
     +,   9.4167467E-07,   8.4215390E-07,   7.5148432E-07
     +,   6.6909678E-07,   5.9442175E-07,   5.2691479E-07
     +,   4.6603847E-07,   4.1128473E-07,   3.6215880E-07
     +,   3.1819596E-07,   2.7894950E-07,   2.4400325E-07
     +,   2.1296128E-07,   1.8545762E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz115 = Yx/0.0720263157894737
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8091732E-05,   1.8509723E-05
     +,   1.8930987E-05,   1.9355415E-05,   1.9782899E-05
     +,   2.0213332E-05,   2.0646605E-05,   2.1082615E-05
     +,   2.1521255E-05,   2.1962434E-05,   2.2406051E-05
     +,   2.2852011E-05,   2.3300217E-05,   2.3750585E-05
     +,   2.4203031E-05,   2.4657462E-05,   2.5113801E-05
     +,   2.5571981E-05,   2.6031923E-05,   2.6493562E-05
     +,   2.6956846E-05,   2.7421711E-05,   2.7888103E-05
     +,   2.8356006E-05,   2.8825358E-05,   2.9296154E-05
     +,   2.9768375E-05,   3.0242023E-05,   3.0717096E-05
     +,   3.1193631E-05,   3.1671665E-05,   3.2151260E-05
     +,   3.2632503E-05,   3.3115466E-05,   3.3600296E-05
     +,   3.4087145E-05,   3.4576187E-05,   3.5067649E-05
     +,   3.5561792E-05,   3.6058893E-05,   3.6559311E-05
     +,   3.7063430E-05,   3.7571699E-05,   3.8084632E-05
     +,   3.8602800E-05,   3.9126859E-05,   3.9657523E-05
     +,   4.0195620E-05,   4.0742063E-05,   4.1297859E-05
     +,   4.1864136E-05,   4.2442156E-05,   4.3033284E-05
     +,   4.3639076E-05,   4.4261182E-05,   4.4901481E-05
     +,   4.5561992E-05,   4.6244946E-05,   4.6952784E-05
     +,   4.7688140E-05,   4.8453938E-05,   4.9253311E-05
     +,   5.0089657E-05,   5.0966672E-05,   5.1888394E-05
     +,   5.2859032E-05,   5.3883305E-05,   5.4966062E-05
     +,   5.6112654E-05,   5.7328642E-05,   5.8620040E-05
     +,   5.9993086E-05,   6.1454477E-05,   6.3011037E-05
     +,   6.4670006E-05,   6.6438901E-05,   6.8325331E-05
     +,   7.0336981E-05,   7.2481809E-05,   7.4767697E-05
     +,   7.7202283E-05,   7.9793186E-05,   8.2547442E-05
     +,   8.5471860E-05,   8.8572291E-05,   9.1854119E-05
     +,   9.5321302E-05,   9.8977020E-05,   1.0282266E-04
     +,   1.0685834E-04,   1.1108235E-04,   1.1549082E-04
     +,   1.2007770E-04,   1.2483497E-04,   1.2975214E-04
     +,   1.3481588E-04,   1.4001093E-04,   1.4531886E-04
     +,   1.5071948E-04,   1.5618969E-04,   1.6170485E-04
     +,   1.6723787E-04,   1.7276082E-04,   1.7824389E-04
     +,   1.8365729E-04,   1.8897075E-04,   1.9415432E-04
     +,   1.9917874E-04,   2.0401676E-04,   2.0864315E-04
     +,   2.1303484E-04,   2.1717252E-04,   2.2103994E-04
     +,   2.2462543E-04,   2.2792087E-04,   2.3092331E-04
     +,   2.3363359E-04,   2.3605731E-04,   2.3820407E-04
     +,   2.4008739E-04,   2.4172389E-04,   2.4313321E-04
     +,   2.4433702E-04,   2.4535891E-04,   2.4622335E-04
     +,   2.4695604E-04,   2.4758308E-04,   2.4813134E-04
     +,   2.4862919E-04,   2.4910693E-04,   2.4959867E-04
     +,   2.5014338E-04,   2.5078788E-04,   2.5158882E-04
     +,   2.5261572E-04,   2.5395403E-04,   2.5570736E-04
     +,   2.5799964E-04,   2.6097737E-04,   2.6480915E-04
     +,   2.6968517E-04,   2.7581412E-04,   2.8341971E-04
     +,   2.9273418E-04,   3.0398872E-04,   3.1740635E-04
     +,   3.3318991E-04,   3.5150925E-04,   3.7249012E-04
     +,   3.9620444E-04,   4.2265968E-04,   4.5178918E-04
     +,   4.8344990E-04,   5.1742303E-04,   5.5341667E-04
     +,   5.9107103E-04,   6.2997296E-04,   6.6967343E-04
     +,   7.0970308E-04,   7.4958568E-04,   7.8886165E-04
     +,   8.2709710E-04,   8.6389045E-04,   8.9887722E-04
     +,   9.3173189E-04,   9.6216513E-04,   9.8992151E-04
     +,   1.0147889E-03,   1.0366173E-03,   1.0553454E-03
     +,   1.0710392E-03,   1.0839388E-03,   1.0945007E-03
     +,   1.1034264E-03,   1.1116641E-03,   1.1203801E-03
     +,   1.1308900E-03,   1.1445599E-03,   1.1626947E-03
     +,   1.1864352E-03,   1.2166915E-03,   1.2541357E-03
     +,   1.2992792E-03,   1.3526366E-03,   1.4149429E-03
     +,   1.4874135E-03,   1.5719989E-03,   1.6715848E-03
     +,   1.7900668E-03,   1.9321982E-03,   2.1032055E-03
     +,   2.3080911E-03,   2.5507328E-03,   2.8330735E-03
     +,   3.1547043E-03,   3.5130428E-03,   3.9041298E-03
     +,   4.3236548E-03,   4.7674878E-03,   5.2308226E-03
     +,   5.7057170E-03,   6.1776494E-03,   6.6225333E-03
     +,   7.0061674E-03,   7.2875293E-03,   7.4259895E-03
     +,   7.3902411E-03,   7.1661407E-03,   6.7606755E-03
     +,   6.2008318E-03,   5.5283210E-03,   4.7922172E-03
     +,   4.0415330E-03,   3.3193373E-03,   2.6590577E-03
     +,   2.0828268E-03,   1.6014067E-03,   1.2154886E-03
     +,   9.1798825E-04,   6.9679588E-04,   5.3744513E-04
     +,   4.2545164E-04,   3.4790917E-04,   2.9431572E-04
     +,   2.5675472E-04,   2.2963865E-04,   2.0922918E-04
     +,   1.9311809E-04,   1.7978378E-04,   1.6826592E-04
     +,   1.5795149E-04,   1.4844412E-04,   1.3948944E-04
     +,   1.3093122E-04,   1.2268285E-04,   1.1470357E-04
     +,   1.0698219E-04,   9.9524310E-05,   9.2342707E-05
     +,   8.5451276E-05,   7.8862555E-05,   7.2587027E-05
     +,   6.6632441E-05,   6.1003630E-05,   5.5703149E-05
     +,   5.0731705E-05,   4.6087840E-05,   4.1767555E-05
     +,   3.7764719E-05,   3.4071432E-05,   3.0677311E-05
     +,   2.7570157E-05,   2.4736328E-05,   2.2160817E-05
     +,   1.9827441E-05,   1.7719374E-05,   1.5819653E-05
     +,   1.4111292E-05,   1.2577540E-05,   1.1202251E-05
     +,   9.9701901E-06,   8.8670849E-06,   7.8796629E-06
     +,   6.9958164E-06,   6.2046770E-06,   5.4964198E-06
     +,   4.8622987E-06,   4.2946076E-06,   3.7865350E-06
     +,   3.3320318E-06,   2.9257615E-06,   2.5630204E-06
     +,   2.2396189E-06,   1.9517879E-06,   1.6961372E-06
     +,   1.4696188E-06,   1.2694276E-06,   1.0930225E-06
     +,   9.3804630E-07,   8.0234838E-07,   6.8393007E-07
     +,   5.8096458E-07,   4.9175770E-07,   4.1476625E-07
     +,   3.4856737E-07,   2.9187308E-07,   2.4350797E-07
     +,   2.0241049E-07,   1.6763033E-07,   1.3831242E-07
     +,   1.1369991E-07,   9.3119432E-08,   7.5980992E-08
     +,   6.1765490E-08,   5.0022788E-08,   4.0361133E-08
     +,   3.2444220E-08,   2.5982633E-08,   2.0730333E-08
     +,   1.6477827E-08,   1.3048806E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz120 = Yx/0.0452
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1571002E-06,   2.3997670E-06
     +,   2.6641872E-06,   2.9519138E-06,   3.2646674E-06
     +,   3.6043848E-06,   3.9732786E-06,   4.3739046E-06
     +,   4.8092475E-06,   5.2828423E-06,   5.7988541E-06
     +,   6.3622379E-06,   6.9788798E-06,   7.6557626E-06
     +,   8.4011444E-06,   9.2247446E-06,   1.0137939E-05
     +,   1.1153957E-05,   1.2288078E-05,   1.3557804E-05
     +,   1.4983027E-05,   1.6586171E-05,   1.8392257E-05
     +,   2.0429106E-05,   2.2727034E-05,   2.5319259E-05
     +,   2.8241428E-05,   3.1531701E-05,   3.5230536E-05
     +,   3.9380484E-05,   4.4026063E-05,   4.9213566E-05
     +,   5.4990964E-05,   6.1407918E-05,   6.8515816E-05
     +,   7.6367964E-05,   8.5019936E-05,   9.4529809E-05
     +,   1.0495944E-04,   1.1637322E-04,   1.2884098E-04
     +,   1.4243645E-04,   1.5723842E-04,   1.7333071E-04
     +,   1.9080208E-04,   2.0974575E-04,   2.3025906E-04
     +,   2.5244273E-04,   2.7640015E-04,   3.0223679E-04
     +,   3.3005892E-04,   3.5997343E-04,   3.9208544E-04
     +,   4.2649882E-04,   4.6330842E-04,   5.0260307E-04
     +,   5.4445403E-04,   5.8891188E-04,   6.3599850E-04
     +,   6.8569905E-04,   7.3795562E-04,   7.9266215E-04
     +,   8.4965670E-04,   9.0872915E-04,   9.6961815E-04
     +,   1.0320088E-03,   1.0955501E-03,   1.1598431E-03
     +,   1.2244618E-03,   1.2889389E-03,   1.3527893E-03
     +,   1.4155078E-03,   1.4765986E-03,   1.5355947E-03
     +,   1.5921094E-03,   1.6458741E-03,   1.6967891E-03
     +,   1.7449536E-03,   1.7906949E-03,   1.8345403E-03
     +,   1.8771689E-03,   1.9193394E-03,   1.9617777E-03
     +,   2.0050877E-03,   2.0496682E-03,   2.0956821E-03
     +,   2.1430694E-03,   2.1916181E-03,   2.2410441E-03
     +,   2.2911024E-03,   2.3416337E-03,   2.3925693E-03
     +,   2.4438782E-03,   2.4954511E-03,   2.5469635E-03
     +,   2.5977567E-03,   2.6467845E-03,   2.6926303E-03
     +,   2.7336266E-03,   2.7680292E-03,   2.7942224E-03
     +,   2.8108996E-03,   2.8171781E-03,   2.8126179E-03
     +,   2.7971603E-03,   2.7710125E-03,   2.7345265E-03
     +,   2.6881108E-03,   2.6322156E-03,   2.5674007E-03
     +,   2.4944590E-03,   2.4145376E-03,   2.3292336E-03
     +,   2.2405924E-03,   2.1510297E-03,   2.0631242E-03
     +,   1.9794079E-03,   1.9020871E-03,   1.8328590E-03
     +,   1.7727504E-03,   1.7220782E-03,   1.6804882E-03
     +,   1.6470521E-03,   1.6204125E-03,   1.5989421E-03
     +,   1.5809024E-03,   1.5645608E-03,   1.5483075E-03
     +,   1.5307249E-03,   1.5106468E-03,   1.4871982E-03
     +,   1.4598208E-03,   1.4282826E-03,   1.3926877E-03
     +,   1.3534493E-03,   1.3112657E-03,   1.2670731E-03
     +,   1.2219790E-03,   1.1771863E-03,   1.1339106E-03
     +,   1.0933066E-03,   1.0563902E-03,   1.0239767E-03
     +,   9.9663762E-04,   9.7468612E-04,   9.5816824E-04
     +,   9.4688445E-04,   9.4042910E-04,   9.3823625E-04
     +,   9.3963486E-04,   9.4390911E-04,   9.5034897E-04
     +,   9.5829536E-04,   9.6717384E-04,   9.7651524E-04
     +,   9.8596129E-04,   9.9525787E-04,   1.0042426E-03
     +,   1.0128211E-03,   1.0209425E-03,   1.0285748E-03
     +,   1.0356794E-03,   1.0421975E-03,   1.0480324E-03
     +,   1.0530511E-03,   1.0570798E-03,   1.0599123E-03
     +,   1.0613219E-03,   1.0610763E-03,   1.0589483E-03
     +,   1.0547361E-03,   1.0482734E-03,   1.0394377E-03
     +,   1.0281622E-03,   1.0144322E-03,   9.9828967E-04
     +,   9.7982504E-04,   9.5917255E-04,   9.3650207E-04
     +,   9.1200822E-04,   8.8590011E-04,   8.5839746E-04
     +,   8.2971918E-04,   8.0007728E-04,   7.6967303E-04
     +,   7.3869748E-04,   7.0732716E-04,   6.7572296E-04
     +,   6.4403174E-04,   6.1239162E-04,   5.8092689E-04
     +,   5.4975244E-04,   5.1897817E-04,   4.8870652E-04
     +,   4.5903306E-04,   4.3004821E-04,   4.0183921E-04
     +,   3.7448856E-04,   3.4807110E-04,   3.2265592E-04
     +,   2.9830652E-04,   2.7507843E-04,   2.5301633E-04
     +,   2.3215516E-04,   2.1252091E-04,   1.9412616E-04
     +,   1.7697195E-04,   1.6104867E-04,   1.4633531E-04
     +,   1.3279916E-04,   1.2039811E-04,   1.0908239E-04
     +,   9.8795383E-05,   8.9474233E-05,   8.1052640E-05
     +,   7.3462776E-05,   6.6636094E-05,   6.0504393E-05
     +,   5.5001528E-05,   5.0064857E-05,   4.5634883E-05
     +,   4.1656473E-05,   3.8079299E-05,   3.4857734E-05
     +,   3.1950629E-05,   2.9321433E-05,   2.6938085E-05
     +,   2.4772486E-05,   2.2800003E-05,   2.0999263E-05
     +,   1.9351875E-05,   1.7841900E-05,   1.6455435E-05
     +,   1.5180404E-05,   1.4006389E-05,   1.2924151E-05
     +,   1.1925540E-05,   1.1003393E-05,   1.0151314E-05
     +,   9.3635063E-06,   8.6347445E-06,   7.9603442E-06
     +,   7.3360447E-06,   6.7579213E-06,   6.2223967E-06
     +,   5.7262400E-06,   5.2664959E-06,   4.8404258E-06
     +,   4.4455378E-06,   4.0795826E-06,   3.7404702E-06
     +,   3.4262862E-06,   3.1352974E-06,   2.8659140E-06
     +,   2.6166529E-06,   2.3861530E-06,   2.1731689E-06
     +,   1.9765469E-06,   1.7952008E-06,   1.6281213E-06
     +,   1.4743738E-06,   1.3330816E-06,   1.2034101E-06
     +,   1.0845740E-06,   9.7584427E-07,   8.7651875E-07
     +,   7.8593416E-07,   7.0346874E-07,   6.2853223E-07
     +,   5.6056098E-07,   4.9902235E-07,   4.4341704E-07
     +,   3.9327350E-07,   3.4814374E-07,   3.0760739E-07
     +,   2.7127362E-07,   2.3877175E-07,   2.0975976E-07
     +,   1.8391567E-07,   1.6094332E-07,   1.4056528E-07
     +,   1.2252818E-07,   1.0659597E-07,   9.2553798E-08
     +,   8.0203058E-08,   6.9363992E-08,   5.9871439E-08
     +,   5.1575711E-08,   4.4341832E-08,   3.8046995E-08
     +,   3.2581330E-08,   2.7845433E-08,   2.3750914E-08
     +,   2.0218195E-08,   1.7176898E-08,   1.4564051E-08
     +,   1.2324221E-08,   1.0408100E-08,   8.7724956E-09
     +,   7.3791933E-09,   6.1948944E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz60 = Yx/0.0499722222222222
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5687652E-06,   4.6779924E-06
     +,   4.7872900E-06,   4.8965953E-06,   5.0058543E-06
     +,   5.1150373E-06,   5.2241371E-06,   5.3331755E-06
     +,   5.4422117E-06,   5.5513606E-06,   5.6607837E-06
     +,   5.7707207E-06,   5.8814935E-06,   5.9935273E-06
     +,   6.1073683E-06,   6.2237104E-06,   6.3434136E-06
     +,   6.4675378E-06,   6.5973736E-06,   6.7344790E-06
     +,   6.8807108E-06,   7.0382757E-06,   7.2097610E-06
     +,   7.3981996E-06,   7.6070783E-06,   7.8404264E-06
     +,   8.1028220E-06,   8.3994400E-06,   8.7360813E-06
     +,   9.1191869E-06,   9.5558471E-06,   1.0053776E-05
     +,   1.0621291E-05,   1.1267252E-05,   1.2000966E-05
     +,   1.2832082E-05,   1.3770442E-05,   1.4825911E-05
     +,   1.6008233E-05,   1.7326664E-05,   1.8789988E-05
     +,   2.0406162E-05,   2.2182236E-05,   2.4124323E-05
     +,   2.6237685E-05,   2.8527051E-05,   3.0997191E-05
     +,   3.3653847E-05,   3.6505109E-05,   3.9563223E-05
     +,   4.2846990E-05,   4.6384630E-05,   5.0217070E-05
     +,   5.4401935E-05,   5.9016638E-05,   6.4163039E-05
     +,   6.9969763E-05,   7.6595024E-05,   8.4227613E-05
     +,   9.3086666E-05,   1.0341977E-04,   1.1549978E-04
     +,   1.2961907E-04,   1.4608599E-04,   1.6521876E-04
     +,   1.8733919E-04,   2.1277556E-04,   2.4185909E-04
     +,   2.7493908E-04,   3.1239219E-04,   3.5465788E-04
     +,   4.0226767E-04,   4.5590667E-04,   5.1646115E-04
     +,   5.8509340E-04,   6.6329382E-04,   7.5291161E-04
     +,   8.5615920E-04,   9.7557495E-04,   1.1139099E-03
     +,   1.2739417E-03,   1.4582461E-03,   1.6688019E-03
     +,   1.9065727E-03,   2.1708834E-03,   2.4588644E-03
     +,   2.7648362E-03,   3.0801068E-03,   3.3930996E-03
     +,   3.6902844E-03,   3.9576930E-03,   4.1829376E-03
     +,   4.3573794E-03,   4.4778264E-03,   4.5472649E-03
     +,   4.5743771E-03,   4.5718425E-03,   4.5538321E-03
     +,   4.5333304E-03,   4.5199194E-03,   4.5185252E-03
     +,   4.5292443E-03,   4.5482041E-03,   4.5691235E-03
     +,   4.5852065E-03,   4.5908769E-03,   4.5829164E-03
     +,   4.5606093E-03,   4.5249388E-03,   4.4771424E-03
     +,   4.4173975E-03,   4.3443167E-03,   4.2556264E-03
     +,   4.1496977E-03,   4.0273475E-03,   3.8928408E-03
     +,   3.7538540E-03,   3.6201787E-03,   3.5018520E-03
     +,   3.4072304E-03,   3.3415973E-03,   3.3064717E-03
     +,   3.2996002E-03,   3.3154672E-03,   3.3462250E-03
     +,   3.3828551E-03,   3.4164672E-03,   3.4394339E-03
     +,   3.4462509E-03,   3.4338508E-03,   3.4014932E-03
     +,   3.3503112E-03,   3.2827412E-03,   3.2020269E-03
     +,   3.1118395E-03,   3.0160116E-03,   2.9183272E-03
     +,   2.8222622E-03,   2.7307076E-03,   2.6457030E-03
     +,   2.5682398E-03,   2.4982046E-03,   2.4344628E-03
     +,   2.3751049E-03,   2.3177799E-03,   2.2600268E-03
     +,   2.1995876E-03,   2.1346400E-03,   2.0639307E-03
     +,   1.9868352E-03,   1.9033583E-03,   1.8141102E-03
     +,   1.7202357E-03,   1.6233197E-03,   1.5252699E-03
     +,   1.4281783E-03,   1.3341442E-03,   1.2450948E-03
     +,   1.1626338E-03,   1.0879341E-03,   1.0216566E-03
     +,   9.6395653E-04,   9.1454276E-04,   8.7276567E-04
     +,   8.3773525E-04,   8.0844766E-04,   7.8389421E-04
     +,   7.6314074E-04,   7.4538158E-04,   7.2996074E-04
     +,   7.1637391E-04,   7.0424343E-04,   6.9329317E-04
     +,   6.8331504E-04,   6.7414274E-04,   6.6562719E-04
     +,   6.5762131E-04,   6.4997433E-04,   6.4252596E-04
     +,   6.3510903E-04,   6.2755437E-04,   6.1969843E-04
     +,   6.1138626E-04,   6.0247898E-04,   5.9285841E-04
     +,   5.8243109E-04,   5.7112990E-04,   5.5891508E-04
     +,   5.4577441E-04,   5.3172430E-04,   5.1680492E-04
     +,   5.0107937E-04,   4.8463154E-04,   4.6756191E-04
     +,   4.4998259E-04,   4.3201415E-04,   4.1378263E-04
     +,   3.9541538E-04,   3.7703529E-04,   3.5875922E-04
     +,   3.4069640E-04,   3.2294492E-04,   3.0558932E-04
     +,   2.8870074E-04,   2.7233825E-04,   2.5654561E-04
     +,   2.4135406E-04,   2.2678403E-04,   2.1284564E-04
     +,   1.9953903E-04,   1.8685737E-04,   1.7478896E-04
     +,   1.6331770E-04,   1.5242409E-04,   1.4208698E-04
     +,   1.3228517E-04,   1.2299744E-04,   1.1420270E-04
     +,   1.0588073E-04,   9.8013399E-05,   9.0582929E-05
     +,   8.3572864E-05,   7.6968245E-05,   7.0754992E-05
     +,   6.4919288E-05,   5.9447910E-05,   5.4328309E-05
     +,   4.9548027E-05,   4.5094312E-05,   4.0954350E-05
     +,   3.7115435E-05,   3.3564647E-05,   3.0288576E-05
     +,   2.7273691E-05,   2.4506602E-05,   2.1973527E-05
     +,   1.9660712E-05,   1.7554621E-05,   1.5641845E-05
     +,   1.3909069E-05,   1.2343325E-05,   1.0932117E-05
     +,   9.6633803E-06,   8.5254615E-06,   7.5072630E-06
     +,   6.5983377E-06,   5.7888246E-06,   5.0694198E-06
     +,   4.4314515E-06,   3.8669305E-06,   3.3684053E-06
     +,   2.9290293E-06,   2.5425556E-06,   2.2032755E-06
     +,   1.9059746E-06,   1.6459327E-06,   1.4189021E-06
     +,   1.2210551E-06,   1.0489427E-06,   8.9948065E-07
     +,   7.6992353E-07,   6.5782444E-07,   5.6100271E-07
     +,   4.7752513E-07,   4.0569006E-07,   3.4398676E-07
     +,   2.9108580E-07,   2.4582033E-07,   2.0716575E-07
     +,   1.7422219E-07,   1.4620247E-07,   1.2242154E-07
     +,   1.0228207E-07,   8.5263054E-08,   7.0912719E-08
     +,   5.8840875E-08,   4.8708682E-08,   4.0225089E-08
     +,   3.3138438E-08,   2.7233568E-08,   2.2325239E-08
     +,   1.8255816E-08,   1.4890283E-08,   1.2114256E-08
     +,   9.8302984E-09,   7.9562783E-09,   6.4226588E-09
     +,   5.1709454E-09,   4.1521586E-09,   3.3251699E-09
     +,   2.6557592E-09,   2.1153725E-09,   1.6803833E-09
     +,   1.3311958E-09,   1.0516936E-09,   8.2858909E-10
     +,   6.5101846E-10,   5.1008503E-10,   3.9855624E-10
     +,   3.1054465E-10,   2.4129601E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz65 = Yx/0.0688947368421053
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1236840E-05,   1.1729934E-05
     +,   1.2236987E-05,   1.2757791E-05,   1.3292092E-05
     +,   1.3839574E-05,   1.4399860E-05,   1.4972516E-05
     +,   1.5557032E-05,   1.6152871E-05,   1.6759388E-05
     +,   1.7375894E-05,   1.8001634E-05,   1.8635781E-05
     +,   1.9277442E-05,   1.9925670E-05,   2.0579442E-05
     +,   2.1237687E-05,   2.1899255E-05,   2.2562963E-05
     +,   2.3227554E-05,   2.3891738E-05,   2.4554154E-05
     +,   2.5213445E-05,   2.5868150E-05,   2.6516851E-05
     +,   2.7158050E-05,   2.7790256E-05,   2.8411963E-05
     +,   2.9021663E-05,   2.9617864E-05,   3.0199088E-05
     +,   3.0763895E-05,   3.1310898E-05,   3.1838783E-05
     +,   3.2346332E-05,   3.2832460E-05,   3.3296226E-05
     +,   3.3736953E-05,   3.4154149E-05,   3.4547727E-05
     +,   3.4917972E-05,   3.5265708E-05,   3.5592377E-05
     +,   3.5900208E-05,   3.6192348E-05,   3.6473073E-05
     +,   3.6747977E-05,   3.7024216E-05,   3.7310740E-05
     +,   3.7618560E-05,   3.7961006E-05,   3.8354003E-05
     +,   3.8816324E-05,   3.9369741E-05,   4.0039315E-05
     +,   4.0853400E-05,   4.1843788E-05,   4.3045606E-05
     +,   4.4497228E-05,   4.6240169E-05,   4.8318765E-05
     +,   5.0779792E-05,   5.3672506E-05,   5.7048244E-05
     +,   6.0959941E-05,   6.5463042E-05,   7.0614631E-05
     +,   7.6475379E-05,   8.3108913E-05,   9.0584945E-05
     +,   9.8979355E-05,   1.0837843E-04,   1.1887955E-04
     +,   1.3059669E-04,   1.4366346E-04,   1.5823582E-04
     +,   1.7449650E-04,   1.9265908E-04,   2.1296807E-04
     +,   2.3569514E-04,   2.6113848E-04,   2.8960631E-04
     +,   3.2140894E-04,   3.5683211E-04,   3.9612403E-04
     +,   4.3946799E-04,   4.8697778E-04,   5.3868053E-04
     +,   5.9453037E-04,   6.5441791E-04,   7.1819127E-04
     +,   7.8571390E-04,   8.5697428E-04,   9.3228987E-04
     +,   1.0126506E-03,   1.1002566E-03,   1.1991371E-03
     +,   1.3157915E-03,   1.4595253E-03,   1.6423629E-03
     +,   1.8782930E-03,   2.1821205E-03,   2.5679306E-03
     +,   3.0475149E-03,   3.6281487E-03,   4.3089380E-03
     +,   5.0754347E-03,   5.8937902E-03,   6.7079593E-03
     +,   7.4447794E-03,   8.0293659E-03,   8.4066270E-03
     +,   8.5602179E-03,   8.5189370E-03,   8.3469488E-03
     +,   8.1227198E-03,   7.9163266E-03,   7.7738124E-03
     +,   7.7116913E-03,   7.7202264E-03,   7.7718222E-03
     +,   7.8315306E-03,   7.8672832E-03,   7.8574419E-03
     +,   7.7931173E-03,   7.6751225E-03,   7.5094025E-03
     +,   7.3059513E-03,   7.0827864E-03,   6.8693431E-03
     +,   6.7023560E-03,   6.6120685E-03,   6.6059651E-03
     +,   6.6602235E-03,   6.7254263E-03,   6.7440583E-03
     +,   6.6715009E-03,   6.4907242E-03,   6.2151533E-03
     +,   5.8797286E-03,   5.5251895E-03,   5.1829680E-03
     +,   4.8670303E-03,   4.5749391E-03,   4.2956439E-03
     +,   4.0189945E-03,   3.7419561E-03,   3.4694709E-03
     +,   3.2109418E-03,   2.9752939E-03,   2.7672870E-03
     +,   2.5864313E-03,   2.4282308E-03,   2.2866265E-03
     +,   2.1562295E-03,   2.0335950E-03,   1.9174382E-03
     +,   1.8081239E-03,   1.7068953E-03,   1.6151400E-03
     +,   1.5339270E-03,   1.4637779E-03,   1.4045768E-03
     +,   1.3555981E-03,   1.3155821E-03,   1.2828475E-03
     +,   1.2554339E-03,   1.2312724E-03,   1.2083724E-03
     +,   1.1849977E-03,   1.1598045E-03,   1.1319238E-03
     +,   1.1009867E-03,   1.0670929E-03,   1.0307194E-03
     +,   9.9261408E-04,   9.5367519E-04,   9.1483170E-04
     +,   8.7694603E-04,   8.4074383E-04,   8.0677372E-04
     +,   7.7538606E-04,   7.4673671E-04,   7.2080840E-04
     +,   6.9744303E-04,   6.7637570E-04,   6.5726804E-04
     +,   6.3974579E-04,   6.2342756E-04,   6.0794561E-04
     +,   5.9296557E-04,   5.7819975E-04,   5.6341157E-04
     +,   5.4841785E-04,   5.3308799E-04,   5.1734172E-04
     +,   5.0114095E-04,   4.8448381E-04,   4.6739611E-04
     +,   4.4992741E-04,   4.3214209E-04,   4.1411290E-04
     +,   3.9591789E-04,   3.7763765E-04,   3.5934965E-04
     +,   3.4112809E-04,   3.2304405E-04,   3.0516382E-04
     +,   2.8754759E-04,   2.7025089E-04,   2.5332588E-04
     +,   2.3682063E-04,   2.2077799E-04,   2.0523740E-04
     +,   1.9023527E-04,   1.7580431E-04,   1.6197222E-04
     +,   1.4876253E-04,   1.3619559E-04,   1.2428591E-04
     +,   1.1304318E-04,   1.0247294E-04,   9.2575770E-05
     +,   8.3346735E-05,   7.4776392E-05,   6.6851469E-05
     +,   5.9554663E-05,   5.2864598E-05,   4.6756875E-05
     +,   4.1204898E-05,   3.6179950E-05,   3.1651412E-05
     +,   2.7587696E-05,   2.3957002E-05,   2.0727046E-05
     +,   1.7865847E-05,   1.5342277E-05,   1.3126102E-05
     +,   1.1188135E-05,   9.5006317E-06,   8.0375248E-06
     +,   6.7744004E-06,   5.6884969E-06,   4.7588546E-06
     +,   3.9663519E-06,   3.2936002E-06,   2.7248541E-06
     +,   2.2460044E-06,   1.8445236E-06,   1.5092710E-06
     +,   1.2304461E-06,   9.9949227E-07,   8.0895916E-07
     +,   6.5238970E-07,   5.2423184E-07,   4.1974320E-07
     +,   3.3488476E-07,   2.6623144E-07,   2.1089943E-07
     +,   1.6647509E-07,   1.3094386E-07,   1.0263152E-07
     +,   8.0155125E-08,   6.2379598E-08,   4.8373575E-08
     +,   3.7378413E-08,   2.8779219E-08,   2.2079112E-08
     +,   1.6877870E-08,   1.2855113E-08,   9.7555528E-09
     +,   7.3763369E-09,   5.5568532E-09,   4.1706332E-09
     +,   3.1185878E-09,   2.3231468E-09,   1.7240737E-09
     +,   1.2746032E-09,   9.3871011E-10,   6.8865880E-10
     +,   5.0325816E-10,   3.6632825E-10,   2.6560754E-10
     +,   1.9181430E-10,   1.3797143E-10,   9.8843850E-11
     +,   7.0525703E-11,   5.0116664E-11,   3.5467747E-11
     +,   2.4997820E-11,   1.7545635E-11,   1.2264079E-11
     +,   8.5365508E-12,   5.9171557E-12,   4.0842182E-12
     +,   2.8072013E-12,   1.9212748E-12,   1.3093641E-12
     +,   8.8852959E-13,   6.0038053E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz70 = Yx/0.090825
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.4962401E-06,   6.9949751E-06
     +,   7.5254170E-06,   8.0888194E-06,   8.6863920E-06
     +,   9.3192857E-06,   9.9885820E-06,   1.0695271E-05
     +,   1.1440230E-05,   1.2224250E-05,   1.3047948E-05
     +,   1.3911801E-05,   1.4816118E-05,   1.5761005E-05
     +,   1.6746379E-05,   1.7771923E-05,   1.8837090E-05
     +,   1.9941077E-05,   2.1082826E-05,   2.2260992E-05
     +,   2.3473958E-05,   2.4719811E-05,   2.5996329E-05
     +,   2.7301072E-05,   2.8631162E-05,   2.9983581E-05
     +,   3.1354950E-05,   3.2741627E-05,   3.4139735E-05
     +,   3.5545138E-05,   3.6953501E-05,   3.8360282E-05
     +,   3.9760795E-05,   4.1150201E-05,   4.2523574E-05
     +,   4.3875909E-05,   4.5202174E-05,   4.6497335E-05
     +,   4.7756483E-05,   4.8974660E-05,   5.0147170E-05
     +,   5.1269413E-05,   5.2337011E-05,   5.3345837E-05
     +,   5.4292035E-05,   5.5172080E-05,   5.5982779E-05
     +,   5.6721296E-05,   5.7385219E-05,   5.7972502E-05
     +,   5.8481575E-05,   5.8911282E-05,   5.9260903E-05
     +,   5.9530186E-05,   5.9719296E-05,   5.9828864E-05
     +,   5.9859954E-05,   5.9814040E-05,   5.9693044E-05
     +,   5.9499289E-05,   5.9235532E-05,   5.8904981E-05
     +,   5.8511290E-05,   5.8058667E-05,   5.7551861E-05
     +,   5.6996410E-05,   5.6398672E-05,   5.5766141E-05
     +,   5.5107703E-05,   5.4434047E-05,   5.3758115E-05
     +,   5.3095824E-05,   5.2466690E-05,   5.1894865E-05
     +,   5.1410152E-05,   5.1049294E-05,   5.0857427E-05
     +,   5.0889634E-05,   5.1212672E-05,   5.1906809E-05
     +,   5.3067473E-05,   5.4807155E-05,   5.7256526E-05
     +,   6.0565897E-05,   6.4905034E-05,   7.0463771E-05
     +,   7.7449549E-05,   8.6086744E-05,   9.6611475E-05
     +,   1.0926930E-04,   1.2430993E-04,   1.4198097E-04
     +,   1.6252376E-04,   1.8617118E-04,   2.1314439E-04
     +,   2.4364870E-04,   2.7788075E-04,   3.1602179E-04
     +,   3.5824784E-04,   4.0472057E-04,   4.5559480E-04
     +,   5.1100040E-04,   5.7104474E-04,   6.3578435E-04
     +,   7.0522772E-04,   7.7933533E-04,   8.5805950E-04
     +,   9.4146206E-04,   1.0299321E-03,   1.1244931E-03
     +,   1.2271850E-03,   1.3414883E-03,   1.4726496E-03
     +,   1.6279625E-03,   1.8168451E-03,   2.0508764E-03
     +,   2.3436346E-03,   2.7106372E-03,   3.1687955E-03
     +,   3.7344028E-03,   4.4174921E-03,   5.2133440E-03
     +,   6.0980325E-03,   7.0373449E-03,   8.0077341E-03
     +,   9.0107732E-03,   1.0064211E-02,   1.1176636E-02
     +,   1.2324220E-02,   1.3428067E-02,   1.4344483E-02
     +,   1.4925294E-02,   1.5159582E-02,   1.5249166E-02
     +,   1.5474740E-02,   1.5965894E-02,   1.6614335E-02
     +,   1.7171847E-02,   1.7403735E-02,   1.7201757E-02
     +,   1.6617831E-02,   1.5822235E-02,   1.5022522E-02
     +,   1.4356971E-02,   1.3803757E-02,   1.3199490E-02
     +,   1.2375167E-02,   1.1289937E-02,   1.0052987E-02
     +,   8.8390252E-03,   7.7831438E-03,   6.9288970E-03
     +,   6.2419204E-03,   5.6575006E-03,   5.1246770E-03
     +,   4.6255910E-03,   4.1687312E-03,   3.7698566E-03
     +,   3.4365705E-03,   3.1641442E-03,   2.9398836E-03
     +,   2.7498035E-03,   2.5829154E-03,   2.4322781E-03
     +,   2.2941858E-03,   2.1669671E-03,   2.0501572E-03
     +,   1.9440871E-03,   1.8496298E-03,   1.7679201E-03
     +,   1.6999752E-03,   1.6462692E-03,   1.6064041E-03
     +,   1.5789437E-03,   1.5614284E-03,   1.5505663E-03
     +,   1.5425580E-03,   1.5334943E-03,   1.5197599E-03
     +,   1.4983905E-03,   1.4673343E-03,   1.4255900E-03
     +,   1.3732268E-03,   1.3112654E-03,   1.2414904E-03
     +,   1.1662018E-03,   1.0879424E-03,   1.0092367E-03
     +,   9.3238091E-04,   8.5929775E-04,   7.9142785E-04
     +,   7.2971039E-04,   6.7460886E-04,   6.2616513E-04
     +,   5.8408128E-04,   5.4781424E-04,   5.1666627E-04
     +,   4.8985914E-04,   4.6659730E-04,   4.4611623E-04
     +,   4.2771682E-04,   4.1078305E-04,   3.9479160E-04
     +,   3.7931569E-04,   3.6402437E-04,   3.4867396E-04
     +,   3.3310198E-04,   3.1721938E-04,   3.0099973E-04
     +,   2.8446797E-04,   2.6769101E-04,   2.5076867E-04
     +,   2.3382256E-04,   2.1698598E-04,   2.0039637E-04
     +,   1.8418931E-04,   1.6849130E-04,   1.5341399E-04
     +,   1.3905215E-04,   1.2548269E-04,   1.1276096E-04
     +,   1.0092265E-04,   8.9985115E-05,   7.9948317E-05
     +,   7.0796399E-05,   6.2500738E-05,   5.5023036E-05
     +,   4.8317168E-05,   4.2331143E-05,   3.7009861E-05
     +,   3.2297296E-05,   2.8137601E-05,   2.4476210E-05
     +,   2.1261156E-05,   1.8443981E-05,   1.5979575E-05
     +,   1.3826748E-05,   1.1948400E-05,   1.0311242E-05
     +,   8.8855377E-06,   7.6449978E-06,   6.5665545E-06
     +,   5.6299336E-06,   4.8173165E-06,   4.1131225E-06
     +,   3.5037642E-06,   2.9773380E-06,   2.5233780E-06
     +,   2.1327064E-06,   1.7972962E-06,   1.5100447E-06
     +,   1.2647013E-06,   1.0557725E-06,   8.7841124E-07
     +,   7.2833416E-07,   6.0177427E-07,   4.9542780E-07
     +,   4.0639546E-07,   3.3213516E-07,   2.7043143E-07
     +,   2.1936278E-07,   1.7726477E-07,   1.4269926E-07
     +,   1.1443235E-07,   9.1411906E-08,   7.2740228E-08
     +,   5.7657608E-08,   4.5524814E-08,   3.5805520E-08
     +,   2.8051556E-08,   2.1890916E-08,   1.7016616E-08
     +,   1.3176129E-08,   1.0162570E-08,   7.8075830E-09
     +,   5.9749374E-09,   4.5545692E-09,   3.4583161E-09
     +,   2.6156406E-09,   1.9705815E-09,   1.4787882E-09
     +,   1.1053997E-09,   8.2305046E-10,   6.1042699E-10
     +,   4.5095400E-10,   3.3184053E-10,   2.4323119E-10
     +,   1.7758078E-10,   1.2914189E-10,   9.3545137E-11
     +,   6.7494101E-11,   4.8505356E-11,   3.4721614E-11
     +,   2.4756244E-11,   1.7581343E-11,   1.2436227E-11
     +,   8.7620007E-12,   6.1486909E-12,   4.2976816E-12
     +,   2.9918923E-12,   2.0745567E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz75 = Yx/0.122926829268293
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9426743E-08,   2.2489552E-08
     +,   2.5991666E-08,   2.9988914E-08,   3.4543177E-08
     +,   3.9722853E-08,   4.5603365E-08,   5.2267758E-08
     +,   5.9807007E-08,   6.8321413E-08,   7.7920042E-08
     +,   8.8722231E-08,   1.0085797E-07,   1.1446855E-07
     +,   1.2970730E-07,   1.4674042E-07,   1.6574752E-07
     +,   1.8692261E-07,   2.1047492E-07,   2.3662943E-07
     +,   2.6562836E-07,   2.9773150E-07,   3.3321751E-07
     +,   3.7238698E-07,   4.1555759E-07,   4.6307420E-07
     +,   5.1530282E-07,   5.7263600E-07,   6.3549328E-07
     +,   7.0432310E-07,   7.7960584E-07,   8.6185452E-07
     +,   9.5161852E-07,   1.0494850E-06,   1.1560826E-06
     +,   1.2720841E-06,   1.3982093E-06,   1.5352255E-06
     +,   1.6839634E-06,   1.8452935E-06,   2.0201619E-06
     +,   2.2095694E-06,   2.4145811E-06,   2.6363321E-06
     +,   2.8760230E-06,   3.1349259E-06,   3.4143779E-06
     +,   3.7157868E-06,   4.0406208E-06,   4.3904097E-06
     +,   4.7667354E-06,   5.1712263E-06,   5.6055360E-06
     +,   6.0713714E-06,   6.5703944E-06,   7.1043128E-06
     +,   7.6747701E-06,   8.2833767E-06,   8.9316572E-06
     +,   9.6210497E-06,   1.0352859E-05,   1.1128255E-05
     +,   1.1948176E-05,   1.2813405E-05,   1.3724505E-05
     +,   1.4681681E-05,   1.5684971E-05,   1.6733971E-05
     +,   1.7828090E-05,   1.8966244E-05,   2.0147141E-05
     +,   2.1368985E-05,   2.2629763E-05,   2.3926967E-05
     +,   2.5257874E-05,   2.6619462E-05,   2.8008366E-05
     +,   2.9421019E-05,   3.0853837E-05,   3.2303229E-05
     +,   3.3765617E-05,   3.5237968E-05,   3.6717691E-05
     +,   3.8203347E-05,   3.9694736E-05,   4.1193889E-05
     +,   4.2705375E-05,   4.4237677E-05,   4.5803827E-05
     +,   4.7423138E-05,   4.9122627E-05,   5.0938565E-05
     +,   5.2918524E-05,   5.5123543E-05,   5.7630048E-05
     +,   6.0531594E-05,   6.3941319E-05,   6.7992827E-05
     +,   7.2842311E-05,   7.8668352E-05,   8.5673746E-05
     +,   9.4083720E-05,   1.0414702E-04,   1.1613173E-04
     +,   1.3032398E-04,   1.4702158E-04,   1.6652320E-04
     +,   1.8911615E-04,   2.1506022E-04,   2.4456569E-04
     +,   2.7776841E-04,   3.1472015E-04,   3.5537570E-04
     +,   3.9961867E-04,   4.4729552E-04,   4.9829681E-04
     +,   5.5263413E-04,   6.1053789E-04,   6.7250029E-04
     +,   7.3929742E-04,   8.1195973E-04,   8.9175696E-04
     +,   9.8029559E-04,   1.0798019E-03,   1.1935811E-03
     +,   1.3265244E-03,   1.4854633E-03,   1.6790141E-03
     +,   1.9169402E-03,   2.2089535E-03,   2.5634370E-03
     +,   2.9864055E-03,   3.4822735E-03,   4.0579359E-03
     +,   4.7314577E-03,   5.5410988E-03,   6.5422743E-03
     +,   7.7758464E-03,   9.2097325E-03,   1.0702869E-02
     +,   1.2071587E-02,   1.3288110E-02,   1.4687767E-02
     +,   1.6857352E-02,   1.9986521E-02,   2.3255238E-02
     +,   2.5256924E-02,   2.5330724E-02,   2.4212731E-02
     +,   2.2988738E-02,   2.2079729E-02,   2.1752631E-02
     +,   2.2164730E-02,   2.2565329E-02,   2.2131326E-02
     +,   2.0991703E-02,   1.9419000E-02,   1.7374570E-02
     +,   1.5107750E-02,   1.3181230E-02,   1.1865048E-02
     +,   1.0943373E-02,   1.0069916E-02,   9.0792365E-03
     +,   7.9945065E-03,   6.9114715E-03,   5.9250263E-03
     +,   5.1024104E-03,   4.4679907E-03,   4.0002395E-03
     +,   3.6494199E-03,   3.3653020E-03,   3.1159273E-03
     +,   2.8896106E-03,   2.6863180E-03,   2.5081970E-03
     +,   2.3545984E-03,   2.2213247E-03,   2.1019322E-03
     +,   1.9895080E-03,   1.8782289E-03,   1.7644805E-03
     +,   1.6473749E-03,   1.5285872E-03,   1.4116331E-03
     +,   1.3008215E-03,   1.2001853E-03,   1.1126802E-03
     +,   1.0397821E-03,   9.8145241E-04,   9.3636196E-04
     +,   9.0227876E-04,   8.7648060E-04,   8.5612340E-04
     +,   8.3852321E-04,   8.2135142E-04,   8.0274319E-04
     +,   7.8134023E-04,   7.5627852E-04,   7.2715251E-04
     +,   6.9395849E-04,   6.5702334E-04,   6.1692565E-04
     +,   5.7442370E-04,   5.3038384E-04,   4.8570507E-04
     +,   4.4126177E-04,   3.9785638E-04,   3.5617803E-04
     +,   3.1677666E-04,   2.8005420E-04,   2.4626852E-04
     +,   2.1554127E-04,   1.8787487E-04,   1.6317799E-04
     +,   1.4129089E-04,   1.2200722E-04,   1.0509366E-04
     +,   9.0309157E-05,   7.7418816E-05,   6.6200162E-05
     +,   5.6450077E-05,   4.7987629E-05,   4.0653442E-05
     +,   3.4307963E-05,   2.8829965E-05,   2.4114341E-05
     +,   2.0069103E-05,   1.6613034E-05,   1.3674116E-05
     +,   1.1188235E-05,   9.0977564E-06,   7.3506458E-06
     +,   5.9000654E-06,   4.7040548E-06,   3.7249335E-06
     +,   2.9292146E-06,   2.2873965E-06,   1.7736538E-06
     +,   1.3655635E-06,   1.0438873E-06,   7.9229943E-07
     +,   5.9706031E-07,   4.4671867E-07,   3.3184295E-07
     +,   2.4474838E-07,   1.7922670E-07,   1.3031091E-07
     +,   9.4070614E-08,   6.7427258E-08,   4.7987207E-08
     +,   3.3909654E-08,   2.3792404E-08,   1.6575974E-08
     +,   1.1466847E-08,   7.8764444E-09,   5.3721183E-09
     +,   3.6382855E-09,   2.4466975E-09,   1.6337639E-09
     +,   1.0832539E-09,   7.1319411E-10,   4.6624465E-10
     +,   3.0265021E-10,   1.9507335E-10,   1.2484622E-10
     +,   7.9334601E-11,   5.0056615E-11,   3.1359814E-11
     +,   1.9506822E-11,   1.2047252E-11,   7.3871638E-12
     +,   4.4973465E-12,   2.7183785E-12,   1.6312628E-12
     +,   9.7186441E-13,   5.7482030E-13,   3.3752870E-13
     +,   1.9675166E-13,   1.1385775E-13,   6.5406366E-14
     +,   3.7299218E-14,   2.1114216E-14,   1.1864728E-14
     +,   6.6179222E-15,   3.6641803E-15,   2.0137677E-15
     +,   1.0985020E-15,   5.9479024E-16,   3.1964980E-16
     +,   1.7050773E-16,   9.0270968E-17,   4.7435344E-17
     +,   2.4738861E-17,   1.2805533E-17,   6.5786034E-18
     +,   3.3543204E-18,   1.6974212E-18,   8.5253034E-19
     +,   4.2496089E-19,   2.1024970E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz80 = Yx/0.14146511627907
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.0756846E-06,   7.4000523E-06
     +,   7.7245559E-06,   8.0479513E-06,   8.3689520E-06
     +,   8.6862374E-06,   8.9984596E-06,   9.3042581E-06
     +,   9.6022623E-06,   9.8911214E-06,   1.0169490E-05
     +,   1.0436057E-05,   1.0689556E-05,   1.0928772E-05
     +,   1.1152555E-05,   1.1359833E-05,   1.1549626E-05
     +,   1.1721047E-05,   1.1873322E-05,   1.2005791E-05
     +,   1.2117926E-05,   1.2209325E-05,   1.2279727E-05
     +,   1.2329021E-05,   1.2357228E-05,   1.2364536E-05
     +,   1.2351270E-05,   1.2317907E-05,   1.2265070E-05
     +,   1.2193530E-05,   1.2104194E-05,   1.1998097E-05
     +,   1.1876405E-05,   1.1740395E-05,   1.1591454E-05
     +,   1.1431061E-05,   1.1260780E-05,   1.1082250E-05
     +,   1.0897156E-05,   1.0707246E-05,   1.0514278E-05
     +,   1.0320042E-05,   1.0126319E-05,   9.9348827E-06
     +,   9.7474804E-06,   9.5658197E-06,   9.3915478E-06
     +,   9.2262590E-06,   9.0714630E-06,   8.9285841E-06
     +,   8.7989501E-06,   8.6837908E-06,   8.5842257E-06
     +,   8.5012589E-06,   8.4357907E-06,   8.3886007E-06
     +,   8.3603663E-06,   8.3516597E-06,   8.3629648E-06
     +,   8.3946834E-06,   8.4471603E-06,   8.5206984E-06
     +,   8.6155787E-06,   8.7321050E-06,   8.8706265E-06
     +,   9.0315652E-06,   9.2154887E-06,   9.4231154E-06
     +,   9.6554068E-06,   9.9135723E-06,   1.0199177E-05
     +,   1.0514138E-05,   1.0860842E-05,   1.1242119E-05
     +,   1.1661380E-05,   1.2122608E-05,   1.2630371E-05
     +,   1.3189865E-05,   1.3806960E-05,   1.4488159E-05
     +,   1.5240505E-05,   1.6071672E-05,   1.6989705E-05
     +,   1.8003124E-05,   1.9120556E-05,   2.0350839E-05
     +,   2.1702541E-05,   2.3184070E-05,   2.4803074E-05
     +,   2.6566533E-05,   2.8480366E-05,   3.0549039E-05
     +,   3.2775384E-05,   3.5160538E-05,   3.7703634E-05
     +,   4.0401323E-05,   4.3248310E-05,   4.6236619E-05
     +,   4.9356360E-05,   5.2595107E-05,   5.5939046E-05
     +,   5.9372444E-05,   6.2879051E-05,   6.6441891E-05
     +,   7.0044764E-05,   7.3672862E-05,   7.7313452E-05
     +,   8.0957267E-05,   8.4599837E-05,   8.8242406E-05
     +,   9.1892725E-05,   9.5566960E-05,   9.9289588E-05
     +,   1.0309512E-04,   1.0702763E-04,   1.1114199E-04
     +,   1.1550284E-04,   1.2018560E-04,   1.2527512E-04
     +,   1.3086693E-04,   1.3706737E-04,   1.4399522E-04
     +,   1.5178531E-04,   1.6059620E-04,   1.7062158E-04
     +,   1.8210866E-04,   1.9539252E-04,   2.1094149E-04
     +,   2.2943193E-04,   2.5183958E-04,   2.7956083E-04
     +,   3.1452684E-04,   3.5930250E-04,   4.1709546E-04
     +,   4.9166777E-04,   5.8710645E-04,   7.0750999E-04
     +,   8.5673004E-04,   1.0383151E-03,   1.2556690E-03
     +,   1.5122026E-03,   1.8111389E-03,   2.1549934E-03
     +,   2.5457314E-03,   2.9872530E-03,   3.4904194E-03
     +,   4.0765302E-03,   4.7731241E-03,   5.6009647E-03
     +,   6.5636849E-03,   7.6578343E-03,   8.9005427E-03
     +,   1.0342300E-02,   1.2063834E-02,   1.4202533E-02
     +,   1.6914479E-02,   2.0165244E-02,   2.3765381E-02
     +,   2.7737295E-02,   3.1698197E-02,   3.4060370E-02
     +,   3.4136649E-02,   3.3558965E-02,   3.3605665E-02
     +,   3.3351466E-02,   3.2102045E-02,   3.0226272E-02
     +,   2.7442973E-02,   2.4069456E-02,   2.0908548E-02
     +,   1.7960837E-02,   1.5298111E-02,   1.3286054E-02
     +,   1.1835949E-02,   1.0526300E-02,   9.1796974E-03
     +,   7.9076551E-03,   6.8447804E-03,   6.0209869E-03
     +,   5.3848689E-03,   4.8610079E-03,   4.3912898E-03
     +,   3.9504454E-03,   3.5403122E-03,   3.1750321E-03
     +,   2.8683357E-03,   2.6271152E-03,   2.4501004E-03
     +,   2.3289155E-03,   2.2498725E-03,   2.1961355E-03
     +,   2.1502336E-03,   2.0966667E-03,   2.0240892E-03
     +,   1.9266016E-03,   1.8039020E-03,   1.6603895E-03
     +,   1.5035411E-03,   1.3420219E-03,   1.1840047E-03
     +,   1.0359739E-03,   9.0212369E-04,   7.8433508E-04
     +,   6.8258174E-04,   5.9554295E-04,   5.2120478E-04
     +,   4.5738270E-04,   4.0206924E-04,   3.5360458E-04
     +,   3.1072181E-04,   2.7251258E-04,   2.3835276E-04
     +,   2.0781322E-04,   1.8058279E-04,   1.5641304E-04
     +,   1.3508117E-04,   1.1636660E-04,   1.0004116E-04
     +,   8.5870903E-05,   7.3621741E-05,   6.3063686E-05
     +,   5.3979013E-05,   4.6168097E-05,   3.9451930E-05
     +,   3.3673296E-05,   2.8697012E-05,   2.4408650E-05
     +,   2.0711779E-05,   1.7525210E-05,   1.4780674E-05
     +,   1.2420566E-05,   1.0395665E-05,   8.6633609E-06
     +,   7.1865397E-06,   5.9326912E-06,   4.8728989E-06
     +,   3.9814686E-06,   3.2355763E-06,   2.6148903E-06
     +,   2.1013141E-06,   1.6788517E-06,   1.3334511E-06
     +,   1.0528098E-06,   8.2621415E-07,   6.4442253E-07
     +,   4.9952826E-07,   3.8480414E-07,   2.9456737E-07
     +,   2.2406391E-07,   1.6935299E-07,   1.2718311E-07
     +,   9.4899782E-08,   7.0354886E-08,   5.1821775E-08
     +,   3.7923495E-08,   2.7572256E-08,   1.9916094E-08
     +,   1.4292408E-08,   1.0189883E-08,   7.2175297E-09
     +,   5.0788787E-09,   3.5506804E-09,   2.4661200E-09
     +,   1.7016532E-09,   1.1665212E-09,   7.9446349E-10
     +,   5.3753979E-10,   3.6133280E-10,   2.4130789E-10
     +,   1.6010175E-10,   1.0553014E-10,   6.9106269E-11
     +,   4.4959866E-11,   2.9059744E-11,   1.8660015E-11
     +,   1.1904071E-11,   7.5444729E-12,   4.7503221E-12
     +,   2.9714141E-12,   1.8465474E-12,   1.1399839E-12
     +,   6.9917981E-13,   4.2600580E-13,   2.5786315E-13
     +,   1.5505724E-13,   9.2626624E-14,   5.4968071E-14
     +,   3.2404391E-14,   1.8977065E-14,   1.1039983E-14
     +,   6.3801435E-15,   3.6626810E-15,   2.0887475E-15
     +,   1.1832369E-15,   6.6583719E-16,   3.7218384E-16
     +,   2.0665736E-16,   1.1398039E-16,   6.2446472E-17
     +,   3.3983276E-17,   1.8370216E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz85 = Yx/0.160186046511628
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5208828E-17,   7.0850216E-17
     +,   1.1061544E-16,   1.7204860E-16,   2.6659129E-16
     +,   4.1153157E-16,   6.3288677E-16,   9.6965452E-16
     +,   1.4800508E-15,   2.2506720E-15,   3.4097743E-15
     +,   5.1466040E-15,   7.7393002E-15,   1.1595044E-14
     +,   1.7307670E-14,   2.5739786E-14,   3.8139779E-14
     +,   5.6307196E-14,   8.2826758E-14,   1.2139596E-13
     +,   1.7728526E-13,   2.5797992E-13,   3.7406674E-13
     +,   5.4048053E-13,   7.7817646E-13,   1.1165092E-12
     +,   1.5963963E-12,   2.2747106E-12,   3.2302078E-12
     +,   4.5715688E-12,   6.4482855E-12,   9.0652832E-12
     +,   1.2702478E-11,   1.7741092E-11,   2.4698521E-11
     +,   3.4274628E-11,   4.7413205E-11,   6.5382484E-11
     +,   8.9883219E-11,   1.2318360E-10,   1.6830709E-10
     +,   2.2926304E-10,   3.1135630E-10,   4.2157985E-10
     +,   5.6912314E-10,   7.6602374E-10,   1.0279906E-09
     +,   1.3754623E-09,   1.8349283E-09,   2.4406039E-09
     +,   3.2365173E-09,   4.2791095E-09,   5.6404321E-09
     +,   7.4122379E-09,   9.7105239E-09,   1.2681872E-08
     +,   1.6510176E-08,   2.1425398E-08,   2.7713710E-08
     +,   3.5729535E-08,   4.5909598E-08,   5.8789730E-08
     +,   7.5022420E-08,   9.5400480E-08,   1.2088070E-07
     +,   1.5260832E-07,   1.9195259E-07,   2.4053179E-07
     +,   3.0025751E-07,   3.7335923E-07,   4.6243727E-07
     +,   5.7048186E-07,   7.0093330E-07,   8.5768897E-07
     +,   1.0451608E-06,   1.2682945E-06,   1.5325674E-06
     +,   1.8440082E-06,   2.2092140E-06,   2.6353257E-06
     +,   3.1299448E-06,   3.7011919E-06,   4.3575128E-06
     +,   5.1077518E-06,   5.9608833E-06,   6.9261137E-06
     +,   8.0125401E-06,   9.2292967E-06,   1.0585168E-05
     +,   1.2088760E-05,   1.3748346E-05,   1.5571701E-05
     +,   1.7566203E-05,   1.9739036E-05,   2.2097209E-05
     +,   2.4647477E-05,   2.7397127E-05,   3.0353607E-05
     +,   3.3525554E-05,   3.6922349E-05,   4.0555278E-05
     +,   4.4436867E-05,   4.8582013E-05,   5.3006956E-05
     +,   5.7730042E-05,   6.2770872E-05,   6.8149347E-05
     +,   7.3884876E-05,   7.9995545E-05,   8.6496300E-05
     +,   9.3396447E-05,   1.0069946E-04,   1.0839928E-04
     +,   1.1648049E-04,   1.2491505E-04,   1.3366352E-04
     +,   1.4267258E-04,   1.5187805E-04,   1.6120409E-04
     +,   1.7056803E-04,   1.7988324E-04,   1.8906343E-04
     +,   1.9802901E-04,   2.0671480E-04,   2.1507656E-04
     +,   2.2309831E-04,   2.3080205E-04,   2.3825369E-04
     +,   2.4557218E-04,   2.5293342E-04,   2.6057681E-04
     +,   2.6880449E-04,   2.7798154E-04,   2.8852615E-04
     +,   3.0089740E-04,   3.1557260E-04,   3.3301476E-04
     +,   3.5363369E-04,   3.7774400E-04,   4.0552090E-04
     +,   4.3696619E-04,   4.7189958E-04,   5.0998514E-04
     +,   5.5079721E-04,   5.9392810E-04,   6.3915312E-04
     +,   6.8661623E-04,   7.3705253E-04,   7.9207082E-04
     +,   8.5453189E-04,   9.2905812E-04,   1.0226385E-03
     +,   1.1451251E-03,   1.3091603E-03,   1.5287697E-03
     +,   1.8157637E-03,   2.1737893E-03,   2.5929618E-03
     +,   3.0541287E-03,   3.5536867E-03,   4.1417489E-03
     +,   4.9366211E-03,   6.0965377E-03,   7.7831130E-03
     +,   1.0107456E-02,   1.3041720E-02,   1.6403856E-02
     +,   1.9911952E-02,   2.3452586E-02,   2.7703155E-02
     +,   3.3369828E-02,   3.8787980E-02,   4.1640002E-02
     +,   4.1332316E-02,   3.9434645E-02,   3.7596576E-02
     +,   3.7202179E-02,   3.7236743E-02,   3.4811825E-02
     +,   2.9499799E-02,   2.3677474E-02,   1.8670620E-02
     +,   1.4805739E-02,   1.2221945E-02,   1.0541921E-02
     +,   9.2430329E-03,   8.0919722E-03,   7.0327958E-03
     +,   6.0661086E-03,   5.2493508E-03,   4.6453876E-03
     +,   4.2548315E-03,   4.0128990E-03,   3.8320236E-03
     +,   3.6412051E-03,   3.4023463E-03,   3.1084248E-03
     +,   2.7736477E-03,   2.4224680E-03,   2.0805371E-03
     +,   1.7685414E-03,   1.4990850E-03,   1.2764153E-03
     +,   1.0981561E-03,   9.5786870E-04,   8.4741495E-04
     +,   7.5870747E-04,   6.8471272E-04,   6.1988825E-04
     +,   5.6027604E-04,   5.0340116E-04,   4.4804855E-04
     +,   3.9396825E-04,   3.4155886E-04,   2.9157402E-04
     +,   2.4487334E-04,   2.0222926E-04,   1.6420370E-04
     +,   1.3109494E-04,   1.0293650E-04,   7.9524529E-05
     +,   6.0477294E-05,   4.5299425E-05,   3.3440236E-05
     +,   2.4343602E-05,   1.7486067E-05,   1.2400305E-05
     +,   8.6859372E-06,   6.0118273E-06,   4.1126136E-06
     +,   2.7811877E-06,   1.8594163E-06,   1.2289539E-06
     +,   8.0287407E-07,   5.1836980E-07,   3.3067337E-07
     +,   2.0835154E-07,   1.2963045E-07,   7.9616477E-08
     +,   4.8255274E-08,   2.8853442E-08,   1.7015598E-08
     +,   9.8943840E-09,   5.6716694E-09,   3.2041283E-09
     +,   1.7836359E-09,   9.7820430E-10,   5.2844451E-10
     +,   2.8115157E-10,   1.4730304E-10,   7.5988632E-11
     +,   3.8591536E-11,   1.9293287E-11,   9.4942127E-12
     +,   4.5983516E-12,   2.1917526E-12,   1.0280262E-12
     +,   4.7448623E-13,   2.1548253E-13,   9.6279891E-14
     +,   4.2323475E-14,   1.8303943E-14,   7.7874447E-15
     +,   3.2591547E-15,   1.3417887E-15,   5.4338815E-16
     +,   2.1644971E-16,   8.4806355E-17,   3.2683534E-17
     +,   1.2389079E-17,   4.6188835E-18,   1.6936832E-18
     +,   6.1084771E-19,   2.1668112E-19,   7.5592521E-20
     +,   2.5937794E-20,   8.7528512E-21,   2.9050793E-21
     +,   9.4825554E-22,   3.0442751E-22,   9.6116643E-23
     +,   2.9847341E-23,   9.1153572E-24,   2.7380727E-24
     +,   8.0891138E-25,   2.3507269E-25,   6.7203449E-26
     +,   1.8904190E-26,   5.2354911E-27,   1.4288439E-27
     +,   3.8507303E-28,   1.0287747E-28,   2.7463123E-29
     +,   7.4334892E-30,   2.0928590E-30,   6.3562055E-31
     +,   2.1598712E-31,   8.3285985E-32,   3.5775606E-32
     +,   1.6514257E-32,   7.9313925E-33
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz90 = Yx/0.163441860465116
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3375909E-06,   3.6645738E-06
     +,   4.0170016E-06,   4.3960868E-06,   4.8030106E-06
     +,   5.2389105E-06,   5.7048660E-06,   6.2018803E-06
     +,   6.7308665E-06,   7.2926496E-06,   7.8879129E-06
     +,   8.5172060E-06,   9.1809197E-06,   9.8792689E-06
     +,   1.0612282E-05,   1.1379763E-05,   1.2181303E-05
     +,   1.3016240E-05,   1.3883662E-05,   1.4782383E-05
     +,   1.5710943E-05,   1.6667585E-05,   1.7650254E-05
     +,   1.8656654E-05,   1.9684088E-05,   2.0729674E-05
     +,   2.1790189E-05,   2.2862148E-05,   2.3941817E-05
     +,   2.5025223E-05,   2.6108180E-05,   2.7186315E-05
     +,   2.8255114E-05,   2.9309931E-05,   3.0346051E-05
     +,   3.1358719E-05,   3.2343185E-05,   3.3294742E-05
     +,   3.4208842E-05,   3.5080982E-05,   3.5906956E-05
     +,   3.6682763E-05,   3.7404687E-05,   3.8069382E-05
     +,   3.8673847E-05,   3.9215538E-05,   3.9692353E-05
     +,   4.0102674E-05,   4.0445397E-05,   4.0719973E-05
     +,   4.0926367E-05,   4.1065137E-05,   4.1137362E-05
     +,   4.1144700E-05,   4.1089319E-05,   4.0973933E-05
     +,   4.0801715E-05,   4.0576339E-05,   4.0301868E-05
     +,   3.9982755E-05,   3.9623777E-05,   3.9230010E-05
     +,   3.8806756E-05,   3.8359449E-05,   3.7893649E-05
     +,   3.7415004E-05,   3.6929094E-05,   3.6441488E-05
     +,   3.5957579E-05,   3.5482633E-05,   3.5021654E-05
     +,   3.4579407E-05,   3.4160304E-05,   3.3768476E-05
     +,   3.3407607E-05,   3.3081018E-05,   3.2791617E-05
     +,   3.2541899E-05,   3.2333897E-05,   3.2169235E-05
     +,   3.2049142E-05,   3.1974425E-05,   3.1945539E-05
     +,   3.1962583E-05,   3.2025346E-05,   3.2133365E-05
     +,   3.2285923E-05,   3.2482152E-05,   3.2721018E-05
     +,   3.3001452E-05,   3.3322336E-05,   3.3682569E-05
     +,   3.4081120E-05,   3.4517110E-05,   3.4989822E-05
     +,   3.5498706E-05,   3.6043522E-05,   3.6624217E-05
     +,   3.7241105E-05,   3.7894719E-05,   3.8585982E-05
     +,   3.9316004E-05,   4.0086277E-05,   4.0898449E-05
     +,   4.1754462E-05,   4.2656466E-05,   4.3606702E-05
     +,   4.4607550E-05,   4.5661585E-05,   4.6771496E-05
     +,   4.7940019E-05,   4.9170234E-05,   5.0465336E-05
     +,   5.1829156E-05,   5.3265925E-05,   5.4780907E-05
     +,   5.6380351E-05,   5.8072124E-05,   5.9865826E-05
     +,   6.1773462E-05,   6.3809857E-05,   6.5993045E-05
     +,   6.8344816E-05,   7.0891656E-05,   7.3665418E-05
     +,   7.6704237E-05,   8.0054742E-05,   8.3773994E-05
     +,   8.7933942E-05,   9.2626222E-05,   9.7970551E-05
     +,   1.0412343E-04,   1.1129177E-04,   1.1974430E-04
     +,   1.2982610E-04,   1.4196773E-04,   1.5668676E-04
     +,   1.7457861E-04,   1.9629180E-04,   2.2248100E-04
     +,   2.5373639E-04,   2.9049654E-04,   3.3295073E-04
     +,   3.8093701E-04,   4.3385159E-04,   4.9060991E-04
     +,   5.4964528E-04,   6.0897192E-04,   6.6632836E-04
     +,   7.1938091E-04,   7.6596631E-04,   8.0435869E-04
     +,   8.3353394E-04,   8.5339573E-04,   8.6493714E-04
     +,   8.7032752E-04,   8.7290589E-04,   8.7705988E-04
     +,   8.8797807E-04,   9.1125362E-04,   9.5235067E-04
     +,   1.0159756E-03,   1.1054613E-03,   1.2223808E-03
     +,   1.3666368E-03,   1.5371689E-03,   1.7332115E-03
     +,   1.9558147E-03,   2.2093807E-03,   2.5035783E-03
     +,   2.8559747E-03,   3.2937096E-03,   3.8509725E-03
     +,   4.5675435E-03,   5.5066771E-03,   6.7912536E-03
     +,   8.6212652E-03,   1.1254454E-02,   1.4860936E-02
     +,   1.9200314E-02,   2.3552937E-02,   2.7319340E-02
     +,   3.1378988E-02,   3.7172809E-02,   4.3454211E-02
     +,   4.8238330E-02,   4.9730748E-02,   4.7919393E-02
     +,   4.4099443E-02,   3.7485171E-02,   2.9526697E-02
     +,   2.2432437E-02,   1.7418643E-02,   1.4364987E-02
     +,   1.2417488E-02,   1.0942839E-02,   9.6665584E-03
     +,   8.4739877E-03,   7.2876378E-03,   6.1000073E-03
     +,   4.9851788E-03,   4.0272167E-03,   3.2602912E-03
     +,   2.6694804E-03,   2.2191794E-03,   1.8728905E-03
     +,   1.5998529E-03,   1.3763051E-03,   1.1855526E-03
     +,   1.0171478E-03,   8.6539832E-04,   7.2776899E-04
     +,   6.0354359E-04,   4.9282733E-04,   3.9587406E-04
     +,   3.1268469E-04,   2.4282513E-04,   1.8542065E-04
     +,   1.3925480E-04,   1.0290458E-04,   7.4862939E-05
     +,   5.3654152E-05,   3.7914979E-05,   2.6442804E-05
     +,   1.8219369E-05,   1.2414589E-05,   8.3739151E-06
     +,   5.5960086E-06,   3.7070160E-06,   2.4348901E-06
     +,   1.5857185E-06,   1.0235535E-06,   6.5440537E-07
     +,   4.1405386E-07,   2.5901551E-07,   1.6002797E-07
     +,   9.7547193E-08,   5.8609920E-08,   3.4681385E-08
     +,   2.0195710E-08,   1.1565923E-08,   6.5110748E-09
     +,   3.6018573E-09,   1.9574629E-09,   1.0449838E-09
     +,   5.4806532E-10,   2.8251057E-10,   1.4323435E-10
     +,   7.1528547E-11,   3.5272008E-11,   1.7247483E-11
     +,   8.4213131E-12,   4.1510519E-12,   2.0986808E-12
     +,   1.1099827E-12,   6.2595339E-13,   3.8046077E-13
     +,   2.4856603E-13,   1.7213386E-13,   1.2411803E-13
     +,   9.1745723E-14,   6.8756172E-14,   5.1878528E-14
     +,   3.9251256E-14,   2.9713255E-14,   2.2477915E-14
     +,   1.6982399E-14,   1.2809950E-14,   9.6457690E-15
     +,   7.2498846E-15,   5.4388837E-15,   4.0725827E-15
     +,   3.0437610E-15,   2.2705197E-15,   1.6904822E-15
     +,   1.2562394E-15,   9.3175932E-16,   6.8978017E-16
     +,   5.0966682E-16,   3.7586949E-16,   2.7666502E-16
     +,   2.0325797E-16,   1.4904168E-16,   1.0907941E-16
     +,   7.9678934E-17,   5.8092319E-17,   4.2273184E-17
     +,   3.0702684E-17,   2.2256754E-17,   1.6103223E-17
     +,   1.1628876E-17,   8.3815871E-18,   6.0296214E-18
     +,   4.3293045E-18,   3.1025615E-18,   2.2191510E-18
     +,   1.5842597E-18,   1.1288333E-18,   8.0279957E-19
     +,   5.6983480E-19,   4.0370374E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_ttz95 = Yx/0.157093023255814
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.5280069E-05,   9.8999750E-05
     +,   1.0288432E-04,   1.0694202E-04,   1.1118131E-04
     +,   1.1561075E-04,   1.2023919E-04,   1.2507549E-04
     +,   1.3012861E-04,   1.3540764E-04,   1.4092147E-04
     +,   1.4667890E-04,   1.5268839E-04,   1.5895822E-04
     +,   1.6549611E-04,   1.7230940E-04,   1.7940468E-04
     +,   1.8678779E-04,   1.9446354E-04,   2.0243606E-04
     +,   2.1070818E-04,   2.1928136E-04,   2.2815575E-04
     +,   2.3733056E-04,   2.4680237E-04,   2.5656715E-04
     +,   2.6661879E-04,   2.7694911E-04,   2.8754861E-04
     +,   2.9840588E-04,   3.0950765E-04,   3.2083885E-04
     +,   3.3238326E-04,   3.4412259E-04,   3.5603729E-04
     +,   3.6810691E-04,   3.8030950E-04,   3.9262266E-04
     +,   4.0502395E-04,   4.1748915E-04,   4.2999574E-04
     +,   4.4252074E-04,   4.5504223E-04,   4.6753866E-04
     +,   4.7999067E-04,   4.9238012E-04,   5.0469075E-04
     +,   5.1690906E-04,   5.2902388E-04,   5.4102705E-04
     +,   5.5291271E-04,   5.6467962E-04,   5.7632790E-04
     +,   5.8786373E-04,   5.9929379E-04,   6.1063014E-04
     +,   6.2188704E-04,   6.3308259E-04,   6.4423744E-04
     +,   6.5537507E-04,   6.6652161E-04,   6.7770493E-04
     +,   6.8895443E-04,   7.0030201E-04,   7.1178033E-04
     +,   7.2342111E-04,   7.3525903E-04,   7.4732630E-04
     +,   7.5965613E-04,   7.7228056E-04,   7.8523066E-04
     +,   7.9853501E-04,   8.1222143E-04,   8.2631467E-04
     +,   8.4083795E-04,   8.5581123E-04,   8.7125099E-04
     +,   8.8716997E-04,   9.0357609E-04,   9.2047558E-04
     +,   9.3786593E-04,   9.5574191E-04,   9.7409065E-04
     +,   9.9289301E-04,   1.0121239E-03,   1.0317486E-03
     +,   1.0517265E-03,   1.0720082E-03,   1.0925343E-03
     +,   1.1132407E-03,   1.1340530E-03,   1.1548921E-03
     +,   1.1756677E-03,   1.1962907E-03,   1.2166643E-03
     +,   1.2366915E-03,   1.2562752E-03,   1.2753218E-03
     +,   1.2937431E-03,   1.3114567E-03,   1.3283934E-03
     +,   1.3444956E-03,   1.3597221E-03,   1.3740483E-03
     +,   1.3874718E-03,   1.4000074E-03,   1.4116941E-03
     +,   1.4225926E-03,   1.4327855E-03,   1.4423758E-03
     +,   1.4514877E-03,   1.4602583E-03,   1.4688427E-03
     +,   1.4774088E-03,   1.4861278E-03,   1.4951807E-03
     +,   1.5047459E-03,   1.5150009E-03,   1.5261162E-03
     +,   1.5382537E-03,   1.5515625E-03,   1.5661730E-03
     +,   1.5822034E-03,   1.5997480E-03,   1.6188817E-03
     +,   1.6396575E-03,   1.6621023E-03,   1.6862226E-03
     +,   1.7119987E-03,   1.7393861E-03,   1.7683214E-03
     +,   1.7987107E-03,   1.8304465E-03,   1.8633866E-03
     +,   1.8973767E-03,   1.9322386E-03,   1.9677719E-03
     +,   2.0037533E-03,   2.0399422E-03,   2.0760819E-03
     +,   2.1118894E-03,   2.1470645E-03,   2.1812909E-03
     +,   2.2142376E-03,   2.2455559E-03,   2.2748834E-03
     +,   2.3018573E-03,   2.3261041E-03,   2.3472535E-03
     +,   2.3649463E-03,   2.3788409E-03,   2.3886173E-03
     +,   2.3939938E-03,   2.3947321E-03,   2.3906492E-03
     +,   2.3816288E-03,   2.3676243E-03,   2.3486679E-03
     +,   2.3248855E-03,   2.2964857E-03,   2.2637739E-03
     +,   2.2271413E-03,   2.1870791E-03,   2.1441570E-03
     +,   2.0990255E-03,   2.0524049E-03,   2.0050856E-03
     +,   1.9579132E-03,   1.9117759E-03,   1.8676037E-03
     +,   1.8263591E-03,   1.7890314E-03,   1.7566265E-03
     +,   1.7301705E-03,   1.7107019E-03,   1.6992756E-03
     +,   1.6969559E-03,   1.7048216E-03,   1.7239550E-03
     +,   1.7554440E-03,   1.8003593E-03,   1.8597459E-03
     +,   1.9345921E-03,   2.0258024E-03,   2.1341541E-03
     +,   2.2602419E-03,   2.4044239E-03,   2.5667858E-03
     +,   2.7470731E-03,   2.9446334E-03,   3.1584417E-03
     +,   3.3870749E-03,   3.6287729E-03,   3.8815362E-03
     +,   4.1433382E-03,   4.4123004E-03,   4.6869321E-03
     +,   4.9663740E-03,   5.2505736E-03,   5.5402732E-03
     +,   5.8368207E-03,   6.1418070E-03,   6.4565800E-03
     +,   6.7817029E-03,   7.1165687E-03,   7.4594691E-03
     +,   7.8080180E-03,   8.1600128E-03,   8.5144071E-03
     +,   8.8721551E-03,   9.2362994E-03,   9.6111540E-03
     +,   1.0000885E-02,   1.0407591E-02,   1.0829803E-02
     +,   1.1262039E-02,   1.1695909E-02,   1.2122960E-02
     +,   1.2538425E-02,   1.2945926E-02,   1.3361382E-02
     +,   1.3815650E-02,   1.4354484E-02,   1.5036005E-02
     +,   1.5926050E-02,   1.7095674E-02,   1.8627290E-02
     +,   2.0636955E-02,   2.3301693E-02,   2.6855571E-02
     +,   3.1514525E-02,   3.7341833E-02,   4.4141743E-02
     +,   5.1476825E-02,   5.8797996E-02,   6.5565243E-02
     +,   7.1256749E-02,   7.5336568E-02,   7.7332199E-02
     +,   7.7022523E-02,   7.4530490E-02,   7.0206799E-02
     +,   6.4446099E-02,   5.7631791E-02,   5.0192069E-02
     +,   4.2609777E-02,   3.5334703E-02,   2.8687926E-02
     +,   2.2837894E-02,   1.7839570E-02,   1.3683242E-02
     +,   1.0323731E-02,   7.6875365E-03,   5.6754765E-03
     +,   4.1729547E-03,   3.0662860E-03,   2.2562672E-03
     +,   1.6640617E-03,   1.2305460E-03,   9.1261230E-04
     +,   6.7909347E-04,   5.0743483E-04,   3.8125602E-04
     +,   2.8859937E-04,   2.2065872E-04,   1.7087045E-04
     +,   1.3431221E-04,   1.0729017E-04,   8.7050787E-05
     +,   7.1576025E-05,   5.9426911E-05,   4.9611448E-05
     +,   4.1470506E-05,   3.4581688E-05,   2.8682132E-05
     +,   2.3609355E-05,   1.9257372E-05,   1.5550064E-05
     +,   1.2423357E-05,   9.8176406E-06,   7.6736123E-06
     +,   5.9326635E-06,   4.5374068E-06,   3.4336479E-06
     +,   2.5713734E-06,   1.9059859E-06,   1.3985652E-06
     +,   1.0160255E-06,   7.3086227E-07,   5.2058573E-07
     +,   3.6719399E-07,   2.5646736E-07,   1.7737651E-07
     +,   1.2146434E-07,   8.2350013E-08,   5.5269322E-08
     +,   3.6717285E-08,   2.4141059E-08,   1.5707103E-08
     +,   1.0111596E-08,   6.4399526E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt100 = Yx/0.40726
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7485583E-04,   1.8464858E-04
     +,   1.9491208E-04,   2.0566373E-04,   2.1692121E-04
     +,   2.2870232E-04,   2.4102571E-04,   2.5391034E-04
     +,   2.6737576E-04,   2.8144295E-04,   2.9613328E-04
     +,   3.1146983E-04,   3.2747700E-04,   3.4418140E-04
     +,   3.6161207E-04,   3.7980030E-04,   3.9878130E-04
     +,   4.1859318E-04,   4.3927887E-04,   4.6088587E-04
     +,   4.8346628E-04,   5.0707767E-04,   5.3178344E-04
     +,   5.5765267E-04,   5.8475829E-04,   6.1318063E-04
     +,   6.4300135E-04,   6.7430746E-04,   7.0718478E-04
     +,   7.4172032E-04,   7.7799731E-04,   8.1609329E-04
     +,   8.5607544E-04,   8.9799956E-04,   9.4190415E-04
     +,   9.8780717E-04,   1.0357016E-03,   1.0855522E-03
     +,   1.1372942E-03,   1.1908239E-03,   1.2460051E-03
     +,   1.3026611E-03,   1.3605800E-03,   1.4195109E-03
     +,   1.4791720E-03,   1.5392480E-03,   1.5994032E-03
     +,   1.6592805E-03,   1.7185152E-03,   1.7767393E-03
     +,   1.8335920E-03,   1.8887294E-03,   1.9418343E-03
     +,   1.9926233E-03,   2.0408519E-03,   2.0863295E-03
     +,   2.1289142E-03,   2.1685264E-03,   2.2051451E-03
     +,   2.2388063E-03,   2.2696138E-03,   2.2977202E-03
     +,   2.3233346E-03,   2.3467229E-03,   2.3681882E-03
     +,   2.3880755E-03,   2.4067683E-03,   2.4246755E-03
     +,   2.4422305E-03,   2.4598860E-03,   2.4781052E-03
     +,   2.4973534E-03,   2.5180990E-03,   2.5407898E-03
     +,   2.5658580E-03,   2.5936961E-03,   2.6246456E-03
     +,   2.6589835E-03,   2.6969018E-03,   2.7385002E-03
     +,   2.7837539E-03,   2.8325168E-03,   2.8844944E-03
     +,   2.9392624E-03,   2.9962377E-03,   3.0547122E-03
     +,   3.1138586E-03,   3.1727548E-03,   3.2304192E-03
     +,   3.2858611E-03,   3.3381241E-03,   3.3863254E-03
     +,   3.4297307E-03,   3.4677940E-03,   3.5002206E-03
     +,   3.5269835E-03,   3.5483618E-03,   3.5649464E-03
     +,   3.5776289E-03,   3.5875635E-03,   3.5961247E-03
     +,   3.6048167E-03,   3.6151875E-03,   3.6287380E-03
     +,   3.6467803E-03,   3.6703725E-03,   3.7002035E-03
     +,   3.7365172E-03,   3.7790912E-03,   3.8272119E-03
     +,   3.8797150E-03,   3.9350479E-03,   3.9913715E-03
     +,   4.0466981E-03,   4.0990184E-03,   4.1464898E-03
     +,   4.1875453E-03,   4.2210445E-03,   4.2463718E-03
     +,   4.2634811E-03,   4.2729317E-03,   4.2758207E-03
     +,   4.2737508E-03,   4.2686625E-03,   4.2627165E-03
     +,   4.2580967E-03,   4.2568580E-03,   4.2607486E-03
     +,   4.2710532E-03,   4.2885020E-03,   4.3132058E-03
     +,   4.3446091E-03,   4.3815761E-03,   4.4224439E-03
     +,   4.4651623E-03,   4.5074262E-03,   4.5468681E-03
     +,   4.5812088E-03,   4.6084151E-03,   4.6268241E-03
     +,   4.6352190E-03,   4.6328907E-03,   4.6196333E-03
     +,   4.5957076E-03,   4.5617693E-03,   4.5187790E-03
     +,   4.4678869E-03,   4.4103283E-03,   4.3473323E-03
     +,   4.2799958E-03,   4.2092488E-03,   4.1358010E-03
     +,   4.0601306E-03,   3.9824699E-03,   3.9028656E-03
     +,   3.8212137E-03,   3.7373225E-03,   3.6509589E-03
     +,   3.5619510E-03,   3.4702001E-03,   3.3757766E-03
     +,   3.2789181E-03,   3.1800740E-03,   3.0799157E-03
     +,   2.9793135E-03,   2.8793388E-03,   2.7812456E-03
     +,   2.6864342E-03,   2.5964263E-03,   2.5128406E-03
     +,   2.4373829E-03,   2.3718216E-03,   2.3179781E-03
     +,   2.2777237E-03,   2.2529908E-03,   2.2457701E-03
     +,   2.2581089E-03,   2.2921036E-03,   2.3498784E-03
     +,   2.4335377E-03,   2.5451046E-03,   2.6864039E-03
     +,   2.8589256E-03,   3.0637139E-03,   3.3011811E-03
     +,   3.5709694E-03,   3.8718814E-03,   4.2018699E-03
     +,   4.5581372E-03,   4.9372618E-03,   5.3355489E-03
     +,   5.7492950E-03,   6.1750324E-03,   6.6097346E-03
     +,   7.0508108E-03,   7.4958629E-03,   7.9421885E-03
     +,   8.3862329E-03,   8.8230884E-03,   9.2460569E-03
     +,   9.6466318E-03,   1.0014978E-02,   1.0340909E-02
     +,   1.0615160E-02,   1.0830700E-02,   1.0984045E-02
     +,   1.1075832E-02,   1.1110898E-02,   1.1097458E-02
     +,   1.1045821E-02,   1.0966663E-02,   1.0869377E-02
     +,   1.0760882E-02,   1.0644825E-02,   1.0521658E-02
     +,   1.0389241E-02,   1.0243724E-02,   1.0080663E-02
     +,   9.8959506E-03,   9.6865045E-03,   9.4505288E-03
     +,   9.1876267E-03,   8.8986708E-03,   8.5855769E-03
     +,   8.2510579E-03,   7.8985039E-03,   7.5318343E-03
     +,   7.1553425E-03,   6.7734919E-03,   6.3907104E-03
     +,   6.0111634E-03,   5.6384709E-03,   5.2754702E-03
     +,   4.9241683E-03,   4.5857467E-03,   4.2606043E-03
     +,   3.9486033E-03,   3.6493142E-03,   3.3622275E-03
     +,   3.0869329E-03,   2.8232473E-03,   2.5712878E-03
     +,   2.3314175E-03,   2.1041606E-03,   1.8901197E-03
     +,   1.6898680E-03,   1.5038557E-03,   1.3323224E-03
     +,   1.1752786E-03,   1.0325175E-03,   9.0359768E-04
     +,   7.8789878E-04,   6.8466994E-04,   5.9306418E-04
     +,   5.1217759E-04,   4.4109026E-04,   3.7889657E-04
     +,   3.2472075E-04,   2.7772610E-04,   2.3712801E-04
     +,   2.0219930E-04,   1.7226829E-04,   1.4671746E-04
     +,   1.2498438E-04,   1.0656179E-04,   9.0991300E-05
     +,   7.7863479E-05,   6.6816210E-05,   5.7530586E-05
     +,   4.9727772E-05,   4.3166729E-05,   3.7641097E-05
     +,   3.2975346E-05,   2.9021177E-05,   2.5654579E-05
     +,   2.2772943E-05,   2.0291316E-05,   1.8140427E-05
     +,   1.6263575E-05,   1.4615017E-05,   1.3157596E-05
     +,   1.1861526E-05,   1.0702649E-05,   9.6616359E-06
     +,   8.7227290E-06,   7.8732473E-06,   7.1027407E-06
     +,   6.4025908E-06,   5.7656785E-06,   5.1859060E-06
     +,   4.6581263E-06,   4.1778012E-06,   3.7409925E-06
     +,   3.3441256E-06,   2.9840219E-06,   2.6577316E-06
     +,   2.3625807E-06,   2.0960542E-06,   1.8558470E-06
     +,   1.6397752E-06,   1.4458259E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt105 = Yx/0.220804347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4340252E-04,   2.5579060E-04
     +,   2.6856846E-04,   2.8172956E-04,   2.9526543E-04
     +,   3.0916743E-04,   3.2342508E-04,   3.3802833E-04
     +,   3.5296555E-04,   3.6822638E-04,   3.8380010E-04
     +,   3.9967697E-04,   4.1584828E-04,   4.3230740E-04
     +,   4.4904946E-04,   4.6607247E-04,   4.8337714E-04
     +,   5.0096831E-04,   5.1885349E-04,   5.3704536E-04
     +,   5.5555988E-04,   5.7441765E-04,   5.9364201E-04
     +,   6.1326206E-04,   6.3330762E-04,   6.5381319E-04
     +,   6.7481474E-04,   6.9634762E-04,   7.1844936E-04
     +,   7.4115489E-04,   7.6449761E-04,   7.8850880E-04
     +,   8.1321498E-04,   8.3863939E-04,   8.6479960E-04
     +,   8.9170941E-04,   9.1937743E-04,   9.4780955E-04
     +,   9.7701047E-04,   1.0069812E-03,   1.0377273E-03
     +,   1.0692565E-03,   1.1015807E-03,   1.1347227E-03
     +,   1.1687147E-03,   1.2036012E-03,   1.2394411E-03
     +,   1.2763039E-03,   1.3142795E-03,   1.3534616E-03
     +,   1.3939594E-03,   1.4358860E-03,   1.4793499E-03
     +,   1.5244617E-03,   1.5713078E-03,   1.6199658E-03
     +,   1.6704755E-03,   1.7228439E-03,   1.7770343E-03
     +,   1.8329647E-03,   1.8905009E-03,   1.9494510E-03
     +,   2.0095727E-03,   2.0705739E-03,   2.1321147E-03
     +,   2.1938197E-03,   2.2552819E-03,   2.3160705E-03
     +,   2.3757548E-03,   2.4339014E-03,   2.4901030E-03
     +,   2.5439649E-03,   2.5951455E-03,   2.6433403E-03
     +,   2.6883038E-03,   2.7298541E-03,   2.7678737E-03
     +,   2.8023124E-03,   2.8331969E-03,   2.8606199E-03
     +,   2.8847591E-03,   2.9058526E-03,   2.9242167E-03
     +,   2.9402408E-03,   2.9543727E-03,   2.9671339E-03
     +,   2.9790888E-03,   2.9908612E-03,   3.0031016E-03
     +,   3.0164765E-03,   3.0316629E-03,   3.0493147E-03
     +,   3.0700499E-03,   3.0944168E-03,   3.1228941E-03
     +,   3.1558529E-03,   3.1935584E-03,   3.2361508E-03
     +,   3.2836515E-03,   3.3359600E-03,   3.3928761E-03
     +,   3.4540952E-03,   3.5192489E-03,   3.5879069E-03
     +,   3.6596106E-03,   3.7338745E-03,   3.8102120E-03
     +,   3.8881195E-03,   3.9671152E-03,   4.0466883E-03
     +,   4.1263183E-03,   4.2054574E-03,   4.2835088E-03
     +,   4.3598320E-03,   4.4337232E-03,   4.5044236E-03
     +,   4.5711296E-03,   4.6330113E-03,   4.6892497E-03
     +,   4.7390489E-03,   4.7817030E-03,   4.8166136E-03
     +,   4.8433524E-03,   4.8616701E-03,   4.8715449E-03
     +,   4.8731696E-03,   4.8669735E-03,   4.8536076E-03
     +,   4.8338999E-03,   4.8088362E-03,   4.7795190E-03
     +,   4.7470960E-03,   4.7127246E-03,   4.6775038E-03
     +,   4.6424251E-03,   4.6083177E-03,   4.5757811E-03
     +,   4.5451792E-03,   4.5165713E-03,   4.4897026E-03
     +,   4.4640219E-03,   4.4386708E-03,   4.4125211E-03
     +,   4.3842522E-03,   4.3523950E-03,   4.3154457E-03
     +,   4.2719422E-03,   4.2205737E-03,   4.1602622E-03
     +,   4.0902379E-03,   4.0100911E-03,   3.9198170E-03
     +,   3.8198044E-03,   3.7108264E-03,   3.5939817E-03
     +,   3.4706797E-03,   3.3425346E-03,   3.2112971E-03
     +,   3.0787939E-03,   2.9468678E-03,   2.8172927E-03
     +,   2.6917425E-03,   2.5717649E-03,   2.4587340E-03
     +,   2.3538538E-03,   2.2581436E-03,   2.1724638E-03
     +,   2.0975100E-03,   2.0338383E-03,   1.9818863E-03
     +,   1.9420034E-03,   1.9144606E-03,   1.8994731E-03
     +,   1.8972191E-03,   1.9078489E-03,   1.9314904E-03
     +,   1.9682494E-03,   2.0182170E-03,   2.0814666E-03
     +,   2.1580590E-03,   2.2480630E-03,   2.3515574E-03
     +,   2.4686588E-03,   2.5995676E-03,   2.7445834E-03
     +,   2.9041313E-03,   3.0787913E-03,   3.2693094E-03
     +,   3.4765895E-03,   3.7016210E-03,   3.9454792E-03
     +,   4.2092032E-03,   4.4936519E-03,   4.7993888E-03
     +,   5.1265191E-03,   5.4745120E-03,   5.8419728E-03
     +,   6.2265457E-03,   6.6248034E-03,   7.0321942E-03
     +,   7.4430876E-03,   7.8509171E-03,   8.2484763E-03
     +,   8.6282631E-03,   8.9828484E-03,   9.3053505E-03
     +,   9.5898509E-03,   9.8317070E-03,   1.0027802E-02
     +,   1.0176680E-02,   1.0278502E-02,   1.0334758E-02
     +,   1.0348187E-02,   1.0322237E-02,   1.0260825E-02
     +,   1.0167934E-02,   1.0047415E-02,   9.9027334E-03
     +,   9.7369552E-03,   9.5526231E-03,   9.3518309E-03
     +,   9.1361981E-03,   8.9069372E-03,   8.6648194E-03
     +,   8.4102591E-03,   8.1433132E-03,   7.8638457E-03
     +,   7.5716437E-03,   7.2665731E-03,   6.9487826E-03
     +,   6.6189147E-03,   6.2781409E-03,   5.9282463E-03
     +,   5.5715539E-03,   5.2109109E-03,   4.8494237E-03
     +,   4.4903615E-03,   4.1369642E-03,   3.7923113E-03
     +,   3.4591572E-03,   3.1398796E-03,   2.8364484E-03
     +,   2.5503838E-03,   2.2827415E-03,   2.0341557E-03
     +,   1.8048823E-03,   1.5948289E-03,   1.4035875E-03
     +,   1.2305022E-03,   1.0747390E-03,   9.3530014E-04
     +,   8.1109116E-04,   7.0097268E-04,   6.0378335E-04
     +,   5.1836343E-04,   4.4359019E-04,   3.7839456E-04
     +,   3.2176779E-04,   2.7276535E-04,   2.3051593E-04
     +,   1.9422310E-04,   1.6316191E-04,   1.3667368E-04
     +,   1.1416645E-04,   9.5112155E-05,   7.9038109E-05
     +,   6.5525484E-05,   5.4205480E-05,   4.4753906E-05
     +,   3.6886948E-05,   3.0357973E-05,   2.4954170E-05
     +,   2.0492487E-05,   1.6816137E-05,   1.3791931E-05
     +,   1.1307612E-05,   9.2685495E-06,   7.5959624E-06
     +,   6.2241738E-06,   5.0990561E-06,   4.1758999E-06
     +,   3.4181558E-06,   2.7958326E-06,   2.2845322E-06
     +,   1.8642938E-06,   1.5188991E-06,   1.2350781E-06
     +,   1.0019908E-06,   8.1077684E-07,   6.5413286E-07
     +,   5.2606021E-07,   4.2158510E-07,   3.3659887E-07
     +,   2.6767856E-07,   2.1198584E-07,   1.6715101E-07
     +,   1.3120803E-07,   1.0251731E-07,   7.9722170E-08
     +,   6.1696646E-08,   4.7514188E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt107 = Yx/0.208911111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9963080E-04,   2.1046589E-04
     +,   2.2172350E-04,   2.3341092E-04,   2.4553540E-04
     +,   2.5810426E-04,   2.7112503E-04,   2.8460537E-04
     +,   2.9855286E-04,   3.1297572E-04,   3.2788172E-04
     +,   3.4327857E-04,   3.5917354E-04,   3.7557352E-04
     +,   3.9248460E-04,   4.0991124E-04,   4.2785707E-04
     +,   4.4632316E-04,   4.6530829E-04,   4.8480858E-04
     +,   5.0481665E-04,   5.2532129E-04,   5.4630678E-04
     +,   5.6775403E-04,   5.8963744E-04,   6.1192818E-04
     +,   6.3459075E-04,   6.5758545E-04,   6.8086752E-04
     +,   7.0438697E-04,   7.2809181E-04,   7.5192313E-04
     +,   7.7582162E-04,   7.9972617E-04,   8.2357292E-04
     +,   8.4729987E-04,   8.7084674E-04,   8.9415308E-04
     +,   9.1716694E-04,   9.3983696E-04,   9.6212368E-04
     +,   9.8399317E-04,   1.0054226E-03,   1.0264000E-03
     +,   1.0469285E-03,   1.0670243E-03,   1.0867212E-03
     +,   1.1060693E-03,   1.1251385E-03,   1.1440187E-03
     +,   1.1628189E-03,   1.1816699E-03,   1.2007229E-03
     +,   1.2201493E-03,   1.2401385E-03,   1.2608989E-03
     +,   1.2826523E-03,   1.3056304E-03,   1.3300765E-03
     +,   1.3562328E-03,   1.3843413E-03,   1.4146368E-03
     +,   1.4473351E-03,   1.4826360E-03,   1.5207080E-03
     +,   1.5616782E-03,   1.6056389E-03,   1.6526179E-03
     +,   1.7025946E-03,   1.7554716E-03,   1.8110870E-03
     +,   1.8691955E-03,   1.9294822E-03,   1.9915414E-03
     +,   2.0549002E-03,   2.1190180E-03,   2.1832911E-03
     +,   2.2470721E-03,   2.3096949E-03,   2.3704937E-03
     +,   2.4288197E-03,   2.4840916E-03,   2.5358004E-03
     +,   2.5835603E-03,   2.6271273E-03,   2.6664219E-03
     +,   2.7015402E-03,   2.7327761E-03,   2.7606043E-03
     +,   2.7856713E-03,   2.8087699E-03,   2.8308055E-03
     +,   2.8527447E-03,   2.8755618E-03,   2.9001960E-03
     +,   2.9274737E-03,   2.9580751E-03,   2.9924838E-03
     +,   3.0309658E-03,   3.0735519E-03,   3.1200447E-03
     +,   3.1700423E-03,   3.2229791E-03,   3.2781577E-03
     +,   3.3348266E-03,   3.3922140E-03,   3.4495781E-03
     +,   3.5062397E-03,   3.5616118E-03,   3.6151838E-03
     +,   3.6665138E-03,   3.7152029E-03,   3.7608645E-03
     +,   3.8030678E-03,   3.8413205E-03,   3.8750509E-03
     +,   3.9035815E-03,   3.9261724E-03,   3.9420249E-03
     +,   3.9503518E-03,   3.9504203E-03,   3.9416254E-03
     +,   3.9235521E-03,   3.8960145E-03,   3.8591297E-03
     +,   3.8132924E-03,   3.7591977E-03,   3.6978181E-03
     +,   3.6303543E-03,   3.5581798E-03,   3.4827520E-03
     +,   3.4055843E-03,   3.3281122E-03,   3.2516851E-03
     +,   3.1774563E-03,   3.1063785E-03,   3.0391631E-03
     +,   2.9762764E-03,   2.9179268E-03,   2.8641105E-03
     +,   2.8146284E-03,   2.7691261E-03,   2.7271400E-03
     +,   2.6881353E-03,   2.6515534E-03,   2.6168476E-03
     +,   2.5834988E-03,   2.5510504E-03,   2.5191072E-03
     +,   2.4873370E-03,   2.4554729E-03,   2.4232978E-03
     +,   2.3906366E-03,   2.3573434E-03,   2.3232861E-03
     +,   2.2883560E-03,   2.2524486E-03,   2.2154814E-03
     +,   2.1773924E-03,   2.1381686E-03,   2.0978409E-03
     +,   2.0565127E-03,   2.0143772E-03,   1.9717233E-03
     +,   1.9289390E-03,   1.8865239E-03,   1.8450846E-03
     +,   1.8053207E-03,   1.7680131E-03,   1.7340062E-03
     +,   1.7041881E-03,   1.6794677E-03,   1.6607470E-03
     +,   1.6489113E-03,   1.6447997E-03,   1.6491975E-03
     +,   1.6628244E-03,   1.6863267E-03,   1.7202740E-03
     +,   1.7651618E-03,   1.8214087E-03,   1.8893610E-03
     +,   1.9693016E-03,   2.0614539E-03,   2.1659955E-03
     +,   2.2830605E-03,   2.4127483E-03,   2.5551559E-03
     +,   2.7103736E-03,   2.8784708E-03,   3.0595253E-03
     +,   3.2535871E-03,   3.4606226E-03,   3.6804690E-03
     +,   3.9127762E-03,   4.1568782E-03,   4.4116960E-03
     +,   4.6756458E-03,   4.9465816E-03,   5.2217408E-03
     +,   5.4977364E-03,   5.7706852E-03,   6.0363403E-03
     +,   6.2903143E-03,   6.5283417E-03,   6.7466269E-03
     +,   6.9420924E-03,   7.1126865E-03,   7.2575291E-03
     +,   7.3770164E-03,   7.4726855E-03,   7.5470358E-03
     +,   7.6031447E-03,   7.6442300E-03,   7.6731564E-03
     +,   7.6919603E-03,   7.7015287E-03,   7.7013513E-03
     +,   7.6895771E-03,   7.6631489E-03,   7.6182117E-03
     +,   7.5505944E-03,   7.4563790E-03,   7.3324158E-03
     +,   7.1767191E-03,   6.9887741E-03,   6.7696148E-03
     +,   6.5217293E-03,   6.2487926E-03,   5.9553622E-03
     +,   5.6464677E-03,   5.3272545E-03,   5.0026090E-03
     +,   4.6769585E-03,   4.3541337E-03,   4.0372773E-03
     +,   3.7288868E-03,   3.4309032E-03,   3.1447965E-03
     +,   2.8716393E-03,   2.6122218E-03,   2.3671412E-03
     +,   2.1368188E-03,   1.9215191E-03,   1.7213578E-03
     +,   1.5363295E-03,   1.3662720E-03,   1.2108638E-03
     +,   1.0696363E-03,   9.4200316E-04,   8.2724902E-04
     +,   7.2457246E-04,   6.3311844E-04,   5.5199990E-04
     +,   4.8031917E-04,   4.1719674E-04,   3.6179359E-04
     +,   3.1331633E-04,   2.7102348E-04,   2.3423292E-04
     +,   2.0232356E-04,   1.7473062E-04,   1.5094085E-04
     +,   1.3049148E-04,   1.1296719E-04,   9.7992568E-05
     +,   8.5230939E-05,   7.4381933E-05,   6.5177228E-05
     +,   5.7378074E-05,   5.0773528E-05,   4.5178793E-05
     +,   4.0432460E-05,   3.6394402E-05,   3.2944194E-05
     +,   2.9979508E-05,   2.7413458E-05,   2.5173656E-05
     +,   2.3199802E-05,   2.1442662E-05,   1.9862051E-05
     +,   1.8425941E-05,   1.7108758E-05,   1.5890659E-05
     +,   1.4756188E-05,   1.3693703E-05,   1.2694407E-05
     +,   1.1751779E-05,   1.0861167E-05,   1.0019088E-05
     +,   9.2231412E-06,   8.4714729E-06,   7.7627674E-06
     +,   7.0958704E-06,   6.4698497E-06,   5.8837227E-06
     +,   5.3365534E-06,   4.8272591E-06,   4.3547334E-06
     +,   3.9176971E-06,   3.5148278E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt110 = Yx/0.164906976744186
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5256774E-04,   1.5990736E-04
     +,   1.6756471E-04,   1.7555615E-04,   1.8389850E-04
     +,   1.9260918E-04,   2.0170631E-04,   2.1120840E-04
     +,   2.2113413E-04,   2.3150288E-04,   2.4233329E-04
     +,   2.5364428E-04,   2.6545435E-04,   2.7778128E-04
     +,   2.9064226E-04,   3.0405345E-04,   3.1802960E-04
     +,   3.3258455E-04,   3.4773021E-04,   3.6347663E-04
     +,   3.7983243E-04,   3.9680375E-04,   4.1439442E-04
     +,   4.3260743E-04,   4.5144095E-04,   4.7089375E-04
     +,   4.9096049E-04,   5.1163434E-04,   5.3290644E-04
     +,   5.5476557E-04,   5.7720050E-04,   6.0019584E-04
     +,   6.2373694E-04,   6.4780761E-04,   6.7239045E-04
     +,   6.9746678E-04,   7.2301773E-04,   7.4902258E-04
     +,   7.7546155E-04,   8.0231071E-04,   8.2954555E-04
     +,   8.5713930E-04,   8.8506198E-04,   9.1327837E-04
     +,   9.4174925E-04,   9.7042782E-04,   9.9926197E-04
     +,   1.0281900E-03,   1.0571401E-03,   1.0860338E-03
     +,   1.1147790E-03,   1.1432753E-03,   1.1714119E-03
     +,   1.1990699E-03,   1.2261239E-03,   1.2524424E-03
     +,   1.2778955E-03,   1.3023535E-03,   1.3256931E-03
     +,   1.3478060E-03,   1.3685970E-03,   1.3879961E-03
     +,   1.4059597E-03,   1.4224786E-03,   1.4375803E-03
     +,   1.4513308E-03,   1.4638448E-03,   1.4752757E-03
     +,   1.4858260E-03,   1.4957348E-03,   1.5052827E-03
     +,   1.5147765E-03,   1.5245500E-03,   1.5349459E-03
     +,   1.5463108E-03,   1.5589785E-03,   1.5732601E-03
     +,   1.5894290E-03,   1.6077089E-03,   1.6282648E-03
     +,   1.6511854E-03,   1.6764909E-03,   1.7041116E-03
     +,   1.7338985E-03,   1.7656207E-03,   1.7989712E-03
     +,   1.8335789E-03,   1.8690180E-03,   1.9048232E-03
     +,   1.9405094E-03,   1.9755904E-03,   2.0095911E-03
     +,   2.0420719E-03,   2.0726442E-03,   2.1009825E-03
     +,   2.1268311E-03,   2.1500164E-03,   2.1704461E-03
     +,   2.1881040E-03,   2.2030442E-03,   2.2153885E-03
     +,   2.2252998E-03,   2.2329774E-03,   2.2386378E-03
     +,   2.2425021E-03,   2.2447824E-03,   2.2456683E-03
     +,   2.2453263E-03,   2.2438909E-03,   2.2414674E-03
     +,   2.2381360E-03,   2.2339588E-03,   2.2289909E-03
     +,   2.2232858E-03,   2.2169070E-03,   2.2099414E-03
     +,   2.2024969E-03,   2.1947131E-03,   2.1867582E-03
     +,   2.1788254E-03,   2.1711208E-03,   2.1638595E-03
     +,   2.1572448E-03,   2.1514602E-03,   2.1466438E-03
     +,   2.1428862E-03,   2.1402063E-03,   2.1385502E-03
     +,   2.1377841E-03,   2.1376922E-03,   2.1379830E-03
     +,   2.1382961E-03,   2.1382230E-03,   2.1373199E-03
     +,   2.1351248E-03,   2.1311825E-03,   2.1250679E-03
     +,   2.1164035E-03,   2.1048703E-03,   2.0902373E-03
     +,   2.0723592E-03,   2.0511819E-03,   2.0267467E-03
     +,   1.9991843E-03,   1.9687086E-03,   1.9356048E-03
     +,   1.9002079E-03,   1.8628993E-03,   1.8240822E-03
     +,   1.7841636E-03,   1.7435483E-03,   1.7026195E-03
     +,   1.6617324E-03,   1.6212022E-03,   1.5812978E-03
     +,   1.5422509E-03,   1.5042466E-03,   1.4674278E-03
     +,   1.4319017E-03,   1.3977487E-03,   1.3650255E-03
     +,   1.3337743E-03,   1.3040325E-03,   1.2758402E-03
     +,   1.2492418E-03,   1.2242978E-03,   1.2010854E-03
     +,   1.1797054E-03,   1.1602775E-03,   1.1429453E-03
     +,   1.1278746E-03,   1.1152504E-03,   1.1052741E-03
     +,   1.0981583E-03,   1.0941244E-03,   1.0933956E-03
     +,   1.0961944E-03,   1.1027362E-03,   1.1132247E-03
     +,   1.1278464E-03,   1.1467697E-03,   1.1701358E-03
     +,   1.1980576E-03,   1.2306167E-03,   1.2678581E-03
     +,   1.3097894E-03,   1.3563731E-03,   1.4075339E-03
     +,   1.4631533E-03,   1.5230638E-03,   1.5870642E-03
     +,   1.6549149E-03,   1.7263433E-03,   1.8010518E-03
     +,   1.8787342E-03,   1.9590836E-03,   2.0418058E-03
     +,   2.1266239E-03,   2.2133295E-03,   2.3017658E-03
     +,   2.3918550E-03,   2.4836198E-03,   2.5771901E-03
     +,   2.6728122E-03,   2.7708258E-03,   2.8716740E-03
     +,   2.9758546E-03,   3.0838968E-03,   3.1962777E-03
     +,   3.3133926E-03,   3.4354685E-03,   3.5624814E-03
     +,   3.6940945E-03,   3.8296347E-03,   3.9680237E-03
     +,   4.1077691E-03,   4.2470046E-03,   4.3835412E-03
     +,   4.5149215E-03,   4.6385191E-03,   4.7516781E-03
     +,   4.8517981E-03,   4.9364539E-03,   5.0034942E-03
     +,   5.0511300E-03,   5.0779814E-03,   5.0830944E-03
     +,   5.0659669E-03,   5.0265212E-03,   4.9650669E-03
     +,   4.8822896E-03,   4.7791861E-03,   4.6570161E-03
     +,   4.5172842E-03,   4.3616965E-03,   4.1921176E-03
     +,   4.0105563E-03,   3.8191176E-03,   3.6199926E-03
     +,   3.4153850E-03,   3.2074810E-03,   2.9984387E-03
     +,   2.7903076E-03,   2.5849834E-03,   2.3841907E-03
     +,   2.1894504E-03,   2.0020681E-03,   1.8230928E-03
     +,   1.6533370E-03,   1.4934032E-03,   1.3436611E-03
     +,   1.2042887E-03,   1.0753038E-03,   9.5657876E-04
     +,   8.4785791E-04,   7.4879138E-04,   6.5896177E-04
     +,   5.7789509E-04,   5.0507323E-04,   4.3995533E-04
     +,   3.8199138E-04,   3.3062720E-04,   2.8531012E-04
     +,   2.4550062E-04,   2.1067973E-04,   1.8034686E-04
     +,   1.5402772E-04,   1.3127824E-04,   1.1168480E-04
     +,   9.4864547E-05,   8.0467566E-05,   6.8177847E-05
     +,   5.7711251E-05,   4.8813959E-05,   4.1261861E-05
     +,   3.4859251E-05,   2.9434992E-05,   2.4841920E-05
     +,   2.0953137E-05,   1.7660799E-05,   1.4872850E-05
     +,   1.2511766E-05,   1.0511808E-05,   8.8178849E-06
     +,   7.3833889E-06,   6.1692831E-06,   5.1425222E-06
     +,   4.2752090E-06,   3.5437847E-06,   2.9281332E-06
     +,   2.4111864E-06,   1.9782735E-06,   1.6168759E-06
     +,   1.3161886E-06,   1.0669556E-06,   8.6117910E-07
     +,   6.9200769E-07,   5.5353433E-07,   4.4071686E-07
     +,   3.4923184E-07,   2.7541239E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt115 = Yx/0.112853658536585
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9496633E-04,   2.0369631E-04
     +,   2.1257509E-04,   2.2158990E-04,   2.3072732E-04
     +,   2.3997379E-04,   2.4931549E-04,   2.5873893E-04
     +,   2.6823068E-04,   2.7777857E-04,   2.8737111E-04
     +,   2.9699807E-04,   3.0665117E-04,   3.1632409E-04
     +,   3.2601366E-04,   3.3571894E-04,   3.4544311E-04
     +,   3.5519281E-04,   3.6497897E-04,   3.7481741E-04
     +,   3.8472877E-04,   3.9473848E-04,   4.0487785E-04
     +,   4.1518384E-04,   4.2569792E-04,   4.3646761E-04
     +,   4.4754526E-04,   4.5898787E-04,   4.7085629E-04
     +,   4.8321512E-04,   4.9613125E-04,   5.0967309E-04
     +,   5.2390987E-04,   5.3890969E-04,   5.5473903E-04
     +,   5.7146122E-04,   5.8913435E-04,   6.0781109E-04
     +,   6.2753737E-04,   6.4834917E-04,   6.7027513E-04
     +,   6.9333194E-04,   7.1752537E-04,   7.4285048E-04
     +,   7.6928927E-04,   7.9681323E-04,   8.2538137E-04
     +,   8.5494097E-04,   8.8542991E-04,   9.1677532E-04
     +,   9.4889535E-04,   9.8169956E-04,   1.0150912E-03
     +,   1.0489664E-03,   1.0832133E-03,   1.1177174E-03
     +,   1.1523571E-03,   1.1870052E-03,   1.2215282E-03
     +,   1.2557864E-03,   1.2896342E-03,   1.3229192E-03
     +,   1.3554778E-03,   1.3871458E-03,   1.4177506E-03
     +,   1.4471126E-03,   1.4750541E-03,   1.5013942E-03
     +,   1.5259599E-03,   1.5485879E-03,   1.5691288E-03
     +,   1.5874541E-03,   1.6034624E-03,   1.6170844E-03
     +,   1.6282881E-03,   1.6370846E-03,   1.6435285E-03
     +,   1.6477249E-03,   1.6498215E-03,   1.6500170E-03
     +,   1.6485524E-03,   1.6457107E-03,   1.6418084E-03
     +,   1.6371934E-03,   1.6322368E-03,   1.6273222E-03
     +,   1.6228459E-03,   1.6192057E-03,   1.6167907E-03
     +,   1.6159775E-03,   1.6171234E-03,   1.6205565E-03
     +,   1.6265721E-03,   1.6354226E-03,   1.6473128E-03
     +,   1.6623916E-03,   1.6807520E-03,   1.7024194E-03
     +,   1.7273532E-03,   1.7554434E-03,   1.7865115E-03
     +,   1.8203132E-03,   1.8565336E-03,   1.8948080E-03
     +,   1.9347131E-03,   1.9757894E-03,   2.0175336E-03
     +,   2.0594224E-03,   2.1009143E-03,   2.1414664E-03
     +,   2.1805272E-03,   2.2175703E-03,   2.2520781E-03
     +,   2.2835748E-03,   2.3116078E-03,   2.3357822E-03
     +,   2.3557476E-03,   2.3712234E-03,   2.3819923E-03
     +,   2.3879134E-03,   2.3889246E-03,   2.3850466E-03
     +,   2.3763804E-03,   2.3631093E-03,   2.3454893E-03
     +,   2.3238470E-03,   2.2985619E-03,   2.2700564E-03
     +,   2.2387831E-03,   2.2052089E-03,   2.1697963E-03
     +,   2.1329906E-03,   2.0952052E-03,   2.0568126E-03
     +,   2.0181311E-03,   1.9794176E-03,   1.9408743E-03
     +,   1.9026349E-03,   1.8647752E-03,   1.8273124E-03
     +,   1.7902193E-03,   1.7534262E-03,   1.7168345E-03
     +,   1.6803186E-03,   1.6437524E-03,   1.6070042E-03
     +,   1.5699506E-03,   1.5324906E-03,   1.4945496E-03
     +,   1.4560792E-03,   1.4170682E-03,   1.3775460E-03
     +,   1.3375804E-03,   1.2972729E-03,   1.2567597E-03
     +,   1.2162122E-03,   1.1758248E-03,   1.1358091E-03
     +,   1.0963907E-03,   1.0578042E-03,   1.0202794E-03
     +,   9.8404218E-04,   9.4930775E-04,   9.1627490E-04
     +,   8.8512030E-04,   8.5599959E-04,   8.2904514E-04
     +,   8.0436660E-04,   7.8204653E-04,   7.6214608E-04
     +,   7.4470637E-04,   7.2974997E-04,   7.1728387E-04
     +,   7.0730195E-04,   6.9979148E-04,   6.9473434E-04
     +,   6.9211057E-04,   6.9190498E-04,   6.9410854E-04
     +,   6.9872267E-04,   7.0576259E-04,   7.1526016E-04
     +,   7.2726473E-04,   7.4184634E-04,   7.5909426E-04
     +,   7.7911525E-04,   8.0203259E-04,   8.2798151E-04
     +,   8.5710734E-04,   8.8955346E-04,   9.2546036E-04
     +,   9.6495659E-04,   1.0081490E-03,   1.0551162E-03
     +,   1.1059081E-03,   1.1605353E-03,   1.2189617E-03
     +,   1.2811072E-03,   1.3468496E-03,   1.4160250E-03
     +,   1.4884226E-03,   1.5637943E-03,   1.6418638E-03
     +,   1.7223258E-03,   1.8048423E-03,   1.8890579E-03
     +,   1.9745957E-03,   2.0610488E-03,   2.1479833E-03
     +,   2.2349404E-03,   2.3214282E-03,   2.4069145E-03
     +,   2.4908294E-03,   2.5725784E-03,   2.6515315E-03
     +,   2.7270447E-03,   2.7984565E-03,   2.8651331E-03
     +,   2.9264602E-03,   2.9818679E-03,   3.0308447E-03
     +,   3.0729626E-03,   3.1078698E-03,   3.1352914E-03
     +,   3.1550527E-03,   3.1670399E-03,   3.1712076E-03
     +,   3.1675587E-03,   3.1561269E-03,   3.1369734E-03
     +,   3.1101648E-03,   3.0757771E-03,   3.0338918E-03
     +,   2.9845976E-03,   2.9280121E-03,   2.8642835E-03
     +,   2.7936134E-03,   2.7162696E-03,   2.6326058E-03
     +,   2.5430578E-03,   2.4481569E-03,   2.3485317E-03
     +,   2.2448981E-03,   2.1380358E-03,   2.0287817E-03
     +,   1.9180081E-03,   1.8066019E-03,   1.6954276E-03
     +,   1.5853161E-03,   1.4770507E-03,   1.3713366E-03
     +,   1.2687930E-03,   1.1699561E-03,   1.0752669E-03
     +,   9.8506466E-04,   8.9959754E-04,   8.1903354E-04
     +,   7.4346160E-04,   6.7289546E-04,   6.0729007E-04
     +,   5.4655306E-04,   4.9054925E-04,   4.3910611E-04
     +,   3.9202484E-04,   3.4909262E-04,   3.1007774E-04
     +,   2.7474036E-04,   2.4283928E-04,   2.1413229E-04
     +,   1.8837785E-04,   1.6534026E-04,   1.4479301E-04
     +,   1.2651831E-04,   1.1030796E-04,   9.5965443E-05
     +,   8.3308085E-05,   7.2164119E-05,   6.2376108E-05
     +,   5.3798045E-05,   4.6297540E-05,   3.9753097E-05
     +,   3.4055614E-05,   2.9105899E-05,   2.4815487E-05
     +,   2.1104588E-05,   1.7902448E-05,   1.5145693E-05
     +,   1.2778079E-05,   1.0749934E-05,   9.0170406E-06
     +,   7.5405665E-06,   6.2860768E-06,   5.2234332E-06
     +,   4.3260193E-06,   3.5706223E-06,   2.9368380E-06
     +,   2.4069500E-06,   1.9654640E-06,   1.5989981E-06
     +,   1.2959214E-06,   1.0462469E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt120 = Yx/0.091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9723119E-03,   2.2902144E-03
     +,   2.6283637E-03,   2.9831706E-03,   3.3512271E-03
     +,   3.7298712E-03,   4.1177585E-03,   4.5153177E-03
     +,   4.9250685E-03,   5.3516370E-03,   5.8014425E-03
     +,   6.2820544E-03,   6.8012006E-03,   7.3656151E-03
     +,   7.9798950E-03,   8.6457757E-03,   9.3619637E-03
     +,   1.0124613E-02,   1.0927963E-02,   1.1764769E-02
     +,   1.2626161E-02,   1.3501658E-02,   1.4380534E-02
     +,   1.5255371E-02,   1.6126167E-02,   1.7002398E-02
     +,   1.7898127E-02,   1.8820433E-02,   1.9755857E-02
     +,   2.0664856E-02,   2.1491483E-02,   2.2186665E-02
     +,   2.2733808E-02,   2.3159815E-02,   2.3522973E-02
     +,   2.3880849E-02,   2.4255272E-02,   2.4611879E-02
     +,   2.4866167E-02,   2.4913043E-02,   2.4667261E-02
     +,   2.4095293E-02,   2.3224182E-02,   2.2125524E-02
     +,   2.0885343E-02,   1.9577056E-02,   1.8249914E-02
     +,   1.6933138E-02,   1.5647294E-02,   1.4413143E-02
     +,   1.3252993E-02,   1.2187185E-02,   1.1229493E-02
     +,   1.0385091E-02,   9.6511627E-03,   9.0184053E-03
     +,   8.4729567E-03,   7.9979319E-03,   7.5752954E-03
     +,   7.1881879E-03,   6.8233972E-03,   6.4728665E-03
     +,   6.1340421E-03,   5.8087474E-03,   5.5013318E-03
     +,   5.2166525E-03,   4.9584499E-03,   4.7285496E-03
     +,   4.5265569E-03,   4.3502185E-03,   4.1958946E-03
     +,   4.0592486E-03,   3.9358172E-03,   3.8215281E-03
     +,   3.7130297E-03,   3.6078936E-03,   3.5046663E-03
     +,   3.4027724E-03,   3.3023371E-03,   3.2039697E-03
     +,   3.1085268E-03,   3.0168742E-03,   2.9297501E-03
     +,   2.8476128E-03,   2.7706225E-03,   2.6986105E-03
     +,   2.6311560E-03,   2.5676070E-03,   2.5072023E-03
     +,   2.4491232E-03,   2.3925679E-03,   2.3368148E-03
     +,   2.2812567E-03,   2.2254179E-03,   2.1689690E-03
     +,   2.1117281E-03,   2.0536301E-03,   1.9947349E-03
     +,   1.9351804E-03,   1.8751849E-03,   1.8149999E-03
     +,   1.7549158E-03,   1.6952212E-03,   1.6362082E-03
     +,   1.5781472E-03,   1.5212825E-03,   1.4658344E-03
     +,   1.4119894E-03,   1.3598944E-03,   1.3096686E-03
     +,   1.2614026E-03,   1.2151537E-03,   1.1709636E-03
     +,   1.1288450E-03,   1.0887994E-03,   1.0508080E-03
     +,   1.0148466E-03,   9.8087476E-04,   9.4884873E-04
     +,   9.1871445E-04,   8.9041196E-04,   8.6387846E-04
     +,   8.3904603E-04,   8.1584085E-04,   7.9418556E-04
     +,   7.7400374E-04,   7.5521122E-04,   7.3772651E-04
     +,   7.2146469E-04,   7.0634205E-04,   6.9227401E-04
     +,   6.7917950E-04,   6.6697825E-04,   6.5559254E-04
     +,   6.4494932E-04,   6.3497847E-04,   6.2561466E-04
     +,   6.1679800E-04,   6.0847163E-04,   6.0058542E-04
     +,   5.9309299E-04,   5.8595382E-04,   5.7913020E-04
     +,   5.7259097E-04,   5.6630751E-04,   5.6025560E-04
     +,   5.5441487E-04,   5.4876762E-04,   5.4330059E-04
     +,   5.3800148E-04,   5.3286209E-04,   5.2787625E-04
     +,   5.2304001E-04,   5.1835156E-04,   5.1381049E-04
     +,   5.0941895E-04,   5.0518021E-04,   5.0109875E-04
     +,   4.9717980E-04,   4.9343042E-04,   4.8985804E-04
     +,   4.8646994E-04,   4.8327437E-04,   4.8027936E-04
     +,   4.7749261E-04,   4.7492079E-04,   4.7257068E-04
     +,   4.7044750E-04,   4.6855531E-04,   4.6689698E-04
     +,   4.6547368E-04,   4.6428494E-04,   4.6332864E-04
     +,   4.6260038E-04,   4.6209423E-04,   4.6180226E-04
     +,   4.6171469E-04,   4.6181929E-04,   4.6210343E-04
     +,   4.6255116E-04,   4.6314628E-04,   4.6387041E-04
     +,   4.6470438E-04,   4.6562796E-04,   4.6661994E-04
     +,   4.6765886E-04,   4.6872202E-04,   4.6978728E-04
     +,   4.7083301E-04,   4.7183604E-04,   4.7277551E-04
     +,   4.7362983E-04,   4.7437931E-04,   4.7500434E-04
     +,   4.7548715E-04,   4.7581075E-04,   4.7595994E-04
     +,   4.7592068E-04,   4.7568104E-04,   4.7522984E-04
     +,   4.7455894E-04,   4.7366091E-04,   4.7253046E-04
     +,   4.7116415E-04,   4.6955995E-04,   4.6771782E-04
     +,   4.6563911E-04,   4.6332684E-04,   4.6078514E-04
     +,   4.5802005E-04,   4.5503798E-04,   4.5184707E-04
     +,   4.4845630E-04,   4.4487504E-04,   4.4111340E-04
     +,   4.3718208E-04,   4.3309212E-04,   4.2885484E-04
     +,   4.2448097E-04,   4.1998175E-04,   4.1536830E-04
     +,   4.1065045E-04,   4.0583874E-04,   4.0094266E-04
     +,   3.9597080E-04,   3.9093121E-04,   3.8583175E-04
     +,   3.8067898E-04,   3.7547888E-04,   3.7023649E-04
     +,   3.6495613E-04,   3.5964212E-04,   3.5429685E-04
     +,   3.4892280E-04,   3.4352203E-04,   3.3809574E-04
     +,   3.3264447E-04,   3.2716902E-04,   3.2166956E-04
     +,   3.1614609E-04,   3.1059829E-04,   3.0502613E-04
     +,   2.9942981E-04,   2.9380905E-04,   2.8816369E-04
     +,   2.8249455E-04,   2.7680252E-04,   2.7108818E-04
     +,   2.6535313E-04,   2.5959921E-04,   2.5382856E-04
     +,   2.4804362E-04,   2.4224764E-04,   2.3644438E-04
     +,   2.3063742E-04,   2.2483093E-04,   2.1902974E-04
     +,   2.1323896E-04,   2.0746372E-04,   2.0170934E-04
     +,   1.9598166E-04,   1.9028674E-04,   1.8463038E-04
     +,   1.7901840E-04,   1.7345724E-04,   1.6795265E-04
     +,   1.6251042E-04,   1.5713641E-04,   1.5183642E-04
     +,   1.4661571E-04,   1.4147918E-04,   1.3643186E-04
     +,   1.3147837E-04,   1.2662286E-04,   1.2186896E-04
     +,   1.1722049E-04,   1.1268023E-04,   1.0825116E-04
     +,   1.0393533E-04,   9.9734920E-05,   9.5651201E-05
     +,   9.1685601E-05,   8.7838584E-05,   8.4110914E-05
     +,   8.0502286E-05,   7.7012781E-05,   7.3641655E-05
     +,   7.0387956E-05,   6.7250701E-05,   6.4228327E-05
     +,   6.1319413E-05,   5.8521866E-05,   5.5833869E-05
     +,   5.3253047E-05,   5.0777209E-05,   4.8403712E-05
     +,   4.6130110E-05,   4.3953609E-05,   4.1871568E-05
     +,   3.9881059E-05,   3.7979360E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt60 = Yx/0.248652173913044
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.2339312E-04,   1.0333931E-03
     +,   1.1518830E-03,   1.2788157E-03,   1.4140256E-03
     +,   1.5572199E-03,   1.7079680E-03,   1.8657009E-03
     +,   2.0297018E-03,   2.1991399E-03,   2.3730833E-03
     +,   2.5505680E-03,   2.7306883E-03,   2.9127332E-03
     +,   3.0963428E-03,   3.2817244E-03,   3.4698474E-03
     +,   3.6626763E-03,   3.8633372E-03,   4.0762457E-03
     +,   4.3071192E-03,   4.5628622E-03,   4.8513194E-03
     +,   5.1808842E-03,   5.5598454E-03,   5.9957253E-03
     +,   6.4942986E-03,   7.0585762E-03,   7.6879179E-03
     +,   8.3775446E-03,   9.1187991E-03,   9.9002775E-03
     +,   1.0709511E-02,   1.1534405E-02,   1.2364007E-02
     +,   1.3188099E-02,   1.3997280E-02,   1.4784146E-02
     +,   1.5546886E-02,   1.6293643E-02,   1.7045282E-02
     +,   1.7833266E-02,   1.8691385E-02,   1.9642193E-02
     +,   2.0682428E-02,   2.1774305E-02,   2.2850344E-02
     +,   2.3832707E-02,   2.4662243E-02,   2.5322365E-02
     +,   2.5845900E-02,   2.6300633E-02,   2.6760001E-02
     +,   2.7271863E-02,   2.7836250E-02,   2.8398668E-02
     +,   2.8858770E-02,   2.9093290E-02,   2.8989183E-02
     +,   2.8480658E-02,   2.7574880E-02,   2.6352607E-02
     +,   2.4940319E-02,   2.3467571E-02,   2.2032136E-02
     +,   2.0686762E-02,   1.9445922E-02,   1.8301809E-02
     +,   1.7237993E-02,   1.6237821E-02,   1.5287764E-02
     +,   1.4378835E-02,   1.3506459E-02,   1.2669772E-02
     +,   1.1869850E-02,   1.1108227E-02,   1.0385958E-02
     +,   9.7032432E-03,   9.0597430E-03,   8.4551238E-03
     +,   7.8895260E-03,   7.3635024E-03,   6.8780300E-03
     +,   6.4338949E-03,   6.0312678E-03,   5.6691766E-03
     +,   5.3454754E-03,   5.0568320E-03,   4.7992622E-03
     +,   4.5684683E-03,   4.3603620E-03,   4.1713454E-03
     +,   3.9984346E-03,   3.8392150E-03,   3.6917496E-03
     +,   3.5544399E-03,   3.4258678E-03,   3.3047590E-03
     +,   3.1899041E-03,   3.0802018E-03,   2.9746389E-03
     +,   2.8723355E-03,   2.7725461E-03,   2.6746914E-03
     +,   2.5783461E-03,   2.4832569E-03,   2.3893320E-03
     +,   2.2966419E-03,   2.2053975E-03,   2.1159379E-03
     +,   2.0287072E-03,   1.9442162E-03,   1.8630138E-03
     +,   1.7856413E-03,   1.7126072E-03,   1.6443420E-03
     +,   1.5811895E-03,   1.5233621E-03,   1.4709648E-03
     +,   1.4239596E-03,   1.3821907E-03,   1.3453907E-03
     +,   1.3131957E-03,   1.2851632E-03,   1.2607959E-03
     +,   1.2395610E-03,   1.2209122E-03,   1.2043068E-03
     +,   1.1892240E-03,   1.1751765E-03,   1.1617215E-03
     +,   1.1484700E-03,   1.1350904E-03,   1.1213110E-03
     +,   1.1069203E-03,   1.0917654E-03,   1.0757492E-03
     +,   1.0588267E-03,   1.0409964E-03,   1.0222974E-03
     +,   1.0028031E-03,   9.8261540E-04,   9.6185488E-04
     +,   9.4065833E-04,   9.1917487E-04,   8.9755462E-04
     +,   8.7594963E-04,   8.5450802E-04,   8.3337171E-04
     +,   8.1266998E-04,   7.9252233E-04,   7.7303307E-04
     +,   7.5429515E-04,   7.3638186E-04,   7.1935350E-04
     +,   7.0325501E-04,   6.8811915E-04,   6.7396217E-04
     +,   6.6078996E-04,   6.4859673E-04,   6.3736696E-04
     +,   6.2707590E-04,   6.1769271E-04,   6.0917973E-04
     +,   6.0149428E-04,   5.9458899E-04,   5.8841496E-04
     +,   5.8292010E-04,   5.7805085E-04,   5.7375245E-04
     +,   5.6997052E-04,   5.6665018E-04,   5.6373706E-04
     +,   5.6117738E-04,   5.5891881E-04,   5.5690954E-04
     +,   5.5510027E-04,   5.5344234E-04,   5.5188965E-04
     +,   5.5039831E-04,   5.4892641E-04,   5.4743415E-04
     +,   5.4588582E-04,   5.4424751E-04,   5.4248865E-04
     +,   5.4058240E-04,   5.3850521E-04,   5.3623703E-04
     +,   5.3376216E-04,   5.3106865E-04,   5.2814814E-04
     +,   5.2499742E-04,   5.2161631E-04,   5.1800959E-04
     +,   5.1418552E-04,   5.1015639E-04,   5.0593808E-04
     +,   5.0155038E-04,   4.9701618E-04,   4.9236068E-04
     +,   4.8761247E-04,   4.8280205E-04,   4.7796156E-04
     +,   4.7312435E-04,   4.6832484E-04,   4.6359721E-04
     +,   4.5897588E-04,   4.5449458E-04,   4.5018530E-04
     +,   4.4607845E-04,   4.4220214E-04,   4.3858125E-04
     +,   4.3523830E-04,   4.3219127E-04,   4.2945446E-04
     +,   4.2703771E-04,   4.2494660E-04,   4.2318145E-04
     +,   4.2173755E-04,   4.2060579E-04,   4.1977142E-04
     +,   4.1921536E-04,   4.1891320E-04,   4.1883637E-04
     +,   4.1895182E-04,   4.1922272E-04,   4.1960907E-04
     +,   4.2006728E-04,   4.2055169E-04,   4.2101502E-04
     +,   4.2140830E-04,   4.2168202E-04,   4.2178680E-04
     +,   4.2167411E-04,   4.2129628E-04,   4.2060803E-04
     +,   4.1956676E-04,   4.1813252E-04,   4.1626938E-04
     +,   4.1394582E-04,   4.1113395E-04,   4.0781184E-04
     +,   4.0396236E-04,   3.9957400E-04,   3.9463997E-04
     +,   3.8916015E-04,   3.8313936E-04,   3.7658770E-04
     +,   3.6952086E-04,   3.6195922E-04,   3.5392819E-04
     +,   3.4545641E-04,   3.3657753E-04,   3.2732860E-04
     +,   3.1774840E-04,   3.0787860E-04,   2.9776269E-04
     +,   2.8744593E-04,   2.7697321E-04,   2.6638989E-04
     +,   2.5574150E-04,   2.4507265E-04,   2.3442613E-04
     +,   2.2384306E-04,   2.1336335E-04,   2.0302375E-04
     +,   1.9285832E-04,   1.8289893E-04,   1.7317434E-04
     +,   1.6370970E-04,   1.5452699E-04,   1.4564543E-04
     +,   1.3708122E-04,   1.2884676E-04,   1.2095144E-04
     +,   1.1340260E-04,   1.0620381E-04,   9.9357028E-05
     +,   9.2860988E-05,   8.6712993E-05,   8.0907666E-05
     +,   7.5438649E-05,   7.0297341E-05,   6.5474538E-05
     +,   6.0959268E-05,   5.6740322E-05,   5.2805313E-05
     +,   4.9141403E-05,   4.5735720E-05,   4.2574800E-05
     +,   3.9645474E-05,   3.6934256E-05,   3.4428213E-05
     +,   3.2114327E-05,   2.9980227E-05,   2.8013661E-05
     +,   2.6203088E-05,   2.4537219E-05,   2.3005523E-05
     +,   2.1597785E-05,   2.0304567E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt65 = Yx/0.301893617021277
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.9558317E-04,   6.3616305E-04
     +,   6.7822990E-04,   7.2182476E-04,   7.6700730E-04
     +,   8.1385660E-04,   8.6247548E-04,   9.1299030E-04
     +,   9.6555531E-04,   1.0203578E-03,   1.0776176E-03
     +,   1.1375945E-03,   1.2005923E-03,   1.2669611E-03
     +,   1.3371021E-03,   1.4114674E-03,   1.4905564E-03
     +,   1.5749120E-03,   1.6651085E-03,   1.7617504E-03
     +,   1.8654637E-03,   1.9768979E-03,   2.0967424E-03
     +,   2.2257683E-03,   2.3648601E-03,   2.5151062E-03
     +,   2.6778644E-03,   2.8548241E-03,   3.0480316E-03
     +,   3.2598539E-03,   3.4928350E-03,   3.7494472E-03
     +,   4.0317578E-03,   4.3410310E-03,   4.6773930E-03
     +,   5.0396388E-03,   5.4253046E-03,   5.8310283E-03
     +,   6.2533109E-03,   6.6892277E-03,   7.1374197E-03
     +,   7.5984243E-03,   8.0746403E-03,   8.5696829E-03
     +,   9.0873390E-03,   9.6306857E-03,   1.0201716E-02
     +,   1.0801516E-02,   1.1430875E-02,   1.2090830E-02
     +,   1.2782988E-02,   1.3509971E-02,   1.4275783E-02
     +,   1.5085577E-02,   1.5942791E-02,   1.6843788E-02
     +,   1.7771697E-02,   1.8694989E-02,   1.9576238E-02
     +,   2.0389764E-02,   2.1139720E-02,   2.1865597E-02
     +,   2.2630114E-02,   2.3496650E-02,   2.4507666E-02
     +,   2.5671568E-02,   2.6957346E-02,   2.8298201E-02
     +,   2.9608635E-02,   3.0809892E-02,   3.1851489E-02
     +,   3.2713320E-02,   3.3393551E-02,   3.3894643E-02
     +,   3.4215756E-02,   3.4348834E-02,   3.4273386E-02
     +,   3.3954479E-02,   3.3347413E-02,   3.2415804E-02
     +,   3.1160291E-02,   2.9641422E-02,   2.7975842E-02
     +,   2.6296463E-02,   2.4702478E-02,   2.3230417E-02
     +,   2.1863841E-02,   2.0564161E-02,   1.9299401E-02
     +,   1.8054815E-02,   1.6829079E-02,   1.5625404E-02
     +,   1.4446004E-02,   1.3291896E-02,   1.2166233E-02
     +,   1.1077427E-02,   1.0039767E-02,   9.0715522E-03
     +,   8.1909960E-03,   7.4121947E-03,   6.7420220E-03
     +,   6.1792312E-03,   5.7151057E-03,   5.3357393E-03
     +,   5.0245430E-03,   4.7648652E-03,   4.5418446E-03
     +,   4.3435320E-03,   4.1611488E-03,   3.9888211E-03
     +,   3.8230165E-03,   3.6618304E-03,   3.5044278E-03
     +,   3.3505931E-03,   3.2004989E-03,   3.0545257E-03
     +,   2.9132117E-03,   2.7771662E-03,   2.6470479E-03
     +,   2.5234667E-03,   2.4069466E-03,   2.2978613E-03
     +,   2.1963939E-03,   2.1025129E-03,   2.0159874E-03
     +,   1.9364272E-03,   1.8632975E-03,   1.7959911E-03
     +,   1.7338556E-03,   1.6762560E-03,   1.6225902E-03
     +,   1.5723294E-03,   1.5250208E-03,   1.4803037E-03
     +,   1.4378973E-03,   1.3976007E-03,   1.3592819E-03
     +,   1.3228599E-03,   1.2882914E-03,   1.2555582E-03
     +,   1.2246560E-03,   1.1955794E-03,   1.1683130E-03
     +,   1.1428265E-03,   1.1190699E-03,   1.0969678E-03
     +,   1.0764205E-03,   1.0573051E-03,   1.0394780E-03
     +,   1.0227773E-03,   1.0070276E-03,   9.9204970E-04
     +,   9.7765902E-04,   9.6367579E-04,   9.4992836E-04
     +,   9.3626155E-04,   9.2253688E-04,   9.0863614E-04
     +,   8.9446653E-04,   8.7996147E-04,   8.6507929E-04
     +,   8.4980478E-04,   8.3414890E-04,   8.1814505E-04
     +,   8.0184848E-04,   7.8533008E-04,   7.6867943E-04
     +,   7.5199699E-04,   7.3538895E-04,   7.1896851E-04
     +,   7.0285070E-04,   6.8714860E-04,   6.7197089E-04
     +,   6.5741915E-04,   6.4358814E-04,   6.3056132E-04
     +,   6.1841035E-04,   6.0719607E-04,   5.9696613E-04
     +,   5.8775599E-04,   5.7958806E-04,   5.7247397E-04
     +,   5.6641432E-04,   5.6139939E-04,   5.5741053E-04
     +,   5.5442192E-04,   5.5240089E-04,   5.5130955E-04
     +,   5.5110594E-04,   5.5174448E-04,   5.5317860E-04
     +,   5.5535865E-04,   5.5823597E-04,   5.6176097E-04
     +,   5.6588487E-04,   5.7055918E-04,   5.7573593E-04
     +,   5.8136799E-04,   5.8740837E-04,   5.9381151E-04
     +,   6.0053053E-04,   6.0751801E-04,   6.1472639E-04
     +,   6.2210654E-04,   6.2960747E-04,   6.3717581E-04
     +,   6.4475636E-04,   6.5229071E-04,   6.5971731E-04
     +,   6.6697283E-04,   6.7399000E-04,   6.8069989E-04
     +,   6.8702997E-04,   6.9290807E-04,   6.9825916E-04
     +,   7.0300867E-04,   7.0708233E-04,   7.1040721E-04
     +,   7.1291329E-04,   7.1453437E-04,   7.1520766E-04
     +,   7.1487756E-04,   7.1349449E-04,   7.1101659E-04
     +,   7.0741138E-04,   7.0265500E-04,   6.9673453E-04
     +,   6.8964687E-04,   6.8140012E-04,   6.7201280E-04
     +,   6.6151487E-04,   6.4994732E-04,   6.3736021E-04
     +,   6.2381278E-04,   6.0937408E-04,   5.9412024E-04
     +,   5.7813275E-04,   5.6150008E-04,   5.4431480E-04
     +,   5.2667066E-04,   5.0866342E-04,   4.9038976E-04
     +,   4.7194507E-04,   4.5342190E-04,   4.3490846E-04
     +,   4.1649071E-04,   3.9824861E-04,   3.8025569E-04
     +,   3.6257802E-04,   3.4527757E-04,   3.2840643E-04
     +,   3.1200994E-04,   2.9612688E-04,   2.8078881E-04
     +,   2.6601931E-04,   2.5183530E-04,   2.3824825E-04
     +,   2.2526411E-04,   2.1288230E-04,   2.0109779E-04
     +,   1.8990214E-04,   1.7928319E-04,   1.6922510E-04
     +,   1.5970960E-04,   1.5071752E-04,   1.4222706E-04
     +,   1.3421572E-04,   1.2666071E-04,   1.1953912E-04
     +,   1.1282739E-04,   1.0650244E-04,   1.0054218E-04
     +,   9.4925104E-05,   8.9630157E-05,   8.4637359E-05
     +,   7.9928141E-05,   7.5484342E-05,   7.1289585E-05
     +,   6.7327819E-05,   6.3584717E-05,   6.0046426E-05
     +,   5.6700450E-05,   5.3534914E-05,   5.0539107E-05
     +,   4.7702797E-05,   4.5016852E-05,   4.2472577E-05
     +,   4.0061925E-05,   3.7777649E-05,   3.5612753E-05
     +,   3.3561006E-05,   3.1616306E-05,   2.9773297E-05
     +,   2.8026649E-05,   2.6371648E-05,   2.4803623E-05
     +,   2.3318415E-05,   2.1911881E-05,   2.0580314E-05
     +,   1.9320016E-05,   1.8127668E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt70 = Yx/0.352714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4643028E-04,   2.6670611E-04
     +,   2.8858683E-04,   3.1222115E-04,   3.3777510E-04
     +,   3.6543290E-04,   3.9539486E-04,   4.2787526E-04
     +,   4.6309692E-04,   5.0128700E-04,   5.4266612E-04
     +,   5.8743951E-04,   6.3578546E-04,   6.8784284E-04
     +,   7.4369903E-04,   8.0337812E-04,   8.6683023E-04
     +,   9.3392609E-04,   1.0044528E-03,   1.0781167E-03
     +,   1.1545529E-03,   1.2333357E-03,   1.3140050E-03
     +,   1.3960997E-03,   1.4791813E-03,   1.5628986E-03
     +,   1.6470248E-03,   1.7315160E-03,   1.8165775E-03
     +,   1.9027004E-03,   1.9907174E-03,   2.0818121E-03
     +,   2.1775216E-03,   2.2796902E-03,   2.3903933E-03
     +,   2.5118063E-03,   2.6460730E-03,   2.7951009E-03
     +,   2.9604174E-03,   3.1429625E-03,   3.3429894E-03
     +,   3.5599491E-03,   3.7924577E-03,   4.0383148E-03
     +,   4.2945715E-03,   4.5576356E-03,   4.8234384E-03
     +,   5.0876634E-03,   5.3460645E-03,   5.5949115E-03
     +,   5.8315839E-03,   6.0552591E-03,   6.2676924E-03
     +,   6.4738845E-03,   6.6823685E-03,   6.9051501E-03
     +,   7.1567623E-03,   7.4526989E-03,   7.8071337E-03
     +,   8.2305139E-03,   8.7278653E-03,   9.2988936E-03
     +,   9.9410471E-03,   1.0655564E-02,   1.1454650E-02
     +,   1.2365565E-02,   1.3426609E-02,   1.4671446E-02
     +,   1.6107274E-02,   1.7698348E-02,   1.9370738E-02
     +,   2.1040902E-02,   2.2657072E-02,   2.4226723E-02
     +,   2.5812054E-02,   2.7488118E-02,   2.9280037E-02
     +,   3.1114750E-02,   3.2832660E-02,   3.4281988E-02
     +,   3.5443377E-02,   3.6463730E-02,   3.7522666E-02
     +,   3.8642209E-02,   3.9658464E-02,   4.0408857E-02
     +,   4.0923804E-02,   4.1430037E-02,   4.2210452E-02
     +,   4.3447558E-02,   4.5097712E-02,   4.6852987E-02
     +,   4.8263192E-02,   4.8952989E-02,   4.8783615E-02
     +,   4.7864098E-02,   4.6420164E-02,   4.4606987E-02
     +,   4.2416375E-02,   3.9772529E-02,   3.6715828E-02
     +,   3.3459894E-02,   3.0269880E-02,   2.7323423E-02
     +,   2.4676602E-02,   2.2305040E-02,   2.0150404E-02
     +,   1.8156836E-02,   1.6297234E-02,   1.4579390E-02
     +,   1.3029935E-02,   1.1672133E-02,   1.0514019E-02
     +,   9.5469048E-03,   8.7496806E-03,   8.0932984E-03
     +,   7.5452831E-03,   7.0736744E-03,   6.6510472E-03
     +,   6.2571000E-03,   5.8796941E-03,   5.5140592E-03
     +,   5.1607215E-03,   4.8230328E-03,   4.5050122E-03
     +,   4.2099464E-03,   3.9394996E-03,   3.6937615E-03
     +,   3.4714018E-03,   3.2702188E-03,   3.0875569E-03
     +,   2.9207848E-03,   2.7675086E-03,   2.6258086E-03
     +,   2.4942160E-03,   2.3717075E-03,   2.2576051E-03
     +,   2.1514695E-03,   2.0529667E-03,   1.9618061E-03
     +,   1.8776787E-03,   1.8002144E-03,   1.7289817E-03
     +,   1.6634865E-03,   1.6032020E-03,   1.5475737E-03
     +,   1.4960507E-03,   1.4481037E-03,   1.4032364E-03
     +,   1.3610016E-03,   1.3210027E-03,   1.2829106E-03
     +,   1.2464565E-03,   1.2114313E-03,   1.1776829E-03
     +,   1.1451136E-03,   1.1136706E-03,   1.0833332E-03
     +,   1.0541088E-03,   1.0260233E-03,   9.9911203E-04
     +,   9.7341096E-04,   9.4895402E-04,   9.2577055E-04
     +,   9.0387481E-04,   8.8327186E-04,   8.6395524E-04
     +,   8.4590918E-04,   8.2910579E-04,   8.1351137E-04
     +,   7.9908816E-04,   7.8579475E-04,   7.7358808E-04
     +,   7.6242664E-04,   7.5227040E-04,   7.4308173E-04
     +,   7.3482585E-04,   7.2747108E-04,   7.2098750E-04
     +,   7.1534677E-04,   7.1052019E-04,   7.0647936E-04
     +,   7.0319430E-04,   7.0063106E-04,   6.9875328E-04
     +,   6.9751957E-04,   6.9688424E-04,   6.9679564E-04
     +,   6.9719786E-04,   6.9802930E-04,   6.9922465E-04
     +,   7.0071383E-04,   7.0242328E-04,   7.0427818E-04
     +,   7.0620113E-04,   7.0811546E-04,   7.0994406E-04
     +,   7.1161136E-04,   7.1304530E-04,   7.1417616E-04
     +,   7.1493891E-04,   7.1527256E-04,   7.1512238E-04
     +,   7.1443821E-04,   7.1317708E-04,   7.1130175E-04
     +,   7.0878054E-04,   7.0558931E-04,   7.0170994E-04
     +,   6.9712952E-04,   6.9184118E-04,   6.8584445E-04
     +,   6.7914330E-04,   6.7174732E-04,   6.6366972E-04
     +,   6.5492868E-04,   6.4554671E-04,   6.3554931E-04
     +,   6.2496465E-04,   6.1382540E-04,   6.0216512E-04
     +,   5.9002044E-04,   5.7743030E-04,   5.6443526E-04
     +,   5.5107684E-04,   5.3739717E-04,   5.2344077E-04
     +,   5.0925172E-04,   4.9487426E-04,   4.8035246E-04
     +,   4.6573012E-04,   4.5105169E-04,   4.3635853E-04
     +,   4.2169195E-04,   4.0709219E-04,   3.9259664E-04
     +,   3.7824109E-04,   3.6405967E-04,   3.5008453E-04
     +,   3.3634383E-04,   3.2286334E-04,   3.0966738E-04
     +,   2.9677679E-04,   2.8420912E-04,   2.7197914E-04
     +,   2.6009939E-04,   2.4857989E-04,   2.3742720E-04
     +,   2.2664558E-04,   2.1623782E-04,   2.0620377E-04
     +,   1.9654095E-04,   1.8724617E-04,   1.7831457E-04
     +,   1.6973904E-04,   1.6151175E-04,   1.5362412E-04
     +,   1.4606690E-04,   1.3882990E-04,   1.3190233E-04
     +,   1.2527371E-04,   1.1893345E-04,   1.1287033E-04
     +,   1.0707367E-04,   1.0153313E-04,   9.6238276E-05
     +,   9.1179070E-05,   8.6346066E-05,   8.1730272E-05
     +,   7.7322788E-05,   7.3115196E-05,   6.9099689E-05
     +,   6.5268927E-05,   6.1615734E-05,   5.8133224E-05
     +,   5.4815278E-05,   5.1655639E-05,   4.8648762E-05
     +,   4.5788929E-05,   4.3071072E-05,   4.0489933E-05
     +,   3.8040820E-05,   3.5718822E-05,   3.3519478E-05
     +,   3.1438176E-05,   2.9470630E-05,   2.7612472E-05
     +,   2.5859410E-05,   2.4207395E-05,   2.2652206E-05
     +,   2.1189880E-05,   1.9816331E-05,   1.8527711E-05
     +,   1.7320042E-05,   1.6189595E-05,   1.5132536E-05
     +,   1.4145252E-05,   1.3224075E-05,   1.2365537E-05
     +,   1.1566150E-05,   1.0822623E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt75 = Yx/0.44464
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0128084E-04,   2.1070814E-04
     +,   2.2032364E-04,   2.3012265E-04,   2.4010113E-04
     +,   2.5025688E-04,   2.6058889E-04,   2.7109790E-04
     +,   2.8178663E-04,   2.9265994E-04,   3.0372452E-04
     +,   3.1498939E-04,   3.2646561E-04,   3.3816657E-04
     +,   3.5010796E-04,   3.6230779E-04,   3.7478612E-04
     +,   3.8756579E-04,   4.0067179E-04,   4.1413269E-04
     +,   4.2797968E-04,   4.4224897E-04,   4.5698063E-04
     +,   4.7222266E-04,   4.8802845E-04,   5.0446350E-04
     +,   5.2160356E-04,   5.3953892E-04,   5.5837713E-04
     +,   5.7824538E-04,   5.9929321E-04,   6.2169484E-04
     +,   6.4565259E-04,   6.7139696E-04,   6.9918722E-04
     +,   7.2931161E-04,   7.6208613E-04,   7.9784769E-04
     +,   8.3695608E-04,   8.7977457E-04,   9.2667463E-04
     +,   9.7801315E-04,   1.0341239E-03,   1.0952983E-03
     +,   1.1617661E-03,   1.2336776E-03,   1.3110783E-03
     +,   1.3938915E-03,   1.4819014E-03,   1.5747461E-03
     +,   1.6719212E-03,   1.7728066E-03,   1.8767087E-03
     +,   1.9829511E-03,   2.0909538E-03,   2.2003923E-03
     +,   2.3113096E-03,   2.4242573E-03,   2.5403877E-03
     +,   2.6614768E-03,   2.7898499E-03,   2.9282246E-03
     +,   3.0794442E-03,   3.2461905E-03,   3.4307165E-03
     +,   3.6346572E-03,   3.8590701E-03,   4.1045733E-03
     +,   4.3717534E-03,   4.6615358E-03,   4.9756370E-03
     +,   5.3168009E-03,   5.6889085E-03,   6.0966229E-03
     +,   6.5447381E-03,   7.0370068E-03,   7.5745839E-03
     +,   8.1548085E-03,   8.7710293E-03,   9.4143469E-03
     +,   1.0077397E-02,   1.0759537E-02,   1.1470519E-02
     +,   1.2230411E-02,   1.3063747E-02,   1.3990444E-02
     +,   1.5018289E-02,   1.6144080E-02,   1.7363159E-02
     +,   1.8679311E-02,   2.0099971E-02,   2.1611903E-02
     +,   2.3160767E-02,   2.4675250E-02,   2.6148161E-02
     +,   2.7710296E-02,   2.9592574E-02,   3.1955529E-02
     +,   3.4730501E-02,   3.7633806E-02,   4.0353995E-02
     +,   4.2764254E-02,   4.5045421E-02,   4.7646660E-02
     +,   5.1014155E-02,   5.5098232E-02,   5.9028346E-02
     +,   6.1643913E-02,   6.2714577E-02,   6.3249856E-02
     +,   6.4116396E-02,   6.4854473E-02,   6.4476274E-02
     +,   6.2899858E-02,   6.0828570E-02,   5.8595177E-02
     +,   5.5919901E-02,   5.2611437E-02,   4.8863862E-02
     +,   4.4908065E-02,   4.0777165E-02,   3.6484383E-02
     +,   3.2211404E-02,   2.8200632E-02,   2.4575969E-02
     +,   2.1355642E-02,   1.8562037E-02,   1.6242273E-02
     +,   1.4403688E-02,   1.2976035E-02,   1.1839009E-02
     +,   1.0875748E-02,   1.0005781E-02,   9.1879545E-03
     +,   8.4071802E-03,   7.6614372E-03,   6.9546038E-03
     +,   6.2932777E-03,   5.6847376E-03,   5.1351013E-03
     +,   4.6477024E-03,   4.2223525E-03,   3.8556037E-03
     +,   3.5417057E-03,   3.2737455E-03,   3.0445508E-03
     +,   2.8474003E-03,   2.6764115E-03,   2.5266716E-03
     +,   2.3942050E-03,   2.2758725E-03,   2.1692223E-03
     +,   2.0723280E-03,   1.9836458E-03,   1.9019098E-03
     +,   1.8260631E-03,   1.7551981E-03,   1.6885278E-03
     +,   1.6253684E-03,   1.5651420E-03,   1.5073619E-03
     +,   1.4516367E-03,   1.3976741E-03,   1.3452717E-03
     +,   1.2943085E-03,   1.2447452E-03,   1.1966126E-03
     +,   1.1500036E-03,   1.1050516E-03,   1.0619222E-03
     +,   1.0208049E-03,   9.8189444E-04,   9.4537542E-04
     +,   9.1141649E-04,   8.8015792E-04,   8.5170340E-04
     +,   8.2611374E-04,   8.0340618E-04,   7.8354985E-04
     +,   7.6646713E-04,   7.5203710E-04,   7.4009987E-04
     +,   7.3046156E-04,   7.2290009E-04,   7.1717362E-04
     +,   7.1302574E-04,   7.1019563E-04,   7.0842076E-04
     +,   7.0744602E-04,   7.0702797E-04,   7.0694013E-04
     +,   7.0697459E-04,   7.0694840E-04,   7.0670061E-04
     +,   7.0609723E-04,   7.0502947E-04,   7.0341420E-04
     +,   7.0119114E-04,   6.9832260E-04,   6.9479109E-04
     +,   6.9059746E-04,   6.8575551E-04,   6.8029424E-04
     +,   6.7424990E-04,   6.6766742E-04,   6.6059607E-04
     +,   6.5308664E-04,   6.4519059E-04,   6.3695863E-04
     +,   6.2843779E-04,   6.1967026E-04,   6.1069417E-04
     +,   6.0154236E-04,   5.9224089E-04,   5.8280973E-04
     +,   5.7326438E-04,   5.6361436E-04,   5.5386429E-04
     +,   5.4401468E-04,   5.3406326E-04,   5.2400521E-04
     +,   5.1383296E-04,   5.0353963E-04,   4.9311813E-04
     +,   4.8256066E-04,   4.7186192E-04,   4.6101824E-04
     +,   4.5002881E-04,   4.3889441E-04,   4.2761929E-04
     +,   4.1621103E-04,   4.0468050E-04,   3.9304121E-04
     +,   3.8130893E-04,   3.6950407E-04,   3.5764783E-04
     +,   3.4576375E-04,   3.3387783E-04,   3.2201729E-04
     +,   3.1021002E-04,   2.9848365E-04,   2.8686717E-04
     +,   2.7538891E-04,   2.6407596E-04,   2.5295425E-04
     +,   2.4204866E-04,   2.3138266E-04,   2.2097700E-04
     +,   2.1084999E-04,   2.0101872E-04,   1.9149701E-04
     +,   1.8229564E-04,   1.7342417E-04,   1.6488887E-04
     +,   1.5669341E-04,   1.4883895E-04,   1.4132493E-04
     +,   1.3414885E-04,   1.2730554E-04,   1.2078822E-04
     +,   1.1458923E-04,   1.0869931E-04,   1.0310789E-04
     +,   9.7803466E-05,   9.2774368E-05,   8.8008048E-05
     +,   8.3491563E-05,   7.9212165E-05,   7.5157259E-05
     +,   7.1313982E-05,   6.7669869E-05,   6.4213069E-05
     +,   6.0932234E-05,   5.7816247E-05,   5.4854700E-05
     +,   5.2038027E-05,   4.9357011E-05,   4.6803343E-05
     +,   4.4369117E-05,   4.2047330E-05,   3.9831310E-05
     +,   3.7715250E-05,   3.5693596E-05,   3.3761618E-05
     +,   3.1914726E-05,   3.0149082E-05,   2.8461009E-05
     +,   2.6847170E-05,   2.5304729E-05,   2.3830877E-05
     +,   2.2423235E-05,   2.1079430E-05,   1.9797424E-05
     +,   1.8575151E-05,   1.7410819E-05,   1.6302547E-05
     +,   1.5248691E-05,   1.4247501E-05,   1.3297410E-05
     +,   1.2396737E-05,   1.1543952E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt80 = Yx/0.496039215686275
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5050423E-05,   6.6642198E-05
     +,   6.8272187E-05,   6.9944734E-05,   7.1664253E-05
     +,   7.3435418E-05,   7.5262848E-05,   7.7151264E-05
     +,   7.9105368E-05,   8.1129860E-05,   8.3229323E-05
     +,   8.5408152E-05,   8.7670720E-05,   9.0021087E-05
     +,   9.2463219E-05,   9.5000854E-05,   9.7637625E-05
     +,   1.0037696E-04,   1.0322229E-04,   1.0617696E-04
     +,   1.0924449E-04,   1.1242857E-04,   1.1573311E-04
     +,   1.1916296E-04,   1.2272295E-04,   1.2641953E-04
     +,   1.3025981E-04,   1.3425229E-04,   1.3840712E-04
     +,   1.4273608E-04,   1.4725303E-04,   1.5197384E-04
     +,   1.5691678E-04,   1.6210235E-04,   1.6755365E-04
     +,   1.7329599E-04,   1.7935687E-04,   1.8576579E-04
     +,   1.9255422E-04,   1.9975415E-04,   2.0739892E-04
     +,   2.1552132E-04,   2.2415341E-04,   2.3332535E-04
     +,   2.4306485E-04,   2.5339573E-04,   2.6433711E-04
     +,   2.7590303E-04,   2.8810094E-04,   3.0093206E-04
     +,   3.1439052E-04,   3.2846458E-04,   3.4313658E-04
     +,   3.5838684E-04,   3.7419226E-04,   3.9053461E-04
     +,   4.0740159E-04,   4.2479445E-04,   4.4273483E-04
     +,   4.6127199E-04,   4.8049315E-04,   5.0053315E-04
     +,   5.2158243E-04,   5.4389978E-04,   5.6781870E-04
     +,   5.9375149E-04,   6.2219548E-04,   6.5372471E-04
     +,   6.8898883E-04,   7.2868838E-04,   7.7356515E-04
     +,   8.2436058E-04,   8.8179554E-04,   9.4652164E-04
     +,   1.0190990E-03,   1.0999629E-03,   1.1894029E-03
     +,   1.2875638E-03,   1.3944689E-03,   1.5100533E-03
     +,   1.6342051E-03,   1.7668549E-03,   1.9080073E-03
     +,   2.0578338E-03,   2.2166728E-03,   2.3850834E-03
     +,   2.5638067E-03,   2.7537949E-03,   2.9561690E-03
     +,   3.1722842E-03,   3.4037663E-03,   3.6525829E-03
     +,   3.9211293E-03,   4.2123110E-03,   4.5294878E-03
     +,   4.8763379E-03,   5.2567492E-03,   5.6744884E-03
     +,   6.1331582E-03,   6.6362415E-03,   7.1879546E-03
     +,   7.7944393E-03,   8.4653208E-03,   9.2134727E-03
     +,   1.0051735E-02,   1.0985569E-02,   1.2004333E-02
     +,   1.3078053E-02,   1.4168070E-02,   1.5255941E-02
     +,   1.6380502E-02,   1.7652290E-02,   1.9210801E-02
     +,   2.1136874E-02,   2.3393216E-02,   2.5851630E-02
     +,   2.8365333E-02,   3.0835949E-02,   3.3315443E-02
     +,   3.6085397E-02,   3.9421991E-02,   4.3097556E-02
     +,   4.6385456E-02,   4.8901565E-02,   5.1109541E-02
     +,   5.3517319E-02,   5.5882268E-02,   5.7916410E-02
     +,   6.0326766E-02,   6.4579673E-02,   7.1183488E-02
     +,   7.8525081E-02,   8.4875941E-02,   8.9286983E-02
     +,   9.0181388E-02,   8.7375931E-02,   8.2807600E-02
     +,   7.7579170E-02,   7.1791522E-02,   6.5874852E-02
     +,   5.9871785E-02,   5.3101089E-02,   4.5492232E-02
     +,   3.8050171E-02,   3.1787466E-02,   2.6861889E-02
     +,   2.2850584E-02,   1.9415392E-02,   1.6493065E-02
     +,   1.4103807E-02,   1.2208210E-02,   1.0712405E-02
     +,   9.5169498E-03,   8.5426886E-03,   7.7333641E-03
     +,   7.0499312E-03,   6.4643677E-03,   5.9553003E-03
     +,   5.5053649E-03,   5.1000956E-03,   4.7276858E-03
     +,   4.3793172E-03,   4.0493160E-03,   3.7348762E-03
     +,   3.4353561E-03,   3.1515297E-03,   2.8848464E-03
     +,   2.6368434E-03,   2.4087843E-03,   2.2014889E-03
     +,   2.0153010E-03,   1.8500923E-03,   1.7053236E-03
     +,   1.5801323E-03,   1.4734233E-03,   1.3838959E-03
     +,   1.3101147E-03,   1.2505489E-03,   1.2036115E-03
     +,   1.1676847E-03,   1.1411679E-03,   1.1225092E-03
     +,   1.1102336E-03,   1.1029664E-03,   1.0994528E-03
     +,   1.0985711E-03,   1.0993325E-03,   1.1008868E-03
     +,   1.1025119E-03,   1.1036107E-03,   1.1036985E-03
     +,   1.1023928E-03,   1.0994051E-03,   1.0945268E-03
     +,   1.0876229E-03,   1.0786194E-03,   1.0675002E-03
     +,   1.0542970E-03,   1.0390833E-03,   1.0219692E-03
     +,   1.0030983E-03,   9.8264101E-04,   9.6078851E-04
     +,   9.3774905E-04,   9.1374526E-04,   8.8900456E-04
     +,   8.6375506E-04,   8.3822402E-04,   8.1262947E-04
     +,   7.8717468E-04,   7.6204509E-04,   7.3740684E-04
     +,   7.1340107E-04,   6.9014094E-04,   6.6771382E-04
     +,   6.4617768E-04,   6.2556530E-04,   6.0588162E-04
     +,   5.8710645E-04,   5.6920201E-04,   5.5210892E-04
     +,   5.3575513E-04,   5.2005757E-04,   5.0492643E-04
     +,   4.9026753E-04,   4.7598674E-04,   4.6199423E-04
     +,   4.4820522E-04,   4.3454359E-04,   4.2094223E-04
     +,   4.0734708E-04,   3.9371566E-04,   3.8001777E-04
     +,   3.6623570E-04,   3.5236578E-04,   3.3841393E-04
     +,   3.2439709E-04,   3.1034206E-04,   2.9628372E-04
     +,   2.8226225E-04,   2.6832265E-04,   2.5451428E-04
     +,   2.4088782E-04,   2.2749377E-04,   2.1438110E-04
     +,   2.0159784E-04,   1.8918845E-04,   1.7719224E-04
     +,   1.6564394E-04,   1.5457401E-04,   1.4400613E-04
     +,   1.3395815E-04,   1.2444274E-04,   1.1546686E-04
     +,   1.0703136E-04,   9.9132158E-05,   9.1760987E-05
     +,   8.4905412E-05,   7.8548946E-05,   7.2672112E-05
     +,   6.7253415E-05,   6.2269362E-05,   5.7694786E-05
     +,   5.3503725E-05,   4.9670231E-05,   4.6167945E-05
     +,   4.2970896E-05,   4.0054092E-05,   3.7393376E-05
     +,   3.4965578E-05,   3.2748834E-05,   3.0722818E-05
     +,   2.8868651E-05,   2.7168815E-05,   2.5607287E-05
     +,   2.4169645E-05,   2.2842676E-05,   2.1614702E-05
     +,   2.0475107E-05,   1.9414625E-05,   1.8424915E-05
     +,   1.7498765E-05,   1.6629725E-05,   1.5812262E-05
     +,   1.5041463E-05,   1.4313137E-05,   1.3623580E-05
     +,   1.2969581E-05,   1.2348418E-05,   1.1757635E-05
     +,   1.1195185E-05,   1.0659202E-05,   1.0148124E-05
     +,   9.6605027E-06,   9.1951242E-06,   8.7508379E-06
     +,   8.3266714E-06,   7.9216870E-06,   7.5350745E-06
     +,   7.1660343E-06,   6.8138729E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt85 = Yx/0.53378431372549
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.9533748E-05,   6.0858245E-05
     +,   6.2181120E-05,   6.3501822E-05,   6.4819847E-05
     +,   6.6134853E-05,   6.7446526E-05,   6.8754758E-05
     +,   7.0059446E-05,   7.1360773E-05,   7.2658957E-05
     +,   7.3954368E-05,   7.5247583E-05,   7.6539305E-05
     +,   7.7830387E-05,   7.9121943E-05,   8.0415244E-05
     +,   8.1711703E-05,   8.3012950E-05,   8.4320927E-05
     +,   8.5637679E-05,   8.6965556E-05,   8.8307032E-05
     +,   8.9665104E-05,   9.1042719E-05,   9.2443399E-05
     +,   9.3870811E-05,   9.5328956E-05,   9.6822310E-05
     +,   9.8355609E-05,   9.9934077E-05,   1.0156336E-04
     +,   1.0324947E-04,   1.0499910E-04,   1.0681925E-04
     +,   1.0871766E-04,   1.1070245E-04,   1.1278240E-04
     +,   1.1496692E-04,   1.1726581E-04,   1.1968963E-04
     +,   1.2224932E-04,   1.2495636E-04,   1.2782260E-04
     +,   1.3086031E-04,   1.3408186E-04,   1.3749984E-04
     +,   1.4112683E-04,   1.4497509E-04,   1.4905659E-04
     +,   1.5338266E-04,   1.5796394E-04,   1.6280978E-04
     +,   1.6792877E-04,   1.7332725E-04,   1.7901041E-04
     +,   1.8498130E-04,   1.9124053E-04,   1.9778647E-04
     +,   2.0461500E-04,   2.1171916E-04,   2.1908939E-04
     +,   2.2671308E-04,   2.3457501E-04,   2.4265794E-04
     +,   2.5094106E-04,   2.5940273E-04,   2.6801808E-04
     +,   2.7676229E-04,   2.8560837E-04,   2.9453050E-04
     +,   3.0350147E-04,   3.1249688E-04,   3.2149252E-04
     +,   3.3046809E-04,   3.3940584E-04,   3.4829220E-04
     +,   3.5711852E-04,   3.6588171E-04,   3.7458600E-04
     +,   3.8324090E-04,   3.9186544E-04,   4.0048594E-04
     +,   4.0913874E-04,   4.1786893E-04,   4.2673320E-04
     +,   4.3579863E-04,   4.4514568E-04,   4.5486673E-04
     +,   4.6507016E-04,   4.7587944E-04,   4.8743474E-04
     +,   4.9989467E-04,   5.1343767E-04,   5.2826357E-04
     +,   5.4459082E-04,   5.6266185E-04,   5.8273680E-04
     +,   6.0509873E-04,   6.3004612E-04,   6.5789808E-04
     +,   6.8898557E-04,   7.2366220E-04,   7.6229533E-04
     +,   8.0528023E-04,   8.5305027E-04,   9.0608496E-04
     +,   9.6493389E-04,   1.0302466E-03,   1.1027935E-03
     +,   1.1834812E-03,   1.2733765E-03,   1.3736781E-03
     +,   1.4856919E-03,   1.6107288E-03,   1.7500136E-03
     +,   1.9044998E-03,   2.0747359E-03,   2.2606556E-03
     +,   2.4614860E-03,   2.6756595E-03,   2.9008195E-03
     +,   3.1339969E-03,   3.3719358E-03,   3.6116508E-03
     +,   3.8512473E-03,   4.0911450E-03,   4.3354053E-03
     +,   4.5931102E-03,   4.8789992E-03,   5.2129193E-03
     +,   5.6174616E-03,   6.1145034E-03,   6.7222659E-03
     +,   7.4560251E-03,   8.3341785E-03,   9.3878889E-03
     +,   1.0667725E-02,   1.2238891E-02,   1.4161079E-02
     +,   1.6457602E-02,   1.9084450E-02,   2.1914836E-02
     +,   2.4759959E-02,   2.7440637E-02,   2.9885026E-02
     +,   3.2207146E-02,   3.4773760E-02,   3.8229767E-02
     +,   4.3167282E-02,   4.9271941E-02,   5.5108223E-02
     +,   5.9682440E-02,   6.3694127E-02,   6.8449125E-02
     +,   7.4635513E-02,   8.1901804E-02,   8.8391803E-02
     +,   9.2434615E-02,   9.4250269E-02,   9.3659073E-02
     +,   8.9684092E-02,   8.3130918E-02,   7.6318234E-02
     +,   7.0244662E-02,   6.3835405E-02,   5.6254271E-02
     +,   4.8063710E-02,   4.0194914E-02,   3.3156738E-02
     +,   2.7117675E-02,   2.2058250E-02,   1.7877338E-02
     +,   1.4508148E-02,   1.1919733E-02,   1.0049597E-02
     +,   8.7874569E-03,   8.0134077E-03,   7.6301470E-03
     +,   7.5632334E-03,   7.7455202E-03,   8.1063276E-03
     +,   8.5711209E-03,   9.0671862E-03,   9.5297731E-03
     +,   9.9061299E-03,   1.0157482E-02,   1.0259495E-02
     +,   1.0202482E-02,   9.9911429E-03,   9.6438434E-03
     +,   9.1902185E-03,   8.6671533E-03,   8.1131067E-03
     +,   7.5623100E-03,   7.0402008E-03,   6.5613384E-03
     +,   6.1298748E-03,   5.7422188E-03,   5.3906362E-03
     +,   5.0666705E-03,   4.7634114E-03,   4.4764937E-03
     +,   4.2040176E-03,   3.9457832E-03,   3.7022652E-03
     +,   3.4738714E-03,   3.2605010E-03,   3.0614228E-03
     +,   2.8754170E-03,   2.7010376E-03,   2.5368656E-03
     +,   2.3816673E-03,   2.2344457E-03,   2.0944653E-03
     +,   1.9612079E-03,   1.8343045E-03,   1.7134827E-03
     +,   1.5985377E-03,   1.4893264E-03,   1.3857333E-03
     +,   1.2876751E-03,   1.1950937E-03,   1.1079408E-03
     +,   1.0261518E-03,   9.4964082E-04,   8.7829016E-04
     +,   8.1193604E-04,   7.5036433E-04,   6.9331960E-04
     +,   6.4051710E-04,   5.9165224E-04,   5.4640946E-04
     +,   5.0447893E-04,   4.6557284E-04,   4.2942245E-04
     +,   3.9578936E-04,   3.6446741E-04,   3.3527965E-04
     +,   3.0807458E-04,   2.8272343E-04,   2.5911778E-04
     +,   2.3716278E-04,   2.1677224E-04,   1.9786684E-04
     +,   1.8037224E-04,   1.6421634E-04,   1.4932689E-04
     +,   1.3563246E-04,   1.2306304E-04,   1.1154814E-04
     +,   1.0101820E-04,   9.1405986E-05,   8.2646031E-05
     +,   7.4674732E-05,   6.7431334E-05,   6.0858732E-05
     +,   5.4902874E-05,   4.9512659E-05,   4.4640383E-05
     +,   4.0241957E-05,   3.6276364E-05,   3.2705364E-05
     +,   2.9493593E-05,   2.6608719E-05,   2.4020608E-05
     +,   2.1701509E-05,   1.9626055E-05,   1.7770884E-05
     +,   1.6114434E-05,   1.4636947E-05,   1.3320444E-05
     +,   1.2148472E-05,   1.1105948E-05,   1.0179160E-05
     +,   9.3557364E-06,   8.6243444E-06,   7.9748452E-06
     +,   7.3979900E-06,   6.8855315E-06,   6.4299920E-06
     +,   6.0247235E-06,   5.6637250E-06,   5.3416866E-06
     +,   5.0538315E-06,   4.7959534E-06,   4.5642942E-06
     +,   4.3555242E-06,   4.1667236E-06,   3.9952929E-06
     +,   3.8389703E-06,   3.6957463E-06,   3.5638820E-06
     +,   3.4418449E-06,   3.3283134E-06,   3.2221271E-06
     +,   3.1222949E-06,   3.0279496E-06,   2.9383573E-06
     +,   2.8528780E-06,   2.7709773E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt90 = Yx/0.518823529411765
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3572127E-05,   3.5331217E-05
     +,   3.7156566E-05,   3.9048671E-05,   4.1007846E-05
     +,   4.3034266E-05,   4.5127839E-05,   4.7288348E-05
     +,   4.9515260E-05,   5.1808020E-05,   5.4165655E-05
     +,   5.6587116E-05,   5.9071132E-05,   6.1616185E-05
     +,   6.4220636E-05,   6.6882676E-05,   6.9600283E-05
     +,   7.2371447E-05,   7.5193871E-05,   7.8065321E-05
     +,   8.0983424E-05,   8.3945844E-05,   8.6950131E-05
     +,   8.9994108E-05,   9.3075265E-05,   9.6191550E-05
     +,   9.9340738E-05,   1.0252091E-04,   1.0573012E-04
     +,   1.0896667E-04,   1.1222901E-04,   1.1551564E-04
     +,   1.1882532E-04,   1.2215694E-04,   1.2550940E-04
     +,   1.2888180E-04,   1.3227323E-04,   1.3568283E-04
     +,   1.3910991E-04,   1.4255327E-04,   1.4601210E-04
     +,   1.4948528E-04,   1.5297135E-04,   1.5646870E-04
     +,   1.5997545E-04,   1.6348947E-04,   1.6700801E-04
     +,   1.7052816E-04,   1.7404644E-04,   1.7755917E-04
     +,   1.8106199E-04,   1.8455018E-04,   1.8801888E-04
     +,   1.9146285E-04,   1.9487631E-04,   1.9825369E-04
     +,   2.0158936E-04,   2.0487755E-04,   2.0811283E-04
     +,   2.1129033E-04,   2.1440546E-04,   2.1745446E-04
     +,   2.2043465E-04,   2.2334409E-04,   2.2618292E-04
     +,   2.2895196E-04,   2.3165416E-04,   2.3429441E-04
     +,   2.3687958E-04,   2.3941860E-04,   2.4192296E-04
     +,   2.4440634E-04,   2.4688497E-04,   2.4937754E-04
     +,   2.5190515E-04,   2.5449146E-04,   2.5716214E-04
     +,   2.5994517E-04,   2.6287089E-04,   2.6597132E-04
     +,   2.6927993E-04,   2.7283235E-04,   2.7666509E-04
     +,   2.8081611E-04,   2.8532415E-04,   2.9022942E-04
     +,   2.9557204E-04,   3.0139359E-04,   3.0773538E-04
     +,   3.1463950E-04,   3.2214817E-04,   3.3030313E-04
     +,   3.3914522E-04,   3.4871505E-04,   3.5905099E-04
     +,   3.7018844E-04,   3.8215984E-04,   3.9499137E-04
     +,   4.0870399E-04,   4.2330896E-04,   4.3880852E-04
     +,   4.5519107E-04,   4.7243261E-04,   4.9049011E-04
     +,   5.0930417E-04,   5.2879611E-04,   5.4886460E-04
     +,   5.6938722E-04,   5.9022231E-04,   6.1120826E-04
     +,   6.3216424E-04,   6.5289799E-04,   6.7320443E-04
     +,   6.9287675E-04,   7.1170728E-04,   7.2949927E-04
     +,   7.4606907E-04,   7.6126022E-04,   7.7494502E-04
     +,   7.8703678E-04,   7.9749309E-04,   8.0632285E-04
     +,   8.1359188E-04,   8.1942370E-04,   8.2400098E-04
     +,   8.2756480E-04,   8.3041069E-04,   8.3288393E-04
     +,   8.3536957E-04,   8.3828566E-04,   8.4206875E-04
     +,   8.4716349E-04,   8.5400790E-04,   8.6301955E-04
     +,   8.7458367E-04,   8.8904338E-04,   9.0668991E-04
     +,   9.2775823E-04,   9.5243158E-04,   9.8084414E-04
     +,   1.0130904E-03,   1.0492433E-03,   1.0893724E-03
     +,   1.1335645E-03,   1.1819362E-03,   1.2346555E-03
     +,   1.2919450E-03,   1.3540704E-03,   1.4213321E-03
     +,   1.4940293E-03,   1.5724236E-03,   1.6566732E-03
     +,   1.7467822E-03,   1.8425515E-03,   1.9435263E-03
     +,   2.0489581E-03,   2.1578113E-03,   2.2687966E-03
     +,   2.3804347E-03,   2.4911505E-03,   2.5994440E-03
     +,   2.7040397E-03,   2.8040861E-03,   2.8993206E-03
     +,   2.9902246E-03,   3.0780884E-03,   3.1650008E-03
     +,   3.2537347E-03,   3.3475761E-03,   3.4500991E-03
     +,   3.5649634E-03,   3.6958402E-03,   3.8465189E-03
     +,   4.0212409E-03,   4.2251698E-03,   4.4649392E-03
     +,   4.7489163E-03,   5.0870376E-03,   5.4904572E-03
     +,   5.9715929E-03,   6.5452871E-03,   7.2308425E-03
     +,   8.0540767E-03,   9.0494957E-03,   1.0269485E-02
     +,   1.1812208E-02,   1.3867131E-02,   1.6729407E-02
     +,   2.0688819E-02,   2.5781479E-02,   3.1678189E-02
     +,   3.8039681E-02,   4.4899140E-02,   5.2158762E-02
     +,   5.9094407E-02,   6.5443039E-02,   7.1879849E-02
     +,   7.8443907E-02,   8.4587075E-02,   9.0285234E-02
     +,   9.5353864E-02,   9.8460115E-02,   9.7710393E-02
     +,   9.3033366E-02,   8.5973904E-02,   7.8563027E-02
     +,   7.1997717E-02,   6.5809652E-02,   5.9876658E-02
     +,   5.4627214E-02,   4.9741328E-02,   4.4719744E-02
     +,   3.9605413E-02,   3.4795824E-02,   3.0636890E-02
     +,   2.7119331E-02,   2.3953248E-02,   2.0930257E-02
     +,   1.8080300E-02,   1.5524819E-02,   1.3314657E-02
     +,   1.1417119E-02,   9.7815152E-03,   8.3779469E-03
     +,   7.1897889E-03,   6.1946916E-03,   5.3595169E-03
     +,   4.6477397E-03,   4.0282239E-03,   3.4792759E-03
     +,   2.9881336E-03,   2.5484341E-03,   2.1575096E-03
     +,   1.8142218E-03,   1.5174489E-03,   1.2651301E-03
     +,   1.0540067E-03,   8.7977969E-04,   7.3750166E-04
     +,   6.2205561E-04,   5.2858389E-04,   4.5277254E-04
     +,   3.9097213E-04,   3.4021062E-04,   2.9813740E-04
     +,   2.6292499E-04,   2.3316234E-04,   2.0775964E-04
     +,   1.8587339E-04,   1.6684992E-04,   1.5017673E-04
     +,   1.3545291E-04,   1.2236545E-04,   1.1066921E-04
     +,   1.0017146E-04,   9.0720830E-05,   8.2197897E-05
     +,   7.4506352E-05,   6.7566340E-05,   6.1310217E-05
     +,   5.5679197E-05,   5.0620365E-05,   4.6084679E-05
     +,   4.2026306E-05,   3.8402432E-05,   3.5172114E-05
     +,   3.2296750E-05,   2.9740213E-05,   2.7468723E-05
     +,   2.5450807E-05,   2.3657531E-05,   2.2062615E-05
     +,   2.0642248E-05,   1.9374935E-05,   1.8241508E-05
     +,   1.7225077E-05,   1.6310614E-05,   1.5485064E-05
     +,   1.4736914E-05,   1.4056241E-05,   1.3434355E-05
     +,   1.2863816E-05,   1.2338117E-05,   1.1851721E-05
     +,   1.1399778E-05,   1.0978173E-05,   1.0583301E-05
     +,   1.0212062E-05,   9.8618020E-06,   9.5301775E-06
     +,   9.2151995E-06,   8.9151017E-06,   8.6283826E-06
     +,   8.3536970E-06,   8.0899090E-06,   7.8359881E-06
     +,   7.5910712E-06,   7.3543688E-06,   7.1252239E-06
     +,   6.9030311E-06,   6.6872899E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_hatt95 = Yx/0.490823529411765
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.8982155E-06,   1.0066041E-05
     +,   1.0233463E-05,   1.0400490E-05,   1.0567136E-05
     +,   1.0733449E-05,   1.0899489E-05,   1.1065352E-05
     +,   1.1231149E-05,   1.1397036E-05,   1.1563196E-05
     +,   1.1729846E-05,   1.1897255E-05,   1.2065729E-05
     +,   1.2235623E-05,   1.2407348E-05,   1.2581373E-05
     +,   1.2758225E-05,   1.2938504E-05,   1.3122875E-05
     +,   1.3312081E-05,   1.3506946E-05,   1.3708375E-05
     +,   1.3917382E-05,   1.4135043E-05,   1.4362567E-05
     +,   1.4601249E-05,   1.4852490E-05,   1.5117808E-05
     +,   1.5398844E-05,   1.5697331E-05,   1.6015139E-05
     +,   1.6354259E-05,   1.6716793E-05,   1.7104956E-05
     +,   1.7521093E-05,   1.7967655E-05,   1.8447192E-05
     +,   1.8962386E-05,   1.9515963E-05,   2.0110780E-05
     +,   2.0749749E-05,   2.1435841E-05,   2.2172066E-05
     +,   2.2961482E-05,   2.3807133E-05,   2.4712073E-05
     +,   2.5679306E-05,   2.6711805E-05,   2.7812426E-05
     +,   2.8983941E-05,   3.0228975E-05,   3.1549967E-05
     +,   3.2949258E-05,   3.4428787E-05,   3.5990422E-05
     +,   3.7635633E-05,   3.9365601E-05,   4.1181193E-05
     +,   4.3082884E-05,   4.5070807E-05,   4.7144702E-05
     +,   4.9303784E-05,   5.1546998E-05,   5.3872933E-05
     +,   5.6279503E-05,   5.8764581E-05,   6.1325321E-05
     +,   6.3958956E-05,   6.6662054E-05,   6.9431364E-05
     +,   7.2263087E-05,   7.5153832E-05,   7.8099845E-05
     +,   8.1097845E-05,   8.4144871E-05,   8.7238244E-05
     +,   9.0375892E-05,   9.3556715E-05,   9.6780641E-05
     +,   1.0004836E-04,   1.0336244E-04,   1.0672649E-04
     +,   1.1014621E-04,   1.1362887E-04,   1.1718418E-04
     +,   1.2082352E-04,   1.2456103E-04,   1.2841268E-04
     +,   1.3239702E-04,   1.3653502E-04,   1.4084944E-04
     +,   1.4536505E-04,   1.5010862E-04,   1.5510825E-04
     +,   1.6039274E-04,   1.6599194E-04,   1.7193520E-04
     +,   1.7825195E-04,   1.8496985E-04,   1.9211558E-04
     +,   1.9971248E-04,   2.0778208E-04,   2.1634120E-04
     +,   2.2540356E-04,   2.3497874E-04,   2.4507090E-04
     +,   2.5567980E-04,   2.6680101E-04,   2.7842622E-04
     +,   2.9054211E-04,   3.0313383E-04,   3.1618297E-04
     +,   3.2967151E-04,   3.4357983E-04,   3.5789187E-04
     +,   3.7259224E-04,   3.8767219E-04,   4.0312586E-04
     +,   4.1895584E-04,   4.3517226E-04,   4.5179264E-04
     +,   4.6884149E-04,   4.8635344E-04,   5.0436909E-04
     +,   5.2293314E-04,   5.4209551E-04,   5.6190422E-04
     +,   5.8240775E-04,   6.0364488E-04,   6.2564772E-04
     +,   6.4843247E-04,   6.7199947E-04,   6.9632655E-04
     +,   7.2137197E-04,   7.4706879E-04,   7.7332475E-04
     +,   8.0002524E-04,   8.2703622E-04,   8.5420825E-04
     +,   8.8137860E-04,   9.0837892E-04,   9.3504356E-04
     +,   9.6121611E-04,   9.8674721E-04,   1.0115103E-03
     +,   1.0353948E-03,   1.0583116E-03,   1.0801883E-03
     +,   1.1009701E-03,   1.1206128E-03,   1.1390748E-03
     +,   1.1563167E-03,   1.1722959E-03,   1.1869667E-03
     +,   1.2002840E-03,   1.2122077E-03,   1.2227232E-03
     +,   1.2318511E-03,   1.2396696E-03,   1.2463367E-03
     +,   1.2521123E-03,   1.2573702E-03,   1.2626111E-03
     +,   1.2684572E-03,   1.2756438E-03,   1.2849895E-03
     +,   1.2973575E-03,   1.3136155E-03,   1.3345823E-03
     +,   1.3609987E-03,   1.3935096E-03,   1.4327102E-03
     +,   1.4792348E-03,   1.5339393E-03,   1.5981731E-03
     +,   1.6741136E-03,   1.7651168E-03,   1.8760106E-03
     +,   2.0132004E-03,   2.1844381E-03,   2.3981177E-03
     +,   2.6621299E-03,   2.9822951E-03,   3.3606424E-03
     +,   3.7939087E-03,   4.2730086E-03,   4.7841445E-03
     +,   5.3121946E-03,   5.8467854E-03,   6.3903932E-03
     +,   6.9653993E-03,   7.6154293E-03,   8.3974879E-03
     +,   9.3684150E-03,   1.0578711E-02,   1.2084110E-02
     +,   1.3957991E-02,   1.6258767E-02,   1.8940110E-02
     +,   2.1797756E-02,   2.4588579E-02,   2.7299171E-02
     +,   3.0326959E-02,   3.4283355E-02,   3.9435714E-02
     +,   4.5354236E-02,   5.0977498E-02,   5.4876309E-02
     +,   5.6589112E-02,   5.7909291E-02,   6.0855992E-02
     +,   6.4650774E-02,   6.6801094E-02,   6.6734150E-02
     +,   6.5697193E-02,   6.3868567E-02,   6.0581353E-02
     +,   5.6408238E-02,   5.2836038E-02,   5.0381046E-02
     +,   4.8440110E-02,   4.6267826E-02,   4.3344039E-02
     +,   3.9705623E-02,   3.5994560E-02,   3.2690872E-02
     +,   2.9675625E-02,   2.6713980E-02,   2.3867117E-02
     +,   2.1321131E-02,   1.9143684E-02,   1.7282227E-02
     +,   1.5655642E-02,   1.4199144E-02,   1.2865912E-02
     +,   1.1622947E-02,   1.0452962E-02,   9.3539152E-03
     +,   8.3300294E-03,   7.3819826E-03,   6.5047652E-03
     +,   5.6921104E-03,   4.9408851E-03,   4.2517288E-03
     +,   3.6270476E-03,   3.0687763E-03,   2.5772711E-03
     +,   2.1510734E-03,   1.7870213E-03,   1.4803247E-03
     +,   1.2249276E-03,   1.0140113E-03,   8.4056432E-04
     +,   6.9793762E-04,   5.8026897E-04,   4.8269221E-04
     +,   4.0134235E-04,   3.3323784E-04,   2.7611267E-04
     +,   2.2823058E-04,   1.8821860E-04,   1.5494460E-04
     +,   1.2743955E-04,   1.0485155E-04,   8.6416781E-05
     +,   7.1452996E-05,   5.9357237E-05,   4.9603430E-05
     +,   4.1740645E-05,   3.5390247E-05,   3.0240535E-05
     +,   2.6038890E-05,   2.2583617E-05,   1.9716079E-05
     +,   1.7313030E-05,   1.5278978E-05,   1.3540722E-05
     +,   1.2041788E-05,   1.0738830E-05,   9.5980786E-06
     +,   8.5932661E-06,   7.7035011E-06,   6.9121825E-06
     +,   6.2057716E-06,   5.5732689E-06,   5.0055005E-06
     +,   4.4947919E-06,   4.0347018E-06,   3.6196859E-06
     +,   3.2450287E-06,   2.9065984E-06,   2.6008324E-06
     +,   2.3245605E-06,   2.0750149E-06,   1.8496991E-06
     +,   1.6464095E-06,   1.4631364E-06,   1.2980904E-06
     +,   1.1496247E-06,   1.0162624E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt100 = Yx/0.41832
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.7705060E-06,   9.8842820E-06
     +,   9.9972031E-06,   1.0109481E-05,   1.0221364E-05
     +,   1.0333145E-05,   1.0445155E-05,   1.0557771E-05
     +,   1.0671428E-05,   1.0786613E-05,   1.0903866E-05
     +,   1.1023788E-05,   1.1147052E-05,   1.1274395E-05
     +,   1.1406632E-05,   1.1544652E-05,   1.1689422E-05
     +,   1.1842004E-05,   1.2003541E-05,   1.2175270E-05
     +,   1.2358526E-05,   1.2554737E-05,   1.2765438E-05
     +,   1.2992268E-05,   1.3236954E-05,   1.3501358E-05
     +,   1.3787422E-05,   1.4097203E-05,   1.4432862E-05
     +,   1.4796658E-05,   1.5190949E-05,   1.5618189E-05
     +,   1.6080916E-05,   1.6581747E-05,   1.7123386E-05
     +,   1.7708579E-05,   1.8340130E-05,   1.9020890E-05
     +,   1.9753759E-05,   2.0541582E-05,   2.1387275E-05
     +,   2.2293691E-05,   2.3263647E-05,   2.4299905E-05
     +,   2.5405143E-05,   2.6581938E-05,   2.7832730E-05
     +,   2.9159823E-05,   3.0565345E-05,   3.2051215E-05
     +,   3.3619122E-05,   3.5270543E-05,   3.7006619E-05
     +,   3.8828326E-05,   4.0736115E-05,   4.2730288E-05
     +,   4.4810684E-05,   4.6976798E-05,   4.9227692E-05
     +,   5.1562056E-05,   5.3978110E-05,   5.6473717E-05
     +,   5.9046110E-05,   6.1692263E-05,   6.4408770E-05
     +,   6.7191431E-05,   7.0036047E-05,   7.2937568E-05
     +,   7.5890959E-05,   7.8890400E-05,   8.1930135E-05
     +,   8.5003638E-05,   8.8104593E-05,   9.1226037E-05
     +,   9.4361087E-05,   9.7502852E-05,   1.0064415E-04
     +,   1.0377789E-04,   1.0689729E-04,   1.0999587E-04
     +,   1.1306706E-04,   1.1610531E-04,   1.1910510E-04
     +,   1.2206208E-04,   1.2497226E-04,   1.2783297E-04
     +,   1.3064229E-04,   1.3339979E-04,   1.3610594E-04
     +,   1.3876303E-04,   1.4137472E-04,   1.4394619E-04
     +,   1.4648422E-04,   1.4899751E-04,   1.5149653E-04
     +,   1.5399310E-04,   1.5650115E-04,   1.5903584E-04
     +,   1.6161423E-04,   1.6425426E-04,   1.6697537E-04
     +,   1.6979758E-04,   1.7274183E-04,   1.7582902E-04
     +,   1.7908018E-04,   1.8251591E-04,   1.8615584E-04
     +,   1.9001817E-04,   1.9411964E-04,   1.9847481E-04
     +,   2.0309530E-04,   2.0799044E-04,   2.1316530E-04
     +,   2.1862228E-04,   2.2435912E-04,   2.3037010E-04
     +,   2.3664480E-04,   2.4316920E-04,   2.4992440E-04
     +,   2.5688836E-04,   2.6403510E-04,   2.7133492E-04
     +,   2.7875527E-04,   2.8626155E-04,   2.9381720E-04
     +,   3.0138370E-04,   3.0892275E-04,   3.1639525E-04
     +,   3.2376347E-04,   3.3098980E-04,   3.3803968E-04
     +,   3.4487981E-04,   3.5148067E-04,   3.5781472E-04
     +,   3.6385897E-04,   3.6959368E-04,   3.7500312E-04
     +,   3.8007519E-04,   3.8480206E-04,   3.8917997E-04
     +,   3.9320852E-04,   3.9689106E-04,   4.0023471E-04
     +,   4.0325016E-04,   4.0595100E-04,   4.0835448E-04
     +,   4.1048112E-04,   4.1235474E-04,   4.1400269E-04
     +,   4.1545642E-04,   4.1675137E-04,   4.1792754E-04
     +,   4.1902988E-04,   4.2010951E-04,   4.2122317E-04
     +,   4.2243482E-04,   4.2381574E-04,   4.2544489E-04
     +,   4.2740992E-04,   4.2980674E-04,   4.3274017E-04
     +,   4.3632352E-04,   4.4067766E-04,   4.4593104E-04
     +,   4.5221840E-04,   4.5967937E-04,   4.6845703E-04
     +,   4.7869596E-04,   4.9054250E-04,   5.0414377E-04
     +,   5.1964674E-04,   5.3720071E-04,   5.5696297E-04
     +,   5.7910354E-04,   6.0381286E-04,   6.3131895E-04
     +,   6.6190213E-04,   6.9591426E-04,   7.3380518E-04
     +,   7.7615335E-04,   8.2369300E-04,   8.7733840E-04
     +,   9.3820359E-04,   1.0076137E-03,   1.0870845E-03
     +,   1.1782735E-03,   1.2829113E-03,   1.4027172E-03
     +,   1.5393010E-03,   1.6940753E-03,   1.8682546E-03
     +,   2.0628844E-03,   2.2789040E-03,   2.5172671E-03
     +,   2.7790286E-03,   3.0653274E-03,   3.3773254E-03
     +,   3.7162194E-03,   4.0834076E-03,   4.4809012E-03
     +,   4.9119135E-03,   5.3814463E-03,   5.8964770E-03
     +,   6.4651715E-03,   7.0948415E-03,   7.7888309E-03
     +,   8.5424399E-03,   9.3397731E-03,   1.0154118E-02
     +,   1.0954988E-02,   1.1722903E-02,   1.2467890E-02
     +,   1.3239998E-02,   1.4117010E-02,   1.5168114E-02
     +,   1.6417837E-02,   1.7839309E-02,   1.9375151E-02
     +,   2.0965757E-02,   2.2596464E-02,   2.4370590E-02
     +,   2.6551222E-02,   2.9485472E-02,   3.3330224E-02
     +,   3.7778683E-02,   4.2430487E-02,   4.7396973E-02
     +,   5.2699503E-02,   5.7727937E-02,   6.2265661E-02
     +,   6.6716522E-02,   7.1355037E-02,   7.5111851E-02
     +,   7.5563312E-02,   7.2989076E-02,   7.0505641E-02
     +,   6.8814963E-02,   6.6234559E-02,   6.2275864E-02
     +,   5.7766572E-02,   5.3161290E-02,   4.8352033E-02
     +,   4.3192636E-02,   3.7544675E-02,   3.1590100E-02
     +,   2.5897974E-02,   2.0880671E-02,   1.6589845E-02
     +,   1.2981210E-02,   1.0049991E-02,   7.7676401E-03
     +,   6.0421857E-03,   4.7473097E-03,   3.7633795E-03
     +,   2.9986850E-03,   2.3914410E-03,   1.9025720E-03
     +,   1.5070746E-03,   1.1875560E-03,   9.3062653E-04
     +,   7.2528748E-04,   5.6228769E-04,   4.3383203E-04
     +,   3.3338022E-04,   2.5545942E-04,   1.9548742E-04
     +,   1.4966061E-04,   1.1485570E-04,   8.8540131E-05
     +,   6.8693356E-05,   5.3732689E-05,   4.2439333E-05
     +,   3.3886849E-05,   2.7378284E-05,   2.2393593E-05
     +,   1.8546354E-05,   1.5548823E-05,   1.3187337E-05
     +,   1.1302467E-05,   9.7757793E-06,   8.5190713E-06
     +,   7.4672412E-06,   6.5722834E-06,   5.7992629E-06
     +,   5.1227744E-06,   4.5245979E-06,   3.9915913E-06
     +,   3.5142696E-06,   3.0857382E-06,   2.7007625E-06
     +,   2.3552980E-06,   2.0459793E-06,   1.7699365E-06
     +,   1.5245381E-06,   1.3073570E-06,   1.1160481E-06
     +,   9.4837799E-07,   8.0216950E-07,   6.7534882E-07
     +,   5.6591762E-07,   4.7199785E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt105 = Yx/0.409857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3531429E-05,   3.4534278E-05
     +,   3.5541878E-05,   3.6552683E-05,   3.7565107E-05
     +,   3.8577560E-05,   3.9588409E-05,   4.0596027E-05
     +,   4.1598745E-05,   4.2594973E-05,   4.3583088E-05
     +,   4.4561508E-05,   4.5528679E-05,   4.6483136E-05
     +,   4.7423426E-05,   4.8348207E-05,   4.9256250E-05
     +,   5.0146362E-05,   5.1017512E-05,   5.1868785E-05
     +,   5.2699394E-05,   5.3508713E-05,   5.4296273E-05
     +,   5.5061802E-05,   5.5805162E-05,   5.6526482E-05
     +,   5.7226051E-05,   5.7904392E-05,   5.8562262E-05
     +,   5.9200658E-05,   5.9820843E-05,   6.0424267E-05
     +,   6.1012775E-05,   6.1588376E-05,   6.2153420E-05
     +,   6.2710533E-05,   6.3262611E-05,   6.3812862E-05
     +,   6.4364831E-05,   6.4922278E-05,   6.5489359E-05
     +,   6.6070439E-05,   6.6670233E-05,   6.7293688E-05
     +,   6.7946057E-05,   6.8632835E-05,   6.9359710E-05
     +,   7.0132664E-05,   7.0957765E-05,   7.1841343E-05
     +,   7.2789735E-05,   7.3809410E-05,   7.4906813E-05
     +,   7.6088487E-05,   7.7360710E-05,   7.8729747E-05
     +,   8.0201557E-05,   8.1781865E-05,   8.3475978E-05
     +,   8.5288768E-05,   8.7224573E-05,   8.9287125E-05
     +,   9.1479262E-05,   9.3803268E-05,   9.6260512E-05
     +,   9.8851146E-05,   1.0157457E-04,   1.0442881E-04
     +,   1.0741095E-04,   1.1051655E-04,   1.1374027E-04
     +,   1.1707508E-04,   1.2051305E-04,   1.2404453E-04
     +,   1.2765892E-04,   1.3134442E-04,   1.3508790E-04
     +,   1.3887514E-04,   1.4269116E-04,   1.4652021E-04
     +,   1.5034563E-04,   1.5415062E-04,   1.5791756E-04
     +,   1.6162953E-04,   1.6526890E-04,   1.6881907E-04
     +,   1.7226364E-04,   1.7558729E-04,   1.7877558E-04
     +,   1.8181557E-04,   1.8469592E-04,   1.8740687E-04
     +,   1.8994055E-04,   1.9229167E-04,   1.9445705E-04
     +,   1.9643585E-04,   1.9823026E-04,   1.9984451E-04
     +,   2.0128637E-04,   2.0256580E-04,   2.0369592E-04
     +,   2.0469241E-04,   2.0557368E-04,   2.0636102E-04
     +,   2.0707792E-04,   2.0775052E-04,   2.0840704E-04
     +,   2.0907773E-04,   2.0979460E-04,   2.1059126E-04
     +,   2.1150261E-04,   2.1256450E-04,   2.1381328E-04
     +,   2.1528594E-04,   2.1701893E-04,   2.1904838E-04
     +,   2.2140930E-04,   2.2413553E-04,   2.2725841E-04
     +,   2.3080721E-04,   2.3480751E-04,   2.3928187E-04
     +,   2.4424755E-04,   2.4971750E-04,   2.5569895E-04
     +,   2.6219263E-04,   2.6919288E-04,   2.7668630E-04
     +,   2.8465257E-04,   2.9306218E-04,   3.0187913E-04
     +,   3.1105737E-04,   3.2054435E-04,   3.3027833E-04
     +,   3.4019095E-04,   3.5020776E-04,   3.6024716E-04
     +,   3.7022322E-04,   3.8004707E-04,   3.8962747E-04
     +,   3.9887198E-04,   4.0768919E-04,   4.1599109E-04
     +,   4.2369324E-04,   4.3071734E-04,   4.3699268E-04
     +,   4.4245800E-04,   4.4706182E-04,   4.5076470E-04
     +,   4.5353998E-04,   4.5537401E-04,   4.5626771E-04
     +,   4.5623590E-04,   4.5530815E-04,   4.5352892E-04
     +,   4.5095675E-04,   4.4766476E-04,   4.4373964E-04
     +,   4.3928224E-04,   4.3440700E-04,   4.2924145E-04
     +,   4.2392610E-04,   4.1861521E-04,   4.1347562E-04
     +,   4.0868830E-04,   4.0444604E-04,   4.0095556E-04
     +,   3.9843569E-04,   3.9711685E-04,   3.9723996E-04
     +,   3.9905412E-04,   4.0281512E-04,   4.0878131E-04
     +,   4.1721197E-04,   4.2836191E-04,   4.4248110E-04
     +,   4.5981209E-04,   4.8058937E-04,   5.0504517E-04
     +,   5.3341757E-04,   5.6596671E-04,   6.0299371E-04
     +,   6.4487092E-04,   6.9208274E-04,   7.4526545E-04
     +,   8.0524595E-04,   8.7308092E-04,   9.5008156E-04
     +,   1.0378058E-03,   1.1380024E-03,   1.2525314E-03
     +,   1.3832181E-03,   1.5316482E-03,   1.6989632E-03
     +,   1.8856660E-03,   2.0914632E-03,   2.3151783E-03
     +,   2.5548127E-03,   2.8077103E-03,   3.0707868E-03
     +,   3.3407582E-03,   3.6144322E-03,   3.8889560E-03
     +,   4.1620582E-03,   4.4323509E-03,   4.6997969E-03
     +,   4.9662194E-03,   5.2358368E-03,   5.5158827E-03
     +,   5.8172676E-03,   6.1552720E-03,   6.5500508E-03
     +,   7.0263064E-03,   7.6107867E-03,   8.3264001E-03
     +,   9.1832876E-03,   1.0170344E-02,   1.1253051E-02
     +,   1.2382234E-02,   1.3511606E-02,   1.4614284E-02
     +,   1.5687907E-02,   1.6750671E-02,   1.7840995E-02
     +,   1.9026302E-02,   2.0411724E-02,   2.2137942E-02
     +,   2.4357066E-02,   2.7152730E-02,   3.0406013E-02
     +,   3.3784490E-02,   3.7073337E-02,   4.0581964E-02
     +,   4.4887975E-02,   5.0045289E-02,   5.5617630E-02
     +,   6.1476272E-02,   6.7365244E-02,   7.2005972E-02
     +,   7.4461006E-02,   7.5355895E-02,   7.5177789E-02
     +,   7.3308863E-02,   6.9734432E-02,   6.5280132E-02
     +,   5.9922598E-02,   5.3057961E-02,   4.4988975E-02
     +,   3.6826421E-02,   2.9374249E-02,   2.2833927E-02
     +,   1.7264981E-02,   1.2780204E-02,   9.4045568E-03
     +,   6.9955797E-03,   5.3113196E-03,   4.1143252E-03
     +,   3.2291773E-03,   2.5467770E-03,   2.0052048E-03
     +,   1.5702008E-03,   1.2217945E-03,   9.4634271E-04
     +,   7.3239888E-04,   5.6912343E-04,   4.4614947E-04
     +,   3.5410695E-04,   2.8510331E-04,   2.3290972E-04
     +,   1.9286513E-04,   1.6161191E-04,   1.3677926E-04
     +,   1.1670024E-04,   1.0019648E-04,   8.6429907E-05
     +,   7.4800795E-05,   6.4875123E-05,   5.6337984E-05
     +,   4.8955633E-05,   4.2551710E-05,   3.6987250E-05
     +,   3.2149914E-05,   2.7944554E-05,   2.4289729E-05
     +,   2.1113736E-05,   1.8354007E-05,   1.5955358E-05
     +,   1.3869595E-05,   1.2055032E-05,   1.0475387E-05
     +,   9.0995854E-06,   7.9007132E-06,   6.8557633E-06
     +,   5.9447780E-06,   5.1506431E-06,   4.4584353E-06
     +,   3.8552898E-06,   3.3299320E-06,   2.8726024E-06
     +,   2.4747173E-06,   2.1288263E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt107 = Yx/0.379714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.4849850E-06,   7.8079001E-06
     +,   8.1433300E-06,   8.4915155E-06,   8.8526713E-06
     +,   9.2269884E-06,   9.6146323E-06,   1.0015733E-05
     +,   1.0430384E-05,   1.0858665E-05,   1.1300591E-05
     +,   1.1756152E-05,   1.2225290E-05,   1.2707907E-05
     +,   1.3203861E-05,   1.3712954E-05,   1.4234951E-05
     +,   1.4769563E-05,   1.5316451E-05,   1.5875232E-05
     +,   1.6445476E-05,   1.7026696E-05,   1.7618362E-05
     +,   1.8219929E-05,   1.8830749E-05,   1.9450203E-05
     +,   2.0077598E-05,   2.0712223E-05,   2.1353339E-05
     +,   2.2000193E-05,   2.2652019E-05,   2.3308043E-05
     +,   2.3967488E-05,   2.4629611E-05,   2.5293661E-05
     +,   2.5958936E-05,   2.6624764E-05,   2.7290529E-05
     +,   2.7955699E-05,   2.8619761E-05,   2.9282364E-05
     +,   2.9943210E-05,   3.0602136E-05,   3.1259096E-05
     +,   3.1914195E-05,   3.2567717E-05,   3.3220105E-05
     +,   3.3871980E-05,   3.4524201E-05,   3.5177836E-05
     +,   3.5834197E-05,   3.6494843E-05,   3.7161626E-05
     +,   3.7836682E-05,   3.8522427E-05,   3.9221657E-05
     +,   3.9937455E-05,   4.0673262E-05,   4.1432897E-05
     +,   4.2220563E-05,   4.3040840E-05,   4.3898723E-05
     +,   4.4799574E-05,   4.5749224E-05,   4.6753936E-05
     +,   4.7820289E-05,   4.8955430E-05,   5.0166756E-05
     +,   5.1462208E-05,   5.2850028E-05,   5.4338889E-05
     +,   5.5937704E-05,   5.7655878E-05,   5.9502916E-05
     +,   6.1488689E-05,   6.3623294E-05,   6.5916858E-05
     +,   6.8379573E-05,   7.1021801E-05,   7.3853902E-05
     +,   7.6885808E-05,   8.0127655E-05,   8.3588893E-05
     +,   8.7279055E-05,   9.1206741E-05,   9.5380441E-05
     +,   9.9807628E-05,   1.0449543E-04,   1.0944955E-04
     +,   1.1467544E-04,   1.2017724E-04,   1.2595781E-04
     +,   1.3201874E-04,   1.3836066E-04,   1.4498278E-04
     +,   1.5188233E-04,   1.5905568E-04,   1.6649670E-04
     +,   1.7419834E-04,   1.8215099E-04,   1.9034406E-04
     +,   1.9876384E-04,   2.0739574E-04,   2.1622216E-04
     +,   2.2522430E-04,   2.3438103E-04,   2.4366885E-04
     +,   2.5306214E-04,   2.6253416E-04,   2.7205620E-04
     +,   2.8159708E-04,   2.9112547E-04,   3.0060764E-04
     +,   3.1001051E-04,   3.1929894E-04,   3.2843935E-04
     +,   3.3739730E-04,   3.4614067E-04,   3.5463754E-04
     +,   3.6285911E-04,   3.7077945E-04,   3.7837535E-04
     +,   3.8562753E-04,   3.9252176E-04,   3.9904888E-04
     +,   4.0520428E-04,   4.1098977E-04,   4.1641272E-04
     +,   4.2148674E-04,   4.2623095E-04,   4.3067001E-04
     +,   4.3483367E-04,   4.3875643E-04,   4.4247619E-04
     +,   4.4603358E-04,   4.4947103E-04,   4.5283159E-04
     +,   4.5615659E-04,   4.5948656E-04,   4.6285780E-04
     +,   4.6630224E-04,   4.6984522E-04,   4.7350617E-04
     +,   4.7729613E-04,   4.8121740E-04,   4.8526411E-04
     +,   4.8942165E-04,   4.9366569E-04,   4.9796508E-04
     +,   5.0228124E-04,   5.0656928E-04,   5.1078049E-04
     +,   5.1486405E-04,   5.1876873E-04,   5.2244606E-04
     +,   5.2585249E-04,   5.2895240E-04,   5.3172064E-04
     +,   5.3414697E-04,   5.3623621E-04,   5.3801405E-04
     +,   5.3952698E-04,   5.4084597E-04,   5.4206781E-04
     +,   5.4331595E-04,   5.4474210E-04,   5.4652517E-04
     +,   5.4887240E-04,   5.5201806E-04,   5.5622397E-04
     +,   5.6177884E-04,   5.6900183E-04,   5.7824282E-04
     +,   5.8989238E-04,   6.0438813E-04,   6.2223116E-04
     +,   6.4400659E-04,   6.7040819E-04,   7.0227345E-04
     +,   7.4062875E-04,   7.8672852E-04,   8.4210461E-04
     +,   9.0859970E-04,   9.8839344E-04,   1.0839847E-03
     +,   1.1981149E-03,   1.3336291E-03,   1.4932631E-03
     +,   1.6793289E-03,   1.8933145E-03,   2.1355252E-03
     +,   2.4047229E-03,   2.6978981E-03,   3.0102932E-03
     +,   3.3357099E-03,   3.6670868E-03,   3.9972686E-03
     +,   4.3200557E-03,   4.6312460E-03,   4.9295984E-03
     +,   5.2175000E-03,   5.5012680E-03,   5.7907654E-03
     +,   6.0983794E-03,   6.4374642E-03,   6.8207625E-03
     +,   7.2587035E-03,   7.7576875E-03,   8.3179111E-03
     +,   8.9312177E-03,   9.5804073E-03,   1.0242762E-02
     +,   1.0899027E-02,   1.1543750E-02,   1.2188851E-02
     +,   1.2852870E-02,   1.3538895E-02,   1.4217293E-02
     +,   1.4833043E-02,   1.5343669E-02,   1.5766893E-02
     +,   1.6204102E-02,   1.6818689E-02,   1.7775383E-02
     +,   1.9163372E-02,   2.0932948E-02,   2.2891426E-02
     +,   2.4808556E-02,   2.6616110E-02,   2.8540108E-02
     +,   3.0908210E-02,   3.3635676E-02,   3.6029365E-02
     +,   3.7569392E-02,   3.8904794E-02,   4.1379515E-02
     +,   4.5287129E-02,   4.9132474E-02,   5.0929472E-02
     +,   5.0087739E-02,   4.7811653E-02,   4.5584925E-02
     +,   4.3812335E-02,   4.2209834E-02,   4.0625900E-02
     +,   3.9028496E-02,   3.7253220E-02,   3.4999080E-02
     +,   3.1948108E-02,   2.8011667E-02,   2.3529744E-02
     +,   1.9107426E-02,   1.5233424E-02,   1.2077986E-02
     +,   9.5695145E-03,   7.5663156E-03,   5.9576491E-03
     +,   4.6731071E-03,   3.6587606E-03,   2.8638700E-03
     +,   2.2420075E-03,   1.7549834E-03,   1.3734422E-03
     +,   1.0749344E-03,   8.4177544E-04,   6.5969408E-04
     +,   5.1725772E-04,   4.0550876E-04,   3.1757879E-04
     +,   2.4827244E-04,   1.9367233E-04,   1.5079434E-04
     +,   1.1731573E-04,   9.1385256E-05,   7.1498995E-05
     +,   5.6418558E-05,   4.5114568E-05,   3.6736608E-05
     +,   3.0586354E-05,   2.6101021E-05,   2.2834527E-05
     +,   2.0442181E-05,   1.8663366E-05,   1.7306531E-05
     +,   1.6234213E-05,   1.5350694E-05,   1.4590999E-05
     +,   1.3912419E-05,   1.3287847E-05,   1.2700641E-05
     +,   1.2141189E-05,   1.1604228E-05,   1.1087266E-05
     +,   1.0589310E-05,   1.0110286E-05,   9.6504382E-06
     +,   9.2101827E-06,   8.7898397E-06,   8.3896584E-06
     +,   8.0096652E-06,   7.6497608E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt110 = Yx/0.329291666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2214893E-05,   1.2556427E-05
     +,   1.2907014E-05,   1.3266758E-05,   1.3635751E-05
     +,   1.4014068E-05,   1.4401779E-05,   1.4798923E-05
     +,   1.5205529E-05,   1.5621621E-05,   1.6047188E-05
     +,   1.6482209E-05,   1.6926631E-05,   1.7380400E-05
     +,   1.7843422E-05,   1.8315590E-05,   1.8796773E-05
     +,   1.9286823E-05,   1.9785555E-05,   2.0292766E-05
     +,   2.0808237E-05,   2.1331714E-05,   2.1862914E-05
     +,   2.2401560E-05,   2.2947297E-05,   2.3499802E-05
     +,   2.4058692E-05,   2.4623576E-05,   2.5194031E-05
     +,   2.5769610E-05,   2.6349864E-05,   2.6934298E-05
     +,   2.7522423E-05,   2.8113702E-05,   2.8707615E-05
     +,   2.9303612E-05,   2.9901121E-05,   3.0499574E-05
     +,   3.1098411E-05,   3.1697014E-05,   3.2294825E-05
     +,   3.2891250E-05,   3.3485707E-05,   3.4077631E-05
     +,   3.4666453E-05,   3.5251633E-05,   3.5832651E-05
     +,   3.6409005E-05,   3.6980229E-05,   3.7545902E-05
     +,   3.8105627E-05,   3.8659076E-05,   3.9205952E-05
     +,   3.9746072E-05,   4.0279232E-05,   4.0805407E-05
     +,   4.1324594E-05,   4.1836924E-05,   4.2342592E-05
     +,   4.2841941E-05,   4.3335425E-05,   4.3823664E-05
     +,   4.4307388E-05,   4.4787514E-05,   4.5265133E-05
     +,   4.5741504E-05,   4.6218149E-05,   4.6696703E-05
     +,   4.7179150E-05,   4.7667610E-05,   4.8164577E-05
     +,   4.8672708E-05,   4.9195063E-05,   4.9734925E-05
     +,   5.0295908E-05,   5.0882038E-05,   5.1497602E-05
     +,   5.2147276E-05,   5.2836102E-05,   5.3569536E-05
     +,   5.4353368E-05,   5.5193817E-05,   5.6097455E-05
     +,   5.7071309E-05,   5.8122696E-05,   5.9259481E-05
     +,   6.0489732E-05,   6.1822044E-05,   6.3265215E-05
     +,   6.4828571E-05,   6.6521672E-05,   6.8354406E-05
     +,   7.0336922E-05,   7.2479714E-05,   7.4793592E-05
     +,   7.7289413E-05,   7.9978498E-05,   8.2872059E-05
     +,   8.5981897E-05,   8.9319386E-05,   9.2896589E-05
     +,   9.6725060E-05,   1.0081693E-04,   1.0518365E-04
     +,   1.0983712E-04,   1.1478888E-04,   1.2005008E-04
     +,   1.2563130E-04,   1.3154298E-04,   1.3779502E-04
     +,   1.4439583E-04,   1.5135370E-04,   1.5867487E-04
     +,   1.6636503E-04,   1.7442730E-04,   1.8286417E-04
     +,   1.9167471E-04,   2.0085699E-04,   2.1040523E-04
     +,   2.2031194E-04,   2.3056660E-04,   2.4115492E-04
     +,   2.5205920E-04,   2.6325931E-04,   2.7473160E-04
     +,   2.8644773E-04,   2.9837782E-04,   3.1048656E-04
     +,   3.2273761E-04,   3.3509007E-04,   3.4750148E-04
     +,   3.5992576E-04,   3.7231680E-04,   3.8462435E-04
     +,   3.9679903E-04,   4.0879025E-04,   4.2054683E-04
     +,   4.3201758E-04,   4.4315361E-04,   4.5390686E-04
     +,   4.6423098E-04,   4.7408292E-04,   4.8342324E-04
     +,   4.9221714E-04,   5.0043385E-04,   5.0804974E-04
     +,   5.1504764E-04,   5.2141800E-04,   5.2716036E-04
     +,   5.3228386E-04,   5.3680904E-04,   5.4076820E-04
     +,   5.4420688E-04,   5.4718420E-04,   5.4977514E-04
     +,   5.5206928E-04,   5.5417186E-04,   5.5620505E-04
     +,   5.5830594E-04,   5.6062627E-04,   5.6333101E-04
     +,   5.6659576E-04,   5.7060580E-04,   5.7555031E-04
     +,   5.8162113E-04,   5.8900722E-04,   5.9789064E-04
     +,   6.0844258E-04,   6.2082056E-04,   6.3516438E-04
     +,   6.5159390E-04,   6.7020819E-04,   6.9108908E-04
     +,   7.1430102E-04,   7.3989492E-04,   7.6791650E-04
     +,   7.9841388E-04,   8.3144224E-04,   8.6707505E-04
     +,   9.0541929E-04,   9.4661833E-04,   9.9086016E-04
     +,   1.0383849E-03,   1.0894923E-03,   1.1445336E-03
     +,   1.2039072E-03,   1.2680517E-03,   1.3374425E-03
     +,   1.4125978E-03,   1.4940823E-03,   1.5825664E-03
     +,   1.6788804E-03,   1.7840812E-03,   1.8995175E-03
     +,   2.0268583E-03,   2.1680342E-03,   2.3250901E-03
     +,   2.5000118E-03,   2.6945549E-03,   2.9101870E-03
     +,   3.1482386E-03,   3.4103338E-03,   3.6989637E-03
     +,   4.0179957E-03,   4.3726927E-03,   4.7690719E-03
     +,   5.2122525E-03,   5.7040248E-03,   6.2402952E-03
     +,   6.8091345E-03,   7.3901578E-03,   7.9558780E-03
     +,   8.4754881E-03,   8.9209210E-03,   9.2749465E-03
     +,   9.5399152E-03,   9.7447736E-03,   9.9462168E-03
     +,   1.0220372E-02,   1.0644873E-02,   1.1275884E-02
     +,   1.2128944E-02,   1.3170644E-02,   1.4325533E-02
     +,   1.5502736E-02,   1.6641397E-02,   1.7753584E-02
     +,   1.8921591E-02,   2.0229382E-02,   2.1676768E-02
     +,   2.3163445E-02,   2.4558200E-02,   2.5760742E-02
     +,   2.6685126E-02,   2.7240785E-02,   2.7429815E-02
     +,   2.7500851E-02,   2.7899278E-02,   2.8875010E-02
     +,   3.0108118E-02,   3.0928079E-02,   3.1006198E-02
     +,   3.0645797E-02,   3.0287962E-02,   2.9938150E-02
     +,   2.9207040E-02,   2.7759645E-02,   2.5599875E-02
     +,   2.3016855E-02,   2.0378254E-02,   1.7950863E-02
     +,   1.5821368E-02,   1.3926349E-02,   1.2150389E-02
     +,   1.0417202E-02,   8.7237563E-03,   7.1213986E-03
     +,   5.6770677E-03,   4.4414280E-03,   3.4338981E-03
     +,   2.6431947E-03,   2.0375724E-03,   1.5778831E-03
     +,   1.2278634E-03,   9.5907704E-04,   7.5124955E-04
     +,   5.9037865E-04,   4.6642634E-04,   3.7162218E-04
     +,   2.9956931E-04,   2.4491243E-04,   2.0324877E-04
     +,   1.7108759E-04,   1.4577918E-04,   1.2539802E-04
     +,   1.0859682E-04,   9.4454277E-05,   8.2350998E-05
     +,   7.1865477E-05,   6.2706109E-05,   5.4661130E-05
     +,   4.7571830E-05,   4.1312633E-05,   3.5782647E-05
     +,   3.0897485E-05,   2.6586569E-05,   2.2788927E-05
     +,   1.9451540E-05,   1.6527936E-05,   1.3976090E-05
     +,   1.1758273E-05,   9.8396840E-06,   8.1885373E-06
     +,   6.7752603E-06,   5.5726978E-06,   4.5556180E-06
     +,   3.7009449E-06,   2.9874352E-06,   2.3958576E-06
     +,   1.9087554E-06,   1.5105504E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt115 = Yx/0.24104347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2241234E-05,   1.2931220E-05
     +,   1.3648973E-05,   1.4394928E-05,   1.5169480E-05
     +,   1.5972995E-05,   1.6805789E-05,   1.7668139E-05
     +,   1.8560262E-05,   1.9482371E-05,   2.0434576E-05
     +,   2.1416943E-05,   2.2429485E-05,   2.3472128E-05
     +,   2.4544750E-05,   2.5647136E-05,   2.6778987E-05
     +,   2.7939934E-05,   2.9129495E-05,   3.0347104E-05
     +,   3.1592084E-05,   3.2863652E-05,   3.4160897E-05
     +,   3.5482855E-05,   3.6828304E-05,   3.8196038E-05
     +,   3.9584633E-05,   4.0992549E-05,   4.2418102E-05
     +,   4.3859480E-05,   4.5314697E-05,   4.6781672E-05
     +,   4.8258109E-05,   4.9741655E-05,   5.1229723E-05
     +,   5.2719690E-05,   5.4208704E-05,   5.5693828E-05
     +,   5.7172081E-05,   5.8640213E-05,   6.0095063E-05
     +,   6.1533261E-05,   6.2951403E-05,   6.4346059E-05
     +,   6.5713735E-05,   6.7050933E-05,   6.8354209E-05
     +,   6.9620059E-05,   7.0845148E-05,   7.2026131E-05
     +,   7.3159827E-05,   7.4243166E-05,   7.5273259E-05
     +,   7.6247437E-05,   7.7163189E-05,   7.8018362E-05
     +,   7.8811019E-05,   7.9539546E-05,   8.0202721E-05
     +,   8.0799698E-05,   8.1329992E-05,   8.1793631E-05
     +,   8.2191014E-05,   8.2523111E-05,   8.2791375E-05
     +,   8.2997802E-05,   8.3144914E-05,   8.3235813E-05
     +,   8.3274172E-05,   8.3264276E-05,   8.3210973E-05
     +,   8.3119681E-05,   8.2996434E-05,   8.2847851E-05
     +,   8.2681065E-05,   8.2503808E-05,   8.2324237E-05
     +,   8.2151113E-05,   8.1993516E-05,   8.1861057E-05
     +,   8.1763603E-05,   8.1711332E-05,   8.1714701E-05
     +,   8.1784274E-05,   8.1930753E-05,   8.2164857E-05
     +,   8.2497179E-05,   8.2938190E-05,   8.3498075E-05
     +,   8.4186730E-05,   8.5013533E-05,   8.5987398E-05
     +,   8.7116452E-05,   8.8408211E-05,   8.9869369E-05
     +,   9.1505535E-05,   9.3321476E-05,   9.5320705E-05
     +,   9.7505821E-05,   9.9877878E-05,   1.0243705E-04
     +,   1.0518185E-04,   1.0810989E-04,   1.1121704E-04
     +,   1.1449815E-04,   1.1794698E-04,   1.2155566E-04
     +,   1.2531529E-04,   1.2921616E-04,   1.3324754E-04
     +,   1.3739754E-04,   1.4165396E-04,   1.4600367E-04
     +,   1.5043349E-04,   1.5492944E-04,   1.5947800E-04
     +,   1.6406509E-04,   1.6867749E-04,   1.7330158E-04
     +,   1.7792486E-04,   1.8253532E-04,   1.8712142E-04
     +,   1.9167249E-04,   1.9617917E-04,   2.0063303E-04
     +,   2.0502631E-04,   2.0935289E-04,   2.1360727E-04
     +,   2.1778551E-04,   2.2188433E-04,   2.2590191E-04
     +,   2.2983683E-04,   2.3368922E-04,   2.3745942E-04
     +,   2.4114869E-04,   2.4475899E-04,   2.4829249E-04
     +,   2.5175174E-04,   2.5513946E-04,   2.5845869E-04
     +,   2.6171218E-04,   2.6490242E-04,   2.6803202E-04
     +,   2.7110308E-04,   2.7411722E-04,   2.7707571E-04
     +,   2.7997946E-04,   2.8282887E-04,   2.8562368E-04
     +,   2.8836395E-04,   2.9104907E-04,   2.9367863E-04
     +,   2.9625240E-04,   2.9877084E-04,   3.0123568E-04
     +,   3.0364955E-04,   3.0601755E-04,   3.0834749E-04
     +,   3.1065103E-04,   3.1294391E-04,   3.1524815E-04
     +,   3.1759276E-04,   3.2001536E-04,   3.2256366E-04
     +,   3.2529785E-04,   3.2829266E-04,   3.3163879E-04
     +,   3.3544577E-04,   3.3984415E-04,   3.4498685E-04
     +,   3.5105040E-04,   3.5823588E-04,   3.6676860E-04
     +,   3.7689559E-04,   3.8888131E-04,   4.0300339E-04
     +,   4.1954406E-04,   4.3877840E-04,   4.6096282E-04
     +,   4.8632215E-04,   5.1503268E-04,   5.4720615E-04
     +,   5.8287388E-04,   6.2197918E-04,   6.6436548E-04
     +,   7.0977042E-04,   7.5783022E-04,   8.0809329E-04
     +,   8.6003775E-04,   9.1309473E-04,   9.6670125E-04
     +,   1.0203521E-03,   1.0736652E-03,   1.1264757E-03
     +,   1.1789338E-03,   1.2316114E-03,   1.2855950E-03
     +,   1.3425678E-03,   1.4048413E-03,   1.4753275E-03
     +,   1.5574234E-03,   1.6548214E-03,   1.7712493E-03
     +,   1.9101229E-03,   2.0741420E-03,   2.2649011E-03
     +,   2.4824876E-03,   2.7251900E-03,   2.9894887E-03
     +,   3.2704682E-03,   3.5627221E-03,   3.8617277E-03
     +,   4.1653751E-03,   4.4749947E-03,   4.7951834E-03
     +,   5.1321434E-03,   5.4910155E-03,   5.8733397E-03
     +,   6.2761325E-03,   6.6932309E-03,   7.1184351E-03
     +,   7.5484263E-03,   7.9834294E-03,   8.4251808E-03
     +,   8.8727372E-03,   9.3188817E-03,   9.7495914E-03
     +,   1.0148467E-02,   1.0504493E-02,   1.0819276E-02
     +,   1.1110028E-02,   1.1407941E-02,   1.1753731E-02
     +,   1.2193719E-02,   1.2781496E-02,   1.3589172E-02
     +,   1.4712124E-02,   1.6228784E-02,   1.8101742E-02
     +,   2.0091472E-02,   2.1799259E-02,   2.2855934E-02
     +,   2.3114370E-02,   2.2686163E-02,   2.1824177E-02
     +,   2.0779314E-02,   1.9721750E-02,   1.8718153E-02
     +,   1.7739171E-02,   1.6700136E-02,   1.5527855E-02
     +,   1.4211464E-02,   1.2803865E-02,   1.1385669E-02
     +,   1.0027608E-02,   8.7731956E-03,   7.6392433E-03
     +,   6.6236653E-03,   5.7144980E-03,   4.8980215E-03
     +,   4.1644131E-03,   3.5094607E-03,   2.9325059E-03
     +,   2.4328625E-03,   2.0072241E-03,   1.6490679E-03
     +,   1.3499191E-03,   1.1010444E-03,   8.9463202E-04
     +,   7.2422775E-04,   5.8460655E-04,   4.7138377E-04
     +,   3.8063849E-04,   3.0870622E-04,   2.5214927E-04
     +,   2.0782578E-04,   1.7297415E-04,   1.4529786E-04
     +,   1.2297633E-04,   1.0464283E-04,   8.9312256E-05
     +,   7.6303462E-05,   6.5152439E-05,   5.5544664E-05
     +,   4.7257217E-05,   4.0122846E-05,   3.4003726E-05
     +,   2.8778866E-05,   2.4337991E-05,   2.0578165E-05
     +,   1.7404876E-05,   1.4731646E-05,   1.2481530E-05
     +,   1.0586708E-05,   8.9889727E-06,   7.6387123E-06
     +,   6.4945721E-06,   5.5221599E-06,   4.6933574E-06
     +,   3.9850847E-06,   3.3786200E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt120 = Yx/0.158395348837209
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3930032E-04,   4.8374714E-04
     +,   5.3177704E-04,   5.8374717E-04,   6.4013060E-04
     +,   7.0155802E-04,   7.6886581E-04,   8.4315223E-04
     +,   9.2582766E-04,   1.0186733E-03,   1.1238651E-03
     +,   1.2439907E-03,   1.3820323E-03,   1.5413184E-03
     +,   1.7254774E-03,   1.9384007E-03,   2.1842904E-03
     +,   2.4678183E-03,   2.7943857E-03,   3.1704740E-03
     +,   3.6038386E-03,   4.1035186E-03,   4.6793832E-03
     +,   5.3415163E-03,   6.0993792E-03,   6.9617098E-03
     +,   7.9367384E-03,   9.0327952E-03,   1.0258133E-02
     +,   1.1618700E-02,   1.3113644E-02,   1.4729330E-02
     +,   1.6434450E-02,   1.8178456E-02,   1.9895788E-02
     +,   2.1516714E-02,   2.2984160E-02,   2.4272876E-02
     +,   2.5401525E-02,   2.6424402E-02,   2.7397906E-02
     +,   2.8332787E-02,   2.9161144E-02,   2.9747033E-02
     +,   2.9943150E-02,   2.9662976E-02,   2.8924482E-02
     +,   2.7839940E-02,   2.6561139E-02,   2.5216784E-02
     +,   2.3876607E-02,   2.2555098E-02,   2.1242158E-02
     +,   1.9934790E-02,   1.8652096E-02,   1.7428853E-02
     +,   1.6298914E-02,   1.5280342E-02,   1.4370344E-02
     +,   1.3549834E-02,   1.2792706E-02,   1.2074992E-02
     +,   1.1380882E-02,   1.0704994E-02,   1.0051383E-02
     +,   9.4303759E-03,   8.8540241E-03,   8.3319778E-03
     +,   7.8683263E-03,   7.4607348E-03,   7.1013188E-03
     +,   6.7791408E-03,   6.4828754E-03,   6.2031327E-03
     +,   5.9336559E-03,   5.6715626E-03,   5.4168832E-03
     +,   5.1716845E-03,   4.9390472E-03,   4.7222986E-03
     +,   4.5243120E-03,   4.3470589E-03,   4.1914252E-03
     +,   4.0571452E-03,   3.9429716E-03,   3.8468752E-03
     +,   3.7663416E-03,   3.6986386E-03,   3.6410408E-03
     +,   3.5910048E-03,   3.5462591E-03,   3.5048665E-03
     +,   3.4652425E-03,   3.4261313E-03,   3.3866055E-03
     +,   3.3460450E-03,   3.3041087E-03,   3.2607089E-03
     +,   3.2159777E-03,   3.1702339E-03,   3.1239195E-03
     +,   3.0775510E-03,   3.0316545E-03,   2.9867026E-03
     +,   2.9430874E-03,   2.9010396E-03,   2.8606588E-03
     +,   2.8218806E-03,   2.7845027E-03,   2.7482223E-03
     +,   2.7126828E-03,   2.6775110E-03,   2.6423836E-03
     +,   2.6070417E-03,   2.5713383E-03,   2.5352316E-03
     +,   2.4987876E-03,   2.4621673E-03,   2.4255908E-03
     +,   2.3892974E-03,   2.3535176E-03,   2.3184356E-03
     +,   2.2841685E-03,   2.2507382E-03,   2.2180690E-03
     +,   2.1859978E-03,   2.1542807E-03,   2.1226166E-03
     +,   2.0906676E-03,   2.0580969E-03,   2.0245819E-03
     +,   1.9898482E-03,   1.9536787E-03,   1.9159330E-03
     +,   1.8765504E-03,   1.8355513E-03,   1.7930305E-03
     +,   1.7491544E-03,   1.7041379E-03,   1.6582400E-03
     +,   1.6117452E-03,   1.5649521E-03,   1.5181527E-03
     +,   1.4716270E-03,   1.4256396E-03,   1.3804196E-03
     +,   1.3361623E-03,   1.2930316E-03,   1.2511555E-03
     +,   1.2106228E-03,   1.1714936E-03,   1.1338007E-03
     +,   1.0975550E-03,   1.0627441E-03,   1.0293428E-03
     +,   9.9731714E-04,   9.6662826E-04,   9.3723089E-04
     +,   9.0908178E-04,   8.8214065E-04,   8.5636909E-04
     +,   8.3173258E-04,   8.0820284E-04,   7.8575726E-04
     +,   7.6437450E-04,   7.4403867E-04,   7.2473724E-04
     +,   7.0646097E-04,   6.8920001E-04,   6.7294633E-04
     +,   6.5769430E-04,   6.4343610E-04,   6.3016452E-04
     +,   6.1787036E-04,   6.0654542E-04,   5.9617817E-04
     +,   5.8675703E-04,   5.7826785E-04,   5.7069561E-04
     +,   5.6402339E-04,   5.5823079E-04,   5.5329682E-04
     +,   5.4919760E-04,   5.4590625E-04,   5.4339383E-04
     +,   5.4162758E-04,   5.4057257E-04,   5.4019009E-04
     +,   5.4043811E-04,   5.4127141E-04,   5.4264191E-04
     +,   5.4449757E-04,   5.4678263E-04,   5.4943963E-04
     +,   5.5240712E-04,   5.5562204E-04,   5.5901753E-04
     +,   5.6252617E-04,   5.6607870E-04,   5.6960434E-04
     +,   5.7303288E-04,   5.7629216E-04,   5.7931198E-04
     +,   5.8202317E-04,   5.8435748E-04,   5.8624963E-04
     +,   5.8763736E-04,   5.8846083E-04,   5.8866572E-04
     +,   5.8820104E-04,   5.8702211E-04,   5.8508961E-04
     +,   5.8237015E-04,   5.7883753E-04,   5.7447166E-04
     +,   5.6926010E-04,   5.6319783E-04,   5.5628730E-04
     +,   5.4853741E-04,   5.3996622E-04,   5.3059711E-04
     +,   5.2046101E-04,   5.0959561E-04,   4.9804448E-04
     +,   4.8585644E-04,   4.7308466E-04,   4.5978703E-04
     +,   4.4602616E-04,   4.3186487E-04,   4.1736910E-04
     +,   4.0260638E-04,   3.8764483E-04,   3.7255112E-04
     +,   3.5739091E-04,   3.4222947E-04,   3.2712836E-04
     +,   3.1214638E-04,   2.9733925E-04,   2.8275969E-04
     +,   2.6845446E-04,   2.5446643E-04,   2.4083437E-04
     +,   2.2759259E-04,   2.1476952E-04,   2.0238888E-04
     +,   1.9047043E-04,   1.7902958E-04,   1.6807650E-04
     +,   1.5761735E-04,   1.4765542E-04,   1.3818959E-04
     +,   1.2921552E-04,   1.2072660E-04,   1.1271370E-04
     +,   1.0516481E-04,   9.8066368E-05,   9.1403468E-05
     +,   8.5160151E-05,   7.9318888E-05,   7.3861629E-05
     +,   6.8770227E-05,   6.4026208E-05,   5.9610804E-05
     +,   5.5505378E-05,   5.1691990E-05,   4.8152695E-05
     +,   4.4870088E-05,   4.1827552E-05,   3.9009108E-05
     +,   3.6399324E-05,   3.3983477E-05,   3.1747804E-05
     +,   2.9679239E-05,   2.7765383E-05,   2.5994586E-05
     +,   2.4356128E-05,   2.2839758E-05,   2.1436133E-05
     +,   2.0136404E-05,   1.8932524E-05,   1.7816850E-05
     +,   1.6782509E-05,   1.5823001E-05,   1.4932447E-05
     +,   1.4105340E-05,   1.3336708E-05,   1.2621907E-05
     +,   1.1956682E-05,   1.1337189E-05,   1.0759830E-05
     +,   1.0221368E-05,   9.7187849E-06,   9.2493683E-06
     +,   8.8105789E-06,   8.4001522E-06,   8.0159543E-06
     +,   7.6560900E-06,   7.3187625E-06,   7.0023816E-06
     +,   6.7054380E-06,   6.4265892E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt60 = Yx/0.272404255319149
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5697471E-04,   1.6859171E-04
     +,   1.8131093E-04,   1.9525684E-04,   2.1056464E-04
     +,   2.2738002E-04,   2.4585842E-04,   2.6616416E-04
     +,   2.8846849E-04,   3.1294962E-04,   3.3978783E-04
     +,   3.6916515E-04,   4.0126269E-04,   4.3625804E-04
     +,   4.7432497E-04,   5.1563210E-04,   5.6034495E-04
     +,   6.0863030E-04,   6.6066260E-04,   7.1663642E-04
     +,   7.7678188E-04,   8.4138621E-04,   9.1081864E-04
     +,   9.8556001E-04,   1.0662178E-03,   1.1535611E-03
     +,   1.2485118E-03,   1.3521377E-03,   1.4656171E-03
     +,   1.5901899E-03,   1.7270945E-03,   1.8775252E-03
     +,   2.0426242E-03,   2.2235529E-03,   2.4216895E-03
     +,   2.6389675E-03,   2.8784177E-03,   3.1448600E-03
     +,   3.4457138E-03,   3.7917001E-03,   4.1973419E-03
     +,   4.6807183E-03,   5.2624163E-03,   5.9633097E-03
     +,   6.8013938E-03,   7.7882451E-03,   8.9263925E-03
     +,   1.0209033E-02,   1.1623005E-02,   1.3154547E-02
     +,   1.4795922E-02,   1.6549638E-02,   1.8427558E-02
     +,   2.0444365E-02,   2.2607053E-02,   2.4906505E-02
     +,   2.7309814E-02,   2.9748637E-02,   3.2100137E-02
     +,   3.4178231E-02,   3.5764292E-02,   3.6687020E-02
     +,   3.6910389E-02,   3.6566686E-02,   3.5899948E-02
     +,   3.5146926E-02,   3.4417678E-02,   3.3649724E-02
     +,   3.2671783E-02,   3.1343650E-02,   2.9673321E-02
     +,   2.7825538E-02,   2.6022431E-02,   2.4421955E-02
     +,   2.3059156E-02,   2.1871405E-02,   2.0766823E-02
     +,   1.9683011E-02,   1.8609779E-02,   1.7578004E-02
     +,   1.6631782E-02,   1.5801627E-02,   1.5091142E-02
     +,   1.4477781E-02,   1.3922607E-02,   1.3381753E-02
     +,   1.2816453E-02,   1.2199596E-02,   1.1519981E-02
     +,   1.0783275E-02,   1.0009835E-02,   9.2298547E-03
     +,   8.4767584E-03,   7.7808574E-03,   7.1646408E-03
     +,   6.6404799E-03,   6.2106154E-03,   5.8691674E-03
     +,   5.6048357E-03,   5.4036523E-03,   5.2510668E-03
     +,   5.1333127E-03,   5.0380453E-03,   4.9546128E-03
     +,   4.8741545E-03,   4.7896719E-03,   4.6961186E-03
     +,   4.5904010E-03,   4.4713393E-03,   4.3394603E-03
     +,   4.1967086E-03,   4.0460424E-03,   3.8910275E-03
     +,   3.7354166E-03,   3.5828406E-03,   3.4364944E-03
     +,   3.2989993E-03,   3.1722665E-03,   3.0574983E-03
     +,   2.9551862E-03,   2.8652293E-03,   2.7870075E-03
     +,   2.7195222E-03,   2.6615278E-03,   2.6116453E-03
     +,   2.5684815E-03,   2.5306954E-03,   2.4970823E-03
     +,   2.4665906E-03,   2.4383364E-03,   2.4115986E-03
     +,   2.3858030E-03,   2.3604929E-03,   2.3353060E-03
     +,   2.3099410E-03,   2.2841475E-03,   2.2577073E-03
     +,   2.2304244E-03,   2.2021206E-03,   2.1726375E-03
     +,   2.1418410E-03,   2.1096212E-03,   2.0758985E-03
     +,   2.0406288E-03,   2.0038006E-03,   1.9654422E-03
     +,   1.9256206E-03,   1.8844361E-03,   1.8420249E-03
     +,   1.7985521E-03,   1.7542072E-03,   1.7092017E-03
     +,   1.6637656E-03,   1.6181382E-03,   1.5725599E-03
     +,   1.5272835E-03,   1.4825554E-03,   1.4386164E-03
     +,   1.3956958E-03,   1.3540188E-03,   1.3137927E-03
     +,   1.2752078E-03,   1.2384399E-03,   1.2036460E-03
     +,   1.1709599E-03,   1.1404926E-03,   1.1123331E-03
     +,   1.0865459E-03,   1.0631678E-03,   1.0422088E-03
     +,   1.0236517E-03,   1.0074546E-03,   9.9354552E-04
     +,   9.8182668E-04,   9.7217935E-04,   9.6445828E-04
     +,   9.5850020E-04,   9.5412362E-04,   9.5113338E-04
     +,   9.4932382E-04,   9.4848138E-04,   9.4838976E-04
     +,   9.4883307E-04,   9.4960030E-04,   9.5048745E-04
     +,   9.5130218E-04,   9.5186516E-04,   9.5201423E-04
     +,   9.5160521E-04,   9.5051352E-04,   9.4863557E-04
     +,   9.4588811E-04,   9.4220915E-04,   9.3755650E-04
     +,   9.3190785E-04,   9.2525763E-04,   9.1761607E-04
     +,   9.0900902E-04,   8.9947117E-04,   8.8904845E-04
     +,   8.7779423E-04,   8.6576684E-04,   8.5302803E-04
     +,   8.3964039E-04,   8.2566735E-04,   8.1117067E-04
     +,   7.9620851E-04,   7.8083790E-04,   7.6511165E-04
     +,   7.4907654E-04,   7.3277741E-04,   7.1625336E-04
     +,   6.9954147E-04,   6.8267371E-04,   6.6567806E-04
     +,   6.4858212E-04,   6.3141034E-04,   6.1418500E-04
     +,   5.9692620E-04,   5.7965517E-04,   5.6239089E-04
     +,   5.4515194E-04,   5.2795804E-04,   5.1082857E-04
     +,   4.9378240E-04,   4.7683867E-04,   4.6001759E-04
     +,   4.4333935E-04,   4.2682383E-04,   4.1049058E-04
     +,   3.9436002E-04,   3.7845265E-04,   3.6278728E-04
     +,   3.4738262E-04,   3.3225794E-04,   3.1743047E-04
     +,   3.0291674E-04,   2.8873284E-04,   2.7489426E-04
     +,   2.6141386E-04,   2.4830390E-04,   2.3557562E-04
     +,   2.2323905E-04,   2.1130216E-04,   1.9977134E-04
     +,   1.8865196E-04,   1.7794855E-04,   1.6766279E-04
     +,   1.5779519E-04,   1.4834575E-04,   1.3931212E-04
     +,   1.3069052E-04,   1.2247657E-04,   1.1466461E-04
     +,   1.0724714E-04,   1.0021583E-04,   9.3561772E-05
     +,   8.7275075E-05,   8.1344762E-05,   7.5759119E-05
     +,   7.0506314E-05,   6.5573993E-05,   6.0949118E-05
     +,   5.6618395E-05,   5.2568808E-05,   4.8786918E-05
     +,   4.5259163E-05,   4.1972493E-05,   3.8913873E-05
     +,   3.6070342E-05,   3.3429267E-05,   3.0978495E-05
     +,   2.8706256E-05,   2.6601056E-05,   2.4651825E-05
     +,   2.2848208E-05,   2.1180034E-05,   1.9637893E-05
     +,   1.8212650E-05,   1.6895850E-05,   1.5679379E-05
     +,   1.4555750E-05,   1.3517814E-05,   1.2559024E-05
     +,   1.1673151E-05,   1.0854505E-05,   1.0097728E-05
     +,   9.3978642E-06,   8.7503895E-06,   8.1510434E-06
     +,   7.5959815E-06,   7.0815886E-06,   6.6046127E-06
     +,   6.1620040E-06,   5.7510251E-06,   5.3691174E-06
     +,   5.0139879E-06,   4.6834916E-06,   4.3757159E-06
     +,   4.0888731E-06,   3.8213657E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt65 = Yx/0.3241875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.3691587E-05,   6.8099311E-05
     +,   7.2788025E-05,   7.7770012E-05,   8.3057421E-05
     +,   8.8662309E-05,   9.4596529E-05,   1.0087177E-04
     +,   1.0749925E-04,   1.1449029E-04,   1.2185542E-04
     +,   1.2960483E-04,   1.3774839E-04,   1.4629532E-04
     +,   1.5525433E-04,   1.6463388E-04,   1.7444193E-04
     +,   1.8468635E-04,   1.9537521E-04,   2.0651724E-04
     +,   2.1812244E-04,   2.3020283E-04,   2.4277373E-04
     +,   2.5585564E-04,   2.6947429E-04,   2.8366497E-04
     +,   2.9847297E-04,   3.1395681E-04,   3.3019105E-04
     +,   3.4726848E-04,   3.6530237E-04,   3.8442950E-04
     +,   4.0481033E-04,   4.2662997E-04,   4.5009854E-04
     +,   4.7544760E-04,   5.0293043E-04,   5.3281785E-04
     +,   5.6539878E-04,   6.0097809E-04,   6.3988945E-04
     +,   6.8250950E-04,   7.2928728E-04,   7.8079163E-04
     +,   8.3777570E-04,   9.0125471E-04,   9.7259536E-04
     +,   1.0536019E-03,   1.1465861E-03,   1.2544111E-03
     +,   1.3804964E-03,   1.5288054E-03,   1.7038217E-03
     +,   1.9105679E-03,   2.1546194E-03,   2.4422121E-03
     +,   2.7801846E-03,   3.1757727E-03,   3.6359869E-03
     +,   4.1665831E-03,   4.7707907E-03,   5.4484331E-03
     +,   6.1962088E-03,   7.0103873E-03,   7.8918515E-03
     +,   8.8524660E-03,   9.9193715E-03,   1.1131545E-02
     +,   1.2526251E-02,   1.4118779E-02,   1.5890101E-02
     +,   1.7795997E-02,   1.9799436E-02,   2.1902915E-02
     +,   2.4154225E-02,   2.6616121E-02,   2.9318044E-02
     +,   3.2214645E-02,   3.5164844E-02,   3.7946682E-02
     +,   4.0320285E-02,   4.2118598E-02,   4.3300234E-02
     +,   4.3934483E-02,   4.4139091E-02,   4.4006441E-02
     +,   4.3541763E-02,   4.2660914E-02,   4.1295912E-02
     +,   3.9542723E-02,   3.7693534E-02,   3.6072310E-02
     +,   3.4806401E-02,   3.3744741E-02,   3.2584175E-02
     +,   3.1076200E-02,   2.9158140E-02,   2.6951721E-02
     +,   2.4664864E-02,   2.2478420E-02,   2.0482671E-02
     +,   1.8686259E-02,   1.7067296E-02,   1.5619651E-02
     +,   1.4363359E-02,   1.3324728E-02,   1.2511144E-02
     +,   1.1900537E-02,   1.1447792E-02,   1.1099091E-02
     +,   1.0804136E-02,   1.0523140E-02,   1.0229474E-02
     +,   9.9099781E-03,   9.5634609E-03,   9.1974707E-03
     +,   8.8240467E-03,   8.4553361E-03,   8.1007704E-03
     +,   7.7660284E-03,   7.4538612E-03,   7.1653626E-03
     +,   6.9011701E-03,   6.6617769E-03,   6.4473334E-03
     +,   6.2569957E-03,   6.0884170E-03,   5.9376727E-03
     +,   5.7995631E-03,   5.6682508E-03,   5.5379793E-03
     +,   5.4037711E-03,   5.2618729E-03,   5.1100031E-03
     +,   4.9474062E-03,   4.7746892E-03,   4.5936066E-03
     +,   4.4067306E-03,   4.2171022E-03,   4.0279371E-03
     +,   3.8423534E-03,   3.6631315E-03,   3.4925384E-03
     +,   3.3322270E-03,   3.1832298E-03,   3.0459124E-03
     +,   2.9200790E-03,   2.8050554E-03,   2.6998026E-03
     +,   2.6030354E-03,   2.5133523E-03,   2.4293414E-03
     +,   2.3496773E-03,   2.2731698E-03,   2.1988170E-03
     +,   2.1258434E-03,   2.0536836E-03,   1.9819846E-03
     +,   1.9105941E-03,   1.8395442E-03,   1.7690100E-03
     +,   1.6992976E-03,   1.6308182E-03,   1.5640467E-03
     +,   1.4995015E-03,   1.4377161E-03,   1.3792177E-03
     +,   1.3244983E-03,   1.2739958E-03,   1.2280766E-03
     +,   1.1870292E-03,   1.1510517E-03,   1.1202424E-03
     +,   1.0946102E-03,   1.0740738E-03,   1.0584632E-03
     +,   1.0475343E-03,   1.0409788E-03,   1.0384319E-03
     +,   1.0394887E-03,   1.0437110E-03,   1.0506461E-03
     +,   1.0598332E-03,   1.0708160E-03,   1.0831523E-03
     +,   1.0964214E-03,   1.1102313E-03,   1.1242259E-03
     +,   1.1380860E-03,   1.1515333E-03,   1.1643318E-03
     +,   1.1762842E-03,   1.1872306E-03,   1.1970485E-03
     +,   1.2056414E-03,   1.2129414E-03,   1.2188981E-03
     +,   1.2234746E-03,   1.2266453E-03,   1.2283847E-03
     +,   1.2286687E-03,   1.2274720E-03,   1.2247629E-03
     +,   1.2205025E-03,   1.2146496E-03,   1.2071589E-03
     +,   1.1979830E-03,   1.1870775E-03,   1.1744032E-03
     +,   1.1599319E-03,   1.1436462E-03,   1.1255488E-03
     +,   1.1056608E-03,   1.0840246E-03,   1.0607064E-03
     +,   1.0357959E-03,   1.0094070E-03,   9.8167371E-04
     +,   9.5274823E-04,   9.2280214E-04,   8.9201680E-04
     +,   8.6058094E-04,   8.2869059E-04,   7.9654076E-04
     +,   7.6432189E-04,   7.3221471E-04,   7.0039253E-04
     +,   6.6901423E-04,   6.3822058E-04,   6.0813548E-04
     +,   5.7886605E-04,   5.5050000E-04,   5.2310625E-04
     +,   4.9673434E-04,   4.7142003E-04,   4.4718178E-04
     +,   4.2402372E-04,   4.0193929E-04,   3.8091178E-04
     +,   3.6091454E-04,   3.4191419E-04,   3.2387365E-04
     +,   3.0675199E-04,   2.9050480E-04,   2.7508696E-04
     +,   2.6045399E-04,   2.4656230E-04,   2.3336873E-04
     +,   2.2083199E-04,   2.0891434E-04,   1.9757914E-04
     +,   1.8679281E-04,   1.7652464E-04,   1.6674671E-04
     +,   1.5743266E-04,   1.4855884E-04,   1.4010408E-04
     +,   1.3204920E-04,   1.2437618E-04,   1.1706859E-04
     +,   1.1011178E-04,   1.0349220E-04,   9.7196760E-05
     +,   9.1213224E-05,   8.5530584E-05,   8.0137768E-05
     +,   7.5024087E-05,   7.0179551E-05,   6.5594366E-05
     +,   6.1258652E-05,   5.7162721E-05,   5.3297244E-05
     +,   4.9653034E-05,   4.6220754E-05,   4.2991185E-05
     +,   3.9955576E-05,   3.7104877E-05,   3.4430606E-05
     +,   3.1924053E-05,   2.9577035E-05,   2.7381273E-05
     +,   2.5329005E-05,   2.3412402E-05,   2.1624148E-05
     +,   1.9956966E-05,   1.8404047E-05,   1.6958689E-05
     +,   1.5614491E-05,   1.4365452E-05,   1.3205688E-05
     +,   1.2129733E-05,   1.1132264E-05,   1.0208336E-05
     +,   9.3531698E-06,   8.5623269E-06,   7.8315115E-06
     +,   7.1567738E-06,   6.5342856E-06,   5.9605309E-06
     +,   5.4321117E-06,   4.9459109E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt70 = Yx/0.378571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.1807855E-05,   8.4358158E-05
     +,   8.6950298E-05,   8.9582878E-05,   9.2254406E-05
     +,   9.4963267E-05,   9.7707649E-05,   1.0048572E-04
     +,   1.0329548E-04,   1.0613492E-04,   1.0900195E-04
     +,   1.1189446E-04,   1.1481034E-04,   1.1774755E-04
     +,   1.2070413E-04,   1.2367827E-04,   1.2666837E-04
     +,   1.2967311E-04,   1.3269145E-04,   1.3572289E-04
     +,   1.3876730E-04,   1.4182519E-04,   1.4489770E-04
     +,   1.4798700E-04,   1.5109578E-04,   1.5422820E-04
     +,   1.5738927E-04,   1.6058558E-04,   1.6382513E-04
     +,   1.6711756E-04,   1.7047457E-04,   1.7390991E-04
     +,   1.7743980E-04,   1.8108312E-04,   1.8486186E-04
     +,   1.8880155E-04,   1.9293152E-04,   1.9728561E-04
     +,   2.0190292E-04,   2.0682790E-04,   2.1211218E-04
     +,   2.1781460E-04,   2.2400293E-04,   2.3075525E-04
     +,   2.3816152E-04,   2.4632565E-04,   2.5536821E-04
     +,   2.6542932E-04,   2.7667230E-04,   2.8928788E-04
     +,   3.0349870E-04,   3.1956384E-04,   3.3778339E-04
     +,   3.5850392E-04,   3.8211775E-04,   4.0906877E-04
     +,   4.3984927E-04,   4.7499902E-04,   5.1510544E-04
     +,   5.6080642E-04,   6.1279943E-04,   6.7186897E-04
     +,   7.3892472E-04,   8.1507920E-04,   9.0174028E-04
     +,   1.0007207E-03,   1.1143826E-03,   1.2457202E-03
     +,   1.3984343E-03,   1.5768446E-03,   1.7857321E-03
     +,   2.0299412E-03,   2.3139678E-03,   2.6414262E-03
     +,   3.0147627E-03,   3.4351686E-03,   3.9028262E-03
     +,   4.4173906E-03,   4.9784346E-03,   5.5854279E-03
     +,   6.2373201E-03,   6.9324221E-03,   7.6691261E-03
     +,   8.4487079E-03,   9.2789941E-03,   1.0177135E-02
     +,   1.1167605E-02,   1.2274798E-02,   1.3512085E-02
     +,   1.4875251E-02,   1.6347237E-02,   1.7917598E-02
     +,   1.9608436E-02,   2.1485234E-02,   2.3630675E-02
     +,   2.6083929E-02,   2.8781954E-02,   3.1549323E-02
     +,   3.4169581E-02,   3.6521167E-02,   3.8693182E-02
     +,   4.0935971E-02,   4.3408737E-02,   4.5948625E-02
     +,   4.8156105E-02,   4.9709190E-02,   5.0512210E-02
     +,   5.0578624E-02,   4.9941536E-02,   4.8711166E-02
     +,   4.7096044E-02,   4.5305707E-02,   4.3444257E-02
     +,   4.1486990E-02,   3.9358139E-02,   3.7042361E-02
     +,   3.4616902E-02,   3.2186206E-02,   2.9820964E-02
     +,   2.7559625E-02,   2.5427263E-02,   2.3428412E-02
     +,   2.1544058E-02,   1.9755976E-02,   1.8071407E-02
     +,   1.6520061E-02,   1.5135080E-02,   1.3941200E-02
     +,   1.2950328E-02,   1.2158345E-02,   1.1541246E-02
     +,   1.1056955E-02,   1.0653942E-02,   1.0283978E-02
     +,   9.9120969E-03,   9.5212683E-03,   9.1111232E-03
     +,   8.6927144E-03,   8.2818931E-03,   7.8935279E-03
     +,   7.5374204E-03,   7.2167697E-03,   6.9286004E-03
     +,   6.6656144E-03,   6.4186794E-03,   6.1789984E-03
     +,   5.9397630E-03,   5.6969561E-03,   5.4493658E-03
     +,   5.1980480E-03,   4.9455115E-03,   4.6949163E-03
     +,   4.4493913E-03,   4.2115585E-03,   3.9833398E-03
     +,   3.7659742E-03,   3.5600786E-03,   3.3657902E-03
     +,   3.1829437E-03,   3.0112050E-03,   2.8501423E-03
     +,   2.6993009E-03,   2.5582588E-03,   2.4266362E-03
     +,   2.3040990E-03,   2.1903638E-03,   2.0852047E-03
     +,   1.9884396E-03,   1.8999083E-03,   1.8194730E-03
     +,   1.7470064E-03,   1.6823850E-03,   1.6254581E-03
     +,   1.5760576E-03,   1.5339827E-03,   1.4989839E-03
     +,   1.4707606E-03,   1.4489554E-03,   1.4331485E-03
     +,   1.4228594E-03,   1.4175464E-03,   1.4166152E-03
     +,   1.4194312E-03,   1.4253241E-03,   1.4336070E-03
     +,   1.4435892E-03,   1.4545900E-03,   1.4659548E-03
     +,   1.4770710E-03,   1.4873717E-03,   1.4963528E-03
     +,   1.5035848E-03,   1.5087030E-03,   1.5114278E-03
     +,   1.5115560E-03,   1.5089622E-03,   1.5035953E-03
     +,   1.4954729E-03,   1.4846788E-03,   1.4713501E-03
     +,   1.4556743E-03,   1.4378793E-03,   1.4182208E-03
     +,   1.3969786E-03,   1.3744446E-03,   1.3509135E-03
     +,   1.3266752E-03,   1.3020103E-03,   1.2771788E-03
     +,   1.2524157E-03,   1.2279251E-03,   1.2038818E-03
     +,   1.1804218E-03,   1.1576444E-03,   1.1356103E-03
     +,   1.1143452E-03,   1.0938415E-03,   1.0740561E-03
     +,   1.0549204E-03,   1.0363422E-03,   1.0182090E-03
     +,   1.0003949E-03,   9.8276453E-04,   9.6518022E-04
     +,   9.4750291E-04,   9.2959910E-04,   9.1134437E-04
     +,   8.9262816E-04,   8.7335217E-04,   8.5343677E-04
     +,   8.3282194E-04,   8.1146701E-04,   7.8935095E-04
     +,   7.6647277E-04,   7.4285269E-04,   7.1852829E-04
     +,   6.9355324E-04,   6.6799979E-04,   6.4195256E-04
     +,   6.1550736E-04,   5.8876799E-04,   5.6184805E-04
     +,   5.3486502E-04,   5.0793763E-04,   4.8118384E-04
     +,   4.5472154E-04,   4.2866461E-04,   4.0311876E-04
     +,   3.7818204E-04,   3.5394687E-04,   3.3049250E-04
     +,   3.0788776E-04,   2.8619170E-04,   2.6545179E-04
     +,   2.4570280E-04,   2.2696839E-04,   2.0926254E-04
     +,   1.9258926E-04,   1.7694203E-04,   1.6230608E-04
     +,   1.4866023E-04,   1.3597684E-04,   1.2422178E-04
     +,   1.1335708E-04,   1.0334209E-04,   9.4132833E-05
     +,   8.5683743E-05,   7.7949073E-05,   7.0882721E-05
     +,   6.4438631E-05,   5.8571739E-05,   5.3238717E-05
     +,   4.8397818E-05,   4.4008939E-05,   4.0034047E-05
     +,   3.6437777E-05,   3.3186483E-05,   3.0249264E-05
     +,   2.7597076E-05,   2.5203466E-05,   2.3043765E-05
     +,   2.1095642E-05,   1.9338442E-05,   1.7753549E-05
     +,   1.6323853E-05,   1.5034010E-05,   1.3869991E-05
     +,   1.2819142E-05,   1.1870120E-05,   1.1012594E-05
     +,   1.0237361E-05,   9.5360574E-06,   8.9012465E-06
     +,   8.3261666E-06,   7.8048197E-06,   7.3317588E-06
     +,   6.9021439E-06,   6.5115905E-06,   6.1562000E-06
     +,   5.8324290E-06,   5.5371379E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt75 = Yx/0.409714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.9648515E-05,   7.3558695E-05
     +,   7.7613156E-05,   8.1808277E-05,   8.6139589E-05
     +,   9.0601818E-05,   9.5188923E-05,   9.9894089E-05
     +,   1.0470974E-04,   1.0962779E-04,   1.1463925E-04
     +,   1.1973469E-04,   1.2490411E-04,   1.3013711E-04
     +,   1.3542282E-04,   1.4075023E-04,   1.4610795E-04
     +,   1.5148456E-04,   1.5686867E-04,   1.6224895E-04
     +,   1.6761420E-04,   1.7295353E-04,   1.7825635E-04
     +,   1.8351297E-04,   1.8871360E-04,   1.9384989E-04
     +,   1.9891374E-04,   2.0389828E-04,   2.0879759E-04
     +,   2.1360681E-04,   2.1832254E-04,   2.2294249E-04
     +,   2.2746599E-04,   2.3189394E-04,   2.3622895E-04
     +,   2.4047543E-04,   2.4463970E-04,   2.4873007E-04
     +,   2.5275745E-04,   2.5673441E-04,   2.6067637E-04
     +,   2.6460114E-04,   2.6852899E-04,   2.7248327E-04
     +,   2.7649035E-04,   2.8057903E-04,   2.8478215E-04
     +,   2.8913553E-04,   2.9367922E-04,   2.9845716E-04
     +,   3.0351797E-04,   3.0891571E-04,   3.1470985E-04
     +,   3.2096746E-04,   3.2776254E-04,   3.3517837E-04
     +,   3.4330905E-04,   3.5225993E-04,   3.6215023E-04
     +,   3.7311422E-04,   3.8530337E-04,   3.9888819E-04
     +,   4.1405894E-04,   4.3102927E-04,   4.5003681E-04
     +,   4.7134241E-04,   4.9523538E-04,   5.2202924E-04
     +,   5.5206736E-04,   5.8571436E-04,   6.2336330E-04
     +,   6.6542084E-04,   7.1231253E-04,   7.6445990E-04
     +,   8.2227914E-04,   8.8615989E-04,   9.5644360E-04
     +,   1.0334031E-03,   1.1172328E-03,   1.2080299E-03
     +,   1.3057844E-03,   1.4104118E-03,   1.5217596E-03
     +,   1.6396946E-03,   1.7641559E-03,   1.8952905E-03
     +,   2.0335529E-03,   2.1798802E-03,   2.3357996E-03
     +,   2.5035958E-03,   2.6863783E-03,   2.8880909E-03
     +,   3.1134391E-03,   3.3677053E-03,   3.6564814E-03
     +,   3.9854064E-03,   4.3601682E-03,   4.7866721E-03
     +,   5.2716723E-03,   5.8232709E-03,   6.4513129E-03
     +,   7.1665244E-03,   7.9786228E-03,   8.8926749E-03
     +,   9.9052982E-03,   1.1001580E-02,   1.2155426E-02
     +,   1.3335511E-02,   1.4516919E-02,   1.5694028E-02
     +,   1.6887218E-02,   1.8137299E-02,   1.9490378E-02
     +,   2.0989317E-02,   2.2687126E-02,   2.4678241E-02
     +,   2.7108938E-02,   3.0112112E-02,   3.3644717E-02
     +,   3.7345149E-02,   4.0657338E-02,   4.3295968E-02
     +,   4.5593116E-02,   4.8141200E-02,   5.1001929E-02
     +,   5.3538952E-02,   5.5181924E-02,   5.6015022E-02
     +,   5.6347616E-02,   5.6077339E-02,   5.4925013E-02
     +,   5.3040795E-02,   5.0863072E-02,   4.8512321E-02
     +,   4.5781434E-02,   4.2649303E-02,   3.9455995E-02
     +,   3.6593165E-02,   3.4206863E-02,   3.2162935E-02
     +,   3.0195339E-02,   2.8111845E-02,   2.5922917E-02
     +,   2.3799298E-02,   2.1910060E-02,   2.0298375E-02
     +,   1.8889578E-02,   1.7583860E-02,   1.6327703E-02
     +,   1.5118684E-02,   1.3973121E-02,   1.2902062E-02
     +,   1.1908770E-02,   1.0995554E-02,   1.0166997E-02
     +,   9.4274106E-03,   8.7762522E-03,   8.2056001E-03
     +,   7.7008558E-03,   7.2438326E-03,   6.8164733E-03
     +,   6.4042415E-03,   5.9981630E-03,   5.5951998E-03
     +,   5.1972852E-03,   4.8095626E-03,   4.4384594E-03
     +,   4.0899510E-03,   3.7685200E-03,   3.4767846E-03
     +,   3.2156766E-03,   2.9848763E-03,   2.7833062E-03
     +,   2.6095363E-03,   2.4620423E-03,   2.3392404E-03
     +,   2.2394801E-03,   2.1609955E-03,   2.1018437E-03
     +,   2.0598921E-03,   2.0328541E-03,   2.0183395E-03
     +,   2.0139304E-03,   2.0172603E-03,   2.0260881E-03
     +,   2.0383596E-03,   2.0522589E-03,   2.0662360E-03
     +,   2.0790328E-03,   2.0896781E-03,   2.0974842E-03
     +,   2.1020211E-03,   2.1031038E-03,   2.1007448E-03
     +,   2.0951328E-03,   2.0865954E-03,   2.0755602E-03
     +,   2.0625263E-03,   2.0480293E-03,   2.0326080E-03
     +,   2.0167807E-03,   2.0010157E-03,   1.9857013E-03
     +,   1.9711335E-03,   1.9574948E-03,   1.9448404E-03
     +,   1.9330996E-03,   1.9220726E-03,   1.9114374E-03
     +,   1.9007722E-03,   1.8895684E-03,   1.8772632E-03
     +,   1.8632708E-03,   1.8470035E-03,   1.8279138E-03
     +,   1.8055161E-03,   1.7794125E-03,   1.7493085E-03
     +,   1.7150264E-03,   1.6765167E-03,   1.6338450E-03
     +,   1.5871970E-03,   1.5368651E-03,   1.4832311E-03
     +,   1.4267500E-03,   1.3679296E-03,   1.3073203E-03
     +,   1.2454911E-03,   1.1830085E-03,   1.1204267E-03
     +,   1.0582787E-03,   9.9705753E-04,   9.3720778E-04
     +,   8.7912014E-04,   8.2313258E-04,   7.6951599E-04
     +,   7.1848067E-04,   6.7017839E-04,   6.2470319E-04
     +,   5.8209046E-04,   5.4232753E-04,   5.0536043E-04
     +,   4.7109887E-04,   4.3942023E-04,   4.1018042E-04
     +,   3.8322111E-04,   3.5837546E-04,   3.3547060E-04
     +,   3.1433647E-04,   2.9480996E-04,   2.7673482E-04
     +,   2.5996618E-04,   2.4437264E-04,   2.2983576E-04
     +,   2.1624949E-04,   2.0352050E-04,   1.9156856E-04
     +,   1.8032410E-04,   1.6972671E-04,   1.5972466E-04
     +,   1.5027412E-04,   1.4133738E-04,   1.3288116E-04
     +,   1.2487661E-04,   1.1729872E-04,   1.1012462E-04
     +,   1.0333332E-04,   9.6906217E-05,   9.0825866E-05
     +,   8.5075568E-05,   7.9639503E-05,   7.4503005E-05
     +,   6.9652036E-05,   6.5072883E-05,   6.0752314E-05
     +,   5.6678229E-05,   5.2838324E-05,   4.9221457E-05
     +,   4.5816378E-05,   4.2612875E-05,   3.9600680E-05
     +,   3.6770445E-05,   3.4112800E-05,   3.1619216E-05
     +,   2.9281164E-05,   2.7090831E-05,   2.5040519E-05
     +,   2.3122857E-05,   2.1331018E-05,   1.9658186E-05
     +,   1.8098071E-05,   1.6644444E-05,   1.5291515E-05
     +,   1.4033554E-05,   1.2865250E-05,   1.1781335E-05
     +,   1.0776921E-05,   9.8471846E-06,   8.9876357E-06
     +,   8.1938688E-06,   7.4617742E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt80 = Yx/0.44156
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3059150E-05,   4.4262706E-05
     +,   4.5494598E-05,   4.6756941E-05,   4.8052130E-05
     +,   4.9382765E-05,   5.0751794E-05,   5.2162384E-05
     +,   5.3617998E-05,   5.5122448E-05,   5.6679812E-05
     +,   5.8294452E-05,   5.9971033E-05,   6.1714542E-05
     +,   6.3530220E-05,   6.5423643E-05,   6.7400571E-05
     +,   6.9467045E-05,   7.1629307E-05,   7.3893832E-05
     +,   7.6267177E-05,   7.8756042E-05,   8.1367172E-05
     +,   8.4107487E-05,   8.6983600E-05,   9.0002315E-05
     +,   9.3170063E-05,   9.6493211E-05,   9.9977813E-05
     +,   1.0362951E-04,   1.0745356E-04,   1.1145473E-04
     +,   1.1563717E-04,   1.2000452E-04,   1.2455953E-04
     +,   1.2930432E-04,   1.3424008E-04,   1.3936705E-04
     +,   1.4468498E-04,   1.5019189E-04,   1.5588559E-04
     +,   1.6176233E-04,   1.6781779E-04,   1.7404638E-04
     +,   1.8044174E-04,   1.8699643E-04,   1.9370261E-04
     +,   2.0055138E-04,   2.0753342E-04,   2.1463897E-04
     +,   2.2185793E-04,   2.2918011E-04,   2.3659520E-04
     +,   2.4409377E-04,   2.5166594E-04,   2.5930346E-04
     +,   2.6699807E-04,   2.7474313E-04,   2.8253326E-04
     +,   2.9036423E-04,   2.9823356E-04,   3.0614049E-04
     +,   3.1408572E-04,   3.2207259E-04,   3.3010595E-04
     +,   3.3819239E-04,   3.4634193E-04,   3.5456548E-04
     +,   3.6287811E-04,   3.7129715E-04,   3.7984480E-04
     +,   3.8854740E-04,   3.9743874E-04,   4.0655964E-04
     +,   4.1596242E-04,   4.2571319E-04,   4.3589447E-04
     +,   4.4661027E-04,   4.5799161E-04,   4.7020154E-04
     +,   4.8343971E-04,   4.9795036E-04,   5.1402737E-04
     +,   5.3202041E-04,   5.5233564E-04,   5.7544338E-04
     +,   6.0187152E-04,   6.3220673E-04,   6.6707941E-04
     +,   7.0715672E-04,   7.5312017E-04,   8.0563780E-04
     +,   8.6533494E-04,   9.3276514E-04,   1.0083736E-03
     +,   1.0924533E-03,   1.1851357E-03,   1.2863559E-03
     +,   1.3958731E-03,   1.5132722E-03,   1.6380382E-03
     +,   1.7696008E-03,   1.9074657E-03,   2.0512887E-03
     +,   2.2010275E-03,   2.3570277E-03,   2.5200988E-03
     +,   2.6915604E-03,   2.8732517E-03,   3.0674723E-03
     +,   3.2768496E-03,   3.5042472E-03,   3.7525434E-03
     +,   4.0245298E-03,   4.3227896E-03,   4.6498636E-03
     +,   5.0085131E-03,   5.4022814E-03,   5.8357506E-03
     +,   6.3143424E-03,   6.8430337E-03,   7.4242251E-03
     +,   8.0563007E-03,   8.7348344E-03,   9.4580036E-03
     +,   1.0235013E-02,   1.1093332E-02,   1.2078537E-02
     +,   1.3245416E-02,   1.4642750E-02,   1.6299633E-02
     +,   1.8216444E-02,   2.0365030E-02,   2.2702461E-02
     +,   2.5203260E-02,   2.7890556E-02,   3.0819789E-02
     +,   3.3972949E-02,   3.7121750E-02,   3.9869364E-02
     +,   4.2015083E-02,   4.3926600E-02,   4.6298385E-02
     +,   4.9322598E-02,   5.2317586E-02,   5.4513089E-02
     +,   5.5969495E-02,   5.7241835E-02,   5.8364850E-02
     +,   5.8863118E-02,   5.8657546E-02,   5.8097318E-02
     +,   5.7055261E-02,   5.4885846E-02,   5.1378839E-02
     +,   4.7087140E-02,   4.2746335E-02,   3.8802132E-02
     +,   3.5375874E-02,   3.2368228E-02,   2.9589064E-02
     +,   2.6898503E-02,   2.4266312E-02,   2.1725968E-02
     +,   1.9304486E-02,   1.7001493E-02,   1.4814378E-02
     +,   1.2763919E-02,   1.0892933E-02,   9.2447568E-03
     +,   7.8439480E-03,   6.6905743E-03,   5.7659298E-03
     +,   5.0419034E-03,   4.4885739E-03,   4.0784329E-03
     +,   3.7879969E-03,   3.5975550E-03,   3.4901109E-03
     +,   3.4506074E-03,   3.4654620E-03,   3.5225218E-03
     +,   3.6110973E-03,   3.7219636E-03,   3.8471904E-03
     +,   3.9798850E-03,   4.1139806E-03,   4.2440980E-03
     +,   4.3654605E-03,   4.4739302E-03,   4.5661321E-03
     +,   4.6395781E-03,   4.6927705E-03,   4.7253119E-03
     +,   4.7378875E-03,   4.7321427E-03,   4.7104480E-03
     +,   4.6755848E-03,   4.6303323E-03,   4.5770942E-03
     +,   4.5176027E-03,   4.4527147E-03,   4.3824101E-03
     +,   4.3059434E-03,   4.2221062E-03,   4.1295909E-03
     +,   4.0273420E-03,   3.9148615E-03,   3.7923888E-03
     +,   3.6609508E-03,   3.5223190E-03,   3.3788150E-03
     +,   3.2330907E-03,   3.0878559E-03,   2.9456394E-03
     +,   2.8086165E-03,   2.6784611E-03,   2.5562681E-03
     +,   2.4425718E-03,   2.3373852E-03,   2.2402720E-03
     +,   2.1504504E-03,   2.0669166E-03,   1.9885423E-03
     +,   1.9141670E-03,   1.8426900E-03,   1.7731399E-03
     +,   1.7047145E-03,   1.6368045E-03,   1.5690030E-03
     +,   1.5011055E-03,   1.4330834E-03,   1.3650473E-03
     +,   1.2972153E-03,   1.2298906E-03,   1.1634043E-03
     +,   1.0980961E-03,   1.0342936E-03,   9.7229192E-04
     +,   9.1233518E-04,   8.5461675E-04,   7.9928216E-04
     +,   7.4642902E-04,   6.9610716E-04,   6.4832933E-04
     +,   6.0308265E-04,   5.6032877E-04,   5.2000978E-04
     +,   4.8205530E-04,   4.4638978E-04,   4.1292820E-04
     +,   3.8158279E-04,   3.5226648E-04,   3.2489104E-04
     +,   2.9936724E-04,   2.7560673E-04,   2.5352367E-04
     +,   2.3303364E-04,   2.1405205E-04,   1.9649621E-04
     +,   1.8028628E-04,   1.6534371E-04,   1.5159104E-04
     +,   1.3895276E-04,   1.2735681E-04,   1.1673207E-04
     +,   1.0700992E-04,   9.8125063E-05,   9.0014779E-05
     +,   8.2618673E-05,   7.5879332E-05,   6.9742913E-05
     +,   6.4158667E-05,   5.9078509E-05,   5.4457621E-05
     +,   5.0254741E-05,   4.6431109E-05,   4.2951422E-05
     +,   3.9782797E-05,   3.6895544E-05,   3.4262215E-05
     +,   3.1858151E-05,   2.9660760E-05,   2.7649847E-05
     +,   2.5806974E-05,   2.4115823E-05,   2.2561573E-05
     +,   2.1130965E-05,   1.9812291E-05,   1.8594928E-05
     +,   1.7469549E-05,   1.6427704E-05,   1.5461992E-05
     +,   1.4565685E-05,   1.3732888E-05,   1.2958239E-05
     +,   1.2237018E-05,   1.1564915E-05,   1.0938124E-05
     +,   1.0353134E-05,   9.8068476E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt85 = Yx/0.44464
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.8082340E-05,   4.9663755E-05
     +,   5.1275103E-05,   5.2915493E-05,   5.4583907E-05
     +,   5.6279245E-05,   5.8000282E-05,   5.9745715E-05
     +,   6.1514096E-05,   6.3303974E-05,   6.5113745E-05
     +,   6.6941728E-05,   6.8786212E-05,   7.0645423E-05
     +,   7.2517469E-05,   7.4400501E-05,   7.6292599E-05
     +,   7.8191893E-05,   8.0096426E-05,   8.2004321E-05
     +,   8.3913714E-05,   8.5822787E-05,   8.7729779E-05
     +,   8.9633133E-05,   9.1531125E-05,   9.3422459E-05
     +,   9.5305761E-05,   9.7179902E-05,   9.9043878E-05
     +,   1.0089688E-04,   1.0273836E-04,   1.0456786E-04
     +,   1.0638525E-04,   1.0819062E-04,   1.0998429E-04
     +,   1.1176681E-04,   1.1353903E-04,   1.1530211E-04
     +,   1.1705740E-04,   1.1880654E-04,   1.2055153E-04
     +,   1.2229453E-04,   1.2403799E-04,   1.2578472E-04
     +,   1.2753776E-04,   1.2930032E-04,   1.3107594E-04
     +,   1.3286846E-04,   1.3468192E-04,   1.3652063E-04
     +,   1.3838914E-04,   1.4029226E-04,   1.4223522E-04
     +,   1.4422348E-04,   1.4626268E-04,   1.4835921E-04
     +,   1.5051954E-04,   1.5275089E-04,   1.5506086E-04
     +,   1.5745775E-04,   1.5995068E-04,   1.6254968E-04
     +,   1.6526536E-04,   1.6810975E-04,   1.7109625E-04
     +,   1.7423900E-04,   1.7755426E-04,   1.8105931E-04
     +,   1.8477371E-04,   1.8871816E-04,   1.9291574E-04
     +,   1.9739104E-04,   2.0217092E-04,   2.0728342E-04
     +,   2.1275891E-04,   2.1862915E-04,   2.2492708E-04
     +,   2.3168619E-04,   2.3894125E-04,   2.4672726E-04
     +,   2.5507782E-04,   2.6402716E-04,   2.7360604E-04
     +,   2.8384491E-04,   2.9476985E-04,   3.0640454E-04
     +,   3.1876744E-04,   3.3187406E-04,   3.4573258E-04
     +,   3.6034797E-04,   3.7571983E-04,   3.9184158E-04
     +,   4.0870238E-04,   4.2628916E-04,   4.4458674E-04
     +,   4.6357777E-04,   4.8324993E-04,   5.0359266E-04
     +,   5.2460731E-04,   5.4630451E-04,   5.6871475E-04
     +,   5.9188815E-04,   6.1590527E-04,   6.4087805E-04
     +,   6.6696148E-04,   6.9435866E-04,   7.2332722E-04
     +,   7.5418846E-04,   7.8733871E-04,   8.2325604E-04
     +,   8.6250651E-04,   9.0575771E-04,   9.5378078E-04
     +,   1.0074636E-03,   1.0678048E-03,   1.1359263E-03
     +,   1.2130559E-03,   1.3005302E-03,   1.3997514E-03
     +,   1.5121694E-03,   1.6392106E-03,   1.7821828E-03
     +,   1.9421733E-03,   2.1199416E-03,   2.3157911E-03
     +,   2.5295061E-03,   2.7604334E-03,   3.0076317E-03
     +,   3.2703197E-03,   3.5484275E-03,   3.8433471E-03
     +,   4.1585891E-03,   4.5003388E-03,   4.8774434E-03
     +,   5.3009195E-03,   5.7826489E-03,   6.3334103E-03
     +,   6.9603655E-03,   7.6645715E-03,   8.4387697E-03
     +,   9.2664668E-03,   1.0123373E-02,   1.0981736E-02
     +,   1.1817305E-02,   1.2617429E-02,   1.3387993E-02
     +,   1.4156266E-02,   1.4969304E-02,   1.5889693E-02
     +,   1.6990507E-02,   1.8347822E-02,   2.0025276E-02
     +,   2.2050194E-02,   2.4391368E-02,   2.6954612E-02
     +,   2.9604377E-02,   3.2213703E-02,   3.4734853E-02
     +,   3.7238140E-02,   3.9823897E-02,   4.2421132E-02
     +,   4.4708103E-02,   4.6370067E-02,   4.7456466E-02
     +,   4.8332423E-02,   4.9209841E-02,   4.9836494E-02
     +,   4.9686886E-02,   4.8358615E-02,   4.5797873E-02
     +,   4.2292662E-02,   3.8282961E-02,   3.4120519E-02
     +,   3.0009657E-02,   2.6148992E-02,   2.2819282E-02
     +,   2.0284515E-02,   1.8644666E-02,   1.7808964E-02
     +,   1.7593138E-02,   1.7831838E-02,   1.8420933E-02
     +,   1.9287735E-02,   2.0343084E-02,   2.1463800E-02
     +,   2.2511654E-02,   2.3363529E-02,   2.3929020E-02
     +,   2.4157999E-02,   2.4047691E-02,   2.3646774E-02
     +,   2.3041353E-02,   2.2318440E-02,   2.1527471E-02
     +,   2.0669295E-02,   1.9721858E-02,   1.8679745E-02
     +,   1.7574236E-02,   1.6461181E-02,   1.5392541E-02
     +,   1.4395859E-02,   1.3473409E-02,   1.2615306E-02
     +,   1.1813693E-02,   1.1069595E-02,   1.0391623E-02
     +,   9.7905770E-03,   9.2736380E-03,   8.8405823E-03
     +,   8.4826937E-03,   8.1839869E-03,   7.9239896E-03
     +,   7.6810895E-03,   7.4358303E-03,   7.1734292E-03
     +,   6.8853255E-03,   6.5694773E-03,   6.2296567E-03
     +,   5.8740093E-03,   5.5132615E-03,   5.1587964E-03
     +,   4.8209932E-03,   4.5080269E-03,   4.2250846E-03
     +,   3.9741048E-03,   3.7540530E-03,   3.5615177E-03
     +,   3.3914647E-03,   3.2381101E-03,   3.0956785E-03
     +,   2.9590374E-03,   2.8240830E-03,   2.6879287E-03
     +,   2.5489361E-03,   2.4066039E-03,   2.2613462E-03
     +,   2.1142587E-03,   1.9668778E-03,   1.8209552E-03
     +,   1.6782391E-03,   1.5403461E-03,   1.4086607E-03
     +,   1.2842638E-03,   1.1678999E-03,   1.0599946E-03
     +,   9.6069073E-04,   8.6988410E-04,   7.8727159E-04
     +,   7.1241008E-04,   6.4477464E-04,   5.8378477E-04
     +,   5.2884716E-04,   4.7938505E-04,   4.3485017E-04
     +,   3.9473121E-04,   3.5856204E-04,   3.2592486E-04
     +,   2.9644585E-04,   2.6978966E-04,   2.4565912E-04
     +,   2.2379222E-04,   2.0395609E-04,   1.8594283E-04
     +,   1.6956784E-04,   1.5466881E-04,   1.4109979E-04
     +,   1.2873129E-04,   1.1744857E-04,   1.0714952E-04
     +,   9.7742406E-05,   8.9145418E-05,   8.1285827E-05
     +,   7.4098658E-05,   6.7524874E-05,   6.1511579E-05
     +,   5.6011504E-05,   5.0981282E-05,   4.6382189E-05
     +,   4.2178468E-05,   3.8338065E-05,   3.4831191E-05
     +,   3.1631054E-05,   2.8712611E-05,   2.6053225E-05
     +,   2.3631670E-05,   2.1428683E-05,   1.9426208E-05
     +,   1.7607546E-05,   1.5957399E-05,   1.4461359E-05
     +,   1.3106271E-05,   1.1879749E-05,   1.0770489E-05
     +,   9.7678785E-06,   8.8622364E-06,   8.0445079E-06
     +,   7.3064612E-06,   6.6404273E-06,   6.0394614E-06
     +,   5.4971283E-06,   5.0076228E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt90 = Yx/0.45486
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4383504E-05,   2.5209192E-05
     +,   2.6055024E-05,   2.6921438E-05,   2.7808886E-05
     +,   2.8717848E-05,   2.9648831E-05,   3.0602379E-05
     +,   3.1579038E-05,   3.2579435E-05,   3.3604203E-05
     +,   3.4654026E-05,   3.5729598E-05,   3.6831687E-05
     +,   3.7961123E-05,   3.9118746E-05,   4.0305473E-05
     +,   4.1522282E-05,   4.2770193E-05,   4.4050299E-05
     +,   4.5363780E-05,   4.6711866E-05,   4.8095844E-05
     +,   4.9517195E-05,   5.0977262E-05,   5.2477691E-05
     +,   5.4020122E-05,   5.5606270E-05,   5.7237950E-05
     +,   5.8917114E-05,   6.0645765E-05,   6.2425977E-05
     +,   6.4259955E-05,   6.6149958E-05,   6.8098336E-05
     +,   7.0107511E-05,   7.2180010E-05,   7.4318254E-05
     +,   7.6524957E-05,   7.8802608E-05,   8.1153870E-05
     +,   8.3581392E-05,   8.6087697E-05,   8.8675362E-05
     +,   9.1346810E-05,   9.4104435E-05,   9.6950454E-05
     +,   9.9887009E-05,   1.0291598E-04,   1.0603909E-04
     +,   1.0925784E-04,   1.1257344E-04,   1.1598680E-04
     +,   1.1949871E-04,   1.2310923E-04,   1.2681853E-04
     +,   1.3062614E-04,   1.3453125E-04,   1.3853276E-04
     +,   1.4262913E-04,   1.4681845E-04,   1.5109862E-04
     +,   1.5546686E-04,   1.5992032E-04,   1.6445620E-04
     +,   1.6907082E-04,   1.7376100E-04,   1.7852293E-04
     +,   1.8335320E-04,   1.8824825E-04,   1.9320488E-04
     +,   1.9821987E-04,   2.0329103E-04,   2.0841575E-04
     +,   2.1359295E-04,   2.1882237E-04,   2.2410433E-04
     +,   2.2944051E-04,   2.3483437E-04,   2.4029109E-04
     +,   2.4581738E-04,   2.5142301E-04,   2.5711971E-04
     +,   2.6292269E-04,   2.6885048E-04,   2.7492549E-04
     +,   2.8117411E-04,   2.8762818E-04,   2.9432360E-04
     +,   3.0130276E-04,   3.0861361E-04,   3.1630995E-04
     +,   3.2445171E-04,   3.3310550E-04,   3.4234379E-04
     +,   3.5224354E-04,   3.6288783E-04,   3.7436173E-04
     +,   3.8675391E-04,   4.0015182E-04,   4.1464262E-04
     +,   4.3030726E-04,   4.4722151E-04,   4.6544822E-04
     +,   4.8503876E-04,   5.0602754E-04,   5.2842777E-04
     +,   5.5222964E-04,   5.7739904E-04,   6.0387602E-04
     +,   6.3156948E-04,   6.6036615E-04,   6.9012406E-04
     +,   7.2068512E-04,   7.5187394E-04,   7.8351458E-04
     +,   8.1543531E-04,   8.4749231E-04,   8.7957655E-04
     +,   9.1164728E-04,   9.4374735E-04,   9.7602606E-04
     +,   1.0087690E-03,   1.0424198E-03,   1.0775963E-03
     +,   1.1151050E-03,   1.1559412E-03,   1.2012819E-03
     +,   1.2524629E-03,   1.3109299E-03,   1.3781809E-03
     +,   1.4556706E-03,   1.5447146E-03,   1.6463483E-03
     +,   1.7612058E-03,   1.8893816E-03,   2.0303132E-03
     +,   2.1827233E-03,   2.3446477E-03,   2.5135297E-03
     +,   2.6864407E-03,   2.8604132E-03,   3.0328699E-03
     +,   3.2020549E-03,   3.3674170E-03,   3.5298858E-03
     +,   3.6919015E-03,   3.8571635E-03,   4.0301112E-03
     +,   4.2152433E-03,   4.4163433E-03,   4.6358583E-03
     +,   4.8746755E-03,   5.1323520E-03,   5.4077408E-03
     +,   5.6998357E-03,   6.0084113E-03,   6.3340478E-03
     +,   6.6771405E-03,   7.0359753E-03,   7.4043954E-03
     +,   7.7697420E-03,   8.1121614E-03,   8.4059890E-03
     +,   8.6233942E-03,   8.7396754E-03,   8.7389722E-03
     +,   8.6189918E-03,   8.3932932E-03,   8.0907550E-03
     +,   7.7526220E-03,   7.4280687E-03,   7.1693552E-03
     +,   7.0277164E-03,   7.0502902E-03,   7.2793779E-03
     +,   7.7550951E-03,   8.5213520E-03,   9.6305273E-03
     +,   1.1139289E-02,   1.3089758E-02,   1.5481066E-02
     +,   1.8248497E-02,   2.1271642E-02,   2.4429012E-02
     +,   2.7694199E-02,   3.1206913E-02,   3.5192024E-02
     +,   3.9734654E-02,   4.4670530E-02,   4.9692135E-02
     +,   5.4369483E-02,   5.8075301E-02,   6.0222574E-02
     +,   6.0753349E-02,   6.0305856E-02,   5.9660155E-02
     +,   5.8814436E-02,   5.6993559E-02,   5.3927571E-02
     +,   5.0479736E-02,   4.7607783E-02,   4.5394160E-02
     +,   4.3348577E-02,   4.1088428E-02,   3.8558979E-02
     +,   3.5896342E-02,   3.3217069E-02,   3.0546697E-02
     +,   2.7909670E-02,   2.5389235E-02,   2.3082558E-02
     +,   2.1054914E-02,   1.9334812E-02,   1.7909581E-02
     +,   1.6721455E-02,   1.5690148E-02,   1.4750544E-02
     +,   1.3871571E-02,   1.3046413E-02,   1.2271413E-02
     +,   1.1533684E-02,   1.0812405E-02,   1.0087687E-02
     +,   9.3489205E-03,   8.5982513E-03,   7.8485133E-03
     +,   7.1180286E-03,   6.4249979E-03,   5.7835430E-03
     +,   5.2020345E-03,   4.6831933E-03,   4.2253304E-03
     +,   3.8239621E-03,   3.4731778E-03,   3.1664832E-03
     +,   2.8974062E-03,   2.6598170E-03,   2.4481106E-03
     +,   2.2573494E-03,   2.0833923E-03,   1.9229538E-03
     +,   1.7735802E-03,   1.6335559E-03,   1.5017887E-03
     +,   1.3776510E-03,   1.2608225E-03,   1.1511374E-03
     +,   1.0484952E-03,   9.5279707E-04,   8.6389086E-04
     +,   7.8156829E-04,   7.0557941E-04,   6.3563715E-04
     +,   5.7143072E-04,   5.1264430E-04,   4.5897046E-04
     +,   4.1011022E-04,   3.6577045E-04,   3.2566732E-04
     +,   2.8952578E-04,   2.5707379E-04,   2.2803948E-04
     +,   2.0215371E-04,   1.7915299E-04,   1.5877633E-04
     +,   1.4077112E-04,   1.2489631E-04,   1.1092361E-04
     +,   9.8638789E-05,   8.7844404E-05,   7.8361038E-05
     +,   7.0026748E-05,   6.2696192E-05,   5.6240617E-05
     +,   5.0547285E-05,   4.5516746E-05,   4.1063031E-05
     +,   3.7110924E-05,   3.3595796E-05,   3.0461364E-05
     +,   2.7659458E-05,   2.5148171E-05,   2.2891722E-05
     +,   2.0858981E-05,   1.9023408E-05,   1.7361930E-05
     +,   1.5854657E-05,   1.4484572E-05,   1.3236789E-05
     +,   1.2098573E-05,   1.1058739E-05,   1.0107681E-05
     +,   9.2368864E-06,   8.4389985E-06,   7.7074419E-06
     +,   7.0364804E-06,   6.4209248E-06,   5.8562064E-06
     +,   5.3381395E-06,   4.8630072E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_htt95 = Yx/0.4382
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3429468E-06,   4.6837354E-06
     +,   5.0445615E-06,   5.4260108E-06,   5.8286359E-06
     +,   6.2529589E-06,   6.6994626E-06,   7.1685895E-06
     +,   7.6607384E-06,   8.1762773E-06,   8.7155131E-06
     +,   9.2787059E-06,   9.8660721E-06,   1.0477773E-05
     +,   1.1113928E-05,   1.1774600E-05,   1.2459813E-05
     +,   1.3169544E-05,   1.3903721E-05,   1.4662251E-05
     +,   1.5444986E-05,   1.6251766E-05,   1.7082390E-05
     +,   1.7936691E-05,   1.8814395E-05,   1.9715328E-05
     +,   2.0639254E-05,   2.1585973E-05,   2.2555299E-05
     +,   2.3547067E-05,   2.4561155E-05,   2.5597481E-05
     +,   2.6655998E-05,   2.7736727E-05,   2.8839735E-05
     +,   2.9965149E-05,   3.1113188E-05,   3.2284068E-05
     +,   3.3478194E-05,   3.4695870E-05,   3.5937610E-05
     +,   3.7203899E-05,   3.8495295E-05,   3.9812396E-05
     +,   4.1155810E-05,   4.2526190E-05,   4.3924174E-05
     +,   4.5350382E-05,   4.6805435E-05,   4.8289861E-05
     +,   4.9804145E-05,   5.1348678E-05,   5.2923722E-05
     +,   5.4529515E-05,   5.6165947E-05,   5.7832927E-05
     +,   5.9530121E-05,   6.1256927E-05,   6.3012616E-05
     +,   6.4796164E-05,   6.6606313E-05,   6.8441637E-05
     +,   7.0300273E-05,   7.2180286E-05,   7.4079522E-05
     +,   7.5995318E-05,   7.7925135E-05,   7.9865895E-05
     +,   8.1814585E-05,   8.3767838E-05,   8.5722313E-05
     +,   8.7674329E-05,   8.9620400E-05,   9.1556765E-05
     +,   9.3479794E-05,   9.5385971E-05,   9.7271644E-05
     +,   9.9133344E-05,   1.0096794E-04,   1.0277246E-04
     +,   1.0454401E-04,   1.0628020E-04,   1.0797886E-04
     +,   1.0963833E-04,   1.1125718E-04,   1.1283471E-04
     +,   1.1437047E-04,   1.1586474E-04,   1.1731828E-04
     +,   1.1873263E-04,   1.2011002E-04,   1.2145350E-04
     +,   1.2276696E-04,   1.2405537E-04,   1.2532502E-04
     +,   1.2658330E-04,   1.2783942E-04,   1.2910426E-04
     +,   1.3039098E-04,   1.3171515E-04,   1.3309541E-04
     +,   1.3455356E-04,   1.3611549E-04,   1.3781138E-04
     +,   1.3967646E-04,   1.4175169E-04,   1.4408404E-04
     +,   1.4672700E-04,   1.4974142E-04,   1.5319559E-04
     +,   1.5716498E-04,   1.6173303E-04,   1.6698962E-04
     +,   1.7303151E-04,   1.7996006E-04,   1.8788090E-04
     +,   1.9690007E-04,   2.0712386E-04,   2.1865273E-04
     +,   2.3158028E-04,   2.4598822E-04,   2.6194117E-04
     +,   2.7948219E-04,   2.9862984E-04,   3.1937243E-04
     +,   3.4166168E-04,   3.6541422E-04,   3.9050289E-04
     +,   4.1676196E-04,   4.4397978E-04,   4.7190796E-04
     +,   5.0025748E-04,   5.2871113E-04,   5.5692287E-04
     +,   5.8453251E-04,   6.1117398E-04,   6.3648325E-04
     +,   6.6011213E-04,   6.8174140E-04,   7.0108887E-04
     +,   7.1791961E-04,   7.3205505E-04,   7.4337760E-04
     +,   7.5183710E-04,   7.5744768E-04,   7.6028873E-04
     +,   7.6049933E-04,   7.5827213E-04,   7.5384433E-04
     +,   7.4748625E-04,   7.3949218E-04,   7.3016825E-04
     +,   7.1982213E-04,   7.0875254E-04,   6.9724198E-04
     +,   6.8555254E-04,   6.7392044E-04,   6.6255493E-04
     +,   6.5164146E-04,   6.4134592E-04,   6.3181727E-04
     +,   6.2319753E-04,   6.1562791E-04,   6.0925592E-04
     +,   6.0424226E-04,   6.0076365E-04,   5.9901649E-04
     +,   5.9921405E-04,   6.0158299E-04,   6.0635753E-04
     +,   6.1377318E-04,   6.2406150E-04,   6.3745468E-04
     +,   6.5419701E-04,   6.7456701E-04,   6.9892313E-04
     +,   7.2775170E-04,   7.6172140E-04,   8.0173422E-04
     +,   8.4895623E-04,   9.0481329E-04,   9.7094214E-04
     +,   1.0491186E-03,   1.1411658E-03,   1.2488544E-03
     +,   1.3737993E-03,   1.5173687E-03,   1.6805835E-03
     +,   1.8640090E-03,   2.0676986E-03,   2.2914286E-03
     +,   2.5352819E-03,   2.8006961E-03,   3.0917511E-03
     +,   3.4160612E-03,   3.7845466E-03,   4.2099543E-03
     +,   4.7051143E-03,   5.2821580E-03,   5.9525874E-03
     +,   6.7254147E-03,   7.6006385E-03,   8.5597634E-03
     +,   9.5623508E-03,   1.0558853E-02,   1.1519372E-02
     +,   1.2460500E-02,   1.3444918E-02,   1.4540201E-02
     +,   1.5752304E-02,   1.6980145E-02,   1.8042272E-02
     +,   1.8778602E-02,   1.9152839E-02,   1.9260764E-02
     +,   1.9234734E-02,   1.9143626E-02,   1.8988047E-02
     +,   1.8773507E-02,   1.8549558E-02,   1.8357985E-02
     +,   1.8164400E-02,   1.7870035E-02,   1.7385490E-02
     +,   1.6668480E-02,   1.5696174E-02,   1.4440920E-02
     +,   1.2902518E-02,   1.1160462E-02,   9.3768127E-03
     +,   7.7344500E-03,   6.3601551E-03,   5.2882987E-03
     +,   4.4785407E-03,   3.8602233E-03,   3.3693376E-03
     +,   2.9634349E-03,   2.6187720E-03,   2.3216042E-03
     +,   2.0618080E-03,   1.8307427E-03,   1.6215623E-03
     +,   1.4298379E-03,   1.2534701E-03,   1.0919635E-03
     +,   9.4550691E-04,   8.1425259E-04,   6.9795205E-04
     +,   5.9591437E-04,   5.0712185E-04,   4.3036227E-04
     +,   3.6437385E-04,   3.0793188E-04,   2.5988687E-04
     +,   2.1917740E-04,   1.8483582E-04,   1.5598522E-04
     +,   1.3183242E-04,   1.1166398E-04,   9.4846575E-05
     +,   8.0825928E-05,   6.9122580E-05,   5.9327558E-05
     +,   5.1098075E-05,   4.4151544E-05,   3.8256694E-05
     +,   3.3226916E-05,   2.8913000E-05,   2.5195772E-05
     +,   2.1979780E-05,   1.9188394E-05,   1.6759657E-05
     +,   1.4642672E-05,   1.2794946E-05,   1.1180662E-05
     +,   9.7693937E-06,   8.5347674E-06,   7.4541176E-06
     +,   6.5076129E-06,   5.6781437E-06,   4.9507507E-06
     +,   4.3125547E-06,   3.7523214E-06,   3.2604153E-06
     +,   2.8284423E-06,   2.4492037E-06,   2.1164217E-06
     +,   1.8246488E-06,   1.5691596E-06,   1.3457811E-06
     +,   1.1508675E-06,   9.8116413E-07,   8.3380104E-07
     +,   7.0619410E-07,   5.9604554E-07,   5.0127790E-07
     +,   4.2003617E-07,   3.5064321E-07,   2.9160208E-07
     +,   2.4156415E-07,   1.9933154E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz100 = Yx/0.1405
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9043560E-05,   1.9419234E-05
     +,   1.9793690E-05,   2.0166692E-05,   2.0538024E-05
     +,   2.0907501E-05,   2.1274973E-05,   2.1640319E-05
     +,   2.2003449E-05,   2.2364346E-05,   2.2723005E-05
     +,   2.3079483E-05,   2.3433895E-05,   2.3786406E-05
     +,   2.4137247E-05,   2.4486699E-05,   2.4835124E-05
     +,   2.5182950E-05,   2.5530666E-05,   2.5878848E-05
     +,   2.6228139E-05,   2.6579261E-05,   2.6933001E-05
     +,   2.7290260E-05,   2.7651966E-05,   2.8019167E-05
     +,   2.8392964E-05,   2.8774537E-05,   2.9165139E-05
     +,   2.9566087E-05,   2.9978763E-05,   3.0404606E-05
     +,   3.0845120E-05,   3.1301843E-05,   3.1776352E-05
     +,   3.2270287E-05,   3.2785272E-05,   3.3322969E-05
     +,   3.3885070E-05,   3.4473203E-05,   3.5089059E-05
     +,   3.5734254E-05,   3.6410398E-05,   3.7119036E-05
     +,   3.7861679E-05,   3.8639748E-05,   3.9454608E-05
     +,   4.0307536E-05,   4.1199681E-05,   4.2132127E-05
     +,   4.3105785E-05,   4.4121472E-05,   4.5179862E-05
     +,   4.6281501E-05,   4.7426711E-05,   4.8615748E-05
     +,   4.9848612E-05,   5.1125189E-05,   5.2445183E-05
     +,   5.3808089E-05,   5.5213241E-05,   5.6659814E-05
     +,   5.8146732E-05,   5.9672795E-05,   6.1236715E-05
     +,   6.2836807E-05,   6.4471467E-05,   6.6138746E-05
     +,   6.7836707E-05,   6.9563117E-05,   7.1315808E-05
     +,   7.3092328E-05,   7.4890311E-05,   7.6707169E-05
     +,   7.8540368E-05,   8.0387435E-05,   8.2245795E-05
     +,   8.4112857E-05,   8.5986314E-05,   8.7863955E-05
     +,   8.9743597E-05,   9.1623493E-05,   9.3501978E-05
     +,   9.5377931E-05,   9.7250369E-05,   9.9119141E-05
     +,   1.0098419E-04,   1.0284648E-04,   1.0470731E-04
     +,   1.0656893E-04,   1.0843438E-04,   1.1030748E-04
     +,   1.1219292E-04,   1.1409662E-04,   1.1602537E-04
     +,   1.1798696E-04,   1.1999041E-04,   1.2204563E-04
     +,   1.2416374E-04,   1.2635664E-04,   1.2863750E-04
     +,   1.3101993E-04,   1.3351860E-04,   1.3614829E-04
     +,   1.3892462E-04,   1.4186314E-04,   1.4497919E-04
     +,   1.4828771E-04,   1.5180318E-04,   1.5553906E-04
     +,   1.5950718E-04,   1.6371811E-04,   1.6818005E-04
     +,   1.7289915E-04,   1.7787862E-04,   1.8311894E-04
     +,   1.8861720E-04,   1.9436705E-04,   2.0035845E-04
     +,   2.0657778E-04,   2.1300772E-04,   2.1962672E-04
     +,   2.2640964E-04,   2.3332817E-04,   2.4035078E-04
     +,   2.4744237E-04,   2.5456608E-04,   2.6168241E-04
     +,   2.6875097E-04,   2.7572975E-04,   2.8257724E-04
     +,   2.8925177E-04,   2.9571319E-04,   3.0192270E-04
     +,   3.0784425E-04,   3.1344529E-04,   3.1869611E-04
     +,   3.2357161E-04,   3.2805165E-04,   3.3212116E-04
     +,   3.3577025E-04,   3.3899437E-04,   3.4179536E-04
     +,   3.4418027E-04,   3.4616175E-04,   3.4775783E-04
     +,   3.4899180E-04,   3.4989091E-04,   3.5048739E-04
     +,   3.5081644E-04,   3.5091658E-04,   3.5082872E-04
     +,   3.5059551E-04,   3.5026076E-04,   3.4986902E-04
     +,   3.4946474E-04,   3.4909198E-04,   3.4879401E-04
     +,   3.4861299E-04,   3.4858927E-04,   3.4876220E-04
     +,   3.4916922E-04,   3.4984617E-04,   3.5082744E-04
     +,   3.5214610E-04,   3.5383389E-04,   3.5592192E-04
     +,   3.5844030E-04,   3.6141853E-04,   3.6488628E-04
     +,   3.6887234E-04,   3.7340543E-04,   3.7851449E-04
     +,   3.8422862E-04,   3.9057704E-04,   3.9759115E-04
     +,   4.0530475E-04,   4.1375612E-04,   4.2299196E-04
     +,   4.3307259E-04,   4.4407885E-04,   4.5611887E-04
     +,   4.6934173E-04,   4.8395109E-04,   5.0021900E-04
     +,   5.1850110E-04,   5.3925096E-04,   5.6303333E-04
     +,   5.9052760E-04,   6.2251830E-04,   6.5988785E-04
     +,   7.0358289E-04,   7.5457082E-04,   8.1379234E-04
     +,   8.8211248E-04,   9.6026610E-04,   1.0488137E-03
     +,   1.1481167E-03,   1.2583293E-03,   1.3793926E-03
     +,   1.5110220E-03,   1.6527117E-03,   1.8037589E-03
     +,   1.9632939E-03,   2.1303813E-03,   2.3042576E-03
     +,   2.4846238E-03,   2.6719545E-03,   2.8677210E-03
     +,   3.0743154E-03,   3.2945233E-03,   3.5305985E-03
     +,   3.7832514E-03,   4.0509650E-03,   4.3301415E-03
     +,   4.6161492E-03,   4.9050627E-03,   5.1951697E-03
     +,   5.4878546E-03,   5.7882597E-03,   6.1069923E-03
     +,   6.4630839E-03,   6.8861181E-03,   7.4141049E-03
     +,   8.0865622E-03,   8.9369239E-03,   9.9875033E-03
     +,   1.1241784E-02,   1.2665978E-02,   1.4169130E-02
     +,   1.5613308E-02,   1.6873544E-02,   1.7914632E-02
     +,   1.8810576E-02,   1.9666288E-02,   2.0492606E-02
     +,   2.1147577E-02,   2.1410715E-02,   2.1130890E-02
     +,   2.0316936E-02,   1.9105025E-02,   1.7657148E-02
     +,   1.6087314E-02,   1.4452511E-02,   1.2780055E-02
     +,   1.1095215E-02,   9.4348742E-03,   7.8480169E-03
     +,   6.3865315E-03,   5.0928118E-03,   3.9905845E-03
     +,   3.0833432E-03,   2.3580382E-03,   1.7910070E-03
     +,   1.3541221E-03,   1.0199273E-03,   7.6483650E-04
     +,   5.7023641E-04,   4.2209786E-04,   3.0995262E-04
     +,   2.2585760E-04,   1.6361954E-04,   1.1830219E-04
     +,   8.5926746E-05,   6.3277577E-05,   4.7768528E-05
     +,   3.7356742E-05,   3.0469233E-05,   2.5932508E-05
     +,   2.2902879E-05,   2.0798057E-05,   1.9233066E-05
     +,   1.7964898E-05,   1.6848040E-05,   1.5801052E-05
     +,   1.4782730E-05,   1.3775690E-05,   1.2776180E-05
     +,   1.1787364E-05,   1.0815783E-05,   9.8688997E-06
     +,   8.9541645E-06,   8.0781410E-06,   7.2464441E-06
     +,   6.4633819E-06,   5.7321568E-06,   5.0547264E-06
     +,   4.4319668E-06,   3.8638323E-06,   3.3493372E-06
     +,   2.8868401E-06,   2.4740318E-06,   2.1081962E-06
     +,   1.7862224E-06,   1.5048159E-06,   1.2605202E-06
     +,   1.0498804E-06,   8.6945727E-07,   7.1594627E-07
     +,   5.8617985E-07,   4.7720562E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz105 = Yx/0.1245
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9988532E-05,   4.1169049E-05
     +,   4.2359017E-05,   4.3556694E-05,   4.4760258E-05
     +,   4.5967827E-05,   4.7177451E-05,   4.8387134E-05
     +,   4.9594815E-05,   5.0798462E-05,   5.1995958E-05
     +,   5.3185202E-05,   5.4364074E-05,   5.5530505E-05
     +,   5.6682416E-05,   5.7817790E-05,   5.8934627E-05
     +,   6.0031049E-05,   6.1105180E-05,   6.2155297E-05
     +,   6.3179730E-05,   6.4176973E-05,   6.5145563E-05
     +,   6.6084278E-05,   6.6991925E-05,   6.7867542E-05
     +,   6.8710346E-05,   6.9519658E-05,   7.0295006E-05
     +,   7.1036076E-05,   7.1742797E-05,   7.2415249E-05
     +,   7.3053699E-05,   7.3658630E-05,   7.4230717E-05
     +,   7.4770782E-05,   7.5279924E-05,   7.5759344E-05
     +,   7.6210497E-05,   7.6634948E-05,   7.7034521E-05
     +,   7.7411110E-05,   7.7766876E-05,   7.8104007E-05
     +,   7.8424935E-05,   7.8732177E-05,   7.9028396E-05
     +,   7.9316378E-05,   7.9598962E-05,   7.9879152E-05
     +,   8.0159982E-05,   8.0444610E-05,   8.0736216E-05
     +,   8.1038095E-05,   8.1353588E-05,   8.1686019E-05
     +,   8.2038845E-05,   8.2415463E-05,   8.2819388E-05
     +,   8.3254148E-05,   8.3723244E-05,   8.4230276E-05
     +,   8.4778811E-05,   8.5372500E-05,   8.6014996E-05
     +,   8.6709952E-05,   8.7461201E-05,   8.8272456E-05
     +,   8.9147623E-05,   9.0090565E-05,   9.1105328E-05
     +,   9.2195936E-05,   9.3366623E-05,   9.4621588E-05
     +,   9.5965202E-05,   9.7402051E-05,   9.8936696E-05
     +,   1.0057375E-04,   1.0231816E-04,   1.0417485E-04
     +,   1.0614874E-04,   1.0824500E-04,   1.1046859E-04
     +,   1.1282481E-04,   1.1531856E-04,   1.1795489E-04
     +,   1.2073849E-04,   1.2367406E-04,   1.2676574E-04
     +,   1.3001735E-04,   1.3343236E-04,   1.3701338E-04
     +,   1.4076231E-04,   1.4468034E-04,   1.4876777E-04
     +,   1.5302344E-04,   1.5744552E-04,   1.6203018E-04
     +,   1.6677282E-04,   1.7166672E-04,   1.7670412E-04
     +,   1.8187502E-04,   1.8716829E-04,   1.9257028E-04
     +,   1.9806638E-04,   2.0364007E-04,   2.0927294E-04
     +,   2.1494510E-04,   2.2063550E-04,   2.2632207E-04
     +,   2.3198097E-04,   2.3758842E-04,   2.4311940E-04
     +,   2.4854933E-04,   2.5385301E-04,   2.5900634E-04
     +,   2.6398525E-04,   2.6876738E-04,   2.7333104E-04
     +,   2.7765671E-04,   2.8172688E-04,   2.8552618E-04
     +,   2.8904117E-04,   2.9226195E-04,   2.9518144E-04
     +,   2.9779485E-04,   3.0010095E-04,   3.0210125E-04
     +,   3.0380086E-04,   3.0520701E-04,   3.0633016E-04
     +,   3.0718325E-04,   3.0778183E-04,   3.0814315E-04
     +,   3.0828663E-04,   3.0823291E-04,   3.0800421E-04
     +,   3.0762327E-04,   3.0711366E-04,   3.0649899E-04
     +,   3.0580314E-04,   3.0504950E-04,   3.0426108E-04
     +,   3.0346052E-04,   3.0266945E-04,   3.0190873E-04
     +,   3.0119868E-04,   3.0055823E-04,   3.0000642E-04
     +,   2.9956095E-04,   2.9923953E-04,   2.9905912E-04
     +,   2.9903668E-04,   2.9918939E-04,   2.9953397E-04
     +,   3.0008820E-04,   3.0086952E-04,   3.0189630E-04
     +,   3.0318726E-04,   3.0476134E-04,   3.0663825E-04
     +,   3.0883748E-04,   3.1137891E-04,   3.1428161E-04
     +,   3.1756473E-04,   3.2124625E-04,   3.2534290E-04
     +,   3.2987006E-04,   3.3484134E-04,   3.4026901E-04
     +,   3.4616291E-04,   3.5253179E-04,   3.5938382E-04
     +,   3.6672730E-04,   3.7457142E-04,   3.8293007E-04
     +,   3.9182251E-04,   4.0127744E-04,   4.1133648E-04
     +,   4.2205970E-04,   4.3352958E-04,   4.4585654E-04
     +,   4.5918394E-04,   4.7369429E-04,   4.8961316E-04
     +,   5.0720922E-04,   5.2679738E-04,   5.4873555E-04
     +,   5.7341892E-04,   6.0126494E-04,   6.3270458E-04
     +,   6.6815939E-04,   7.0801732E-04,   7.5260713E-04
     +,   8.0217601E-04,   8.5686368E-04,   9.1668224E-04
     +,   9.8150526E-04,   1.0510796E-03,   1.1250339E-03
     +,   1.2029089E-03,   1.2841998E-03,   1.3684235E-03
     +,   1.4551718E-03,   1.5441639E-03,   1.6353226E-03
     +,   1.7288013E-03,   1.8250023E-03,   1.9245581E-03
     +,   2.0282746E-03,   2.1370184E-03,   2.2515559E-03
     +,   2.3724120E-03,   2.4997802E-03,   2.6335306E-03
     +,   2.7733671E-03,   2.9191412E-03,   3.0712630E-03
     +,   3.2310570E-03,   3.4010534E-03,   3.5852266E-03
     +,   3.7891169E-03,   4.0197945E-03,   4.2856061E-03
     +,   4.5956285E-03,   4.9591847E-03,   5.3861905E-03
     +,   5.8887680E-03,   6.4833849E-03,   7.1911830E-03
     +,   8.0343531E-03,   9.0291677E-03,   1.0179832E-02
     +,   1.1477273E-02,   1.2902241E-02,   1.4425689E-02
     +,   1.5998915E-02,   1.7539214E-02,   1.8928573E-02
     +,   2.0037727E-02,   2.0765271E-02,   2.1064309E-02
     +,   2.0939542E-02,   2.0424448E-02,   1.9562924E-02
     +,   1.8406071E-02,   1.7014556E-02,   1.5454059E-02
     +,   1.3785357E-02,   1.2059910E-02,   1.0325136E-02
     +,   8.6334506E-03,   7.0438650E-03,   5.6126909E-03
     +,   4.3797395E-03,   3.3598135E-03,   2.5437530E-03
     +,   1.9066343E-03,   1.4176582E-03,   1.0472048E-03
     +,   7.6986459E-04,   5.6471617E-04,   4.1467280E-04
     +,   3.0589409E-04,   2.2741819E-04,   1.7084344E-04
     +,   1.2997020E-04,   1.0034651E-04,   7.8807447E-05
     +,   6.3091073E-05,   5.1560910E-05,   4.3020398E-05
     +,   3.6592439E-05,   3.1639527E-05,   2.7706337E-05
     +,   2.4474710E-05,   2.1727026E-05,   1.9319106E-05
     +,   1.7158163E-05,   1.5187613E-05,   1.3374813E-05
     +,   1.1703003E-05,   1.0164597E-05,   8.7571434E-06
     +,   7.4798222E-06,   6.3318353E-06,   5.3109588E-06
     +,   4.4131730E-06,   3.6326612E-06,   2.9618441E-06
     +,   2.3919463E-06,   1.9132701E-06,   1.5157843E-06
     +,   1.1893901E-06,   9.2436278E-07,   7.1151385E-07
     +,   5.4244299E-07,   4.0958719E-07,   3.0631500E-07
     +,   2.2688788E-07,   1.6645014E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz107 = Yx/0.118487804878049
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5202120E-05,   1.5760506E-05
     +,   1.6343285E-05,   1.6951491E-05,   1.7586204E-05
     +,   1.8248524E-05,   1.8939598E-05,   1.9660611E-05
     +,   2.0412757E-05,   2.1197317E-05,   2.2015545E-05
     +,   2.2868740E-05,   2.3758230E-05,   2.4685354E-05
     +,   2.5651460E-05,   2.6657910E-05,   2.7706063E-05
     +,   2.8797271E-05,   2.9932868E-05,   3.1114170E-05
     +,   3.2342450E-05,   3.3618944E-05,   3.4944802E-05
     +,   3.6321198E-05,   3.7749080E-05,   3.9229435E-05
     +,   4.0763083E-05,   4.2350726E-05,   4.3992917E-05
     +,   4.5690096E-05,   4.7442507E-05,   4.9250211E-05
     +,   5.1113111E-05,   5.3030868E-05,   5.5002922E-05
     +,   5.7028479E-05,   5.9106500E-05,   6.1235703E-05
     +,   6.3414576E-05,   6.5641158E-05,   6.7913461E-05
     +,   7.0229020E-05,   7.2585142E-05,   7.4978831E-05
     +,   7.7406825E-05,   7.9865546E-05,   8.2351158E-05
     +,   8.4859552E-05,   8.7386354E-05,   8.9926943E-05
     +,   9.2476490E-05,   9.5029929E-05,   9.7581986E-05
     +,   1.0012740E-04,   1.0266044E-04,   1.0517566E-04
     +,   1.0766729E-04,   1.1012961E-04,   1.1255686E-04
     +,   1.1494341E-04,   1.1728364E-04,   1.1957216E-04
     +,   1.2180354E-04,   1.2397283E-04,   1.2607529E-04
     +,   1.2810643E-04,   1.3006227E-04,   1.3193904E-04
     +,   1.3373388E-04,   1.3544402E-04,   1.3706775E-04
     +,   1.3860375E-04,   1.4005171E-04,   1.4141193E-04
     +,   1.4268588E-04,   1.4387588E-04,   1.4498536E-04
     +,   1.4601885E-04,   1.4698226E-04,   1.4788276E-04
     +,   1.4872901E-04,   1.4953101E-04,   1.5030042E-04
     +,   1.5105057E-04,   1.5179644E-04,   1.5255481E-04
     +,   1.5334417E-04,   1.5418496E-04,   1.5509926E-04
     +,   1.5611117E-04,   1.5724647E-04,   1.5853267E-04
     +,   1.5999899E-04,   1.6167622E-04,   1.6359678E-04
     +,   1.6579416E-04,   1.6830338E-04,   1.7116015E-04
     +,   1.7440162E-04,   1.7806499E-04,   1.8218874E-04
     +,   1.8681092E-04,   1.9197055E-04,   1.9770581E-04
     +,   2.0405521E-04,   2.1105671E-04,   2.1874721E-04
     +,   2.2716212E-04,   2.3633617E-04,   2.4630211E-04
     +,   2.5708904E-04,   2.6872460E-04,   2.8123087E-04
     +,   2.9462666E-04,   3.0892345E-04,   3.2412747E-04
     +,   3.4023490E-04,   3.5723456E-04,   3.7510222E-04
     +,   3.9380300E-04,   4.1328874E-04,   4.3349530E-04
     +,   4.5434260E-04,   4.7573578E-04,   4.9756310E-04
     +,   5.1969400E-04,   5.4198498E-04,   5.6427449E-04
     +,   5.8639050E-04,   6.0814765E-04,   6.2935520E-04
     +,   6.4981525E-04,   6.6933216E-04,   6.8771146E-04
     +,   7.0476852E-04,   7.2033209E-04,   7.3424709E-04
     +,   7.4638065E-04,   7.5662578E-04,   7.6490489E-04
     +,   7.7117101E-04,   7.7541021E-04,   7.7764242E-04
     +,   7.7792100E-04,   7.7633141E-04,   7.7298761E-04
     +,   7.6803082E-04,   7.6162338E-04,   7.5394590E-04
     +,   7.4519048E-04,   7.3555525E-04,   7.2524056E-04
     +,   7.1444217E-04,   7.0334645E-04,   6.9212535E-04
     +,   6.8093481E-04,   6.6990952E-04,   6.5916142E-04
     +,   6.4877857E-04,   6.3882535E-04,   6.2934274E-04
     +,   6.2034884E-04,   6.1184255E-04,   6.0380512E-04
     +,   5.9620483E-04,   5.8899738E-04,   5.8213476E-04
     +,   5.7556434E-04,   5.6923623E-04,   5.6310574E-04
     +,   5.5713794E-04,   5.5131130E-04,   5.4562133E-04
     +,   5.4008281E-04,   5.3473446E-04,   5.2963954E-04
     +,   5.2488904E-04,   5.2060140E-04,   5.1692437E-04
     +,   5.1403255E-04,   5.1212602E-04,   5.1142892E-04
     +,   5.1218184E-04,   5.1463966E-04,   5.1906315E-04
     +,   5.2571273E-04,   5.3484226E-04,   5.4669351E-04
     +,   5.6149205E-04,   5.7944597E-04,   6.0074998E-04
     +,   6.2559301E-04,   6.5417163E-04,   6.8670843E-04
     +,   7.2348397E-04,   7.6486450E-04,   8.1133493E-04
     +,   8.6353841E-04,   9.2230609E-04,   9.8867400E-04
     +,   1.0638655E-03,   1.1492554E-03,   1.2462741E-03
     +,   1.3562556E-03,   1.4802131E-03,   1.6186038E-03
     +,   1.7710602E-03,   1.9361671E-03,   2.1113919E-03
     +,   2.2932268E-03,   2.4775933E-03,   2.6605169E-03
     +,   2.8390295E-03,   3.0120788E-03,   3.1811588E-03
     +,   3.3504025E-03,   3.5259856E-03,   3.7147899E-03
     +,   3.9226352E-03,   4.1525331E-03,   4.4037183E-03
     +,   4.6717478E-03,   4.9498859E-03,   5.2315085E-03
     +,   5.5127735E-03,   5.7945889E-03,   6.0831965E-03
     +,   6.3888347E-03,   6.7227581E-03,   7.0931027E-03
     +,   7.5010424E-03,   7.9386160E-03,   8.3893789E-03
     +,   8.8318484E-03,   9.2449132E-03,   9.6132997E-03
     +,   9.9306293E-03,   1.0199304E-02,   1.0427043E-02
     +,   1.0621731E-02,   1.0786067E-02,   1.0913770E-02
     +,   1.0988097E-02,   1.0983136E-02,   1.0867860E-02
     +,   1.0612656E-02,   1.0197009E-02,   9.6162315E-03
     +,   8.8850465E-03,   8.0365762E-03,   7.1165548E-03
     +,   6.1750081E-03,   5.2580261E-03,   4.4016419E-03
     +,   3.6292351E-03,   2.9522146E-03,   2.3725668E-03
     +,   1.8859422E-03,   1.4843241E-03,   1.1579957E-03
     +,   8.9673023E-04,   6.9043325E-04,   5.2956038E-04
     +,   4.0543079E-04,   3.1043304E-04,   2.3810640E-04
     +,   1.8316149E-04,   1.4139840E-04,   1.0956172E-04
     +,   8.5175408E-05,   6.6384397E-05,   5.1811669E-05
     +,   4.0439048E-05,   3.1514155E-05,   2.4480718E-05
     +,   1.8925552E-05,   1.4537342E-05,   1.1079141E-05
     +,   8.3662926E-06,   6.2527761E-06,   4.6204523E-06
     +,   3.3729195E-06,   2.4306028E-06,   1.7280236E-06
     +,   1.2113670E-06,   8.3696580E-07,   5.6973738E-07
     +,   3.8197069E-07,   2.5215522E-07,   1.6386335E-07
     +,   1.0481272E-07,   6.5979698E-08,   4.0877225E-08
     +,   2.4926724E-08,   1.4966240E-08,   8.8528518E-09
     +,   5.1653073E-09,   2.9787270E-09,   1.7039485E-09
     +,   9.7273001E-10,   5.5970067E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz110 = Yx/0.09485
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4528486E-05,   4.5762386E-05
     +,   4.7018460E-05,   4.8297003E-05,   4.9598304E-05
     +,   5.0922721E-05,   5.2270603E-05,   5.3642379E-05
     +,   5.5038454E-05,   5.6459379E-05,   5.7905669E-05
     +,   5.9377908E-05,   6.0876759E-05,   6.2402927E-05
     +,   6.3957217E-05,   6.5540458E-05,   6.7153604E-05
     +,   6.8797679E-05,   7.0473790E-05,   7.2183138E-05
     +,   7.3927069E-05,   7.5706979E-05,   7.7524383E-05
     +,   7.9381018E-05,   8.1278537E-05,   8.3218954E-05
     +,   8.5204221E-05,   8.7236505E-05,   8.9318070E-05
     +,   9.1451322E-05,   9.3638751E-05,   9.5883035E-05
     +,   9.8186865E-05,   1.0055308E-04,   1.0298456E-04
     +,   1.0548431E-04,   1.0805528E-04,   1.1070052E-04
     +,   1.1342315E-04,   1.1622597E-04,   1.1911206E-04
     +,   1.2208418E-04,   1.2514506E-04,   1.2829714E-04
     +,   1.3154277E-04,   1.3488393E-04,   1.3832227E-04
     +,   1.4185923E-04,   1.4549569E-04,   1.4923215E-04
     +,   1.5306857E-04,   1.5700451E-04,   1.6103867E-04
     +,   1.6516962E-04,   1.6939477E-04,   1.7371135E-04
     +,   1.7811581E-04,   1.8260391E-04,   1.8717100E-04
     +,   1.9181181E-04,   1.9652076E-04,   2.0129197E-04
     +,   2.0611896E-04,   2.1099590E-04,   2.1591678E-04
     +,   2.2087571E-04,   2.2586813E-04,   2.3088972E-04
     +,   2.3593813E-04,   2.4101199E-04,   2.4611285E-04
     +,   2.5124391E-04,   2.5641223E-04,   2.6162755E-04
     +,   2.6690395E-04,   2.7226019E-04,   2.7771943E-04
     +,   2.8331010E-04,   2.8906658E-04,   2.9502923E-04
     +,   3.0124385E-04,   3.0776311E-04,   3.1464445E-04
     +,   3.2195204E-04,   3.2975402E-04,   3.3812376E-04
     +,   3.4713614E-04,   3.5686963E-04,   3.6740169E-04
     +,   3.7880838E-04,   3.9116337E-04,   4.0453297E-04
     +,   4.1897557E-04,   4.3454007E-04,   4.5126289E-04
     +,   4.6916309E-04,   4.8824536E-04,   5.0849293E-04
     +,   5.2987109E-04,   5.5232155E-04,   5.7576655E-04
     +,   6.0010434E-04,   6.2521460E-04,   6.5095531E-04
     +,   6.7716948E-04,   7.0368429E-04,   7.3031452E-04
     +,   7.5686595E-04,   7.8314246E-04,   8.0894696E-04
     +,   8.3408237E-04,   8.5836358E-04,   8.8161224E-04
     +,   9.0366742E-04,   9.2438183E-04,   9.4362971E-04
     +,   9.6130377E-04,   9.7732025E-04,   9.9161500E-04
     +,   1.0041472E-03,   1.0148968E-03,   1.0238623E-03
     +,   1.0310601E-03,   1.0365250E-03,   1.0403055E-03
     +,   1.0424603E-03,   1.0430602E-03,   1.0421841E-03
     +,   1.0399172E-03,   1.0363490E-03,   1.0315721E-03
     +,   1.0256820E-03,   1.0187720E-03,   1.0109369E-03
     +,   1.0022694E-03,   9.9285913E-04,   9.8279375E-04
     +,   9.7215676E-04,   9.6102781E-04,   9.4948104E-04
     +,   9.3758927E-04,   9.2541776E-04,   9.1302884E-04
     +,   9.0047927E-04,   8.8782387E-04,   8.7511132E-04
     +,   8.6238672E-04,   8.4969337E-04,   8.3707151E-04
     +,   8.2455727E-04,   8.1218447E-04,   7.9998543E-04
     +,   7.8799075E-04,   7.7622692E-04,   7.6471968E-04
     +,   7.5349212E-04,   7.4256508E-04,   7.3195744E-04
     +,   7.2168536E-04,   7.1176357E-04,   7.0220511E-04
     +,   6.9302152E-04,   6.8422389E-04,   6.7582447E-04
     +,   6.6783553E-04,   6.6027098E-04,   6.5314909E-04
     +,   6.4649247E-04,   6.4032717E-04,   6.3468568E-04
     +,   6.2960660E-04,   6.2513555E-04,   6.2132243E-04
     +,   6.1822339E-04,   6.1589817E-04,   6.1440823E-04
     +,   6.1381597E-04,   6.1417965E-04,   6.1555341E-04
     +,   6.1798195E-04,   6.2149967E-04,   6.2612741E-04
     +,   6.3187006E-04,   6.3871709E-04,   6.4664154E-04
     +,   6.5560255E-04,   6.6554698E-04,   6.7641673E-04
     +,   6.8815215E-04,   7.0070109E-04,   7.1402703E-04
     +,   7.2811870E-04,   7.4299797E-04,   7.5872953E-04
     +,   7.7542610E-04,   7.9325627E-04,   8.1243966E-04
     +,   8.3324639E-04,   8.5599144E-04,   8.8101695E-04
     +,   9.0867502E-04,   9.3930576E-04,   9.7321253E-04
     +,   1.0106377E-03,   1.0517342E-03,   1.0965577E-03
     +,   1.1450584E-03,   1.1970873E-03,   1.2524293E-03
     +,   1.3108525E-03,   1.3721717E-03,   1.4363251E-03
     +,   1.5034627E-03,   1.5740301E-03,   1.6488212E-03
     +,   1.7290035E-03,   1.8161001E-03,   1.9119187E-03
     +,   2.0184247E-03,   2.1375539E-03,   2.2710348E-03
     +,   2.4201719E-03,   2.5856590E-03,   2.7674499E-03
     +,   2.9647145E-03,   3.1758426E-03,   3.3985362E-03
     +,   3.6299920E-03,   3.8671042E-03,   4.1066781E-03
     +,   4.3455660E-03,   4.5807888E-03,   4.8095668E-03
     +,   5.0292090E-03,   5.2369805E-03,   5.4299366E-03
     +,   5.6048115E-03,   5.7579177E-03,   5.8852481E-03
     +,   5.9826737E-03,   6.0462430E-03,   6.0725319E-03
     +,   6.0589812E-03,   6.0041668E-03,   5.9078792E-03
     +,   5.7711611E-03,   5.5961129E-03,   5.3857085E-03
     +,   5.1435316E-03,   4.8736441E-03,   4.5804004E-03
     +,   4.2684344E-03,   3.9426452E-03,   3.6081919E-03
     +,   3.2704063E-03,   2.9347236E-03,   2.6065111E-03
     +,   2.2908391E-03,   1.9922007E-03,   1.7143255E-03
     +,   1.4600212E-03,   1.2310685E-03,   1.0281992E-03
     +,   8.5119519E-04,   6.9904228E-04,   5.7007483E-04
     +,   4.6218836E-04,   3.7303512E-04,   3.0017699E-04
     +,   2.4121774E-04,   1.9390811E-04,   1.5621127E-04
     +,   1.2633267E-04,   1.0272967E-04,   8.4107021E-05
     +,   6.9399568E-05,   5.7742644E-05,   4.8448510E-05
     +,   4.0975028E-05,   3.4902288E-05,   2.9907169E-05
     +,   2.5744943E-05,   2.2231074E-05,   1.9228377E-05
     +,   1.6634865E-05,   1.4375681E-05,   1.2395411E-05
     +,   1.0652964E-05,   9.1175643E-06,   7.7652767E-06
     +,   6.5771346E-06,   5.5371465E-06,   4.6314967E-06
     +,   3.8475391E-06,   3.1735749E-06,   2.5984225E-06
     +,   2.1114818E-06,   1.7025793E-06,   1.3621374E-06
     +,   1.0811279E-06,   8.5123088E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz115 = Yx/0.0720263157894737
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6223908E-05,   3.7208923E-05
     +,   3.8220005E-05,   3.9257990E-05,   4.0323685E-05
     +,   4.1417883E-05,   4.2541327E-05,   4.3694712E-05
     +,   4.4878645E-05,   4.6093730E-05,   4.7340422E-05
     +,   4.8619124E-05,   4.9930113E-05,   5.1273590E-05
     +,   5.2649604E-05,   5.4058113E-05,   5.5498909E-05
     +,   5.6971694E-05,   5.8475998E-05,   6.0011193E-05
     +,   6.1576560E-05,   6.3171217E-05,   6.4794061E-05
     +,   6.6444067E-05,   6.8119829E-05,   6.9820046E-05
     +,   7.1543152E-05,   7.3287607E-05,   7.5051743E-05
     +,   7.6833872E-05,   7.8632249E-05,   8.0445156E-05
     +,   8.2270897E-05,   8.4107800E-05,   8.5954307E-05
     +,   8.7808978E-05,   8.9670517E-05,   9.1537739E-05
     +,   9.3409864E-05,   9.5286130E-05,   9.7166238E-05
     +,   9.9050187E-05,   1.0093827E-04,   1.0283125E-04
     +,   1.0473029E-04,   1.0663705E-04,   1.0855368E-04
     +,   1.1048286E-04,   1.1242791E-04,   1.1439266E-04
     +,   1.1638161E-04,   1.1839994E-04,   1.2045348E-04
     +,   1.2254888E-04,   1.2469328E-04,   1.2689488E-04
     +,   1.2916232E-04,   1.3150521E-04,   1.3393382E-04
     +,   1.3645914E-04,   1.3909297E-04,   1.4184779E-04
     +,   1.4473656E-04,   1.4777297E-04,   1.5097136E-04
     +,   1.5434613E-04,   1.5791232E-04,   1.6168490E-04
     +,   1.6567932E-04,   1.6991027E-04,   1.7439283E-04
     +,   1.7914111E-04,   1.8416898E-04,   1.8948907E-04
     +,   1.9511313E-04,   2.0105189E-04,   2.0731427E-04
     +,   2.1390748E-04,   2.2083729E-04,   2.2810795E-04
     +,   2.3572061E-04,   2.4367562E-04,   2.5197057E-04
     +,   2.6060169E-04,   2.6956294E-04,   2.7884747E-04
     +,   2.8844626E-04,   2.9835023E-04,   3.0854886E-04
     +,   3.1903217E-04,   3.2979070E-04,   3.4081526E-04
     +,   3.5209753E-04,   3.6363225E-04,   3.7541619E-04
     +,   3.8744768E-04,   3.9972979E-04,   4.1226676E-04
     +,   4.2506831E-04,   4.3814484E-04,   4.5151246E-04
     +,   4.6518713E-04,   4.7918875E-04,   4.9353635E-04
     +,   5.0825102E-04,   5.2335154E-04,   5.3885381E-04
     +,   5.5476947E-04,   5.7110540E-04,   5.8786164E-04
     +,   6.0502748E-04,   6.2258384E-04,   6.4049830E-04
     +,   6.5872719E-04,   6.7721074E-04,   6.9587835E-04
     +,   7.1464095E-04,   7.3339918E-04,   7.5203687E-04
     +,   7.7042810E-04,   7.8843598E-04,   8.0591423E-04
     +,   8.2271016E-04,   8.3866977E-04,   8.5363805E-04
     +,   8.6746248E-04,   8.7999785E-04,   8.9110766E-04
     +,   9.0066984E-04,   9.0857508E-04,   9.1473502E-04
     +,   9.1907970E-04,   9.2156179E-04,   9.2215574E-04
     +,   9.2085986E-04,   9.1769488E-04,   9.1270451E-04
     +,   9.0595207E-04,   8.9752115E-04,   8.8751124E-04
     +,   8.7603723E-04,   8.6322479E-04,   8.4920874E-04
     +,   8.3412894E-04,   8.1812951E-04,   8.0135249E-04
     +,   7.8393961E-04,   7.6602731E-04,   7.4774685E-04
     +,   7.2922069E-04,   7.1056274E-04,   6.9187931E-04
     +,   6.7326677E-04,   6.5481308E-04,   6.3659676E-04
     +,   6.1869068E-04,   6.0116046E-04,   5.8406638E-04
     +,   5.6746404E-04,   5.5140728E-04,   5.3594640E-04
     +,   5.2113004E-04,   5.0700700E-04,   4.9362530E-04
     +,   4.8103073E-04,   4.6926865E-04,   4.5838277E-04
     +,   4.4841436E-04,   4.3939997E-04,   4.3137089E-04
     +,   4.2435309E-04,   4.1836404E-04,   4.1341173E-04
     +,   4.0949386E-04,   4.0659722E-04,   4.0469610E-04
     +,   4.0375273E-04,   4.0371690E-04,   4.0452648E-04
     +,   4.0610862E-04,   4.0838070E-04,   4.1125275E-04
     +,   4.1462804E-04,   4.1840819E-04,   4.2249344E-04
     +,   4.2678602E-04,   4.3119394E-04,   4.3563312E-04
     +,   4.4003053E-04,   4.4432573E-04,   4.4847419E-04
     +,   4.5244870E-04,   4.5624108E-04,   4.5986346E-04
     +,   4.6334954E-04,   4.6675562E-04,   4.7016147E-04
     +,   4.7367066E-04,   4.7741222E-04,   4.8154115E-04
     +,   4.8623906E-04,   4.9171469E-04,   4.9820385E-04
     +,   5.0597067E-04,   5.1530177E-04,   5.2650855E-04
     +,   5.3991826E-04,   5.5587065E-04,   5.7470711E-04
     +,   5.9676333E-04,   6.2235986E-04,   6.5178657E-04
     +,   6.8529451E-04,   7.2309072E-04,   7.6532672E-04
     +,   8.1209844E-04,   8.6344534E-04,   9.1936276E-04
     +,   9.7981072E-04,   1.0447209E-03,   1.1140237E-03
     +,   1.1876614E-03,   1.2655993E-03,   1.3478339E-03
     +,   1.4344086E-03,   1.5254011E-03,   1.6209017E-03
     +,   1.7209965E-03,   1.8257394E-03,   1.9351026E-03
     +,   2.0489232E-03,   2.1668582E-03,   2.2883408E-03
     +,   2.4125280E-03,   2.5382508E-03,   2.6640082E-03
     +,   2.7879523E-03,   2.9078857E-03,   3.0213047E-03
     +,   3.1254669E-03,   3.2174715E-03,   3.2943590E-03
     +,   3.3532465E-03,   3.3914868E-03,   3.4067989E-03
     +,   3.3974124E-03,   3.3622133E-03,   3.3008212E-03
     +,   3.2136582E-03,   3.1019736E-03,   2.9677923E-03
     +,   2.8138442E-03,   2.6434446E-03,   2.4603393E-03
     +,   2.2685074E-03,   2.0719888E-03,   1.8747204E-03
     +,   1.6803562E-03,   1.4921364E-03,   1.3127892E-03
     +,   1.1444928E-03,   9.8883943E-04,   8.4683788E-04
     +,   7.1896991E-04,   6.0526130E-04,   5.0533540E-04
     +,   4.1850933E-04,   3.4388102E-04,   2.8039858E-04
     +,   2.2692684E-04,   1.8230957E-04,   1.4541768E-04
     +,   1.1517847E-04,   9.0597860E-05,   7.0777045E-05
     +,   5.4919903E-05,   4.2329215E-05,   3.2406886E-05
     +,   2.4643907E-05,   1.8614468E-05,   1.3964649E-05
     +,   1.0404581E-05,   7.6981696E-06,   5.6556464E-06
     +,   4.1252447E-06,   2.9870585E-06,   2.1468441E-06
     +,   1.5312731E-06,   1.0837878E-06,   7.6102521E-07
     +,   5.3009910E-07,   3.6621722E-07,   2.5089017E-07
     +,   1.7041606E-07,   1.1475185E-07,   7.6586105E-08
     +,   5.0655235E-08,   3.3197356E-08,   2.1554296E-08
     +,   1.3862437E-08,   8.8302246E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz120 = Yx/0.0452
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.6623583E-05,   8.3528328E-05
     +,   9.0938178E-05,   9.8892931E-05,   1.0744184E-04
     +,   1.1664612E-04,   1.2658133E-04,   1.3734000E-04
     +,   1.4903417E-04,   1.6179885E-04,   1.7579322E-04
     +,   1.9120378E-04,   2.0824585E-04,   2.2716438E-04
     +,   2.4823355E-04,   2.7175568E-04,   2.9805736E-04
     +,   3.2748425E-04,   3.6039317E-04,   3.9714272E-04
     +,   4.3808122E-04,   4.8353386E-04,   5.3378864E-04
     +,   5.8908865E-04,   6.4961257E-04,   7.1547943E-04
     +,   7.8673841E-04,   8.6337625E-04,   9.4532309E-04
     +,   1.0324637E-03,   1.1246479E-03,   1.2216943E-03
     +,   1.3233931E-03,   1.4294910E-03,   1.5396620E-03
     +,   1.6534672E-03,   1.7703034E-03,   1.8893377E-03
     +,   2.0094616E-03,   2.1292313E-03,   2.2468742E-03
     +,   2.3602911E-03,   2.4671303E-03,   2.5648971E-03
     +,   2.6511010E-03,   2.7234342E-03,   2.7799595E-03
     +,   2.8192846E-03,   2.8406992E-03,   2.8442601E-03
     +,   2.8308027E-03,   2.8018877E-03,   2.7596587E-03
     +,   2.7066718E-03,   2.6456765E-03,   2.5793845E-03
     +,   2.5102799E-03,   2.4404519E-03,   2.3714942E-03
     +,   2.3044674E-03,   2.2399186E-03,   2.1779574E-03
     +,   2.1183633E-03,   2.0607011E-03,   2.0044416E-03
     +,   1.9490712E-03,   1.8941531E-03,   1.8393917E-03
     +,   1.7846220E-03,   1.7298266E-03,   1.6750896E-03
     +,   1.6205725E-03,   1.5664693E-03,   1.5129787E-03
     +,   1.4602684E-03,   1.4084664E-03,   1.3576526E-03
     +,   1.3078585E-03,   1.2590771E-03,   1.2112787E-03
     +,   1.1644327E-03,   1.1185162E-03,   1.0735443E-03
     +,   1.0295695E-03,   9.8670670E-04,   9.4512047E-04
     +,   9.0504019E-04,   8.6673978E-04,   8.3053578E-04
     +,   7.9676462E-04,   7.6576811E-04,   7.3787576E-04
     +,   7.1338413E-04,   6.9253962E-04,   6.7552715E-04
     +,   6.6246203E-04,   6.5338303E-04,   6.4825430E-04
     +,   6.4696977E-04,   6.4936117E-04,   6.5521034E-04
     +,   6.6426001E-04,   6.7623018E-04,   6.9082872E-04
     +,   7.0776453E-04,   7.2675809E-04,   7.4754556E-04
     +,   7.6988398E-04,   7.9355319E-04,   8.1835681E-04
     +,   8.4410986E-04,   8.7064452E-04,   8.9779304E-04
     +,   9.2539168E-04,   9.5326529E-04,   9.8123064E-04
     +,   1.0090827E-03,   1.0366068E-03,   1.0635640E-03
     +,   1.0897038E-03,   1.1147648E-03,   1.1384754E-03
     +,   1.1605656E-03,   1.1807715E-03,   1.1988411E-03
     +,   1.2145407E-03,   1.2276624E-03,   1.2380256E-03
     +,   1.2454849E-03,   1.2499311E-03,   1.2512930E-03
     +,   1.2495383E-03,   1.2446744E-03,   1.2367464E-03
     +,   1.2258393E-03,   1.2120702E-03,   1.1955934E-03
     +,   1.1765925E-03,   1.1552777E-03,   1.1318859E-03
     +,   1.1066747E-03,   1.0799186E-03,   1.0519034E-03
     +,   1.0229230E-03,   9.9327404E-04,   9.6324959E-04
     +,   9.3313301E-04,   9.0319559E-04,   8.7369059E-04
     +,   8.4484456E-04,   8.1685750E-04,   7.8990043E-04
     +,   7.6411152E-04,   7.3959230E-04,   7.1641180E-04
     +,   6.9460593E-04,   6.7418063E-04,   6.5511063E-04
     +,   6.3734740E-04,   6.2082219E-04,   6.0544879E-04
     +,   5.9112953E-04,   5.7776045E-04,   5.6523480E-04
     +,   5.5344601E-04,   5.4229301E-04,   5.3168245E-04
     +,   5.2153057E-04,   5.1176507E-04,   5.0232495E-04
     +,   4.9316214E-04,   4.8424114E-04,   4.7553662E-04
     +,   4.6703278E-04,   4.5872363E-04,   4.5060855E-04
     +,   4.4269141E-04,   4.3498023E-04,   4.2748390E-04
     +,   4.2021059E-04,   4.1316723E-04,   4.0635839E-04
     +,   3.9978506E-04,   3.9344409E-04,   3.8732795E-04
     +,   3.8142578E-04,   3.7572210E-04,   3.7019767E-04
     +,   3.6483040E-04,   3.5959628E-04,   3.5446900E-04
     +,   3.4942126E-04,   3.4442596E-04,   3.3945663E-04
     +,   3.3448750E-04,   3.2949424E-04,   3.2445544E-04
     +,   3.1935191E-04,   3.1416709E-04,   3.0888719E-04
     +,   3.0350179E-04,   2.9800381E-04,   2.9238831E-04
     +,   2.8665338E-04,   2.8079998E-04,   2.7483114E-04
     +,   2.6875181E-04,   2.6256905E-04,   2.5629150E-04
     +,   2.4992874E-04,   2.4349101E-04,   2.3699006E-04
     +,   2.3043790E-04,   2.2384657E-04,   2.1722814E-04
     +,   2.1059508E-04,   2.0395996E-04,   1.9733439E-04
     +,   1.9072993E-04,   1.8415823E-04,   1.7763005E-04
     +,   1.7115563E-04,   1.6474517E-04,   1.5840850E-04
     +,   1.5215442E-04,   1.4599130E-04,   1.3992749E-04
     +,   1.3397078E-04,   1.2812807E-04,   1.2240584E-04
     +,   1.1681032E-04,   1.1134731E-04,   1.0602170E-04
     +,   1.0083789E-04,   9.5800206E-05,   9.0911948E-05
     +,   8.6175896E-05,   8.1594604E-05,   7.7170022E-05
     +,   7.2903327E-05,   6.8795096E-05,   6.4845713E-05
     +,   6.1055020E-05,   5.7422098E-05,   5.3945580E-05
     +,   5.0623887E-05,   4.7454982E-05,   4.4436230E-05
     +,   4.1564654E-05,   3.8837225E-05,   3.6250331E-05
     +,   3.3800115E-05,   3.1482676E-05,   2.9293884E-05
     +,   2.7229320E-05,   2.5284449E-05,   2.3454781E-05
     +,   2.1735754E-05,   2.0122641E-05,   1.8610745E-05
     +,   1.7195480E-05,   1.5872289E-05,   1.4636586E-05
     +,   1.3483884E-05,   1.2409896E-05,   1.1410327E-05
     +,   1.0481019E-05,   9.6180020E-06,   8.8174338E-06
     +,   8.0755626E-06,   7.3887895E-06,   6.7537121E-06
     +,   6.1670708E-06,   5.6257163E-06,   5.1266579E-06
     +,   4.6670993E-06,   4.2443289E-06,   3.8558333E-06
     +,   3.4991854E-06,   3.1721434E-06,   2.8725501E-06
     +,   2.5984154E-06,   2.3478326E-06,   2.1190447E-06
     +,   1.9103750E-06,   1.7202817E-06,   1.5473029E-06
     +,   1.3900750E-06,   1.2473405E-06,   1.1179091E-06
     +,   1.0006903E-06,   8.9465476E-07,   7.9886064E-07
     +,   7.1242164E-07,   6.3452899E-07,   5.6442332E-07
     +,   5.0141290E-07,   4.4485091E-07,   3.9414857E-07
     +,   3.4875745E-07,   3.0817947E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz60 = Yx/0.0499722222222222
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3757711E-05,   2.4716988E-05
     +,   2.5764815E-05,   2.6912276E-05,   2.8171646E-05
     +,   2.9556433E-05,   3.1081461E-05,   3.2762942E-05
     +,   3.4618559E-05,   3.6667734E-05,   3.8931681E-05
     +,   4.1433839E-05,   4.4200304E-05,   4.7260492E-05
     +,   5.0648050E-05,   5.4401884E-05,   5.8567752E-05
     +,   6.3199928E-05,   6.8363261E-05,   7.4135554E-05
     +,   8.0609992E-05,   8.7897570E-05,   9.6129414E-05
     +,   1.0545910E-04,   1.1606236E-04,   1.2813907E-04
     +,   1.4191044E-04,   1.5761665E-04,   1.7551266E-04
     +,   1.9586214E-04,   2.1893038E-04,   2.4497672E-04
     +,   2.7424854E-04,   3.0697527E-04,   3.4336711E-04
     +,   3.8361872E-04,   4.2791746E-04,   4.7645986E-04
     +,   5.2947749E-04,   5.8725692E-04,   6.5018242E-04
     +,   7.1875734E-04,   7.9363224E-04,   8.7561458E-04
     +,   9.6566492E-04,   1.0648649E-03,   1.1743659E-03
     +,   1.2953090E-03,   1.4287310E-03,   1.5754543E-03
     +,   1.7359853E-03,   1.9104296E-03,   2.0984181E-03
     +,   2.2991069E-03,   2.5111488E-03,   2.7327901E-03
     +,   2.9618894E-03,   3.1960080E-03,   3.4324469E-03
     +,   3.6682619E-03,   3.9002430E-03,   4.1248547E-03
     +,   4.3381802E-03,   4.5359205E-03,   4.7134366E-03
     +,   4.8659067E-03,   4.9886415E-03,   5.0774612E-03
     +,   5.1291389E-03,   5.1418194E-03,   5.1153186E-03
     +,   5.0512282E-03,   4.9527599E-03,   4.8244181E-03
     +,   4.6714731E-03,   4.4993907E-03,   4.3133576E-03
     +,   4.1179541E-03,   3.9170091E-03,   3.7137121E-03
     +,   3.5108544E-03,   3.3110348E-03,   3.1169262E-03
     +,   2.9312796E-03,   2.7569078E-03,   2.5964032E-03
     +,   2.4519148E-03,   2.3248214E-03,   2.2155684E-03
     +,   2.1235533E-03,   2.0471979E-03,   1.9841334E-03
     +,   1.9314541E-03,   1.8860272E-03,   1.8448067E-03
     +,   1.8050896E-03,   1.7647110E-03,   1.7221676E-03
     +,   1.6766485E-03,   1.6280147E-03,   1.5767069E-03
     +,   1.5236369E-03,   1.4700363E-03,   1.4173224E-03
     +,   1.3669537E-03,   1.3203116E-03,   1.2786118E-03
     +,   1.2428272E-03,   1.2136435E-03,   1.1914474E-03
     +,   1.1763329E-03,   1.1681173E-03,   1.1663863E-03
     +,   1.1705350E-03,   1.1798225E-03,   1.1934162E-03
     +,   1.2104410E-03,   1.2300179E-03,   1.2512913E-03
     +,   1.2734567E-03,   1.2957690E-03,   1.3175505E-03
     +,   1.3381953E-03,   1.3571637E-03,   1.3739850E-03
     +,   1.3882528E-03,   1.3996301E-03,   1.4078523E-03
     +,   1.4127322E-03,   1.4141719E-03,   1.4121691E-03
     +,   1.4068204E-03,   1.3983297E-03,   1.3869994E-03
     +,   1.3732257E-03,   1.3574811E-03,   1.3402983E-03
     +,   1.3222372E-03,   1.3038616E-03,   1.2857083E-03
     +,   1.2682584E-03,   1.2519145E-03,   1.2369747E-03
     +,   1.2236270E-03,   1.2119407E-03,   1.2018624E-03
     +,   1.1932326E-03,   1.1857968E-03,   1.1792209E-03
     +,   1.1731208E-03,   1.1670790E-03,   1.1606719E-03
     +,   1.1534928E-03,   1.1451661E-03,   1.1353674E-03
     +,   1.1238335E-03,   1.1103707E-03,   1.0948573E-03
     +,   1.0772425E-03,   1.0575479E-03,   1.0358546E-03
     +,   1.0123008E-03,   9.8707119E-04,   9.6038723E-04
     +,   9.3249488E-04,   9.0365816E-04,   8.7414804E-04
     +,   8.4423687E-04,   8.1418577E-04,   7.8424212E-04
     +,   7.5463689E-04,   7.2557834E-04,   6.9724681E-04
     +,   6.6979782E-04,   6.4336200E-04,   6.1804062E-04
     +,   5.9390935E-04,   5.7102193E-04,   5.4940907E-04
     +,   5.2908005E-04,   5.1002682E-04,   4.9222622E-04
     +,   4.7564253E-04,   4.6022769E-04,   4.4592432E-04
     +,   4.3267006E-04,   4.2039700E-04,   4.0903321E-04
     +,   3.9850539E-04,   3.8874068E-04,   3.7966613E-04
     +,   3.7121115E-04,   3.6330809E-04,   3.5589316E-04
     +,   3.4890606E-04,   3.4229134E-04,   3.3599877E-04
     +,   3.2998330E-04,   3.2420486E-04,   3.1862824E-04
     +,   3.1322389E-04,   3.0796704E-04,   3.0283732E-04
     +,   2.9781854E-04,   2.9289900E-04,   2.8806998E-04
     +,   2.8332576E-04,   2.7866391E-04,   2.7408381E-04
     +,   2.6958660E-04,   2.6517449E-04,   2.6085132E-04
     +,   2.5662093E-04,   2.5248746E-04,   2.4845471E-04
     +,   2.4452645E-04,   2.4070563E-04,   2.3699415E-04
     +,   2.3339284E-04,   2.2990177E-04,   2.2651942E-04
     +,   2.2324307E-04,   2.2006891E-04,   2.1699193E-04
     +,   2.1400586E-04,   2.1110328E-04,   2.0827611E-04
     +,   2.0551548E-04,   2.0281175E-04,   2.0015477E-04
     +,   1.9753426E-04,   1.9493981E-04,   1.9236089E-04
     +,   1.8978704E-04,   1.8720850E-04,   1.8461568E-04
     +,   1.8199951E-04,   1.7935185E-04,   1.7666530E-04
     +,   1.7393316E-04,   1.7114967E-04,   1.6831013E-04
     +,   1.6541095E-04,   1.6244919E-04,   1.5942307E-04
     +,   1.5633188E-04,   1.5317596E-04,   1.4995632E-04
     +,   1.4667482E-04,   1.4333449E-04,   1.3993877E-04
     +,   1.3649184E-04,   1.3299866E-04,   1.2946475E-04
     +,   1.2589589E-04,   1.2229824E-04,   1.1867846E-04
     +,   1.1504350E-04,   1.1140019E-04,   1.0775550E-04
     +,   1.0411661E-04,   1.0049068E-04,   9.6884512E-05
     +,   9.3304807E-05,   8.9758316E-05,   8.6251304E-05
     +,   8.2789651E-05,   7.9379213E-05,   7.6025462E-05
     +,   7.2733266E-05,   6.9507129E-05,   6.6351335E-05
     +,   6.3269785E-05,   6.0265720E-05,   5.7341978E-05
     +,   5.4501306E-05,   5.1745581E-05,   4.9076716E-05
     +,   4.6495868E-05,   4.4004129E-05,   4.1601928E-05
     +,   3.9289662E-05,   3.7067086E-05,   3.4933964E-05
     +,   3.2889493E-05,   3.0932868E-05,   2.9062849E-05
     +,   2.7277991E-05,   2.5576819E-05,   2.3957462E-05
     +,   2.2418115E-05,   2.0956615E-05,   1.9570896E-05
     +,   1.8258594E-05,   1.7017459E-05,   1.5844997E-05
     +,   1.4738830E-05,   1.3696406E-05,   1.2715283E-05
     +,   1.1792889E-05,   1.0926780E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz65 = Yx/0.0688947368421053
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5271895E-05,   2.6318941E-05
     +,   2.7393970E-05,   2.8495990E-05,   2.9623850E-05
     +,   3.0776231E-05,   3.1951648E-05,   3.3148473E-05
     +,   3.4364879E-05,   3.5598972E-05,   3.6848618E-05
     +,   3.8111612E-05,   3.9385643E-05,   4.0668307E-05
     +,   4.1957199E-05,   4.3249893E-05,   4.4544096E-05
     +,   4.5837638E-05,   4.7128633E-05,   4.8415590E-05
     +,   4.9697555E-05,   5.0974300E-05,   5.2246563E-05
     +,   5.3516356E-05,   5.4787150E-05,   5.6064517E-05
     +,   5.7356370E-05,   5.8673675E-05,   6.0031030E-05
     +,   6.1447441E-05,   6.2947220E-05,   6.4560911E-05
     +,   6.6326342E-05,   6.8289868E-05,   7.0507347E-05
     +,   7.3045514E-05,   7.5982942E-05,   7.9410958E-05
     +,   8.3434476E-05,   8.8171771E-05,   9.3755029E-05
     +,   1.0032887E-04,   1.0804943E-04,   1.1708226E-04
     +,   1.2759987E-04,   1.3977929E-04,   1.5379944E-04
     +,   1.6983898E-04,   1.8807514E-04,   2.0868378E-04
     +,   2.3184076E-04,   2.5772452E-04,   2.8651964E-04
     +,   3.1842350E-04,   3.5364486E-04,   3.9241431E-04
     +,   4.3498256E-04,   4.8162648E-04,   5.3265656E-04
     +,   5.8843184E-04,   6.4938574E-04,   7.1607128E-04
     +,   7.8921759E-04,   8.6982083E-04,   9.5923053E-04
     +,   1.0592336E-03,   1.1721497E-03,   1.3008323E-03
     +,   1.4486655E-03,   1.6194017E-03,   1.8169832E-03
     +,   2.0451811E-03,   2.3072541E-03,   2.6054485E-03
     +,   2.9406101E-03,   3.3117463E-03,   3.7156516E-03
     +,   4.1467170E-03,   4.5969319E-03,   5.0561777E-03
     +,   5.5128289E-03,   5.9549082E-03,   6.3712299E-03
     +,   6.7527285E-03,   7.0930608E-03,   7.3885783E-03
     +,   7.6373257E-03,   7.8374911E-03,   7.9858825E-03
     +,   8.0770403E-03,   8.1036035E-03,   8.0577685E-03
     +,   7.9336679E-03,   7.7296929E-03,   7.4503585E-03
     +,   7.1069794E-03,   6.7169578E-03,   6.3019539E-03
     +,   5.8849459E-03,   5.4872464E-03,   5.1257149E-03
     +,   4.8111598E-03,   4.5478661E-03,   4.3345680E-03
     +,   4.1660531E-03,   4.0351329E-03,   3.9342409E-03
     +,   3.8563639E-03,   3.7953369E-03,   3.7456863E-03
     +,   3.7023036E-03,   3.6602353E-03,   3.6147323E-03
     +,   3.5615643E-03,   3.4974590E-03,   3.4205529E-03
     +,   3.3306417E-03,   3.2291953E-03,   3.1191099E-03
     +,   3.0042061E-03,   2.8886835E-03,   2.7765562E-03
     +,   2.6711987E-03,   2.5750601E-03,   2.4895619E-03
     +,   2.4151455E-03,   2.3514088E-03,   2.2973432E-03
     +,   2.2515273E-03,   2.2123782E-03,   2.1783062E-03
     +,   2.1478785E-03,   2.1198995E-03,   2.0934641E-03
     +,   2.0679531E-03,   2.0429888E-03,   2.0183721E-03
     +,   1.9940012E-03,   1.9697878E-03,   1.9456109E-03
     +,   1.9212810E-03,   1.8965470E-03,   1.8711146E-03
     +,   1.8446838E-03,   1.8169965E-03,   1.7878658E-03
     +,   1.7571929E-03,   1.7249736E-03,   1.6912727E-03
     +,   1.6562028E-03,   1.6198852E-03,   1.5824282E-03
     +,   1.5439013E-03,   1.5043262E-03,   1.4636826E-03
     +,   1.4219281E-03,   1.3790164E-03,   1.3349251E-03
     +,   1.2896791E-03,   1.2433751E-03,   1.1961809E-03
     +,   1.1483441E-03,   1.1001821E-03,   1.0520639E-03
     +,   1.0043870E-03,   9.5755397E-04,   9.1195555E-04
     +,   8.6794613E-04,   8.2582555E-04,   7.8583421E-04
     +,   7.4814982E-04,   7.1288843E-04,   6.8010640E-04
     +,   6.4981170E-04,   6.2197633E-04,   5.9654139E-04
     +,   5.7342876E-04,   5.5255136E-04,   5.3381675E-04
     +,   5.1713042E-04,   5.0239958E-04,   4.8953446E-04
     +,   4.7844631E-04,   4.6904606E-04,   4.6124271E-04
     +,   4.5494261E-04,   4.5004635E-04,   4.4644825E-04
     +,   4.4403540E-04,   4.4268815E-04,   4.4228017E-04
     +,   4.4267924E-04,   4.4374907E-04,   4.4535068E-04
     +,   4.4734392E-04,   4.4959050E-04,   4.5195440E-04
     +,   4.5430486E-04,   4.5651809E-04,   4.5847820E-04
     +,   4.6007952E-04,   4.6122656E-04,   4.6183626E-04
     +,   4.6183803E-04,   4.6117362E-04,   4.5979852E-04
     +,   4.5768052E-04,   4.5480111E-04,   4.5115338E-04
     +,   4.4674240E-04,   4.4158331E-04,   4.3570178E-04
     +,   4.2913211E-04,   4.2191581E-04,   4.1410021E-04
     +,   4.0573862E-04,   3.9688783E-04,   3.8760682E-04
     +,   3.7795567E-04,   3.6799605E-04,   3.5778750E-04
     +,   3.4738833E-04,   3.3685498E-04,   3.2624093E-04
     +,   3.1559562E-04,   3.0496449E-04,   2.9438938E-04
     +,   2.8390810E-04,   2.7355339E-04,   2.6335340E-04
     +,   2.5333333E-04,   2.4351387E-04,   2.3391172E-04
     +,   2.2453982E-04,   2.1540921E-04,   2.0652688E-04
     +,   1.9789769E-04,   1.8952458E-04,   1.8140874E-04
     +,   1.7354944E-04,   1.6594442E-04,   1.5859106E-04
     +,   1.5148589E-04,   1.4462433E-04,   1.3800140E-04
     +,   1.3161228E-04,   1.2545200E-04,   1.1951504E-04
     +,   1.1379588E-04,   1.0828976E-04,   1.0299134E-04
     +,   9.7895449E-05,   9.2997427E-05,   8.8292662E-05
     +,   8.3776409E-05,   7.9444064E-05,   7.5291391E-05
     +,   7.1314214E-05,   6.7508219E-05,   6.3869091E-05
     +,   6.0392798E-05,   5.7075307E-05,   5.3912365E-05
     +,   5.0899707E-05,   4.8033336E-05,   4.5308909E-05
     +,   4.2722048E-05,   4.0268562E-05,   3.7944123E-05
     +,   3.5744277E-05,   3.3664495E-05,   3.1700427E-05
     +,   2.9847626E-05,   2.8101580E-05,   2.6457756E-05
     +,   2.4911842E-05,   2.3459308E-05,   2.2095901E-05
     +,   2.0817233E-05,   1.9619163E-05,   1.8497467E-05
     +,   1.7448174E-05,   1.6467273E-05,   1.5550993E-05
     +,   1.4695570E-05,   1.3897468E-05,   1.3153204E-05
     +,   1.2459438E-05,   1.1813028E-05,   1.1210893E-05
     +,   1.0650163E-05,   1.0128037E-05,   9.6419217E-06
     +,   9.1892935E-06,   8.7678272E-06,   8.3752702E-06
     +,   8.0095524E-06,   7.6686774E-06,   7.3508127E-06
     +,   7.0542028E-06,   6.7772426E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz70 = Yx/0.090825
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8157718E-05,   2.9269957E-05
     +,   3.0402245E-05,   3.1553594E-05,   3.2722986E-05
     +,   3.3909426E-05,   3.5111945E-05,   3.6329657E-05
     +,   3.7561731E-05,   3.8807557E-05,   4.0066607E-05
     +,   4.1338626E-05,   4.2623600E-05,   4.3921831E-05
     +,   4.5233992E-05,   4.6561192E-05,   4.7905010E-05
     +,   4.9267583E-05,   5.0651626E-05,   5.2060568E-05
     +,   5.3498541E-05,   5.4970460E-05,   5.6482109E-05
     +,   5.8040237E-05,   5.9652426E-05,   6.1327424E-05
     +,   6.3074956E-05,   6.4905864E-05,   6.6832159E-05
     +,   6.8867004E-05,   7.1024770E-05,   7.3321004E-05
     +,   7.5772514E-05,   7.8397265E-05,   8.1214464E-05
     +,   8.4244442E-05,   8.7508568E-05,   9.1029266E-05
     +,   9.4830022E-05,   9.8934681E-05,   1.0336807E-04
     +,   1.0815504E-04,   1.1332062E-04,   1.1888942E-04
     +,   1.2488537E-04,   1.3133112E-04,   1.3824760E-04
     +,   1.4565338E-04,   1.5356419E-04,   1.6199231E-04
     +,   1.7094596E-04,   1.8042891E-04,   1.9044020E-04
     +,   2.0097499E-04,   2.1202273E-04,   2.2357047E-04
     +,   2.3560255E-04,   2.4810297E-04,   2.6105772E-04
     +,   2.7445873E-04,   2.8830708E-04,   3.0261939E-04
     +,   3.1743129E-04,   3.3280655E-04,   3.4884285E-04
     +,   3.6567796E-04,   3.8350120E-04,   4.0255758E-04
     +,   4.2316143E-04,   4.4569897E-04,   4.7064229E-04
     +,   4.9854693E-04,   5.3006050E-04,   5.6590704E-04
     +,   6.0687627E-04,   6.5378746E-04,   7.0744316E-04
     +,   7.6857291E-04,   8.3778141E-04,   9.1550651E-04
     +,   1.0020059E-03,   1.0974252E-03,   1.2018958E-03
     +,   1.3157341E-03,   1.4396324E-03,   1.5748993E-03
     +,   1.7235880E-03,   1.8886118E-03,   2.0737138E-03
     +,   2.2834835E-03,   2.5233582E-03,   2.7996770E-03
     +,   3.1197027E-03,   3.4912892E-03,   3.9217449E-03
     +,   4.4156271E-03,   4.9719564E-03,   5.5815787E-03
     +,   6.2269298E-03,   6.8850159E-03,   7.5340965E-03
     +,   8.1611173E-03,   8.7664211E-03,   9.3618585E-03
     +,   9.9626528E-03,   1.0576018E-02,   1.1192718E-02
     +,   1.1785280E-02,   1.2313114E-02,   1.2731348E-02
     +,   1.3000599E-02,   1.3096426E-02,   1.3016458E-02
     +,   1.2782353E-02,   1.2433299E-02,   1.2011768E-02
     +,   1.1549321E-02,   1.1060013E-02,   1.0545799E-02
     +,   1.0007765E-02,   9.4556361E-03,   8.9092413E-03
     +,   8.3929189E-03,   7.9274643E-03,   7.5245718E-03
     +,   7.1852840E-03,   6.9017652E-03,   6.6609448E-03
     +,   6.4481688E-03,   6.2501803E-03,   6.0566962E-03
     +,   5.8608735E-03,   5.6587812E-03,   5.4486473E-03
     +,   5.2301348E-03,   5.0039501E-03,   4.7717909E-03
     +,   4.5362846E-03,   4.3008858E-03,   4.0695369E-03
     +,   3.8461308E-03,   3.6338950E-03,   3.4349398E-03
     +,   3.2501339E-03,   3.0792730E-03,   2.9213855E-03
     +,   2.7751140E-03,   2.6390192E-03,   2.5117088E-03
     +,   2.3918657E-03,   2.2782576E-03,   2.1697120E-03
     +,   2.0651449E-03,   1.9636063E-03,   1.8643498E-03
     +,   1.7668954E-03,   1.6710464E-03,   1.5768711E-03
     +,   1.4846630E-03,   1.3948928E-03,   1.3081240E-03
     +,   1.2249626E-03,   1.1460163E-03,   1.0718517E-03
     +,   1.0029644E-03,   9.3976973E-04,   8.8259304E-04
     +,   8.3165482E-04,   7.8706350E-04,   7.4881635E-04
     +,   7.1680290E-04,   6.9080683E-04,   6.7051675E-04
     +,   6.5553974E-04,   6.4542057E-04,   6.3965464E-04
     +,   6.3770870E-04,   6.3903513E-04,   6.4308691E-04
     +,   6.4932927E-04,   6.5724785E-04,   6.6635740E-04
     +,   6.7620457E-04,   6.8637339E-04,   6.9648609E-04
     +,   7.0620491E-04,   7.1523199E-04,   7.2331069E-04
     +,   7.3022605E-04,   7.3580281E-04,   7.3990726E-04
     +,   7.4244395E-04,   7.4335706E-04,   7.4262742E-04
     +,   7.4027013E-04,   7.3633302E-04,   7.3089288E-04
     +,   7.2405214E-04,   7.1593485E-04,   7.0668157E-04
     +,   6.9644663E-04,   6.8539183E-04,   6.7368243E-04
     +,   6.6148152E-04,   6.4894836E-04,   6.3623133E-04
     +,   6.2346645E-04,   6.1077427E-04,   5.9825683E-04
     +,   5.8599690E-04,   5.7405554E-04,   5.6247425E-04
     +,   5.5127410E-04,   5.4045575E-04,   5.3000194E-04
     +,   5.1988079E-04,   5.1004637E-04,   5.0044182E-04
     +,   4.9100223E-04,   4.8165876E-04,   4.7233928E-04
     +,   4.6297317E-04,   4.5349318E-04,   4.4383798E-04
     +,   4.3395319E-04,   4.2379351E-04,   4.1332483E-04
     +,   4.0252408E-04,   3.9137920E-04,   3.7988942E-04
     +,   3.6806575E-04,   3.5592975E-04,   3.4351158E-04
     +,   3.3084955E-04,   3.1798970E-04,   3.0498303E-04
     +,   2.9188365E-04,   2.7874962E-04,   2.6563962E-04
     +,   2.5261135E-04,   2.3972096E-04,   2.2702281E-04
     +,   2.1456798E-04,   2.0240214E-04,   1.9056664E-04
     +,   1.7909825E-04,   1.6802840E-04,   1.5738228E-04
     +,   1.4717982E-04,   1.3743654E-04,   1.2816217E-04
     +,   1.1936159E-04,   1.1103619E-04,   1.0318325E-04
     +,   9.5796146E-05,   8.8865265E-05,   8.2378923E-05
     +,   7.6323136E-05,   7.0681810E-05,   6.5437525E-05
     +,   6.0572158E-05,   5.6066852E-05,   5.1901992E-05
     +,   4.8057758E-05,   4.4514829E-05,   4.1253654E-05
     +,   3.8255108E-05,   3.5500787E-05,   3.2972865E-05
     +,   3.0654053E-05,   2.8527857E-05,   2.6578751E-05
     +,   2.4792036E-05,   2.3153776E-05,   2.1650943E-05
     +,   2.0271518E-05,   1.9004186E-05,   1.7838640E-05
     +,   1.6765249E-05,   1.5775320E-05,   1.4860788E-05
     +,   1.4014433E-05,   1.3229599E-05,   1.2500373E-05
     +,   1.1821340E-05,   1.1187729E-05,   1.0595205E-05
     +,   1.0039906E-05,   9.5184396E-06,   9.0277408E-06
     +,   8.5651391E-06,   8.1282269E-06,   7.7149271E-06
     +,   7.3233482E-06,   6.9518769E-06,   6.5990384E-06
     +,   6.2635727E-06,   5.9443209E-06,   5.6402969E-06
     +,   5.3505823E-06,   5.0743943E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz75 = Yx/0.122926829268293
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1020903E-05,   3.1619427E-05
     +,   3.2199681E-05,   3.2760599E-05,   3.3301189E-05
     +,   3.3820568E-05,   3.4317960E-05,   3.4792687E-05
     +,   3.5244204E-05,   3.5672132E-05,   3.6076188E-05
     +,   3.6456269E-05,   3.6812420E-05,   3.7144877E-05
     +,   3.7454047E-05,   3.7740516E-05,   3.8005110E-05
     +,   3.8248843E-05,   3.8472965E-05,   3.8678969E-05
     +,   3.8868598E-05,   3.9043873E-05,   3.9207109E-05
     +,   3.9360912E-05,   3.9508228E-05,   3.9652372E-05
     +,   3.9797003E-05,   3.9946215E-05,   4.0104522E-05
     +,   4.0276922E-05,   4.0468905E-05,   4.0686529E-05
     +,   4.0936411E-05,   4.1225809E-05,   4.1562660E-05
     +,   4.1955584E-05,   4.2413987E-05,   4.2948021E-05
     +,   4.3568722E-05,   4.4287877E-05,   4.5118231E-05
     +,   4.6073317E-05,   4.7167538E-05,   4.8416088E-05
     +,   4.9834933E-05,   5.1440671E-05,   5.3250475E-05
     +,   5.5281911E-05,   5.7552759E-05,   6.0080827E-05
     +,   6.2883621E-05,   6.5978122E-05,   6.9380338E-05
     +,   7.3105351E-05,   7.7166136E-05,   8.1573999E-05
     +,   8.6337677E-05,   9.1463087E-05,   9.6952819E-05
     +,   1.0280600E-04,   1.0901780E-04,   1.1557953E-04
     +,   1.2247780E-04,   1.2969565E-04,   1.3721221E-04
     +,   1.4500240E-04,   1.5303899E-04,   1.6129158E-04
     +,   1.6972974E-04,   1.7832205E-04,   1.8704006E-04
     +,   1.9585766E-04,   2.0475578E-04,   2.1372203E-04
     +,   2.2275558E-04,   2.3186876E-04,   2.4108907E-04
     +,   2.5046273E-04,   2.6005742E-04,   2.6996425E-04
     +,   2.8029858E-04,   2.9120353E-04,   3.0284864E-04
     +,   3.1543290E-04,   3.2918187E-04,   3.4435070E-04
     +,   3.6122007E-04,   3.8010118E-04,   4.0133274E-04
     +,   4.2529058E-04,   4.5239358E-04,   4.8311663E-04
     +,   5.1800907E-04,   5.5772119E-04,   6.0302560E-04
     +,   6.5483339E-04,   7.1421149E-04,   7.8236795E-04
     +,   8.6064846E-04,   9.5050014E-04,   1.0534852E-03
     +,   1.1712869E-03,   1.3058151E-03,   1.4592988E-03
     +,   1.6344656E-03,   1.8346343E-03,   2.0637095E-03
     +,   2.3259623E-03,   2.6254668E-03,   2.9649911E-03
     +,   3.3443451E-03,   3.7585851E-03,   4.1966336E-03
     +,   4.6418984E-03,   5.0757355E-03,   5.4844837E-03
     +,   5.8679953E-03,   6.2463544E-03,   6.6594691E-03
     +,   7.1565555E-03,   7.7766441E-03,   8.5283788E-03
     +,   9.3819769E-03,   1.0283246E-02,   1.1186560E-02
     +,   1.2087022E-02,   1.3024751E-02,   1.4047329E-02
     +,   1.5149287E-02,   1.6233413E-02,   1.7134009E-02
     +,   1.7694745E-02,   1.7850747E-02,   1.7657330E-02
     +,   1.7247014E-02,   1.6746512E-02,   1.6212298E-02
     +,   1.5631000E-02,   1.4979303E-02,   1.4285635E-02
     +,   1.3632837E-02,   1.3095656E-02,   1.2668960E-02
     +,   1.2253230E-02,   1.1714369E-02,   1.0972387E-02
     +,   1.0053493E-02,   9.0734363E-03,   8.1730774E-03
     +,   7.4530928E-03,   6.9422843E-03,   6.6040060E-03
     +,   6.3647097E-03,   6.1456356E-03,   5.8857980E-03
     +,   5.5526863E-03,   5.1425067E-03,   4.6733762E-03
     +,   4.1753380E-03,   3.6805065E-03,   3.2154713E-03
     +,   2.7974742E-03,   2.4340074E-03,   2.1247780E-03
     +,   1.8646873E-03,   1.6466876E-03,   1.4637846E-03
     +,   1.3100356E-03,   1.1808110E-03,   1.0726458E-03
     +,   9.8294648E-04,   9.0969942E-04,   8.5127325E-04
     +,   8.0629316E-04,   7.7356189E-04,   7.5198268E-04
     +,   7.4051128E-04,   7.3810748E-04,   7.4369716E-04
     +,   7.5615395E-04,   7.7429140E-04,   7.9687190E-04
     +,   8.2262413E-04,   8.5027225E-04,   8.7856833E-04
     +,   9.0632279E-04,   9.3243900E-04,   9.5594703E-04
     +,   9.7602716E-04,   9.9203235E-04,   1.0035002E-03
     +,   1.0101619E-03,   1.0119369E-03,   1.0089256E-03
     +,   1.0013907E-03,   9.8973315E-04,   9.7446219E-04
     +,   9.5616753E-04,   9.3548017E-04,   9.1304327E-04
     +,   8.8948396E-04,   8.6538482E-04,   8.4126292E-04
     +,   8.1755471E-04,   7.9460995E-04,   7.7268324E-04
     +,   7.5193675E-04,   7.3244941E-04,   7.1422249E-04
     +,   6.9719099E-04,   6.8123802E-04,   6.6620886E-04
     +,   6.5192307E-04,   6.3818635E-04,   6.2480243E-04
     +,   6.1158300E-04,   5.9835543E-04,   5.8496755E-04
     +,   5.7129189E-04,   5.5723108E-04,   5.4271554E-04
     +,   5.2770425E-04,   5.1218498E-04,   4.9617101E-04
     +,   4.7969745E-04,   4.6281831E-04,   4.4560360E-04
     +,   4.2813571E-04,   4.1050345E-04,   3.9279877E-04
     +,   3.7511639E-04,   3.5754853E-04,   3.4018070E-04
     +,   3.2309224E-04,   3.0635530E-04,   2.9003111E-04
     +,   2.7417127E-04,   2.5881809E-04,   2.4400438E-04
     +,   2.2975291E-04,   2.1607832E-04,   2.0298858E-04
     +,   1.9048560E-04,   1.7856513E-04,   1.6721888E-04
     +,   1.5643594E-04,   1.4620292E-04,   1.3650414E-04
     +,   1.2732274E-04,   1.1864214E-04,   1.1044452E-04
     +,   1.0271197E-04,   9.5427305E-05,   8.8573353E-05
     +,   8.2132727E-05,   7.6088305E-05,   7.0423594E-05
     +,   6.5122142E-05,   6.0167389E-05,   5.5542943E-05
     +,   5.1232815E-05,   4.7221216E-05,   4.3492186E-05
     +,   4.0030056E-05,   3.6819754E-05,   3.3846172E-05
     +,   3.1094602E-05,   2.8550950E-05,   2.6201562E-05
     +,   2.4033192E-05,   2.2033133E-05,   2.0189455E-05
     +,   1.8490822E-05,   1.6926446E-05,   1.5486168E-05
     +,   1.4160653E-05,   1.2941004E-05,   1.1819121E-05
     +,   1.0787346E-05,   9.8387336E-06,   8.9667528E-06
     +,   8.1655062E-06,   7.4294521E-06,   6.7535939E-06
     +,   6.1332498E-06,   5.5641949E-06,   5.0424856E-06
     +,   4.5644892E-06,   4.1269072E-06,   3.7266352E-06
     +,   3.3608546E-06,   3.0269114E-06,   2.7223869E-06
     +,   2.4449978E-06,   2.1926573E-06,   1.9633912E-06
     +,   1.7553926E-06,   1.5669505E-06,   1.3964941E-06
     +,   1.2425384E-06,   1.1037197E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz80 = Yx/0.14146511627907
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7281242E-05,   1.7705799E-05
     +,   1.8127732E-05,   1.8546609E-05,   1.8962035E-05
     +,   1.9373656E-05,   1.9781162E-05,   2.0184303E-05
     +,   2.0582866E-05,   2.0976742E-05,   2.1365853E-05
     +,   2.1750207E-05,   2.2129894E-05,   2.2505083E-05
     +,   2.2876036E-05,   2.3243101E-05,   2.3606730E-05
     +,   2.3967468E-05,   2.4325966E-05,   2.4682980E-05
     +,   2.5039368E-05,   2.5396103E-05,   2.5754247E-05
     +,   2.6114996E-05,   2.6479624E-05,   2.6849513E-05
     +,   2.7226151E-05,   2.7611106E-05,   2.8006043E-05
     +,   2.8412695E-05,   2.8832868E-05,   2.9268431E-05
     +,   2.9721296E-05,   3.0193431E-05,   3.0686810E-05
     +,   3.1203421E-05,   3.1745265E-05,   3.2314314E-05
     +,   3.2912543E-05,   3.3541815E-05,   3.4204018E-05
     +,   3.4900913E-05,   3.5634206E-05,   3.6405487E-05
     +,   3.7216287E-05,   3.8067996E-05,   3.8961924E-05
     +,   3.9899260E-05,   4.0881128E-05,   4.1908566E-05
     +,   4.2982534E-05,   4.4103985E-05,   4.5273875E-05
     +,   4.6493271E-05,   4.7763220E-05,   4.9085069E-05
     +,   5.0460385E-05,   5.1891060E-05,   5.3379419E-05
     +,   5.4928376E-05,   5.6541467E-05,   5.8223090E-05
     +,   5.9978465E-05,   6.1813997E-05,   6.3737440E-05
     +,   6.5757660E-05,   6.7885449E-05,   7.0132985E-05
     +,   7.2514718E-05,   7.5046875E-05,   7.7748271E-05
     +,   8.0639824E-05,   8.3745348E-05,   8.7091175E-05
     +,   9.0706730E-05,   9.4624542E-05,   9.8880038E-05
     +,   1.0351181E-04,   1.0856198E-04,   1.1407588E-04
     +,   1.2010129E-04,   1.2668959E-04,   1.3389370E-04
     +,   1.4176921E-04,   1.5037160E-04,   1.5975753E-04
     +,   1.6998089E-04,   1.8109391E-04,   1.9314255E-04
     +,   2.0616682E-04,   2.2019772E-04,   2.3525403E-04
     +,   2.5134117E-04,   2.6845126E-04,   2.8656164E-04
     +,   3.0563428E-04,   3.2562314E-04,   3.4647441E-04
     +,   3.6814046E-04,   3.9058598E-04,   4.1380766E-04
     +,   4.3784649E-04,   4.6281269E-04,   4.8889988E-04
     +,   5.1641051E-04,   5.4576871E-04,   5.7753455E-04
     +,   6.1241037E-04,   6.5124937E-04,   6.9504889E-04
     +,   7.4494013E-04,   8.0218347E-04,   8.6813135E-04
     +,   9.4420236E-04,   1.0317973E-03,   1.1322128E-03
     +,   1.2464748E-03,   1.3751733E-03,   1.5182236E-03
     +,   1.6747045E-03,   1.8427371E-03,   2.0195288E-03
     +,   2.2016990E-03,   2.3859607E-03,   2.5701853E-03
     +,   2.7548308E-03,   2.9445807E-03,   3.1495562E-03
     +,   3.3855487E-03,   3.6722275E-03,   4.0290556E-03
     +,   4.4691018E-03,   4.9927938E-03,   5.5842944E-03
     +,   6.2143332E-03,   6.8508312E-03,   7.4751587E-03
     +,   8.0964835E-03,   8.7544490E-03,   9.5060179E-03
     +,   1.0404578E-02,   1.1484971E-02,   1.2757104E-02
     +,   1.4194685E-02,   1.5714711E-02,   1.7178934E-02
     +,   1.8449094E-02,   1.9465240E-02,   2.0271622E-02
     +,   2.0975173E-02,   2.1692559E-02,   2.2494787E-02
     +,   2.3310443E-02,   2.3856031E-02,   2.3745727E-02
     +,   2.2768162E-02,   2.1072712E-02,   1.9059148E-02
     +,   1.7090486E-02,   1.5318705E-02,   1.3730332E-02
     +,   1.2276848E-02,   1.0940926E-02,   9.7269509E-03
     +,   8.6360117E-03,   7.6602143E-03,   6.7900503E-03
     +,   6.0204044E-03,   5.3501436E-03,   4.7780033E-03
     +,   4.2987596E-03,   3.9019438E-03,   3.5734656E-03
     +,   3.2988258E-03,   3.0660506E-03,   2.8669636E-03
     +,   2.6968939E-03,   2.5534178E-03,   2.4350260E-03
     +,   2.3401633E-03,   2.2667723E-03,   2.2121400E-03
     +,   2.1729635E-03,   2.1455465E-03,   2.1260912E-03
     +,   2.1109940E-03,   2.0971247E-03,   2.0820037E-03
     +,   2.0638923E-03,   2.0417853E-03,   2.0153217E-03
     +,   1.9846633E-03,   1.9503682E-03,   1.9132681E-03
     +,   1.8743566E-03,   1.8347104E-03,   1.7954139E-03
     +,   1.7574839E-03,   1.7217970E-03,   1.6890257E-03
     +,   1.6595727E-03,   1.6335244E-03,   1.6106145E-03
     +,   1.5902395E-03,   1.5714882E-03,   1.5532067E-03
     +,   1.5340952E-03,   1.5128183E-03,   1.4881181E-03
     +,   1.4589201E-03,   1.4244210E-03,   1.3841587E-03
     +,   1.3380366E-03,   1.2863185E-03,   1.2295990E-03
     +,   1.1687506E-03,   1.1048443E-03,   1.0390633E-03
     +,   9.7262155E-04,   9.0669503E-04,   8.4234506E-04
     +,   7.8047725E-04,   7.2181533E-04,   6.6688500E-04
     +,   6.1601232E-04,   5.6934363E-04,   5.2687206E-04
     +,   4.8846233E-04,   4.5387988E-04,   4.2282406E-04
     +,   3.9495795E-04,   3.6992825E-04,   3.4738373E-04
     +,   3.2699117E-04,   3.0844618E-04,   2.9147527E-04
     +,   2.7584028E-04,   2.6133907E-04,   2.4780261E-04
     +,   2.3509107E-04,   2.2309105E-04,   2.1171277E-04
     +,   2.0088500E-04,   1.9055139E-04,   1.8066754E-04
     +,   1.7119969E-04,   1.6212133E-04,   1.5341092E-04
     +,   1.4505144E-04,   1.3702968E-04,   1.2933402E-04
     +,   1.2195465E-04,   1.1488344E-04,   1.0811310E-04
     +,   1.0163648E-04,   9.5446921E-05,   8.9538386E-05
     +,   8.3904924E-05,   7.8540223E-05,   7.3437986E-05
     +,   6.8592097E-05,   6.3996304E-05,   5.9643855E-05
     +,   5.5527835E-05,   5.1641531E-05,   4.7977621E-05
     +,   4.4528653E-05,   4.1287214E-05,   3.8245715E-05
     +,   3.5396239E-05,   3.2730775E-05,   3.0241465E-05
     +,   2.7920350E-05,   2.5759320E-05,   2.3750305E-05
     +,   2.1885500E-05,   2.0156913E-05,   1.8556924E-05
     +,   1.7077835E-05,   1.5712323E-05,   1.4453078E-05
     +,   1.3293192E-05,   1.2225834E-05,   1.1244590E-05
     +,   1.0343172E-05,   9.5157175E-06,   8.7565613E-06
     +,   8.0603522E-06,   7.4221107E-06,   6.8370719E-06
     +,   6.3008570E-06,   5.8093096E-06,   5.3586336E-06
     +,   4.9452547E-06,   4.5659244E-06,   4.2176084E-06
     +,   3.8975663E-06,   3.6032527E-06,   3.3323813E-06
     +,   3.0828389E-06,   2.8527404E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz85 = Yx/0.160186046511628
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.2116679E-06,   9.4432971E-06
     +,   9.6776794E-06,   9.9147865E-06,   1.0154597E-05
     +,   1.0397106E-05,   1.0642314E-05,   1.0890240E-05
     +,   1.1140914E-05,   1.1394402E-05,   1.1650778E-05
     +,   1.1910154E-05,   1.2172670E-05,   1.2438506E-05
     +,   1.2707887E-05,   1.2981081E-05,   1.3258421E-05
     +,   1.3540292E-05,   1.3827163E-05,   1.4119561E-05
     +,   1.4418128E-05,   1.4723573E-05,   1.5036727E-05
     +,   1.5358555E-05,   1.5690104E-05,   1.6032607E-05
     +,   1.6387423E-05,   1.6756077E-05,   1.7140268E-05
     +,   1.7541888E-05,   1.7963019E-05,   1.8405950E-05
     +,   1.8873196E-05,   1.9367493E-05,   1.9891817E-05
     +,   2.0449390E-05,   2.1043674E-05,   2.1678370E-05
     +,   2.2357466E-05,   2.3085133E-05,   2.3865841E-05
     +,   2.4704243E-05,   2.5605219E-05,   2.6573831E-05
     +,   2.7615310E-05,   2.8735014E-05,   2.9938406E-05
     +,   3.1230986E-05,   3.2618264E-05,   3.4105717E-05
     +,   3.5698693E-05,   3.7402366E-05,   3.9221650E-05
     +,   4.1161231E-05,   4.3225213E-05,   4.5417419E-05
     +,   4.7740978E-05,   5.0198410E-05,   5.2791536E-05
     +,   5.5521286E-05,   5.8387788E-05,   6.1390216E-05
     +,   6.4526568E-05,   6.7793997E-05,   7.1188551E-05
     +,   7.4704862E-05,   7.8336867E-05,   8.2076898E-05
     +,   8.5916727E-05,   8.9846573E-05,   9.3856208E-05
     +,   9.7934120E-05,   1.0206848E-04,   1.0624655E-04
     +,   1.1045549E-04,   1.1468239E-04,   1.1891415E-04
     +,   1.2313802E-04,   1.2734212E-04,   1.3151566E-04
     +,   1.3564859E-04,   1.3973305E-04,   1.4376275E-04
     +,   1.4773420E-04,   1.5164619E-04,   1.5550123E-04
     +,   1.5930481E-04,   1.6306690E-04,   1.6680139E-04
     +,   1.7052722E-04,   1.7426845E-04,   1.7805434E-04
     +,   1.8191992E-04,   1.8590655E-04,   1.9006174E-04
     +,   1.9443885E-04,   1.9909820E-04,   2.0410576E-04
     +,   2.0953390E-04,   2.1545982E-04,   2.2196623E-04
     +,   2.2913887E-04,   2.3706710E-04,   2.4584058E-04
     +,   2.5554938E-04,   2.6628128E-04,   2.7811903E-04
     +,   2.9113752E-04,   3.0540305E-04,   3.2096883E-04
     +,   3.3786995E-04,   3.5612439E-04,   3.7572446E-04
     +,   3.9663888E-04,   4.1880523E-04,   4.4213413E-04
     +,   4.6650352E-04,   4.9176818E-04,   5.1776029E-04
     +,   5.4430711E-04,   5.7124643E-04,   5.9845072E-04
     +,   6.2586251E-04,   6.5354048E-04,   6.8170659E-04
     +,   7.1080134E-04,   7.4154994E-04,   7.7501015E-04
     +,   8.1263395E-04,   8.5629598E-04,   9.0832717E-04
     +,   9.7149838E-04,   1.0489874E-03,   1.1442446E-03
     +,   1.2607889E-03,   1.4018489E-03,   1.5698660E-03
     +,   1.7659392E-03,   1.9893709E-03,   2.2374738E-03
     +,   2.5059276E-03,   2.7898250E-03,   3.0853474E-03
     +,   3.3916144E-03,   3.7120713E-03,   4.0548132E-03
     +,   4.4311215E-03,   4.8523927E-03,   5.3262417E-03
     +,   5.8530238E-03,   6.4238734E-03,   7.0209168E-03
     +,   7.6203542E-03,   8.1997011E-03,   8.7509938E-03
     +,   9.2987055E-03,   9.9116592E-03,   1.0691009E-02
     +,   1.1726039E-02,   1.3038024E-02,   1.4552130E-02
     +,   1.6117053E-02,   1.7550284E-02,   1.8677277E-02
     +,   1.9361319E-02,   1.9537546E-02,   1.9242030E-02
     +,   1.8607968E-02,   1.7819429E-02,   1.7040847E-02
     +,   1.6350346E-02,   1.5708975E-02,   1.4993528E-02
     +,   1.4088134E-02,   1.2983345E-02,   1.1813703E-02
     +,   1.0801977E-02,   1.0143701E-02,   9.9082822E-03
     +,   1.0017906E-02,   1.0305268E-02,   1.0598940E-02
     +,   1.0780486E-02,   1.0793014E-02,   1.0620438E-02
     +,   1.0268073E-02,   9.7577721E-03,   9.1304090E-03
     +,   8.4431451E-03,   7.7578998E-03,   7.1264599E-03
     +,   6.5801977E-03,   6.1275330E-03,   5.7580853E-03
     +,   5.4504690E-03,   5.1806737E-03,   4.9287896E-03
     +,   4.6826992E-03,   4.4386885E-03,   4.1996026E-03
     +,   3.9717988E-03,   3.7620775E-03,   3.5753706E-03
     +,   3.4136109E-03,   3.2756070E-03,   3.1576476E-03
     +,   3.0545290E-03,   2.9606312E-03,   2.8707639E-03
     +,   2.7806831E-03,   2.6872805E-03,   2.5885550E-03
     +,   2.4834650E-03,   2.3717498E-03,   2.2538167E-03
     +,   2.1306446E-03,   2.0036753E-03,   1.8746745E-03
     +,   1.7455831E-03,   1.6183585E-03,   1.4947918E-03
     +,   1.3763970E-03,   1.2643464E-03,   1.1594470E-03
     +,   1.0621530E-03,   9.7262539E-04,   8.9079834E-04
     +,   8.1643165E-04,   7.4915943E-04,   6.8853609E-04
     +,   6.3407066E-04,   5.8524357E-04,   5.4152007E-04
     +,   5.0236756E-04,   4.6726959E-04,   4.3572806E-04
     +,   4.0727566E-04,   3.8148466E-04,   3.5796949E-04
     +,   3.3638856E-04,   3.1644656E-04,   2.9789458E-04
     +,   2.8052586E-04,   2.6417102E-04,   2.4869450E-04
     +,   2.3399093E-04,   2.1997921E-04,   2.0659728E-04
     +,   1.9379931E-04,   1.8155332E-04,   1.6983594E-04
     +,   1.5863095E-04,   1.4792844E-04,   1.3772164E-04
     +,   1.2800535E-04,   1.1877533E-04,   1.1002804E-04
     +,   1.0175903E-04,   9.3962102E-05,   8.6629414E-05
     +,   7.9751830E-05,   7.3318122E-05,   6.7314759E-05
     +,   6.1726460E-05,   5.6536959E-05,   5.1728057E-05
     +,   4.7280671E-05,   4.3175300E-05,   3.9392005E-05
     +,   3.5910522E-05,   3.2710799E-05,   2.9773424E-05
     +,   2.7079564E-05,   2.4610974E-05,   2.2350343E-05
     +,   2.0281550E-05,   1.8389199E-05,   1.6659205E-05
     +,   1.5078279E-05,   1.3634350E-05,   1.2316113E-05
     +,   1.1113359E-05,   1.0016557E-05,   9.0171170E-06
     +,   8.1070330E-06,   7.2790804E-06,   6.5265413E-06
     +,   5.8432520E-06,   5.2235973E-06,   4.6623250E-06
     +,   4.1546527E-06,   3.6960992E-06,   3.2825715E-06
     +,   2.9102259E-06,   2.5755471E-06,   2.2752317E-06
     +,   2.0062562E-06,   1.7657832E-06,   1.5512170E-06
     +,   1.3601273E-06,   1.1902952E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz90 = Yx/0.163441860465116
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_ashz_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5804448E-05,   1.6323902E-05
     +,   1.6851276E-05,   1.7386821E-05,   1.7930854E-05
     +,   1.8483774E-05,   1.9046061E-05,   1.9618279E-05
     +,   2.0201080E-05,   2.0795234E-05,   2.1401567E-05
     +,   2.2021030E-05,   2.2654640E-05,   2.3303526E-05
     +,   2.3968894E-05,   2.4652032E-05,   2.5354322E-05
     +,   2.6077189E-05,   2.6822148E-05,   2.7590735E-05
     +,   2.8384540E-05,   2.9205177E-05,   3.0054251E-05
     +,   3.0933410E-05,   3.1844200E-05,   3.2788197E-05
     +,   3.3766872E-05,   3.4781624E-05,   3.5833757E-05
     +,   3.6924441E-05,   3.8054717E-05,   3.9225448E-05
     +,   4.0437331E-05,   4.1690844E-05,   4.2986296E-05
     +,   4.4323690E-05,   4.5702876E-05,   4.7123372E-05
     +,   4.8584559E-05,   5.0085397E-05,   5.1624760E-05
     +,   5.3201187E-05,   5.4812979E-05,   5.6458241E-05
     +,   5.8134858E-05,   5.9840579E-05,   6.1572973E-05
     +,   6.3329535E-05,   6.5107677E-05,   6.6904795E-05
     +,   6.8718356E-05,   7.0545888E-05,   7.2385053E-05
     +,   7.4233860E-05,   7.6090386E-05,   7.7953278E-05
     +,   7.9821461E-05,   8.1694430E-05,   8.3572202E-05
     +,   8.5455365E-05,   8.7345237E-05,   8.9243891E-05
     +,   9.1153983E-05,   9.3079143E-05,   9.5023774E-05
     +,   9.6992946E-05,   9.8992692E-05,   1.0102962E-04
     +,   1.0311128E-04,   1.0524556E-04,   1.0744124E-04
     +,   1.0970723E-04,   1.1205301E-04,   1.1448812E-04
     +,   1.1702213E-04,   1.1966468E-04,   1.2242480E-04
     +,   1.2531107E-04,   1.2833159E-04,   1.3149355E-04
     +,   1.3480293E-04,   1.3826476E-04,   1.4188245E-04
     +,   1.4565821E-04,   1.4959239E-04,   1.5368416E-04
     +,   1.5793039E-04,   1.6232695E-04,   1.6686745E-04
     +,   1.7154438E-04,   1.7634890E-04,   1.8127043E-04
     +,   1.8629750E-04,   1.9141793E-04,   1.9661908E-04
     +,   2.0188747E-04,   2.0721040E-04,   2.1257471E-04
     +,   2.1796873E-04,   2.2338108E-04,   2.2880257E-04
     +,   2.3422494E-04,   2.3964280E-04,   2.4505259E-04
     +,   2.5045394E-04,   2.5584953E-04,   2.6124518E-04
     +,   2.6665023E-04,   2.7207847E-04,   2.7754766E-04
     +,   2.8307948E-04,   2.8870086E-04,   2.9444278E-04
     +,   3.0034193E-04,   3.0643932E-04,   3.1278198E-04
     +,   3.1942132E-04,   3.2641517E-04,   3.3382594E-04
     +,   3.4172201E-04,   3.5017770E-04,   3.5927206E-04
     +,   3.6908878E-04,   3.7971820E-04,   3.9125443E-04
     +,   4.0379533E-04,   4.1744343E-04,   4.3230242E-04
     +,   4.4847996E-04,   4.6608172E-04,   4.8521583E-04
     +,   5.0598639E-04,   5.2849797E-04,   5.5284891E-04
     +,   5.7913666E-04,   6.0745573E-04,   6.3789671E-04
     +,   6.7054789E-04,   7.0549938E-04,   7.4284070E-04
     +,   7.8265864E-04,   8.2503789E-04,   8.7005785E-04
     +,   9.1778662E-04,   9.6826471E-04,   1.0215048E-03
     +,   1.0774726E-03,   1.1360716E-03,   1.1971332E-03
     +,   1.2604167E-03,   1.3256035E-03,   1.3923021E-03
     +,   1.4600706E-03,   1.5284489E-03,   1.5969875E-03
     +,   1.6652787E-03,   1.7329892E-03,   1.7998895E-03
     +,   1.8658449E-03,   1.9308036E-03,   1.9947821E-03
     +,   2.0578236E-03,   2.1199638E-03,   2.1812029E-03
     +,   2.2415037E-03,   2.3007863E-03,   2.3589812E-03
     +,   2.4161227E-03,   2.4725483E-03,   2.5291748E-03
     +,   2.5878893E-03,   2.6520537E-03,   2.7270147E-03
     +,   2.8204764E-03,   2.9423491E-03,   3.1037838E-03
     +,   3.3153540E-03,   3.5855714E-03,   3.9219679E-03
     +,   4.3364195E-03,   4.8526549E-03,   5.5091968E-03
     +,   6.3503869E-03,   7.4066119E-03,   8.6767199E-03
     +,   1.0126722E-02,   1.1702262E-02,   1.3338979E-02
     +,   1.4967903E-02,   1.6532119E-02,   1.8012695E-02
     +,   1.9425888E-02,   2.0777987E-02,   2.2019390E-02
     +,   2.3038352E-02,   2.3696773E-02,   2.3901397E-02
     +,   2.3666918E-02,   2.3086794E-02,   2.2230562E-02
     +,   2.1104405E-02,   1.9720854E-02,   1.8164985E-02
     +,   1.6574485E-02,   1.5077064E-02,   1.3746922E-02
     +,   1.2592692E-02,   1.1574361E-02,   1.0643978E-02
     +,   9.7816605E-03,   8.9974068E-03,   8.3050281E-03
     +,   7.6999771E-03,   7.1594673E-03,   6.6569964E-03
     +,   6.1742412E-03,   5.7026427E-03,   5.2386257E-03
     +,   4.7796001E-03,   4.3239961E-03,   3.8734621E-03
     +,   3.4343034E-03,   3.0164188E-03,   2.6303744E-03
     +,   2.2844349E-03,   1.9828859E-03,   1.7258649E-03
     +,   1.5102348E-03,   1.3308863E-03,   1.1819814E-03
     +,   1.0578316E-03,   9.5338171E-04,   8.6440099E-04
     +,   7.8749598E-04,   7.2002626E-04,   6.5996737E-04
     +,   6.0580036E-04,   5.5640854E-04,   5.1098393E-04
     +,   4.6894970E-04,   4.2990176E-04,   3.9355992E-04
     +,   3.5972457E-04,   3.2824485E-04,   2.9900033E-04
     +,   2.7188810E-04,   2.4681256E-04,   2.2367862E-04
     +,   2.0239192E-04,   1.8285922E-04,   1.6498393E-04
     +,   1.4866877E-04,   1.3381678E-04,   1.2033064E-04
     +,   1.0811249E-04,   9.7065837E-05,   8.7096894E-05
     +,   7.8114681E-05,   7.0031310E-05,   6.2763414E-05
     +,   5.6233235E-05,   5.0368355E-05,   4.5101639E-05
     +,   4.0371819E-05,   3.6123758E-05,   3.2307278E-05
     +,   2.8877455E-05,   2.5794356E-05,   2.3022381E-05
     +,   2.0529686E-05,   1.8288018E-05,   1.6272390E-05
     +,   1.4460560E-05,   1.2832594E-05,   1.1370693E-05
     +,   1.0059061E-05,   8.8833276E-06,   7.8307112E-06
     +,   6.8895165E-06,   6.0492666E-06,   5.3003364E-06
     +,   4.6340515E-06,   4.0424106E-06,   3.5181793E-06
     +,   3.0546692E-06,   2.6458190E-06,   2.2860388E-06
     +,   1.9702202E-06,   1.6937202E-06,   1.4522670E-06
     +,   1.2420014E-06,   1.0593845E-06,   9.0123342E-07
     +,   7.6464755E-07,   6.4702994E-07,   5.4603044E-07
     +,   4.5955701E-07,   3.8573015E-07,   3.2288793E-07
     +,   2.6954828E-07,   2.2440916E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_ashz_ttz95 = Yx/0.157093023255814
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7919681E-05,   1.8281009E-05
     +,   1.8639110E-05,   1.8993960E-05,   1.9345631E-05
     +,   1.9694262E-05,   2.0040086E-05,   2.0383419E-05
     +,   2.0724694E-05,   2.1064443E-05,   2.1403319E-05
     +,   2.1742078E-05,   2.2081620E-05,   2.2422968E-05
     +,   2.2767288E-05,   2.3115883E-05,   2.3470215E-05
     +,   2.3831886E-05,   2.4202674E-05,   2.4584497E-05
     +,   2.4979468E-05,   2.5389851E-05,   2.5818099E-05
     +,   2.6266851E-05,   2.6738908E-05,   2.7237300E-05
     +,   2.7765218E-05,   2.8326065E-05,   2.8923452E-05
     +,   2.9561192E-05,   3.0243307E-05,   3.0974054E-05
     +,   3.1757892E-05,   3.2599495E-05,   3.3503777E-05
     +,   3.4475866E-05,   3.5521094E-05,   3.6645000E-05
     +,   3.7853410E-05,   3.9152179E-05,   4.0547482E-05
     +,   4.2045576E-05,   4.3652835E-05,   4.5375735E-05
     +,   4.7220787E-05,   4.9194481E-05,   5.1303261E-05
     +,   5.3553413E-05,   5.5951023E-05,   5.8501879E-05
     +,   6.1211365E-05,   6.4084401E-05,   6.7125249E-05
     +,   7.0337643E-05,   7.3724143E-05,   7.7286735E-05
     +,   8.1026097E-05,   8.4941777E-05,   8.9032023E-05
     +,   9.3293675E-05,   9.7721997E-05,   1.0231074E-04
     +,   1.0705169E-04,   1.1193523E-04,   1.1695002E-04
     +,   1.2208233E-04,   1.2731744E-04,   1.3263806E-04
     +,   1.3802592E-04,   1.4346054E-04,   1.4892055E-04
     +,   1.5438255E-04,   1.5982270E-04,   1.6521542E-04
     +,   1.7053503E-04,   1.7575518E-04,   1.8084909E-04
     +,   1.8578983E-04,   1.9055128E-04,   1.9510776E-04
     +,   1.9943409E-04,   2.0350682E-04,   2.0730338E-04
     +,   2.1080342E-04,   2.1398797E-04,   2.1684075E-04
     +,   2.1934735E-04,   2.2149619E-04,   2.2327811E-04
     +,   2.2468680E-04,   2.2571866E-04,   2.2637281E-04
     +,   2.2665132E-04,   2.2655896E-04,   2.2610299E-04
     +,   2.2529342E-04,   2.2414241E-04,   2.2266466E-04
     +,   2.2087661E-04,   2.1879688E-04,   2.1644520E-04
     +,   2.1384326E-04,   2.1101348E-04,   2.0797948E-04
     +,   2.0476540E-04,   2.0139571E-04,   1.9789550E-04
     +,   1.9428988E-04,   1.9060361E-04,   1.8686133E-04
     +,   1.8308754E-04,   1.7930577E-04,   1.7553970E-04
     +,   1.7181168E-04,   1.6814416E-04,   1.6455849E-04
     +,   1.6107580E-04,   1.5771651E-04,   1.5450094E-04
     +,   1.5144891E-04,   1.4857999E-04,   1.4591396E-04
     +,   1.4347074E-04,   1.4127031E-04,   1.3933290E-04
     +,   1.3767970E-04,   1.3633199E-04,   1.3531206E-04
     +,   1.3464276E-04,   1.3434768E-04,   1.3445108E-04
     +,   1.3497786E-04,   1.3595338E-04,   1.3740316E-04
     +,   1.3935278E-04,   1.4182758E-04,   1.4485217E-04
     +,   1.4844979E-04,   1.5264236E-04,   1.5744963E-04
     +,   1.6288814E-04,   1.6897090E-04,   1.7570690E-04
     +,   1.8310008E-04,   1.9114770E-04,   1.9984071E-04
     +,   2.0916233E-04,   2.1908632E-04,   2.2957652E-04
     +,   2.4058697E-04,   2.5206004E-04,   2.6392550E-04
     +,   2.7610036E-04,   2.8848989E-04,   3.0098704E-04
     +,   3.1347247E-04,   3.2581651E-04,   3.3788229E-04
     +,   3.4952755E-04,   3.6060682E-04,   3.7097849E-04
     +,   3.8050802E-04,   3.8907319E-04,   3.9657077E-04
     +,   4.0292271E-04,   4.0808116E-04,   4.1203279E-04
     +,   4.1480272E-04,   4.1645634E-04,   4.1709791E-04
     +,   4.1686729E-04,   4.1593434E-04,   4.1449015E-04
     +,   4.1273690E-04,   4.1087766E-04,   4.0910539E-04
     +,   4.0759632E-04,   4.0650612E-04,   4.0597198E-04
     +,   4.0612303E-04,   4.0709836E-04,   4.0907165E-04
     +,   4.1228690E-04,   4.1709773E-04,   4.2401406E-04
     +,   4.3374958E-04,   4.4727238E-04,   4.6585104E-04
     +,   4.9109641E-04,   5.2498368E-04,   5.6986476E-04
     +,   6.2843715E-04,   7.0366944E-04,   7.9866347E-04
     +,   9.1645028E-04,   1.0596949E-03,   1.2303046E-03
     +,   1.4289946E-03,   1.6548375E-03,   1.9048180E-03
     +,   2.1734815E-03,   2.4528094E-03,   2.7323579E-03
     +,   2.9996687E-03,   3.2410123E-03,   3.4424704E-03
     +,   3.5911473E-03,   3.6764203E-03,   3.6911245E-03
     +,   3.6323834E-03,   3.5020206E-03,   3.3064836E-03
     +,   3.0562498E-03,   2.7647780E-03,   2.4472177E-03
     +,   2.1190234E-03,   1.7946304E-03,   1.4863551E-03
     +,   1.2037016E-03,   9.5306430E-04,   7.3771575E-04
     +,   5.5818859E-04,   4.1283088E-04,   2.9843065E-04
     +,   2.1084833E-04,   1.4558939E-04,   9.8245662E-05
     +,   6.4791137E-05,   4.1756299E-05,   2.6297777E-05
     +,   1.6184777E-05,   9.7339380E-06,   5.7207803E-06
     +,   3.2854641E-06,   1.8438593E-06,   1.0112083E-06
     +,   5.4190946E-07,   2.8378912E-07,   1.4523087E-07
     +,   7.2628936E-08,   3.5492835E-08,   1.6949864E-08
     +,   7.9104963E-09,   3.6078853E-09,   1.6081169E-09
     +,   7.0054851E-10,   2.9831831E-10,   1.2420333E-10
     +,   5.0581008E-11,   2.0168972E-11,   7.8900159E-12
     +,   3.0409041E-12,   1.1651921E-12,   4.5225981E-13
     +,   1.8419210E-13,   8.3064421E-14,   4.3700219E-14
     +,   2.7110616E-14,   1.9081552E-14,   1.4471654E-14
     +,   1.1401037E-14,   9.1494305E-15,   7.4111359E-15
     +,   6.0342470E-15,   4.9292561E-15,   4.0357143E-15
     +,   3.3095904E-15,   2.7174193E-15,   2.2331786E-15
     +,   1.8363263E-15,   1.5105368E-15,   1.2427532E-15
     +,   1.0224471E-15,   8.4107926E-16,   6.9170277E-16
     +,   5.6865901E-16,   4.6729971E-16,   3.8381900E-16
     +,   3.1507672E-16,   2.5849452E-16,   2.1193908E-16
     +,   1.7365548E-16,   1.4218940E-16,   1.1634425E-16
     +,   9.5128087E-17,   7.7724809E-17,   6.3458636E-17
     +,   5.1772007E-17,   4.2206193E-17,   3.4381517E-17
     +,   2.7986428E-17,   2.2763271E-17,   1.8500874E-17
     +,   1.5024957E-17,   1.2192770E-17,   9.8867671E-18
     +,   8.0107620E-18,   6.4856705E-18,   5.2468968E-18
     +,   4.2414112E-18,   3.4259980E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt100 = Yx/0.0238
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.3384559E-05,   9.8327037E-05
     +,   1.0334927E-04,   1.0843588E-04,   1.1357042E-04
     +,   1.1873555E-04,   1.2391305E-04,   1.2908420E-04
     +,   1.3422962E-04,   1.3932996E-04,   1.4436556E-04
     +,   1.4931697E-04,   1.5416507E-04,   1.5889129E-04
     +,   1.6347796E-04,   1.6790822E-04,   1.7216656E-04
     +,   1.7623873E-04,   1.8011208E-04,   1.8377567E-04
     +,   1.8722031E-04,   1.9043891E-04,   1.9342618E-04
     +,   1.9617917E-04,   1.9869678E-04,   2.0098024E-04
     +,   2.0303269E-04,   2.0485939E-04,   2.0646754E-04
     +,   2.0786611E-04,   2.0906584E-04,   2.1007907E-04
     +,   2.1091949E-04,   2.1160199E-04,   2.1214254E-04
     +,   2.1255795E-04,   2.1286559E-04,   2.1308324E-04
     +,   2.1322892E-04,   2.1332066E-04,   2.1337603E-04
     +,   2.1341231E-04,   2.1344618E-04,   2.1349337E-04
     +,   2.1356861E-04,   2.1368529E-04,   2.1385562E-04
     +,   2.1409003E-04,   2.1439747E-04,   2.1478505E-04
     +,   2.1525777E-04,   2.1581899E-04,   2.1646961E-04
     +,   2.1720893E-04,   2.1803379E-04,   2.1893902E-04
     +,   2.1991771E-04,   2.2096085E-04,   2.2205790E-04
     +,   2.2319661E-04,   2.2436351E-04,   2.2554427E-04
     +,   2.2672345E-04,   2.2788570E-04,   2.2901571E-04
     +,   2.3009832E-04,   2.3111976E-04,   2.3206748E-04
     +,   2.3293091E-04,   2.3370185E-04,   2.3437510E-04
     +,   2.3494854E-04,   2.3542422E-04,   2.3580782E-04
     +,   2.3610958E-04,   2.3634435E-04,   2.3653160E-04
     +,   2.3669540E-04,   2.3686446E-04,   2.3707177E-04
     +,   2.3735427E-04,   2.3775247E-04,   2.3830951E-04
     +,   2.3907097E-04,   2.4008333E-04,   2.4139354E-04
     +,   2.4304767E-04,   2.4509005E-04,   2.4756155E-04
     +,   2.5049888E-04,   2.5393328E-04,   2.5788884E-04
     +,   2.6238163E-04,   2.6741909E-04,   2.7299850E-04
     +,   2.7910576E-04,   2.8571623E-04,   2.9279242E-04
     +,   3.0028573E-04,   3.0813483E-04,   3.1626780E-04
     +,   3.2460081E-04,   3.3304183E-04,   3.4148843E-04
     +,   3.4983340E-04,   3.5796367E-04,   3.6576396E-04
     +,   3.7311847E-04,   3.7991419E-04,   3.8604383E-04
     +,   3.9140740E-04,   3.9591634E-04,   3.9949591E-04
     +,   4.0208755E-04,   4.0365171E-04,   4.0417010E-04
     +,   4.0364702E-04,   4.0211156E-04,   3.9961777E-04
     +,   3.9624603E-04,   3.9210176E-04,   3.8731631E-04
     +,   3.8204438E-04,   3.7646259E-04,   3.7076676E-04
     +,   3.6516972E-04,   3.5989590E-04,   3.5517866E-04
     +,   3.5125494E-04,   3.4836004E-04,   3.4672255E-04
     +,   3.4655820E-04,   3.4806464E-04,   3.5141539E-04
     +,   3.5675464E-04,   3.6419215E-04,   3.7379804E-04
     +,   3.8559915E-04,   3.9957670E-04,   4.1566431E-04
     +,   4.3374501E-04,   4.5365305E-04,   4.7517710E-04
     +,   4.9806212E-04,   5.2201131E-04,   5.4669665E-04
     +,   5.7176396E-04,   5.9683825E-04,   6.2153582E-04
     +,   6.4547424E-04,   6.6828047E-04,   6.8959943E-04
     +,   7.0910488E-04,   7.2650897E-04,   7.4156851E-04
     +,   7.5408933E-04,   7.6393335E-04,   7.7102176E-04
     +,   7.7533425E-04,   7.7690871E-04,   7.7584042E-04
     +,   7.7227462E-04,   7.6640438E-04,   7.5846148E-04
     +,   7.4870908E-04,   7.3743286E-04,   7.2493358E-04
     +,   7.1151747E-04,   6.9748645E-04,   6.8313110E-04
     +,   6.6872418E-04,   6.5451319E-04,   6.4071361E-04
     +,   6.2750740E-04,   6.1503862E-04,   6.0341111E-04
     +,   5.9268915E-04,   5.8289827E-04,   5.7402626E-04
     +,   5.6602631E-04,   5.5882084E-04,   5.5230653E-04
     +,   5.4635887E-04,   5.4083747E-04,   5.3559145E-04
     +,   5.3046626E-04,   5.2530796E-04,   5.1996799E-04
     +,   5.1430782E-04,   5.0820399E-04,   5.0154864E-04
     +,   4.9425371E-04,   4.8625184E-04,   4.7749671E-04
     +,   4.6796276E-04,   4.5764449E-04,   4.4655552E-04
     +,   4.3472680E-04,   4.2220316E-04,   4.0904206E-04
     +,   3.9531136E-04,   3.8108730E-04,   3.6644965E-04
     +,   3.5148169E-04,   3.3626915E-04,   3.2089587E-04
     +,   3.0544365E-04,   2.8999193E-04,   2.7461635E-04
     +,   2.5938667E-04,   2.4436731E-04,   2.2961841E-04
     +,   2.1519436E-04,   2.0114270E-04,   1.8750544E-04
     +,   1.7432001E-04,   1.6161829E-04,   1.4942614E-04
     +,   1.3776439E-04,   1.2665022E-04,   1.1609508E-04
     +,   1.0610602E-04,   9.6686650E-05,   8.7836568E-05
     +,   7.9551093E-05,   7.1822207E-05,   6.4639207E-05
     +,   5.7988524E-05,   5.1853545E-05,   4.6215482E-05
     +,   4.1053991E-05,   3.6347086E-05,   3.2071195E-05
     +,   2.8201861E-05,   2.4714373E-05,   2.1583317E-05
     +,   1.8783303E-05,   1.6289354E-05,   1.4076933E-05
     +,   1.2122028E-05,   1.0401517E-05,   8.8934121E-06
     +,   7.5768307E-06,   6.4320129E-06,   5.4405127E-06
     +,   4.5852667E-06,   3.8505259E-06,   3.2218154E-06
     +,   2.6859666E-06,   2.2311162E-06,   1.8465471E-06
     +,   1.5226839E-06,   1.2510383E-06,   1.0241024E-06
     +,   8.3526226E-07,   6.7874066E-07,   5.4952483E-07
     +,   4.4327513E-07,   3.5625169E-07,   2.8525443E-07
     +,   2.2756240E-07,   1.8086799E-07,   1.4322224E-07
     +,   1.1299016E-07,   8.8808775E-08,   6.9542502E-08
     +,   5.4252201E-08,   4.2165539E-08,   3.2649091E-08
     +,   2.5185569E-08,   1.9354957E-08,   1.4818116E-08
     +,   1.1301966E-08,   8.5875476E-09,   6.5002483E-09
     +,   4.9016400E-09,   3.6820647E-09,   2.7554012E-09
     +,   2.0540425E-09,   1.5253527E-09,   1.1283797E-09
     +,   8.3151186E-10,   6.1037808E-10,   4.4632387E-10
     +,   3.2509503E-10,   2.3587671E-10,   1.7047681E-10
     +,   1.2272788E-10,   8.8008503E-11,   6.2863131E-11
     +,   4.4726420E-11,   3.1696753E-11,   2.2374581E-11
     +,   1.5731515E-11,   1.1017140E-11,   7.6848666E-12
     +,   5.3392408E-12,   3.6947468E-12,   2.5465953E-12
     +,   1.7481985E-12,   1.1953226E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt105 = Yx/0.0185862068965517
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.4472282E-05,   8.6772510E-05
     +,   8.9045512E-05,   9.1287213E-05,   9.3493778E-05
     +,   9.5661555E-05,   9.7787168E-05,   9.9867546E-05
     +,   1.0189992E-04,   1.0388203E-04,   1.0581189E-04
     +,   1.0768803E-04,   1.0950950E-04,   1.1127579E-04
     +,   1.1298703E-04,   1.1464386E-04,   1.1624756E-04
     +,   1.1779997E-04,   1.1930356E-04,   1.2076144E-04
     +,   1.2217728E-04,   1.2355534E-04,   1.2490040E-04
     +,   1.2621784E-04,   1.2751331E-04,   1.2879302E-04
     +,   1.3006345E-04,   1.3133117E-04,   1.3260299E-04
     +,   1.3388568E-04,   1.3518594E-04,   1.3651019E-04
     +,   1.3786452E-04,   1.3925452E-04,   1.4068522E-04
     +,   1.4216085E-04,   1.4368494E-04,   1.4526003E-04
     +,   1.4688777E-04,   1.4856864E-04,   1.5030235E-04
     +,   1.5208741E-04,   1.5392150E-04,   1.5580138E-04
     +,   1.5772310E-04,   1.5968230E-04,   1.6167414E-04
     +,   1.6369372E-04,   1.6573645E-04,   1.6779813E-04
     +,   1.6987538E-04,   1.7196601E-04,   1.7406914E-04
     +,   1.7618595E-04,   1.7831930E-04,   1.8047464E-04
     +,   1.8265973E-04,   1.8488502E-04,   1.8716347E-04
     +,   1.8951077E-04,   1.9194516E-04,   1.9448707E-04
     +,   1.9715888E-04,   1.9998450E-04,   2.0298909E-04
     +,   2.0619800E-04,   2.0963659E-04,   2.1332908E-04
     +,   2.1729837E-04,   2.2156449E-04,   2.2614472E-04
     +,   2.3105185E-04,   2.3629464E-04,   2.4187592E-04
     +,   2.4779321E-04,   2.5403791E-04,   2.6059448E-04
     +,   2.6744069E-04,   2.7454828E-04,   2.8188236E-04
     +,   2.8940159E-04,   2.9705974E-04,   3.0480488E-04
     +,   3.1258192E-04,   3.2033169E-04,   3.2799391E-04
     +,   3.3550634E-04,   3.4280776E-04,   3.4983770E-04
     +,   3.5653886E-04,   3.6285765E-04,   3.6874498E-04
     +,   3.7415780E-04,   3.7906010E-04,   3.8342347E-04
     +,   3.8722693E-04,   3.9045876E-04,   3.9311530E-04
     +,   3.9520202E-04,   3.9673244E-04,   3.9772809E-04
     +,   3.9821834E-04,   3.9823866E-04,   3.9783053E-04
     +,   3.9704033E-04,   3.9591800E-04,   3.9451604E-04
     +,   3.9288896E-04,   3.9109139E-04,   3.8917773E-04
     +,   3.8720158E-04,   3.8521396E-04,   3.8326409E-04
     +,   3.8139775E-04,   3.7965810E-04,   3.7808434E-04
     +,   3.7671265E-04,   3.7557527E-04,   3.7470122E-04
     +,   3.7411597E-04,   3.7384138E-04,   3.7389575E-04
     +,   3.7429357E-04,   3.7504523E-04,   3.7615711E-04
     +,   3.7763061E-04,   3.7946244E-04,   3.8164336E-04
     +,   3.8415863E-04,   3.8698677E-04,   3.9010023E-04
     +,   3.9346470E-04,   3.9703902E-04,   4.0077575E-04
     +,   4.0462165E-04,   4.0851792E-04,   4.1240134E-04
     +,   4.1620532E-04,   4.1986071E-04,   4.2329793E-04
     +,   4.2644725E-04,   4.2924104E-04,   4.3161528E-04
     +,   4.3351049E-04,   4.3487354E-04,   4.3565899E-04
     +,   4.3582974E-04,   4.3535896E-04,   4.3423095E-04
     +,   4.3244084E-04,   4.2999716E-04,   4.2692060E-04
     +,   4.2324589E-04,   4.1902091E-04,   4.1430703E-04
     +,   4.0917922E-04,   4.0372496E-04,   3.9804410E-04
     +,   3.9224667E-04,   3.8645306E-04,   3.8079073E-04
     +,   3.7539235E-04,   3.7039429E-04,   3.6593262E-04
     +,   3.6214033E-04,   3.5914383E-04,   3.5705994E-04
     +,   3.5599218E-04,   3.5602684E-04,   3.5723043E-04
     +,   3.5964660E-04,   3.6329322E-04,   3.6816116E-04
     +,   3.7421286E-04,   3.8138116E-04,   3.8957092E-04
     +,   3.9865912E-04,   4.0849688E-04,   4.1891215E-04
     +,   4.2971401E-04,   4.4069620E-04,   4.5164058E-04
     +,   4.6232282E-04,   4.7251891E-04,   4.8200795E-04
     +,   4.9057807E-04,   4.9803080E-04,   5.0418655E-04
     +,   5.0888758E-04,   5.1200017E-04,   5.1341834E-04
     +,   5.1306549E-04,   5.1089411E-04,   5.0688756E-04
     +,   5.0105777E-04,   4.9344514E-04,   4.8411635E-04
     +,   4.7316222E-04,   4.6069411E-04,   4.4684095E-04
     +,   4.3174720E-04,   4.1556897E-04,   3.9846910E-04
     +,   3.8061495E-04,   3.6217674E-04,   3.4332188E-04
     +,   3.2421309E-04,   3.0500820E-04,   2.8585616E-04
     +,   2.6689449E-04,   2.4824907E-04,   2.3003457E-04
     +,   2.1235197E-04,   1.9528776E-04,   1.7891458E-04
     +,   1.6329250E-04,   1.4846836E-04,   1.3447534E-04
     +,   1.2133479E-04,   1.0905819E-04,   9.7645687E-05
     +,   8.7088411E-05,   7.7370125E-05,   6.8467547E-05
     +,   6.0350954E-05,   5.2985848E-05,   4.6334451E-05
     +,   4.0356044E-05,   3.5007524E-05,   3.0244764E-05
     +,   2.6023556E-05,   2.2299902E-05,   1.9030344E-05
     +,   1.6172802E-05,   1.3687172E-05,   1.1535060E-05
     +,   9.6803669E-06,   8.0895152E-06,   6.7314040E-06
     +,   5.5773780E-06,   4.6013406E-06,   3.7797502E-06
     +,   3.0914430E-06,   2.5174945E-06,   2.0411478E-06
     +,   1.6476885E-06,   1.3242408E-06,   1.0595966E-06
     +,   8.4408572E-07,   6.6943045E-07,   5.2855336E-07
     +,   4.1545866E-07,   3.2510286E-07,   2.5325997E-07
     +,   1.9640706E-07,   1.5162976E-07,   1.1653284E-07
     +,   8.9155549E-08,   6.7901183E-08,   5.1478782E-08
     +,   3.8850906E-08,   2.9187527E-08,   2.1827784E-08
     +,   1.6249178E-08,   1.2041162E-08,   8.8820631E-09
     +,   6.5216996E-09,   4.7666333E-09,   3.4679168E-09
     +,   2.5114577E-09,   1.8104067E-09,   1.2990390E-09
     +,   9.2782870E-10,   6.5963868E-10,   4.6679988E-10
     +,   3.2881392E-10,   2.3054360E-10,   1.6089705E-10
     +,   1.1176962E-10,   7.7283971E-11,   5.3190414E-11
     +,   3.6438911E-11,   2.4846953E-11,   1.6864251E-11
     +,   1.1392914E-11,   7.6610246E-12,   5.1276301E-12
     +,   3.4159980E-12,   2.2651668E-12,   1.4950392E-12
     +,   9.8216715E-13,   6.4222450E-13,   4.1799081E-13
     +,   2.7077749E-13,   1.7459723E-13,   1.1205387E-13
     +,   7.1580308E-14,   4.5511805E-14,   2.8802505E-14
     +,   1.8142582E-14,   1.1374798E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt107 = Yx/0.0160740740740741
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.1198068E-05,   7.2742492E-05
     +,   7.4248303E-05,   7.5712502E-05,   7.7132543E-05
     +,   7.8506375E-05,   7.9832607E-05,   8.1110520E-05
     +,   8.2340295E-05,   8.3523119E-05,   8.4661136E-05
     +,   8.5757740E-05,   8.6817621E-05,   8.7846878E-05
     +,   8.8853056E-05,   8.9845315E-05,   9.0834445E-05
     +,   9.1832917E-05,   9.2854978E-05,   9.3916562E-05
     +,   9.5035415E-05,   9.6230870E-05,   9.7523996E-05
     +,   9.8937409E-05,   1.0049504E-04,   1.0222224E-04
     +,   1.0414546E-04,   1.0629193E-04,   1.0868967E-04
     +,   1.1136696E-04,   1.1435227E-04,   1.1767370E-04
     +,   1.2135877E-04,   1.2543396E-04,   1.2992421E-04
     +,   1.3485254E-04,   1.4023947E-04,   1.4610235E-04
     +,   1.5245544E-04,   1.5930807E-04,   1.6666563E-04
     +,   1.7452751E-04,   1.8288750E-04,   1.9173278E-04
     +,   2.0104360E-04,   2.1079266E-04,   2.2094484E-04
     +,   2.3145709E-04,   2.4227823E-04,   2.5334887E-04
     +,   2.6460181E-04,   2.7596275E-04,   2.8735024E-04
     +,   2.9867812E-04,   3.0985390E-04,   3.2078361E-04
     +,   3.3137057E-04,   3.4151852E-04,   3.5113332E-04
     +,   3.6012469E-04,   3.6840842E-04,   3.7590848E-04
     +,   3.8255882E-04,   3.8830552E-04,   3.9310806E-04
     +,   3.9694051E-04,   3.9979300E-04,   4.0167200E-04
     +,   4.0260068E-04,   4.0261826E-04,   4.0177978E-04
     +,   4.0015491E-04,   3.9782570E-04,   3.9488563E-04
     +,   3.9143671E-04,   3.8758657E-04,   3.8344666E-04
     +,   3.7912885E-04,   3.7474264E-04,   3.7039194E-04
     +,   3.6617389E-04,   3.6217491E-04,   3.5846958E-04
     +,   3.5511886E-04,   3.5216883E-04,   3.4964978E-04
     +,   3.4757642E-04,   3.4594742E-04,   3.4474651E-04
     +,   3.4394328E-04,   3.4349516E-04,   3.4334834E-04
     +,   3.4344030E-04,   3.4370189E-04,   3.4405966E-04
     +,   3.4443798E-04,   3.4476173E-04,   3.4495778E-04
     +,   3.4495752E-04,   3.4469858E-04,   3.4412599E-04
     +,   3.4319385E-04,   3.4186570E-04,   3.4011586E-04
     +,   3.3792877E-04,   3.3529973E-04,   3.3223434E-04
     +,   3.2874823E-04,   3.2486577E-04,   3.2062002E-04
     +,   3.1605136E-04,   3.1120633E-04,   3.0613737E-04
     +,   3.0090057E-04,   2.9555627E-04,   2.9016618E-04
     +,   2.8479483E-04,   2.7950667E-04,   2.7436696E-04
     +,   2.6944026E-04,   2.6479000E-04,   2.6047850E-04
     +,   2.5656633E-04,   2.5311121E-04,   2.5016820E-04
     +,   2.4778966E-04,   2.4602376E-04,   2.4491493E-04
     +,   2.4450282E-04,   2.4482224E-04,   2.4590251E-04
     +,   2.4776661E-04,   2.5043156E-04,   2.5390679E-04
     +,   2.5819507E-04,   2.6329103E-04,   2.6918092E-04
     +,   2.7584255E-04,   2.8324558E-04,   2.9135059E-04
     +,   3.0010889E-04,   3.0946257E-04,   3.1934556E-04
     +,   3.2968319E-04,   3.4039165E-04,   3.5138038E-04
     +,   3.6255256E-04,   3.7380451E-04,   3.8502846E-04
     +,   3.9611448E-04,   4.0695205E-04,   4.1743074E-04
     +,   4.2744429E-04,   4.3689267E-04,   4.4568468E-04
     +,   4.5373960E-04,   4.6099015E-04,   4.6738505E-04
     +,   4.7289082E-04,   4.7749159E-04,   4.8119170E-04
     +,   4.8401460E-04,   4.8600245E-04,   4.8721448E-04
     +,   4.8772545E-04,   4.8762161E-04,   4.8699873E-04
     +,   4.8595711E-04,   4.8459749E-04,   4.8301750E-04
     +,   4.8130660E-04,   4.7954288E-04,   4.7778877E-04
     +,   4.7608916E-04,   4.7446889E-04,   4.7293134E-04
     +,   4.7145871E-04,   4.7001275E-04,   4.6853622E-04
     +,   4.6695524E-04,   4.6518250E-04,   4.6312183E-04
     +,   4.6067106E-04,   4.5772729E-04,   4.5419033E-04
     +,   4.4996801E-04,   4.4497874E-04,   4.3915518E-04
     +,   4.3244631E-04,   4.2482096E-04,   4.1626632E-04
     +,   4.0678983E-04,   3.9641897E-04,   3.8519953E-04
     +,   3.7319370E-04,   3.6047760E-04,   3.4714077E-04
     +,   3.3328158E-04,   3.1900386E-04,   3.0441515E-04
     +,   2.8962453E-04,   2.7473929E-04,   2.5986167E-04
     +,   2.4508813E-04,   2.3050891E-04,   2.1620422E-04
     +,   2.0224488E-04,   1.8869273E-04,   1.7559966E-04
     +,   1.6300681E-04,   1.5094613E-04,   1.3944153E-04
     +,   1.2850876E-04,   1.1815569E-04,   1.0838386E-04
     +,   9.9189965E-05,   9.0566064E-05,   8.2499719E-05
     +,   7.4975505E-05,   6.7976289E-05,   6.1482308E-05
     +,   5.5472541E-05,   4.9925424E-05,   4.4818738E-05
     +,   4.0129657E-05,   3.5835299E-05,   3.1913205E-05
     +,   2.8341150E-05,   2.5097001E-05,   2.2159165E-05
     +,   1.9506795E-05,   1.7119595E-05,   1.4977782E-05
     +,   1.3062325E-05,   1.1355104E-05,   9.8386163E-06
     +,   8.4961966E-06,   7.3121273E-06,   6.2715371E-06
     +,   5.3603662E-06,   4.5654715E-06,   3.8746621E-06
     +,   3.2766231E-06,   2.7608801E-06,   2.3178316E-06
     +,   1.9387433E-06,   1.6156779E-06,   1.3414459E-06
     +,   1.1095919E-06,   9.1437249E-07,   7.5065765E-07
     +,   6.1391790E-07,   5.0017803E-07,   4.0595884E-07
     +,   3.2822726E-07,   2.6435916E-07,   2.1209959E-07
     +,   1.6951583E-07,   1.3495809E-07,   1.0702832E-07
     +,   8.4549313E-08,   6.6532415E-08,   5.2150948E-08
     +,   4.0718419E-08,   3.1668247E-08,   2.4533273E-08
     +,   1.8931289E-08,   1.4551221E-08,   1.1140762E-08
     +,   8.4961345E-09,   6.4537686E-09,   4.8830704E-09
     +,   3.6801258E-09,   2.7625950E-09,   2.0656243E-09
     +,   1.5384082E-09,   1.1412172E-09,   8.4323526E-10
     +,   6.2058786E-10,   4.5492501E-10,   3.3216049E-10
     +,   2.4156588E-10,   1.7498177E-10,   1.2624904E-10
     +,   9.0725802E-11,   6.4939581E-11,   4.6297608E-11
     +,   3.2875508E-11,   2.3251973E-11,   1.6379863E-11
     +,   1.1492982E-11,   8.0318642E-12,   5.5907640E-12
     +,   3.8760171E-12,   2.6765111E-12,   1.8408198E-12
     +,   1.2610189E-12,   8.6037601E-13,   5.8468622E-13
     +,   3.9574287E-13,   2.6678955E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt110 = Yx/0.0155555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0321854E-05,   1.0833848E-05
     +,   1.1354988E-05,   1.1884628E-05,   1.2422193E-05
     +,   1.2967203E-05,   1.3519320E-05,   1.4078376E-05
     +,   1.4644420E-05,   1.5217791E-05,   1.5799118E-05
     +,   1.6389418E-05,   1.6990136E-05,   1.7603204E-05
     +,   1.8231098E-05,   1.8876908E-05,   1.9544386E-05
     +,   2.0238011E-05,   2.0963020E-05,   2.1725467E-05
     +,   2.2532260E-05,   2.3391169E-05,   2.4310821E-05
     +,   2.5300800E-05,   2.6371410E-05,   2.7533892E-05
     +,   2.8800148E-05,   3.0182751E-05,   3.1694817E-05
     +,   3.3349861E-05,   3.5161615E-05,   3.7143869E-05
     +,   3.9310216E-05,   4.1673873E-05,   4.4247336E-05
     +,   4.7042216E-05,   5.0068855E-05,   5.3336058E-05
     +,   5.6851040E-05,   6.0618575E-05,   6.4641477E-05
     +,   6.8919806E-05,   7.3450879E-05,   7.8229124E-05
     +,   8.3245926E-05,   8.8489585E-05,   9.3945353E-05
     +,   9.9595469E-05,   1.0541934E-04,   1.1139375E-04
     +,   1.1749315E-04,   1.2369001E-04,   1.2995517E-04
     +,   1.3625872E-04,   1.4256952E-04,   1.4885703E-04
     +,   1.5509086E-04,   1.6124173E-04,   1.6728193E-04
     +,   1.7318582E-04,   1.7893022E-04,   1.8449494E-04
     +,   1.8986248E-04,   1.9501930E-04,   1.9995506E-04
     +,   2.0466255E-04,   2.0913851E-04,   2.1338218E-04
     +,   2.1739637E-04,   2.2118591E-04,   2.2475835E-04
     +,   2.2812255E-04,   2.3128920E-04,   2.3426955E-04
     +,   2.3707571E-04,   2.3971996E-04,   2.4221436E-04
     +,   2.4457052E-04,   2.4679978E-04,   2.4891284E-04
     +,   2.5091937E-04,   2.5282870E-04,   2.5464909E-04
     +,   2.5638848E-04,   2.5805383E-04,   2.5965186E-04
     +,   2.6118846E-04,   2.6266908E-04,   2.6409846E-04
     +,   2.6548048E-04,   2.6681821E-04,   2.6811342E-04
     +,   2.6936628E-04,   2.7057540E-04,   2.7173728E-04
     +,   2.7284608E-04,   2.7389335E-04,   2.7486775E-04
     +,   2.7575518E-04,   2.7653846E-04,   2.7719772E-04
     +,   2.7770991E-04,   2.7805020E-04,   2.7819135E-04
     +,   2.7810491E-04,   2.7776134E-04,   2.7713116E-04
     +,   2.7618575E-04,   2.7489755E-04,   2.7324122E-04
     +,   2.7119499E-04,   2.6874026E-04,   2.6586317E-04
     +,   2.6255476E-04,   2.5881166E-04,   2.5463596E-04
     +,   2.5003616E-04,   2.4502614E-04,   2.3962637E-04
     +,   2.3386243E-04,   2.2776511E-04,   2.2137031E-04
     +,   2.1471822E-04,   2.0785199E-04,   2.0081757E-04
     +,   1.9366358E-04,   1.8643902E-04,   1.7919404E-04
     +,   1.7197788E-04,   1.6483948E-04,   1.5782524E-04
     +,   1.5098047E-04,   1.4434686E-04,   1.3796390E-04
     +,   1.3186723E-04,   1.2608894E-04,   1.2065803E-04
     +,   1.1559978E-04,   1.1093575E-04,   1.0668405E-04
     +,   1.0285994E-04,   9.9475859E-05,   9.6541327E-05
     +,   9.4063616E-05,   9.2048438E-05,   9.0499554E-05
     +,   8.9419576E-05,   8.8810280E-05,   8.8672663E-05
     +,   8.9007372E-05,   8.9814836E-05,   9.1095346E-05
     +,   9.2849179E-05,   9.5076692E-05,   9.7778211E-05
     +,   1.0095382E-04,   1.0460310E-04,   1.0872522E-04
     +,   1.1331844E-04,   1.1837923E-04,   1.2390268E-04
     +,   1.2988158E-04,   1.3630564E-04,   1.4316104E-04
     +,   1.5043058E-04,   1.5809271E-04,   1.6612037E-04
     +,   1.7448109E-04,   1.8313724E-04,   1.9204515E-04
     +,   2.0115435E-04,   2.1040809E-04,   2.1974408E-04
     +,   2.2909397E-04,   2.3838309E-04,   2.4753279E-04
     +,   2.5646022E-04,   2.6507862E-04,   2.7329923E-04
     +,   2.8103299E-04,   2.8819122E-04,   2.9468667E-04
     +,   3.0043561E-04,   3.0535989E-04,   3.0938757E-04
     +,   3.1245462E-04,   3.1450653E-04,   3.1549946E-04
     +,   3.1540144E-04,   3.1419293E-04,   3.1186757E-04
     +,   3.0843256E-04,   3.0390883E-04,   2.9833088E-04
     +,   2.9174576E-04,   2.8421238E-04,   2.7580140E-04
     +,   2.6659324E-04,   2.5667620E-04,   2.4614503E-04
     +,   2.3510028E-04,   2.2364565E-04,   2.1188559E-04
     +,   1.9992396E-04,   1.8786381E-04,   1.7580319E-04
     +,   1.6383505E-04,   1.5204673E-04,   1.4051810E-04
     +,   1.2931993E-04,   1.1851409E-04,   1.0815395E-04
     +,   9.8283315E-05,   8.8935936E-05,   8.0136466E-05
     +,   7.1901362E-05,   6.4238775E-05,   5.7148827E-05
     +,   5.0624865E-05,   4.4654917E-05,   3.9221199E-05
     +,   3.4301745E-05,   2.9871488E-05,   2.5902697E-05
     +,   2.2365508E-05,   1.9228997E-05,   1.6461956E-05
     +,   1.4033189E-05,   1.1911883E-05,   1.0068215E-05
     +,   8.4737630E-06,   7.1015993E-06,   5.9264030E-06
     +,   4.9247110E-06,   4.0750415E-06,   3.3577189E-06
     +,   2.7549713E-06,   2.2508941E-06,   1.8313171E-06
     +,   1.4836854E-06,   1.1969860E-06,   9.6163524E-07
     +,   7.6932781E-07,   6.1290234E-07,   4.8623764E-07
     +,   3.8413924E-07,   3.0221577E-07,   2.3677332E-07
     +,   1.8472831E-07,   1.4352536E-07,   1.1104937E-07
     +,   8.5564551E-08,   6.5654895E-08,   5.0169589E-08
     +,   3.8177909E-08,   2.8932034E-08,   2.1834607E-08
     +,   1.6410302E-08,   1.2282572E-08,   9.1550225E-09
     +,   6.7956600E-09,   5.0235438E-09,   3.6982031E-09
     +,   2.7112455E-09,   1.9794888E-09,   1.4392577E-09
     +,   1.0421242E-09,   7.5144962E-10,   5.3961435E-10
     +,   3.8589087E-10,   2.7481245E-10,   1.9489600E-10
     +,   1.3764720E-10,   9.6810601E-11,   6.7805206E-11
     +,   4.7292923E-11,   3.2847974E-11,   2.2720093E-11
     +,   1.5649024E-11,   1.0733661E-11,   7.3312805E-12
     +,   4.9864409E-12,   3.3772800E-12,   2.2778114E-12
     +,   1.5297755E-12,   1.0230736E-12,   6.8131346E-13
     +,   4.5179201E-13,   2.9832506E-13,   1.9614959E-13
     +,   1.2842232E-13,   8.3720723E-14,   5.4346945E-14
     +,   3.5127873E-14,   2.2608505E-14,   1.4488400E-14
     +,   9.2450334E-15,   5.8737966E-15,   3.7158806E-15
     +,   2.3405737E-15,   1.4679456E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt115 = Yx/0.00852173913043478
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.1164407E-05,   5.3043015E-05
     +,   5.4931657E-05,   5.6825811E-05,   5.8720758E-05
     +,   6.0611750E-05,   6.2494000E-05,   6.4362750E-05
     +,   6.6213353E-05,   6.8041409E-05,   6.9842747E-05
     +,   7.1613591E-05,   7.3350653E-05,   7.5051197E-05
     +,   7.6713171E-05,   7.8335324E-05,   7.9917256E-05
     +,   8.1459526E-05,   8.2963823E-05,   8.4432846E-05
     +,   8.5870626E-05,   8.7282366E-05,   8.8674562E-05
     +,   9.0055109E-05,   9.1433008E-05,   9.2818700E-05
     +,   9.4223760E-05,   9.5660864E-05,   9.7143704E-05
     +,   9.8686876E-05,   1.0030559E-04,   1.0201557E-04
     +,   1.0383284E-04,   1.0577339E-04,   1.0785296E-04
     +,   1.1008677E-04,   1.1248914E-04,   1.1507316E-04
     +,   1.1785076E-04,   1.2083168E-04,   1.2402395E-04
     +,   1.2743307E-04,   1.3106207E-04,   1.3491120E-04
     +,   1.3897772E-04,   1.4325597E-04,   1.4773707E-04
     +,   1.5240909E-04,   1.5725718E-04,   1.6226342E-04
     +,   1.6740737E-04,   1.7266606E-04,   1.7801445E-04
     +,   1.8342605E-04,   1.8887244E-04,   1.9432527E-04
     +,   1.9975529E-04,   2.0513385E-04,   2.1043276E-04
     +,   2.1562545E-04,   2.2068701E-04,   2.2559494E-04
     +,   2.3032915E-04,   2.3487309E-04,   2.3921339E-04
     +,   2.4334001E-04,   2.4724705E-04,   2.5093192E-04
     +,   2.5439615E-04,   2.5764431E-04,   2.6068478E-04
     +,   2.6352846E-04,   2.6618913E-04,   2.6868263E-04
     +,   2.7102642E-04,   2.7323922E-04,   2.7534011E-04
     +,   2.7734812E-04,   2.7928216E-04,   2.8115982E-04
     +,   2.8299712E-04,   2.8480811E-04,   2.8660445E-04
     +,   2.8839515E-04,   2.9018597E-04,   2.9197952E-04
     +,   2.9377508E-04,   2.9556829E-04,   2.9735110E-04
     +,   2.9911209E-04,   3.0083657E-04,   3.0250603E-04
     +,   3.0409920E-04,   3.0559200E-04,   3.0695769E-04
     +,   3.0816713E-04,   3.0918993E-04,   3.0999395E-04
     +,   3.1054651E-04,   3.1081456E-04,   3.1076552E-04
     +,   3.1036770E-04,   3.0959101E-04,   3.0840794E-04
     +,   3.0679346E-04,   3.0472627E-04,   3.0218923E-04
     +,   2.9916997E-04,   2.9566101E-04,   2.9166028E-04
     +,   2.8717195E-04,   2.8220558E-04,   2.7677728E-04
     +,   2.7090855E-04,   2.6462710E-04,   2.5796535E-04
     +,   2.5096143E-04,   2.4365698E-04,   2.3609810E-04
     +,   2.2833320E-04,   2.2041293E-04,   2.1238951E-04
     +,   2.0431582E-04,   1.9624372E-04,   1.8822389E-04
     +,   1.8030606E-04,   1.7253608E-04,   1.6495788E-04
     +,   1.5761062E-04,   1.5053044E-04,   1.4374832E-04
     +,   1.3729172E-04,   1.3118282E-04,   1.2544027E-04
     +,   1.2007801E-04,   1.1510603E-04,   1.1053118E-04
     +,   1.0635698E-04,   1.0258401E-04,   9.9210534E-05
     +,   9.6233140E-05,   9.3647090E-05,   9.1446280E-05
     +,   8.9624227E-05,   8.8174311E-05,   8.7089749E-05
     +,   8.6364162E-05,   8.5991662E-05,   8.5966960E-05
     +,   8.6285421E-05,   8.6943073E-05,   8.7936591E-05
     +,   8.9263041E-05,   9.0919959E-05,   9.2905044E-05
     +,   9.5215823E-05,   9.7849406E-05,   1.0080240E-04
     +,   1.0407060E-04,   1.0764827E-04,   1.1152840E-04
     +,   1.1570226E-04,   1.2015882E-04,   1.2488480E-04
     +,   1.2986459E-04,   1.3508016E-04,   1.4051011E-04
     +,   1.4613043E-04,   1.5191456E-04,   1.5783303E-04
     +,   1.6385349E-04,   1.6994085E-04,   1.7605811E-04
     +,   1.8216632E-04,   1.8822408E-04,   1.9418915E-04
     +,   2.0001861E-04,   2.0566826E-04,   2.1109416E-04
     +,   2.1625313E-04,   2.2110298E-04,   2.2560265E-04
     +,   2.2971306E-04,   2.3339804E-04,   2.3662436E-04
     +,   2.3936186E-04,   2.4158428E-04,   2.4326961E-04
     +,   2.4440026E-04,   2.4496304E-04,   2.4494983E-04
     +,   2.4435704E-04,   2.4318622E-04,   2.4144369E-04
     +,   2.3914030E-04,   2.3629141E-04,   2.3291681E-04
     +,   2.2904028E-04,   2.2468889E-04,   2.1989302E-04
     +,   2.1468598E-04,   2.0910356E-04,   2.0318308E-04
     +,   1.9696320E-04,   1.9048418E-04,   1.8378609E-04
     +,   1.7690916E-04,   1.6989360E-04,   1.6277887E-04
     +,   1.5560293E-04,   1.4840215E-04,   1.4121179E-04
     +,   1.3406503E-04,   1.2699245E-04,   1.2002228E-04
     +,   1.1318071E-04,   1.0649144E-04,   9.9975085E-05
     +,   9.3649673E-05,   8.7531320E-05,   8.1632919E-05
     +,   7.5964985E-05,   7.0536036E-05,   6.5352346E-05
     +,   6.0417689E-05,   5.5733944E-05,   5.1301475E-05
     +,   4.7118974E-05,   4.3183343E-05,   3.9490184E-05
     +,   3.6034191E-05,   3.2808995E-05,   2.9807146E-05
     +,   2.7020515E-05,   2.4440646E-05,   2.2058364E-05
     +,   1.9864181E-05,   1.7848537E-05,   1.6001728E-05
     +,   1.4313896E-05,   1.2775254E-05,   1.1376243E-05
     +,   1.0107478E-05,   8.9597288E-06,   7.9240690E-06
     +,   6.9919670E-06,   6.1552387E-06,   5.4060220E-06
     +,   4.7368630E-06,   4.1407816E-06,   3.6111453E-06
     +,   3.1417489E-06,   2.7268322E-06,   2.3610360E-06
     +,   2.0393732E-06,   1.7572498E-06,   1.5104628E-06
     +,   1.2951592E-06,   1.1078124E-06,   9.4521823E-07
     +,   8.0448541E-07,   6.8300244E-07,   5.7841260E-07
     +,   4.8860500E-07,   4.1170222E-07,   3.4602488E-07
     +,   2.9008413E-07,   2.4256684E-07,   2.0231548E-07
     +,   1.6831021E-07,   1.3965931E-07,   1.1558628E-07
     +,   9.5415636E-08,   7.8560475E-08,   6.4513955E-08
     +,   5.2841049E-08,   4.3166743E-08,   3.5171425E-08
     +,   2.8581516E-08,   2.3165349E-08,   1.8725869E-08
     +,   1.5097299E-08,   1.2139533E-08,   9.7354151E-09
     +,   7.7866114E-09,   6.2113878E-09,   4.9416262E-09
     +,   3.9209151E-09,   3.1027423E-09,   2.4487083E-09
     +,   1.9273745E-09,   1.5129517E-09,   1.1844560E-09
     +,   9.2478275E-10,   7.2010081E-10,   5.5920518E-10
     +,   4.3309087E-10,   3.3450986E-10,   2.5767144E-10
     +,   1.9794449E-10,   1.5165139E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt120 = Yx/0.009625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7359097E-04,   2.9545114E-04
     +,   3.1966707E-04,   3.4666527E-04,   3.7693174E-04
     +,   4.1099495E-04,   4.4940325E-04,   4.9270020E-04
     +,   5.4140773E-04,   5.9603859E-04,   6.5714365E-04
     +,   7.2543783E-04,   8.0201868E-04,   8.8870508E-04
     +,   9.8851044E-04,   1.1062212E-03,   1.2489712E-03
     +,   1.4266021E-03,   1.6515993E-03,   1.9386597E-03
     +,   2.3044874E-03,   2.7684844E-03,   3.3533466E-03
     +,   4.0814672E-03,   4.9621323E-03,   5.9736324E-03
     +,   7.0606084E-03,   8.1792772E-03,   9.3966052E-03
     +,   1.0967338E-02,   1.3236206E-02,   1.6325774E-02
     +,   1.9904967E-02,   2.3375094E-02,   2.6312085E-02
     +,   2.9004712E-02,   3.2880269E-02,   3.8967222E-02
     +,   4.5496352E-02,   5.0896253E-02,   5.6040153E-02
     +,   5.9734840E-02,   5.9956856E-02,   5.7629932E-02
     +,   5.3945135E-02,   4.8703879E-02,   4.2501014E-02
     +,   3.7187170E-02,   3.3330750E-02,   3.0310879E-02
     +,   2.7710410E-02,   2.5373749E-02,   2.2964705E-02
     +,   2.0472135E-02,   1.8121110E-02,   1.5940690E-02
     +,   1.3944154E-02,   1.2217001E-02,   1.0756899E-02
     +,   9.4680954E-03,   8.2699964E-03,   7.1457513E-03
     +,   6.1250892E-03,   5.2488646E-03,   4.5397589E-03
     +,   3.9906986E-03,   3.5727720E-03,   3.2522904E-03
     +,   3.0028317E-03,   2.8075804E-03,   2.6552489E-03
     +,   2.5356088E-03,   2.4375555E-03,   2.3497257E-03
     +,   2.2621052E-03,   2.1674859E-03,   2.0621971E-03
     +,   1.9460635E-03,   1.8217382E-03,   1.6936681E-03
     +,   1.5669455E-03,   1.4462172E-03,   1.3349627E-03
     +,   1.2350788E-03,   1.1469009E-03,   1.0694488E-03
     +,   1.0008737E-03,   9.3890773E-04,   8.8129315E-04
     +,   8.2607940E-04,   7.7181810E-04,   7.1763870E-04
     +,   6.6322758E-04,   6.0873909E-04,   5.5467745E-04
     +,   5.0176698E-04,   4.5080876E-04,   4.0258162E-04
     +,   3.5774516E-04,   3.1679575E-04,   2.8002899E-04
     +,   2.4754961E-04,   2.1928039E-04,   1.9500233E-04
     +,   1.7438625E-04,   1.5703567E-04,   1.4252344E-04
     +,   1.3042074E-04,   1.2031975E-04,   1.1185026E-04
     +,   1.0468915E-04,   9.8561883E-05,   9.3243485E-05
     +,   8.8553199E-05,   8.4350475E-05,   8.0527760E-05
     +,   7.7005388E-05,   7.3725168E-05,   7.0646187E-05
     +,   6.7740075E-05,   6.4987922E-05,   6.2377774E-05
     +,   5.9902362E-05,   5.7557456E-05,   5.5340806E-05
     +,   5.3251533E-05,   5.1288986E-05,   4.9452778E-05
     +,   4.7742044E-05,   4.6155641E-05,   4.4691566E-05
     +,   4.3347249E-05,   4.2119165E-05,   4.1003183E-05
     +,   3.9994244E-05,   3.9086590E-05,   3.8273840E-05
     +,   3.7549016E-05,   3.6904570E-05,   3.6332574E-05
     +,   3.5824814E-05,   3.5372868E-05,   3.4968176E-05
     +,   3.4602210E-05,   3.4266555E-05,   3.3952994E-05
     +,   3.3653581E-05,   3.3360779E-05,   3.3067485E-05
     +,   3.2767097E-05,   3.2453583E-05,   3.2121552E-05
     +,   3.1766242E-05,   3.1383559E-05,   3.0970084E-05
     +,   3.0523130E-05,   3.0040688E-05,   2.9521409E-05
     +,   2.8964589E-05,   2.8370205E-05,   2.7738781E-05
     +,   2.7071388E-05,   2.6369649E-05,   2.5635647E-05
     +,   2.4871837E-05,   2.4081010E-05,   2.3266319E-05
     +,   2.2431153E-05,   2.1579035E-05,   2.0713618E-05
     +,   1.9838684E-05,   1.8958042E-05,   1.8075427E-05
     +,   1.7194505E-05,   1.6318905E-05,   1.5452038E-05
     +,   1.4597133E-05,   1.3757268E-05,   1.2935287E-05
     +,   1.2133734E-05,   1.1354886E-05,   1.0600803E-05
     +,   9.8732571E-06,   9.1736965E-06,   8.5032925E-06
     +,   7.8629873E-06,   7.2534576E-06,   6.6750858E-06
     +,   6.1280189E-06,   5.6122367E-06,   5.1274560E-06
     +,   4.6732148E-06,   4.2489091E-06,   3.8537883E-06
     +,   3.4869418E-06,   3.1473562E-06,   2.8339507E-06
     +,   2.5455704E-06,   2.2809834E-06,   2.0389273E-06
     +,   1.8181302E-06,   1.6173107E-06,   1.4351770E-06
     +,   1.2704547E-06,   1.1219099E-06,   9.8832652E-07
     +,   8.6852981E-07,   7.6139997E-07,   6.6586614E-07
     +,   5.8090552E-07,   5.0555360E-07,   4.3890859E-07
     +,   3.8012720E-07,   3.2842067E-07,   2.8305908E-07
     +,   2.4337263E-07,   2.0874567E-07,   1.7861299E-07
     +,   1.5246052E-07,   1.2982427E-07,   1.1028285E-07
     +,   9.3457125E-08,   7.9008309E-08,   6.6633604E-08
     +,   5.6062664E-08,   4.7055739E-08,   3.9401705E-08
     +,   3.2914379E-08,   2.7429902E-08,   2.2805036E-08
     +,   1.8915175E-08,   1.5651974E-08,   1.2921326E-08
     +,   1.0642044E-08,   8.7444478E-09,   7.1685351E-09
     +,   5.8630025E-09,   4.7841984E-09,   3.8949826E-09
     +,   3.1638190E-09,   2.5640703E-09,   2.0733357E-09
     +,   1.6727874E-09,   1.3466250E-09,   1.0816645E-09
     +,   8.6694063E-10,   6.9334427E-10,   5.5332205E-10
     +,   4.4063925E-10,   3.5017186E-10,   2.7770342E-10
     +,   2.1978204E-10,   1.7359240E-10,   1.3684033E-10
     +,   1.0765983E-10,   8.4540187E-11,   6.6261663E-11
     +,   5.1840945E-11,   4.0486635E-11,   3.1564175E-11
     +,   2.4566736E-11,   1.9089574E-11,   1.4810242E-11
     +,   1.1472716E-11,   8.8744680E-12,   6.8551163E-12
     +,   5.2882056E-12,   4.0743325E-12,   3.1354030E-12
     +,   2.4101689E-12,   1.8507466E-12,   1.4198043E-12
     +,   1.0882508E-12,   8.3344751E-13,   6.3783066E-13
     +,   4.8781183E-13,   3.7285615E-13,   2.8484861E-13
     +,   2.1751615E-13,   1.6603952E-13,   1.2670457E-13
     +,   9.6664572E-14,   7.3731237E-14,   5.6230557E-14
     +,   4.2878498E-14,   3.2694557E-14,   2.4927941E-14
     +,   1.9005436E-14,   1.4489764E-14,   1.1046636E-14
     +,   8.4215395E-15,   6.4199511E-15,   4.8938510E-15
     +,   3.7301866E-15,   2.8429295E-15,   2.1663774E-15
     +,   1.6505314E-15,   1.2572171E-15,   9.5736936E-16
     +,   7.2879096E-16,   5.5458111E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt60 = Yx/0.26204347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5245940E-04,   1.5647168E-04
     +,   1.5999132E-04,   1.6299744E-04,   1.6548020E-04
     +,   1.6744185E-04,   1.6889766E-04,   1.6987647E-04
     +,   1.7042150E-04,   1.7059121E-04,   1.7045987E-04
     +,   1.7011915E-04,   1.6967981E-04,   1.6927469E-04
     +,   1.6906252E-04,   1.6923377E-04,   1.7001790E-04
     +,   1.7169247E-04,   1.7459360E-04,   1.7912671E-04
     +,   1.8577563E-04,   1.9510707E-04,   2.0776720E-04
     +,   2.2446716E-04,   2.4594995E-04,   2.7294664E-04
     +,   3.0611016E-04,   3.4594364E-04,   3.9272814E-04
     +,   4.4646434E-04,   5.0684734E-04,   5.7329412E-04
     +,   6.4504647E-04,   7.2138029E-04,   8.0196175E-04
     +,   8.8740612E-04,   9.8009629E-04,   1.0852420E-03
     +,   1.2120453E-03,   1.3746036E-03,   1.5922111E-03
     +,   1.8885826E-03,   2.2897257E-03,   2.8201323E-03
     +,   3.4981472E-03,   4.3339469E-03,   5.3333305E-03
     +,   6.5009594E-03,   7.8245653E-03,   9.2421630E-03
     +,   1.0659758E-02,   1.2076540E-02,   1.3689985E-02
     +,   1.5793554E-02,   1.8594138E-02,   2.2310017E-02
     +,   2.7393991E-02,   3.3833303E-02,   4.0092692E-02
     +,   4.4943720E-02,   4.8535943E-02,   5.0563630E-02
     +,   5.1958170E-02,   5.2925654E-02,   5.3198505E-02
     +,   5.1781349E-02,   4.7503866E-02,   4.2541072E-02
     +,   3.8695719E-02,   3.4312919E-02,   2.8224846E-02
     +,   2.2504328E-02,   1.8836414E-02,   1.6670274E-02
     +,   1.5059585E-02,   1.3466452E-02,   1.1709793E-02
     +,   9.8778540E-03,   8.1890728E-03,   6.8429867E-03
     +,   5.9090960E-03,   5.3220461E-03,   4.9548736E-03
     +,   4.6849702E-03,   4.4244663E-03,   4.1272561E-03
     +,   3.7843934E-03,   3.4119403E-03,   3.0359903E-03
     +,   2.6799135E-03,   2.3578135E-03,   2.0741334E-03
     +,   1.8268867E-03,   1.6115556E-03,   1.4237572E-03
     +,   1.2602445E-03,   1.1187224E-03,   9.9733169E-04
     +,   8.9415524E-04,   8.0704974E-04,   7.3365821E-04
     +,   6.7158497E-04,   6.1855267E-04,   5.7255221E-04
     +,   5.3190649E-04,   4.9529813E-04,   4.6175168E-04
     +,   4.3058905E-04,   4.0137421E-04,   3.7385654E-04
     +,   3.4791967E-04,   3.2352598E-04,   3.0068136E-04
     +,   2.7939744E-04,   2.5967398E-04,   2.4148075E-04
     +,   2.2475715E-04,   2.0940944E-04,   1.9532180E-04
     +,   1.8236184E-04,   1.7039261E-04,   1.5928248E-04
     +,   1.4891206E-04,   1.3917859E-04,   1.2999981E-04
     +,   1.2131511E-04,   1.1308200E-04,   1.0527571E-04
     +,   9.7883567E-05,   9.0903115E-05,   8.4336600E-05
     +,   7.8189500E-05,   7.2466122E-05,   6.7169181E-05
     +,   6.2297215E-05,   5.7844354E-05,   5.3800472E-05
     +,   5.0150964E-05,   4.6877081E-05,   4.3956912E-05
     +,   4.1366282E-05,   3.9079361E-05,   3.7069323E-05
     +,   3.5309207E-05,   3.3772663E-05,   3.2434124E-05
     +,   3.1269359E-05,   3.0255800E-05,   2.9372633E-05
     +,   2.8600834E-05,   2.7923261E-05,   2.7324664E-05
     +,   2.6791522E-05,   2.6311949E-05,   2.5875595E-05
     +,   2.5473522E-05,   2.5098047E-05,   2.4742589E-05
     +,   2.4401566E-05,   2.4070299E-05,   2.3744835E-05
     +,   2.3421901E-05,   2.3098810E-05,   2.2773374E-05
     +,   2.2443824E-05,   2.2108745E-05,   2.1767069E-05
     +,   2.1418004E-05,   2.1060967E-05,   2.0695566E-05
     +,   2.0321630E-05,   1.9939107E-05,   1.9548072E-05
     +,   1.9148711E-05,   1.8741324E-05,   1.8326275E-05
     +,   1.7903994E-05,   1.7474998E-05,   1.7039865E-05
     +,   1.6599190E-05,   1.6153601E-05,   1.5703799E-05
     +,   1.5250514E-05,   1.4794467E-05,   1.4336401E-05
     +,   1.3877100E-05,   1.3417362E-05,   1.2957965E-05
     +,   1.2499676E-05,   1.2043320E-05,   1.1589657E-05
     +,   1.1139447E-05,   1.0693460E-05,   1.0252448E-05
     +,   9.8171076E-06,   9.3881163E-06,   8.9661480E-06
     +,   8.5518413E-06,   8.1457720E-06,   7.7484829E-06
     +,   7.3604956E-06,   6.9822941E-06,   6.6142875E-06
     +,   6.2568438E-06,   5.9103163E-06,   5.5749783E-06
     +,   5.2510536E-06,   4.9387404E-06,   4.6381892E-06
     +,   4.3494829E-06,   4.0726595E-06,   3.8077321E-06
     +,   3.5546691E-06,   3.3133811E-06,   3.0837425E-06
     +,   2.8656061E-06,   2.6587893E-06,   2.4630649E-06
     +,   2.2781792E-06,   2.1038704E-06,   1.9398356E-06
     +,   1.7857532E-06,   1.6412962E-06,   1.5061210E-06
     +,   1.3798643E-06,   1.2621555E-06,   1.1526250E-06
     +,   1.0508986E-06,   9.5659448E-07,   8.6933210E-07
     +,   7.8873933E-07,   7.1444839E-07,   6.4609242E-07
     +,   5.8331278E-07,   5.2576610E-07,   4.7311332E-07
     +,   4.2502623E-07,   3.8119279E-07,   3.4131230E-07
     +,   3.0509472E-07,   2.7226397E-07,   2.4255965E-07
     +,   2.1573491E-07,   1.9155482E-07,   1.6979838E-07
     +,   1.5025978E-07,   1.3274597E-07,   1.1707571E-07
     +,   1.0308038E-07,   9.0605027E-08,   7.9504687E-08
     +,   6.9645736E-08,   6.0905890E-08,   5.3172588E-08
     +,   4.6342322E-08,   4.0320536E-08,   3.5021525E-08
     +,   3.0367236E-08,   2.6286596E-08,   2.2715362E-08
     +,   1.9595802E-08,   1.6875866E-08,   1.4508609E-08
     +,   1.2452027E-08,   1.0668722E-08,   9.1251682E-09
     +,   7.7915168E-09,   6.6413768E-09,   5.6513394E-09
     +,   4.8006323E-09,   4.0709689E-09,   3.4462775E-09
     +,   2.9124501E-09,   2.4570836E-09,   2.0693403E-09
     +,   1.7397973E-09,   1.4602103E-09,   1.2234530E-09
     +,   1.0233115E-09,   8.5444229E-10,   7.1220718E-10
     +,   5.9263094E-10,   4.9227811E-10,   4.0821641E-10
     +,   3.3792341E-10,   2.7925398E-10,   2.3037272E-10
     +,   1.8971863E-10,   1.5597065E-10,   1.2800359E-10
     +,   1.0487070E-10,   8.5769634E-11,   7.0026956E-11
     +,   5.7074723E-11,   4.6438145E-11,   3.7718304E-11
     +,   3.0583119E-11,   2.4754660E-11,   2.0002520E-11
     +,   1.6134623E-11,   1.2992264E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt65 = Yx/0.231760869565217
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5591281E-05,   6.8466361E-05
     +,   7.1569040E-05,   7.4904485E-05,   7.8475867E-05
     +,   8.2284052E-05,   8.6327425E-05,   9.0601694E-05
     +,   9.5099640E-05,   9.9811288E-05,   1.0472351E-04
     +,   1.0982015E-04,   1.1508226E-04,   1.2048815E-04
     +,   1.2601366E-04,   1.3163273E-04,   1.3731763E-04
     +,   1.4303988E-04,   1.4877059E-04,   1.5448153E-04
     +,   1.6014585E-04,   1.6573897E-04,   1.7123940E-04
     +,   1.7662991E-04,   1.8189763E-04,   1.8703581E-04
     +,   1.9204347E-04,   1.9692670E-04,   2.0169858E-04
     +,   2.0637980E-04,   2.1099903E-04,   2.1559329E-04
     +,   2.2020868E-04,   2.2490123E-04,   2.2973889E-04
     +,   2.3480314E-04,   2.4019362E-04,   2.4603284E-04
     +,   2.5247442E-04,   2.5971324E-04,   2.6800096E-04
     +,   2.7766390E-04,   2.8912621E-04,   3.0293706E-04
     +,   3.1979906E-04,   3.4059767E-04,   3.6642415E-04
     +,   3.9858843E-04,   4.3860762E-04,   4.8815718E-04
     +,   5.4896472E-04,   6.2262494E-04,   7.1032700E-04
     +,   8.1251760E-04,   9.2852418E-04,   1.0563202E-03
     +,   1.1925143E-03,   1.3328391E-03,   1.4732580E-03
     +,   1.6117566E-03,   1.7506744E-03,   1.8991362E-03
     +,   2.0747562E-03,   2.3034620E-03,   2.6161184E-03
     +,   3.0421009E-03,   3.6038749E-03,   4.3202294E-03
     +,   5.2220356E-03,   6.3645481E-03,   7.8076124E-03
     +,   9.5620612E-03,   1.1562674E-02,   1.3739193E-02
     +,   1.6151659E-02,   1.9006427E-02,   2.2452470E-02
     +,   2.6156453E-02,   2.9355170E-02,   3.2565523E-02
     +,   3.8001627E-02,   4.5359284E-02,   5.0667763E-02
     +,   5.1696088E-02,   4.9520738E-02,   4.7454603E-02
     +,   4.5334812E-02,   4.1250791E-02,   3.8278729E-02
     +,   3.6773067E-02,   3.2456007E-02,   2.5716245E-02
     +,   1.9859493E-02,   1.5736375E-02,   1.2626356E-02
     +,   1.0062136E-02,   8.0056135E-03,   6.5017021E-03
     +,   5.4894299E-03,   4.8268833E-03,   4.3776683E-03
     +,   4.0497920E-03,   3.7867471E-03,   3.5509812E-03
     +,   3.3163331E-03,   3.0667048E-03,   2.7958588E-03
     +,   2.5061844E-03,   2.2061686E-03,   1.9072950E-03
     +,   1.6212313E-03,   1.3577171E-03,   1.1235155E-03
     +,   9.2204404E-04,   7.5372477E-04,   6.1659276E-04
     +,   5.0714816E-04,   4.2110417E-04,   3.5405817E-04
     +,   3.0192087E-04,   2.6118258E-04,   2.2900842E-04
     +,   2.0321389E-04,   1.8218077E-04,   1.6474830E-04
     +,   1.5010337E-04,   1.3767969E-04,   1.2708393E-04
     +,   1.1803362E-04,   1.1031827E-04,   1.0376900E-04
     +,   9.8242897E-05,   9.3611059E-05,   8.9754969E-05
     +,   8.6563312E-05,   8.3932246E-05,   8.1766091E-05
     +,   7.9977690E-05,   7.8488913E-05,   7.7231009E-05
     +,   7.6144497E-05,   7.5178636E-05,   7.4290809E-05
     +,   7.3445815E-05,   7.2615105E-05,   7.1775874E-05
     +,   7.0910333E-05,   7.0005073E-05,   6.9050366E-05
     +,   6.8039531E-05,   6.6968518E-05,   6.5835557E-05
     +,   6.4640662E-05,   6.3385327E-05,   6.2072249E-05
     +,   6.0705243E-05,   5.9288897E-05,   5.7828318E-05
     +,   5.6329081E-05,   5.4797227E-05,   5.3238844E-05
     +,   5.1660114E-05,   5.0067327E-05,   4.8466663E-05
     +,   4.6864068E-05,   4.5265246E-05,   4.3675747E-05
     +,   4.2100775E-05,   4.0545099E-05,   3.9013081E-05
     +,   3.7508784E-05,   3.6035824E-05,   3.4597295E-05
     +,   3.3195854E-05,   3.1833843E-05,   3.0513056E-05
     +,   2.9234852E-05,   2.8000273E-05,   2.6809994E-05
     +,   2.5664223E-05,   2.4562867E-05,   2.3505587E-05
     +,   2.2491771E-05,   2.1520491E-05,   2.0590625E-05
     +,   1.9700932E-05,   1.8850014E-05,   1.8036308E-05
     +,   1.7258164E-05,   1.6513957E-05,   1.5801954E-05
     +,   1.5120410E-05,   1.4467654E-05,   1.3842037E-05
     +,   1.3241925E-05,   1.2665750E-05,   1.2112062E-05
     +,   1.1579495E-05,   1.1066742E-05,   1.0572602E-05
     +,   1.0096001E-05,   9.6359727E-06,   9.1916145E-06
     +,   8.7621283E-06,   8.3468613E-06,   7.9451875E-06
     +,   7.5565836E-06,   7.1806185E-06,   6.8169343E-06
     +,   6.4652077E-06,   6.1251685E-06,   5.7966199E-06
     +,   5.4793945E-06,   5.1733382E-06,   4.8783213E-06
     +,   4.5942470E-06,   4.3210321E-06,   4.0585751E-06
     +,   3.8067776E-06,   3.5655626E-06,   3.3348167E-06
     +,   3.1144186E-06,   2.9042480E-06,   2.7041665E-06
     +,   2.5140068E-06,   2.3335849E-06,   2.1627106E-06
     +,   2.0011755E-06,   1.8487444E-06,   1.7051655E-06
     +,   1.5701827E-06,   1.4435244E-06,   1.3249004E-06
     +,   1.2140105E-06,   1.1105561E-06,   1.0142224E-06
     +,   9.2469026E-07,   8.4164395E-07,   7.6476636E-07
     +,   6.9373550E-07,   6.2823261E-07,   5.6794732E-07
     +,   5.1257422E-07,   4.6181057E-07,   4.1536171E-07
     +,   3.7294512E-07,   3.3428731E-07,   2.9912246E-07
     +,   2.6719596E-07,   2.3826759E-07,   2.1210550E-07
     +,   1.8849023E-07,   1.6721550E-07,   1.4808691E-07
     +,   1.3092030E-07,   1.1554341E-07,   1.0179652E-07
     +,   8.9530580E-08,   7.8606639E-08,   6.8895972E-08
     +,   6.0280513E-08,   5.2651473E-08,   4.5908397E-08
     +,   3.9959495E-08,   3.4721474E-08,   3.0117857E-08
     +,   2.6079293E-08,   2.2543192E-08,   1.9452907E-08
     +,   1.6757202E-08,   1.4409999E-08,   1.2370120E-08
     +,   1.0600674E-08,   9.0686045E-09,   7.7444904E-09
     +,   6.6022934E-09,   5.6187828E-09,   4.7735225E-09
     +,   4.0483741E-09,   3.4274594E-09,   2.8967375E-09
     +,   2.4439644E-09,   2.0583839E-09,   1.7306427E-09
     +,   1.4525553E-09,   1.2170507E-09,   1.0179605E-09
     +,   8.4996110E-10,   7.0846146E-10,   5.8949273E-10
     +,   4.8965487E-10,   4.0601944E-10,   3.3608830E-10
     +,   2.7771838E-10,   2.2908976E-10,   1.8864765E-10
     +,   1.5507685E-10,   1.2725859E-10,   1.0425027E-10
     +,   8.5253506E-11,   6.9598001E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt70 = Yx/0.203933333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4172953E-05,   4.5584649E-05
     +,   4.7024481E-05,   4.8489917E-05,   4.9978262E-05
     +,   5.1486746E-05,   5.3012576E-05,   5.4553031E-05
     +,   5.6105466E-05,   5.7667570E-05,   5.9237304E-05
     +,   6.0813127E-05,   6.2394131E-05,   6.3980166E-05
     +,   6.5572029E-05,   6.7171590E-05,   6.8782094E-05
     +,   7.0408147E-05,   7.2056093E-05,   7.3734009E-05
     +,   7.5451971E-05,   7.7222132E-05,   7.9058838E-05
     +,   8.0978818E-05,   8.3001010E-05,   8.5146981E-05
     +,   8.7440698E-05,   8.9908826E-05,   9.2580856E-05
     +,   9.5489289E-05,   9.8670134E-05,   1.0216334E-04
     +,   1.0601354E-04,   1.1027097E-04,   1.1499240E-04
     +,   1.2024226E-04,   1.2609363E-04,   1.3262904E-04
     +,   1.3994116E-04,   1.4813140E-04,   1.5730973E-04
     +,   1.6759068E-04,   1.7908918E-04,   1.9191408E-04
     +,   2.0615938E-04,   2.2189438E-04,   2.3915185E-04
     +,   2.5791582E-04,   2.7810951E-04,   2.9958534E-04
     +,   3.2211692E-04,   3.4539634E-04,   3.6903555E-04
     +,   3.9257813E-04,   4.1551009E-04,   4.3728889E-04
     +,   4.5736853E-04,   4.7523636E-04,   4.9044995E-04
     +,   5.0267647E-04,   5.1172968E-04,   5.1760336E-04
     +,   5.2049779E-04,   5.2083755E-04,   5.1927887E-04
     +,   5.1670335E-04,   5.1419664E-04,   5.1301159E-04
     +,   5.1451003E-04,   5.2008766E-04,   5.3108099E-04
     +,   5.4866343E-04,   5.7375111E-04,   6.0692790E-04
     +,   6.4843748E-04,   6.9825631E-04,   7.5627747E-04
     +,   8.2262169E-04,   8.9805858E-04,   9.8447339E-04
     +,   1.0853029E-03,   1.2058630E-03,   1.3533834E-03
     +,   1.5367615E-03,   1.7658666E-03,   2.0505199E-03
     +,   2.3988446E-03,   2.8150945E-03,   3.2971713E-03
     +,   3.8368346E-03,   4.4277683E-03,   5.0852792E-03
     +,   5.8700698E-03,   6.9047725E-03,   8.3934441E-03
     +,   1.0623325E-02,   1.3833237E-02,   1.8040400E-02
     +,   2.3130789E-02,   2.8612068E-02,   3.2727871E-02
     +,   3.3615399E-02,   3.2814585E-02,   3.4010008E-02
     +,   3.6870249E-02,   3.7574243E-02,   3.4792617E-02
     +,   3.0740870E-02,   2.7194189E-02,   2.3469890E-02
     +,   1.8928403E-02,   1.4456934E-02,   1.1052465E-02
     +,   8.8252649E-03,   7.3866323E-03,   6.3467324E-03
     +,   5.4666298E-03,   4.6592830E-03,   3.9361920E-03
     +,   3.3312764E-03,   2.8523987E-03,   2.4785958E-03
     +,   2.1793635E-03,   1.9297530E-03,   1.7142019E-03
     +,   1.5241262E-03,   1.3547424E-03,   1.2032667E-03
     +,   1.0680503E-03,   9.4815996E-04,   8.4294344E-04
     +,   7.5174239E-04,   6.7368784E-04,   6.0769805E-04
     +,   5.5252074E-04,   5.0682970E-04,   4.6930675E-04
     +,   4.3869161E-04,   4.1381153E-04,   3.9360084E-04
     +,   3.7710622E-04,   3.6348548E-04,   3.5200504E-04
     +,   3.4203686E-04,   3.3305638E-04,   3.2463431E-04
     +,   3.1643180E-04,   3.0819402E-04,   2.9974073E-04
     +,   2.9095658E-04,   2.8178204E-04,   2.7220396E-04
     +,   2.6224615E-04,   2.5195917E-04,   2.4141342E-04
     +,   2.3069224E-04,   2.1988535E-04,   2.0908251E-04
     +,   1.9837022E-04,   1.8782941E-04,   1.7753079E-04
     +,   1.6753460E-04,   1.5789029E-04,   1.4863584E-04
     +,   1.3979759E-04,   1.3139161E-04,   1.2342561E-04
     +,   1.1589924E-04,   1.0880532E-04,   1.0213158E-04
     +,   9.5862342E-05,   8.9979272E-05,   8.4461812E-05
     +,   7.9288700E-05,   7.4438925E-05,   6.9891321E-05
     +,   6.5625478E-05,   6.1622290E-05,   5.7863737E-05
     +,   5.4332853E-05,   5.1013962E-05,   4.7892914E-05
     +,   4.4956741E-05,   4.2193431E-05,   3.9592091E-05
     +,   3.7142931E-05,   3.4837060E-05,   3.2666179E-05
     +,   3.0622708E-05,   2.8699858E-05,   2.6891134E-05
     +,   2.5190504E-05,   2.3592425E-05,   2.2091641E-05
     +,   2.0683070E-05,   1.9361854E-05,   1.8123428E-05
     +,   1.6963369E-05,   1.5877329E-05,   1.4861112E-05
     +,   1.3910706E-05,   1.3022232E-05,   1.2191875E-05
     +,   1.1415957E-05,   1.0691013E-05,   1.0013649E-05
     +,   9.3806239E-06,   8.7888902E-06,   8.2355664E-06
     +,   7.7178838E-06,   7.2332532E-06,   6.7792839E-06
     +,   6.3537432E-06,   5.9545387E-06,   5.5797354E-06
     +,   5.2275809E-06,   4.8964662E-06,   4.5849010E-06
     +,   4.2915285E-06,   4.0151417E-06,   3.7546206E-06
     +,   3.5089486E-06,   3.2772232E-06,   3.0586230E-06
     +,   2.8523903E-06,   2.6578339E-06,   2.4743376E-06
     +,   2.3013370E-06,   2.1382996E-06,   1.9847344E-06
     +,   1.8401943E-06,   1.7042590E-06,   1.5765254E-06
     +,   1.4566106E-06,   1.3441618E-06,   1.2388297E-06
     +,   1.1402792E-06,   1.0481921E-06,   9.6226029E-07
     +,   8.8217939E-07,   8.0765324E-07,   7.3839897E-07
     +,   6.7414112E-07,   6.1460662E-07,   5.5953149E-07
     +,   5.0866242E-07,   4.6175359E-07,   4.1856396E-07
     +,   3.7886096E-07,   3.4242461E-07,   3.0903900E-07
     +,   2.7849762E-07,   2.5060478E-07,   2.2517334E-07
     +,   2.0202333E-07,   1.8098409E-07,   1.6189527E-07
     +,   1.4460512E-07,   1.2896942E-07,   1.1485256E-07
     +,   1.0212855E-07,   9.0679045E-08,   8.0393050E-08
     +,   7.1167108E-08,   6.2906139E-08,   5.5520982E-08
     +,   4.8929451E-08,   4.3055998E-08,   3.7831096E-08
     +,   3.3190545E-08,   2.9075556E-08,   2.5432639E-08
     +,   2.2212975E-08,   1.9371871E-08,   1.6868805E-08
     +,   1.4667257E-08,   1.2733889E-08,   1.1038871E-08
     +,   9.5551194E-09,   8.2584597E-09,   7.1270478E-09
     +,   6.1414624E-09,   5.2842291E-09,   4.5398649E-09
     +,   3.8945021E-09,   3.3358938E-09,   2.8531342E-09
     +,   2.4365749E-09,   2.0777269E-09,   1.7690707E-09
     +,   1.5040189E-09,   1.2767596E-09,   1.0822211E-09
     +,   9.1594810E-10,   7.7406448E-10,   6.5317662E-10
     +,   5.5034632E-10,   4.6300819E-10,   3.8894940E-10
     +,   3.2624575E-10,   2.7324262E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt75 = Yx/0.142116279069767
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9793022E-05,   2.9361479E-05
     +,   2.8898949E-05,   2.8409373E-05,   2.7896773E-05
     +,   2.7365204E-05,   2.6818740E-05,   2.6261423E-05
     +,   2.5697247E-05,   2.5130095E-05,   2.4563764E-05
     +,   2.4001904E-05,   2.3448029E-05,   2.2905497E-05
     +,   2.2377515E-05,   2.1867158E-05,   2.1377335E-05
     +,   2.0910893E-05,   2.0470579E-05,   2.0059117E-05
     +,   1.9679235E-05,   1.9333751E-05,   1.9025612E-05
     +,   1.8757964E-05,   1.8534263E-05,   1.8358303E-05
     +,   1.8234345E-05,   1.8167164E-05,   1.8162140E-05
     +,   1.8225326E-05,   1.8363497E-05,   1.8584176E-05
     +,   1.8895696E-05,   1.9307152E-05,   1.9828381E-05
     +,   2.0469906E-05,   2.1242799E-05,   2.2158565E-05
     +,   2.3229004E-05,   2.4465808E-05,   2.5880547E-05
     +,   2.7484142E-05,   2.9286637E-05,   3.1296808E-05
     +,   3.3521770E-05,   3.5966597E-05,   3.8633920E-05
     +,   4.1523595E-05,   4.4632336E-05,   4.7953508E-05
     +,   5.1476898E-05,   5.5188666E-05,   5.9071368E-05
     +,   6.3104417E-05,   6.7263878E-05,   7.1523958E-05
     +,   7.5857177E-05,   8.0235877E-05,   8.4633517E-05
     +,   8.9026602E-05,   9.3396637E-05,   9.7732598E-05
     +,   1.0203321E-04,   1.0631030E-04,   1.1059138E-04
     +,   1.1492181E-04,   1.1936824E-04,   1.2401927E-04
     +,   1.2898749E-04,   1.3440823E-04,   1.4043933E-04
     +,   1.4725655E-04,   1.5505044E-04,   1.6401811E-04
     +,   1.7435702E-04,   1.8625513E-04,   1.9988041E-04
     +,   2.1537118E-04,   2.3282807E-04,   2.5230527E-04
     +,   2.7380214E-04,   2.9726484E-04,   3.2258037E-04
     +,   3.4958695E-04,   3.7807456E-04,   4.0780491E-04
     +,   4.3851999E-04,   4.6997037E-04,   5.0192839E-04
     +,   5.3421792E-04,   5.6672806E-04,   5.9942051E-04
     +,   6.3232449E-04,   6.6551456E-04,   6.9906429E-04
     +,   7.3298224E-04,   7.6716125E-04,   8.0133282E-04
     +,   8.3509780E-04,   8.6803193E-04,   8.9991739E-04
     +,   9.3106693E-04,   9.6272631E-04,   9.9745800E-04
     +,   1.0394778E-03,   1.0948692E-03,   1.1716099E-03
     +,   1.2792669E-03,   1.4282025E-03,   1.6284897E-03
     +,   1.8892910E-03,   2.2195305E-03,   2.6287998E-03
     +,   3.1268774E-03,   3.7239250E-03,   4.4422266E-03
     +,   5.3418707E-03,   6.5264706E-03,   8.0712056E-03
     +,   9.8911375E-03,   1.1689643E-02,   1.3108734E-02
     +,   1.4000887E-02,   1.4579184E-02,   1.5235012E-02
     +,   1.6059523E-02,   1.6528463E-02,   1.5897011E-02
     +,   1.4005671E-02,   1.1469029E-02,   9.0526203E-03
     +,   7.1264296E-03,   5.6787659E-03,   4.5687379E-03
     +,   3.6842485E-03,   2.9735728E-03,   2.4153178E-03
     +,   1.9858049E-03,   1.6529495E-03,   1.3871242E-03
     +,   1.1689144E-03,   9.8817993E-04,   8.3955971E-04
     +,   7.1897864E-04,   6.2217348E-04,   5.4458855E-04
     +,   4.8186694E-04,   4.3033416E-04,   3.8722795E-04
     +,   3.5066565E-04,   3.1944699E-04,   2.9280400E-04
     +,   2.7018317E-04,   2.5110226E-04,   2.3508481E-04
     +,   2.2164671E-04,   2.1030905E-04,   2.0062046E-04
     +,   1.9217754E-04,   1.8463630E-04,   1.7771375E-04
     +,   1.7118598E-04,   1.6488254E-04,   1.5867854E-04
     +,   1.5248700E-04,   1.4625232E-04,   1.3994458E-04
     +,   1.3355415E-04,   1.2708677E-04,   1.2056027E-04
     +,   1.1400186E-04,   1.0744510E-04,   1.0092704E-04
     +,   9.4486852E-05,   8.8164670E-05,   8.1998936E-05
     +,   7.6025768E-05,   7.0278373E-05,   6.4785694E-05
     +,   5.9571586E-05,   5.4654727E-05,   5.0048762E-05
     +,   4.5761910E-05,   4.1796909E-05,   3.8151658E-05
     +,   3.4819906E-05,   3.1791496E-05,   2.9052821E-05
     +,   2.6587692E-05,   2.4378232E-05,   2.2404967E-05
     +,   2.0647733E-05,   1.9086252E-05,   1.7700486E-05
     +,   1.6470914E-05,   1.5378986E-05,   1.4407394E-05
     +,   1.3540152E-05,   1.2762656E-05,   1.2061796E-05
     +,   1.1425995E-05,   1.0845104E-05,   1.0310316E-05
     +,   9.8141054E-06,   9.3501740E-06,   8.9132336E-06
     +,   8.4989451E-06,   8.1038261E-06,   7.7251070E-06
     +,   7.3606070E-06,   7.0086567E-06,   6.6680359E-06
     +,   6.3378729E-06,   6.0175498E-06,   5.7066691E-06
     +,   5.4050201E-06,   5.1125126E-06,   4.8291267E-06
     +,   4.5549004E-06,   4.2899314E-06,   4.0343043E-06
     +,   3.7881048E-06,   3.5514249E-06,   3.3243311E-06
     +,   3.1068521E-06,   2.8989850E-06,   2.7007086E-06
     +,   2.5119693E-06,   2.3326650E-06,   2.1626645E-06
     +,   2.0018165E-06,   1.8499413E-06,   1.7068219E-06
     +,   1.5722190E-06,   1.4458883E-06,   1.3275516E-06
     +,   1.2169189E-06,   1.1136952E-06,   1.0175763E-06
     +,   9.2824314E-07,   8.4537498E-07,   7.6865444E-07
     +,   6.9776371E-07,   6.3238235E-07,   5.7219444E-07
     +,   5.1689398E-07,   4.6618112E-07,   4.1976091E-07
     +,   3.7734767E-07,   3.3867008E-07,   3.0346320E-07
     +,   2.7147360E-07,   2.4246168E-07,   2.1619910E-07
     +,   1.9246824E-07,   1.7106304E-07,   1.5179145E-07
     +,   1.3447273E-07,   1.1893644E-07,   1.0502387E-07
     +,   9.2588010E-08,   8.1492445E-08,   7.1610017E-08
     +,   6.2823545E-08,   5.5025893E-08,   4.8117744E-08
     +,   4.2008363E-08,   3.6615109E-08,   3.1862537E-08
     +,   2.7681811E-08,   2.4010474E-08,   2.0792220E-08
     +,   1.7976154E-08,   1.5516244E-08,   1.3371147E-08
     +,   1.1503937E-08,   9.8813482E-09,   8.4738732E-09
     +,   7.2550344E-09,   6.2014482E-09,   5.2922244E-09
     +,   4.5089994E-09,   3.8354249E-09,   3.2571883E-09
     +,   2.7616178E-09,   2.3376585E-09,   1.9755695E-09
     +,   1.6668456E-09,   1.4040880E-09,   1.1808234E-09
     +,   9.9145359E-10,   8.3109525E-10,   6.9554607E-10
     +,   5.8115485E-10,   4.8479160E-10,   4.0374723E-10
     +,   3.3570705E-10,   2.7867766E-10,   2.3096229E-10
     +,   1.9110451E-10,   1.5786922E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt80 = Yx/0.0633783783783784
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8268352E-05,   2.9084762E-05
     +,   2.9916897E-05,   3.0764091E-05,   3.1625525E-05
     +,   3.2500222E-05,   3.3387038E-05,   3.4284647E-05
     +,   3.5191548E-05,   3.6106085E-05,   3.7026402E-05
     +,   3.7950467E-05,   3.8876100E-05,   3.9800932E-05
     +,   4.0722469E-05,   4.1638072E-05,   4.2544980E-05
     +,   4.3440330E-05,   4.4321183E-05,   4.5184537E-05
     +,   4.6027362E-05,   4.6846631E-05,   4.7639325E-05
     +,   4.8402537E-05,   4.9133359E-05,   4.9829141E-05
     +,   5.0487295E-05,   5.1105497E-05,   5.1681644E-05
     +,   5.2213927E-05,   5.2700852E-05,   5.3141295E-05
     +,   5.3534546E-05,   5.3880311E-05,   5.4178803E-05
     +,   5.4430744E-05,   5.4637407E-05,   5.4800665E-05
     +,   5.4923017E-05,   5.5007622E-05,   5.5058332E-05
     +,   5.5079709E-05,   5.5077071E-05,   5.5056491E-05
     +,   5.5024837E-05,   5.4989741E-05,   5.4959670E-05
     +,   5.4943837E-05,   5.4952237E-05,   5.4995617E-05
     +,   5.5085409E-05,   5.5233686E-05,   5.5453067E-05
     +,   5.5756656E-05,   5.6157896E-05,   5.6670451E-05
     +,   5.7308011E-05,   5.8084195E-05,   5.9012222E-05
     +,   6.0104827E-05,   6.1373968E-05,   6.2830622E-05
     +,   6.4484426E-05,   6.6343666E-05,   6.8414935E-05
     +,   7.0702743E-05,   7.3209754E-05,   7.5936085E-05
     +,   7.8879923E-05,   8.2036619E-05,   8.5399581E-05
     +,   8.8959379E-05,   9.2704940E-05,   9.6622556E-05
     +,   1.0069712E-04,   1.0491198E-04,   1.0924899E-04
     +,   1.1368911E-04,   1.1821307E-04,   1.2280137E-04
     +,   1.2743434E-04,   1.3209335E-04,   1.3676001E-04
     +,   1.4141755E-04,   1.4604983E-04,   1.5064269E-04
     +,   1.5518279E-04,   1.5965867E-04,   1.6405979E-04
     +,   1.6837711E-04,   1.7260248E-04,   1.7672841E-04
     +,   1.8074762E-04,   1.8465327E-04,   1.8843821E-04
     +,   1.9209442E-04,   1.9561357E-04,   1.9898580E-04
     +,   2.0220065E-04,   2.0524625E-04,   2.0811039E-04
     +,   2.1078021E-04,   2.1324347E-04,   2.1548894E-04
     +,   2.1750804E-04,   2.1929608E-04,   2.2085408E-04
     +,   2.2219158E-04,   2.2332990E-04,   2.2430664E-04
     +,   2.2518137E-04,   2.2604322E-04,   2.2701958E-04
     +,   2.2828621E-04,   2.3007662E-04,   2.3269061E-04
     +,   2.3649653E-04,   2.4192709E-04,   2.4946054E-04
     +,   2.5958702E-04,   2.7275502E-04,   2.8929816E-04
     +,   3.0935308E-04,   3.3278452E-04,   3.5914485E-04
     +,   3.8770813E-04,   4.1765303E-04,   4.4844192E-04
     +,   4.8050631E-04,   5.1626062E-04,   5.6143769E-04
     +,   6.2645559E-04,   7.2731165E-04,   8.8511652E-04
     +,   1.1235401E-03,   1.4638434E-03,   1.9182819E-03
     +,   2.4838743E-03,   3.1389708E-03,   3.8442451E-03
     +,   4.5483126E-03,   5.1963623E-03,   5.7391063E-03
     +,   6.1392528E-03,   6.3742152E-03,   6.4352951E-03
     +,   6.3247737E-03,   6.0536591E-03,   5.6416187E-03
     +,   5.1183584E-03,   4.5239539E-03,   3.9055157E-03
     +,   3.3097127E-03,   2.7740116E-03,   2.3206009E-03
     +,   1.9553525E-03,   1.6713041E-03,   1.4543403E-03
     +,   1.2883716E-03,   1.1585600E-03,   1.0525991E-03
     +,   9.6093881E-04,   8.7662687E-04,   7.9512078E-04
     +,   7.1408076E-04,   6.3305389E-04,   5.5300293E-04
     +,   4.7571849E-04,   4.0324355E-04,   3.3741101E-04
     +,   2.7953926E-04,   2.3028677E-04,   1.8965434E-04
     +,   1.5709501E-04,   1.3167609E-04,   1.1224594E-04
     +,   9.7594093E-05,   8.6572378E-05,   7.8172736E-05
     +,   7.1567440E-05,   6.6118591E-05,   6.1364939E-05
     +,   5.6995646E-05,   5.2819301E-05,   4.8733735E-05
     +,   4.4699307E-05,   4.0716757E-05,   3.6810041E-05
     +,   3.3014465E-05,   2.9368664E-05,   2.5908495E-05
     +,   2.2664191E-05,   1.9658941E-05,   1.6908039E-05
     +,   1.4418900E-05,   1.2191911E-05,   1.0221473E-05
     +,   8.4968806E-06,   7.0033861E-06,   5.7234324E-06
     +,   4.6377622E-06,   3.7262146E-06,   2.9684677E-06
     +,   2.3447656E-06,   1.8364403E-06,   1.4261393E-06
     +,   1.0981258E-06,   8.3840075E-07,   6.3469582E-07
     +,   4.7642146E-07,   3.5458896E-07,   2.6168124E-07
     +,   1.9148689E-07,   1.3893808E-07,   9.9957568E-08
     +,   7.1306282E-08,   5.0438686E-08,   3.5376917E-08
     +,   2.4603258E-08,   1.6966515E-08,   1.1601568E-08
     +,   7.8661175E-09,   5.2884692E-09,   3.5255960E-09
     +,   2.3305802E-09,   1.5276350E-09,   9.9290154E-10
     +,   6.3992850E-10,   4.0896944E-10,   2.5916636E-10
     +,   1.6285587E-10,   1.0147804E-10,   6.2701837E-11
     +,   3.8416895E-11,   2.3340645E-11,   1.4061998E-11
     +,   8.4007523E-12,   4.9766281E-12,   2.9235297E-12
     +,   1.7030528E-12,   9.8376472E-13,   5.6351505E-13
     +,   3.2009652E-13,   1.8030565E-13,   1.0071301E-13
     +,   5.5785227E-14,   3.0642145E-14,   1.6690844E-14
     +,   9.0155087E-15,   4.8291678E-15,   2.5651855E-15
     +,   1.3512056E-15,   7.0581487E-16,   3.6562680E-16
     +,   1.8782667E-16,   9.5684223E-17,   4.8339360E-17
     +,   2.4218970E-17,   1.2033736E-17,   5.9297964E-18
     +,   2.8980221E-18,   1.4048351E-18,   6.7553948E-19
     +,   3.2228916E-19,   1.5260243E-19,   7.1747378E-20
     +,   3.3521633E-20,   1.5585747E-20,   7.2279583E-21
     +,   3.3558035E-21,   1.5690743E-21,   7.4560083E-22
     +,   3.6469754E-22,   1.8652187E-22,   1.0128742E-22
     +,   5.8965788E-23,   3.6781492E-23,   2.4337567E-23
     +,   1.6830696E-23,   1.1991080E-23,   8.7026370E-24
     +,   6.3844757E-24,   4.7113653E-24,   3.4869249E-24
     +,   2.5837472E-24,   1.9149449E-24,   1.4187597E-24
     +,   1.0504463E-24,   7.7711580E-25,   5.7437574E-25
     +,   4.2411908E-25,   3.1285817E-25,   2.3055281E-25
     +,   1.6972596E-25,   1.2482137E-25,   9.1701894E-26
     +,   6.7301902E-26,   4.9343404E-26,   3.6139860E-26
     +,   2.6442014E-26,   1.9326933E-26
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt85 = Yx/0.02909375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1191677E-06,   2.2695460E-06
     +,   2.4275405E-06,   2.5932723E-06,   2.7668407E-06
     +,   2.9483224E-06,   3.1377704E-06,   3.3352112E-06
     +,   3.5406424E-06,   3.7540403E-06,   3.9753459E-06
     +,   4.2044730E-06,   4.4413073E-06,   4.6857044E-06
     +,   4.9374949E-06,   5.1964844E-06,   5.4624570E-06
     +,   5.7351767E-06,   6.0143980E-06,   6.2998656E-06
     +,   6.5913323E-06,   6.8885524E-06,   7.1913087E-06
     +,   7.4994327E-06,   7.8127759E-06,   8.1312983E-06
     +,   8.4550302E-06,   8.7841145E-06,   9.1188449E-06
     +,   9.4596844E-06,   9.8072924E-06,   1.0162572E-05
     +,   1.0526696E-05,   1.0901154E-05,   1.1287786E-05
     +,   1.1688827E-05,   1.2106953E-05,   1.2545312E-05
     +,   1.3007588E-05,   1.3497968E-05,   1.4021282E-05
     +,   1.4582920E-05,   1.5188916E-05,   1.5845912E-05
     +,   1.6561187E-05,   1.7342609E-05,   1.8198612E-05
     +,   1.9138153E-05,   2.0170619E-05,   2.1305783E-05
     +,   2.2553673E-05,   2.3924476E-05,   2.5428379E-05
     +,   2.7075552E-05,   2.8875767E-05,   3.0838568E-05
     +,   3.2972894E-05,   3.5287052E-05,   3.7788606E-05
     +,   4.0484305E-05,   4.3380023E-05,   4.6480793E-05
     +,   4.9790608E-05,   5.3312917E-05,   5.7050529E-05
     +,   6.1005372E-05,   6.5179556E-05,   6.9574482E-05
     +,   7.4192234E-05,   7.9034551E-05,   8.4104220E-05
     +,   8.9403904E-05,   9.4937488E-05,   1.0070859E-04
     +,   1.0672159E-04,   1.1298078E-04,   1.1948930E-04
     +,   1.2624888E-04,   1.3325950E-04,   1.4051775E-04
     +,   1.4801520E-04,   1.5573877E-04,   1.6366747E-04
     +,   1.7177344E-04,   1.8001870E-04,   1.8835640E-04
     +,   1.9672824E-04,   2.0506624E-04,   2.1329102E-04
     +,   2.2131420E-04,   2.2903878E-04,   2.3636031E-04
     +,   2.4316981E-04,   2.4935641E-04,   2.5481012E-04
     +,   2.5942424E-04,   2.6310020E-04,   2.6574923E-04
     +,   2.6729677E-04,   2.6768449E-04,   2.6687290E-04
     +,   2.6484329E-04,   2.6159850E-04,   2.5716392E-04
     +,   2.5158640E-04,   2.4493350E-04,   2.3729209E-04
     +,   2.2876586E-04,   2.1947161E-04,   2.0953648E-04
     +,   1.9909546E-04,   1.8828547E-04,   1.7724460E-04
     +,   1.6610579E-04,   1.5499683E-04,   1.4403455E-04
     +,   1.3332591E-04,   1.2296320E-04,   1.1302603E-04
     +,   1.0357820E-04,   9.4669158E-05,   8.6334927E-05
     +,   7.8598750E-05,   7.1472350E-05,   6.4958818E-05
     +,   5.9056161E-05,   5.3759461E-05,   4.9066712E-05
     +,   4.4982633E-05,   4.1525596E-05,   3.8732742E-05
     +,   3.6667065E-05,   3.5422123E-05,   3.5126493E-05
     +,   3.5944937E-05,   3.8077098E-05,   4.1752875E-05
     +,   4.7225847E-05,   5.4767723E-05,   6.4665539E-05
     +,   7.7224264E-05,   9.2778202E-05,   1.1171184E-04
     +,   1.3448628E-04,   1.6167366E-04,   1.9402178E-04
     +,   2.3256105E-04,   2.7880055E-04,   3.3505470E-04
     +,   4.0490148E-04,   4.9367867E-04,   6.0881936E-04
     +,   7.5973908E-04,   9.5699134E-04,   1.2105292E-03
     +,   1.5272554E-03,   1.9083758E-03,   2.3472023E-03
     +,   2.8279214E-03,   3.3257219E-03,   3.8086749E-03
     +,   4.2411457E-03,   4.5887218E-03,   4.8239557E-03
     +,   4.9314671E-03,   4.9105547E-03,   4.7742715E-03
     +,   4.5449734E-03,   4.2481190E-03,   3.9068805E-03
     +,   3.5395487E-03,   3.1599901E-03,   2.7799436E-03
     +,   2.4112300E-03,   2.0663349E-03,   1.7570092E-03
     +,   1.4919931E-03,   1.2750571E-03,   1.1043540E-03
     +,   9.7334658E-04,   8.7283691E-04,   7.9322798E-04
     +,   7.2631106E-04,   6.6622370E-04,   6.0958916E-04
     +,   5.5506773E-04,   5.0265051E-04,   4.5296305E-04
     +,   4.0674862E-04,   3.6456643E-04,   3.2666800E-04
     +,   2.9301466E-04,   2.6335745E-04,   2.3732703E-04
     +,   2.1451224E-04,   1.9451567E-04,   1.7698182E-04
     +,   1.6160218E-04,   1.4810913E-04,   1.3626688E-04
     +,   1.2586218E-04,   1.1669684E-04,   1.0858447E-04
     +,   1.0135197E-04,   9.4842464E-05,   8.8916859E-05
     +,   8.3456682E-05,   7.8365410E-05,   7.3567571E-05
     +,   6.9006725E-05,   6.4643231E-05,   6.0451541E-05
     +,   5.6416746E-05,   5.2531457E-05,   4.8793612E-05
     +,   4.5204619E-05,   4.1767511E-05,   3.8485639E-05
     +,   3.5362082E-05,   3.2399519E-05,   2.9599300E-05
     +,   2.6961707E-05,   2.4486102E-05,   2.2170785E-05
     +,   2.0012953E-05,   1.8008974E-05,   1.6154612E-05
     +,   1.4444976E-05,   1.2874497E-05,   1.1437166E-05
     +,   1.0126695E-05,   8.9364803E-06,   7.8596067E-06
     +,   6.8890386E-06,   6.0177599E-06,   5.2386590E-06
     +,   4.5447105E-06,   3.9290699E-06,   3.3850736E-06
     +,   2.9062637E-06,   2.4864764E-06,   2.1198939E-06
     +,   1.8010371E-06,   1.5247658E-06,   1.2863180E-06
     +,   1.0813228E-06,   9.0577566E-07,   7.5602344E-07
     +,   6.2876677E-07,   5.2105190E-07,   4.3022845E-07
     +,   3.5394200E-07,   2.9011747E-07,   2.3692883E-07
     +,   1.9277547E-07,   1.5626553E-07,   1.2619564E-07
     +,   1.0152883E-07,   8.1373877E-08,   6.4970820E-08
     +,   5.1675304E-08,   4.0942421E-08,   3.2312990E-08
     +,   2.5402839E-08,   1.9892397E-08,   1.5516019E-08
     +,   1.2054540E-08,   9.3281374E-09,   7.1896880E-09
     +,   5.5193223E-09,   4.2200017E-09,   3.2135743E-09
     +,   2.4373172E-09,   1.8410909E-09,   1.3850637E-09
     +,   1.0377640E-09,   7.7437445E-10,   5.7548177E-10
     +,   4.2592030E-10,   3.1394043E-10,   2.3045019E-10
     +,   1.6847074E-10,   1.2265308E-10,   8.8929475E-11
     +,   6.4211941E-11,   4.6173922E-11,   3.3065991E-11
     +,   2.3581156E-11,   1.6747725E-11,   1.1845213E-11
     +,   8.3432454E-12,   5.8522315E-12,   4.0880181E-12
     +,   2.8437819E-12,   1.9700786E-12,   1.3591360E-12
     +,   9.3377866E-13,   6.3887676E-13,   4.3530270E-13
     +,   2.9536318E-13,   1.9958300E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt90 = Yx/0.0245
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0642904E-06,   2.3252919E-06
     +,   2.6139573E-06,   2.9324679E-06,   3.2830796E-06
     +,   3.6681074E-06,   4.0899231E-06,   4.5509278E-06
     +,   5.0535382E-06,   5.6001932E-06,   6.1932919E-06
     +,   6.8351960E-06,   7.5282001E-06,   8.2745119E-06
     +,   9.0762096E-06,   9.9352383E-06,   1.0853350E-05
     +,   1.1832101E-05,   1.2872803E-05,   1.3976505E-05
     +,   1.5143952E-05,   1.6375572E-05,   1.7671415E-05
     +,   1.9031238E-05,   2.0454254E-05,   2.1939402E-05
     +,   2.3485105E-05,   2.5089366E-05,   2.6749731E-05
     +,   2.8463297E-05,   3.0226700E-05,   3.2036147E-05
     +,   3.3887412E-05,   3.5775858E-05,   3.7696464E-05
     +,   3.9643870E-05,   4.1612395E-05,   4.3596039E-05
     +,   4.5588728E-05,   4.7583966E-05,   4.9575381E-05
     +,   5.1556384E-05,   5.3520442E-05,   5.5461034E-05
     +,   5.7371817E-05,   5.9246559E-05,   6.1079321E-05
     +,   6.2864405E-05,   6.4596519E-05,   6.6270717E-05
     +,   6.7882516E-05,   6.9427922E-05,   7.0903436E-05
     +,   7.2306189E-05,   7.3633717E-05,   7.4884294E-05
     +,   7.6056713E-05,   7.7150318E-05,   7.8165111E-05
     +,   7.9101599E-05,   7.9960868E-05,   8.0744525E-05
     +,   8.1454637E-05,   8.2093771E-05,   8.2664934E-05
     +,   8.3171442E-05,   8.3617044E-05,   8.4005726E-05
     +,   8.4341795E-05,   8.4629719E-05,   8.4874257E-05
     +,   8.5080246E-05,   8.5252665E-05,   8.5396605E-05
     +,   8.5517211E-05,   8.5619715E-05,   8.5709347E-05
     +,   8.5791384E-05,   8.5871063E-05,   8.5953645E-05
     +,   8.6044383E-05,   8.6148459E-05,   8.6271022E-05
     +,   8.6417167E-05,   8.6591892E-05,   8.6800108E-05
     +,   8.7046552E-05,   8.7335815E-05,   8.7672270E-05
     +,   8.8060056E-05,   8.8502966E-05,   8.9004447E-05
     +,   8.9567460E-05,   9.0194539E-05,   9.0887574E-05
     +,   9.1647824E-05,   9.2475850E-05,   9.3371302E-05
     +,   9.4333132E-05,   9.5359173E-05,   9.6446420E-05
     +,   9.7590746E-05,   9.8787023E-05,   1.0002898E-04
     +,   1.0130937E-04,   1.0261990E-04,   1.0395121E-04
     +,   1.0529304E-04,   1.0663432E-04,   1.0796329E-04
     +,   1.0926752E-04,   1.1053422E-04,   1.1175022E-04
     +,   1.1290247E-04,   1.1397784E-04,   1.1496373E-04
     +,   1.1584800E-04,   1.1661941E-04,   1.1726768E-04
     +,   1.1778395E-04,   1.1816084E-04,   1.1839279E-04
     +,   1.1847611E-04,   1.1840953E-04,   1.1819402E-04
     +,   1.1783331E-04,   1.1733366E-04,   1.1670440E-04
     +,   1.1595763E-04,   1.1510847E-04,   1.1417483E-04
     +,   1.1317758E-04,   1.1214004E-04,   1.1108807E-04
     +,   1.1004943E-04,   1.0905355E-04,   1.0813111E-04
     +,   1.0731348E-04,   1.0663213E-04,   1.0611818E-04
     +,   1.0580203E-04,   1.0571282E-04,   1.0587829E-04
     +,   1.0632467E-04,   1.0707680E-04,   1.0815862E-04
     +,   1.0959380E-04,   1.1140676E-04,   1.1362395E-04
     +,   1.1627588E-04,   1.1939892E-04,   1.2303740E-04
     +,   1.2724605E-04,   1.3209230E-04,   1.3765742E-04
     +,   1.4403596E-04,   1.5133350E-04,   1.5966156E-04
     +,   1.6912809E-04,   1.7982269E-04,   1.9180169E-04
     +,   2.0506857E-04,   2.1955541E-04,   2.3511150E-04
     +,   2.5150337E-04,   2.6843083E-04,   2.8556702E-04
     +,   3.0263423E-04,   3.1951565E-04,   3.3640425E-04
     +,   3.5397930E-04,   3.7359502E-04,   3.9745620E-04
     +,   4.2876083E-04,   4.7183529E-04,   5.3236197E-04
     +,   6.1784091E-04,   7.3843711E-04,   9.0819201E-04
     +,   1.1461498E-03,   1.4763072E-03,   1.9248764E-03
     +,   2.5136818E-03,   3.2499034E-03,   4.1146018E-03
     +,   5.0548553E-03,   5.9849122E-03,   6.7989426E-03
     +,   7.3929885E-03,   7.6892166E-03,   7.6538748E-03
     +,   7.3025152E-03,   6.6922037E-03,   5.9050974E-03
     +,   5.0298758E-03,   4.1466430E-03,   3.3177559E-03
     +,   2.5843182E-03,   1.9670981E-03,   1.4701851E-03
     +,   1.0857413E-03,   7.9868588E-04,   5.9072219E-04
     +,   4.4340966E-04,   3.4018440E-04,   2.6744808E-04
     +,   2.1495565E-04,   1.7561382E-04,   1.4489940E-04
     +,   1.2012522E-04,   9.9747362E-05,   8.2833307E-05
     +,   6.8732406E-05,   5.6920726E-05,   4.6957226E-05
     +,   3.8485530E-05,   3.1238971E-05,   2.5033331E-05
     +,   1.9747526E-05,   1.5298609E-05,   1.1618080E-05
     +,   8.6371747E-06,   6.2800154E-06,   4.4630674E-06
     +,   3.0989149E-06,   2.1017152E-06,   1.3920833E-06
     +,   9.0043494E-07,   5.6873591E-07,   3.5077241E-07
     +,   2.1125337E-07,   1.2423997E-07,   7.1352055E-08
     +,   4.0018115E-08,   2.1921421E-08,   1.1729990E-08
     +,   6.1324550E-09,   3.1336340E-09,   1.5660624E-09
     +,   7.6618245E-10,   3.6754413E-10,   1.7334523E-10
     +,   8.0734759E-11,   3.7396426E-11,   1.7417181E-11
     +,   8.2853282E-12,   4.1040708E-12,   2.1562773E-12
     +,   1.2143313E-12,   7.3136614E-13,   4.6499848E-13
     +,   3.0688630E-13,   2.0714582E-13,   1.4149223E-13
     +,   9.7146805E-14,   6.6782415E-14,   4.5868010E-14
     +,   3.1440304E-14,   2.1495136E-14,   1.4653667E-14
     +,   9.9599530E-15,   6.7493046E-15,   4.5597634E-15
     +,   3.0711873E-15,   2.0623829E-15,   1.3808175E-15
     +,   9.2175036E-16,   6.1350316E-16,   4.0715929E-16
     +,   2.6944086E-16,   1.7779466E-16,   1.1699071E-16
     +,   7.6767900E-17,   5.0235377E-17,   3.2783060E-17
     +,   2.1336479E-17,   1.3849469E-17,   8.9661209E-18
     +,   5.7894557E-18,   3.7287085E-18,   2.3953389E-18
     +,   1.5349272E-18,   9.8111634E-19,   6.2559049E-19
     +,   3.9791888E-19,   2.5249807E-19,   1.5983911E-19
     +,   1.0094270E-19,   6.3599449E-20,   3.9977571E-20
     +,   2.5071554E-20,   1.5687167E-20,   9.7931674E-21
     +,   6.0997102E-21,   3.7907187E-21,   2.3504438E-21
     +,   1.4541464E-21,   8.9760880E-22,   5.5284074E-22
     +,   3.3972935E-22,   2.0830469E-22
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_hatt95 = Yx/0.0275483870967742
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6807770E-06,   2.8568425E-06
     +,   3.0411875E-06,   3.2339467E-06,   3.4352372E-06
     +,   3.6451565E-06,   3.8637854E-06,   4.0911805E-06
     +,   4.3273740E-06,   4.5723864E-06,   4.8262013E-06
     +,   5.0887838E-06,   5.3600693E-06,   5.6399685E-06
     +,   5.9283648E-06,   6.2251124E-06,   6.5300369E-06
     +,   6.8429367E-06,   7.1635827E-06,   7.4917152E-06
     +,   7.8270450E-06,   8.1692579E-06,   8.5180036E-06
     +,   8.8729321E-06,   9.2336195E-06,   9.5996666E-06
     +,   9.9706185E-06,   1.0346009E-05,   1.0725347E-05
     +,   1.1108124E-05,   1.1493810E-05,   1.1881861E-05
     +,   1.2271714E-05,   1.2662797E-05,   1.3054524E-05
     +,   1.3446300E-05,   1.3837523E-05,   1.4227573E-05
     +,   1.4615862E-05,   1.5001749E-05,   1.5384639E-05
     +,   1.5763912E-05,   1.6138960E-05,   1.6509181E-05
     +,   1.6873975E-05,   1.7232760E-05,   1.7584953E-05
     +,   1.7929993E-05,   1.8267327E-05,   1.8596415E-05
     +,   1.8916737E-05,   1.9227784E-05,   1.9529065E-05
     +,   1.9820129E-05,   2.0100497E-05,   2.0369762E-05
     +,   2.0627505E-05,   2.0873347E-05,   2.1106925E-05
     +,   2.1327907E-05,   2.1535980E-05,   2.1730870E-05
     +,   2.1912332E-05,   2.2080159E-05,   2.2234197E-05
     +,   2.2374314E-05,   2.2500453E-05,   2.2612610E-05
     +,   2.2710867E-05,   2.2795370E-05,   2.2866396E-05
     +,   2.2924312E-05,   2.2969647E-05,   2.3003071E-05
     +,   2.3025468E-05,   2.3037930E-05,   2.3041805E-05
     +,   2.3038740E-05,   2.3030716E-05,   2.3020089E-05
     +,   2.3009652E-05,   2.3002667E-05,   2.3002927E-05
     +,   2.3014794E-05,   2.3043251E-05,   2.3093964E-05
     +,   2.3173292E-05,   2.3288354E-05,   2.3447014E-05
     +,   2.3657945E-05,   2.3930626E-05,   2.4275305E-05
     +,   2.4703006E-05,   2.5225541E-05,   2.5855456E-05
     +,   2.6605903E-05,   2.7490818E-05,   2.8524571E-05
     +,   2.9722247E-05,   3.1099309E-05,   3.2671836E-05
     +,   3.4456240E-05,   3.6469566E-05,   3.8729111E-05
     +,   4.1252795E-05,   4.4059099E-05,   4.7166734E-05
     +,   5.0594837E-05,   5.4363085E-05,   5.8491438E-05
     +,   6.2999345E-05,   6.7906520E-05,   7.3231167E-05
     +,   7.8990743E-05,   8.5199717E-05,   9.1870221E-05
     +,   9.9009325E-05,   1.0661964E-04,   1.1469617E-04
     +,   1.2322674E-04,   1.3219006E-04,   1.4155413E-04
     +,   1.5127574E-04,   1.6130057E-04,   1.7156258E-04
     +,   1.8198324E-04,   1.9247459E-04,   2.0293797E-04
     +,   2.1326891E-04,   2.2335671E-04,   2.3309008E-04
     +,   2.4235809E-04,   2.5105572E-04,   2.5908562E-04
     +,   2.6636332E-04,   2.7281922E-04,   2.7840136E-04
     +,   2.8307774E-04,   2.8683792E-04,   2.8969313E-04
     +,   2.9167603E-04,   2.9283940E-04,   2.9325494E-04
     +,   2.9301003E-04,   2.9220473E-04,   2.9094864E-04
     +,   2.8935680E-04,   2.8754550E-04,   2.8562872E-04
     +,   2.8371316E-04,   2.8189470E-04,   2.8025394E-04
     +,   2.7885227E-04,   2.7772799E-04,   2.7689291E-04
     +,   2.7632955E-04,   2.7598962E-04,   2.7579285E-04
     +,   2.7562890E-04,   2.7536103E-04,   2.7483242E-04
     +,   2.7387642E-04,   2.7232987E-04,   2.7004952E-04
     +,   2.6693230E-04,   2.6293600E-04,   2.5810205E-04
     +,   2.5257710E-04,   2.4663398E-04,   2.4069572E-04
     +,   2.3536803E-04,   2.3148656E-04,   2.3019365E-04
     +,   2.3304932E-04,   2.4216942E-04,   2.6036488E-04
     +,   2.9121584E-04,   3.3898407E-04,   4.0826536E-04
     +,   5.0332071E-04,   6.2711455E-04,   7.8025158E-04
     +,   9.6020359E-04,   1.1612703E-03,   1.3755879E-03
     +,   1.5952151E-03,   1.8148401E-03,   2.0340942E-03
     +,   2.2582533E-03,   2.4964632E-03,   2.7575407E-03
     +,   3.0443352E-03,   3.3487112E-03,   3.6494264E-03
     +,   3.9142882E-03,   4.1064317E-03,   4.1930210E-03
     +,   4.1536130E-03,   3.9853565E-03,   3.7034664E-03
     +,   3.3371842E-03,   2.9227750E-03,   2.4959920E-03
     +,   2.0862727E-03,   1.7137959E-03,   1.3892298E-03
     +,   1.1155362E-03,   8.9047867E-04,   7.0889975E-04
     +,   5.6438590E-04,   4.5031297E-04,   3.6044055E-04
     +,   2.8925456E-04,   2.3218454E-04,   1.8570718E-04
     +,   1.4731188E-04,   1.1533805E-04,   8.8741042E-05
     +,   6.6850160E-05,   4.9167564E-05,   3.5231642E-05
     +,   2.4558472E-05,   1.6634991E-05,   1.0941414E-05
     +,   6.9841167E-06,   4.3246810E-06,   2.5970044E-06
     +,   1.5120619E-06,   8.5340298E-07,   4.6682493E-07
     +,   2.4747706E-07,   1.2714317E-07,   6.3306501E-08
     +,   3.0555842E-08,   1.4305313E-08,   6.5039560E-09
     +,   2.8790255E-09,   1.2475934E-09,   5.3528060E-10
     +,   2.3254498E-10,   1.0642438E-10,   5.4148724E-11
     +,   3.1934799E-11,   2.1748723E-11,   1.6390807E-11
     +,   1.3058478E-11,   1.0673899E-11,   8.8155152E-12
     +,   7.3060533E-12,   6.0588544E-12,   5.0219867E-12
     +,   4.1586157E-12,   3.4398769E-12,   2.8420831E-12
     +,   2.3454138E-12,   1.9332398E-12,   1.5916067E-12
     +,   1.3087999E-12,   1.0749664E-12,   8.8185741E-13
     +,   7.2258155E-13,   5.9137276E-13,   4.8341572E-13
     +,   3.9469461E-13,   3.2187629E-13,   2.6218142E-13
     +,   2.1330195E-13,   1.7332959E-13,   1.4068186E-13
     +,   1.1404777E-13,   9.2345802E-14,   7.4684697E-14
     +,   6.0330037E-14,   4.8676527E-14,   3.9227122E-14
     +,   3.1574810E-14,   2.5384962E-14,   2.0384490E-14
     +,   1.6349445E-14,   1.3097685E-14,   1.0480131E-14
     +,   8.3757997E-15,   6.6860037E-15,   5.3308243E-15
     +,   4.2452457E-15,   3.3767542E-15,   2.6827391E-15
     +,   2.1288284E-15,   1.6872858E-15,   1.3357283E-15
     +,   1.0561707E-15,   8.3412755E-16,   6.5798583E-16
     +,   5.1842143E-16,   4.0797720E-16,   3.2067887E-16
     +,   2.5176262E-16,   1.9742117E-16,   1.5462605E-16
     +,   1.2096295E-16,   9.4517224E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt100 = Yx/0.021
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1939402E-05,   1.2225990E-05
     +,   1.2512244E-05,   1.2797870E-05,   1.3082568E-05
     +,   1.3366040E-05,   1.3647987E-05,   1.3928102E-05
     +,   1.4206085E-05,   1.4481644E-05,   1.4754473E-05
     +,   1.5024276E-05,   1.5290756E-05,   1.5553624E-05
     +,   1.5812589E-05,   1.6067370E-05,   1.6317683E-05
     +,   1.6563250E-05,   1.6803810E-05,   1.7039087E-05
     +,   1.7268834E-05,   1.7492792E-05,   1.7710714E-05
     +,   1.7922373E-05,   1.8127528E-05,   1.8325962E-05
     +,   1.8517459E-05,   1.8701812E-05,   1.8878824E-05
     +,   1.9048306E-05,   1.9210076E-05,   1.9363959E-05
     +,   1.9509796E-05,   1.9647436E-05,   1.9776728E-05
     +,   1.9897538E-05,   2.0009738E-05,   2.0113217E-05
     +,   2.0207865E-05,   2.0293579E-05,   2.0370275E-05
     +,   2.0437872E-05,   2.0496302E-05,   2.0545502E-05
     +,   2.0585421E-05,   2.0616017E-05,   2.0637262E-05
     +,   2.0649130E-05,   2.0651603E-05,   2.0644686E-05
     +,   2.0628382E-05,   2.0602702E-05,   2.0567677E-05
     +,   2.0523337E-05,   2.0469732E-05,   2.0406909E-05
     +,   2.0334937E-05,   2.0253885E-05,   2.0163841E-05
     +,   2.0064897E-05,   1.9957159E-05,   1.9840736E-05
     +,   1.9715762E-05,   1.9582374E-05,   1.9440711E-05
     +,   1.9290954E-05,   1.9133260E-05,   1.8967834E-05
     +,   1.8794868E-05,   1.8614608E-05,   1.8427279E-05
     +,   1.8233175E-05,   1.8032570E-05,   1.7825814E-05
     +,   1.7613263E-05,   1.7395321E-05,   1.7172461E-05
     +,   1.6945218E-05,   1.6714181E-05,   1.6480029E-05
     +,   1.6243574E-05,   1.6005713E-05,   1.5767528E-05
     +,   1.5530239E-05,   1.5295296E-05,   1.5064369E-05
     +,   1.4839422E-05,   1.4622717E-05,   1.4416913E-05
     +,   1.4225084E-05,   1.4050773E-05,   1.3898110E-05
     +,   1.3771822E-05,   1.3677350E-05,   1.3620896E-05
     +,   1.3609539E-05,   1.3651287E-05,   1.3755181E-05
     +,   1.3931366E-05,   1.4191151E-05,   1.4547111E-05
     +,   1.5013071E-05,   1.5604239E-05,   1.6337086E-05
     +,   1.7229462E-05,   1.8300507E-05,   1.9570487E-05
     +,   2.1060705E-05,   2.2793420E-05,   2.4791585E-05
     +,   2.7078315E-05,   2.9677019E-05,   3.2610409E-05
     +,   3.5900706E-05,   3.9568349E-05,   4.3632303E-05
     +,   4.8108483E-05,   5.3010135E-05,   5.8346093E-05
     +,   6.4121115E-05,   7.0334885E-05,   7.6980890E-05
     +,   8.4046340E-05,   9.1512076E-05,   9.9351935E-05
     +,   1.0753168E-04,   1.1601074E-04,   1.2474030E-04
     +,   1.3366574E-04,   1.4272486E-04,   1.5185104E-04
     +,   1.6097164E-04,   1.7001170E-04,   1.7889259E-04
     +,   1.8753568E-04,   1.9586296E-04,   2.0379797E-04
     +,   2.1126811E-04,   2.1820659E-04,   2.2455354E-04
     +,   2.3025657E-04,   2.3527286E-04,   2.3957004E-04
     +,   2.4312631E-04,   2.4593069E-04,   2.4798341E-04
     +,   2.4929520E-04,   2.4988665E-04,   2.4978709E-04
     +,   2.4903368E-04,   2.4766949E-04,   2.4574256E-04
     +,   2.4330376E-04,   2.4040579E-04,   2.3710135E-04
     +,   2.3344255E-04,   2.2947963E-04,   2.2526049E-04
     +,   2.2083016E-04,   2.1623189E-04,   2.1150609E-04
     +,   2.0669180E-04,   2.0182726E-04,   1.9695077E-04
     +,   1.9210076E-04,   1.8731697E-04,   1.8264109E-04
     +,   1.7811677E-04,   1.7378935E-04,   1.6970623E-04
     +,   1.6591701E-04,   1.6247311E-04,   1.5942780E-04
     +,   1.5683695E-04,   1.5476032E-04,   1.5326253E-04
     +,   1.5241672E-04,   1.5230775E-04,   1.5303786E-04
     +,   1.5473380E-04,   1.5755619E-04,   1.6171146E-04
     +,   1.6746642E-04,   1.7516775E-04,   1.8526334E-04
     +,   1.9832613E-04,   2.1507937E-04,   2.3642130E-04
     +,   2.6343940E-04,   2.9740864E-04,   3.3977296E-04
     +,   3.9208960E-04,   4.5592966E-04,   5.3273991E-04
     +,   6.2366569E-04,   7.2933390E-04,   8.4961287E-04
     +,   9.8339841E-04,   1.1284519E-03,   1.2813021E-03
     +,   1.4372515E-03,   1.5905412E-03,   1.7346514E-03
     +,   1.8627109E-03,   1.9679933E-03,   2.0444931E-03
     +,   2.0874480E-03,   2.0937808E-03,   2.0624278E-03
     +,   1.9944578E-03,   1.8929974E-03,   1.7629807E-03
     +,   1.6107205E-03,   1.4433588E-03,   1.2682942E-03
     +,   1.0926331E-03,   9.2269498E-04,   7.6364313E-04
     +,   6.1928638E-04,   4.9203192E-04,   3.8293126E-04
     +,   2.9187804E-04,   2.1785713E-04,   1.5921099E-04
     +,   1.1390452E-04,   7.9765057E-05,   5.4668690E-05
     +,   3.6666865E-05,   2.4063869E-05,   1.5451218E-05
     +,   9.7057928E-06,   5.9640415E-06,   3.5846997E-06
     +,   2.1073324E-06,   1.2116500E-06,   6.8134921E-07
     +,   3.7472455E-07,   2.0158292E-07,   1.0609659E-07
     +,   5.4657392E-08,   2.7585934E-08,   1.3665038E-08
     +,   6.6673107E-09,   3.2256569E-09,   1.5669203E-09
     +,   7.8110207E-10,   4.1287937E-10,   2.4013175E-10
     +,   1.5718582E-10,   1.1496554E-10,   9.1187329E-11
     +,   7.5938707E-11,   6.4875633E-11,   5.6099896E-11
     +,   4.8765131E-11,   4.2470791E-11,   3.7004295E-11
     +,   3.2233449E-11,   2.8062585E-11,   2.4415246E-11
     +,   2.1226918E-11,   1.8441623E-11,   1.6010039E-11
     +,   1.3888749E-11,   1.2039691E-11,   1.0429092E-11
     +,   9.0272225E-12,   7.8080251E-12,   6.7485167E-12
     +,   5.8284788E-12,   5.0301174E-12,   4.3379120E-12
     +,   3.7382072E-12,   3.2190296E-12,   2.7698978E-12
     +,   2.3816756E-12,   2.0463459E-12,   1.7569363E-12
     +,   1.5073314E-12,   1.2922429E-12,   1.1070179E-12
     +,   9.4764843E-13,   8.1061628E-13,   6.9289057E-13
     +,   5.9182200E-13,   5.0512302E-13,   4.3080711E-13
     +,   3.6715176E-13,   3.1267128E-13,   2.6607706E-13
     +,   2.2626017E-13,   1.9225831E-13,   1.6324596E-13
     +,   1.3850836E-13,   1.1743341E-13,   9.9490748E-14
     +,   8.4227703E-14,   7.1253191E-14,   6.0232926E-14
     +,   5.0879152E-14,   4.2946420E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt105 = Yx/0.0129230769230769
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9214497E-09,   2.3962070E-09
     +,   2.9809928E-09,   3.6994610E-09,   4.5799151E-09
     +,   5.6561085E-09,   6.9681829E-09,   8.5637240E-09
     +,   1.0498952E-08,   1.2840218E-08,   1.5665368E-08
     +,   1.9065622E-08,   2.3147464E-08,   2.8034867E-08
     +,   3.3871629E-08,   4.0824084E-08,   4.9084075E-08
     +,   5.8871908E-08,   7.0440052E-08,   8.4076682E-08
     +,   1.0010981E-07,   1.1891122E-07,   1.4090098E-07
     +,   1.6655373E-07,   1.9639910E-07,   2.3103291E-07
     +,   2.7111722E-07,   3.1738765E-07,   3.7065814E-07
     +,   4.3182609E-07,   5.0187617E-07,   5.8188658E-07
     +,   6.7303114E-07,   7.7658399E-07,   8.9392199E-07
     +,   1.0265263E-06,   1.1759846E-06,   1.3439869E-06
     +,   1.5323395E-06,   1.7429289E-06,   1.9777626E-06
     +,   2.2389252E-06,   2.5285899E-06,   2.8490042E-06
     +,   3.2024805E-06,   3.5913799E-06,   4.0181003E-06
     +,   4.4850567E-06,   4.9946620E-06,   5.5493101E-06
     +,   6.1513465E-06,   6.8030495E-06,   7.5065968E-06
     +,   8.2640809E-06,   9.0773719E-06,   9.9482459E-06
     +,   1.0878227E-05,   1.1868616E-05,   1.2920456E-05
     +,   1.4034506E-05,   1.5211212E-05,   1.6450709E-05
     +,   1.7752687E-05,   1.9116571E-05,   2.0541404E-05
     +,   2.2025684E-05,   2.3567689E-05,   2.5165080E-05
     +,   2.6815311E-05,   2.8515200E-05,   3.0261373E-05
     +,   3.2049840E-05,   3.3876451E-05,   3.5736448E-05
     +,   3.7624908E-05,   3.9536582E-05,   4.1465821E-05
     +,   4.3406690E-05,   4.5353165E-05,   4.7299021E-05
     +,   4.9237697E-05,   5.1162780E-05,   5.3067513E-05
     +,   5.4945398E-05,   5.6789690E-05,   5.8593978E-05
     +,   6.0351733E-05,   6.2056846E-05,   6.3703206E-05
     +,   6.5285174E-05,   6.6797453E-05,   6.8235058E-05
     +,   6.9593501E-05,   7.0868904E-05,   7.2057992E-05
     +,   7.3158073E-05,   7.4167292E-05,   7.5084485E-05
     +,   7.5909447E-05,   7.6642755E-05,   7.7286037E-05
     +,   7.7841803E-05,   7.8313649E-05,   7.8706114E-05
     +,   7.9024765E-05,   7.9276135E-05,   7.9467667E-05
     +,   7.9607657E-05,   7.9705191E-05,   7.9769990E-05
     +,   7.9812286E-05,   7.9842757E-05,   7.9872247E-05
     +,   7.9911726E-05,   7.9972022E-05,   8.0063779E-05
     +,   8.0197271E-05,   8.0382306E-05,   8.0628204E-05
     +,   8.0943821E-05,   8.1337545E-05,   8.1817554E-05
     +,   8.2391882E-05,   8.3068931E-05,   8.3857733E-05
     +,   8.4768428E-05,   8.5812833E-05,   8.7004926E-05
     +,   8.8361558E-05,   8.9902802E-05,   9.1652691E-05
     +,   9.3639232E-05,   9.5895040E-05,   9.8456796E-05
     +,   1.0136551E-04,   1.0466575E-04,   1.0840445E-04
     +,   1.1262990E-04,   1.1739039E-04,   1.2273216E-04
     +,   1.2869679E-04,   1.3531896E-04,   1.4262457E-04
     +,   1.5062767E-04,   1.5932714E-04,   1.6870609E-04
     +,   1.7872904E-04,   1.8933989E-04,   2.0046170E-04
     +,   2.1199703E-04,   2.2382825E-04,   2.3581776E-04
     +,   2.4781108E-04,   2.5964083E-04,   2.7112916E-04
     +,   2.8209185E-04,   2.9234312E-04,   3.0170212E-04
     +,   3.0999616E-04,   3.1706574E-04,   3.2277018E-04
     +,   3.2699091E-04,   3.2963447E-04,   3.3063564E-04
     +,   3.2995924E-04,   3.2760057E-04,   3.2358579E-04
     +,   3.1797201E-04,   3.1084599E-04,   3.0232361E-04
     +,   2.9254999E-04,   2.8169944E-04,   2.6997540E-04
     +,   2.5761267E-04,   2.4488126E-04,   2.3208692E-04
     +,   2.1957511E-04,   2.0773376E-04,   1.9699191E-04
     +,   1.8781594E-04,   1.8070223E-04,   1.7616455E-04
     +,   1.7471447E-04,   1.7683838E-04,   1.8297300E-04
     +,   1.9348167E-04,   2.0863897E-04,   2.2863156E-04
     +,   2.5357879E-04,   2.8357815E-04,   3.1878712E-04
     +,   3.5952358E-04,   4.0638010E-04,   4.6033718E-04
     +,   5.2284700E-04,   5.9584639E-04,   6.8166584E-04
     +,   7.8281685E-04,   9.0163865E-04,   1.0397906E-03
     +,   1.1976392E-03,   1.3736353E-03,   1.5637875E-03
     +,   1.7613377E-03,   1.9567839E-03,   2.1384181E-03
     +,   2.2932780E-03,   2.4085236E-03,   2.4730470E-03
     +,   2.4790466E-03,   2.4232341E-03,   2.3075037E-03
     +,   2.1388386E-03,   1.9284763E-03,   1.6904852E-03
     +,   1.4400388E-03,   1.1916357E-03,   9.5759839E-04
     +,   7.4710237E-04,   5.6578330E-04,   4.1583096E-04
     +,   2.9656210E-04,   2.0521236E-04,   1.3776818E-04
     +,   8.9725967E-05,   5.6686920E-05,   3.4740293E-05
     +,   2.0652213E-05,   1.1908812E-05,   6.6607977E-06
     +,   3.6136469E-06,   1.9016680E-06,   9.7069903E-07
     +,   4.8060093E-07,   2.3080922E-07,   1.0751719E-07
     +,   4.8578418E-08,   2.1288946E-08,   9.0492831E-09
     +,   3.7308001E-09,   1.4917342E-09,   5.7846988E-10
     +,   2.1755456E-10,   7.9346064E-11,   2.8062415E-11
     +,   9.6245390E-12,   3.2013281E-12,   1.0328780E-12
     +,   3.2341642E-13,   9.8429443E-14,   2.9220516E-14
     +,   8.5375974E-15,   2.5091498E-15,   7.7799251E-16
     +,   2.7594862E-16,   1.2076923E-16,   6.4927405E-17
     +,   3.9777279E-17,   2.5884190E-17,   1.7225930E-17
     +,   1.1539708E-17,   7.7357716E-18,   5.1783864E-18
     +,   3.4589629E-18,   2.3049212E-18,   1.5320717E-18
     +,   1.0157523E-18,   6.7169976E-19,   4.4303483E-19
     +,   2.9144928E-19,   1.9122250E-19,   1.2513124E-19
     +,   8.1666760E-20,   5.3157828E-20,   3.4508382E-20
     +,   2.2341959E-20,   1.4426017E-20,   9.2899007E-21
     +,   5.9661872E-21,   3.8213668E-21,   2.4409492E-21
     +,   1.5550065E-21,   9.8792709E-22,   6.2595883E-22
     +,   3.9553445E-22,   2.4925834E-22,   1.5665274E-22
     +,   9.8184304E-23,   6.1372179E-23,   3.8257438E-23
     +,   2.3784092E-23,   1.4745852E-23,   9.1175668E-24
     +,   5.6221403E-24,   3.4573999E-24,   2.1203510E-24
     +,   1.2968576E-24,   7.9102421E-25,   4.8118469E-25
     +,   2.9190615E-25,   1.7660395E-25
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt107 = Yx/0.014
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.3450535E-06,   5.5580331E-06
     +,   5.7746010E-06,   5.9945214E-06,   6.2175441E-06
     +,   6.4433980E-06,   6.6717971E-06,   6.9024391E-06
     +,   7.1350000E-06,   7.3691522E-06,   7.6045435E-06
     +,   7.8408093E-06,   8.0775735E-06,   8.3144441E-06
     +,   8.5510219E-06,   8.7868948E-06,   9.0216463E-06
     +,   9.2548462E-06,   9.4860652E-06,   9.7148641E-06
     +,   9.9408044E-06,   1.0163447E-05,   1.0382350E-05
     +,   1.0597088E-05,   1.0807216E-05,   1.1012324E-05
     +,   1.1211996E-05,   1.1405832E-05,   1.1593447E-05
     +,   1.1774477E-05,   1.1948571E-05,   1.2115410E-05
     +,   1.2274695E-05,   1.2426163E-05,   1.2569575E-05
     +,   1.2704738E-05,   1.2831496E-05,   1.2949725E-05
     +,   1.3059371E-05,   1.3160409E-05,   1.3252882E-05
     +,   1.3336884E-05,   1.3412579E-05,   1.3480192E-05
     +,   1.3540023E-05,   1.3592447E-05,   1.3637916E-05
     +,   1.3676970E-05,   1.3710234E-05,   1.3738430E-05
     +,   1.3762365E-05,   1.3782958E-05,   1.3801231E-05
     +,   1.3818311E-05,   1.3835432E-05,   1.3853949E-05
     +,   1.3875336E-05,   1.3901179E-05,   1.3933191E-05
     +,   1.3973213E-05,   1.4023205E-05,   1.4085263E-05
     +,   1.4161602E-05,   1.4254570E-05,   1.4366646E-05
     +,   1.4500431E-05,   1.4658662E-05,   1.4844184E-05
     +,   1.5059986E-05,   1.5309151E-05,   1.5594900E-05
     +,   1.5920534E-05,   1.6289490E-05,   1.6705259E-05
     +,   1.7171446E-05,   1.7691735E-05,   1.8269837E-05
     +,   1.8909494E-05,   1.9614517E-05,   2.0388725E-05
     +,   2.1235830E-05,   2.2159606E-05,   2.3163622E-05
     +,   2.4251454E-05,   2.5426381E-05,   2.6691609E-05
     +,   2.8049952E-05,   2.9504065E-05,   3.1056057E-05
     +,   3.2707754E-05,   3.4460500E-05,   3.6314952E-05
     +,   3.8271151E-05,   4.0328556E-05,   4.2485874E-05
     +,   4.4740777E-05,   4.7090332E-05,   4.9530379E-05
     +,   5.2056086E-05,   5.4661254E-05,   5.7339006E-05
     +,   6.0081031E-05,   6.2878353E-05,   6.5720553E-05
     +,   6.8596586E-05,   7.1494360E-05,   7.4400814E-05
     +,   7.7302095E-05,   8.0183898E-05,   8.3031402E-05
     +,   8.5829146E-05,   8.8561836E-05,   9.1213835E-05
     +,   9.3770032E-05,   9.6215445E-05,   9.8535995E-05
     +,   1.0071821E-04,   1.0275001E-04,   1.0462050E-04
     +,   1.0632051E-04,   1.0784285E-04,   1.0918240E-04
     +,   1.1033642E-04,   1.1130503E-04,   1.1209129E-04
     +,   1.1270137E-04,   1.1314504E-04,   1.1343566E-04
     +,   1.1359052E-04,   1.1363099E-04,   1.1358264E-04
     +,   1.1347540E-04,   1.1334356E-04,   1.1322583E-04
     +,   1.1316525E-04,   1.1320911E-04,   1.1340878E-04
     +,   1.1381930E-04,   1.1449912E-04,   1.1550962E-04
     +,   1.1691431E-04,   1.1877812E-04,   1.2116645E-04
     +,   1.2414408E-04,   1.2777322E-04,   1.3211250E-04
     +,   1.3721475E-04,   1.4312439E-04,   1.4987509E-04
     +,   1.5748767E-04,   1.6596675E-04,   1.7529752E-04
     +,   1.8544318E-04,   1.9634329E-04,   2.0791142E-04
     +,   2.2003296E-04,   2.3256548E-04,   2.4534090E-04
     +,   2.5816626E-04,   2.7082677E-04,   2.8309284E-04
     +,   2.9472547E-04,   3.0548277E-04,   3.1512947E-04
     +,   3.2344638E-04,   3.3023788E-04,   3.3534068E-04
     +,   3.3863165E-04,   3.4003452E-04,   3.3952386E-04
     +,   3.3712899E-04,   3.3293554E-04,   3.2708520E-04
     +,   3.1977400E-04,   3.1125042E-04,   3.0180981E-04
     +,   2.9178872E-04,   2.8155878E-04,   2.7151691E-04
     +,   2.6207420E-04,   2.5364527E-04,   2.4663651E-04
     +,   2.4143602E-04,   2.3840627E-04,   2.3788559E-04
     +,   2.4019761E-04,   2.4567297E-04,   2.5468515E-04
     +,   2.6769860E-04,   2.8532190E-04,   3.0836638E-04
     +,   3.3789009E-04,   3.7521261E-04,   4.2189102E-04
     +,   4.7964093E-04,   5.5018294E-04,   6.3501601E-04
     +,   7.3513546E-04,   8.5072196E-04,   9.8082004E-04
     +,   1.1230641E-03,   1.2735307E-03,   1.4267557E-03
     +,   1.5759306E-03,   1.7133002E-03,   1.8307933E-03
     +,   1.9207344E-03,   1.9766127E-03,   1.9938017E-03
     +,   1.9701014E-03,   1.9060213E-03,   1.8047781E-03
     +,   1.6719812E-03,   1.5150496E-03,   1.3424653E-03
     +,   1.1629777E-03,   9.8481693E-04,   8.1504998E-04
     +,   6.5916253E-04,   5.2087143E-04,   4.0211016E-04
     +,   3.0323901E-04,   2.2336286E-04,   1.6068958E-04
     +,   1.1289469E-04,   7.7451085E-05,   5.1882555E-05
     +,   3.3933586E-05,   2.1667933E-05,   1.3506698E-05
     +,   8.2187298E-06,   4.8816428E-06,   2.8301019E-06
     +,   1.6013350E-06,   8.8430306E-07,   4.7657460E-07
     +,   2.5063585E-07,   1.2862625E-07,   6.4414586E-08
     +,   3.1476347E-08,   1.5007522E-08,   6.9817414E-09
     +,   3.1693148E-09,   1.4038785E-09,   6.0689392E-10
     +,   2.5614627E-10,   1.0564079E-10,   4.2653013E-11
     +,   1.6930572E-11,   6.6702065E-12,   2.6619978E-12
     +,   1.1196985E-12,   5.2746587E-13,   2.9398944E-13
     +,   1.9437043E-13,   1.4504020E-13,   1.1550889E-13
     +,   9.4721574E-14,   7.8584966E-14,   6.5462088E-14
     +,   5.4585588E-14,   4.5509224E-14,   3.7919192E-14
     +,   3.1570954E-14,   2.6264147E-14,   2.1831104E-14
     +,   1.8130928E-14,   1.5045167E-14,   1.2474085E-14
     +,   1.0333633E-14,   8.5531481E-15,   7.0734540E-15
     +,   5.8448424E-15,   4.8255281E-15,   3.9805775E-15
     +,   3.2808112E-15,   2.7017575E-15,   2.2230301E-15
     +,   1.8275674E-15,   1.5011916E-15,   1.2320488E-15
     +,   1.0103074E-15,   8.2776702E-16,   6.7763748E-16
     +,   5.5426268E-16,   4.5296913E-16,   3.6987253E-16
     +,   3.0176253E-16,   2.4598766E-16,   2.0034999E-16
     +,   1.6304222E-16,   1.3256857E-16,   1.0769958E-16
     +,   8.7421139E-17,   7.0901336E-17,   5.7454026E-17
     +,   4.6517921E-17,   3.7631358E-17,   3.0416847E-17
     +,   2.4564424E-17,   1.9821372E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt110 = Yx/0.0126538461538462
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5330203E-05,   1.5574795E-05
     +,   1.5820697E-05,   1.6067919E-05,   1.6316480E-05
     +,   1.6566395E-05,   1.6817683E-05,   1.7070364E-05
     +,   1.7324463E-05,   1.7580016E-05,   1.7837063E-05
     +,   1.8095645E-05,   1.8355811E-05,   1.8617633E-05
     +,   1.8881174E-05,   1.9146524E-05,   1.9413783E-05
     +,   1.9683070E-05,   1.9954510E-05,   2.0228261E-05
     +,   2.0504494E-05,   2.0783404E-05,   2.1065207E-05
     +,   2.1350157E-05,   2.1638522E-05,   2.1930606E-05
     +,   2.2226750E-05,   2.2527312E-05,   2.2832704E-05
     +,   2.3143362E-05,   2.3459765E-05,   2.3782428E-05
     +,   2.4111914E-05,   2.4448815E-05,   2.4793779E-05
     +,   2.5147496E-05,   2.5510697E-05,   2.5884159E-05
     +,   2.6268723E-05,   2.6665250E-05,   2.7074679E-05
     +,   2.7497983E-05,   2.7936196E-05,   2.8390405E-05
     +,   2.8861727E-05,   2.9351360E-05,   2.9860550E-05
     +,   3.0390571E-05,   3.0942785E-05,   3.1518575E-05
     +,   3.2119391E-05,   3.2746724E-05,   3.3402092E-05
     +,   3.4087112E-05,   3.4803339E-05,   3.5552446E-05
     +,   3.6336081E-05,   3.7155914E-05,   3.8013615E-05
     +,   3.8910854E-05,   3.9849256E-05,   4.0830433E-05
     +,   4.1855881E-05,   4.2927095E-05,   4.4045479E-05
     +,   4.5212189E-05,   4.6428409E-05,   4.7694986E-05
     +,   4.9012746E-05,   5.0382103E-05,   5.1803403E-05
     +,   5.3276563E-05,   5.4801334E-05,   5.6376990E-05
     +,   5.8002588E-05,   5.9676837E-05,   6.1397957E-05
     +,   6.3163767E-05,   6.4971849E-05,   6.6819346E-05
     +,   6.8702873E-05,   7.0618946E-05,   7.2563467E-05
     +,   7.4532320E-05,   7.6520875E-05,   7.8524557E-05
     +,   8.0538375E-05,   8.2557533E-05,   8.4576983E-05
     +,   8.6591957E-05,   8.8597852E-05,   9.0590176E-05
     +,   9.2564784E-05,   9.4518138E-05,   9.6447198E-05
     +,   9.8349308E-05,   1.0022279E-04,   1.0206651E-04
     +,   1.0388030E-04,   1.0566472E-04,   1.0742141E-04
     +,   1.0915274E-04,   1.1086228E-04,   1.1255425E-04
     +,   1.1423403E-04,   1.1590790E-04,   1.1758287E-04
     +,   1.1926673E-04,   1.2096813E-04,   1.2269641E-04
     +,   1.2446125E-04,   1.2627302E-04,   1.2814217E-04
     +,   1.3007963E-04,   1.3209606E-04,   1.3420232E-04
     +,   1.3640865E-04,   1.3872521E-04,   1.4116109E-04
     +,   1.4372477E-04,   1.4642376E-04,   1.4926409E-04
     +,   1.5225029E-04,   1.5538547E-04,   1.5867114E-04
     +,   1.6210653E-04,   1.6568946E-04,   1.6941548E-04
     +,   1.7327874E-04,   1.7727145E-04,   1.8138488E-04
     +,   1.8560899E-04,   1.8993358E-04,   1.9434787E-04
     +,   1.9884220E-04,   2.0340779E-04,   2.0803747E-04
     +,   2.1272626E-04,   2.1747228E-04,   2.2227655E-04
     +,   2.2714326E-04,   2.3207974E-04,   2.3709654E-04
     +,   2.4220666E-04,   2.4742415E-04,   2.5276377E-04
     +,   2.5823925E-04,   2.6386135E-04,   2.6963599E-04
     +,   2.7556287E-04,   2.8163311E-04,   2.8782722E-04
     +,   2.9411356E-04,   3.0044778E-04,   3.0677166E-04
     +,   3.1301286E-04,   3.1908593E-04,   3.2489424E-04
     +,   3.3033235E-04,   3.3528841E-04,   3.3964936E-04
     +,   3.4330523E-04,   3.4615415E-04,   3.4810821E-04
     +,   3.4909899E-04,   3.4908287E-04,   3.4804584E-04
     +,   3.4600735E-04,   3.4302351E-04,   3.3918818E-04
     +,   3.3463389E-04,   3.2952969E-04,   3.2407793E-04
     +,   3.1850982E-04,   3.1307986E-04,   3.0805706E-04
     +,   3.0371750E-04,   3.0033520E-04,   2.9817258E-04
     +,   2.9747086E-04,   2.9844177E-04,   3.0125931E-04
     +,   3.0605262E-04,   3.1290113E-04,   3.2183048E-04
     +,   3.3280984E-04,   3.4575188E-04,   3.6051485E-04
     +,   3.7690552E-04,   3.9468135E-04,   4.1356028E-04
     +,   4.3322489E-04,   4.5332991E-04,   4.7351027E-04
     +,   4.9339188E-04,   5.1259773E-04,   5.3075486E-04
     +,   5.4750423E-04,   5.6250812E-04,   5.7545537E-04
     +,   5.8606744E-04,   5.9410429E-04,   5.9936906E-04
     +,   6.0171069E-04,   6.0102728E-04,   5.9726823E-04
     +,   5.9043430E-04,   5.8057852E-04,   5.6780508E-04
     +,   5.5226585E-04,   5.3415750E-04,   5.1371870E-04
     +,   4.9122394E-04,   4.6697509E-04,   4.4129600E-04
     +,   4.1452664E-04,   3.8701325E-04,   3.5909883E-04
     +,   3.3111675E-04,   3.0338659E-04,   2.7620178E-04
     +,   2.4982670E-04,   2.2449443E-04,   2.0040119E-04
     +,   1.7770307E-04,   1.5651748E-04,   1.3692482E-04
     +,   1.1896880E-04,   1.0265812E-04,   8.7971435E-05
     +,   7.4862197E-05,   6.3261890E-05,   5.3083972E-05
     +,   4.4229251E-05,   3.6590933E-05,   3.0056664E-05
     +,   2.4513100E-05,   1.9848998E-05,   1.5957185E-05
     +,   1.2736219E-05,   1.0092078E-05,   7.9391339E-06
     +,   6.2003419E-06,   4.8072816E-06,   3.7001228E-06
     +,   2.8272532E-06,   2.1445953E-06,   1.6149189E-06
     +,   1.2071845E-06,   8.9581812E-07,   6.5990662E-07
     +,   4.8256396E-07,   3.5029996E-07,   2.5242983E-07
     +,   1.8057231E-07,   1.2822279E-07,   9.0382983E-08
     +,   6.3244137E-08,   4.3929905E-08,   3.0290124E-08
     +,   2.0732315E-08,   1.4086566E-08,   9.5009955E-09
     +,   6.3611174E-09,   4.2277586E-09,   2.7892957E-09
     +,   1.8267577E-09,   1.1876163E-09,   7.6645840E-10
     +,   4.9103621E-10,   3.1228181E-10,   1.9715024E-10
     +,   1.2355959E-10,   7.6874611E-11,   4.7480780E-11
     +,   2.9114235E-11,   1.7723432E-11,   1.0712284E-11
     +,   6.4287646E-12,   3.8313233E-12,   2.2678129E-12
     +,   1.3336149E-12,   7.7942926E-13,   4.5302442E-13
     +,   2.6209018E-13,   1.5114154E-13,   8.7061814E-14
     +,   5.0249460E-14,   2.9192845E-14,   1.7178136E-14
     +,   1.0322549E-14,   6.3949484E-15,   4.1233344E-15
     +,   2.7865849E-15,   1.9786743E-15,   1.4718316E-15
     +,   1.1387732E-15,   9.0830615E-16,   7.4050468E-16
     +,   6.1272394E-16,   5.1188705E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt115 = Yx/0.0102083333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3372375E-05,   1.4021442E-05
     +,   1.4687844E-05,   1.5371161E-05,   1.6070913E-05
     +,   1.6786553E-05,   1.7517461E-05,   1.8262954E-05
     +,   1.9022256E-05,   1.9794572E-05,   2.0578980E-05
     +,   2.1374504E-05,   2.2180093E-05,   2.2994622E-05
     +,   2.3816881E-05,   2.4645606E-05,   2.5479443E-05
     +,   2.6316982E-05,   2.7156730E-05,   2.7997134E-05
     +,   2.8836585E-05,   2.9673405E-05,   3.0505866E-05
     +,   3.1332238E-05,   3.2150660E-05,   3.2959331E-05
     +,   3.3756398E-05,   3.4539971E-05,   3.5308192E-05
     +,   3.6059206E-05,   3.6791185E-05,   3.7502341E-05
     +,   3.8190941E-05,   3.8855327E-05,   3.9493923E-05
     +,   4.0105271E-05,   4.0688017E-05,   4.1240964E-05
     +,   4.1763091E-05,   4.2253501E-05,   4.2711566E-05
     +,   4.3136828E-05,   4.3529060E-05,   4.3888314E-05
     +,   4.4214874E-05,   4.4509325E-05,   4.4772522E-05
     +,   4.5005640E-05,   4.5210152E-05,   4.5387849E-05
     +,   4.5540844E-05,   4.5671568E-05,   4.5782770E-05
     +,   4.5877536E-05,   4.5959230E-05,   4.6031560E-05
     +,   4.6098488E-05,   4.6164270E-05,   4.6233436E-05
     +,   4.6310750E-05,   4.6401186E-05,   4.6509940E-05
     +,   4.6642370E-05,   4.6803983E-05,   4.7000398E-05
     +,   4.7237318E-05,   4.7520502E-05,   4.7855690E-05
     +,   4.8248639E-05,   4.8704951E-05,   4.9230181E-05
     +,   4.9829643E-05,   5.0508468E-05,   5.1271410E-05
     +,   5.2122941E-05,   5.3067091E-05,   5.4107353E-05
     +,   5.5246590E-05,   5.6487119E-05,   5.7830497E-05
     +,   5.9277350E-05,   6.0827595E-05,   6.2479972E-05
     +,   6.4232401E-05,   6.6081513E-05,   6.8022986E-05
     +,   7.0051166E-05,   7.2159441E-05,   7.4339783E-05
     +,   7.6583245E-05,   7.8879828E-05,   8.1218452E-05
     +,   8.3587147E-05,   8.5973472E-05,   8.8364504E-05
     +,   9.0746733E-05,   9.3107010E-05,   9.5432079E-05
     +,   9.7709490E-05,   9.9927398E-05,   1.0207535E-04
     +,   1.0414393E-04,   1.0612592E-04,   1.0801567E-04
     +,   1.0980997E-04,   1.1150807E-04,   1.1311167E-04
     +,   1.1462508E-04,   1.1605548E-04,   1.1741268E-04
     +,   1.1870876E-04,   1.1995842E-04,   1.2117825E-04
     +,   1.2238666E-04,   1.2360323E-04,   1.2484856E-04
     +,   1.2614348E-04,   1.2750865E-04,   1.2896392E-04
     +,   1.3052787E-04,   1.3221725E-04,   1.3404613E-04
     +,   1.3602592E-04,   1.3816461E-04,   1.4046664E-04
     +,   1.4293226E-04,   1.4555796E-04,   1.4833575E-04
     +,   1.5125396E-04,   1.5429655E-04,   1.5744423E-04
     +,   1.6067410E-04,   1.6396084E-04,   1.6727639E-04
     +,   1.7059140E-04,   1.7387554E-04,   1.7709787E-04
     +,   1.8022794E-04,   1.8323644E-04,   1.8609580E-04
     +,   1.8878047E-04,   1.9126787E-04,   1.9353870E-04
     +,   1.9557728E-04,   1.9737160E-04,   1.9891374E-04
     +,   2.0019988E-04,   2.0122989E-04,   2.0200753E-04
     +,   2.0254005E-04,   2.0283784E-04,   2.0291405E-04
     +,   2.0278414E-04,   2.0246553E-04,   2.0197681E-04
     +,   2.0133771E-04,   2.0056838E-04,   1.9968899E-04
     +,   1.9871953E-04,   1.9767921E-04,   1.9658665E-04
     +,   1.9545906E-04,   1.9431264E-04,   1.9316214E-04
     +,   1.9202079E-04,   1.9090025E-04,   1.8981071E-04
     +,   1.8876069E-04,   1.8775687E-04,   1.8680438E-04
     +,   1.8590642E-04,   1.8506449E-04,   1.8427799E-04
     +,   1.8354450E-04,   1.8285951E-04,   1.8221645E-04
     +,   1.8160652E-04,   1.8101909E-04,   1.8044136E-04
     +,   1.7985870E-04,   1.7925473E-04,   1.7861156E-04
     +,   1.7791016E-04,   1.7713053E-04,   1.7625213E-04
     +,   1.7525452E-04,   1.7411754E-04,   1.7282186E-04
     +,   1.7134924E-04,   1.6968355E-04,   1.6781049E-04
     +,   1.6571826E-04,   1.6339790E-04,   1.6084348E-04
     +,   1.5805224E-04,   1.5502441E-04,   1.5176384E-04
     +,   1.4827742E-04,   1.4457497E-04,   1.4066900E-04
     +,   1.3657488E-04,   1.3231016E-04,   1.2789408E-04
     +,   1.2334727E-04,   1.1869200E-04,   1.1395086E-04
     +,   1.0914675E-04,   1.0430297E-04,   9.9442448E-05
     +,   9.4587267E-05,   8.9758607E-05,   8.4976877E-05
     +,   8.0261234E-05,   7.5629083E-05,   7.1096292E-05
     +,   6.6677472E-05,   6.2385516E-05,   5.8231388E-05
     +,   5.4224412E-05,   5.0372659E-05,   4.6682246E-05
     +,   4.3157779E-05,   3.9802671E-05,   3.6618952E-05
     +,   3.3607186E-05,   3.0766802E-05,   2.8096343E-05
     +,   2.5593377E-05,   2.3254435E-05,   2.1075326E-05
     +,   1.9051329E-05,   1.7177144E-05,   1.5446876E-05
     +,   1.3854265E-05,   1.2392909E-05,   1.1056028E-05
     +,   9.8367182E-06,   8.7280896E-06,   7.7232298E-06
     +,   6.8152094E-06,   5.9972144E-06,   5.2626415E-06
     +,   4.6050650E-06,   4.0182417E-06,   3.4961909E-06
     +,   3.0332474E-06,   2.6240332E-06,   2.2634506E-06
     +,   1.9467234E-06,   1.6694261E-06,   1.4274207E-06
     +,   1.2168877E-06,   1.0343309E-06,   8.7654854E-07
     +,   7.4061552E-07,   6.2388204E-07,   5.2396530E-07
     +,   4.3872370E-07,   3.6623612E-07,   3.0479370E-07
     +,   2.5288551E-07,   2.0917685E-07,   1.7249187E-07
     +,   1.4180192E-07,   1.1621344E-07,   9.4947758E-08
     +,   7.7332288E-08,   6.2789113E-08,   5.0822347E-08
     +,   4.1007745E-08,   3.2984634E-08,   2.6447951E-08
     +,   2.1140112E-08,   1.6844242E-08,   1.3378831E-08
     +,   1.0592817E-08,   8.3603107E-09,   6.5774088E-09
     +,   5.1582094E-09,   4.0323647E-09,   3.1421608E-09
     +,   2.4406681E-09,   1.8896973E-09,   1.4584233E-09
     +,   1.1219481E-09,   8.6033303E-10,   6.5759570E-10
     +,   5.0100668E-10,   3.8047554E-10,   2.8800431E-10
     +,   2.1730349E-10,   1.6342583E-10,   1.2250861E-10
     +,   9.1536750E-11,   6.8173231E-11,   5.0607227E-11
     +,   3.7445404E-11,   2.7616074E-11,   2.0300648E-11
     +,   1.4874197E-11,   1.0862746E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt120 = Yx/0.00552631578947368
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0126379E-04,   1.0478989E-04
     +,   1.0841806E-04,   1.1214401E-04,   1.1596313E-04
     +,   1.1987059E-04,   1.2386173E-04,   1.2793249E-04
     +,   1.3207973E-04,   1.3630187E-04,   1.4059935E-04
     +,   1.4497535E-04,   1.4943638E-04,   1.5399310E-04
     +,   1.5866091E-04,   1.6346085E-04,   1.6842021E-04
     +,   1.7357292E-04,   1.7896043E-04,   1.8463182E-04
     +,   1.9064375E-04,   1.9706070E-04,   2.0395394E-04
     +,   2.1140151E-04,   2.1948545E-04,   2.2829177E-04
     +,   2.3790679E-04,   2.4841476E-04,   2.5989470E-04
     +,   2.7241648E-04,   2.8603655E-04,   3.0079405E-04
     +,   3.1670596E-04,   3.3376293E-04,   3.5192576E-04
     +,   3.7112177E-04,   3.9124305E-04,   4.1214458E-04
     +,   4.3364719E-04,   4.5553502E-04,   4.7756569E-04
     +,   4.9947156E-04,   5.2096893E-04,   5.4176821E-04
     +,   5.6158390E-04,   5.8014563E-04,   5.9721025E-04
     +,   6.1257312E-04,   6.2607793E-04,   6.3762465E-04
     +,   6.4717629E-04,   6.5476063E-04,   6.6047098E-04
     +,   6.6446175E-04,   6.6694198E-04,   6.6816539E-04
     +,   6.6841865E-04,   6.6800730E-04,   6.6724228E-04
     +,   6.6642527E-04,   6.6583551E-04,   6.6571910E-04
     +,   6.6627905E-04,   6.6767150E-04,   6.7000027E-04
     +,   6.7331863E-04,   6.7763071E-04,   6.8289705E-04
     +,   6.8904128E-04,   6.9595809E-04,   7.0352084E-04
     +,   7.1159098E-04,   7.2002609E-04,   7.2868564E-04
     +,   7.3744036E-04,   7.4617448E-04,   7.5479021E-04
     +,   7.6321093E-04,   7.7138294E-04,   7.7927386E-04
     +,   7.8687235E-04,   7.9418696E-04,   8.0124167E-04
     +,   8.0807577E-04,   8.1473618E-04,   8.2127890E-04
     +,   8.2776247E-04,   8.3424657E-04,   8.4078882E-04
     +,   8.4744295E-04,   8.5425767E-04,   8.6127117E-04
     +,   8.6851156E-04,   8.7599200E-04,   8.8370644E-04
     +,   8.9162565E-04,   8.9969218E-04,   9.0781535E-04
     +,   9.1587030E-04,   9.2369539E-04,   9.3109562E-04
     +,   9.3784905E-04,   9.4371458E-04,   9.4844738E-04
     +,   9.5181202E-04,   9.5360115E-04,   9.5365325E-04
     +,   9.5186452E-04,   9.4820425E-04,   9.4271853E-04
     +,   9.3553402E-04,   9.2684902E-04,   9.1692677E-04
     +,   9.0607506E-04,   8.9463068E-04,   8.8293344E-04
     +,   8.7130698E-04,   8.6003583E-04,   8.4934884E-04
     +,   8.3940395E-04,   8.3027838E-04,   8.2196743E-04
     +,   8.1438239E-04,   8.0735883E-04,   8.0066564E-04
     +,   7.9402170E-04,   7.8710978E-04,   7.7959732E-04
     +,   7.7115401E-04,   7.6147122E-04,   7.5027731E-04
     +,   7.3735416E-04,   7.2254456E-04,   7.0576475E-04
     +,   6.8700168E-04,   6.6631538E-04,   6.4383552E-04
     +,   6.1975181E-04,   5.9430237E-04,   5.6776340E-04
     +,   5.4043665E-04,   5.1263557E-04,   4.8467104E-04
     +,   4.5684061E-04,   4.2942367E-04,   4.0266692E-04
     +,   3.7678325E-04,   3.5194997E-04,   3.2830602E-04
     +,   3.0595140E-04,   2.8495115E-04,   2.6533994E-04
     +,   2.4712452E-04,   2.3028685E-04,   2.1479043E-04
     +,   2.0058519E-04,   1.8760999E-04,   1.7579629E-04
     +,   1.6507138E-04,   1.5536210E-04,   1.4659474E-04
     +,   1.3869740E-04,   1.3160167E-04,   1.2524227E-04
     +,   1.1955731E-04,   1.1448883E-04,   1.0998292E-04
     +,   1.0598908E-04,   1.0245985E-04,   9.9350982E-05
     +,   9.6621021E-05,   9.4231124E-05,   9.2144517E-05
     +,   9.0326779E-05,   8.8745554E-05,   8.7370296E-05
     +,   8.6172447E-05,   8.5125248E-05,   8.4203755E-05
     +,   8.3384766E-05,   8.2646831E-05,   8.1970335E-05
     +,   8.1337261E-05,   8.0731312E-05,   8.0137848E-05
     +,   7.9543846E-05,   7.8937854E-05,   7.8309844E-05
     +,   7.7651282E-05,   7.6955053E-05,   7.6215256E-05
     +,   7.5427233E-05,   7.4587522E-05,   7.3693729E-05
     +,   7.2744391E-05,   7.1738934E-05,   7.0677655E-05
     +,   6.9561655E-05,   6.8392561E-05,   6.7172550E-05
     +,   6.5904445E-05,   6.4591426E-05,   6.3236956E-05
     +,   6.1844767E-05,   6.0418955E-05,   5.8963615E-05
     +,   5.7482899E-05,   5.5981156E-05,   5.4462675E-05
     +,   5.2931617E-05,   5.1392057E-05,   4.9848051E-05
     +,   4.8303486E-05,   4.6762012E-05,   4.5227047E-05
     +,   4.3701948E-05,   4.2189818E-05,   4.0693456E-05
     +,   3.9215454E-05,   3.7758276E-05,   3.6324058E-05
     +,   3.4914690E-05,   3.3531953E-05,   3.2177413E-05
     +,   3.0852341E-05,   2.9557827E-05,   2.8294857E-05
     +,   2.7064254E-05,   2.5866593E-05,   2.4702313E-05
     +,   2.3571787E-05,   2.2475268E-05,   2.1412810E-05
     +,   2.0384379E-05,   1.9389943E-05,   1.8429282E-05
     +,   1.7502105E-05,   1.6608123E-05,   1.5746971E-05
     +,   1.4918182E-05,   1.4121239E-05,   1.3355645E-05
     +,   1.2620862E-05,   1.1916265E-05,   1.1241206E-05
     +,   1.0595067E-05,   9.9772033E-06,   9.3869048E-06
     +,   8.8234601E-06,   8.2861943E-06,   7.7743698E-06
     +,   7.2872435E-06,   6.8240997E-06,   6.3842162E-06
     +,   5.9668350E-06,   5.5712044E-06,   5.1965962E-06
     +,   4.8422830E-06,   4.5075139E-06,   4.1915487E-06
     +,   3.8936687E-06,   3.6131637E-06,   3.3493113E-06
     +,   3.1013985E-06,   2.8687480E-06,   2.6506684E-06
     +,   2.4464816E-06,   2.2555378E-06,   2.0771975E-06
     +,   1.9108256E-06,   1.7558033E-06,   1.6115390E-06
     +,   1.4774564E-06,   1.3529876E-06,   1.2375845E-06
     +,   1.1307279E-06,   1.0319036E-06,   9.4062977E-07
     +,   8.5643160E-07,   7.7886426E-07,   7.0749280E-07
     +,   6.4191107E-07,   5.8172265E-07,   5.2655935E-07
     +,   4.7606343E-07,   4.2990291E-07,   3.8775880E-07
     +,   3.4933038E-07,   3.1433783E-07,   2.8251327E-07
     +,   2.5360958E-07,   2.2739086E-07,   2.0364031E-07
     +,   1.8215219E-07,   1.6273745E-07,   1.4521778E-07
     +,   1.2942976E-07,   1.1521978E-07,   1.0244751E-07
     +,   9.0981665E-08,   8.0702691E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt60 = Yx/0.0233333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.3177292E-05,   8.9633271E-05
     +,   9.6484735E-05,   1.0373685E-04,   1.1139269E-04
     +,   1.1945312E-04,   1.2791676E-04,   1.3677990E-04
     +,   1.4603643E-04,   1.5567844E-04,   1.6569525E-04
     +,   1.7607420E-04,   1.8680040E-04,   1.9785667E-04
     +,   2.0922348E-04,   2.2087882E-04,   2.3279783E-04
     +,   2.4495262E-04,   2.5731162E-04,   2.6983922E-04
     +,   2.8249525E-04,   2.9523423E-04,   3.0800502E-04
     +,   3.2075090E-04,   3.3340763E-04,   3.4590601E-04
     +,   3.5816978E-04,   3.7011778E-04,   3.8166426E-04
     +,   3.9272101E-04,   4.0319847E-04,   4.1300885E-04
     +,   4.2206841E-04,   4.3030045E-04,   4.3763837E-04
     +,   4.4402856E-04,   4.4943395E-04,   4.5383521E-04
     +,   4.5723401E-04,   4.5965367E-04,   4.6113925E-04
     +,   4.6175817E-04,   4.6159769E-04,   4.6076303E-04
     +,   4.5937390E-04,   4.5756102E-04,   4.5546092E-04
     +,   4.5321163E-04,   4.5094723E-04,   4.4879326E-04
     +,   4.4686277E-04,   4.4525205E-04,   4.4403807E-04
     +,   4.4327721E-04,   4.4300384E-04,   4.4323114E-04
     +,   4.4395274E-04,   4.4514443E-04,   4.4676691E-04
     +,   4.4877076E-04,   4.5109761E-04,   4.5368550E-04
     +,   4.5647044E-04,   4.5939031E-04,   4.6238597E-04
     +,   4.6540206E-04,   4.6838829E-04,   4.7129803E-04
     +,   4.7408880E-04,   4.7671975E-04,   4.7915115E-04
     +,   4.8134301E-04,   4.8325426E-04,   4.8484231E-04
     +,   4.8606435E-04,   4.8687763E-04,   4.8724207E-04
     +,   4.8712449E-04,   4.8650059E-04,   4.8536118E-04
     +,   4.8371553E-04,   4.8159788E-04,   4.7906974E-04
     +,   4.7622545E-04,   4.7319359E-04,   4.7013891E-04
     +,   4.6726133E-04,   4.6479257E-04,   4.6299244E-04
     +,   4.6214034E-04,   4.6252561E-04,   4.6443657E-04
     +,   4.6814649E-04,   4.7389962E-04,   4.8189546E-04
     +,   4.9227523E-04,   5.0510920E-04,   5.2038446E-04
     +,   5.3800188E-04,   5.5776804E-04,   5.7940354E-04
     +,   6.0254475E-04,   6.2676193E-04,   6.5157033E-04
     +,   6.7645760E-04,   7.0090342E-04,   7.2440313E-04
     +,   7.4649270E-04,   7.6677103E-04,   7.8491360E-04
     +,   8.0068473E-04,   8.1394368E-04,   8.2463981E-04
     +,   8.3280919E-04,   8.3855662E-04,   8.4204180E-04
     +,   8.4345829E-04,   8.4301364E-04,   8.4091240E-04
     +,   8.3733926E-04,   8.3244813E-04,   8.2635757E-04
     +,   8.1914786E-04,   8.1086514E-04,   8.0152915E-04
     +,   7.9114275E-04,   7.7970291E-04,   7.6721300E-04
     +,   7.5369008E-04,   7.3917606E-04,   7.2373747E-04
     +,   7.0747326E-04,   6.9050590E-04,   6.7298405E-04
     +,   6.5507158E-04,   6.3694181E-04,   6.1877054E-04
     +,   6.0072774E-04,   5.8296899E-04,   5.6563091E-04
     +,   5.4882834E-04,   5.3264946E-04,   5.1715499E-04
     +,   5.0237839E-04,   4.8832939E-04,   4.7499294E-04
     +,   4.6233425E-04,   4.5030256E-04,   4.3883480E-04
     +,   4.2785774E-04,   4.1729384E-04,   4.0706404E-04
     +,   3.9709138E-04,   3.8730231E-04,   3.7763061E-04
     +,   3.6801849E-04,   3.5841891E-04,   3.4879422E-04
     +,   3.3911760E-04,   3.2937378E-04,   3.1955645E-04
     +,   3.0966802E-04,   2.9971916E-04,   2.8972683E-04
     +,   2.7971211E-04,   2.6969923E-04,   2.5971502E-04
     +,   2.4978691E-04,   2.3994136E-04,   2.3020354E-04
     +,   2.2059743E-04,   2.1114454E-04,   2.0186344E-04
     +,   1.9276977E-04,   1.8387797E-04,   1.7519892E-04
     +,   1.6674153E-04,   1.5851356E-04,   1.5052123E-04
     +,   1.4276901E-04,   1.3526063E-04,   1.2799949E-04
     +,   1.2098862E-04,   1.1423006E-04,   1.0772562E-04
     +,   1.0147721E-04,   9.5486350E-05,   8.9753768E-05
     +,   8.4279782E-05,   7.9064594E-05,   7.4107164E-05
     +,   6.9405796E-05,   6.4958207E-05,   6.0761195E-05
     +,   5.6810324E-05,   5.3100270E-05,   4.9625054E-05
     +,   4.6377754E-05,   4.3350436E-05,   4.0534502E-05
     +,   3.7920880E-05,   3.5499976E-05,   3.3261666E-05
     +,   3.1195526E-05,   2.9291223E-05,   2.7538157E-05
     +,   2.5925825E-05,   2.4443987E-05,   2.3082637E-05
     +,   2.1832006E-05,   2.0682723E-05,   1.9625924E-05
     +,   1.8653214E-05,   1.7756642E-05,   1.6928760E-05
     +,   1.6162718E-05,   1.5452179E-05,   1.4791279E-05
     +,   1.4174660E-05,   1.3597511E-05,   1.3055425E-05
     +,   1.2544456E-05,   1.2061094E-05,   1.1602214E-05
     +,   1.1165042E-05,   1.0747120E-05,   1.0346334E-05
     +,   9.9608606E-06,   9.5890900E-06,   9.2296541E-06
     +,   8.8814149E-06,   8.5434149E-06,   8.2148408E-06
     +,   7.8950297E-06,   7.5834682E-06,   7.2797288E-06
     +,   6.9834746E-06,   6.6944713E-06,   6.4125497E-06
     +,   6.1375772E-06,   5.8694700E-06,   5.6081963E-06
     +,   5.3537506E-06,   5.1061329E-06,   4.8653546E-06
     +,   4.6314526E-06,   4.4044682E-06,   4.1844237E-06
     +,   3.9713395E-06,   3.7652514E-06,   3.5661619E-06
     +,   3.3740657E-06,   3.1889572E-06,   3.0108158E-06
     +,   2.8395973E-06,   2.6752430E-06,   2.5176898E-06
     +,   2.3668640E-06,   2.2226648E-06,   2.0849802E-06
     +,   1.9536965E-06,   1.8286880E-06,   1.7098089E-06
     +,   1.5969069E-06,   1.4898302E-06,   1.3884109E-06
     +,   1.2924735E-06,   1.2018446E-06,   1.1163460E-06
     +,   1.0357907E-06,   9.5998917E-07,   8.8875720E-07
     +,   8.2190735E-07,   7.5924993E-07,   7.0059554E-07
     +,   6.4576267E-07,   5.9456471E-07,   5.4682454E-07
     +,   5.0236281E-07,   4.6100945E-07,   4.2259313E-07
     +,   3.8695268E-07,   3.5392688E-07,   3.2336416E-07
     +,   2.9511455E-07,   2.6903709E-07,   2.4499386E-07
     +,   2.2285283E-07,   2.0249028E-07,   1.8378518E-07
     +,   1.6662464E-07,   1.5089968E-07,   1.3650869E-07
     +,   1.2335367E-07,   1.1134408E-07,   1.0039260E-07
     +,   9.0418993E-08,   8.1346194E-08,   7.3103479E-08
     +,   6.5623404E-08,   5.8844019E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt65 = Yx/0.0200344827586207
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4396591E-05,   1.5021735E-05
     +,   1.5686033E-05,   1.6394462E-05,   1.7152612E-05
     +,   1.7966775E-05,   1.8844008E-05,   1.9792169E-05
     +,   2.0819998E-05,   2.1937234E-05,   2.3154565E-05
     +,   2.4483748E-05,   2.5937665E-05,   2.7530292E-05
     +,   2.9276760E-05,   3.1193318E-05,   3.3297289E-05
     +,   3.5607009E-05,   3.8141727E-05,   4.0921444E-05
     +,   4.3966702E-05,   4.7298403E-05,   5.0937426E-05
     +,   5.4904594E-05,   5.9219685E-05,   6.3901767E-05
     +,   6.8968169E-05,   7.4434225E-05,   8.0312733E-05
     +,   8.6613356E-05,   9.3342191E-05,   1.0050114E-04
     +,   1.0808753E-04,   1.1609346E-04,   1.2450565E-04
     +,   1.3330493E-04,   1.4246609E-04,   1.5195773E-04
     +,   1.6174284E-04,   1.7177757E-04,   1.8201345E-04
     +,   1.9239663E-04,   2.0286904E-04,   2.1336938E-04
     +,   2.2383430E-04,   2.3419964E-04,   2.4440212E-04
     +,   2.5438092E-04,   2.6407966E-04,   2.7344821E-04
     +,   2.8244453E-04,   2.9103676E-04,   2.9920461E-04
     +,   3.0694163E-04,   3.1425472E-04,   3.2116679E-04
     +,   3.2771530E-04,   3.3395240E-04,   3.3994357E-04
     +,   3.4576538E-04,   3.5150308E-04,   3.5724661E-04
     +,   3.6308658E-04,   3.6910968E-04,   3.7539445E-04
     +,   3.8200448E-04,   3.8898617E-04,   3.9636268E-04
     +,   4.0413291E-04,   4.1226749E-04,   4.2071080E-04
     +,   4.2937993E-04,   4.3817074E-04,   4.4695978E-04
     +,   4.5561293E-04,   4.6399250E-04,   4.7196422E-04
     +,   4.7940726E-04,   4.8622253E-04,   4.9233885E-04
     +,   4.9771846E-04,   5.0236180E-04,   5.0630677E-04
     +,   5.0962891E-04,   5.1243592E-04,   5.1486277E-04
     +,   5.1706278E-04,   5.1919936E-04,   5.2143598E-04
     +,   5.2392826E-04,   5.2681466E-04,   5.3021213E-04
     +,   5.3421012E-04,   5.3886994E-04,   5.4422492E-04
     +,   5.5028230E-04,   5.5702735E-04,   5.6442840E-04
     +,   5.7244243E-04,   5.8102008E-04,   5.9011159E-04
     +,   5.9966953E-04,   6.0965377E-04,   6.2003144E-04
     +,   6.3077966E-04,   6.4188312E-04,   6.5333280E-04
     +,   6.6512125E-04,   6.7724020E-04,   6.8967254E-04
     +,   7.0238434E-04,   7.1531936E-04,   7.2838797E-04
     +,   7.4146135E-04,   7.5436255E-04,   7.6686556E-04
     +,   7.7869132E-04,   7.8951486E-04,   7.9897163E-04
     +,   8.0667378E-04,   8.1222982E-04,   8.1526610E-04
     +,   8.1545551E-04,   8.1254297E-04,   8.0636988E-04
     +,   7.9689664E-04,   7.8421552E-04,   7.6855836E-04
     +,   7.5029227E-04,   7.2991080E-04,   7.0800883E-04
     +,   6.8525987E-04,   6.6237786E-04,   6.4008561E-04
     +,   6.1907317E-04,   5.9996563E-04,   5.8329536E-04
     +,   5.6947424E-04,   5.5877847E-04,   5.5133970E-04
     +,   5.4714561E-04,   5.4604496E-04,   5.4776104E-04
     +,   5.5191113E-04,   5.5802753E-04,   5.6558353E-04
     +,   5.7401898E-04,   5.8276532E-04,   5.9127022E-04
     +,   5.9901964E-04,   6.0555508E-04,   6.1048853E-04
     +,   6.1351311E-04,   6.1440788E-04,   6.1304087E-04
     +,   6.0936488E-04,   6.0341338E-04,   5.9529120E-04
     +,   5.8516295E-04,   5.7324331E-04,   5.5978238E-04
     +,   5.4505328E-04,   5.2934320E-04,   5.1294069E-04
     +,   4.9612625E-04,   4.7916610E-04,   4.6230707E-04
     +,   4.4577214E-04,   4.2975615E-04,   4.1442498E-04
     +,   3.9991603E-04,   3.8633653E-04,   3.7376353E-04
     +,   3.6224475E-04,   3.5180105E-04,   3.4242505E-04
     +,   3.3408389E-04,   3.2672117E-04,   3.2025913E-04
     +,   3.1459981E-04,   3.0962942E-04,   3.0522162E-04
     +,   3.0124100E-04,   2.9754674E-04,   2.9399715E-04
     +,   2.9045413E-04,   2.8678653E-04,   2.8287384E-04
     +,   2.7860960E-04,   2.7390418E-04,   2.6868610E-04
     +,   2.6290354E-04,   2.5652524E-04,   2.4954032E-04
     +,   2.4195643E-04,   2.3379931E-04,   2.2511098E-04
     +,   2.1594731E-04,   2.0637509E-04,   1.9646935E-04
     +,   1.8631210E-04,   1.7598846E-04,   1.6558390E-04
     +,   1.5518251E-04,   1.4486598E-04,   1.3470992E-04
     +,   1.2478347E-04,   1.1514898E-04,   1.0586043E-04
     +,   9.6962518E-05,   8.8491208E-05,   8.0474274E-05
     +,   7.2930961E-05,   6.5872206E-05,   5.9301638E-05
     +,   5.3216885E-05,   4.7609763E-05,   4.2466836E-05
     +,   3.7770740E-05,   3.3501343E-05,   2.9635637E-05
     +,   2.6149002E-05,   2.3016031E-05,   2.0210822E-05
     +,   1.7707356E-05,   1.5480115E-05,   1.3504555E-05
     +,   1.1757175E-05,   1.0215618E-05,   8.8589613E-06
     +,   7.6678562E-06,   6.6244365E-06,   5.7122820E-06
     +,   4.9164564E-06,   4.2235156E-06,   3.6212753E-06
     +,   3.0988165E-06,   2.6464213E-06,   2.2554289E-06
     +,   1.9181255E-06,   1.6276845E-06,   1.3780958E-06
     +,   1.1640558E-06,   9.8088185E-07,   8.2446252E-07
     +,   6.9119972E-07,   5.7794102E-07,   4.8191873E-07
     +,   4.0071808E-07,   3.3224032E-07,   2.7465100E-07
     +,   2.2635696E-07,   1.8597967E-07,   1.5232571E-07
     +,   1.2436264E-07,   1.0120248E-07,   8.2083972E-08
     +,   6.6355327E-08,   5.3459182E-08,   4.2921922E-08
     +,   3.4342740E-08,   2.7382853E-08,   2.1756822E-08
     +,   1.7225474E-08,   1.3589463E-08,   1.0682582E-08
     +,   8.3672393E-09,   6.5300347E-09,   5.0777804E-09
     +,   3.9341228E-09,   3.0368867E-09,   2.3356899E-09
     +,   1.7898114E-09,   1.3664624E-09,   1.0393907E-09
     +,   7.8769208E-10,   5.9473015E-10,   4.4737819E-10
     +,   3.3528266E-10,   2.5034294E-10,   1.8622519E-10
     +,   1.3801500E-10,   1.0190363E-10,   7.4961280E-11
     +,   5.4936056E-11,   4.0110713E-11,   2.9176932E-11
     +,   2.1144161E-11,   1.5265872E-11,   1.0980544E-11
     +,   7.8687386E-12,   5.6176721E-12,   3.9956424E-12
     +,   2.8313027E-12,   1.9987777E-12,   1.4057616E-12
     +,   9.8500190E-13,   6.8759148E-13,   4.7819420E-13
     +,   3.3131668E-13,   2.2869773E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt70 = Yx/0.0193103448275862
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2480285E-05,   5.4102780E-05
     +,   5.5751381E-05,   5.7424371E-05,   5.9119891E-05
     +,   6.0835893E-05,   6.2570245E-05,   6.4320615E-05
     +,   6.6084547E-05,   6.7859517E-05,   6.9642832E-05
     +,   7.1431707E-05,   7.3223266E-05,   7.5014599E-05
     +,   7.6802731E-05,   7.8584693E-05,   8.0357553E-05
     +,   8.2118371E-05,   8.3864405E-05,   8.5593005E-05
     +,   8.7301727E-05,   8.8988418E-05,   9.0651207E-05
     +,   9.2288719E-05,   9.3899878E-05,   9.5484364E-05
     +,   9.7042284E-05,   9.8574608E-05,   1.0008300E-04
     +,   1.0157003E-04,   1.0303916E-04,   1.0449495E-04
     +,   1.0594297E-04,   1.0738986E-04,   1.0884351E-04
     +,   1.1031286E-04,   1.1180813E-04,   1.1334053E-04
     +,   1.1492262E-04,   1.1656772E-04,   1.1829038E-04
     +,   1.2010593E-04,   1.2203061E-04,   1.2408127E-04
     +,   1.2627551E-04,   1.2863145E-04,   1.3116770E-04
     +,   1.3390339E-04,   1.3685811E-04,   1.4005192E-04
     +,   1.4350549E-04,   1.4724012E-04,   1.5127780E-04
     +,   1.5564174E-04,   1.6035566E-04,   1.6544502E-04
     +,   1.7093599E-04,   1.7685611E-04,   1.8323383E-04
     +,   1.9009822E-04,   1.9747854E-04,   2.0540350E-04
     +,   2.1389966E-04,   2.2299145E-04,   2.3269885E-04
     +,   2.4303480E-04,   2.5400531E-04,   2.6560485E-04
     +,   2.7781675E-04,   2.9060812E-04,   3.0393116E-04
     +,   3.1771790E-04,   3.3188277E-04,   3.4631795E-04
     +,   3.6089690E-04,   3.7547399E-04,   3.8988524E-04
     +,   4.0395249E-04,   4.1748778E-04,   4.3029743E-04
     +,   4.4218672E-04,   4.5296873E-04,   4.6246822E-04
     +,   4.7053106E-04,   4.7702881E-04,   4.8186729E-04
     +,   4.8498966E-04,   4.8638295E-04,   4.8607966E-04
     +,   4.8415977E-04,   4.8075127E-04,   4.7602720E-04
     +,   4.7020303E-04,   4.6353129E-04,   4.5629422E-04
     +,   4.4879876E-04,   4.4136506E-04,   4.3432033E-04
     +,   4.2798830E-04,   4.2268125E-04,   4.1869152E-04
     +,   4.1628367E-04,   4.1568821E-04,   4.1709535E-04
     +,   4.2065061E-04,   4.2645153E-04,   4.3454461E-04
     +,   4.4492350E-04,   4.5753049E-04,   4.7225587E-04
     +,   4.8893807E-04,   5.0737092E-04,   5.2730233E-04
     +,   5.4844422E-04,   5.7047408E-04,   5.9304718E-04
     +,   6.1579928E-04,   6.3836301E-04,   6.6037028E-04
     +,   6.8146863E-04,   7.0133107E-04,   7.1966206E-04
     +,   7.3621073E-04,   7.5077970E-04,   7.6322933E-04
     +,   7.7348220E-04,   7.8152551E-04,   7.8741094E-04
     +,   7.9125044E-04,   7.9320901E-04,   7.9349749E-04
     +,   7.9236098E-04,   7.9006603E-04,   7.8688824E-04
     +,   7.8309671E-04,   7.7894155E-04,   7.7464298E-04
     +,   7.7037979E-04,   7.6628343E-04,   7.6243293E-04
     +,   7.5885636E-04,   7.5553200E-04,   7.5239735E-04
     +,   7.4935582E-04,   7.4629008E-04,   7.4307329E-04
     +,   7.3958118E-04,   7.3570391E-04,   7.3135534E-04
     +,   7.2647660E-04,   7.2104041E-04,   7.1505021E-04
     +,   7.0853543E-04,   7.0154411E-04,   6.9413421E-04
     +,   6.8636448E-04,   6.7828537E-04,   6.6992932E-04
     +,   6.6130602E-04,   6.5240072E-04,   6.4317125E-04
     +,   6.3355302E-04,   6.2346517E-04,   6.1281677E-04
     +,   6.0151616E-04,   5.8948057E-04,   5.7664502E-04
     +,   5.6296942E-04,   5.4844312E-04,   5.3308846E-04
     +,   5.1696185E-04,   5.0015241E-04,   4.8277513E-04
     +,   4.6496745E-04,   4.4688393E-04,   4.2868452E-04
     +,   4.1053069E-04,   3.9257819E-04,   3.7497099E-04
     +,   3.5783483E-04,   3.4127544E-04,   3.2537765E-04
     +,   3.1020364E-04,   2.9579242E-04,   2.8216248E-04
     +,   2.6931526E-04,   2.5723648E-04,   2.4589867E-04
     +,   2.3526489E-04,   2.2529233E-04,   2.1593354E-04
     +,   2.0713893E-04,   1.9885947E-04,   1.9104738E-04
     +,   1.8365668E-04,   1.7664449E-04,   1.6997152E-04
     +,   1.6360213E-04,   1.5750351E-04,   1.5164631E-04
     +,   1.4600449E-04,   1.4055496E-04,   1.3527680E-04
     +,   1.3015151E-04,   1.2516334E-04,   1.2029809E-04
     +,   1.1554343E-04,   1.1088927E-04,   1.0632729E-04
     +,   1.0185055E-04,   9.7453747E-05,   9.3133400E-05
     +,   8.8887551E-05,   8.4715277E-05,   8.0616897E-05
     +,   7.6594180E-05,   7.2649782E-05,   6.8786932E-05
     +,   6.5009488E-05,   6.1322178E-05,   5.7729583E-05
     +,   5.4236498E-05,   5.0847906E-05,   4.7568610E-05
     +,   4.4402914E-05,   4.1354735E-05,   3.8427697E-05
     +,   3.5624835E-05,   3.2948377E-05,   3.0399891E-05
     +,   2.7980435E-05,   2.5690346E-05,   2.3529117E-05
     +,   2.1495583E-05,   1.9588135E-05,   1.7804361E-05
     +,   1.6141312E-05,   1.4595645E-05,   1.3163559E-05
     +,   1.1840775E-05,   1.0622709E-05,   9.5045934E-06
     +,   8.4814601E-06,   7.5481207E-06,   6.6993275E-06
     +,   5.9298577E-06,   5.2344958E-06,   4.6080454E-06
     +,   4.0454242E-06,   3.5417370E-06,   3.0922029E-06
     +,   2.6922389E-06,   2.3375017E-06,   2.0238672E-06
     +,   1.7474271E-06,   1.5045213E-06,   1.2917533E-06
     +,   1.1059681E-06,   9.4424257E-07,   8.0389282E-07
     +,   6.8247533E-07,   5.7776441E-07,   4.8773745E-07
     +,   4.1057166E-07,   3.4463812E-07,   2.8847327E-07
     +,   2.4077565E-07,   2.0039445E-07,   1.6631333E-07
     +,   1.3763652E-07,   1.1358003E-07,   9.3461885E-08
     +,   7.6689091E-08,   6.2747468E-08,   5.1194014E-08
     +,   4.1649358E-08,   3.3787590E-08,   2.7332046E-08
     +,   2.2046864E-08,   1.7733214E-08,   1.4222886E-08
     +,   1.1375070E-08,   9.0715231E-09,   7.2139339E-09
     +,   5.7203708E-09,   4.5231676E-09,   3.5663559E-09
     +,   2.8039244E-09,   2.1982414E-09,   1.7184774E-09
     +,   1.3396145E-09,   1.0413005E-09,   8.0712320E-10
     +,   6.2382660E-10,   4.8079013E-10,   3.6949432E-10
     +,   2.8315722E-10,   2.1637554E-10,   1.6487585E-10
     +,   1.2527537E-10,   9.4916831E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt75 = Yx/0.0188275862068966
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.3710132E-06,   9.5542109E-06
     +,   9.7363918E-06,   9.9178305E-06,   1.0098901E-05
     +,   1.0280091E-05,   1.0462018E-05,   1.0645448E-05
     +,   1.0831306E-05,   1.1020704E-05,   1.1214948E-05
     +,   1.1415557E-05,   1.1624294E-05,   1.1843168E-05
     +,   1.2074480E-05,   1.2320801E-05,   1.2585021E-05
     +,   1.2870359E-05,   1.3180355E-05,   1.3518914E-05
     +,   1.3890280E-05,   1.4299063E-05,   1.4750214E-05
     +,   1.5249067E-05,   1.5801239E-05,   1.6412716E-05
     +,   1.7089757E-05,   1.7838876E-05,   1.8666824E-05
     +,   1.9580530E-05,   2.0587046E-05,   2.1693493E-05
     +,   2.2906994E-05,   2.4234603E-05,   2.5683225E-05
     +,   2.7259530E-05,   2.8969869E-05,   3.0820152E-05
     +,   3.2815904E-05,   3.4961820E-05,   3.7262136E-05
     +,   3.9720144E-05,   4.2338252E-05,   4.5117893E-05
     +,   4.8059377E-05,   5.1161842E-05,   5.4423108E-05
     +,   5.7839632E-05,   6.1406368E-05,   6.5116757E-05
     +,   6.8962574E-05,   7.2933864E-05,   7.7018864E-05
     +,   8.1204271E-05,   8.5474399E-05,   8.9812194E-05
     +,   9.4198469E-05,   9.8612203E-05,   1.0303070E-04
     +,   1.0742951E-04,   1.1178280E-04,   1.1606343E-04
     +,   1.2024307E-04,   1.2429303E-04,   1.2818445E-04
     +,   1.3188837E-04,   1.3537733E-04,   1.3862492E-04
     +,   1.4160773E-04,   1.4430516E-04,   1.4670138E-04
     +,   1.4878545E-04,   1.5055333E-04,   1.5200810E-04
     +,   1.5316185E-04,   1.5403633E-04,   1.5466397E-04
     +,   1.5508877E-04,   1.5536707E-04,   1.5556754E-04
     +,   1.5577149E-04,   1.5607238E-04,   1.5657487E-04
     +,   1.5739360E-04,   1.5865100E-04,   1.6047507E-04
     +,   1.6299602E-04,   1.6634304E-04,   1.7063996E-04
     +,   1.7600131E-04,   1.8252796E-04,   1.9030237E-04
     +,   1.9938462E-04,   2.0980992E-04,   2.2158558E-04
     +,   2.3468849E-04,   2.4906808E-04,   2.6464424E-04
     +,   2.8131521E-04,   2.9895781E-04,   3.1743883E-04
     +,   3.3661784E-04,   3.5636028E-04,   3.7654029E-04
     +,   3.9705218E-04,   4.1781360E-04,   4.3876650E-04
     +,   4.5987807E-04,   4.8113731E-04,   5.0254643E-04
     +,   5.2410772E-04,   5.4581597E-04,   5.6763878E-04
     +,   5.8951031E-04,   6.1131455E-04,   6.3288509E-04
     +,   6.5399858E-04,   6.7438505E-04,   6.9373351E-04
     +,   7.1171415E-04,   7.2799780E-04,   7.4227934E-04
     +,   7.5430569E-04,   7.6389959E-04,   7.7098032E-04
     +,   7.7557989E-04,   7.7785063E-04,   7.7806634E-04
     +,   7.7661610E-04,   7.7398843E-04,   7.7074982E-04
     +,   7.6752063E-04,   7.6494121E-04,   7.6364266E-04
     +,   7.6421059E-04,   7.6715287E-04,   7.7286485E-04
     +,   7.8159978E-04,   7.9344353E-04,   8.0829480E-04
     +,   8.2585635E-04,   8.4563455E-04,   8.6696097E-04
     +,   8.8902219E-04,   9.1090152E-04,   9.3164382E-04
     +,   9.5031393E-04,   9.6606323E-04,   9.7818964E-04
     +,   9.8618749E-04,   9.8977750E-04,   9.8892185E-04
     +,   9.8381797E-04,   9.7487326E-04,   9.6266990E-04
     +,   9.4791304E-04,   9.3138008E-04,   9.1386208E-04
     +,   8.9611567E-04,   8.7882008E-04,   8.6253806E-04
     +,   8.4769347E-04,   8.3455699E-04,   8.2324335E-04
     +,   8.1371656E-04,   8.0580934E-04,   7.9924532E-04
     +,   7.9366914E-04,   7.8867818E-04,   7.8385387E-04
     +,   7.7879359E-04,   7.7313132E-04,   7.6655723E-04
     +,   7.5882423E-04,   7.4975193E-04,   7.3921849E-04
     +,   7.2715065E-04,   7.1351381E-04,   6.9829728E-04
     +,   6.8150455E-04,   6.6314824E-04,   6.4325082E-04
     +,   6.2184699E-04,   5.9898966E-04,   5.7475973E-04
     +,   5.4927595E-04,   5.2269956E-04,   4.9523445E-04
     +,   4.6712664E-04,   4.3865971E-04,   4.1013747E-04
     +,   3.8187311E-04,   3.5417458E-04,   3.2732770E-04
     +,   3.0158015E-04,   2.7713392E-04,   2.5413933E-04
     +,   2.3269124E-04,   2.1282933E-04,   1.9454434E-04
     +,   1.7778724E-04,   1.6247643E-04,   1.4850676E-04
     +,   1.3576016E-04,   1.2411515E-04,   1.1345145E-04
     +,   1.0365673E-04,   9.4630705E-05,   8.6286433E-05
     +,   7.8550438E-05,   7.1362861E-05,   6.4676569E-05
     +,   5.8454720E-05,   5.2668493E-05,   4.7295438E-05
     +,   4.2317872E-05,   3.7720856E-05,   3.3490531E-05
     +,   2.9613429E-05,   2.6076115E-05,   2.2863924E-05
     +,   1.9961230E-05,   1.7351536E-05,   1.5017363E-05
     +,   1.2940342E-05,   1.1101654E-05,   9.4824209E-06
     +,   8.0638229E-06,   6.8273116E-06,   5.7549455E-06
     +,   4.8296483E-06,   4.0352593E-06,   3.3566193E-06
     +,   2.7797016E-06,   2.2916979E-06,   1.8809086E-06
     +,   1.5367933E-06,   1.2499462E-06,   1.0120106E-06
     +,   8.1560353E-07,   6.5426741E-07,   5.2239631E-07
     +,   4.1514593E-07,   3.2834970E-07,   2.5845642E-07
     +,   2.0245984E-07,   1.5782558E-07,   1.2242852E-07
     +,   9.4500429E-08,   7.2580889E-08,   5.5466206E-08
     +,   4.2172871E-08,   3.1902580E-08,   2.4010202E-08
     +,   1.7977371E-08,   1.3390587E-08,   9.9222213E-09
     +,   7.3138624E-09,   5.3628786E-09,   3.9115493E-09
     +,   2.8378784E-09,   2.0479942E-09,   1.4700833E-09
     +,   1.0495900E-09,   7.4536033E-10,   5.2646509E-10
     +,   3.6984446E-10,   2.5841265E-10,   1.7957885E-10
     +,   1.2411730E-10,   8.5317184E-11,   5.8326996E-11
     +,   3.9658211E-11,   2.6817531E-11,   1.8035139E-11
     +,   1.2062652E-11,   8.0237275E-12,   5.3079771E-12
     +,   3.4921198E-12,   2.2848999E-12,   1.4867941E-12
     +,   9.6217186E-13,   6.1924088E-13,   3.9635835E-13
     +,   2.5230645E-13,   1.5973308E-13,   1.0057490E-13
     +,   6.2981738E-14,   3.9227814E-14,   2.4301534E-14
     +,   1.4975119E-14,   9.1796205E-15,   5.5983334E-15
     +,   3.3972319E-15,   2.0517804E-15,   1.2336590E-15
     +,   7.3877997E-16,   4.4089709E-16,   2.6244445E-16
     +,   1.5599345E-16,   9.2737740E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt80 = Yx/0.0185
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5018120E-05,   1.5512313E-05
     +,   1.6007498E-05,   1.6502756E-05,   1.6997134E-05
     +,   1.7489658E-05,   1.7979322E-05,   1.8465114E-05
     +,   1.8945982E-05,   1.9420897E-05,   1.9888790E-05
     +,   2.0348598E-05,   2.0799262E-05,   2.1239717E-05
     +,   2.1668911E-05,   2.2085813E-05,   2.2489407E-05
     +,   2.2878692E-05,   2.3252715E-05,   2.3610546E-05
     +,   2.3951303E-05,   2.4274164E-05,   2.4578356E-05
     +,   2.4863188E-05,   2.5128025E-05,   2.5372345E-05
     +,   2.5595718E-05,   2.5797835E-05,   2.5978517E-05
     +,   2.6137730E-05,   2.6275613E-05,   2.6392501E-05
     +,   2.6488933E-05,   2.6565704E-05,   2.6623873E-05
     +,   2.6664802E-05,   2.6690199E-05,   2.6702151E-05
     +,   2.6703145E-05,   2.6696140E-05,   2.6684584E-05
     +,   2.6672467E-05,   2.6664355E-05,   2.6665428E-05
     +,   2.6681511E-05,   2.6719114E-05,   2.6785428E-05
     +,   2.6888358E-05,   2.7036514E-05,   2.7239186E-05
     +,   2.7506336E-05,   2.7848542E-05,   2.8276927E-05
     +,   2.8803124E-05,   2.9439087E-05,   3.0197114E-05
     +,   3.1089592E-05,   3.2128944E-05,   3.3327426E-05
     +,   3.4697026E-05,   3.6249294E-05,   3.7995196E-05
     +,   3.9944898E-05,   4.2107888E-05,   4.4492754E-05
     +,   4.7106900E-05,   4.9957063E-05,   5.3048669E-05
     +,   5.6386601E-05,   5.9974493E-05,   6.3815722E-05
     +,   6.7912581E-05,   7.2267430E-05,   7.6881814E-05
     +,   8.1757433E-05,   8.6895998E-05,   9.2298666E-05
     +,   9.7966498E-05,   1.0390052E-04,   1.1010122E-04
     +,   1.1656753E-04,   1.2329769E-04,   1.3028702E-04
     +,   1.3752907E-04,   1.4501291E-04,   1.5272430E-04
     +,   1.6064322E-04,   1.6874479E-04,   1.7699714E-04
     +,   1.8536279E-04,   1.9379766E-04,   2.0225103E-04
     +,   2.1066662E-04,   2.1898384E-04,   2.2713908E-04
     +,   2.3506624E-04,   2.4270055E-04,   2.4997891E-04
     +,   2.5684395E-04,   2.6324458E-04,   2.6914003E-04
     +,   2.7449997E-04,   2.7930754E-04,   2.8355935E-04
     +,   2.8726656E-04,   2.9045454E-04,   2.9316166E-04
     +,   2.9543776E-04,   2.9734240E-04,   2.9894174E-04
     +,   3.0030540E-04,   3.0150352E-04,   3.0260306E-04
     +,   3.0366497E-04,   3.0474132E-04,   3.0587343E-04
     +,   3.0709038E-04,   3.0840846E-04,   3.0983196E-04
     +,   3.1135435E-04,   3.1296106E-04,   3.1463261E-04
     +,   3.1634828E-04,   3.1809145E-04,   3.1985351E-04
     +,   3.2163889E-04,   3.2346949E-04,   3.2538772E-04
     +,   3.2745991E-04,   3.2977652E-04,   3.3245291E-04
     +,   3.3562636E-04,   3.3945404E-04,   3.4410707E-04
     +,   3.4976617E-04,   3.5661730E-04,   3.6484728E-04
     +,   3.7464415E-04,   3.8620102E-04,   3.9972455E-04
     +,   4.1544603E-04,   4.3363927E-04,   4.5463917E-04
     +,   4.7885627E-04,   5.0678285E-04,   5.3899357E-04
     +,   5.7612214E-04,   6.1881915E-04,   6.6768896E-04
     +,   7.2321174E-04,   7.8564230E-04,   8.5490459E-04
     +,   9.3049539E-04,   1.0114159E-03,   1.0961277E-03
     +,   1.1825562E-03,   1.2681627E-03,   1.3500790E-03
     +,   1.4252843E-03,   1.4908238E-03,   1.5440636E-03
     +,   1.5829179E-03,   1.6060408E-03,   1.6129677E-03
     +,   1.6041666E-03,   1.5809991E-03,   1.5456126E-03
     +,   1.5007530E-03,   1.4495327E-03,   1.3951802E-03
     +,   1.3407941E-03,   1.2891091E-03,   1.2423055E-03
     +,   1.2018703E-03,   1.1685204E-03,   1.1421790E-03
     +,   1.1220315E-03,   1.1066424E-03,   1.0941288E-03
     +,   1.0823733E-03,   1.0692637E-03,   1.0529180E-03
     +,   1.0318791E-03,   1.0052451E-03,   9.7272941E-04
     +,   9.3464326E-04,   8.9180219E-04,   8.4537879E-04
     +,   7.9673162E-04,   7.4723677E-04,   6.9812778E-04
     +,   6.5039046E-04,   6.0470530E-04,   5.6143518E-04
     +,   5.2065466E-04,   4.8221808E-04,   4.4584033E-04
     +,   4.1117676E-04,   3.7789275E-04,   3.4572004E-04
     +,   3.1449247E-04,   2.8415566E-04,   2.5475785E-04
     +,   2.2643246E-04,   1.9937202E-04,   1.7379165E-04
     +,   1.4990200E-04,   1.2788641E-04,   1.0788083E-04
     +,   8.9961992E-05,   7.4145988E-05,   6.0391430E-05
     +,   4.8605612E-05,   3.8653787E-05,   3.0372046E-05
     +,   2.3579207E-05,   1.8086803E-05,   1.3707988E-05
     +,   1.0265264E-05,   7.5957755E-06,   5.5538057E-06
     +,   4.0127147E-06,   2.8650877E-06,   2.0216896E-06
     +,   1.4098860E-06,   9.7176712E-07,   6.6202756E-07
     +,   4.4581313E-07,   2.9676255E-07,   1.9528095E-07
     +,   1.2703750E-07,   8.1705522E-08,   5.1955492E-08
     +,   3.2665049E-08,   2.0306555E-08,   1.2482438E-08
     +,   7.5871389E-09,   4.5602730E-09,   2.7105338E-09
     +,   1.5931992E-09,   9.2604951E-10,   5.3230248E-10
     +,   3.0258843E-10,   1.7010125E-10,   9.4561373E-11
     +,   5.1984847E-11,   2.8261832E-11,   1.5194021E-11
     +,   8.0776158E-12,   4.2466768E-12,   2.2078537E-12
     +,   1.1351571E-12,   5.7723905E-13,   2.9037184E-13
     +,   1.4453742E-13,   7.1230592E-14,   3.4789402E-14
     +,   1.6868148E-14,   8.1427937E-15,   3.9324775E-15
     +,   1.9150947E-15,   9.5195905E-16,   4.9113083E-16
     +,   2.6808958E-16,   1.5734154E-16,   9.9843314E-17
     +,   6.7990501E-17,   4.8890652E-17,   3.6478543E-17
     +,   2.7841275E-17,   2.1524063E-17,   1.6753582E-17
     +,   1.3082745E-17,   1.0228925E-17,   7.9987778E-18
     +,   6.2522265E-18,   4.8834026E-18,   3.8108852E-18
     +,   2.9709830E-18,   2.3138523E-18,   1.8001820E-18
     +,   1.3990820E-18,   1.0861973E-18,   8.4239872E-19
     +,   6.5262637E-19,   5.0507302E-19,   3.9046508E-19
     +,   3.0154130E-19,   2.3262366E-19,   1.7926618E-19
     +,   1.3800170E-19,   1.0612237E-19,   8.1521435E-20
     +,   6.2556484E-20,   4.7953114E-20,   3.6719507E-20
     +,   2.8087894E-20,   2.1462343E-20,   1.6382391E-20
     +,   1.2491502E-20,   9.5146789E-21
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt85 = Yx/0.01875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.7727675E-06,   6.2481813E-06
     +,   6.7505489E-06,   7.2801563E-06,   7.8371604E-06
     +,   8.4215753E-06,   9.0332696E-06,   9.6719423E-06
     +,   1.0337120E-05,   1.1028183E-05,   1.1744287E-05
     +,   1.2484414E-05,   1.3247348E-05,   1.4031679E-05
     +,   1.4835798E-05,   1.5657892E-05,   1.6495962E-05
     +,   1.7347813E-05,   1.8211076E-05,   1.9083200E-05
     +,   1.9961479E-05,   2.0843056E-05,   2.1724931E-05
     +,   2.2604047E-05,   2.3477151E-05,   2.4341014E-05
     +,   2.5192312E-05,   2.6027703E-05,   2.6843845E-05
     +,   2.7637436E-05,   2.8405213E-05,   2.9144019E-05
     +,   2.9850798E-05,   3.0522639E-05,   3.1156804E-05
     +,   3.1750744E-05,   3.2302145E-05,   3.2808923E-05
     +,   3.3269316E-05,   3.3681779E-05,   3.4045148E-05
     +,   3.4358549E-05,   3.4621458E-05,   3.4833723E-05
     +,   3.4995533E-05,   3.5107463E-05,   3.5170448E-05
     +,   3.5185800E-05,   3.5155193E-05,   3.5080669E-05
     +,   3.4964611E-05,   3.4809735E-05,   3.4619090E-05
     +,   3.4396013E-05,   3.4144137E-05,   3.3867338E-05
     +,   3.3569726E-05,   3.3255626E-05,   3.2929525E-05
     +,   3.2596057E-05,   3.2259966E-05,   3.1926080E-05
     +,   3.1599277E-05,   3.1284439E-05,   3.0986415E-05
     +,   3.0710038E-05,   3.0460013E-05,   3.0240975E-05
     +,   3.0057405E-05,   2.9913639E-05,   2.9813838E-05
     +,   2.9761994E-05,   2.9761948E-05,   2.9817336E-05
     +,   2.9931705E-05,   3.0108498E-05,   3.0351091E-05
     +,   3.0662883E-05,   3.1047395E-05,   3.1508349E-05
     +,   3.2049731E-05,   3.2676024E-05,   3.3392218E-05
     +,   3.4204069E-05,   3.5118093E-05,   3.6141882E-05
     +,   3.7284011E-05,   3.8554372E-05,   3.9963968E-05
     +,   4.1525214E-05,   4.3251850E-05,   4.5158704E-05
     +,   4.7261718E-05,   4.9577895E-05,   5.2125026E-05
     +,   5.4921107E-05,   5.7984642E-05,   6.1333631E-05
     +,   6.4985994E-05,   6.8958398E-05,   7.3266841E-05
     +,   7.7925470E-05,   8.2947314E-05,   8.8342953E-05
     +,   9.4121599E-05,   1.0029038E-04,   1.0685393E-04
     +,   1.1381467E-04,   1.2117312E-04,   1.2892729E-04
     +,   1.3707166E-04,   1.4559839E-04,   1.5449463E-04
     +,   1.6374393E-04,   1.7332306E-04,   1.8320313E-04
     +,   1.9334620E-04,   2.0370662E-04,   2.1422730E-04
     +,   2.2484176E-04,   2.3547256E-04,   2.4603086E-04
     +,   2.5641808E-04,   2.6652776E-04,   2.7624736E-04
     +,   2.8545962E-04,   2.9404816E-04,   3.0189852E-04
     +,   3.0890445E-04,   3.1496998E-04,   3.2001580E-04
     +,   3.2398317E-04,   3.2684070E-04,   3.2859063E-04
     +,   3.2927829E-04,   3.2900120E-04,   3.2792034E-04
     +,   3.2627126E-04,   3.2437476E-04,   3.2264448E-04
     +,   3.2159116E-04,   3.2182151E-04,   3.2403230E-04
     +,   3.2900044E-04,   3.3757093E-04,   3.5064772E-04
     +,   3.6918637E-04,   3.9419005E-04,   4.2670668E-04
     +,   4.6782449E-04,   5.1864755E-04,   5.8024412E-04
     +,   6.5356522E-04,   7.3933182E-04,   8.3788199E-04
     +,   9.4900688E-04,   1.0718146E-03,   1.2046592E-03
     +,   1.3451385E-03,   1.4901679E-03,   1.6361558E-03
     +,   1.7791305E-03,   1.9148014E-03,   2.0385464E-03
     +,   2.1453623E-03,   2.2299096E-03,   2.2868547E-03
     +,   2.3116439E-03,   2.3016387E-03,   2.2573820E-03
     +,   2.1835954E-03,   2.0894774E-03,   1.9879900E-03
     +,   1.8941539E-03,   1.8226248E-03,   1.7850539E-03
     +,   1.7879017E-03,   1.8311609E-03,   1.9083153E-03
     +,   2.0075026E-03,   2.1135656E-03,   2.2105030E-03
     +,   2.2838349E-03,   2.3224449E-03,   2.3196598E-03
     +,   2.2735670E-03,   2.1866814E-03,   2.0651072E-03
     +,   1.9174162E-03,   1.7534394E-03,   1.5830183E-03
     +,   1.4149767E-03,   1.2563518E-03,   1.1119454E-03
     +,   9.8424091E-04,   8.7365636E-04,   7.7901687E-04
     +,   6.9812284E-04,   6.2831712E-04,   5.6697242E-04
     +,   5.1183137E-04,   4.6118748E-04,   4.1392859E-04
     +,   3.6948692E-04,   3.2772400E-04,   2.8877531E-04
     +,   2.5291168E-04,   2.2041835E-04,   1.9150309E-04
     +,   1.6624143E-04,   1.4455988E-04,   1.2624565E-04
     +,   1.1097291E-04,   9.8340519E-05,   8.7914355E-05
     +,   7.9264886E-05,   7.1995557E-05,   6.5762113E-05
     +,   6.0283324E-05,   5.5343087E-05,   5.0785045E-05
     +,   4.6504752E-05,   4.2439708E-05,   3.8558581E-05
     +,   3.4851349E-05,   3.1321422E-05,   2.7979433E-05
     +,   2.4838298E-05,   2.1909773E-05,   1.9202742E-05
     +,   1.6722357E-05,   1.4469490E-05,   1.2440768E-05
     +,   1.0629186E-05,   9.0248741E-06,   7.6154192E-06
     +,   6.3867610E-06,   5.3238632E-06,   4.4112007E-06
     +,   3.6331785E-06,   2.9746100E-06,   2.4210453E-06
     +,   1.9589288E-06,   1.5757309E-06,   1.2600700E-06
     +,   1.0017548E-06,   7.9174413E-07,   6.2209767E-07
     +,   4.8592926E-07,   3.7733574E-07,   2.9127969E-07
     +,   2.2351406E-07,   1.7049167E-07,   1.2926931E-07
     +,   9.7423538E-08,   7.2977556E-08,   5.4332563E-08
     +,   4.0203702E-08,   2.9565591E-08,   2.1607420E-08
     +,   1.5692930E-08,   1.1326100E-08,   8.1229530E-09
     +,   5.7887672E-09,   4.0991561E-09,   2.8841811E-09
     +,   2.0162945E-09,   1.4004995E-09,   9.6651009E-10
     +,   6.6268868E-10,   4.5141768E-10,   3.0550082E-10
     +,   2.0540433E-10,   1.3720125E-10,   9.1043222E-11
     +,   6.0018310E-11,   3.9305319E-11,   2.5571587E-11
     +,   1.6526735E-11,   1.0610841E-11,   6.7675145E-12
     +,   4.2878175E-12,   2.6987106E-12,   1.6873304E-12
     +,   1.0479811E-12,   6.4658728E-13,   3.9629115E-13
     +,   2.4127174E-13,   1.4592063E-13,   8.7665816E-14
     +,   5.2319233E-14,   3.1016564E-14,   1.8265959E-14
     +,   1.0685421E-14,   6.2095109E-15,   3.5844452E-15
     +,   2.0554296E-15,   1.1707973E-15,   6.6248564E-16
     +,   3.7236545E-16,   2.0791146E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt90 = Yx/0.0235666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.5333374E-07,   9.4879516E-07
     +,   1.0532575E-06,   1.1673641E-06,   1.2917785E-06
     +,   1.4271860E-06,   1.5742903E-06,   1.7338092E-06
     +,   1.9064711E-06,   2.0930224E-06,   2.2942063E-06
     +,   2.5107690E-06,   2.7434548E-06,   2.9930000E-06
     +,   3.2601261E-06,   3.5455366E-06,   3.8499115E-06
     +,   4.1738990E-06,   4.5181087E-06,   4.8831112E-06
     +,   5.2694231E-06,   5.6775079E-06,   6.1077535E-06
     +,   6.5605136E-06,   7.0360102E-06,   7.5344396E-06
     +,   8.0558793E-06,   8.6003156E-06,   9.1676457E-06
     +,   9.7576612E-06,   1.0370048E-05,   1.1004383E-05
     +,   1.1660134E-05,   1.2336657E-05,   1.3033195E-05
     +,   1.3748881E-05,   1.4482736E-05,   1.5233667E-05
     +,   1.6000526E-05,   1.6781976E-05,   1.7576687E-05
     +,   1.8383185E-05,   1.9199939E-05,   2.0025356E-05
     +,   2.0857786E-05,   2.1695532E-05,   2.2536882E-05
     +,   2.3380098E-05,   2.4223447E-05,   2.5065221E-05
     +,   2.5903742E-05,   2.6737371E-05,   2.7564553E-05
     +,   2.8383860E-05,   2.9193885E-05,   2.9993453E-05
     +,   3.0781477E-05,   3.1557072E-05,   3.2319535E-05
     +,   3.3068391E-05,   3.3803411E-05,   3.4524626E-05
     +,   3.5232326E-05,   3.5927151E-05,   3.6610058E-05
     +,   3.7282301E-05,   3.7945589E-05,   3.8601906E-05
     +,   3.9253744E-05,   3.9903891E-05,   4.0555664E-05
     +,   4.1212697E-05,   4.1879142E-05,   4.2559488E-05
     +,   4.3258704E-05,   4.3982142E-05,   4.4735516E-05
     +,   4.5524856E-05,   4.6356599E-05,   4.7237423E-05
     +,   4.8174174E-05,   4.9173970E-05,   5.0243914E-05
     +,   5.1391322E-05,   5.2623254E-05,   5.3946835E-05
     +,   5.5368826E-05,   5.6895835E-05,   5.8533900E-05
     +,   6.0288719E-05,   6.2165353E-05,   6.4168096E-05
     +,   6.6300439E-05,   6.8565088E-05,   7.0963819E-05
     +,   7.3497082E-05,   7.6164521E-05,   7.8964214E-05
     +,   8.1893297E-05,   8.4947176E-05,   8.8120221E-05
     +,   9.1404952E-05,   9.4792835E-05,   9.8273304E-05
     +,   1.0183470E-04,   1.0546379E-04,   1.0914566E-04
     +,   1.1286389E-04,   1.1660109E-04,   1.2033859E-04
     +,   1.2405633E-04,   1.2773390E-04,   1.3134992E-04
     +,   1.3488316E-04,   1.3831200E-04,   1.4161588E-04
     +,   1.4477479E-04,   1.4777054E-04,   1.5058661E-04
     +,   1.5320953E-04,   1.5562883E-04,   1.5783789E-04
     +,   1.5983445E-04,   1.6162173E-04,   1.6320852E-04
     +,   1.6460994E-04,   1.6584829E-04,   1.6695313E-04
     +,   1.6796219E-04,   1.6892140E-04,   1.6988521E-04
     +,   1.7091646E-04,   1.7208615E-04,   1.7347251E-04
     +,   1.7516002E-04,   1.7723777E-04,   1.7979686E-04
     +,   1.8292757E-04,   1.8671619E-04,   1.9124089E-04
     +,   1.9656713E-04,   2.0274371E-04,   2.0979944E-04
     +,   2.1774002E-04,   2.2654582E-04,   2.3617402E-04
     +,   2.4656122E-04,   2.5762859E-04,   2.6929210E-04
     +,   2.8147583E-04,   2.9412808E-04,   3.0724003E-04
     +,   3.2087055E-04,   3.3517194E-04,   3.5041571E-04
     +,   3.6701444E-04,   3.8553518E-04,   4.0669870E-04
     +,   4.3135072E-04,   4.6040039E-04,   4.9473229E-04
     +,   5.3507934E-04,   5.8187207E-04,   6.3508633E-04
     +,   6.9410965E-04,   7.5765199E-04,   8.2374294E-04
     +,   8.8988442E-04,   9.5340470E-04,   1.0120441E-03
     +,   1.0647670E-03,   1.1127120E-03,   1.1600504E-03
     +,   1.2144679E-03,   1.2869556E-03,   1.3907349E-03
     +,   1.5392622E-03,   1.7435319E-03,   2.0090933E-03
     +,   2.3333633E-03,   2.7038555E-03,   3.0980685E-03
     +,   3.4857197E-03,   3.8333165E-03,   4.1101393E-03
     +,   4.2939363E-03,   4.3743174E-03,   4.3526259E-03
     +,   4.2386856E-03,   4.0464788E-03,   3.7907984E-03
     +,   3.4861756E-03,   3.1476179E-03,   2.7915635E-03
     +,   2.4356388E-03,   2.0968728E-03,   1.7890658E-03
     +,   1.5205913E-03,   1.2936655E-03,   1.1053276E-03
     +,   9.4950566E-04,   8.1925240E-04,   7.0844282E-04
     +,   6.1259605E-04,   5.2888819E-04,   4.5566465E-04
     +,   3.9186783E-04,   3.3659642E-04,   2.8888485E-04
     +,   2.4768611E-04,   2.1196563E-04,   1.8080970E-04
     +,   1.5348889E-04,   1.2946763E-04,   1.0837348E-04
     +,   8.9944791E-05,   7.3976451E-05,   6.0279908E-05
     +,   4.8662740E-05,   3.8922473E-05,   3.0847063E-05
     +,   2.4223749E-05,   1.8847435E-05,   1.4526700E-05
     +,   1.1087939E-05,   8.3777568E-06,   6.2632439E-06
     +,   4.6307223E-06,   3.3841029E-06,   2.4431577E-06
     +,   1.7416424E-06,   1.2253701E-06,   8.5052062E-07
     +,   5.8215505E-07,   3.9281855E-07,   2.6122237E-07
     +,   1.7114989E-07,   1.1045923E-07,   7.0212309E-08
     +,   4.3947860E-08,   2.7084054E-08,   1.6432452E-08
     +,   9.8146380E-09,   5.7702261E-09,   3.3390772E-09
     +,   1.9017949E-09,   1.0661011E-09,   5.8817962E-10
     +,   3.1936137E-10,   1.7065710E-10,   8.9747765E-11
     +,   4.6447842E-11,   2.3656833E-11,   1.1857813E-11
     +,   5.8492334E-12,   2.8394032E-12,   1.3564359E-12
     +,   6.3771346E-13,   2.9504968E-13,   1.3433766E-13
     +,   6.0193014E-14,   2.6543080E-14,   1.1518843E-14
     +,   4.9194026E-15,   2.0677465E-15,   8.5540851E-16
     +,   3.4830892E-16,   1.3962286E-16,   5.5117612E-17
     +,   2.1438758E-17,   8.2248736E-18,   3.1186829E-18
     +,   1.1732935E-18,   4.4110383E-19,   1.6787814E-19
     +,   6.6094807E-20,   2.7753228E-20,   1.2832070E-20
     +,   6.6417906E-21,   3.8108078E-21,   2.3566729E-21
     +,   1.5255592E-21,   1.0120206E-21,   6.7937862E-22
     +,   4.5841578E-22,   3.0986666E-22,   2.0948269E-22
     +,   1.4152813E-22,   9.5525565E-23,   6.4402352E-23
     +,   4.3368446E-23,   2.9168394E-23,   1.9594120E-23
     +,   1.3146253E-23,   8.8095198E-24,   5.8961267E-24
     +,   3.9414627E-24,   2.6315412E-24,   1.7548402E-24
     +,   1.1687678E-24,   7.7748080E-25
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_htt95 = Yx/0.0246129032258065
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1217248E-24,   2.3667145E-24
     +,   4.9626119E-24,   1.0341454E-23,   2.1417070E-23
     +,   4.4080263E-23,   9.0164271E-23,   1.8328815E-22
     +,   3.7028356E-22,   7.4344640E-22,   1.4834481E-21
     +,   2.9417295E-21,   5.7975272E-21,   1.1355149E-20
     +,   2.2103025E-20,   4.2758391E-20,   8.2205752E-20
     +,   1.5706937E-19,   2.9826057E-19,   5.6287066E-19
     +,   1.0556849E-18,   1.9677642E-18,   3.6451877E-18
     +,   6.7110280E-18,   1.2279023E-17,   2.2328409E-17
     +,   4.0352064E-17,   7.2475243E-17,   1.2936880E-16
     +,   2.2950151E-16,   4.0463037E-16,   7.0900395E-16
     +,   1.2346891E-15,   2.1369004E-15,   3.6756211E-15
     +,   6.2834314E-15,   1.0675378E-14,   1.8025495E-14
     +,   3.0249569E-14,   5.0450732E-14,   8.3625930E-14
     +,   1.3776498E-13,   2.2555962E-13,   3.6703540E-13
     +,   5.9358112E-13,   9.5406755E-13,   1.5240679E-12
     +,   2.4196795E-12,   3.8180349E-12,   5.9875742E-12
     +,   9.3323778E-12,   1.4456527E-11,   2.2256912E-11
     +,   3.4056806E-11,   5.1792910E-11,   7.8284088E-11
     +,   1.1760115E-10,   1.7558423E-10,   2.6055286E-10
     +,   3.8427669E-10,   5.6328792E-10,   8.2065077E-10
     +,   1.1882874E-09,   1.7101169E-09,   2.4461158E-09
     +,   3.4774934E-09,   4.9136468E-09,   6.9005228E-09
     +,   9.6318642E-09,   1.3362279E-08,   1.8424815E-08
     +,   2.5250483E-08,   3.4394610E-08,   4.6564736E-08
     +,   6.2657875E-08,   8.3801318E-08,   1.1139852E-07
     +,   1.4718334E-07,   1.9328283E-07,   2.5228309E-07
     +,   3.2729309E-07,   4.2203413E-07,   5.4089645E-07
     +,   6.8904018E-07,   8.7243512E-07,   1.0979619E-06
     +,   1.3734134E-06,   1.7075870E-06,   2.1102142E-06
     +,   2.5920092E-06,   3.1645818E-06,   3.8402895E-06
     +,   4.6320993E-06,   5.5534329E-06,   6.6178723E-06
     +,   7.8387038E-06,   9.2287883E-06,   1.0799810E-05
     +,   1.2562138E-05,   1.4523911E-05,   1.6690954E-05
     +,   1.9065710E-05,   2.1647291E-05,   2.4430365E-05
     +,   2.7405309E-05,   3.0557647E-05,   3.3867611E-05
     +,   3.7310227E-05,   4.0855623E-05,   4.4469096E-05
     +,   4.8111087E-05,   5.1738669E-05,   5.5305314E-05
     +,   5.8762776E-05,   6.2061205E-05,   6.5151209E-05
     +,   6.7984198E-05,   7.0514463E-05,   7.2699644E-05
     +,   7.4502539E-05,   7.5891810E-05,   7.6842836E-05
     +,   7.7338671E-05,   7.7370431E-05,   7.6937533E-05
     +,   7.6047771E-05,   7.4716991E-05,   7.2968818E-05
     +,   7.0833616E-05,   6.8348090E-05,   6.5553671E-05
     +,   6.2495994E-05,   5.9222988E-05,   5.5784378E-05
     +,   5.2229752E-05,   4.8607679E-05,   4.4964934E-05
     +,   4.1345284E-05,   3.7788486E-05,   3.4329925E-05
     +,   3.1000392E-05,   2.7825614E-05,   2.4825942E-05
     +,   2.2016726E-05,   1.9408797E-05,   1.7008304E-05
     +,   1.4817594E-05,   1.2835974E-05,   1.1060343E-05
     +,   9.4860379E-06,   8.1080434E-06,   6.9223092E-06
     +,   5.9269823E-06,   5.1238799E-06,   4.5201764E-06
     +,   4.1300495E-06,   3.9761144E-06,   4.0907044E-06
     +,   4.5167872E-06,   5.3081690E-06,   6.5291842E-06
     +,   8.2536171E-06,   1.0562829E-05,   1.3543527E-05
     +,   1.7285451E-05,   2.1878355E-05,   2.7408119E-05
     +,   3.3952008E-05,   4.1572228E-05,   5.0305771E-05
     +,   6.0151015E-05,   7.1054776E-05,   8.2903804E-05
     +,   9.5526870E-05,   1.0871846E-04,   1.2229825E-04
     +,   1.3620543E-04,   1.5062929E-04,   1.6616500E-04
     +,   1.8396697E-04,   2.0585943E-04,   2.3435424E-04
     +,   2.7252105E-04,   3.2366154E-04,   3.9078167E-04
     +,   4.7595089E-04,   5.7976804E-04,   7.0120004E-04
     +,   8.3794259E-04,   9.8719832E-04,   1.1464945E-03
     +,   1.3138842E-03,   1.4872194E-03,   1.6626979E-03
     +,   1.8333570E-03,   1.9883697E-03,   2.1137807E-03
     +,   2.1947650E-03,   2.2188118E-03,   2.1788559E-03
     +,   2.0753089E-03,   1.9162283E-03,   1.7155538E-03
     +,   1.4901836E-03,   1.2570098E-03,   1.0306890E-03
     +,   8.2256022E-04,   6.4034207E-04,   4.8816801E-04
     +,   3.6680352E-04,   2.7411155E-04,   2.0583457E-04
     +,   1.5663280E-04,   1.2116314E-04,   9.4911142E-05
     +,   7.4598451E-05,   5.8178135E-05,   4.4563127E-05
     +,   3.3263699E-05,   2.4066891E-05,   1.6820608E-05
     +,   1.1333024E-05,   7.3524425E-06,   4.5901584E-06
     +,   2.7566373E-06,   1.5922191E-06,   8.8443420E-07
     +,   4.7245300E-07,   2.4269707E-07,   1.1988629E-07
     +,   5.6948277E-08,   2.6014073E-08,   1.1427258E-08
     +,   4.8269126E-09,   1.9607165E-09,   7.6588813E-10
     +,   2.8767899E-10,   1.0390960E-10,   3.6092990E-11
     +,   1.2055811E-11,   3.8722146E-12,   1.1959898E-12
     +,   3.5523591E-13,   1.0146415E-13,   2.7867353E-14
     +,   7.3601107E-15,   1.8693731E-15,   4.5657691E-16
     +,   1.0723031E-16,   2.4218469E-17,   5.2599460E-18
     +,   1.0984996E-18,   2.2060904E-19,   4.2606461E-20
     +,   7.9128534E-21,   1.4130957E-21,   2.4266980E-22
     +,   4.0076431E-23,   6.3645953E-24,   9.7193412E-25
     +,   1.4272973E-25,   2.0158663E-26,   2.7385826E-27
     +,   3.5804641E-28,   4.5150876E-29,   5.5323237E-30
     +,   6.7610391E-31,   8.9618114E-32,   1.5501068E-32
     +,   4.0302529E-33,   1.3977356E-33,   5.4031662E-34
     +,   2.1445478E-34,   8.5281805E-35,   3.3767005E-35
     +,   1.3293233E-35,   5.2010897E-36,   2.0224856E-36
     +,   7.8155648E-37,   3.0015728E-37,   1.1455858E-37
     +,   4.3452334E-38,   1.6378922E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz100 = Yx/0.00933333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6924194E-05,   2.7697643E-05
     +,   2.8464723E-05,   2.9223787E-05,   2.9973169E-05
     +,   3.0711202E-05,   3.1436222E-05,   3.2146581E-05
     +,   3.2840639E-05,   3.3516801E-05,   3.4173496E-05
     +,   3.4809182E-05,   3.5422370E-05,   3.6011636E-05
     +,   3.6575602E-05,   3.7112972E-05,   3.7622507E-05
     +,   3.8103059E-05,   3.8553564E-05,   3.8973034E-05
     +,   3.9360599E-05,   3.9715454E-05,   4.0036928E-05
     +,   4.0324441E-05,   4.0577506E-05,   4.0795763E-05
     +,   4.0978954E-05,   4.1126928E-05,   4.1239651E-05
     +,   4.1317187E-05,   4.1359719E-05,   4.1367522E-05
     +,   4.1340980E-05,   4.1280597E-05,   4.1186933E-05
     +,   4.1060681E-05,   4.0902592E-05,   4.0713523E-05
     +,   4.0494389E-05,   4.0246192E-05,   3.9969989E-05
     +,   3.9666909E-05,   3.9338131E-05,   3.8984872E-05
     +,   3.8608399E-05,   3.8210012E-05,   3.7791033E-05
     +,   3.7352816E-05,   3.6896708E-05,   3.6424084E-05
     +,   3.5936311E-05,   3.5434750E-05,   3.4920758E-05
     +,   3.4395645E-05,   3.3860761E-05,   3.3317356E-05
     +,   3.2766697E-05,   3.2209991E-05,   3.1648429E-05
     +,   3.1083127E-05,   3.0515175E-05,   2.9945601E-05
     +,   2.9375415E-05,   2.8805525E-05,   2.8236791E-05
     +,   2.7670067E-05,   2.7106076E-05,   2.6545560E-05
     +,   2.5989129E-05,   2.5437414E-05,   2.4890909E-05
     +,   2.4350133E-05,   2.3815481E-05,   2.3287357E-05
     +,   2.2766077E-05,   2.2251896E-05,   2.1745067E-05
     +,   2.1245804E-05,   2.0754227E-05,   2.0270440E-05
     +,   1.9794552E-05,   1.9326573E-05,   1.8866553E-05
     +,   1.8414445E-05,   1.7970246E-05,   1.7533868E-05
     +,   1.7105263E-05,   1.6684315E-05,   1.6270942E-05
     +,   1.5865011E-05,   1.5466387E-05,   1.5074949E-05
     +,   1.4690572E-05,   1.4313101E-05,   1.3942383E-05
     +,   1.3578299E-05,   1.3220684E-05,   1.2869426E-05
     +,   1.2524368E-05,   1.2185404E-05,   1.1852389E-05
     +,   1.1525225E-05,   1.1203788E-05,   1.0887991E-05
     +,   1.0577734E-05,   1.0272918E-05,   9.9734771E-06
     +,   9.6793501E-06,   9.3904673E-06,   9.1067659E-06
     +,   8.8282231E-06,   8.5547863E-06,   8.2864499E-06
     +,   8.0231803E-06,   7.7649975E-06,   7.5118946E-06
     +,   7.2639209E-06,   7.0211104E-06,   6.7835540E-06
     +,   6.5513500E-06,   6.3246389E-06,   6.1036262E-06
     +,   5.8885771E-06,   5.6798208E-06,   5.4777888E-06
     +,   5.2830469E-06,   5.0962858E-06,   4.9183996E-06
     +,   4.7504686E-06,   4.5938523E-06,   4.4501853E-06
     +,   4.3214645E-06,   4.2100633E-06,   4.1188136E-06
     +,   4.0510263E-06,   4.0105483E-06,   4.0018058E-06
     +,   4.0298164E-06,   4.1002081E-06,   4.2192182E-06
     +,   4.3936470E-06,   4.6308010E-06,   4.9384148E-06
     +,   5.3245290E-06,   5.7972702E-06,   6.3647253E-06
     +,   7.0346764E-06,   7.8142793E-06,   8.7097842E-06
     +,   9.7262855E-06,   1.0867371E-05,   1.2134717E-05
     +,   1.3527867E-05,   1.5044120E-05,   1.6678307E-05
     +,   1.8422636E-05,   2.0266883E-05,   2.2198774E-05
     +,   2.4204361E-05,   2.6268432E-05,   2.8375804E-05
     +,   3.0512309E-05,   3.2666001E-05,   3.4828936E-05
     +,   3.6999212E-05,   3.9182953E-05,   4.1396390E-05
     +,   4.3668602E-05,   4.6044181E-05,   4.8585927E-05
     +,   5.1377443E-05,   5.4526176E-05,   5.8166497E-05
     +,   6.2462546E-05,   6.7610512E-05,   7.3842166E-05
     +,   8.1426915E-05,   9.0672984E-05,   1.0192861E-04
     +,   1.1558237E-04,   1.3206045E-04,   1.5182042E-04
     +,   1.7534343E-04,   2.0312337E-04,   2.3564869E-04
     +,   2.7337731E-04,   3.1671004E-04,   3.6596015E-04
     +,   4.2131529E-04,   4.8279116E-04,   5.5020349E-04
     +,   6.2312698E-04,   7.0086133E-04,   7.8241533E-04
     +,   8.6650957E-04,   9.5158390E-04,   1.0358226E-03
     +,   1.1172146E-03,   1.1936282E-03,   1.2628942E-03
     +,   1.3229002E-03,   1.3717021E-03,   1.4076299E-03
     +,   1.4293758E-03,   1.4360715E-03,   1.4273463E-03
     +,   1.4033490E-03,   1.3647474E-03,   1.3126937E-03
     +,   1.2487596E-03,   1.1748535E-03,   1.0931250E-03
     +,   1.0058525E-03,   9.1532833E-04,   8.2376006E-04
     +,   7.3318795E-04,   6.4540788E-04,   5.6191481E-04
     +,   4.8388148E-04,   4.1215745E-04,   3.4726560E-04
     +,   2.8943690E-04,   2.3865180E-04,   1.9467931E-04
     +,   1.5712272E-04,   1.2547015E-04,   9.9139645E-05
     +,   7.7514247E-05,   5.9972997E-05,   4.5917615E-05
     +,   3.4790930E-05,   2.6087162E-05,   1.9358020E-05
     +,   1.4215540E-05,   1.0330906E-05,   7.4297404E-06
     +,   5.2875271E-06,   3.7236171E-06,   2.5947675E-06
     +,   1.7890731E-06,   1.2204702E-06,   8.2371929E-07
     +,   5.5000925E-07,   3.6330914E-07,   2.3740002E-07
     +,   1.5345751E-07,   9.8133960E-08,   6.2088148E-08
     +,   3.8871217E-08,   2.4089660E-08,   1.4785722E-08
     +,   8.9956922E-09,   5.4326570E-09,   3.2637597E-09
     +,   1.9569355E-09,   1.1768250E-09,   7.1477557E-10
     +,   4.4258916E-10,   2.8250327E-10,   1.8796428E-10
     +,   1.3144751E-10,   9.6867951E-11,   7.4931672E-11
     +,   6.0324731E-11,   5.0034317E-11,   4.2358964E-11
     +,   3.6338432E-11,   3.1426303E-11,   2.7305254E-11
     +,   2.3784051E-11,   2.0741261E-11,   1.8094751E-11
     +,   1.5784811E-11,   1.3765053E-11,   1.1997765E-11
     +,   1.0451372E-11,   9.0985821E-12,   7.9157722E-12
     +,   6.8821359E-12,   5.9794717E-12,   5.1916817E-12
     +,   4.5046571E-12,   3.9058804E-12,   3.3844138E-12
     +,   2.9305668E-12,   2.5358673E-12,   2.1928423E-12
     +,   1.8949237E-12,   1.6363752E-12,   1.4121389E-12
     +,   1.2178088E-12,   1.0495046E-12,   9.0385148E-13
     +,   7.7787982E-13,   6.6901449E-13,   5.7499220E-13
     +,   4.9385111E-13,   4.2386995E-13,   3.6356066E-13
     +,   3.1161952E-13,   2.6691876E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz105 = Yx/0.00943478260869565
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0657692E-32,   7.5800619E-32
     +,   1.8619468E-31,   4.5438085E-31,   1.1016284E-30
     +,   2.6534562E-30,   6.3496398E-30,   1.5095481E-29
     +,   3.5653462E-29,   8.3661169E-29,   1.9503247E-28
     +,   4.5170222E-28,   1.0393428E-27,   2.3759069E-27
     +,   5.3958471E-27,   1.2174546E-26,   2.7290319E-26
     +,   6.0775175E-26,   1.3446382E-25,   2.9556158E-25
     +,   6.4543870E-25,   1.4003055E-24,   3.0181952E-24
     +,   6.4631954E-24,   1.3749885E-23,   2.9061528E-23
     +,   6.1024128E-23,   1.2730559E-22,   2.6385034E-22
     +,   5.4328979E-22,   1.1113960E-21,   2.2587617E-21
     +,   4.5607189E-21,   9.1487614E-21,   1.8232932E-20
     +,   3.6100424E-20,   7.1012460E-20,   1.3877631E-19
     +,   2.6944473E-19,   5.1973200E-19,   9.9600083E-19
     +,   1.8962847E-18,   3.5868433E-18,   6.7404181E-18
     +,   1.2584184E-17,   2.3341555E-17,   4.3012982E-17
     +,   7.8747158E-17,   1.4323028E-16,   2.5882180E-16
     +,   4.6465723E-16,   8.2876271E-16,   1.4685534E-15
     +,   2.5853716E-15,   4.5218299E-15,   7.8573470E-15
     +,   1.3564512E-14,   2.3264749E-14,   3.9642297E-14
     +,   6.7109980E-14,   1.1287058E-13,   1.8860149E-13
     +,   3.1308991E-13,   5.1636934E-13,   8.4610763E-13
     +,   1.3773716E-12,   2.2276679E-12,   3.5794024E-12
     +,   5.7140616E-12,   9.0623203E-12,   1.4279367E-11
     +,   2.2353184E-11,   3.4765146E-11,   5.3716819E-11
     +,   8.2460212E-11,   1.2576297E-10,   1.9055869E-10
     +,   2.8685848E-10,   4.2901704E-10,   6.3746380E-10
     +,   9.4102148E-10,   1.3801219E-09,   2.0109379E-09
     +,   2.9110763E-09,   4.1867048E-09,   5.9822569E-09
     +,   8.4922220E-09,   1.1977095E-08,   1.6782087E-08
     +,   2.3361990E-08,   3.2310769E-08,   4.4397044E-08
     +,   6.0607356E-08,   8.2198980E-08,   1.1075952E-07
     +,   1.4827265E-07,   1.9720351E-07,   2.6057572E-07
     +,   3.4207926E-07,   4.4615467E-07,   5.7811940E-07
     +,   7.4424514E-07,   9.5189245E-07,   1.2095562E-06
     +,   1.5269837E-06,   1.9152080E-06,   2.3865339E-06
     +,   2.9545154E-06,   3.6339179E-06,   4.4405529E-06
     +,   5.3909644E-06,   6.5023278E-06,   7.7918203E-06
     +,   9.2764521E-06,   1.0972179E-05,   1.2893670E-05
     +,   1.5053191E-05,   1.7460361E-05,   2.0120859E-05
     +,   2.3036186E-05,   2.6202781E-05,   2.9611132E-05
     +,   3.3245440E-05,   3.7083475E-05,   4.1096220E-05
     +,   4.5247420E-05,   4.9494774E-05,   5.3789387E-05
     +,   5.8077592E-05,   6.2300882E-05,   6.6398265E-05
     +,   7.0306589E-05,   7.3963260E-05,   7.7306897E-05
     +,   8.0279991E-05,   8.2830222E-05,   8.4911968E-05
     +,   8.6488049E-05,   8.7531123E-05,   8.8024455E-05
     +,   8.7962639E-05,   8.7352106E-05,   8.6211039E-05
     +,   8.4568921E-05,   8.2466133E-05,   7.9952595E-05
     +,   7.7086588E-05,   7.3933581E-05,   7.0564405E-05
     +,   6.7053239E-05,   6.3476211E-05,   5.9909900E-05
     +,   5.6429464E-05,   5.3107065E-05,   5.0010796E-05
     +,   4.7203866E-05,   4.4743443E-05,   4.2679920E-05
     +,   4.1056650E-05,   3.9909744E-05,   3.9267503E-05
     +,   3.9150516E-05,   3.9571478E-05,   4.0534829E-05
     +,   4.2036641E-05,   4.4064254E-05,   4.6595585E-05
     +,   4.9598661E-05,   5.3031239E-05,   5.6840214E-05
     +,   6.0960971E-05,   6.5317487E-05,   6.9823065E-05
     +,   7.4380914E-05,   7.8885249E-05,   8.3224273E-05
     +,   8.7282693E-05,   9.0944879E-05,   9.4099225E-05
     +,   9.6642601E-05,   9.8484459E-05,   9.9550933E-05
     +,   9.9788864E-05,   9.9168952E-05,   9.7688251E-05
     +,   9.5373041E-05,   9.2282535E-05,   8.8516048E-05
     +,   8.4228224E-05,   7.9658945E-05,   7.5185424E-05
     +,   7.1409297E-05,   6.9287737E-05,   7.0312017E-05
     +,   7.6725635E-05,   9.1751041E-05,   1.1975761E-04
     +,   1.6627484E-04,   2.3773362E-04,   3.4081173E-04
     +,   4.8131178E-04,   6.6263217E-04,   8.8402606E-04
     +,   1.1389613E-03,   1.4140522E-03,   1.6891884E-03
     +,   1.9391080E-03,   2.1366116E-03,   2.2570963E-03
     +,   2.2834272E-03,   2.2098657E-03,   2.0438530E-03
     +,   1.8048905E-03,   1.5206579E-03,   1.2215272E-03
     +,   9.3503564E-04,   6.8171893E-04,   4.7320066E-04
     +,   3.1258035E-04,   1.9641689E-04,   1.1735144E-04
     +,   6.6628418E-05,   3.5930119E-05,   1.8392711E-05
     +,   8.9324403E-06,   4.1135372E-06,   1.7958835E-06
     +,   7.4345263E-07,   2.9216025E-07,   1.0932718E-07
     +,   3.9246832E-08,   1.3739166E-08,   4.8478488E-09
     +,   1.8236418E-09,   7.8058615E-10,   3.9122200E-10
     +,   2.2243356E-10,   1.3572339E-10,   8.5286299E-11
     +,   5.4027463E-11,   3.4189415E-11,   2.1536970E-11
     +,   1.3487570E-11,   8.3930467E-12,   5.1885289E-12
     +,   3.1861228E-12,   1.9433285E-12,   1.1772217E-12
     +,   7.0821723E-13,   4.2311914E-13,   2.5102682E-13
     +,   1.4788176E-13,   8.6504785E-14,   5.0244788E-14
     +,   2.8976801E-14,   1.6592063E-14,   9.4328291E-15
     +,   5.3244919E-15,   2.9839679E-15,   1.6602714E-15
     +,   9.1714472E-16,   5.0300845E-16,   2.7389239E-16
     +,   1.4806194E-16,   7.9465931E-17,   4.2343137E-17
     +,   2.2399442E-17,   1.1764003E-17,   6.1339996E-18
     +,   3.1753640E-18,   1.6319085E-18,   8.3264104E-19
     +,   4.2178394E-19,   2.1212123E-19,   1.0590731E-19
     +,   5.2497683E-20,   2.5834700E-20,   1.2622269E-20
     +,   6.1224048E-21,   2.9483270E-21,   1.4095480E-21
     +,   6.6904129E-22,   3.1526570E-22,   1.4749284E-22
     +,   6.8503469E-23,   3.1588423E-23,   1.4461130E-23
     +,   6.5724230E-24,   2.9656340E-24,   1.3285010E-24
     +,   5.9084932E-25,   2.6087783E-25,   1.1435974E-25
     +,   4.9768520E-26,   2.1503467E-26,   9.2238262E-27
     +,   3.9281009E-27,   1.6607519E-27,   6.9710633E-28
     +,   2.9049743E-28,   1.2018659E-28
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz107 = Yx/0.00763636363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9699226E-05,   2.0633888E-05
     +,   2.1592981E-05,   2.2575819E-05,   2.3581626E-05
     +,   2.4609510E-05,   2.5658486E-05,   2.6727463E-05
     +,   2.7815222E-05,   2.8920491E-05,   3.0041852E-05
     +,   3.1177780E-05,   3.2326672E-05,   3.3486802E-05
     +,   3.4656368E-05,   3.5833458E-05,   3.7016089E-05
     +,   3.8202172E-05,   3.9389557E-05,   4.0576015E-05
     +,   4.1759253E-05,   4.2936910E-05,   4.4106568E-05
     +,   4.5265835E-05,   4.6412159E-05,   4.7543093E-05
     +,   4.8656082E-05,   4.9748625E-05,   5.0818184E-05
     +,   5.1862266E-05,   5.2878393E-05,   5.3864122E-05
     +,   5.4817065E-05,   5.5734901E-05,   5.6615361E-05
     +,   5.7456276E-05,   5.8255559E-05,   5.9011196E-05
     +,   5.9721358E-05,   6.0384264E-05,   6.0998304E-05
     +,   6.1561972E-05,   6.2073945E-05,   6.2533029E-05
     +,   6.2938183E-05,   6.3288535E-05,   6.3583379E-05
     +,   6.3822190E-05,   6.4004584E-05,   6.4130385E-05
     +,   6.4199565E-05,   6.4212276E-05,   6.4168860E-05
     +,   6.4069791E-05,   6.3915737E-05,   6.3707535E-05
     +,   6.3446125E-05,   6.3132669E-05,   6.2768413E-05
     +,   6.2354760E-05,   6.1893246E-05,   6.1385523E-05
     +,   6.0833339E-05,   6.0238559E-05,   5.9603095E-05
     +,   5.8929003E-05,   5.8218327E-05,   5.7473266E-05
     +,   5.6695939E-05,   5.5888620E-05,   5.5053504E-05
     +,   5.4192897E-05,   5.3309006E-05,   5.2404121E-05
     +,   5.1480449E-05,   5.0540162E-05,   4.9585458E-05
     +,   4.8618480E-05,   4.7641268E-05,   4.6655809E-05
     +,   4.5664099E-05,   4.4667944E-05,   4.3669221E-05
     +,   4.2669570E-05,   4.1670690E-05,   4.0674069E-05
     +,   3.9681225E-05,   3.8693463E-05,   3.7712121E-05
     +,   3.6738358E-05,   3.5773239E-05,   3.4817796E-05
     +,   3.3872981E-05,   3.2939603E-05,   3.2018364E-05
     +,   3.1110001E-05,   3.0215051E-05,   2.9334082E-05
     +,   2.8467477E-05,   2.7615682E-05,   2.6778949E-05
     +,   2.5957595E-05,   2.5151770E-05,   2.4361672E-05
     +,   2.3587394E-05,   2.2828966E-05,   2.2086449E-05
     +,   2.1359851E-05,   2.0649122E-05,   1.9954165E-05
     +,   1.9274947E-05,   1.8611314E-05,   1.7963186E-05
     +,   1.7330387E-05,   1.6712800E-05,   1.6110236E-05
     +,   1.5522559E-05,   1.4949563E-05,   1.4391114E-05
     +,   1.3847005E-05,   1.3317047E-05,   1.2801076E-05
     +,   1.2298929E-05,   1.1810411E-05,   1.1335333E-05
     +,   1.0873556E-05,   1.0424879E-05,   9.9891795E-06
     +,   9.5662654E-06,   9.1560296E-06,   8.7583121E-06
     +,   8.3730256E-06,   8.0000509E-06,   7.6393517E-06
     +,   7.2908929E-06,   6.9546909E-06,   6.6308476E-06
     +,   6.3195598E-06,   6.0211082E-06,   5.7359252E-06
     +,   5.4646512E-06,   5.2081591E-06,   4.9676078E-06
     +,   4.7445351E-06,   4.5409643E-06,   4.3594728E-06
     +,   4.2033494E-06,   4.0767418E-06,   3.9848210E-06
     +,   3.9339775E-06,   3.9320475E-06,   3.9885654E-06
     +,   4.1150242E-06,   4.3251830E-06,   4.6353821E-06
     +,   5.0648518E-06,   5.6360345E-06,   6.3749721E-06
     +,   7.3116043E-06,   8.4799485E-06,   9.9185281E-06
     +,   1.1670497E-05,   1.3783621E-05,   1.6310340E-05
     +,   1.9307847E-05,   2.2837754E-05,   2.6965416E-05
     +,   3.1759471E-05,   3.7291426E-05,   4.3634496E-05
     +,   5.0861963E-05,   5.9046015E-05,   6.8256792E-05
     +,   7.8560304E-05,   9.0015281E-05,   1.0267318E-04
     +,   1.1657524E-04,   1.3174933E-04,   1.4820835E-04
     +,   1.6594953E-04,   1.8495160E-04,   2.0517169E-04
     +,   2.2654502E-04,   2.4898525E-04,   2.7238269E-04
     +,   2.9660235E-04,   3.2148592E-04,   3.4685381E-04
     +,   3.7250580E-04,   3.9821985E-04,   4.2376012E-04
     +,   4.4887728E-04,   4.7331082E-04,   4.9679459E-04
     +,   5.1906303E-04,   5.3985399E-04,   5.5891246E-04
     +,   5.7599705E-04,   5.9088599E-04,   6.0338015E-04
     +,   6.1330682E-04,   6.2052469E-04,   6.2492758E-04
     +,   6.2644604E-04,   6.2504923E-04,   6.2074640E-04
     +,   6.1358616E-04,   6.0365704E-04,   5.9108512E-04
     +,   5.7603040E-04,   5.5868475E-04,   5.3926802E-04
     +,   5.1802408E-04,   4.9521279E-04,   4.7110682E-04
     +,   4.4598774E-04,   4.2013885E-04,   3.9383816E-04
     +,   3.6735524E-04,   3.4094928E-04,   3.1485956E-04
     +,   2.8930508E-04,   2.6448307E-04,   2.4056567E-04
     +,   2.1769686E-04,   1.9599355E-04,   1.7554733E-04
     +,   1.5642331E-04,   1.3866046E-04,   1.2227471E-04
     +,   1.0726201E-04,   9.3599534E-05,   8.1247388E-05
     +,   7.0152368E-05,   6.0251576E-05,   5.1472740E-05
     +,   4.3737986E-05,   3.6966409E-05,   3.1075459E-05
     +,   2.5982452E-05,   2.1606520E-05,   1.7870110E-05
     +,   1.4699519E-05,   1.2025502E-05,   9.7840302E-06
     +,   7.9166866E-06,   6.3705506E-06,   5.0981103E-06
     +,   4.0572427E-06,   3.2110192E-06,   2.5271793E-06
     +,   1.9778868E-06,   1.5393485E-06,   1.1913544E-06
     +,   9.1686400E-07,   7.0164879E-07,   5.3393046E-07
     +,   4.0401605E-07,   3.0398553E-07,   2.2742567E-07
     +,   1.6918338E-07,   1.2514334E-07,   9.2040999E-08
     +,   6.7308584E-08,   4.8941772E-08,   3.5383596E-08
     +,   2.5434838E-08,   1.8178675E-08,   1.2918263E-08
     +,   9.1274162E-09,   6.4118959E-09,   4.4784074E-09
     +,   3.1100262E-09,   2.1473543E-09,   1.4741385E-09
     +,   1.0061955E-09,   6.8285710E-10,   4.6078649E-10
     +,   3.0916661E-10,   2.0626974E-10,   1.3684823E-10
     +,   9.0291198E-11,   5.9249418E-11,   3.8674418E-11
     +,   2.5114690E-11,   1.6229752E-11,   1.0440189E-11
     +,   6.6880377E-12,   4.2692100E-12,   2.7175538E-12
     +,   1.7268354E-12,   1.0968363E-12,   6.9762978E-13
     +,   4.4529978E-13,   2.8603763E-13,   1.8548987E-13
     +,   1.2187321E-13,   8.1426090E-14,   5.5506676E-14
     +,   3.8702416E-14,   2.7638194E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz110 = Yx/0.00666666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2993892E-06,   3.5098462E-06
     +,   3.7296838E-06,   3.9590009E-06,   4.1978701E-06
     +,   4.4463404E-06,   4.7044296E-06,   4.9721298E-06
     +,   5.2493956E-06,   5.5361606E-06,   5.8323189E-06
     +,   6.1377273E-06,   6.4522137E-06,   6.7755700E-06
     +,   7.1075533E-06,   7.4478862E-06,   7.7962595E-06
     +,   8.1523267E-06,   8.5157199E-06,   8.8860324E-06
     +,   9.2628352E-06,   9.6456788E-06,   1.0034082E-05
     +,   1.0427578E-05,   1.0825641E-05,   1.1227785E-05
     +,   1.1633501E-05,   1.2042292E-05,   1.2453674E-05
     +,   1.2867183E-05,   1.3282392E-05,   1.3698907E-05
     +,   1.4116390E-05,   1.4534555E-05,   1.4953189E-05
     +,   1.5372163E-05,   1.5791440E-05,   1.6211079E-05
     +,   1.6631282E-05,   1.7052334E-05,   1.7474704E-05
     +,   1.7898983E-05,   1.8325936E-05,   1.8756498E-05
     +,   1.9191777E-05,   1.9633077E-05,   2.0081892E-05
     +,   2.0539914E-05,   2.1009035E-05,   2.1491351E-05
     +,   2.1989155E-05,   2.2504933E-05,   2.3041350E-05
     +,   2.3601280E-05,   2.4187688E-05,   2.4803750E-05
     +,   2.5452722E-05,   2.6137963E-05,   2.6862888E-05
     +,   2.7630946E-05,   2.8445575E-05,   2.9310171E-05
     +,   3.0227986E-05,   3.1202191E-05,   3.2235774E-05
     +,   3.3331366E-05,   3.4491441E-05,   3.5717971E-05
     +,   3.7012655E-05,   3.8376580E-05,   3.9810453E-05
     +,   4.1314252E-05,   4.2887496E-05,   4.4528850E-05
     +,   4.6236404E-05,   4.8007525E-05,   4.9838694E-05
     +,   5.1725568E-05,   5.3663149E-05,   5.5645622E-05
     +,   5.7666191E-05,   5.9717509E-05,   6.1791245E-05
     +,   6.3878608E-05,   6.5969885E-05,   6.8054986E-05
     +,   7.0123060E-05,   7.2163071E-05,   7.4163348E-05
     +,   7.6112126E-05,   7.7997531E-05,   7.9807476E-05
     +,   8.1529943E-05,   8.3153245E-05,   8.4665982E-05
     +,   8.6057022E-05,   8.7315973E-05,   8.8432927E-05
     +,   8.9398891E-05,   9.0205649E-05,   9.0846021E-05
     +,   9.1313799E-05,   9.1603964E-05,   9.1712653E-05
     +,   9.1637237E-05,   9.1376343E-05,   9.0929905E-05
     +,   9.0299152E-05,   8.9486552E-05,   8.8495821E-05
     +,   8.7331966E-05,   8.6001033E-05,   8.4510306E-05
     +,   8.2867889E-05,   8.1083075E-05,   7.9165678E-05
     +,   7.7126526E-05,   7.4976801E-05,   7.2728406E-05
     +,   7.0393486E-05,   6.7984358E-05,   6.5513654E-05
     +,   6.2994055E-05,   6.0437967E-05,   5.7857564E-05
     +,   5.5265005E-05,   5.2671690E-05,   5.0088875E-05
     +,   4.7526919E-05,   4.4995879E-05,   4.2504802E-05
     +,   4.0062321E-05,   3.7675978E-05,   3.5352838E-05
     +,   3.3098928E-05,   3.0919469E-05,   2.8819020E-05
     +,   2.6801335E-05,   2.4869276E-05,   2.3024983E-05
     +,   2.1270022E-05,   1.9605330E-05,   1.8031134E-05
     +,   1.6547201E-05,   1.5153023E-05,   1.3847636E-05
     +,   1.2629920E-05,   1.1498810E-05,   1.0453389E-05
     +,   9.4930519E-06,   8.6178743E-06,   7.8289768E-06
     +,   7.1288741E-06,   6.5219351E-06,   6.0150096E-06
     +,   5.6181539E-06,   5.3453709E-06,   5.2155115E-06
     +,   5.2533210E-06,   5.4904954E-06,   5.9668482E-06
     +,   6.7314813E-06,   7.8438452E-06,   9.3746949E-06
     +,   1.1407011E-05,   1.4036426E-05,   1.7371061E-05
     +,   2.1531067E-05,   2.6647778E-05,   3.2861706E-05
     +,   4.0319330E-05,   4.9169714E-05,   5.9560745E-05
     +,   7.1633687E-05,   8.5515800E-05,   1.0131649E-04
     +,   1.1911984E-04,   1.3897665E-04,   1.6089939E-04
     +,   1.8485826E-04,   2.1077608E-04,   2.3852302E-04
     +,   2.6791735E-04,   2.9872757E-04,   3.3067350E-04
     +,   3.6342835E-04,   3.9662680E-04,   4.2987498E-04
     +,   4.6275739E-04,   4.9484335E-04,   5.2570400E-04
     +,   5.5491895E-04,   5.8208458E-04,   6.0682517E-04
     +,   6.2880333E-04,   6.4772286E-04,   6.6333485E-04
     +,   6.7544193E-04,   6.8390148E-04,   6.8862509E-04
     +,   6.8957830E-04,   6.8677956E-04,   6.8029814E-04
     +,   6.7025027E-04,   6.5679790E-04,   6.4014265E-04
     +,   6.2052248E-04,   5.9820933E-04,   5.7350367E-04
     +,   5.4672809E-04,   5.1822350E-04,   4.8834638E-04
     +,   4.5746076E-04,   4.2593078E-04,   3.9411595E-04
     +,   3.6236740E-04,   3.3101902E-04,   3.0037988E-04
     +,   2.7073055E-04,   2.4232111E-04,   2.1536165E-04
     +,   1.9002255E-04,   1.6643427E-04,   1.4468556E-04
     +,   1.2482298E-04,   1.0685505E-04,   9.0756526E-05
     +,   7.6471035E-05,   6.3915271E-05,   5.2985262E-05
     +,   4.3562308E-05,   3.5517078E-05,   2.8714177E-05
     +,   2.3017215E-05,   1.8292889E-05,   1.4412993E-05
     +,   1.1257423E-05,   8.7159788E-06,   6.6891007E-06
     +,   5.0882691E-06,   3.8361932E-06,   2.8664604E-06
     +,   2.1227318E-06,   1.5578649E-06,   1.1330065E-06
     +,   8.1657407E-07,   5.8319358E-07,   4.1273353E-07
     +,   2.8943595E-07,   2.0112334E-07,   1.3848010E-07
     +,   9.4474537E-08,   6.3862146E-08,   4.2773376E-08
     +,   2.8385340E-08,   1.8663554E-08,   1.2158385E-08
     +,   7.8476718E-09,   5.0185611E-09,   3.1796650E-09
     +,   1.9959530E-09,   1.2413386E-09,   7.6487766E-10
     +,   4.6692333E-10,   2.8239930E-10,   1.6921405E-10
     +,   1.0045126E-10,   5.9077944E-11,   3.4423350E-11
     +,   1.9871483E-11,   1.1364409E-11,   6.4388772E-12
     +,   3.6143415E-12,   2.0099909E-12,   1.1073860E-12
     +,   6.0445236E-13,   3.2686671E-13,   1.7512463E-13
     +,   9.2957739E-14,   4.8890027E-14,   2.5477726E-14
     +,   1.3157335E-14,   6.7343338E-15,   3.4172085E-15
     +,   1.7197432E-15,   8.5898644E-16,   4.2629813E-16
     +,   2.1057919E-16,   1.0384094E-16,   5.1349235E-17
     +,   2.5642055E-17,   1.3060194E-17,   6.8738651E-18
     +,   3.7926777E-18,   2.2203726E-18,   1.3862371E-18
     +,   9.1933660E-19,   6.4059421E-19,   4.6277374E-19
     +,   3.4244081E-19,   2.5719480E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz115 = Yx/0.00665
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2661701E-05,   3.3707409E-05
     +,   3.4787932E-05,   3.5903689E-05,   3.7054957E-05
     +,   3.8241913E-05,   3.9464609E-05,   4.0722964E-05
     +,   4.2016734E-05,   4.3345575E-05,   4.4708937E-05
     +,   4.6106106E-05,   4.7536207E-05,   4.8998161E-05
     +,   5.0490729E-05,   5.2012449E-05,   5.3561667E-05
     +,   5.5136534E-05,   5.6735003E-05,   5.8354799E-05
     +,   5.9993468E-05,   6.1648330E-05,   6.3316482E-05
     +,   6.4994958E-05,   6.6680383E-05,   6.8369387E-05
     +,   7.0058355E-05,   7.1743496E-05,   7.3420910E-05
     +,   7.5086515E-05,   7.6736163E-05,   7.8365556E-05
     +,   7.9970327E-05,   8.1546073E-05,   8.3088300E-05
     +,   8.4592502E-05,   8.6054206E-05,   8.7468899E-05
     +,   8.8832232E-05,   9.0139743E-05,   9.1387250E-05
     +,   9.2570561E-05,   9.3685703E-05,   9.4728835E-05
     +,   9.5696283E-05,   9.6584648E-05,   9.7390694E-05
     +,   9.8111486E-05,   9.8744356E-05,   9.9286895E-05
     +,   9.9737015E-05,   1.0009296E-04,   1.0035327E-04
     +,   1.0051685E-04,   1.0058295E-04,   1.0055114E-04
     +,   1.0042136E-04,   1.0019391E-04,   9.9869445E-05
     +,   9.9448938E-05,   9.8933742E-05,   9.8325494E-05
     +,   9.7626216E-05,   9.6838157E-05,   9.5963900E-05
     +,   9.5006333E-05,   9.3968505E-05,   9.2853865E-05
     +,   9.1665897E-05,   9.0408430E-05,   8.9085326E-05
     +,   8.7700741E-05,   8.6258828E-05,   8.4763946E-05
     +,   8.3220482E-05,   8.1632810E-05,   8.0005426E-05
     +,   7.8342870E-05,   7.6649558E-05,   7.4929834E-05
     +,   7.3188181E-05,   7.1428738E-05,   6.9655842E-05
     +,   6.7873414E-05,   6.6085522E-05,   6.4295840E-05
     +,   6.2508123E-05,   6.0725721E-05,   5.8952053E-05
     +,   5.7190166E-05,   5.5442932E-05,   5.3713135E-05
     +,   5.2003350E-05,   5.0315859E-05,   4.8652739E-05
     +,   4.7016041E-05,   4.5407392E-05,   4.3828448E-05
     +,   4.2280473E-05,   4.0764735E-05,   3.9282160E-05
     +,   3.7833677E-05,   3.6419864E-05,   3.5041347E-05
     +,   3.3698474E-05,   3.2391436E-05,   3.1120424E-05
     +,   2.9885483E-05,   2.8686472E-05,   2.7523171E-05
     +,   2.6395384E-05,   2.5302676E-05,   2.4244700E-05
     +,   2.3220895E-05,   2.2230806E-05,   2.1273789E-05
     +,   2.0349285E-05,   1.9456606E-05,   1.8595145E-05
     +,   1.7764194E-05,   1.6963069E-05,   1.6191125E-05
     +,   1.5447733E-05,   1.4732234E-05,   1.4044015E-05
     +,   1.3382572E-05,   1.2747375E-05,   1.2138049E-05
     +,   1.1554243E-05,   1.0995804E-05,   1.0462641E-05
     +,   9.9549070E-06,   9.4729185E-06,   9.0173062E-06
     +,   8.5889533E-06,   8.1891212E-06,   7.8195453E-06
     +,   7.4824684E-06,   7.1807121E-06,   6.9178277E-06
     +,   6.6982011E-06,   6.5271706E-06,   6.4111573E-06
     +,   6.3578368E-06,   6.3763005E-06,   6.4772212E-06
     +,   6.6730522E-06,   6.9781909E-06,   7.4091636E-06
     +,   7.9848460E-06,   8.7266371E-06,   9.6585536E-06
     +,   1.0807393E-05,   1.2202911E-05,   1.3877881E-05
     +,   1.5867956E-05,   1.8211707E-05,   2.0950685E-05
     +,   2.4129127E-05,   2.7793352E-05,   3.1991985E-05
     +,   3.6775280E-05,   4.2194170E-05,   4.8299811E-05
     +,   5.5143260E-05,   6.2774328E-05,   7.1240014E-05
     +,   8.0583821E-05,   9.0845329E-05,   1.0205867E-04
     +,   1.1425028E-04,   1.2743850E-04,   1.4163334E-04
     +,   1.5683452E-04,   1.7302904E-04,   1.9019302E-04
     +,   2.0828987E-04,   2.2726817E-04,   2.4706256E-04
     +,   2.6759470E-04,   2.8877260E-04,   3.1048906E-04
     +,   3.3262381E-04,   3.5504575E-04,   3.7761277E-04
     +,   4.0017153E-04,   4.2256044E-04,   4.4461276E-04
     +,   4.6615765E-04,   4.8701922E-04,   5.0702365E-04
     +,   5.2599900E-04,   5.4377603E-04,   5.6019257E-04
     +,   5.7509582E-04,   5.8834394E-04,   5.9980724E-04
     +,   6.0937041E-04,   6.1693630E-04,   6.2242465E-04
     +,   6.2577438E-04,   6.2694540E-04,   6.2591844E-04
     +,   6.2269549E-04,   6.1730074E-04,   6.0977967E-04
     +,   6.0019828E-04,   5.8864366E-04,   5.7522231E-04
     +,   5.6005723E-04,   5.4328761E-04,   5.2506762E-04
     +,   5.0556345E-04,   4.8494944E-04,   4.6340693E-04
     +,   4.4112277E-04,   4.1828581E-04,   3.9508223E-04
     +,   3.7169468E-04,   3.4830204E-04,   3.2507267E-04
     +,   3.0216450E-04,   2.7972460E-04,   2.5788668E-04
     +,   2.3676766E-04,   2.1646894E-04,   1.9707700E-04
     +,   1.7866168E-04,   1.6127524E-04,   1.4495413E-04
     +,   1.2972072E-04,   1.1558303E-04,   1.0253496E-04
     +,   9.0558759E-05,   7.9627454E-05,   6.9703994E-05
     +,   6.0744016E-05,   5.2697931E-05,   4.5511541E-05
     +,   3.9127077E-05,   3.3485103E-05,   2.8525887E-05
     +,   2.4189996E-05,   2.0418936E-05,   1.7156264E-05
     +,   1.4348335E-05,   1.1944479E-05,   9.8972005E-06
     +,   8.1626267E-06,   6.7007163E-06,   5.4749457E-06
     +,   4.4524513E-06,   3.6039510E-06,   2.9034829E-06
     +,   2.3281689E-06,   1.8580563E-06,   1.4758876E-06
     +,   1.1668067E-06,   9.1810159E-07,   7.1899149E-07
     +,   5.6040182E-07,   4.3473094E-07,   3.3564649E-07
     +,   2.5791661E-07,   1.9725084E-07,   1.5013991E-07
     +,   1.1373823E-07,   8.5753783E-08,   6.4348740E-08
     +,   4.8057654E-08,   3.5720376E-08,   2.6424367E-08
     +,   1.9455044E-08,   1.4255907E-08,   1.0396513E-08
     +,   7.5460536E-09,   5.4510787E-09,   3.9190837E-09
     +,   2.8042522E-09,   1.9970527E-09,   1.4154453E-09
     +,   9.9847541E-10,   7.0099215E-10,   4.8981352E-10
     +,   3.4062830E-10,   2.3576174E-10,   1.6240705E-10
     +,   1.1134508E-10,   7.5977169E-11,   5.1597868E-11
     +,   3.4876203E-11,   2.3462112E-11,   1.5709387E-11
     +,   1.0468793E-11,   6.9437845E-12,   4.5840601E-12
     +,   3.0121647E-12,   1.9700511E-12,   1.2825372E-12
     +,   8.3111030E-13,   5.3613640E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz120 = Yx/0.00821739130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2807470E-05,   2.3418461E-05
     +,   2.4056320E-05,   2.4723757E-05,   2.5424062E-05
     +,   2.6161191E-05,   2.6939859E-05,   2.7765598E-05
     +,   2.8644801E-05,   2.9584864E-05,   3.0594092E-05
     +,   3.1681826E-05,   3.2858396E-05,   3.4135101E-05
     +,   3.5524150E-05,   3.7038582E-05,   3.8692138E-05
     +,   4.0499122E-05,   4.2474203E-05,   4.4632176E-05
     +,   4.6987756E-05,   4.9555299E-05,   5.2348438E-05
     +,   5.5380056E-05,   5.8661451E-05,   6.2202758E-05
     +,   6.6012130E-05,   7.0095826E-05,   7.4457981E-05
     +,   7.9100602E-05,   8.4023624E-05,   8.9225061E-05
     +,   9.4701390E-05,   1.0044805E-04,   1.0646017E-04
     +,   1.1273343E-04,   1.1926512E-04,   1.2605543E-04
     +,   1.3310919E-04,   1.4043634E-04,   1.4805497E-04
     +,   1.5599126E-04,   1.6428150E-04,   1.7297248E-04
     +,   1.8212172E-04,   1.9179695E-04,   2.0207441E-04
     +,   2.1303637E-04,   2.2476743E-04,   2.3734939E-04
     +,   2.5085590E-04,   2.6534547E-04,   2.8085453E-04
     +,   2.9739219E-04,   3.1493121E-04,   3.3340737E-04
     +,   3.5271471E-04,   3.7270656E-04,   3.9319909E-04
     +,   4.1397780E-04,   4.3480692E-04,   4.5544183E-04
     +,   4.7564038E-04,   4.9517961E-04,   5.1386689E-04
     +,   5.3154881E-04,   5.4812187E-04,   5.6353118E-04
     +,   5.7777326E-04,   5.9088541E-04,   6.0293963E-04
     +,   6.1402644E-04,   6.2424468E-04,   6.3368527E-04
     +,   6.4242247E-04,   6.5050379E-04,   6.5794750E-04
     +,   6.6474074E-04,   6.7084457E-04,   6.7620061E-04
     +,   6.8073702E-04,   6.8437809E-04,   6.8705092E-04
     +,   6.8869133E-04,   6.8924669E-04,   6.8867824E-04
     +,   6.8696146E-04,   6.8408507E-04,   6.8005204E-04
     +,   6.7487982E-04,   6.6860247E-04,   6.6127372E-04
     +,   6.5297127E-04,   6.4379908E-04,   6.3388771E-04
     +,   6.2339706E-04,   6.1250763E-04,   6.0141750E-04
     +,   5.9032743E-04,   5.7943293E-04,   5.6890654E-04
     +,   5.5888935E-04,   5.4947764E-04,   5.4071943E-04
     +,   5.3261168E-04,   5.2510406E-04,   5.1811006E-04
     +,   5.1151722E-04,   5.0520210E-04,   4.9904763E-04
     +,   4.9295626E-04,   4.8686200E-04,   4.8073803E-04
     +,   4.7459884E-04,   4.6849882E-04,   4.6252387E-04
     +,   4.5678235E-04,   4.5139040E-04,   4.4645887E-04
     +,   4.4207921E-04,   4.3831204E-04,   4.3517796E-04
     +,   4.3265268E-04,   4.3066562E-04,   4.2910234E-04
     +,   4.2781077E-04,   4.2660971E-04,   4.2529963E-04
     +,   4.2367386E-04,   4.2153063E-04,   4.1868354E-04
     +,   4.1497152E-04,   4.1026511E-04,   4.0447328E-04
     +,   3.9754470E-04,   3.8946880E-04,   3.8027501E-04
     +,   3.7002872E-04,   3.5882567E-04,   3.4678681E-04
     +,   3.3405289E-04,   3.2077671E-04,   3.0711622E-04
     +,   2.9322904E-04,   2.7926860E-04,   2.6537737E-04
     +,   2.5168437E-04,   2.3830385E-04,   2.2533280E-04
     +,   2.1284941E-04,   2.0091432E-04,   1.8957214E-04
     +,   1.7885181E-04,   1.6876771E-04,   1.5932224E-04
     +,   1.5050838E-04,   1.4231083E-04,   1.3470750E-04
     +,   1.2767166E-04,   1.2117407E-04,   1.1518277E-04
     +,   1.0966489E-04,   1.0458770E-04,   9.9918769E-05
     +,   9.5626187E-05,   9.1679089E-05,   8.8048109E-05
     +,   8.4705272E-05,   8.1623642E-05,   7.8777775E-05
     +,   7.6143806E-05,   7.3699273E-05,   7.1422881E-05
     +,   6.9294809E-05,   6.7296809E-05,   6.5411856E-05
     +,   6.3624400E-05,   6.1920407E-05,   6.0287290E-05
     +,   5.8713777E-05,   5.7190013E-05,   5.5707595E-05
     +,   5.4259450E-05,   5.2839645E-05,   5.1443389E-05
     +,   5.0067079E-05,   4.8708051E-05,   4.7364421E-05
     +,   4.6035042E-05,   4.4719516E-05,   4.3417873E-05
     +,   4.2130527E-05,   4.0858318E-05,   3.9602306E-05
     +,   3.8363622E-05,   3.7143465E-05,   3.5943151E-05
     +,   3.4763954E-05,   3.3606986E-05,   3.2473290E-05
     +,   3.1363819E-05,   3.0279416E-05,   2.9220681E-05
     +,   2.8188073E-05,   2.7182003E-05,   2.6202635E-05
     +,   2.5249994E-05,   2.4324061E-05,   2.3424682E-05
     +,   2.2551547E-05,   2.1704274E-05,   2.0882457E-05
     +,   2.0085628E-05,   1.9313216E-05,   1.8564619E-05
     +,   1.7839260E-05,   1.7136539E-05,   1.6455806E-05
     +,   1.5796413E-05,   1.5157773E-05,   1.4539256E-05
     +,   1.3940242E-05,   1.3360172E-05,   1.2798505E-05
     +,   1.2254683E-05,   1.1728178E-05,   1.1218519E-05
     +,   1.0725257E-05,   1.0247940E-05,   9.7861339E-06
     +,   9.3394665E-06,   8.9075793E-06,   8.4901076E-06
     +,   8.0867121E-06,   7.6971028E-06,   7.3209703E-06
     +,   6.9580196E-06,   6.6079929E-06,   6.2706404E-06
     +,   5.9456975E-06,   5.6329109E-06,   5.3320505E-06
     +,   5.0428898E-06,   4.7651870E-06,   4.4987014E-06
     +,   4.2432102E-06,   3.9984893E-06,   3.7642974E-06
     +,   3.5403898E-06,   3.3265424E-06,   3.1225059E-06
     +,   2.9280282E-06,   2.7428669E-06,   2.5667748E-06
     +,   2.3994887E-06,   2.2407451E-06,   2.0902858E-06
     +,   1.9478507E-06,   1.8131670E-06,   1.6859618E-06
     +,   1.5659700E-06,   1.4529245E-06,   1.3465507E-06
     +,   1.2465763E-06,   1.1527404E-06,   1.0647738E-06
     +,   9.8241082E-07,   9.0539578E-07,   8.3347493E-07
     +,   7.6639537E-07,   7.0390939E-07,   6.4577910E-07
     +,   5.9177256E-07,   5.4166009E-07,   4.9521964E-07
     +,   4.5224033E-07,   4.1251360E-07,   3.7584255E-07
     +,   3.4203427E-07,   3.1090735E-07,   2.8228450E-07
     +,   2.5599979E-07,   2.3189219E-07,   2.0981102E-07
     +,   1.8961097E-07,   1.7115669E-07,   1.5431844E-07
     +,   1.3897407E-07,   1.2500983E-07,   1.1231710E-07
     +,   1.0079569E-07,   9.0350134E-08,   8.0892747E-08
     +,   7.2340441E-08,   6.4616934E-08,   5.7650393E-08
     +,   5.1374936E-08,   4.5728889E-08,   4.0655880E-08
     +,   3.6103227E-08,   3.2023010E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz60 = Yx/0.0137307692307692
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4484998E-09,   6.0993339E-09
     +,   8.3154017E-09,   1.1272418E-08,   1.5194365E-08
     +,   2.0364842E-08,   2.7140112E-08,   3.5964529E-08
     +,   4.7387939E-08,   6.2086279E-08,   8.0882735E-08
     +,   1.0477275E-07,   1.3495011E-07,   1.7283442E-07
     +,   2.2009998E-07,   2.7870317E-07,   3.5091040E-07
     +,   4.3932209E-07,   5.4689298E-07,   6.7694577E-07
     +,   8.3317872E-07,   1.0196591E-06,   1.2408038E-06
     +,   1.5013686E-06,   1.8063510E-06,   2.1609885E-06
     +,   2.5706206E-06,   3.0406052E-06,   3.5761932E-06
     +,   4.1823864E-06,   4.8637899E-06,   5.6244498E-06
     +,   6.4677097E-06,   7.3960791E-06,   8.4111343E-06
     +,   9.5134956E-06,   1.0702869E-05,   1.1978212E-05
     +,   1.3338174E-05,   1.4781403E-05,   1.6307653E-05
     +,   1.7918610E-05,   1.9619431E-05,   2.1420465E-05
     +,   2.3339320E-05,   2.5403198E-05,   2.7651402E-05
     +,   3.0137768E-05,   3.2932905E-05,   3.6125752E-05
     +,   3.9824405E-05,   4.4155528E-05,   4.9262355E-05
     +,   5.5301629E-05,   6.2437575E-05,   7.0837341E-05
     +,   8.0663660E-05,   9.2069655E-05,   1.0519485E-04
     +,   1.2016387E-04,   1.3708802E-04,   1.5607011E-04
     +,   1.7720844E-04,   2.0060496E-04,   2.2636565E-04
     +,   2.5459283E-04,   2.8537866E-04,   3.1877682E-04
     +,   3.5478253E-04,   3.9329429E-04,   4.3409510E-04
     +,   4.7682261E-04,   5.2097044E-04,   5.6587951E-04
     +,   6.1075884E-04,   6.5470109E-04,   6.9670100E-04
     +,   7.3568925E-04,   7.7057304E-04,   8.0029212E-04
     +,   8.2389632E-04,   8.4066048E-04,   8.5020537E-04
     +,   8.5263967E-04,   8.4869523E-04,   8.3984836E-04
     +,   8.2841935E-04,   8.1762031E-04,   8.1152789E-04
     +,   8.1491191E-04,   8.3287223E-04,   8.7022100E-04
     +,   9.3064195E-04,   1.0157317E-03,   1.1241215E-03
     +,   1.2509333E-03,   1.3878758E-03,   1.5240173E-03
     +,   1.6473021E-03,   1.7464135E-03,   1.8126651E-03
     +,   1.8413384E-03,   1.8321993E-03,   1.7890192E-03
     +,   1.7183285E-03,   1.6278140E-03,   1.5248703E-03
     +,   1.4156624E-03,   1.3048479E-03,   1.1958499E-03
     +,   1.0913748E-03,   9.9382550E-04,   9.0548390E-04
     +,   8.2835177E-04,   7.6385489E-04,   7.1250577E-04
     +,   6.7375717E-04,   6.4604235E-04,   6.2704284E-04
     +,   6.1404996E-04,   6.0435990E-04,   5.9559906E-04
     +,   5.8594125E-04,   5.7420379E-04,   5.5983959E-04
     +,   5.4284924E-04,   5.2364462E-04,   5.0289911E-04
     +,   4.8139523E-04,   4.5990408E-04,   4.3908603E-04
     +,   4.1943704E-04,   4.0125949E-04,   3.8467086E-04
     +,   3.6962554E-04,   3.5595457E-04,   3.4341050E-04
     +,   3.3170884E-04,   3.2056370E-04,   3.0971723E-04
     +,   2.9895842E-04,   2.8813176E-04,   2.7713849E-04
     +,   2.6593276E-04,   2.5451474E-04,   2.4291860E-04
     +,   2.3120313E-04,   2.1944313E-04,   2.0772053E-04
     +,   1.9611709E-04,   1.8471078E-04,   1.7357290E-04
     +,   1.6276575E-04,   1.5234068E-04,   1.4233870E-04
     +,   1.3279120E-04,   1.2372003E-04,   1.1513748E-04
     +,   1.0704825E-04,   9.9451150E-05,   9.2338632E-05
     +,   8.5698950E-05,   7.9517464E-05,   7.3777155E-05
     +,   6.8459100E-05,   6.3543499E-05,   5.9010439E-05
     +,   5.4839864E-05,   5.1011448E-05,   4.7505011E-05
     +,   4.4300770E-05,   4.1379022E-05,   3.8719954E-05
     +,   3.6303922E-05,   3.4111647E-05,   3.2123822E-05
     +,   3.0321497E-05,   2.8686287E-05,   2.7200398E-05
     +,   2.5846679E-05,   2.4608898E-05,   2.3471959E-05
     +,   2.2421900E-05,   2.1445914E-05,   2.0532509E-05
     +,   1.9671557E-05,   1.8854238E-05,   1.8072942E-05
     +,   1.7321288E-05,   1.6594116E-05,   1.5887219E-05
     +,   1.5197371E-05,   1.4522221E-05,   1.3860159E-05
     +,   1.3210159E-05,   1.2571727E-05,   1.1944839E-05
     +,   1.1329806E-05,   1.0727161E-05,   1.0137617E-05
     +,   9.5620417E-06,   9.0013655E-06,   8.4564990E-06
     +,   7.9283236E-06,   7.4177169E-06,   6.9254261E-06
     +,   6.4520964E-06,   5.9982940E-06,   5.5644578E-06
     +,   5.1508737E-06,   4.7577037E-06,   4.3850109E-06
     +,   4.0327368E-06,   3.7006851E-06,   3.3885565E-06
     +,   3.0959795E-06,   2.8224906E-06,   2.5675342E-06
     +,   2.3304910E-06,   2.1107089E-06,   1.9074689E-06
     +,   1.7200183E-06,   1.5475922E-06,   1.3894053E-06
     +,   1.2446552E-06,   1.1125389E-06,   9.9226759E-07
     +,   8.8306240E-07,   7.8415434E-07,   6.9479574E-07
     +,   6.1427124E-07,   5.4189161E-07,   4.7699319E-07
     +,   4.1894512E-07,   3.6715676E-07,   3.2106516E-07
     +,   2.8014335E-07,   2.4390164E-07,   2.1188420E-07
     +,   1.8366636E-07,   1.5885693E-07,   1.3709763E-07
     +,   1.1806010E-07,   1.0144340E-07,   8.6973976E-08
     +,   7.4405058E-08,   6.3513355E-08,   5.4097256E-08
     +,   4.5975892E-08,   3.8988322E-08,   3.2990336E-08
     +,   2.7853760E-08,   2.3465420E-08,   1.9725244E-08
     +,   1.6544890E-08,   1.3846831E-08,   1.1563361E-08
     +,   9.6353476E-09,   8.0112139E-09,   6.6462120E-09
     +,   5.5017018E-09,   4.5443334E-09,   3.7453320E-09
     +,   3.0800300E-09,   2.5273785E-09,   2.0693451E-09
     +,   1.6905942E-09,   1.3781420E-09,   1.1209805E-09
     +,   9.0980928E-10,   7.3679446E-10,   5.9537442E-10
     +,   4.8004700E-10,   3.8621153E-10,   3.1003511E-10
     +,   2.4834027E-10,   1.9848452E-10,   1.5829156E-10
     +,   1.2595994E-10,   1.0001333E-10,   7.9236895E-11
     +,   6.2639359E-11,   4.9409671E-11,   3.8888944E-11
     +,   3.0541115E-11,   2.3932868E-11,   1.8713368E-11
     +,   1.4599998E-11,   1.1365904E-11,   8.8287589E-12
     +,   6.8429928E-12,   5.2921933E-12,   4.0839207E-12
     +,   3.1445736E-12,   2.4160042E-12,   1.8521534E-12
     +,   1.4167975E-12,   1.0813885E-12,   8.2358285E-13
     +,   6.2585733E-13,   4.7456402E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz65 = Yx/0.0160740740740741
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9799782E-05,   2.0548858E-05
     +,   2.1310630E-05,   2.2084616E-05,   2.2870281E-05
     +,   2.3667046E-05,   2.4474284E-05,   2.5291316E-05
     +,   2.6117397E-05,   2.6951775E-05,   2.7793603E-05
     +,   2.8641989E-05,   2.9496010E-05,   3.0354697E-05
     +,   3.1217041E-05,   3.2082022E-05,   3.2948592E-05
     +,   3.3815719E-05,   3.4682402E-05,   3.5547648E-05
     +,   3.6410565E-05,   3.7270322E-05,   3.8126222E-05
     +,   3.8977741E-05,   3.9824477E-05,   4.0666295E-05
     +,   4.1503296E-05,   4.2335862E-05,   4.3164695E-05
     +,   4.3990854E-05,   4.4815810E-05,   4.5641453E-05
     +,   4.6470141E-05,   4.7304740E-05,   4.8148690E-05
     +,   4.9006012E-05,   4.9881390E-05,   5.0780243E-05
     +,   5.1708863E-05,   5.2674335E-05,   5.3684929E-05
     +,   5.4750082E-05,   5.5880635E-05,   5.7089092E-05
     +,   5.8389862E-05,   5.9799608E-05,   6.1337538E-05
     +,   6.3025800E-05,   6.4889849E-05,   6.6958717E-05
     +,   6.9265356E-05,   7.1846742E-05,   7.4743846E-05
     +,   7.8001642E-05,   8.1667968E-05,   8.5793501E-05
     +,   9.0429712E-05,   9.5627598E-05,   1.0143517E-04
     +,   1.0789504E-04,   1.1504122E-04,   1.2289583E-04
     +,   1.3146517E-04,   1.4073738E-04,   1.5067852E-04
     +,   1.6122921E-04,   1.7230520E-04,   1.8379348E-04
     +,   1.9555635E-04,   2.0742996E-04,   2.1923121E-04
     +,   2.3075980E-04,   2.4180791E-04,   2.5216528E-04
     +,   2.6163165E-04,   2.7002627E-04,   2.7719984E-04
     +,   2.8304858E-04,   2.8752882E-04,   2.9067113E-04
     +,   2.9259454E-04,   2.9351909E-04,   2.9377377E-04
     +,   2.9380014E-04,   2.9414755E-04,   2.9546226E-04
     +,   2.9846898E-04,   3.0395115E-04,   3.1273067E-04
     +,   3.2565574E-04,   3.4359601E-04,   3.6744017E-04
     +,   3.9809159E-04,   4.3644715E-04,   4.8334175E-04
     +,   5.3944736E-04,   6.0516089E-04,   6.8046158E-04
     +,   7.6484086E-04,   8.5727597E-04,   9.5635012E-04
     +,   1.0604198E-03,   1.1678622E-03,   1.2772204E-03
     +,   1.3872773E-03,   1.4969388E-03,   1.6050251E-03
     +,   1.7100896E-03,   1.8103690E-03,   1.9039254E-03
     +,   1.9889341E-03,   2.0639789E-03,   2.1281100E-03
     +,   2.1805922E-03,   2.2203352E-03,   2.2452944E-03
     +,   2.2521319E-03,   2.2364764E-03,   2.1938351E-03
     +,   2.1209596E-03,   2.0172375E-03,   1.8856007E-03
     +,   1.7325782E-03,   1.5674096E-03,   1.4005123E-03
     +,   1.2417629E-03,   1.0990057E-03,   9.7726681E-04
     +,   8.7860838E-04,   8.0262864E-04,   7.4722298E-04
     +,   7.0942380E-04,   6.8604399E-04,   6.7409483E-04
     +,   6.7094847E-04,   6.7434215E-04,   6.8229320E-04
     +,   6.9300295E-04,   7.0478889E-04,   7.1605732E-04
     +,   7.2532071E-04,   7.3124113E-04,   7.3268788E-04
     +,   7.2879146E-04,   7.1898842E-04,   7.0304243E-04
     +,   6.8104418E-04,   6.5338990E-04,   6.2073633E-04
     +,   5.8393984E-04,   5.4398976E-04,   5.0194334E-04
     +,   4.5885870E-04,   4.1573530E-04,   3.7347243E-04
     +,   3.3284086E-04,   2.9446027E-04,   2.5879021E-04
     +,   2.2613592E-04,   1.9666202E-04,   1.7040296E-04
     +,   1.4728744E-04,   1.2716197E-04,   1.0981171E-04
     +,   9.4981093E-05,   8.2394457E-05,   7.1773051E-05
     +,   6.2846528E-05,   5.5362118E-05,   4.9091410E-05
     +,   4.3834043E-05,   3.9417755E-05,   3.5697343E-05
     +,   3.2552714E-05,   2.9886054E-05,   2.7617842E-05
     +,   2.5683836E-05,   2.4032106E-05,   2.2620070E-05
     +,   2.1412303E-05,   2.0378831E-05,   1.9493928E-05
     +,   1.8735029E-05,   1.8082130E-05,   1.7517403E-05
     +,   1.7024984E-05,   1.6590780E-05,   1.6202335E-05
     +,   1.5848804E-05,   1.5520891E-05,   1.5210708E-05
     +,   1.4911703E-05,   1.4618573E-05,   1.4327118E-05
     +,   1.4034094E-05,   1.3737118E-05,   1.3434537E-05
     +,   1.3125325E-05,   1.2808925E-05,   1.2485199E-05
     +,   1.2154352E-05,   1.1816837E-05,   1.1473289E-05
     +,   1.1124476E-05,   1.0771308E-05,   1.0414717E-05
     +,   1.0055684E-05,   9.6952272E-06,   9.3343624E-06
     +,   8.9740688E-06,   8.6153022E-06,   8.2590022E-06
     +,   7.9060719E-06,   7.5573412E-06,   7.2135908E-06
     +,   6.8755671E-06,   6.5439635E-06,   6.2193858E-06
     +,   5.9023901E-06,   5.5934961E-06,   5.2931368E-06
     +,   5.0016870E-06,   4.7194794E-06,   4.4467929E-06
     +,   4.1838293E-06,   3.9307415E-06,   3.6876461E-06
     +,   3.4546122E-06,   3.2316441E-06,   3.0187084E-06
     +,   2.8157438E-06,   2.6226501E-06,   2.4392812E-06
     +,   2.2654610E-06,   2.1010032E-06,   1.9456791E-06
     +,   1.7992389E-06,   1.6614250E-06,   1.5319624E-06
     +,   1.4105540E-06,   1.2968943E-06,   1.1906761E-06
     +,   1.0915863E-06,   9.9930253E-07,   9.1350068E-07
     +,   8.3386368E-07,   7.6007575E-07,   6.9181976E-07
     +,   6.2878473E-07,   5.7067217E-07,   5.1718479E-07
     +,   4.6803424E-07,   4.2294491E-07,   3.8165030E-07
     +,   3.4389180E-07,   3.0942181E-07,   2.7800613E-07
     +,   2.4942119E-07,   2.2345334E-07,   1.9990009E-07
     +,   1.7857208E-07,   1.5929045E-07,   1.4188632E-07
     +,   1.2620124E-07,   1.1208905E-07,   9.9411508E-08
     +,   8.8040544E-08,   7.7857990E-08,   6.8754261E-08
     +,   6.0627627E-08,   5.3384323E-08,   4.6938723E-08
     +,   4.1212143E-08,   3.6132096E-08,   3.1632496E-08
     +,   2.7653497E-08,   2.4140093E-08,   2.1042837E-08
     +,   1.8316479E-08,   1.5920463E-08,   1.3817891E-08
     +,   1.1975792E-08,   1.0364273E-08,   8.9567385E-09
     +,   7.7291773E-09,   6.6602861E-09,   5.7309544E-09
     +,   4.9241677E-09,   4.2248907E-09,   3.6196830E-09
     +,   3.0967169E-09,   2.6454829E-09,   2.2567563E-09
     +,   1.9223683E-09,   1.6351780E-09,   1.3888817E-09
     +,   1.1779913E-09,   9.9767949E-10,   8.4375568E-10
     +,   7.1254780E-10,   6.0088101E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz70 = Yx/0.0197931034482759
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0147024E-05,   1.0606183E-05
     +,   1.1076288E-05,   1.1557458E-05,   1.2049886E-05
     +,   1.2553825E-05,   1.3069614E-05,   1.3597670E-05
     +,   1.4138498E-05,   1.4692734E-05,   1.5261085E-05
     +,   1.5844389E-05,   1.6443593E-05,   1.7059781E-05
     +,   1.7694154E-05,   1.8348050E-05,   1.9022946E-05
     +,   1.9720454E-05,   2.0442323E-05,   2.1190457E-05
     +,   2.1966880E-05,   2.2773766E-05,   2.3613413E-05
     +,   2.4488290E-05,   2.5400890E-05,   2.6353926E-05
     +,   2.7350132E-05,   2.8392344E-05,   2.9483450E-05
     +,   3.0626361E-05,   3.1823984E-05,   3.3079195E-05
     +,   3.4394776E-05,   3.5773395E-05,   3.7217538E-05
     +,   3.8729479E-05,   4.0311199E-05,   4.1964333E-05
     +,   4.3690259E-05,   4.5489731E-05,   4.7363286E-05
     +,   4.9310864E-05,   5.1332008E-05,   5.3425818E-05
     +,   5.5591041E-05,   5.7826132E-05,   6.0129387E-05
     +,   6.2499086E-05,   6.4933658E-05,   6.7431916E-05
     +,   6.9993293E-05,   7.2618037E-05,   7.5307515E-05
     +,   7.8064535E-05,   8.0893180E-05,   8.3799532E-05
     +,   8.6791246E-05,   8.9877838E-05,   9.3070434E-05
     +,   9.6381569E-05,   9.9824712E-05,   1.0341389E-04
     +,   1.0716255E-04,   1.1108334E-04,   1.1518679E-04
     +,   1.1947988E-04,   1.2396589E-04,   1.2864220E-04
     +,   1.3350058E-04,   1.3852511E-04,   1.4369303E-04
     +,   1.4897334E-04,   1.5432856E-04,   1.5971415E-04
     +,   1.6508128E-04,   1.7037839E-04,   1.7555349E-04
     +,   1.8055766E-04,   1.8534879E-04,   1.8989517E-04
     +,   1.9417853E-04,   1.9819877E-04,   2.0197590E-04
     +,   2.0555341E-04,   2.0899904E-04,   2.1240623E-04
     +,   2.1589288E-04,   2.1960083E-04,   2.2369255E-04
     +,   2.2834830E-04,   2.3376184E-04,   2.4013464E-04
     +,   2.4767022E-04,   2.5656732E-04,   2.6701190E-04
     +,   2.7916644E-04,   2.9316213E-04,   3.0908387E-04
     +,   3.2696297E-04,   3.4676126E-04,   3.6836771E-04
     +,   3.9158855E-04,   4.1615570E-04,   4.4173130E-04
     +,   4.6793456E-04,   4.9436925E-04,   5.2065914E-04
     +,   5.4649008E-04,   5.7164842E-04,   5.9604563E-04
     +,   6.1972730E-04,   6.4286782E-04,   6.6573452E-04
     +,   6.8864232E-04,   7.1188639E-04,   7.3568290E-04
     +,   7.6011237E-04,   7.8509806E-04,   8.1042206E-04
     +,   8.3580415E-04,   8.6103525E-04,   8.8615710E-04
     +,   9.1165089E-04,   9.3857775E-04,   9.6859701E-04
     +,   1.0038000E-03,   1.0463579E-03,   1.0979829E-03
     +,   1.1593524E-03,   1.2295997E-03,   1.3060884E-03
     +,   1.3845186E-03,   1.4594673E-03,   1.5251874E-03
     +,   1.5765519E-03,   1.6098565E-03,   1.6233074E-03
     +,   1.6170907E-03,   1.5930289E-03,   1.5539592E-03
     +,   1.5030454E-03,   1.4431936E-03,   1.3767041E-03
     +,   1.3052054E-03,   1.2298136E-03,   1.1513828E-03
     +,   1.0707646E-03,   9.8897773E-04,   9.0723729E-04
     +,   8.2686840E-04,   7.4916845E-04,   6.7526253E-04
     +,   6.0598936E-04,   5.4185209E-04,   4.8304294E-04
     +,   4.2950915E-04,   3.8103128E-04,   3.3729814E-04
     +,   2.9796970E-04,   2.6271565E-04,   2.3122120E-04
     +,   2.0319158E-04,   1.7834760E-04,   1.5641708E-04
     +,   1.3713118E-04,   1.2022748E-04,   1.0545486E-04
     +,   9.2577124E-05,   8.1376602E-05,   7.1657865E-05
     +,   6.3248612E-05,   5.5997407E-05,   4.9770941E-05
     +,   4.4451372E-05,   3.9933806E-05,   3.6122638E-05
     +,   3.2930253E-05,   3.0275922E-05,   2.8084842E-05
     +,   2.6287786E-05,   2.4821347E-05,   2.3628072E-05
     +,   2.2656483E-05,   2.1861049E-05,   2.1202221E-05
     +,   2.0646241E-05,   2.0164760E-05,   1.9734400E-05
     +,   1.9336312E-05,   1.8955670E-05,   1.8581077E-05
     +,   1.8204057E-05,   1.7818611E-05,   1.7420738E-05
     +,   1.7008017E-05,   1.6579281E-05,   1.6134371E-05
     +,   1.5673868E-05,   1.5198873E-05,   1.4710871E-05
     +,   1.4211651E-05,   1.3703182E-05,   1.3187497E-05
     +,   1.2666679E-05,   1.2142861E-05,   1.1618093E-05
     +,   1.1094360E-05,   1.0573611E-05,   1.0057689E-05
     +,   9.5482974E-06,   9.0470221E-06,   8.5553502E-06
     +,   8.0746422E-06,   7.6060874E-06,   7.1507384E-06
     +,   6.7095407E-06,   6.2833042E-06,   5.8726732E-06
     +,   5.4781631E-06,   5.1002030E-06,   4.7390631E-06
     +,   4.3948980E-06,   4.0677814E-06,   3.7576792E-06
     +,   3.4644511E-06,   3.1878678E-06,   2.9276464E-06
     +,   2.6834311E-06,   2.4547924E-06,   2.2412498E-06
     +,   2.0422935E-06,   1.8573754E-06,   1.6859073E-06
     +,   1.5272800E-06,   1.3808848E-06,   1.2460883E-06
     +,   1.1222533E-06,   1.0087547E-06,   9.0496974E-07
     +,   8.1027986E-07,   7.2408022E-07,   6.4578921E-07
     +,   5.7484272E-07,   5.1069264E-07,   4.5281504E-07
     +,   4.0071416E-07,   3.5391778E-07,   3.1197712E-07
     +,   2.7446919E-07,   2.4100086E-07,   2.1120120E-07
     +,   1.8472446E-07,   1.6125188E-07,   1.4048814E-07
     +,   1.2215934E-07,   1.0601430E-07,   9.1823622E-08
     +,   7.9377735E-08,   6.8485043E-08,   5.8971590E-08
     +,   5.0680672E-08,   4.3470695E-08,   3.7213706E-08
     +,   3.1795071E-08,   2.7112600E-08,   2.3074653E-08
     +,   1.9599680E-08,   1.6615564E-08,   1.4058416E-08
     +,   1.1871613E-08,   1.0005375E-08,   8.4160661E-09
     +,   7.0654504E-09,   5.9200165E-09,   4.9505777E-09
     +,   4.1318442E-09,   3.4417691E-09,   2.8613738E-09
     +,   2.3741991E-09,   1.9661412E-09,   1.6250326E-09
     +,   1.3404940E-09,   1.1036134E-09,   9.0682639E-10
     +,   7.4367135E-10,   6.0868555E-10,   4.9723026E-10
     +,   4.0538889E-10,   3.2986905E-10,   2.6789229E-10
     +,   2.1713724E-10,   1.7565405E-10,   1.4181999E-10
     +,   1.1427891E-10,   9.1907239E-11,   7.3770566E-11
     +,   5.9097831E-11,   4.7250908E-11,   3.7705419E-11
     +,   3.0029378E-11,   2.3869578E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz75 = Yx/0.0155555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.1848516E-10,   9.4702035E-10
     +,   1.2437251E-09,   1.6274700E-09,   2.1219022E-09
     +,   2.7565190E-09,   3.5679608E-09,   4.6015431E-09
     +,   5.9130083E-09,   7.5707645E-09,   9.6581712E-09
     +,   1.2276491E-08,   1.5548142E-08,   1.9620389E-08
     +,   2.4669566E-08,   3.0905873E-08,   3.8578591E-08
     +,   4.7981956E-08,   5.9461563E-08,   7.3421297E-08
     +,   9.0330708E-08,   1.1073315E-07,   1.3525337E-07
     +,   1.6460817E-07,   1.9961067E-07,   2.4118495E-07
     +,   2.9036931E-07,   3.4832695E-07,   4.1635192E-07
     +,   4.9587629E-07,   5.8847479E-07,   6.9586741E-07
     +,   8.1992022E-07,   9.6264637E-07,   1.1261993E-06
     +,   1.3128670E-06,   1.5250632E-06,   1.7653061E-06
     +,   2.0362240E-06,   2.3404880E-06,   2.6808443E-06
     +,   3.0600427E-06,   3.4808202E-06,   3.9458660E-06
     +,   4.4577832E-06,   5.0190492E-06,   5.6319750E-06
     +,   6.2986669E-06,   7.0209840E-06,   7.8005005E-06
     +,   8.6384716E-06,   9.5358018E-06,   1.0492999E-05
     +,   1.1510236E-05,   1.2587151E-05,   1.3723082E-05
     +,   1.4916857E-05,   1.6166914E-05,   1.7471264E-05
     +,   1.8827533E-05,   2.0232983E-05,   2.1684549E-05
     +,   2.3178789E-05,   2.4712099E-05,   2.6280677E-05
     +,   2.7880395E-05,   2.9507208E-05,   3.1156789E-05
     +,   3.2825010E-05,   3.4507557E-05,   3.6200403E-05
     +,   3.7899452E-05,   3.9601000E-05,   4.1301337E-05
     +,   4.2997195E-05,   4.4685617E-05,   4.6363872E-05
     +,   4.8029597E-05,   4.9680937E-05,   5.1316405E-05
     +,   5.2934796E-05,   5.4535481E-05,   5.6118017E-05
     +,   5.7682526E-05,   5.9229278E-05,   6.0759070E-05
     +,   6.2272840E-05,   6.3772095E-05,   6.5258595E-05
     +,   6.6734814E-05,   6.8203910E-05,   6.9669935E-05
     +,   7.1138238E-05,   7.2615861E-05,   7.4111871E-05
     +,   7.5637632E-05,   7.7207529E-05,   7.8838821E-05
     +,   8.0552207E-05,   8.2371305E-05,   8.4322579E-05
     +,   8.6434149E-05,   8.8735003E-05,   9.1252587E-05
     +,   9.4011142E-05,   9.7028817E-05,   1.0031436E-04
     +,   1.0386419E-04,   1.0765951E-04,   1.1166346E-04
     +,   1.1581865E-04,   1.2004718E-04,   1.2425006E-04
     +,   1.2831055E-04,   1.3209738E-04,   1.3547273E-04
     +,   1.3830050E-04,   1.4045979E-04,   1.4185916E-04
     +,   1.4245561E-04,   1.4227390E-04,   1.4142814E-04
     +,   1.4014180E-04,   1.3876526E-04,   1.3778931E-04
     +,   1.3785431E-04,   1.3975475E-04,   1.4444119E-04
     +,   1.5301984E-04,   1.6674367E-04,   1.8699515E-04
     +,   2.1524214E-04,   2.5298001E-04,   3.0163993E-04
     +,   3.6250430E-04,   4.3661500E-04,   5.2467908E-04
     +,   6.2696415E-04,   7.4314687E-04,   8.7206421E-04
     +,   1.0113866E-03,   1.1572972E-03,   1.3042972E-03
     +,   1.4452714E-03,   1.5719683E-03,   1.6759847E-03
     +,   1.7500373E-03,   1.7892895E-03,   1.7922977E-03
     +,   1.7611836E-03,   1.7008723E-03,   1.6176264E-03
     +,   1.5173920E-03,   1.4046129E-03,   1.2820072E-03
     +,   1.1512955E-03,   1.0144267E-03,   8.7462086E-04
     +,   7.3670672E-04,   6.0658623E-04,   4.9005786E-04
     +,   3.9160255E-04,   3.1355009E-04,   2.5585757E-04
     +,   2.1647479E-04,   1.9206376E-04,   1.7878189E-04
     +,   1.7292354E-04,   1.7133213E-04,   1.7157936E-04
     +,   1.7196822E-04,   1.7143444E-04,   1.6940845E-04
     +,   1.6567671E-04,   1.6026439E-04,   1.5334311E-04
     +,   1.4516446E-04,   1.3601432E-04,   1.2618175E-04
     +,   1.1593908E-04,   1.0553167E-04,   9.5173658E-05
     +,   8.5046093E-05,   7.5297350E-05,   6.6045985E-05
     +,   5.7383731E-05,   4.9377166E-05,   4.2069281E-05
     +,   3.5482110E-05,   2.9619179E-05,   2.4466352E-05
     +,   1.9994928E-05,   1.6164537E-05,   1.2925559E-05
     +,   1.0221931E-05,   7.9942638E-06,   6.1825335E-06
     +,   4.7280928E-06,   3.5754069E-06,   2.6734854E-06
     +,   1.9767351E-06,   1.4452613E-06,   1.0448978E-06
     +,   7.4702280E-07,   5.2813476E-07,   3.6924106E-07
     +,   2.5528942E-07,   1.7455207E-07,   1.1803180E-07
     +,   7.8932295E-08,   5.2202317E-08,   3.4143824E-08
     +,   2.2086637E-08,   1.4129797E-08,   8.9396908E-09
     +,   5.5936225E-09,   3.4613872E-09,   2.1182760E-09
     +,   1.2819673E-09,   7.6725554E-10,   4.5410636E-10
     +,   2.6577446E-10,   1.5381754E-10,   8.8030867E-11
     +,   4.9817470E-11,   2.7875974E-11,   1.5423289E-11
     +,   8.4376568E-12,   4.5640145E-12,   2.4408082E-12
     +,   1.2905701E-12,   6.7467104E-13,   3.4869484E-13
     +,   1.7816622E-13,   8.9999914E-14,   4.4944835E-14
     +,   2.2188081E-14,   1.0828464E-14,   5.2242417E-15
     +,   2.4915832E-15,   1.1746377E-15,   5.4741622E-16
     +,   2.5218566E-16,   1.1484097E-16,   5.1693279E-17
     +,   2.3000505E-17,   1.0116185E-17,   4.3980155E-18
     +,   1.8899148E-18,   8.0277796E-19,   3.3705506E-19
     +,   1.3987711E-19,   5.7377280E-20,   2.3264523E-20
     +,   9.3238320E-21,   3.6933994E-21,   1.4461114E-21
     +,   5.5967149E-22,   2.1409569E-22,   8.0948457E-23
     +,   3.0251566E-23,   1.1174888E-23,   4.0801476E-24
     +,   1.4724215E-24,   5.2522221E-25,   1.8517901E-25
     +,   6.4529944E-26,   2.2226339E-26,   7.5671036E-27
     +,   2.5463895E-27,   8.4691826E-28,   2.7841621E-28
     +,   9.0469115E-29,   2.9056433E-29,   9.2236697E-30
     +,   2.8941167E-30,   8.9753761E-31,   2.7513028E-31
     +,   8.3356979E-32,   2.4963171E-32,   7.3888563E-33
     +,   2.1617705E-33,   6.2511187E-34,   1.7867588E-34
     +,   5.0476944E-35,   1.4095628E-35,   3.8906865E-36
     +,   1.0614869E-36,   2.8628552E-37,   7.6249582E-38
     +,   2.0085629E-38,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz80 = Yx/0.00991666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6049060E-22,   3.2546381E-22
     +,   6.5586936E-22,   1.3133790E-21,   2.6135012E-21
     +,   5.1679114E-21,   1.0154705E-20,   1.9828020E-20
     +,   3.8472132E-20,   7.4178475E-20,   1.4212516E-19
     +,   2.7059658E-19,   5.1195594E-19,   9.6250788E-19
     +,   1.7981914E-18,   3.3383146E-18,   6.1585379E-18
     +,   1.1289863E-17,   2.0566418E-17,   3.7229679E-17
     +,   6.6969786E-17,   1.1970966E-16,   2.1263560E-16
     +,   3.7532718E-16,   6.5831660E-16,   1.1474270E-15
     +,   1.9873466E-15,   3.4204529E-15,   5.8499564E-15
     +,   9.9421746E-15,   1.6790746E-14,   2.8178589E-14
     +,   4.6992385E-14,   7.7874542E-14,   1.2824022E-13
     +,   2.0985142E-13,   3.4124022E-13,   5.5139676E-13
     +,   8.8539175E-13,   1.4127326E-12,   2.2399931E-12
     +,   3.5293517E-12,   5.5258779E-12,   8.5974240E-12
     +,   1.3292149E-11,   2.0421246E-11,   3.1176599E-11
     +,   4.7297152E-11,   7.1301895E-11,   1.0681372E-10
     +,   1.5900589E-10,   2.3521157E-10,   3.4574954E-10
     +,   5.0504451E-10,   7.3308143E-10,   1.0573953E-09
     +,   1.5155925E-09,   2.1586752E-09,   3.0552898E-09
     +,   4.2971138E-09,   6.0056662E-09,   8.3408009E-09
     +,   1.1510919E-08,   1.5785986E-08,   2.1512840E-08
     +,   2.9132597E-08,   3.9203506E-08,   5.2423502E-08
     +,   6.9661304E-08,   9.1984099E-08,   1.2069735E-07
     +,   1.5737602E-07,   2.0391219E-07,   2.6254526E-07
     +,   3.3591164E-07,   4.2707987E-07,   5.3957700E-07
     +,   6.7741462E-07,   8.4511566E-07,   1.0477103E-06
     +,   1.2906969E-06,   1.5800532E-06,   1.9221118E-06
     +,   2.3235482E-06,   2.7911781E-06,   3.3319120E-06
     +,   3.9524675E-06,   4.6593118E-06,   5.4582842E-06
     +,   6.3545322E-06,   7.3522328E-06,   8.4543190E-06
     +,   9.6623853E-06,   1.0976659E-05,   1.2395960E-05
     +,   1.3917647E-05,   1.5538242E-05,   1.7253460E-05
     +,   1.9059291E-05,   2.0952450E-05,   2.2931919E-05
     +,   2.4999805E-05,   2.7163358E-05,   2.9436102E-05
     +,   3.1840038E-05,   3.4407101E-05,   3.7180489E-05
     +,   4.0215848E-05,   4.3581971E-05,   4.7360303E-05
     +,   5.1643005E-05,   5.6531120E-05,   6.2129067E-05
     +,   6.8539965E-05,   7.5856675E-05,   8.4154635E-05
     +,   9.3480194E-05,   1.0384299E-04,   1.1520445E-04
     +,   1.2747267E-04,   1.4049733E-04,   1.5406816E-04
     +,   1.6791963E-04,   1.8174078E-04,   1.9518723E-04
     +,   2.0789652E-04,   2.1950969E-04,   2.2968702E-04
     +,   2.3812865E-04,   2.4458664E-04,   2.4887826E-04
     +,   2.5089108E-04,   2.5058835E-04,   2.4801117E-04
     +,   2.4328238E-04,   2.3661279E-04,   2.2831216E-04
     +,   2.1880005E-04,   2.0861026E-04,   1.9837997E-04
     +,   1.8880995E-04,   1.8058687E-04,   1.7427796E-04
     +,   1.7023933E-04,   1.6861943E-04,   1.6958972E-04
     +,   1.7395015E-04,   1.8416395E-04,   2.0562904E-04
     +,   2.4761475E-04,   3.2300584E-04,   4.4612761E-04
     +,   6.2863820E-04,   8.7448087E-04,   1.1757525E-03
     +,   1.5119879E-03,   1.8551307E-03,   2.1799149E-03
     +,   2.4744165E-03,   2.7419415E-03,   2.9885485E-03
     +,   3.2015627E-03,   3.3363099E-03,   3.3278388E-03
     +,   3.1270150E-03,   2.7377012E-03,   2.2259452E-03
     +,   1.6922927E-03,   1.2274315E-03,   8.8114798E-04
     +,   6.5867661E-04,   5.3679326E-04,   4.8349719E-04
     +,   4.7053545E-04,   4.7738780E-04,   4.9043627E-04
     +,   5.0102291E-04,   5.0407322E-04,   4.9735437E-04
     +,   4.8089304E-04,   4.5627172E-04,   4.2583529E-04
     +,   3.9199376E-04,   3.5676459E-04,   3.2159605E-04
     +,   2.8740033E-04,   2.5468940E-04,   2.2373121E-04
     +,   1.9467754E-04,   1.6764257E-04,   1.4272865E-04
     +,   1.2003068E-04,   9.9624485E-05,   8.1548649E-05
     +,   6.5791173E-05,   5.2285530E-05,   4.0913113E-05
     +,   3.1509669E-05,   2.3876722E-05,   1.7795930E-05
     +,   1.3042750E-05,   9.3976323E-06,   6.6552598E-06
     +,   4.6313748E-06,   3.1664570E-06,   2.1264921E-06
     +,   1.4024567E-06,   9.0818213E-07,   5.7734974E-07
     +,   3.6024838E-07,   2.2058541E-07,   1.3252411E-07
     +,   7.8107099E-08,   4.5153158E-08,   2.5598458E-08
     +,   1.4230285E-08,   7.7560349E-09,   4.1441179E-09
     +,   2.1703679E-09,   1.1140902E-09,   5.6046018E-10
     +,   2.7628899E-10,   1.3346195E-10,   6.3170073E-11
     +,   2.9295007E-11,   1.3309858E-11,   5.9244259E-12
     +,   2.5835230E-12,   1.1036882E-12,   4.6187950E-13
     +,   1.8934915E-13,   7.6042830E-14,   2.9915384E-14
     +,   1.1528026E-14,   4.3517470E-15,   1.6091808E-15
     +,   5.8285777E-16,   2.0679861E-16,   7.1874597E-17
     +,   2.4469733E-17,   8.1600623E-18,   2.6655285E-18
     +,   8.5292992E-19,   2.6734206E-19,   8.2078644E-20
     +,   2.4684019E-20,   7.2718102E-21,   2.0984326E-21
     +,   5.9313268E-22,   1.6422942E-22,   4.4542286E-23
     +,   1.1833138E-23,   3.0792957E-24,   7.8495550E-25
     +,   1.9600302E-25,   4.7938328E-26,   1.1484898E-26
     +,   2.6953503E-27,   6.1962511E-28,   1.3952230E-28
     +,   3.0773782E-29,   6.6491415E-30,   1.4072561E-30
     +,   2.9173113E-31,   5.9243658E-32,   1.1785044E-32
     +,   2.2963018E-33,   4.3829478E-34,   8.1957733E-35
     +,   1.5014914E-35,   2.6954263E-36,   4.7438509E-37
     +,   8.1940418E-38,   1.3921421E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz85 = Yx/0.0129230769230769
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   4.1760544E-38
     +,   3.8161326E-37,   3.3764353E-36,   2.8922863E-35
     +,   2.3984970E-34,   1.9256825E-33,   1.4969522E-32
     +,   1.1265428E-31,   8.2084940E-31,   5.7902520E-30
     +,   3.9546453E-29,   2.6147946E-28,   1.6739492E-27
     +,   1.0374497E-26,   6.2253679E-26,   3.6164712E-25
     +,   2.0340210E-24,   1.1076345E-23,   5.8396501E-23
     +,   2.9806012E-22,   1.4728881E-21,   7.0470392E-21
     +,   3.2641943E-20,   1.4639240E-19,   6.3561308E-19
     +,   2.6720508E-18,   1.0875145E-17,   4.2855341E-17
     +,   1.6350171E-16,   6.0398653E-16,   2.1601733E-15
     +,   7.4805215E-15,   2.5083077E-14,   8.1438010E-14
     +,   2.5601651E-13,   7.7934653E-13,   2.2974600E-12
     +,   6.5585168E-12,   1.8132409E-11,   4.8550376E-11
     +,   1.2591339E-10,   3.1629974E-10,   7.6972279E-10
     +,   1.8146495E-09,   4.1451567E-09,   9.1749461E-09
     +,   1.9680831E-08,   4.0919051E-08,   8.2469803E-08
     +,   1.6113933E-07,   3.0529125E-07,   5.6091966E-07
     +,   9.9955503E-07,   1.7277373E-06,   2.8971247E-06
     +,   4.7132494E-06,   7.4396330E-06,   1.1394222E-05
     +,   1.6932800E-05,   2.4415596E-05,   3.4156314E-05
     +,   4.6355959E-05,   6.1026793E-05,   7.7919060E-05
     +,   9.6470008E-05,   1.1579225E-04,   1.3471246E-04
     +,   1.5186869E-04,   1.6586289E-04,   1.7544441E-04
     +,   1.7969155E-04,   1.7816457E-04,   1.7102712E-04
     +,   1.5924711E-04,   1.4530830E-04,   1.3537149E-04
     +,   1.4395289E-04,   2.0044715E-04,   3.5246304E-04
     +,   6.5667159E-04,   1.1483994E-03,   1.7921941E-03
     +,   2.4468293E-03,   2.9069537E-03,   3.0308093E-03
     +,   2.8552690E-03,   2.5901953E-03,   2.4613729E-03
     +,   2.4942907E-03,   2.4849994E-03,   2.2479235E-03
     +,   1.8247203E-03,   1.3953721E-03,   1.0774001E-03
     +,   8.7389897E-04,   7.4706884E-04,   6.7419402E-04
     +,   6.4671563E-04,   6.5320777E-04,   6.7485601E-04
     +,   6.9165567E-04,   6.8938831E-04,   6.6246948E-04
     +,   6.1274797E-04,   5.4635783E-04,   4.7068740E-04
     +,   3.9252423E-04,   3.1732113E-04,   2.4900842E-04
     +,   1.8995986E-04,   1.4108127E-04,   1.0209378E-04
     +,   7.1959992E-05,   4.9309154E-05,   3.2742460E-05
     +,   2.0985759E-05,   1.2931078E-05,   7.6326005E-06
     +,   4.3028854E-06,   2.3117773E-06,   1.1818454E-06
     +,   5.7429452E-07,   2.6506797E-07,   1.1615852E-07
     +,   4.8318682E-08,   1.9075284E-08,   7.1460597E-09
     +,   2.5403479E-09,   8.5694907E-10,   2.7430386E-10
     +,   8.3311309E-11,   2.4010578E-11,   6.5661539E-12
     +,   1.7037659E-12,   4.1948454E-13,   9.8005568E-14
     +,   2.1726805E-14,   4.5701019E-15,   9.1214448E-16
     +,   1.7275646E-16,   3.1046570E-17,   5.2939046E-18
     +,   8.5653942E-19,   1.3150798E-19,   1.9158682E-20
     +,   2.6482749E-21,   3.4737145E-22,   4.3235014E-23
     +,   5.1056892E-24,   5.7211304E-25,   6.0834210E-26
     +,   6.1379645E-27,   5.8759280E-28,   5.3374723E-29
     +,   4.6008525E-30,   3.7631348E-31,   2.9203409E-32
     +,   2.1504257E-33,   1.5026648E-34,   9.9633865E-36
     +,   6.2679049E-37,   3.7418360E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz90 = Yx/0.0102083333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_haonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5211561E-06,   6.8768181E-06
     +,   7.2451144E-06,   7.6261567E-06,   8.0200589E-06
     +,   8.4269286E-06,   8.8468778E-06,   9.2800183E-06
     +,   9.7264547E-06,   1.0186322E-05,   1.0659738E-05
     +,   1.1146837E-05,   1.1647757E-05,   1.2162649E-05
     +,   1.2691670E-05,   1.3234984E-05,   1.3792766E-05
     +,   1.4365193E-05,   1.4952450E-05,   1.5554719E-05
     +,   1.6172184E-05,   1.6805021E-05,   1.7453385E-05
     +,   1.8117456E-05,   1.8797318E-05,   1.9493104E-05
     +,   2.0204852E-05,   2.0932590E-05,   2.1676271E-05
     +,   2.2435790E-05,   2.3210971E-05,   2.4001552E-05
     +,   2.4807185E-05,   2.5627396E-05,   2.6461628E-05
     +,   2.7309181E-05,   2.8169212E-05,   2.9040761E-05
     +,   2.9922730E-05,   3.0813797E-05,   3.1712556E-05
     +,   3.2617398E-05,   3.3526547E-05,   3.4438050E-05
     +,   3.5349804E-05,   3.6259520E-05,   3.7164762E-05
     +,   3.8062928E-05,   3.8951275E-05,   3.9826915E-05
     +,   4.0686849E-05,   4.1527965E-05,   4.2347045E-05
     +,   4.3140855E-05,   4.3906017E-05,   4.4639215E-05
     +,   4.5337078E-05,   4.5996276E-05,   4.6613502E-05
     +,   4.7185549E-05,   4.7709294E-05,   4.8181744E-05
     +,   4.8600043E-05,   4.8961545E-05,   4.9263785E-05
     +,   4.9504528E-05,   4.9681799E-05,   4.9793878E-05
     +,   4.9839335E-05,   4.9817067E-05,   4.9726255E-05
     +,   4.9566435E-05,   4.9337457E-05,   4.9039547E-05
     +,   4.8673232E-05,   4.8239399E-05,   4.7739282E-05
     +,   4.7174450E-05,   4.6546775E-05,   4.5858422E-05
     +,   4.5111898E-05,   4.4309905E-05,   4.3455508E-05
     +,   4.2551870E-05,   4.1602492E-05,   4.0610917E-05
     +,   3.9580991E-05,   3.8516529E-05,   3.7421592E-05
     +,   3.6300196E-05,   3.5156401E-05,   3.3994344E-05
     +,   3.2818149E-05,   3.1631822E-05,   3.0439294E-05
     +,   2.9244524E-05,   2.8051189E-05,   2.6862994E-05
     +,   2.5683325E-05,   2.4515552E-05,   2.3362705E-05
     +,   2.2227763E-05,   2.1113347E-05,   2.0021993E-05
     +,   1.8955920E-05,   1.7917106E-05,   1.6907379E-05
     +,   1.5928323E-05,   1.4981232E-05,   1.4067182E-05
     +,   1.3187113E-05,   1.2341640E-05,   1.1531286E-05
     +,   1.0756271E-05,   1.0016734E-05,   9.3125454E-06
     +,   8.6435048E-06,   8.0091750E-06,   7.4090726E-06
     +,   6.8425238E-06,   6.3087537E-06,   5.8069218E-06
     +,   5.3361036E-06,   4.8952706E-06,   4.4833382E-06
     +,   4.0992154E-06,   3.7417208E-06,   3.4096977E-06
     +,   3.1019304E-06,   2.8172428E-06,   2.5544323E-06
     +,   2.3123612E-06,   2.0899170E-06,   1.8861143E-06
     +,   1.7001074E-06,   1.5313256E-06,   1.3796512E-06
     +,   1.2456834E-06,   1.1311568E-06,   1.0395980E-06
     +,   9.7727661E-07,   9.5453686E-07,   9.8764144E-07
     +,   1.1012135E-06,   1.3312815E-06,   1.7289756E-06
     +,   2.3646619E-06,   3.3321257E-06,   4.7523522E-06
     +,   6.7761835E-06,   9.5846272E-06,   1.3385534E-05
     +,   1.8406081E-05,   2.4880454E-05,   3.3031945E-05
     +,   4.3050488E-05,   5.5069773E-05,   6.9148162E-05
     +,   8.5257190E-05,   1.0328460E-04,   1.2306517E-04
     +,   1.4443419E-04,   1.6730961E-04,   1.9179928E-04
     +,   2.1832071E-04,   2.4770890E-04,   2.8129149E-04
     +,   3.2090821E-04,   3.6885426E-04,   4.2772802E-04
     +,   5.0018681E-04,   5.8863795E-04,   6.9489470E-04
     +,   8.1982027E-04,   9.6300192E-04,   1.1225431E-03
     +,   1.2949351E-03,   1.4750612E-03,   1.6563827E-03
     +,   1.8312816E-03,   1.9915306E-03,   2.1288919E-03
     +,   2.2358065E-03,   2.3060876E-03,   2.3355137E-03
     +,   2.3222680E-03,   2.2671651E-03,   2.1735835E-03
     +,   2.0471462E-03,   1.8951860E-03,   1.7260235E-03
     +,   1.5482098E-03,   1.3698132E-03,   1.1977956E-03
     +,   1.0375741E-03,   8.9282572E-04,   7.6550175E-04
     +,   6.5600430E-04,   5.6350237E-04,   4.8632344E-04
     +,   4.2233756E-04,   3.6927982E-04,   3.2499313E-04
     +,   2.8758662E-04,   2.5550605E-04,   2.2753165E-04
     +,   2.0274655E-04,   1.8048393E-04,   1.6026916E-04
     +,   1.4177024E-04,   1.2476087E-04,   1.0909382E-04
     +,   9.4677933E-05,   8.1461294E-05,   6.9417962E-05
     +,   5.8535956E-05,   4.8805097E-05,   4.0207447E-05
     +,   3.2711694E-05,   2.6270422E-05,   2.0818250E-05
     +,   1.6274797E-05,   1.2548690E-05,   9.5418854E-06
     +,   7.1544168E-06,   5.2890896E-06,   3.8550775E-06
     +,   2.7702208E-06,   1.9624626E-06,   1.3704696E-06
     +,   9.4341357E-07,   6.4015040E-07,   4.2813346E-07
     +,   2.8220154E-07,   1.8331789E-07,   1.1734878E-07
     +,   7.4018772E-08,   4.6001084E-08,   2.8166458E-08
     +,   1.6990057E-08,   1.0095257E-08,   5.9084950E-09
     +,   3.4060741E-09,   1.9338102E-09,   1.0812430E-09
     +,   5.9534416E-10,   3.2280195E-10,   1.7234536E-10
     +,   9.0601124E-11,   4.6896508E-11,   2.3899981E-11
     +,   1.1991795E-11,   5.9237797E-12,   2.8810038E-12
     +,   1.3794351E-12,   6.5021008E-13,   3.0172276E-13
     +,   1.3783897E-13,   6.1991665E-14,   2.7446273E-14
     +,   1.1962997E-14,   5.1337549E-15,   2.1691391E-15
     +,   9.0250799E-16,   3.6989214E-16,   1.4941190E-16
     +,   5.9542671E-17,   2.3459003E-17,   9.1742759E-18
     +,   3.5884816E-18,   1.4236384E-18,   5.8657197E-19
     +,   2.5958003E-19,   1.2765655E-19,   7.0842785E-20
     +,   4.3742238E-20,   2.9108182E-20,   2.0245233E-20
     +,   1.4411292E-20,   1.0374808E-20,   7.5071504E-21
     +,   5.4437624E-21,   3.9503056E-21,   2.8668307E-21
     +,   2.0800513E-21,   1.5086875E-21,   1.0938153E-21
     +,   7.9266561E-22,   5.7415988E-22,   4.1567969E-22
     +,   3.0079246E-22,   2.1753959E-22,   1.5724494E-22
     +,   1.1359616E-22,   8.2015874E-23,   5.9177859E-23
     +,   4.2672661E-23,   3.0750158E-23,   2.2143894E-23
     +,   1.5934891E-23,   1.1458597E-23
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_haonly_ttz95 = Yx/0.01232
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9805271E-04,   4.1609743E-04
     +,   4.3442217E-04,   4.5300697E-04,   4.7183255E-04
     +,   4.9087906E-04,   5.1012775E-04,   5.2955892E-04
     +,   5.4915238E-04,   5.6888937E-04,   5.8874919E-04
     +,   6.0871133E-04,   6.2875403E-04,   6.4885424E-04
     +,   6.6898804E-04,   6.8912929E-04,   7.0925005E-04
     +,   7.2932011E-04,   7.4930751E-04,   7.6917547E-04
     +,   7.8888662E-04,   8.0840022E-04,   8.2767161E-04
     +,   8.4665453E-04,   8.6529920E-04,   8.8355376E-04
     +,   9.0136490E-04,   9.1867644E-04,   9.3543268E-04
     +,   9.5157634E-04,   9.6705084E-04,   9.8180026E-04
     +,   9.9577161E-04,   1.0089136E-03,   1.0211779E-03
     +,   1.0325201E-03,   1.0429040E-03,   1.0522940E-03
     +,   1.0606651E-03,   1.0679971E-03,   1.0742778E-03
     +,   1.0795019E-03,   1.0836739E-03,   1.0868046E-03
     +,   1.0889136E-03,   1.0900280E-03,   1.0901833E-03
     +,   1.0894217E-03,   1.0877934E-03,   1.0853527E-03
     +,   1.0821619E-03,   1.0782876E-03,   1.0737994E-03
     +,   1.0687716E-03,   1.0632810E-03,   1.0574070E-03
     +,   1.0512277E-03,   1.0448243E-03,   1.0382766E-03
     +,   1.0316637E-03,   1.0250625E-03,   1.0185475E-03
     +,   1.0121926E-03,   1.0060653E-03,   1.0002323E-03
     +,   9.9475496E-04,   9.8969159E-04,   9.8509446E-04
     +,   9.8101282E-04,   9.7748847E-04,   9.7455969E-04
     +,   9.7225944E-04,   9.7061339E-04,   9.6964260E-04
     +,   9.6936198E-04,   9.6977857E-04,   9.7089459E-04
     +,   9.7270391E-04,   9.7519590E-04,   9.7834982E-04
     +,   9.8213984E-04,   9.8653266E-04,   9.9148694E-04
     +,   9.9695567E-04,   1.0028833E-03,   1.0092102E-03
     +,   1.0158676E-03,   1.0227829E-03,   1.0298785E-03
     +,   1.0370720E-03,   1.0442794E-03,   1.0514114E-03
     +,   1.0583785E-03,   1.0650913E-03,   1.0714616E-03
     +,   1.0774011E-03,   1.0828284E-03,   1.0876623E-03
     +,   1.0918311E-03,   1.0952658E-03,   1.0979098E-03
     +,   1.0997105E-03,   1.1006254E-03,   1.1006239E-03
     +,   1.0996837E-03,   1.0977937E-03,   1.0949518E-03
     +,   1.0911680E-03,   1.0864601E-03,   1.0808576E-03
     +,   1.0743977E-03,   1.0671254E-03,   1.0590936E-03
     +,   1.0503621E-03,   1.0409954E-03,   1.0310612E-03
     +,   1.0206328E-03,   1.0097846E-03,   9.9859247E-04
     +,   9.8713115E-04,   9.7547710E-04,   9.6370408E-04
     +,   9.5188484E-04,   9.4008673E-04,   9.2837727E-04
     +,   9.1681717E-04,   9.0546499E-04,   8.9437445E-04
     +,   8.8359462E-04,   8.7317079E-04,   8.6314260E-04
     +,   8.5354643E-04,   8.4441295E-04,   8.3577132E-04
     +,   8.2764571E-04,   8.2005525E-04,   8.1301894E-04
     +,   8.0655213E-04,   8.0066698E-04,   7.9537503E-04
     +,   7.9068699E-04,   7.8661228E-04,   7.8315998E-04
     +,   7.8034023E-04,   7.7816320E-04,   7.7664206E-04
     +,   7.7578996E-04,   7.7562488E-04,   7.7616610E-04
     +,   7.7743729E-04,   7.7946665E-04,   7.8228442E-04
     +,   7.8592764E-04,   7.9043716E-04,   7.9585944E-04
     +,   8.0224383E-04,   8.0964580E-04,   8.1812573E-04
     +,   8.2774757E-04,   8.3857804E-04,   8.5068872E-04
     +,   8.6415373E-04,   8.7904755E-04,   8.9544710E-04
     +,   9.1342995E-04,   9.3307387E-04,   9.5445488E-04
     +,   9.7764714E-04,   1.0027246E-03,   1.0297589E-03
     +,   1.0588163E-03,   1.0899625E-03,   1.1232597E-03
     +,   1.1587694E-03,   1.1965453E-03,   1.2366426E-03
     +,   1.2791143E-03,   1.3240027E-03,   1.3713457E-03
     +,   1.4211724E-03,   1.4734995E-03,   1.5283144E-03
     +,   1.5855812E-03,   1.6452244E-03,   1.7071255E-03
     +,   1.7711082E-03,   1.8369326E-03,   1.9043011E-03
     +,   1.9728611E-03,   2.0422025E-03,   2.1118941E-03
     +,   2.1815102E-03,   2.2506602E-03,   2.3190372E-03
     +,   2.3864780E-03,   2.4530115E-03,   2.5188967E-03
     +,   2.5846744E-03,   2.6512032E-03,   2.7196563E-03
     +,   2.7915193E-03,   2.8685576E-03,   2.9527808E-03
     +,   3.0463419E-03,   3.1514612E-03,   3.2703136E-03
     +,   3.4049025E-03,   3.5569265E-03,   3.7276782E-03
     +,   3.9179167E-03,   4.1278224E-03,   4.3569487E-03
     +,   4.6042567E-03,   4.8682825E-03,   5.1473472E-03
     +,   5.4398179E-03,   5.7445164E-03,   6.0611265E-03
     +,   6.3904803E-03,   6.7347758E-03,   7.0976410E-03
     +,   7.4839024E-03,   7.8990562E-03,   8.3486345E-03
     +,   8.8373553E-03,   9.3683517E-03,   9.9423276E-03
     +,   1.0556974E-02,   1.1206689E-02,   1.1882404E-02
     +,   1.2571484E-02,   1.3258192E-02,   1.3923929E-02
     +,   1.4547938E-02,   1.5107890E-02,   1.5581000E-02
     +,   1.5945094E-02,   1.6179781E-02,   1.6267914E-02
     +,   1.6196925E-02,   1.5959838E-02,   1.5556427E-02
     +,   1.4993562E-02,   1.4285292E-02,   1.3452133E-02
     +,   1.2519976E-02,   1.1518261E-02,   1.0477751E-02
     +,   9.4284788E-03,   8.3978660E-03,   7.4089631E-03
     +,   6.4796605E-03,   5.6224437E-03,   4.8445561E-03
     +,   4.1486383E-03,   3.5336711E-03,   2.9959816E-03
     +,   2.5300889E-03,   2.1294567E-03,   1.7871188E-03
     +,   1.4961449E-03,   1.2498908E-03,   1.0421732E-03
     +,   8.6739811E-04,   7.2061241E-04,   5.9747347E-04
     +,   4.9424567E-04,   4.0776018E-04,   3.3534746E-04
     +,   2.7477223E-04,   2.2417396E-04,   1.8200657E-04
     +,   1.4697693E-04,   1.1799486E-04,   9.4135801E-05
     +,   7.4610522E-05,   5.8736012E-05,   4.5922723E-05
     +,   3.5657911E-05,   2.7499373E-05,   2.1065631E-05
     +,   1.6032061E-05,   1.2123809E-05,   9.1119064E-06
     +,   6.8070294E-06,   5.0551880E-06,   3.7321777E-06
     +,   2.7391311E-06,   1.9982454E-06,   1.4486972E-06
     +,   1.0435047E-06,   7.4653332E-07,   5.3026332E-07
     +,   3.7379905E-07,   2.6140816E-07,   1.8127743E-07
     +,   1.2460831E-07,   8.4869363E-08,   5.7254638E-08
     +,   3.8244831E-08,   2.5288360E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt100 = Yx/0.168636363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4353116E-03,   1.5312778E-03
     +,   1.6275583E-03,   1.7235267E-03,   1.8185497E-03
     +,   1.9119967E-03,   2.0032565E-03,   2.0917461E-03
     +,   2.1769179E-03,   2.2582873E-03,   2.3354280E-03
     +,   2.4079876E-03,   2.4756959E-03,   2.5383770E-03
     +,   2.5959469E-03,   2.6484197E-03,   2.6959071E-03
     +,   2.7386223E-03,   2.7768631E-03,   2.8110151E-03
     +,   2.8415367E-03,   2.8689431E-03,   2.8938022E-03
     +,   2.9167044E-03,   2.9382468E-03,   2.9590144E-03
     +,   2.9795677E-03,   3.0004042E-03,   3.0219576E-03
     +,   3.0445738E-03,   3.0684937E-03,   3.0938562E-03
     +,   3.1206734E-03,   3.1488454E-03,   3.1781562E-03
     +,   3.2082794E-03,   3.2388011E-03,   3.2692216E-03
     +,   3.2989886E-03,   3.3275068E-03,   3.3541739E-03
     +,   3.3783854E-03,   3.3995835E-03,   3.4172609E-03
     +,   3.4309814E-03,   3.4404055E-03,   3.4452952E-03
     +,   3.4455252E-03,   3.4410858E-03,   3.4320799E-03
     +,   3.4187299E-03,   3.4013544E-03,   3.3803671E-03
     +,   3.3562444E-03,   3.3295222E-03,   3.3007809E-03
     +,   3.2705953E-03,   3.2395499E-03,   3.2081928E-03
     +,   3.1770270E-03,   3.1464999E-03,   3.1169734E-03
     +,   3.0887416E-03,   3.0620031E-03,   3.0368674E-03
     +,   3.0133666E-03,   2.9914512E-03,   2.9710182E-03
     +,   2.9518916E-03,   2.9338843E-03,   2.9167652E-03
     +,   2.9003080E-03,   2.8842981E-03,   2.8685387E-03
     +,   2.8528597E-03,   2.8371352E-03,   2.8212769E-03
     +,   2.8052446E-03,   2.7890387E-03,   2.7726977E-03
     +,   2.7563046E-03,   2.7399594E-03,   2.7238009E-03
     +,   2.7079736E-03,   2.6926489E-03,   2.6779971E-03
     +,   2.6642049E-03,   2.6514586E-03,   2.6399537E-03
     +,   2.6298820E-03,   2.6214428E-03,   2.6148292E-03
     +,   2.6102341E-03,   2.6078341E-03,   2.6078022E-03
     +,   2.6102758E-03,   2.6153720E-03,   2.6231620E-03
     +,   2.6336659E-03,   2.6468530E-03,   2.6626177E-03
     +,   2.6807855E-03,   2.7011074E-03,   2.7232561E-03
     +,   2.7468291E-03,   2.7713606E-03,   2.7963310E-03
     +,   2.8211740E-03,   2.8453008E-03,   2.8681168E-03
     +,   2.8890399E-03,   2.9075244E-03,   2.9230744E-03
     +,   2.9352708E-03,   2.9437770E-03,   2.9483561E-03
     +,   2.9488755E-03,   2.9453144E-03,   2.9377539E-03
     +,   2.9263783E-03,   2.9114641E-03,   2.8933624E-03
     +,   2.8724875E-03,   2.8492967E-03,   2.8242702E-03
     +,   2.7978935E-03,   2.7706444E-03,   2.7429692E-03
     +,   2.7152740E-03,   2.6879099E-03,   2.6611683E-03
     +,   2.6352725E-03,   2.6103756E-03,   2.5865634E-03
     +,   2.5638558E-03,   2.5422045E-03,   2.5215165E-03
     +,   2.5016409E-03,   2.4823914E-03,   2.4635494E-03
     +,   2.4448794E-03,   2.4261300E-03,   2.4070502E-03
     +,   2.3873916E-03,   2.3669249E-03,   2.3454439E-03
     +,   2.3227718E-03,   2.2987705E-03,   2.2733496E-03
     +,   2.2464669E-03,   2.2181375E-03,   2.1884388E-03
     +,   2.1575079E-03,   2.1255556E-03,   2.0928483E-03
     +,   2.0597330E-03,   2.0266157E-03,   1.9939686E-03
     +,   1.9623232E-03,   1.9322684E-03,   1.9044410E-03
     +,   1.8795178E-03,   1.8582140E-03,   1.8412644E-03
     +,   1.8294076E-03,   1.8233884E-03,   1.8239245E-03
     +,   1.8317000E-03,   1.8473553E-03,   1.8714452E-03
     +,   1.9044426E-03,   1.9467095E-03,   1.9984832E-03
     +,   2.0598709E-03,   2.1308148E-03,   2.2111300E-03
     +,   2.3004743E-03,   2.3983726E-03,   2.5042403E-03
     +,   2.6174106E-03,   2.7371754E-03,   2.8628162E-03
     +,   2.9936431E-03,   3.1290543E-03,   3.2685625E-03
     +,   3.4118039E-03,   3.5585554E-03,   3.7087321E-03
     +,   3.8623591E-03,   4.0194979E-03,   4.1802418E-03
     +,   4.3445998E-03,   4.5124255E-03,   4.6833688E-03
     +,   4.8568267E-03,   5.0318767E-03,   5.2072690E-03
     +,   5.3814808E-03,   5.5527096E-03,   5.7189874E-03
     +,   5.8782315E-03,   6.0283602E-03,   6.1674016E-03
     +,   6.2935837E-03,   6.4053624E-03,   6.5015219E-03
     +,   6.5811677E-03,   6.6437032E-03,   6.6888225E-03
     +,   6.7164241E-03,   6.7265723E-03,   6.7194356E-03
     +,   6.6952114E-03,   6.6541275E-03,   6.5963874E-03
     +,   6.5222224E-03,   6.4318762E-03,   6.3257059E-03
     +,   6.2041450E-03,   6.0678408E-03,   5.9176465E-03
     +,   5.7546310E-03,   5.5801207E-03,   5.3956588E-03
     +,   5.2029630E-03,   5.0038774E-03,   4.8003169E-03
     +,   4.5941952E-03,   4.3873149E-03,   4.1813562E-03
     +,   3.9778207E-03,   3.7779757E-03,   3.5828459E-03
     +,   3.3932058E-03,   3.2096272E-03,   3.0324545E-03
     +,   2.8618576E-03,   2.6978899E-03,   2.5405027E-03
     +,   2.3895749E-03,   2.2449538E-03,   2.1064871E-03
     +,   1.9740371E-03,   1.8474727E-03,   1.7266886E-03
     +,   1.6116143E-03,   1.5021927E-03,   1.3983749E-03
     +,   1.3001160E-03,   1.2073735E-03,   1.1200812E-03
     +,   1.0381558E-03,   9.6149417E-04,   8.8996888E-04
     +,   8.2341715E-04,   7.6165312E-04,   7.0447376E-04
     +,   6.5165432E-04,   6.0295407E-04,   5.5812224E-04
     +,   5.1690702E-04,   4.7905499E-04,   4.4431424E-04
     +,   4.1244001E-04,   3.8320009E-04,   3.5637154E-04
     +,   3.3174444E-04,   3.0912462E-04,   2.8833238E-04
     +,   2.6920057E-04,   2.5157709E-04,   2.3532375E-04
     +,   2.2031563E-04,   2.0643833E-04,   1.9358896E-04
     +,   1.8167579E-04,   1.7061476E-04,   1.6033181E-04
     +,   1.5075890E-04,   1.4183619E-04,   1.3350871E-04
     +,   1.2572804E-04,   1.1844975E-04,   1.1163464E-04
     +,   1.0524649E-04,   9.9253542E-05,   9.3626368E-05
     +,   8.8338427E-05,   8.3366096E-05,   7.8687364E-05
     +,   7.4282660E-05,   7.0133690E-05,   6.6224122E-05
     +,   6.2538558E-05,   5.9063284E-05,   5.5785207E-05
     +,   5.2692663E-05,   4.9774404E-05,   4.7020396E-05
     +,   4.4420896E-05,   4.1967174E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt105 = Yx/0.192659090909091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7166127E-03,   1.8322427E-03
     +,   1.9479452E-03,   2.0629917E-03,   2.1766671E-03
     +,   2.2882961E-03,   2.3972371E-03,   2.5029033E-03
     +,   2.6047693E-03,   2.7023905E-03,   2.7953782E-03
     +,   2.8834173E-03,   2.9662699E-03,   3.0437626E-03
     +,   3.1157800E-03,   3.1822701E-03,   3.2432196E-03
     +,   3.2986701E-03,   3.3487009E-03,   3.3934223E-03
     +,   3.4329789E-03,   3.4675437E-03,   3.4973274E-03
     +,   3.5225630E-03,   3.5435108E-03,   3.5604609E-03
     +,   3.5737266E-03,   3.5836364E-03,   3.5905361E-03
     +,   3.5947678E-03,   3.5966737E-03,   3.5965824E-03
     +,   3.5947761E-03,   3.5915165E-03,   3.5870043E-03
     +,   3.5813868E-03,   3.5747506E-03,   3.5671194E-03
     +,   3.5584616E-03,   3.5486922E-03,   3.5376931E-03
     +,   3.5253309E-03,   3.5114440E-03,   3.4959074E-03
     +,   3.4786125E-03,   3.4594950E-03,   3.4385493E-03
     +,   3.4158328E-03,   3.3914703E-03,   3.3656459E-03
     +,   3.3386049E-03,   3.3106338E-03,   3.2820522E-03
     +,   3.2531898E-03,   3.2243622E-03,   3.1958760E-03
     +,   3.1679752E-03,   3.1408626E-03,   3.1146712E-03
     +,   3.0894524E-03,   3.0651919E-03,   3.0418017E-03
     +,   3.0191327E-03,   2.9969732E-03,   2.9750878E-03
     +,   2.9532074E-03,   2.9310610E-03,   2.9083898E-03
     +,   2.8849547E-03,   2.8605661E-03,   2.8350702E-03
     +,   2.8083855E-03,   2.7804843E-03,   2.7514074E-03
     +,   2.7212545E-03,   2.6901853E-03,   2.6584140E-03
     +,   2.6261967E-03,   2.5938167E-03,   2.5615836E-03
     +,   2.5298160E-03,   2.4988321E-03,   2.4689352E-03
     +,   2.4404021E-03,   2.4134929E-03,   2.3884086E-03
     +,   2.3653288E-03,   2.3443676E-03,   2.3255972E-03
     +,   2.3090371E-03,   2.2946615E-03,   2.2823911E-03
     +,   2.2721058E-03,   2.2636524E-03,   2.2568360E-03
     +,   2.2514388E-03,   2.2472227E-03,   2.2439328E-03
     +,   2.2413104E-03,   2.2390937E-03,   2.2370268E-03
     +,   2.2348664E-03,   2.2323832E-03,   2.2293699E-03
     +,   2.2256465E-03,   2.2210565E-03,   2.2154809E-03
     +,   2.2088259E-03,   2.2010328E-03,   2.1920817E-03
     +,   2.1819754E-03,   2.1707525E-03,   2.1584791E-03
     +,   2.1452496E-03,   2.1311752E-03,   2.1163889E-03
     +,   2.1010374E-03,   2.0852822E-03,   2.0692861E-03
     +,   2.0532131E-03,   2.0372309E-03,   2.0214999E-03
     +,   2.0061675E-03,   1.9913695E-03,   1.9772293E-03
     +,   1.9638494E-03,   1.9513128E-03,   1.9396817E-03
     +,   1.9289949E-03,   1.9192705E-03,   1.9104958E-03
     +,   1.9026459E-03,   1.8956697E-03,   1.8894890E-03
     +,   1.8840178E-03,   1.8791434E-03,   1.8747509E-03
     +,   1.8707041E-03,   1.8668624E-03,   1.8630817E-03
     +,   1.8592218E-03,   1.8551385E-03,   1.8507030E-03
     +,   1.8457915E-03,   1.8402999E-03,   1.8341440E-03
     +,   1.8272587E-03,   1.8196111E-03,   1.8111945E-03
     +,   1.8020348E-03,   1.7921927E-03,   1.7817644E-03
     +,   1.7708873E-03,   1.7597327E-03,   1.7485139E-03
     +,   1.7374780E-03,   1.7269163E-03,   1.7171485E-03
     +,   1.7085314E-03,   1.7014520E-03,   1.6963152E-03
     +,   1.6935552E-03,   1.6936128E-03,   1.6969366E-03
     +,   1.7039733E-03,   1.7151556E-03,   1.7308914E-03
     +,   1.7515555E-03,   1.7774766E-03,   1.8089234E-03
     +,   1.8460930E-03,   1.8890991E-03,   1.9379724E-03
     +,   1.9926478E-03,   2.0529542E-03,   2.1186355E-03
     +,   2.1893436E-03,   2.2646543E-03,   2.3440826E-03
     +,   2.4271186E-03,   2.5132466E-03,   2.6019707E-03
     +,   2.6928589E-03,   2.7855826E-03,   2.8799386E-03
     +,   2.9758795E-03,   3.0735172E-03,   3.1731685E-03
     +,   3.2753127E-03,   3.3805852E-03,   3.4897500E-03
     +,   3.6036379E-03,   3.7230933E-03,   3.8489003E-03
     +,   3.9817123E-03,   4.1219760E-03,   4.2698584E-03
     +,   4.4251839E-03,   4.5874403E-03,   4.7556912E-03
     +,   4.9286569E-03,   5.1046838E-03,   5.2818600E-03
     +,   5.4580453E-03,   5.6309742E-03,   5.7983650E-03
     +,   5.9579937E-03,   6.1077918E-03,   6.2459023E-03
     +,   6.3707540E-03,   6.4810822E-03,   6.5759234E-03
     +,   6.6546337E-03,   6.7168428E-03,   6.7623965E-03
     +,   6.7913537E-03,   6.8038926E-03,   6.8002813E-03
     +,   6.7808405E-03,   6.7458875E-03,   6.6957450E-03
     +,   6.6306866E-03,   6.5509807E-03,   6.4568445E-03
     +,   6.3485224E-03,   6.2262509E-03,   6.0903183E-03
     +,   5.9411158E-03,   5.7791201E-03,   5.6049484E-03
     +,   5.4193921E-03,   5.2234312E-03,   5.0182058E-03
     +,   4.8050475E-03,   4.5854650E-03,   4.3611084E-03
     +,   4.1337078E-03,   3.9050931E-03,   3.6770937E-03
     +,   3.4514910E-03,   3.2299871E-03,   3.0141594E-03
     +,   2.8054153E-03,   2.6049493E-03,   2.4137325E-03
     +,   2.2325113E-03,   2.0617989E-03,   1.9018642E-03
     +,   1.7527716E-03,   1.6144057E-03,   1.4864827E-03
     +,   1.3685822E-03,   1.2601962E-03,   1.1607426E-03
     +,   1.0695906E-03,   9.8609377E-04,   9.0961158E-04
     +,   8.3952484E-04,   7.7524083E-04,   7.1620813E-04
     +,   6.6192576E-04,   6.1194180E-04,   5.6584732E-04
     +,   5.2328239E-04,   4.8393189E-04,   4.4751674E-04
     +,   4.1379288E-04,   3.8254700E-04,   3.5359222E-04
     +,   3.2676008E-04,   3.0190035E-04,   2.7887934E-04
     +,   2.5757446E-04,   2.3787198E-04,   2.1966615E-04
     +,   2.0285962E-04,   1.8735873E-04,   1.7307668E-04
     +,   1.5992927E-04,   1.4783794E-04,   1.3672651E-04
     +,   1.2652384E-04,   1.1716098E-04,   1.0857376E-04
     +,   1.0070042E-04,   9.3483504E-05,   8.6868502E-05
     +,   8.0804275E-05,   7.5243668E-05,   7.0142145E-05
     +,   6.5459149E-05,   6.1156650E-05,   5.7200283E-05
     +,   5.3558128E-05,   5.0201539E-05,   4.7104077E-05
     +,   4.4242235E-05,   4.1594434E-05,   3.9141549E-05
     +,   3.6866146E-05,   3.4752866E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt107 = Yx/0.189954545454545
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1243890E-03,   1.2150855E-03
     +,   1.3088067E-03,   1.4051603E-03,   1.5037010E-03
     +,   1.6039371E-03,   1.7053325E-03,   1.8073160E-03
     +,   1.9092889E-03,   2.0106370E-03,   2.1107353E-03
     +,   2.2089623E-03,   2.3047172E-03,   2.3974229E-03
     +,   2.4865419E-03,   2.5715881E-03,   2.6521406E-03
     +,   2.7278352E-03,   2.7983896E-03,   2.8636011E-03
     +,   2.9233415E-03,   2.9775584E-03,   3.0262822E-03
     +,   3.0696115E-03,   3.1077077E-03,   3.1407857E-03
     +,   3.1691110E-03,   3.1929878E-03,   3.2127472E-03
     +,   3.2287408E-03,   3.2413357E-03,   3.2509055E-03
     +,   3.2578211E-03,   3.2624516E-03,   3.2651674E-03
     +,   3.2663159E-03,   3.2662435E-03,   3.2652821E-03
     +,   3.2637366E-03,   3.2619000E-03,   3.2600395E-03
     +,   3.2583838E-03,   3.2571477E-03,   3.2564849E-03
     +,   3.2565177E-03,   3.2573089E-03,   3.2588698E-03
     +,   3.2611662E-03,   3.2641033E-03,   3.2675290E-03
     +,   3.2712563E-03,   3.2750461E-03,   3.2786396E-03
     +,   3.2817549E-03,   3.2841049E-03,   3.2854092E-03
     +,   3.2854050E-03,   3.2838576E-03,   3.2805752E-03
     +,   3.2754145E-03,   3.2682731E-03,   3.2591210E-03
     +,   3.2479668E-03,   3.2348828E-03,   3.2199840E-03
     +,   3.2034325E-03,   3.1854236E-03,   3.1661890E-03
     +,   3.1459751E-03,   3.1250489E-03,   3.1036770E-03
     +,   3.0821245E-03,   3.0606519E-03,   3.0394983E-03
     +,   3.0188723E-03,   2.9989656E-03,   2.9799182E-03
     +,   2.9618379E-03,   2.9447803E-03,   2.9287543E-03
     +,   2.9137146E-03,   2.8995748E-03,   2.8861968E-03
     +,   2.8734030E-03,   2.8609850E-03,   2.8487099E-03
     +,   2.8363357E-03,   2.8236154E-03,   2.8103173E-03
     +,   2.7962327E-03,   2.7811814E-03,   2.7650357E-03
     +,   2.7477073E-03,   2.7291623E-03,   2.7094195E-03
     +,   2.6885497E-03,   2.6666624E-03,   2.6439067E-03
     +,   2.6204521E-03,   2.5964882E-03,   2.5722012E-03
     +,   2.5477731E-03,   2.5233689E-03,   2.4991138E-03
     +,   2.4751106E-03,   2.4514182E-03,   2.4280541E-03
     +,   2.4050046E-03,   2.3822126E-03,   2.3595975E-03
     +,   2.3370592E-03,   2.3144828E-03,   2.2917495E-03
     +,   2.2687495E-03,   2.2453857E-03,   2.2215808E-03
     +,   2.1972938E-03,   2.1725094E-03,   2.1472450E-03
     +,   2.1215614E-03,   2.0955477E-03,   2.0693289E-03
     +,   2.0430558E-03,   2.0169008E-03,   1.9910536E-03
     +,   1.9657137E-03,   1.9410802E-03,   1.9173516E-03
     +,   1.8947102E-03,   1.8733273E-03,   1.8533443E-03
     +,   1.8348779E-03,   1.8180169E-03,   1.8028100E-03
     +,   1.7892777E-03,   1.7773974E-03,   1.7671193E-03
     +,   1.7583549E-03,   1.7509874E-03,   1.7448735E-03
     +,   1.7398485E-03,   1.7357307E-03,   1.7323268E-03
     +,   1.7294408E-03,   1.7268757E-03,   1.7244471E-03
     +,   1.7219840E-03,   1.7193401E-03,   1.7163949E-03
     +,   1.7130619E-03,   1.7092956E-03,   1.7050907E-03
     +,   1.7004865E-03,   1.6955698E-03,   1.6904733E-03
     +,   1.6853724E-03,   1.6804823E-03,   1.6760579E-03
     +,   1.6723860E-03,   1.6697726E-03,   1.6685437E-03
     +,   1.6690299E-03,   1.6715584E-03,   1.6764462E-03
     +,   1.6839877E-03,   1.6944478E-03,   1.7080584E-03
     +,   1.7250030E-03,   1.7454237E-03,   1.7694172E-03
     +,   1.7970318E-03,   1.8282732E-03,   1.8631192E-03
     +,   1.9015191E-03,   1.9434035E-03,   1.9887073E-03
     +,   2.0373780E-03,   2.0893777E-03,   2.1447027E-03
     +,   2.2033977E-03,   2.2655497E-03,   2.3312878E-03
     +,   2.4007850E-03,   2.4742475E-03,   2.5519091E-03
     +,   2.6339977E-03,   2.7207320E-03,   2.8123020E-03
     +,   2.9088454E-03,   3.0104311E-03,   3.1170612E-03
     +,   3.2286500E-03,   3.3450238E-03,   3.4659372E-03
     +,   3.5910830E-03,   3.7201061E-03,   3.8526156E-03
     +,   3.9882194E-03,   4.1265441E-03,   4.2672441E-03
     +,   4.4100122E-03,   4.5545865E-03,   4.7007478E-03
     +,   4.8483089E-03,   4.9970588E-03,   5.1467740E-03
     +,   5.2971430E-03,   5.4477351E-03,   5.5979635E-03
     +,   5.7470687E-03,   5.8940649E-03,   6.0377489E-03
     +,   6.1766659E-03,   6.3091968E-03,   6.4335512E-03
     +,   6.5478017E-03,   6.6499892E-03,   6.7381747E-03
     +,   6.8105049E-03,   6.8653170E-03,   6.9011743E-03
     +,   6.9169318E-03,   6.9118198E-03,   6.8854131E-03
     +,   6.8377112E-03,   6.7690439E-03,   6.6801212E-03
     +,   6.5719830E-03,   6.4459136E-03,   6.3034040E-03
     +,   6.1461120E-03,   5.9757843E-03,   5.7941955E-03
     +,   5.6031044E-03,   5.4042428E-03,   5.1992685E-03
     +,   4.9897311E-03,   4.7771055E-03,   4.5627654E-03
     +,   4.3479633E-03,   4.1338634E-03,   3.9215428E-03
     +,   3.7119917E-03,   3.5061021E-03,   3.3046699E-03
     +,   3.1084225E-03,   2.9179906E-03,   2.7339072E-03
     +,   2.5566102E-03,   2.3864636E-03,   2.2237194E-03
     +,   2.0685501E-03,   1.9210518E-03,   1.7812491E-03
     +,   1.6490896E-03,   1.5244614E-03,   1.4072194E-03
     +,   1.2971743E-03,   1.1940999E-03,   1.0977496E-03
     +,   1.0078675E-03,   9.2418661E-04,   8.4642833E-04
     +,   7.7431160E-04,   7.0756453E-04,   6.4590917E-04
     +,   5.8906933E-04,   5.3677789E-04,   4.8877142E-04
     +,   4.4478563E-04,   4.0456376E-04,   3.6785530E-04
     +,   3.3441634E-04,   3.0400706E-04,   2.7639489E-04
     +,   2.5135928E-04,   2.2868480E-04,   2.0816948E-04
     +,   1.8961896E-04,   1.7285331E-04,   1.5770186E-04
     +,   1.4400821E-04,   1.3162632E-04,   1.2042384E-04
     +,   1.1027887E-04,   1.0108219E-04,   9.2734597E-05
     +,   8.5147229E-05,   7.8241545E-05,   7.1946757E-05
     +,   6.6201035E-05,   6.0948980E-05,   5.6142391E-05
     +,   5.1738170E-05,   4.7698875E-05,   4.3990953E-05
     +,   4.0585197E-05,   3.7455266E-05,   3.4578145E-05
     +,   3.1932868E-05,   2.9500980E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt110 = Yx/0.189795454545455
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6360305E-03,   1.7397909E-03
     +,   1.8442986E-03,   1.9490408E-03,   2.0534981E-03
     +,   2.1571512E-03,   2.2594819E-03,   2.3599912E-03
     +,   2.4581938E-03,   2.5536339E-03,   2.6458828E-03
     +,   2.7345484E-03,   2.8192718E-03,   2.8997345E-03
     +,   2.9756620E-03,   3.0468095E-03,   3.1129811E-03
     +,   3.1740060E-03,   3.2297473E-03,   3.2801074E-03
     +,   3.3249971E-03,   3.3643704E-03,   3.3981861E-03
     +,   3.4264363E-03,   3.4491231E-03,   3.4662818E-03
     +,   3.4779538E-03,   3.4842161E-03,   3.4851721E-03
     +,   3.4809532E-03,   3.4717224E-03,   3.4576764E-03
     +,   3.4390516E-03,   3.4161126E-03,   3.3891627E-03
     +,   3.3585380E-03,   3.3245974E-03,   3.2877212E-03
     +,   3.2483069E-03,   3.2067657E-03,   3.1635098E-03
     +,   3.1189469E-03,   3.0734784E-03,   3.0274959E-03
     +,   2.9813766E-03,   2.9354787E-03,   2.8901431E-03
     +,   2.8456941E-03,   2.8024418E-03,   2.7606790E-03
     +,   2.7206843E-03,   2.6827336E-03,   2.6470779E-03
     +,   2.6139664E-03,   2.5836318E-03,   2.5562928E-03
     +,   2.5321506E-03,   2.5113791E-03,   2.4941252E-03
     +,   2.4805011E-03,   2.4705818E-03,   2.4643920E-03
     +,   2.4619107E-03,   2.4630637E-03,   2.4677168E-03
     +,   2.4756801E-03,   2.4867225E-03,   2.5005399E-03
     +,   2.5167991E-03,   2.5351197E-03,   2.5550833E-03
     +,   2.5762459E-03,   2.5981558E-03,   2.6203466E-03
     +,   2.6423489E-03,   2.6637116E-03,   2.6839962E-03
     +,   2.7027847E-03,   2.7197020E-03,   2.7344015E-03
     +,   2.7465748E-03,   2.7559653E-03,   2.7623519E-03
     +,   2.7655638E-03,   2.7654767E-03,   2.7620061E-03
     +,   2.7551081E-03,   2.7447776E-03,   2.7310548E-03
     +,   2.7139969E-03,   2.6937048E-03,   2.6702974E-03
     +,   2.6439214E-03,   2.6147433E-03,   2.5829433E-03
     +,   2.5487226E-03,   2.5122913E-03,   2.4738773E-03
     +,   2.4337131E-03,   2.3920450E-03,   2.3491224E-03
     +,   2.3051989E-03,   2.2605392E-03,   2.2154090E-03
     +,   2.1700710E-03,   2.1247864E-03,   2.0798219E-03
     +,   2.0354311E-03,   1.9918603E-03,   1.9493456E-03
     +,   1.9081078E-03,   1.8683540E-03,   1.8302690E-03
     +,   1.7940179E-03,   1.7597399E-03,   1.7275481E-03
     +,   1.6975303E-03,   1.6697410E-03,   1.6442144E-03
     +,   1.6209462E-03,   1.5999071E-03,   1.5810422E-03
     +,   1.5642688E-03,   1.5494821E-03,   1.5365524E-03
     +,   1.5253349E-03,   1.5156671E-03,   1.5073762E-03
     +,   1.5002777E-03,   1.4941837E-03,   1.4889038E-03
     +,   1.4842494E-03,   1.4800332E-03,   1.4760792E-03
     +,   1.4722196E-03,   1.4682977E-03,   1.4641737E-03
     +,   1.4597217E-03,   1.4548359E-03,   1.4494259E-03
     +,   1.4434221E-03,   1.4367749E-03,   1.4294521E-03
     +,   1.4214405E-03,   1.4127475E-03,   1.4033957E-03
     +,   1.3934211E-03,   1.3828808E-03,   1.3718414E-03
     +,   1.3603820E-03,   1.3485916E-03,   1.3365690E-03
     +,   1.3244217E-03,   1.3122606E-03,   1.3002031E-03
     +,   1.2883708E-03,   1.2768888E-03,   1.2658833E-03
     +,   1.2554814E-03,   1.2458147E-03,   1.2370131E-03
     +,   1.2292085E-03,   1.2225350E-03,   1.2171275E-03
     +,   1.2131237E-03,   1.2106630E-03,   1.2098851E-03
     +,   1.2109369E-03,   1.2139643E-03,   1.2191180E-03
     +,   1.2265519E-03,   1.2364199E-03,   1.2488792E-03
     +,   1.2640849E-03,   1.2821963E-03,   1.3033634E-03
     +,   1.3277400E-03,   1.3554679E-03,   1.3866837E-03
     +,   1.4215156E-03,   1.4600776E-03,   1.5024737E-03
     +,   1.5487876E-03,   1.5990916E-03,   1.6534398E-03
     +,   1.7118673E-03,   1.7743855E-03,   1.8409907E-03
     +,   1.9116588E-03,   1.9863395E-03,   2.0649643E-03
     +,   2.1474455E-03,   2.2336612E-03,   2.3234712E-03
     +,   2.4167085E-03,   2.5131893E-03,   2.6126918E-03
     +,   2.7149722E-03,   2.8197728E-03,   2.9268137E-03
     +,   3.0358005E-03,   3.1464198E-03,   3.2583820E-03
     +,   3.3713903E-03,   3.4851688E-03,   3.5994777E-03
     +,   3.7141147E-03,   3.8289111E-03,   3.9437502E-03
     +,   4.0585697E-03,   4.1733491E-03,   4.2881109E-03
     +,   4.4028866E-03,   4.5177308E-03,   4.6326853E-03
     +,   4.7477521E-03,   4.8628859E-03,   4.9779811E-03
     +,   5.0928388E-03,   5.2071572E-03,   5.3205243E-03
     +,   5.4324269E-03,   5.5422354E-03,   5.6492006E-03
     +,   5.7524755E-03,   5.8511221E-03,   5.9441077E-03
     +,   6.0303337E-03,   6.1086393E-03,   6.1778435E-03
     +,   6.2367101E-03,   6.2840274E-03,   6.3186120E-03
     +,   6.3393395E-03,   6.3451696E-03,   6.3352012E-03
     +,   6.3087046E-03,   6.2651257E-03,   6.2041609E-03
     +,   6.1257426E-03,   6.0300687E-03,   5.9176139E-03
     +,   5.7891239E-03,   5.6455955E-03,   5.4882448E-03
     +,   5.3185122E-03,   5.1379851E-03,   4.9483865E-03
     +,   4.7514974E-03,   4.5491601E-03,   4.3431893E-03
     +,   4.1353540E-03,   3.9273510E-03,   3.7207645E-03
     +,   3.5170212E-03,   3.3173983E-03,   3.1230133E-03
     +,   2.9347967E-03,   2.7535025E-03,   2.5797004E-03
     +,   2.4138098E-03,   2.2560894E-03,   2.1066507E-03
     +,   1.9654862E-03,   1.8324897E-03,   1.7074619E-03
     +,   1.5901293E-03,   1.4801802E-03,   1.3772650E-03
     +,   1.2810098E-03,   1.1910280E-03,   1.1069422E-03
     +,   1.0283847E-03,   9.5499429E-04,   8.8643306E-04
     +,   8.2238758E-04,   7.6255883E-04,   7.0667901E-04
     +,   6.5449392E-04,   6.0577603E-04,   5.6031003E-04
     +,   5.1790453E-04,   4.7837579E-04,   4.4155965E-04
     +,   4.0729780E-04,   3.7544651E-04,   3.4586727E-04
     +,   3.1842961E-04,   2.9301149E-04,   2.6949344E-04
     +,   2.4776428E-04,   2.2771410E-04,   2.0924023E-04
     +,   1.9224091E-04,   1.7662089E-04,   1.6228622E-04
     +,   1.4914866E-04,   1.3712175E-04,   1.2612440E-04
     +,   1.1607783E-04,   1.0690829E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt115 = Yx/0.183590909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0540172E-03,   1.1223914E-03
     +,   1.1924515E-03,   1.2639974E-03,   1.3368138E-03
     +,   1.4106717E-03,   1.4853326E-03,   1.5605539E-03
     +,   1.6360834E-03,   1.7116731E-03,   1.7870761E-03
     +,   1.8620486E-03,   1.9363544E-03,   2.0097685E-03
     +,   2.0820724E-03,   2.1530627E-03,   2.2225459E-03
     +,   2.2903432E-03,   2.3562803E-03,   2.4201984E-03
     +,   2.4819453E-03,   2.5413753E-03,   2.5983441E-03
     +,   2.6527224E-03,   2.7043708E-03,   2.7531651E-03
     +,   2.7989754E-03,   2.8416873E-03,   2.8811833E-03
     +,   2.9173666E-03,   2.9501487E-03,   2.9794641E-03
     +,   3.0052671E-03,   3.0275385E-03,   3.0462909E-03
     +,   3.0615756E-03,   3.0734765E-03,   3.0821140E-03
     +,   3.0876547E-03,   3.0902955E-03,   3.0902685E-03
     +,   3.0878501E-03,   3.0833296E-03,   3.0770225E-03
     +,   3.0692581E-03,   3.0603735E-03,   3.0507026E-03
     +,   3.0405710E-03,   3.0302820E-03,   3.0201185E-03
     +,   3.0103291E-03,   3.0011148E-03,   2.9926314E-03
     +,   2.9849939E-03,   2.9782513E-03,   2.9723996E-03
     +,   2.9673765E-03,   2.9630701E-03,   2.9593096E-03
     +,   2.9558826E-03,   2.9525408E-03,   2.9489936E-03
     +,   2.9449370E-03,   2.9400543E-03,   2.9340305E-03
     +,   2.9265536E-03,   2.9173454E-03,   2.9061483E-03
     +,   2.8927492E-03,   2.8769842E-03,   2.8587410E-03
     +,   2.8379671E-03,   2.8146645E-03,   2.7888971E-03
     +,   2.7607821E-03,   2.7304876E-03,   2.6982320E-03
     +,   2.6642717E-03,   2.6288880E-03,   2.5923920E-03
     +,   2.5551019E-03,   2.5173470E-03,   2.4794552E-03
     +,   2.4417276E-03,   2.4044674E-03,   2.3679403E-03
     +,   2.3323901E-03,   2.2980210E-03,   2.2650063E-03
     +,   2.2334810E-03,   2.2035427E-03,   2.1752468E-03
     +,   2.1486192E-03,   2.1236413E-03,   2.1002705E-03
     +,   2.0784345E-03,   2.0580308E-03,   2.0389429E-03
     +,   2.0210317E-03,   2.0041529E-03,   1.9881472E-03
     +,   1.9728604E-03,   1.9581353E-03,   1.9438200E-03
     +,   1.9297776E-03,   1.9158780E-03,   1.9020097E-03
     +,   1.8880788E-03,   1.8740081E-03,   1.8597400E-03
     +,   1.8452366E-03,   1.8304806E-03,   1.8154663E-03
     +,   1.8002072E-03,   1.7847279E-03,   1.7690624E-03
     +,   1.7532503E-03,   1.7373394E-03,   1.7213702E-03
     +,   1.7053904E-03,   1.6894357E-03,   1.6735364E-03
     +,   1.6577150E-03,   1.6419834E-03,   1.6263369E-03
     +,   1.6107694E-03,   1.5952552E-03,   1.5797620E-03
     +,   1.5642442E-03,   1.5486523E-03,   1.5329281E-03
     +,   1.5170113E-03,   1.5008372E-03,   1.4843451E-03
     +,   1.4674742E-03,   1.4501677E-03,   1.4323791E-03
     +,   1.4140693E-03,   1.3952074E-03,   1.3757724E-03
     +,   1.3557600E-03,   1.3351763E-03,   1.3140377E-03
     +,   1.2923755E-03,   1.2702352E-03,   1.2476709E-03
     +,   1.2247470E-03,   1.2015431E-03,   1.1781438E-03
     +,   1.1546424E-03,   1.1311388E-03,   1.1077388E-03
     +,   1.0845549E-03,   1.0616995E-03,   1.0392882E-03
     +,   1.0174389E-03,   9.9627022E-04,   9.7589847E-04
     +,   9.5644064E-04,   9.3801139E-04,   9.2072354E-04
     +,   9.0468768E-04,   8.9001149E-04,   8.7679958E-04
     +,   8.6515385E-04,   8.5517130E-04,   8.4694778E-04
     +,   8.4057369E-04,   8.3613582E-04,   8.3371677E-04
     +,   8.3339453E-04,   8.3524187E-04,   8.3932636E-04
     +,   8.4570789E-04,   8.5444091E-04,   8.6557271E-04
     +,   8.7914016E-04,   8.9517265E-04,   9.1368821E-04
     +,   9.3469612E-04,   9.5819629E-04,   9.8417560E-04
     +,   1.0126105E-03,   1.0434694E-03,   1.0767145E-03
     +,   1.1122966E-03,   1.1501643E-03,   1.1902628E-03
     +,   1.2325422E-03,   1.2769466E-03,   1.3234320E-03
     +,   1.3719650E-03,   1.4225178E-03,   1.4750742E-03
     +,   1.5296368E-03,   1.5862170E-03,   1.6448395E-03
     +,   1.7055315E-03,   1.7683359E-03,   1.8332943E-03
     +,   1.9004387E-03,   1.9697936E-03,   2.0413727E-03
     +,   2.1151663E-03,   2.1911343E-03,   2.2692210E-03
     +,   2.3493359E-03,   2.4313619E-03,   2.5151481E-03
     +,   2.6005432E-03,   2.6873760E-03,   2.7754658E-03
     +,   2.8646495E-03,   2.9547713E-03,   3.0457163E-03
     +,   3.1373927E-03,   3.2297517E-03,   3.3227878E-03
     +,   3.4165480E-03,   3.5111003E-03,   3.6065592E-03
     +,   3.7030501E-03,   3.8006913E-03,   3.8995924E-03
     +,   3.9998172E-03,   4.1013644E-03,   4.2041368E-03
     +,   4.3079294E-03,   4.4124001E-03,   4.5170668E-03
     +,   4.6212729E-03,   4.7242111E-03,   4.8249047E-03
     +,   4.9222545E-03,   5.0150147E-03,   5.1018791E-03
     +,   5.1814783E-03,   5.2524307E-03,   5.3134197E-03
     +,   5.3632124E-03,   5.4007219E-03,   5.4250341E-03
     +,   5.4354738E-03,   5.4315845E-03,   5.4131718E-03
     +,   5.3803055E-03,   5.3332835E-03,   5.2726339E-03
     +,   5.1990622E-03,   5.1134434E-03,   5.0167479E-03
     +,   4.9100174E-03,   4.7943341E-03,   4.6707815E-03
     +,   4.5403945E-03,   4.4041649E-03,   4.2630197E-03
     +,   4.1178344E-03,   3.9693904E-03,   3.8184074E-03
     +,   3.6655648E-03,   3.5114959E-03,   3.3567904E-03
     +,   3.2020200E-03,   3.0477457E-03,   2.8945103E-03
     +,   2.7428516E-03,   2.5932959E-03,   2.4463639E-03
     +,   2.3025563E-03,   2.1623350E-03,   2.0261507E-03
     +,   1.8944081E-03,   1.7674592E-03,   1.6456015E-03
     +,   1.5290899E-03,   1.4181036E-03,   1.3127723E-03
     +,   1.2131584E-03,   1.1192744E-03,   1.0310697E-03
     +,   9.4845518E-04,   8.7129290E-04,   7.9941511E-04
     +,   7.3261722E-04,   6.7068258E-04,   6.1337143E-04
     +,   5.6043518E-04,   5.1162648E-04,   4.6669107E-04
     +,   4.2538458E-04,   3.8746503E-04,   3.5270283E-04
     +,   3.2087532E-04,   2.9177524E-04,   2.6520272E-04
     +,   2.4097331E-04,   2.1891075E-04,   1.9885227E-04
     +,   1.8064288E-04,   1.6413943E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt120 = Yx/0.164181818181818
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3317483E-04,   3.5882575E-04
     +,   3.8579319E-04,   4.1408959E-04,   4.4372070E-04
     +,   4.7468554E-04,   5.0697563E-04,   5.4057181E-04
     +,   5.7544443E-04,   6.1155221E-04,   6.4884004E-04
     +,   6.8723661E-04,   7.2665414E-04,   7.6698780E-04
     +,   8.0811296E-04,   8.4988709E-04,   8.9214643E-04
     +,   9.3470886E-04,   9.7737450E-04,   1.0199269E-03
     +,   1.0621337E-03,   1.1037535E-03,   1.1445344E-03
     +,   1.1842245E-03,   1.2225668E-03,   1.2593145E-03
     +,   1.2942287E-03,   1.3270857E-03,   1.3576801E-03
     +,   1.3858308E-03,   1.4113833E-03,   1.4342110E-03
     +,   1.4542184E-03,   1.4713411E-03,   1.4855450E-03
     +,   1.4968253E-03,   1.5052039E-03,   1.5107251E-03
     +,   1.5134556E-03,   1.5134779E-03,   1.5108845E-03
     +,   1.5057797E-03,   1.4982715E-03,   1.4884692E-03
     +,   1.4764852E-03,   1.4624291E-03,   1.4464104E-03
     +,   1.4285397E-03,   1.4089256E-03,   1.3876822E-03
     +,   1.3649281E-03,   1.3407900E-03,   1.3154036E-03
     +,   1.2889190E-03,   1.2615005E-03,   1.2333256E-03
     +,   1.2045878E-03,   1.1754946E-03,   1.1462662E-03
     +,   1.1171321E-03,   1.0883262E-03,   1.0600849E-03
     +,   1.0326420E-03,   1.0062194E-03,   9.8102761E-04
     +,   9.5725729E-04,   9.3507528E-04,   9.1462285E-04
     +,   8.9600869E-04,   8.7931240E-04,   8.6457742E-04
     +,   8.5181621E-04,   8.4100774E-04,   8.3210284E-04
     +,   8.2502264E-04,   8.1966585E-04,   8.1591104E-04
     +,   8.1361964E-04,   8.1264257E-04,   8.1282185E-04
     +,   8.1399636E-04,   8.1600453E-04,   8.1868697E-04
     +,   8.2189118E-04,   8.2547136E-04,   8.2929170E-04
     +,   8.3322648E-04,   8.3716231E-04,   8.4099680E-04
     +,   8.4463926E-04,   8.4801251E-04,   8.5104891E-04
     +,   8.5369218E-04,   8.5589680E-04,   8.5762638E-04
     +,   8.5885293E-04,   8.5955655E-04,   8.5972570E-04
     +,   8.5935369E-04,   8.5844070E-04,   8.5699133E-04
     +,   8.5501478E-04,   8.5252349E-04,   8.4953260E-04
     +,   8.4606139E-04,   8.4212888E-04,   8.3775708E-04
     +,   8.3296822E-04,   8.2778622E-04,   8.2223484E-04
     +,   8.1633934E-04,   8.1012456E-04,   8.0361741E-04
     +,   7.9684408E-04,   7.8983366E-04,   7.8261457E-04
     +,   7.7521778E-04,   7.6767500E-04,   7.6001993E-04
     +,   7.5228832E-04,   7.4451667E-04,   7.3674321E-04
     +,   7.2900852E-04,   7.2135305E-04,   7.1381760E-04
     +,   7.0644368E-04,   6.9927255E-04,   6.9234427E-04
     +,   6.8569713E-04,   6.7936833E-04,   6.7339104E-04
     +,   6.6779612E-04,   6.6261104E-04,   6.5785903E-04
     +,   6.5355800E-04,   6.4972189E-04,   6.4635993E-04
     +,   6.4347551E-04,   6.4106734E-04,   6.3912879E-04
     +,   6.3764706E-04,   6.3660531E-04,   6.3598150E-04
     +,   6.3574727E-04,   6.3587149E-04,   6.3631689E-04
     +,   6.3704292E-04,   6.3800474E-04,   6.3915417E-04
     +,   6.4043957E-04,   6.4180786E-04,   6.4320274E-04
     +,   6.4456818E-04,   6.4584630E-04,   6.4698054E-04
     +,   6.4791454E-04,   6.4859510E-04,   6.4897153E-04
     +,   6.4899720E-04,   6.4863072E-04,   6.4783654E-04
     +,   6.4658583E-04,   6.4485701E-04,   6.4263743E-04
     +,   6.3992315E-04,   6.3671893E-04,   6.3303945E-04
     +,   6.2890933E-04,   6.2436145E-04,   6.1943836E-04
     +,   6.1419111E-04,   6.0867856E-04,   6.0296664E-04
     +,   5.9712585E-04,   5.9123285E-04,   5.8536656E-04
     +,   5.7960808E-04,   5.7403918E-04,   5.6874135E-04
     +,   5.6379254E-04,   5.5926834E-04,   5.5523909E-04
     +,   5.5176986E-04,   5.4891797E-04,   5.4673362E-04
     +,   5.4525927E-04,   5.4452842E-04,   5.4456585E-04
     +,   5.4538663E-04,   5.4699829E-04,   5.4939860E-04
     +,   5.5257755E-04,   5.5651733E-04,   5.6119281E-04
     +,   5.6657306E-04,   5.7262043E-04,   5.7929318E-04
     +,   5.8654480E-04,   5.9432536E-04,   6.0258241E-04
     +,   6.1126123E-04,   6.2030525E-04,   6.2965654E-04
     +,   6.3925725E-04,   6.4904772E-04,   6.5896951E-04
     +,   6.6896359E-04,   6.7896961E-04,   6.8892783E-04
     +,   6.9877837E-04,   7.0846122E-04,   7.1791530E-04
     +,   7.2707859E-04,   7.3588925E-04,   7.4428431E-04
     +,   7.5219991E-04,   7.5957080E-04,   7.6633249E-04
     +,   7.7242020E-04,   7.7776815E-04,   7.8231236E-04
     +,   7.8598986E-04,   7.8874000E-04,   7.9050392E-04
     +,   7.9122715E-04,   7.9085986E-04,   7.8935717E-04
     +,   7.8668044E-04,   7.8279880E-04,   7.7768828E-04
     +,   7.7133410E-04,   7.6373137E-04,   7.5488392E-04
     +,   7.4480515E-04,   7.3352054E-04,   7.2106416E-04
     +,   7.0747989E-04,   6.9282221E-04,   6.7715463E-04
     +,   6.6054839E-04,   6.4308156E-04,   6.2484056E-04
     +,   6.0591701E-04,   5.8640551E-04,   5.6640420E-04
     +,   5.4601411E-04,   5.2533735E-04,   5.0447346E-04
     +,   4.8352117E-04,   4.6257814E-04,   4.4173628E-04
     +,   4.2108251E-04,   4.0070034E-04,   3.8066666E-04
     +,   3.6105060E-04,   3.4191433E-04,   3.2331372E-04
     +,   3.0529741E-04,   2.8790531E-04,   2.7116988E-04
     +,   2.5511766E-04,   2.3976786E-04,   2.2513226E-04
     +,   2.1121651E-04,   1.9802181E-04,   1.8554273E-04
     +,   1.7376924E-04,   1.6268784E-04,   1.5228143E-04
     +,   1.4252884E-04,   1.3340665E-04,   1.2488979E-04
     +,   1.1695155E-04,   1.0956352E-04,   1.0269653E-04
     +,   9.6321724E-05,   9.0409296E-05,   8.4930536E-05
     +,   7.9856363E-05,   7.5159209E-05,   7.0811628E-05
     +,   6.6787994E-05,   6.3063133E-05,   5.9613678E-05
     +,   5.6417095E-05,   5.3452655E-05,   5.0700648E-05
     +,   4.8142734E-05,   4.5762179E-05,   4.3543241E-05
     +,   4.1471681E-05,   3.9534261E-05,   3.7719110E-05
     +,   3.6015197E-05,   3.4412744E-05,   3.2902695E-05
     +,   3.1477091E-05,   3.0128576E-05,   2.8850720E-05
     +,   2.7637599E-05,   2.6484067E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt60 = Yx/0.05
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5631430E-04,   3.7632114E-04
     +,   3.9663076E-04,   4.1724334E-04,   4.3817153E-04
     +,   4.5944302E-04,   4.8109973E-04,   5.0319830E-04
     +,   5.2580883E-04,   5.4901541E-04,   5.7291199E-04
     +,   5.9760275E-04,   6.2319991E-04,   6.4982113E-04
     +,   6.7758921E-04,   7.0662971E-04,   7.3707075E-04
     +,   7.6904177E-04,   8.0267346E-04,   8.3809724E-04
     +,   8.7544229E-04,   9.1483875E-04,   9.5640827E-04
     +,   1.0002687E-03,   1.0465177E-03,   1.0952329E-03
     +,   1.1464601E-03,   1.2001985E-03,   1.2563928E-03
     +,   1.3149176E-03,   1.3755653E-03,   1.4380359E-03
     +,   1.5019301E-03,   1.5667483E-03,   1.6318898E-03
     +,   1.6966640E-03,   1.7603074E-03,   1.8220037E-03
     +,   1.8809163E-03,   1.9362107E-03,   1.9871017E-03
     +,   2.0328828E-03,   2.0729573E-03,   2.1068710E-03
     +,   2.1343308E-03,   2.1552234E-03,   2.1696119E-03
     +,   2.1777370E-03,   2.1799922E-03,   2.1769085E-03
     +,   2.1691199E-03,   2.1573228E-03,   2.1422456E-03
     +,   2.1245987E-03,   2.1050628E-03,   2.0842336E-03
     +,   2.0626162E-03,   2.0406023E-03,   2.0184650E-03
     +,   1.9963623E-03,   1.9743384E-03,   1.9523379E-03
     +,   1.9302292E-03,   1.9078173E-03,   1.8848705E-03
     +,   1.8611440E-03,   1.8363958E-03,   1.8104160E-03
     +,   1.7830305E-03,   1.7541287E-03,   1.7236592E-03
     +,   1.6916502E-03,   1.6581946E-03,   1.6234647E-03
     +,   1.5876913E-03,   1.5511622E-03,   1.5142121E-03
     +,   1.4772069E-03,   1.4405230E-03,   1.4045371E-03
     +,   1.3696156E-03,   1.3360902E-03,   1.3042523E-03
     +,   1.2743364E-03,   1.2465242E-03,   1.2209197E-03
     +,   1.1975687E-03,   1.1764410E-03,   1.1574458E-03
     +,   1.1404299E-03,   1.1251895E-03,   1.1114783E-03
     +,   1.0990177E-03,   1.0875094E-03,   1.0766451E-03
     +,   1.0661199E-03,   1.0556418E-03,   1.0449432E-03
     +,   1.0337873E-03,   1.0219751E-03,   1.0093497E-03
     +,   9.9580223E-04,   9.8126708E-04,   9.6572662E-04
     +,   9.4920420E-04,   9.3176117E-04,   9.1349182E-04
     +,   8.9451839E-04,   8.7498146E-04,   8.5503375E-04
     +,   8.3483697E-04,   8.1455160E-04,   7.9433405E-04
     +,   7.7432970E-04,   7.5467344E-04,   7.3548307E-04
     +,   7.1686064E-04,   6.9888891E-04,   6.8163587E-04
     +,   6.6515169E-04,   6.4946967E-04,   6.3461321E-04
     +,   6.2059145E-04,   6.0740474E-04,   5.9504446E-04
     +,   5.8349787E-04,   5.7274493E-04,   5.6276529E-04
     +,   5.5353373E-04,   5.4502563E-04,   5.3721358E-04
     +,   5.3007226E-04,   5.2357401E-04,   5.1769300E-04
     +,   5.1240210E-04,   5.0767499E-04,   5.0348538E-04
     +,   4.9980677E-04,   4.9661309E-04,   4.9387774E-04
     +,   4.9157476E-04,   4.8967876E-04,   4.8816402E-04
     +,   4.8700548E-04,   4.8617925E-04,   4.8566147E-04
     +,   4.8542966E-04,   4.8546196E-04,   4.8573763E-04
     +,   4.8623729E-04,   4.8694224E-04,   4.8783468E-04
     +,   4.8889755E-04,   4.9011473E-04,   4.9147115E-04
     +,   4.9295131E-04,   4.9454020E-04,   4.9622369E-04
     +,   4.9798691E-04,   4.9981585E-04,   5.0169550E-04
     +,   5.0361210E-04,   5.0555129E-04,   5.0749816E-04
     +,   5.0943933E-04,   5.1136152E-04,   5.1325181E-04
     +,   5.1509769E-04,   5.1688851E-04,   5.1861443E-04
     +,   5.2026671E-04,   5.2183814E-04,   5.2332354E-04
     +,   5.2471942E-04,   5.2602339E-04,   5.2723527E-04
     +,   5.2835682E-04,   5.2939099E-04,   5.3034234E-04
     +,   5.3121703E-04,   5.3202221E-04,   5.3276605E-04
     +,   5.3345750E-04,   5.3410546E-04,   5.3471985E-04
     +,   5.3531007E-04,   5.3588534E-04,   5.3645414E-04
     +,   5.3702481E-04,   5.3760421E-04,   5.3819775E-04
     +,   5.3881016E-04,   5.3944468E-04,   5.4010254E-04
     +,   5.4078334E-04,   5.4148503E-04,   5.4220395E-04
     +,   5.4293411E-04,   5.4366799E-04,   5.4439600E-04
     +,   5.4510706E-04,   5.4578763E-04,   5.4642314E-04
     +,   5.4699753E-04,   5.4749229E-04,   5.4788846E-04
     +,   5.4816552E-04,   5.4830173E-04,   5.4827507E-04
     +,   5.4806267E-04,   5.4764078E-04,   5.4698670E-04
     +,   5.4607668E-04,   5.4488832E-04,   5.4339977E-04
     +,   5.4159027E-04,   5.3944025E-04,   5.3693180E-04
     +,   5.3404906E-04,   5.3077866E-04,   5.2710908E-04
     +,   5.2303163E-04,   5.1854021E-04,   5.1363267E-04
     +,   5.0830864E-04,   5.0257082E-04,   4.9642561E-04
     +,   4.8988254E-04,   4.8295356E-04,   4.7565289E-04
     +,   4.6799838E-04,   4.6001008E-04,   4.5170943E-04
     +,   4.4312028E-04,   4.3426841E-04,   4.2518030E-04
     +,   4.1588335E-04,   4.0640598E-04,   3.9677744E-04
     +,   3.8702611E-04,   3.7718005E-04,   3.6726758E-04
     +,   3.5731631E-04,   3.4735238E-04,   3.3740033E-04
     +,   3.2748433E-04,   3.1762704E-04,   3.0784894E-04
     +,   2.9816874E-04,   2.8860455E-04,   2.7917192E-04
     +,   2.6988424E-04,   2.6075440E-04,   2.5179322E-04
     +,   2.4300961E-04,   2.3441094E-04,   2.2600358E-04
     +,   2.1779280E-04,   2.0978204E-04,   2.0197347E-04
     +,   1.9436909E-04,   1.8696977E-04,   1.7977509E-04
     +,   1.7278413E-04,   1.6599582E-04,   1.5940818E-04
     +,   1.5301850E-04,   1.4682439E-04,   1.4082300E-04
     +,   1.3501097E-04,   1.2938466E-04,   1.2394080E-04
     +,   1.1867592E-04,   1.1358617E-04,   1.0866769E-04
     +,   1.0391713E-04,   9.9330391E-05,   9.4904179E-05
     +,   9.0634494E-05,   8.6518019E-05,   8.2550927E-05
     +,   7.8729892E-05,   7.5051219E-05,   7.1511669E-05
     +,   6.8107605E-05,   6.4835847E-05,   6.1692939E-05
     +,   5.8675469E-05,   5.5780336E-05,   5.3004085E-05
     +,   5.0343606E-05,   4.7795540E-05,   4.5356803E-05
     +,   4.3024040E-05,   4.0794217E-05,   3.8664009E-05
     +,   3.6630438E-05,   3.4690223E-05,   3.2840380E-05
     +,   3.1077696E-05,   2.9399238E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt65 = Yx/0.0540555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2971492E-04,   2.4042213E-04
     +,   2.5125485E-04,   2.6218063E-04,   2.7316416E-04
     +,   2.8416715E-04,   2.9514884E-04,   3.0606680E-04
     +,   3.1687724E-04,   3.2753713E-04,   3.3800496E-04
     +,   3.4824249E-04,   3.5821745E-04,   3.6790586E-04
     +,   3.7729531E-04,   3.8638691E-04,   3.9519984E-04
     +,   4.0377435E-04,   4.1217398E-04,   4.2049008E-04
     +,   4.2884276E-04,   4.3738389E-04,   4.4629694E-04
     +,   4.5579841E-04,   4.6613414E-04,   4.7758006E-04
     +,   4.9043586E-04,   5.0502154E-04,   5.2167033E-04
     +,   5.4072367E-04,   5.6252186E-04,   5.8739854E-04
     +,   6.1567174E-04,   6.4763846E-04,   6.8356731E-04
     +,   7.2369439E-04,   7.6821959E-04,   8.1730157E-04
     +,   8.7106018E-04,   9.2956499E-04,   9.9284376E-04
     +,   1.0608692E-03,   1.1335571E-03,   1.2107558E-03
     +,   1.2922377E-03,   1.3776831E-03,   1.4666682E-03
     +,   1.5586482E-03,   1.6529460E-03,   1.7487445E-03
     +,   1.8450860E-03,   1.9408779E-03,   2.0349126E-03
     +,   2.1259109E-03,   2.2125388E-03,   2.2934927E-03
     +,   2.3675323E-03,   2.4335657E-03,   2.4906925E-03
     +,   2.5382696E-03,   2.5759500E-03,   2.6037109E-03
     +,   2.6218542E-03,   2.6310014E-03,   2.6320615E-03
     +,   2.6261732E-03,   2.6146546E-03,   2.5989227E-03
     +,   2.5804255E-03,   2.5605534E-03,   2.5405814E-03
     +,   2.5216052E-03,   2.5044850E-03,   2.4898194E-03
     +,   2.4779211E-03,   2.4688132E-03,   2.4622504E-03
     +,   2.4577382E-03,   2.4545803E-03,   2.4519274E-03
     +,   2.4488356E-03,   2.4443285E-03,   2.4374505E-03
     +,   2.4273307E-03,   2.4132256E-03,   2.3945486E-03
     +,   2.3709033E-03,   2.3420805E-03,   2.3080690E-03
     +,   2.2690254E-03,   2.2252600E-03,   2.1772049E-03
     +,   2.1253885E-03,   2.0703857E-03,   2.0128135E-03
     +,   1.9532908E-03,   1.8924192E-03,   1.8307792E-03
     +,   1.7689060E-03,   1.7073012E-03,   1.6464125E-03
     +,   1.5866477E-03,   1.5283587E-03,   1.4718578E-03
     +,   1.4173997E-03,   1.3651884E-03,   1.3153808E-03
     +,   1.2680769E-03,   1.2233241E-03,   1.1811187E-03
     +,   1.1414111E-03,   1.1041084E-03,   1.0690830E-03
     +,   1.0361769E-03,   1.0052162E-03,   9.7601156E-04
     +,   9.4837655E-04,   9.2212489E-04,   8.9708844E-04
     +,   8.7311404E-04,   8.5007009E-04,   8.2785217E-04
     +,   8.0638070E-04,   7.8559865E-04,   7.6547125E-04
     +,   7.4598577E-04,   7.2714110E-04,   7.0894946E-04
     +,   6.9142779E-04,   6.7459547E-04,   6.5846962E-04
     +,   6.4306305E-04,   6.2837871E-04,   6.1441259E-04
     +,   6.0114835E-04,   5.8856042E-04,   5.7661318E-04
     +,   5.6526373E-04,   5.5446126E-04,   5.4415088E-04
     +,   5.3427584E-04,   5.2477885E-04,   5.1560375E-04
     +,   5.0669885E-04,   4.9801730E-04,   4.8951758E-04
     +,   4.8116624E-04,   4.7293707E-04,   4.6481236E-04
     +,   4.5678092E-04,   4.4883936E-04,   4.4099108E-04
     +,   4.3324611E-04,   4.2561887E-04,   4.1812859E-04
     +,   4.1079838E-04,   4.0365392E-04,   3.9672278E-04
     +,   3.9003365E-04,   3.8361596E-04,   3.7749935E-04
     +,   3.7171220E-04,   3.6628279E-04,   3.6123849E-04
     +,   3.5660440E-04,   3.5240411E-04,   3.4866089E-04
     +,   3.4539535E-04,   3.4262647E-04,   3.4037177E-04
     +,   3.3864760E-04,   3.3746834E-04,   3.3684689E-04
     +,   3.3679491E-04,   3.3732216E-04,   3.3843718E-04
     +,   3.4014680E-04,   3.4245563E-04,   3.4536675E-04
     +,   3.4888080E-04,   3.5299617E-04,   3.5770863E-04
     +,   3.6301053E-04,   3.6889152E-04,   3.7533802E-04
     +,   3.8233178E-04,   3.8985090E-04,   3.9787017E-04
     +,   4.0635903E-04,   4.1528305E-04,   4.2460329E-04
     +,   4.3427726E-04,   4.4425696E-04,   4.5449150E-04
     +,   4.6492589E-04,   4.7550316E-04,   4.8616217E-04
     +,   4.9684005E-04,   5.0747301E-04,   5.1799626E-04
     +,   5.2834454E-04,   5.3845264E-04,   5.4825767E-04
     +,   5.5769819E-04,   5.6671473E-04,   5.7525141E-04
     +,   5.8325648E-04,   5.9068127E-04,   5.9748185E-04
     +,   6.0361961E-04,   6.0906069E-04,   6.1377557E-04
     +,   6.1774038E-04,   6.2093651E-04,   6.2334951E-04
     +,   6.2496995E-04,   6.2579272E-04,   6.2581699E-04
     +,   6.2504504E-04,   6.2348327E-04,   6.2114105E-04
     +,   6.1803043E-04,   6.1416550E-04,   6.0956366E-04
     +,   6.0424325E-04,   5.9822429E-04,   5.9152936E-04
     +,   5.8418186E-04,   5.7620648E-04,   5.6762953E-04
     +,   5.5847823E-04,   5.4878159E-04,   5.3856918E-04
     +,   5.2787177E-04,   5.1672244E-04,   5.0515390E-04
     +,   4.9320061E-04,   4.8089816E-04,   4.6828383E-04
     +,   4.5539439E-04,   4.4226745E-04,   4.2894212E-04
     +,   4.1545776E-04,   4.0185323E-04,   3.8816716E-04
     +,   3.7443891E-04,   3.6070705E-04,   3.4700899E-04
     +,   3.3338071E-04,   3.1985855E-04,   3.0647599E-04
     +,   2.9326492E-04,   2.8025621E-04,   2.6747890E-04
     +,   2.5495893E-04,   2.4272002E-04,   2.3078440E-04
     +,   2.1917187E-04,   2.0789908E-04,   1.9698017E-04
     +,   1.8642769E-04,   1.7625150E-04,   1.6645876E-04
     +,   1.5705412E-04,   1.4804106E-04,   1.3942005E-04
     +,   1.3118958E-04,   1.2334691E-04,   1.1588752E-04
     +,   1.0880479E-04,   1.0209080E-04,   9.5736825E-05
     +,   8.9732930E-05,   8.4067884E-05,   7.8729747E-05
     +,   7.3706353E-05,   6.8984467E-05,   6.4551088E-05
     +,   6.0392351E-05,   5.6494962E-05,   5.2844985E-05
     +,   4.9429156E-05,   4.6233956E-05,   4.3246568E-05
     +,   4.0454117E-05,   3.7844562E-05,   3.5406010E-05
     +,   3.3127140E-05,   3.0997358E-05,   2.9006365E-05
     +,   2.7144681E-05,   2.5403177E-05,   2.3773517E-05
     +,   2.2247707E-05,   2.0818539E-05,   1.9479097E-05
     +,   1.8223214E-05,   1.7045004E-05,   1.5939211E-05
     +,   1.4900858E-05,   1.3925528E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt70 = Yx/0.0575555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3592548E-04,   1.4438546E-04
     +,   1.5329231E-04,   1.6265415E-04,   1.7247623E-04
     +,   1.8276094E-04,   1.9350802E-04,   2.0471394E-04
     +,   2.1637195E-04,   2.2847290E-04,   2.4100408E-04
     +,   2.5395057E-04,   2.6729467E-04,   2.8101687E-04
     +,   2.9509564E-04,   3.0950786E-04,   3.2422971E-04
     +,   3.3923599E-04,   3.5450095E-04,   3.6999816E-04
     +,   3.8570096E-04,   4.0158161E-04,   4.1761171E-04
     +,   4.3376294E-04,   4.5000456E-04,   4.6630588E-04
     +,   4.8263543E-04,   4.9896073E-04,   5.1525037E-04
     +,   5.3147436E-04,   5.4760621E-04,   5.6362589E-04
     +,   5.7952205E-04,   5.9529656E-04,   6.1096891E-04
     +,   6.2658079E-04,   6.4220239E-04,   6.5793714E-04
     +,   6.7392836E-04,   6.9036242E-04,   7.0747506E-04
     +,   7.2555197E-04,   7.4492896E-04,   7.6599017E-04
     +,   7.8916014E-04,   8.1489445E-04,   8.4366422E-04
     +,   8.7593572E-04,   9.1214961E-04,   9.5269224E-04
     +,   9.9787035E-04,   1.0478855E-03,   1.1028115E-03
     +,   1.1625855E-03,   1.2269929E-03,   1.2956905E-03
     +,   1.3682160E-03,   1.4440266E-03,   1.5225428E-03
     +,   1.6031993E-03,   1.6854940E-03,   1.7690343E-03
     +,   1.8535688E-03,   1.9390098E-03,   2.0254301E-03
     +,   2.1130312E-03,   2.2021250E-03,   2.2930680E-03
     +,   2.3862203E-03,   2.4818750E-03,   2.5802343E-03
     +,   2.6813389E-03,   2.7850582E-03,   2.8910402E-03
     +,   2.9986934E-03,   3.1071696E-03,   3.2153041E-03
     +,   3.3216388E-03,   3.4244058E-03,   3.5215656E-03
     +,   3.6108715E-03,   3.6900032E-03,   3.7567124E-03
     +,   3.8090134E-03,   3.8453673E-03,   3.8648557E-03
     +,   3.8672944E-03,   3.8532689E-03,   3.8240964E-03
     +,   3.7816977E-03,   3.7284037E-03,   3.6667218E-03
     +,   3.5991045E-03,   3.5277132E-03,   3.4542752E-03
     +,   3.3799815E-03,   3.3054601E-03,   3.2308558E-03
     +,   3.1558916E-03,   3.0800714E-03,   3.0027982E-03
     +,   2.9235533E-03,   2.8420121E-03,   2.7581484E-03
     +,   2.6722611E-03,   2.5849750E-03,   2.4971873E-03
     +,   2.4099865E-03,   2.3245218E-03,   2.2418983E-03
     +,   2.1630744E-03,   2.0887535E-03,   2.0193420E-03
     +,   1.9549110E-03,   1.8952215E-03,   1.8397529E-03
     +,   1.7877781E-03,   1.7384356E-03,   1.6908218E-03
     +,   1.6440647E-03,   1.5973919E-03,   1.5501914E-03
     +,   1.5020394E-03,   1.4527106E-03,   1.4021826E-03
     +,   1.3506197E-03,   1.2983354E-03,   1.2457694E-03
     +,   1.1934355E-03,   1.1418991E-03,   1.0917250E-03
     +,   1.0434618E-03,   9.9760236E-04,   9.5457543E-04
     +,   9.1472233E-04,   8.7829551E-04,   8.4545347E-04
     +,   8.1626279E-04,   7.9070136E-04,   7.6866860E-04
     +,   7.4999640E-04,   7.3446019E-04,   7.2178844E-04
     +,   7.1167958E-04,   7.0381275E-04,   6.9785659E-04
     +,   6.9348211E-04,   6.9036963E-04,   6.8821711E-04
     +,   6.8674202E-04,   6.8568933E-04,   6.8482984E-04
     +,   6.8396347E-04,   6.8291783E-04,   6.8154675E-04
     +,   6.7973143E-04,   6.7737512E-04,   6.7440287E-04
     +,   6.7076017E-04,   6.6640991E-04,   6.6133140E-04
     +,   6.5551867E-04,   6.4897945E-04,   6.4173498E-04
     +,   6.3381792E-04,   6.2527141E-04,   6.1614974E-04
     +,   6.0651789E-04,   5.9644884E-04,   5.8602286E-04
     +,   5.7532889E-04,   5.6446047E-04,   5.5351632E-04
     +,   5.4259709E-04,   5.3180667E-04,   5.2124751E-04
     +,   5.1102019E-04,   5.0122320E-04,   4.9194950E-04
     +,   4.8328543E-04,   4.7530976E-04,   4.6809300E-04
     +,   4.6169551E-04,   4.5616660E-04,   4.5154450E-04
     +,   4.4785565E-04,   4.4511512E-04,   4.4332503E-04
     +,   4.4247607E-04,   4.4254767E-04,   4.4350783E-04
     +,   4.4531477E-04,   4.4791683E-04,   4.5125349E-04
     +,   4.5525719E-04,   4.5985318E-04,   4.6496149E-04
     +,   4.7049759E-04,   4.7637353E-04,   4.8250033E-04
     +,   4.8878632E-04,   4.9514085E-04,   5.0147448E-04
     +,   5.0769967E-04,   5.1373203E-04,   5.1949022E-04
     +,   5.2489858E-04,   5.2988558E-04,   5.3438602E-04
     +,   5.3834118E-04,   5.4169795E-04,   5.4441061E-04
     +,   5.4644048E-04,   5.4775592E-04,   5.4833223E-04
     +,   5.4815190E-04,   5.4720417E-04,   5.4548518E-04
     +,   5.4299674E-04,   5.3974777E-04,   5.3575233E-04
     +,   5.3102960E-04,   5.2560470E-04,   5.1950611E-04
     +,   5.1276718E-04,   5.0542399E-04,   4.9751659E-04
     +,   4.8908766E-04,   4.8018148E-04,   4.7084404E-04
     +,   4.6112339E-04,   4.5106787E-04,   4.4072597E-04
     +,   4.3014620E-04,   4.1937732E-04,   4.0846632E-04
     +,   3.9745902E-04,   3.8640038E-04,   3.7533321E-04
     +,   3.6429762E-04,   3.5333136E-04,   3.4246990E-04
     +,   3.3174595E-04,   3.2118848E-04,   3.1082335E-04
     +,   3.0067377E-04,   2.9075940E-04,   2.8109629E-04
     +,   2.7169706E-04,   2.6257223E-04,   2.5372821E-04
     +,   2.4516866E-04,   2.3689495E-04,   2.2890605E-04
     +,   2.2119809E-04,   2.1376503E-04,   2.0660002E-04
     +,   1.9969407E-04,   1.9303706E-04,   1.8661759E-04
     +,   1.8042422E-04,   1.7444504E-04,   1.6866722E-04
     +,   1.6307842E-04,   1.5766677E-04,   1.5242037E-04
     +,   1.4732778E-04,   1.4237860E-04,   1.3756326E-04
     +,   1.3287256E-04,   1.2829834E-04,   1.2383357E-04
     +,   1.1947214E-04,   1.1520866E-04,   1.1103858E-04
     +,   1.0695861E-04,   1.0296567E-04,   9.9058045E-05
     +,   9.5234122E-05,   9.1493326E-05,   8.7835171E-05
     +,   8.4260013E-05,   8.0768135E-05,   7.7360499E-05
     +,   7.4037809E-05,   7.0801339E-05,   6.7652123E-05
     +,   6.4591120E-05,   6.1619598E-05,   5.8738278E-05
     +,   5.5948130E-05,   5.3249594E-05,   5.0643222E-05
     +,   4.8129008E-05,   4.5707071E-05,   4.3376924E-05
     +,   4.1138159E-05,   3.8989816E-05,   3.6930978E-05
     +,   3.4960256E-05,   3.3076252E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt75 = Yx/0.0685263157894737
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5757076E-04,   1.6272182E-04
     +,   1.6789646E-04,   1.7309577E-04,   1.7832207E-04
     +,   1.8357916E-04,   1.8887238E-04,   1.9420867E-04
     +,   1.9959666E-04,   2.0504685E-04,   2.1057145E-04
     +,   2.1618447E-04,   2.2190179E-04,   2.2774121E-04
     +,   2.3372243E-04,   2.3986684E-04,   2.4619783E-04
     +,   2.5274046E-04,   2.5952165E-04,   2.6656987E-04
     +,   2.7391512E-04,   2.8158893E-04,   2.8962397E-04
     +,   2.9805439E-04,   3.0691430E-04,   3.1623925E-04
     +,   3.2606433E-04,   3.3642462E-04,   3.4735404E-04
     +,   3.5888545E-04,   3.7104925E-04,   3.8387300E-04
     +,   3.9738053E-04,   4.1159053E-04,   4.2651623E-04
     +,   4.4216428E-04,   4.5853225E-04,   4.7560985E-04
     +,   4.9337739E-04,   5.1180285E-04,   5.3084514E-04
     +,   5.5045192E-04,   5.7056046E-04,   5.9109868E-04
     +,   6.1198790E-04,   6.3314528E-04,   6.5448810E-04
     +,   6.7593786E-04,   6.9742650E-04,   7.1890280E-04
     +,   7.4034004E-04,   7.6174125E-04,   7.8314648E-04
     +,   8.0464024E-04,   8.2634954E-04,   8.4845140E-04
     +,   8.7116659E-04,   8.9475478E-04,   9.1950787E-04
     +,   9.4573625E-04,   9.7375870E-04,   1.0038867E-03
     +,   1.0364130E-03,   1.0716100E-03,   1.1097272E-03
     +,   1.1509918E-03,   1.1956353E-03,   1.2439019E-03
     +,   1.2960864E-03,   1.3525434E-03,   1.4137157E-03
     +,   1.4801308E-03,   1.5523970E-03,   1.6311739E-03
     +,   1.7171424E-03,   1.8109661E-03,   1.9132441E-03
     +,   2.0244946E-03,   2.1451646E-03,   2.2756308E-03
     +,   2.4162135E-03,   2.5672328E-03,   2.7289526E-03
     +,   2.9015804E-03,   3.0851243E-03,   3.2792902E-03
     +,   3.4832691E-03,   3.6956358E-03,   3.9141988E-03
     +,   4.1360678E-03,   4.3577636E-03,   4.5754793E-03
     +,   4.7854227E-03,   4.9842349E-03,   5.1692501E-03
     +,   5.3387405E-03,   5.4919641E-03,   5.6290426E-03
     +,   5.7508047E-03,   5.8584968E-03,   5.9536356E-03
     +,   6.0377656E-03,   6.1124647E-03,   6.1791651E-03
     +,   6.2390696E-03,   6.2929518E-03,   6.3408753E-03
     +,   6.3819289E-03,   6.4140931E-03,   6.4342325E-03
     +,   6.4384388E-03,   6.4224903E-03,   6.3825464E-03
     +,   6.3157706E-03,   6.2207449E-03,   6.0976008E-03
     +,   5.9478520E-03,   5.7739331E-03,   5.5787279E-03
     +,   5.3650886E-03,   5.1356200E-03,   4.8927013E-03
     +,   4.6386984E-03,   4.3762052E-03,   4.1082902E-03
     +,   3.8386292E-03,   3.5713187E-03,   3.3106830E-03
     +,   3.0608461E-03,   2.8254439E-03,   2.6072671E-03
     +,   2.4081662E-03,   2.2289560E-03,   2.0695624E-03
     +,   1.9291298E-03,   1.8062494E-03,   1.6991632E-03
     +,   1.6059306E-03,   1.5245705E-03,   1.4531731E-03
     +,   1.3899757E-03,   1.3333994E-03,   1.2820741E-03
     +,   1.2348461E-03,   1.1907868E-03,   1.1491715E-03
     +,   1.1094714E-03,   1.0713363E-03,   1.0345654E-03
     +,   9.9907932E-04,   9.6489262E-04,   9.3208597E-04
     +,   9.0078136E-04,   8.7111443E-04,   8.4322074E-04
     +,   8.1722677E-04,   7.9323689E-04,   7.7133044E-04
     +,   7.5156137E-04,   7.3396100E-04,   7.1853492E-04
     +,   7.0526800E-04,   6.9412566E-04,   6.8505545E-04
     +,   6.7798700E-04,   6.7283493E-04,   6.6949934E-04
     +,   6.6786702E-04,   6.6781364E-04,   6.6920556E-04
     +,   6.7190151E-04,   6.7575549E-04,   6.8061939E-04
     +,   6.8634487E-04,   6.9278706E-04,   6.9980585E-04
     +,   7.0726866E-04,   7.1505125E-04,   7.2303892E-04
     +,   7.3112990E-04,   7.3923270E-04,   7.4726914E-04
     +,   7.5517100E-04,   7.6288369E-04,   7.7036244E-04
     +,   7.7757263E-04,   7.8448799E-04,   7.9108949E-04
     +,   7.9736562E-04,   8.0330792E-04,   8.0891221E-04
     +,   8.1417488E-04,   8.1909302E-04,   8.2366227E-04
     +,   8.2787598E-04,   8.3172438E-04,   8.3519309E-04
     +,   8.3826244E-04,   8.4090832E-04,   8.4310089E-04
     +,   8.4480504E-04,   8.4598205E-04,   8.4658799E-04
     +,   8.4657723E-04,   8.4590225E-04,   8.4451516E-04
     +,   8.4236963E-04,   8.3942083E-04,   8.3563052E-04
     +,   8.3096430E-04,   8.2539587E-04,   8.1890641E-04
     +,   8.1148819E-04,   8.0314180E-04,   7.9387944E-04
     +,   7.8372424E-04,   7.7271054E-04,   7.6088152E-04
     +,   7.4829056E-04,   7.3500059E-04,   7.2108087E-04
     +,   7.0660678E-04,   6.9165858E-04,   6.7631941E-04
     +,   6.6067307E-04,   6.4480223E-04,   6.2878890E-04
     +,   6.1271084E-04,   5.9664046E-04,   5.8064342E-04
     +,   5.6478003E-04,   5.4910197E-04,   5.3365249E-04
     +,   5.1846600E-04,   5.0356984E-04,   4.8898230E-04
     +,   4.7471336E-04,   4.6076716E-04,   4.4714136E-04
     +,   4.3382734E-04,   4.2081179E-04,   4.0807881E-04
     +,   3.9561017E-04,   3.8338470E-04,   3.7138126E-04
     +,   3.5957925E-04,   3.4795902E-04,   3.3650213E-04
     +,   3.2519191E-04,   3.1401575E-04,   3.0296278E-04
     +,   2.9202510E-04,   2.8119868E-04,   2.7048288E-04
     +,   2.5987922E-04,   2.4939206E-04,   2.3902909E-04
     +,   2.2880011E-04,   2.1871639E-04,   2.0879047E-04
     +,   1.9903683E-04,   1.8947062E-04,   1.8010664E-04
     +,   1.7095980E-04,   1.6204538E-04,   1.5337722E-04
     +,   1.4496826E-04,   1.3683076E-04,   1.2897556E-04
     +,   1.2141153E-04,   1.1414587E-04,   1.0718462E-04
     +,   1.0053205E-04,   9.4190211E-05,   8.8159533E-05
     +,   8.2439321E-05,   7.7026627E-05,   7.1917653E-05
     +,   6.7106681E-05,   6.2587285E-05,   5.8351390E-05
     +,   5.4390537E-05,   5.0694856E-05,   4.7254347E-05
     +,   4.4057942E-05,   4.1094601E-05,   3.8352693E-05
     +,   3.5820387E-05,   3.3486078E-05,   3.1337819E-05
     +,   2.9364104E-05,   2.7553346E-05,   2.5894458E-05
     +,   2.4376450E-05,   2.2988916E-05,   2.1721678E-05
     +,   2.0565161E-05,   1.9510120E-05,   1.8547924E-05
     +,   1.7670314E-05,   1.6869655E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt80 = Yx/0.09625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0648461E-04,   1.1071716E-04
     +,   1.1500272E-04,   1.1933441E-04,   1.2370505E-04
     +,   1.2810700E-04,   1.3253251E-04,   1.3697342E-04
     +,   1.4142139E-04,   1.4586815E-04,   1.5030509E-04
     +,   1.5472360E-04,   1.5911518E-04,   1.6347127E-04
     +,   1.6778366E-04,   1.7204419E-04,   1.7624506E-04
     +,   1.8037879E-04,   1.8443831E-04,   1.8841711E-04
     +,   1.9230906E-04,   1.9610883E-04,   1.9981158E-04
     +,   2.0341334E-04,   2.0691071E-04,   2.1030132E-04
     +,   2.1358348E-04,   2.1675631E-04,   2.1981997E-04
     +,   2.2277533E-04,   2.2562422E-04,   2.2836936E-04
     +,   2.3101424E-04,   2.3356311E-04,   2.3602117E-04
     +,   2.3839412E-04,   2.4068834E-04,   2.4291080E-04
     +,   2.4506918E-04,   2.4717112E-04,   2.4922509E-04
     +,   2.5123960E-04,   2.5322358E-04,   2.5518602E-04
     +,   2.5713639E-04,   2.5908439E-04,   2.6104014E-04
     +,   2.6301443E-04,   2.6501890E-04,   2.6706615E-04
     +,   2.6917076E-04,   2.7134895E-04,   2.7361995E-04
     +,   2.7600629E-04,   2.7853434E-04,   2.8123573E-04
     +,   2.8414786E-04,   2.8731476E-04,   2.9078810E-04
     +,   2.9462806E-04,   2.9890370E-04,   3.0369396E-04
     +,   3.0908707E-04,   3.1518150E-04,   3.2208522E-04
     +,   3.2991386E-04,   3.3879129E-04,   3.4884541E-04
     +,   3.6020888E-04,   3.7301343E-04,   3.8739017E-04
     +,   4.0346326E-04,   4.2135103E-04,   4.4115836E-04
     +,   4.6297960E-04,   4.8689495E-04,   5.1296788E-04
     +,   5.4124725E-04,   5.7177147E-04,   6.0456834E-04
     +,   6.3965452E-04,   6.7704864E-04,   7.1676605E-04
     +,   7.5883238E-04,   8.0328120E-04,   8.5017068E-04
     +,   8.9958502E-04,   9.5165957E-04,   1.0065935E-03
     +,   1.0646854E-03,   1.1263672E-03,   1.1922293E-03
     +,   1.2630515E-03,   1.3398104E-03,   1.4236429E-03
     +,   1.5157558E-03,   1.6173127E-03,   1.7292361E-03
     +,   1.8520433E-03,   1.9856668E-03,   2.1294048E-03
     +,   2.2819699E-03,   2.4417548E-03,   2.6072012E-03
     +,   2.7773357E-03,   2.9522446E-03,   3.1334260E-03
     +,   3.3239061E-03,   3.5280634E-03,   3.7511827E-03
     +,   3.9988719E-03,   4.2765751E-03,   4.5889928E-03
     +,   4.9395948E-03,   5.3295274E-03,   5.7562753E-03
     +,   6.2117130E-03,   6.6810893E-03,   7.1435566E-03
     +,   7.5757010E-03,   7.9571800E-03,   8.2766982E-03
     +,   8.5354494E-03,   8.7461835E-03,   8.9284712E-03
     +,   9.1028828E-03,   9.2870006E-03,   9.4938185E-03
     +,   9.7310347E-03,   9.9987118E-03,   1.0285476E-02
     +,   1.0566530E-02,   1.0807225E-02,   1.0972961E-02
     +,   1.1040878E-02,   1.1006338E-02,   1.0879839E-02
     +,   1.0676081E-02,   1.0402460E-02,   1.0054585E-02
     +,   9.6214302E-03,   9.0965340E-03,   8.4878458E-03
     +,   7.8206295E-03,   7.1324492E-03,   6.4632068E-03
     +,   5.8457302E-03,   5.3001861E-03,   4.8330701E-03
     +,   4.4397125E-03,   4.1082706E-03,   3.8237455E-03
     +,   3.5711611E-03,   3.3378371E-03,   3.1147511E-03
     +,   2.8969771E-03,   2.6833557E-03,   2.4755516E-03
     +,   2.2768741E-03,   2.0911333E-03,   1.9216889E-03
     +,   1.7709065E-03,   1.6399815E-03,   1.5289860E-03
     +,   1.4370815E-03,   1.3628001E-03,   1.3042985E-03
     +,   1.2595517E-03,   1.2264990E-03,   1.2031412E-03
     +,   1.1875993E-03,   1.1781412E-03,   1.1731953E-03
     +,   1.1713540E-03,   1.1713679E-03,   1.1721425E-03
     +,   1.1727262E-03,   1.1723073E-03,   1.1702069E-03
     +,   1.1658769E-03,   1.1588939E-03,   1.1489645E-03
     +,   1.1359148E-03,   1.1196912E-03,   1.1003504E-03
     +,   1.0780534E-03,   1.0530513E-03,   1.0256675E-03
     +,   9.9628326E-04,   9.6532097E-04,   9.3322119E-04
     +,   9.0042688E-04,   8.6736900E-04,   8.3445193E-04
     +,   8.0203766E-04,   7.7044254E-04,   7.3993154E-04
     +,   7.1071653E-04,   6.8295246E-04,   6.5674330E-04
     +,   6.3214806E-04,   6.0918217E-04,   5.8782555E-04
     +,   5.6802679E-04,   5.4971484E-04,   5.3279771E-04
     +,   5.1717210E-04,   5.0272880E-04,   4.8935460E-04
     +,   4.7693582E-04,   4.6536126E-04,   4.5452596E-04
     +,   4.4433097E-04,   4.3468463E-04,   4.2550280E-04
     +,   4.1671176E-04,   4.0824580E-04,   4.0004743E-04
     +,   3.9206730E-04,   3.8426532E-04,   3.7660706E-04
     +,   3.6906547E-04,   3.6161937E-04,   3.5425319E-04
     +,   3.4695517E-04,   3.3971696E-04,   3.3253425E-04
     +,   3.2540469E-04,   3.1832737E-04,   3.1130269E-04
     +,   3.0433238E-04,   2.9741830E-04,   2.9056205E-04
     +,   2.8376549E-04,   2.7703022E-04,   2.7035738E-04
     +,   2.6374724E-04,   2.5720047E-04,   2.5071713E-04
     +,   2.4429659E-04,   2.3793805E-04,   2.3164097E-04
     +,   2.2540492E-04,   2.1922911E-04,   2.1311300E-04
     +,   2.0705666E-04,   2.0106070E-04,   1.9512567E-04
     +,   1.8925253E-04,   1.8344341E-04,   1.7770033E-04
     +,   1.7202573E-04,   1.6642280E-04,   1.6089524E-04
     +,   1.5544661E-04,   1.5008076E-04,   1.4480200E-04
     +,   1.3961481E-04,   1.3452335E-04,   1.2953169E-04
     +,   1.2464410E-04,   1.1986474E-04,   1.1519710E-04
     +,   1.1064438E-04,   1.0620991E-04,   1.0189617E-04
     +,   9.7705248E-05,   9.3639013E-05,   8.9698908E-05
     +,   8.5885637E-05,   8.2199491E-05,   7.8640514E-05
     +,   7.5208314E-05,   7.1901915E-05,   6.8719863E-05
     +,   6.5660759E-05,   6.2722393E-05,   5.9902704E-05
     +,   5.7198977E-05,   5.4608612E-05,   5.2128478E-05
     +,   4.9755643E-05,   4.7486705E-05,   4.5318458E-05
     +,   4.3247364E-05,   4.1270101E-05,   3.9383147E-05
     +,   3.7582966E-05,   3.5866244E-05,   3.4229481E-05
     +,   3.2669428E-05,   3.1182728E-05,   2.9766266E-05
     +,   2.8416865E-05,   2.7131588E-05,   2.5907444E-05
     +,   2.4741705E-05,   2.3631585E-05,   2.2574568E-05
     +,   2.1568076E-05,   2.0609790E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt85 = Yx/0.115585365853659
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9148536E-05,   8.1383791E-05
     +,   8.3573759E-05,   8.5711705E-05,   8.7791006E-05
     +,   8.9805304E-05,   9.1748479E-05,   9.3614748E-05
     +,   9.5398675E-05,   9.7095377E-05,   9.8700308E-05
     +,   1.0020952E-04,   1.0161965E-04,   1.0292794E-04
     +,   1.0413229E-04,   1.0523123E-04,   1.0622411E-04
     +,   1.0711090E-04,   1.0789240E-04,   1.0857006E-04
     +,   1.0914619E-04,   1.0962375E-04,   1.1000649E-04
     +,   1.1029883E-04,   1.1050592E-04,   1.1063347E-04
     +,   1.1068789E-04,   1.1067612E-04,   1.1060558E-04
     +,   1.1048416E-04,   1.1032016E-04,   1.1012220E-04
     +,   1.0989911E-04,   1.0965992E-04,   1.0941384E-04
     +,   1.0916998E-04,   1.0893751E-04,   1.0872543E-04
     +,   1.0854258E-04,   1.0839746E-04,   1.0829842E-04
     +,   1.0825318E-04,   1.0826916E-04,   1.0835321E-04
     +,   1.0851169E-04,   1.0875031E-04,   1.0907419E-04
     +,   1.0948785E-04,   1.0999511E-04,   1.1059926E-04
     +,   1.1130288E-04,   1.1210801E-04,   1.1301627E-04
     +,   1.1402861E-04,   1.1514574E-04,   1.1636812E-04
     +,   1.1769586E-04,   1.1912920E-04,   1.2066825E-04
     +,   1.2231353E-04,   1.2406576E-04,   1.2592642E-04
     +,   1.2789745E-04,   1.2998190E-04,   1.3218381E-04
     +,   1.3450837E-04,   1.3696235E-04,   1.3955380E-04
     +,   1.4229279E-04,   1.4519080E-04,   1.4826156E-04
     +,   1.5152043E-04,   1.5498510E-04,   1.5867493E-04
     +,   1.6261164E-04,   1.6681886E-04,   1.7132217E-04
     +,   1.7614901E-04,   1.8132915E-04,   1.8689439E-04
     +,   1.9287800E-04,   1.9931603E-04,   2.0624603E-04
     +,   2.1370854E-04,   2.2174571E-04,   2.3040298E-04
     +,   2.3972765E-04,   2.4977035E-04,   2.6058321E-04
     +,   2.7222131E-04,   2.8474172E-04,   2.9820125E-04
     +,   3.1265660E-04,   3.2816344E-04,   3.4477405E-04
     +,   3.6253300E-04,   3.8147913E-04,   4.0163688E-04
     +,   4.2302054E-04,   4.4562464E-04,   4.6942884E-04
     +,   4.9439067E-04,   5.2045233E-04,   5.4753612E-04
     +,   5.7555543E-04,   6.0441892E-04,   6.3403737E-04
     +,   6.6433760E-04,   6.9527770E-04,   7.2685932E-04
     +,   7.5913785E-04,   7.9224235E-04,   8.2637765E-04
     +,   8.6183747E-04,   8.9900062E-04,   9.3833893E-04
     +,   9.8040572E-04,   1.0258436E-03,   1.0753651E-03
     +,   1.1297613E-03,   1.1898801E-03,   1.2565998E-03
     +,   1.3307974E-03,   1.4133060E-03,   1.5048519E-03
     +,   1.6060016E-03,   1.7171727E-03,   1.8386559E-03
     +,   1.9707638E-03,   2.1139965E-03,   2.2693062E-03
     +,   2.4382633E-03,   2.6232065E-03,   2.8271230E-03
     +,   3.0534049E-03,   3.3053139E-03,   3.5853027E-03
     +,   3.8943449E-03,   4.2314902E-03,   4.5938510E-03
     +,   4.9772812E-03,   5.3777928E-03,   5.7932455E-03
     +,   6.2245424E-03,   6.6754925E-03,   7.1510547E-03
     +,   7.6540695E-03,   8.1819613E-03,   8.7249670E-03
     +,   9.2669949E-03,   9.7887870E-03,   1.0272123E-02
     +,   1.0703874E-02,   1.1079266E-02,   1.1404947E-02
     +,   1.1700908E-02,   1.1998158E-02,   1.2327946E-02
     +,   1.2703054E-02,   1.3099355E-02,   1.3451047E-02
     +,   1.3667751E-02,   1.3668898E-02,   1.3417806E-02
     +,   1.2936486E-02,   1.2294038E-02,   1.1576864E-02
     +,   1.0856899E-02,   1.0172911E-02,   9.5299799E-03
     +,   8.9129675E-03,   8.3045876E-03,   7.6988526E-03
     +,   7.1050562E-03,   6.5428684E-03,   6.0329740E-03
     +,   5.5893240E-03,   5.2157883E-03,   4.9073971E-03
     +,   4.6540867E-03,   4.4446094E-03,   4.2690383E-03
     +,   4.1197017E-03,   3.9910218E-03,   3.8789380E-03
     +,   3.7803636E-03,   3.6927555E-03,   3.6138708E-03
     +,   3.5416102E-03,   3.4739277E-03,   3.4087452E-03
     +,   3.3439633E-03,   3.2775258E-03,   3.2075397E-03
     +,   3.1324320E-03,   3.0511029E-03,   2.9630468E-03
     +,   2.8683790E-03,   2.7678041E-03,   2.6625039E-03
     +,   2.5539887E-03,   2.4439241E-03,   2.3339617E-03
     +,   2.2256284E-03,   2.1202592E-03,   2.0189479E-03
     +,   1.9225565E-03,   1.8317529E-03,   1.7470216E-03
     +,   1.6686902E-03,   1.5969530E-03,   1.5318706E-03
     +,   1.4733738E-03,   1.4212526E-03,   1.3751566E-03
     +,   1.3346028E-03,   1.2989825E-03,   1.2675774E-03
     +,   1.2395862E-03,   1.2141621E-03,   1.1904404E-03
     +,   1.1675766E-03,   1.1447858E-03,   1.1213729E-03
     +,   1.0967546E-03,   1.0704829E-03,   1.0422554E-03
     +,   1.0119189E-03,   9.7945810E-04,   9.4498700E-04
     +,   9.0873393E-04,   8.7101624E-04,   8.3221385E-04
     +,   7.9274661E-04,   7.5305678E-04,   7.1357790E-04
     +,   6.7472307E-04,   6.3686946E-04,   6.0034945E-04
     +,   5.6543679E-04,   5.3234928E-04,   5.0124660E-04
     +,   4.7223238E-04,   4.4535485E-04,   4.2061345E-04
     +,   3.9796749E-04,   3.7733972E-04,   3.5862235E-04
     +,   3.4168447E-04,   3.2638109E-04,   3.1255442E-04
     +,   3.0004169E-04,   2.8868025E-04,   2.7831105E-04
     +,   2.6878115E-04,   2.5994721E-04,   2.5167852E-04
     +,   2.4385746E-04,   2.3637997E-04,   2.2915698E-04
     +,   2.2211419E-04,   2.1519160E-04,   2.0834226E-04
     +,   2.0153160E-04,   1.9473718E-04,   1.8794579E-04
     +,   1.8115278E-04,   1.7436137E-04,   1.6758067E-04
     +,   1.6082374E-04,   1.5410726E-04,   1.4745044E-04
     +,   1.4087386E-04,   1.3439794E-04,   1.2804293E-04
     +,   1.2182864E-04,   1.1577271E-04,   1.0989168E-04
     +,   1.0419933E-04,   9.8707897E-05,   9.3426570E-05
     +,   8.8362918E-05,   8.3521503E-05,   7.8905301E-05
     +,   7.4514704E-05,   7.0348709E-05,   6.6404180E-05
     +,   6.2676489E-05,   5.9160102E-05,   5.5847890E-05
     +,   5.2732266E-05,   4.9804541E-05,   4.7055928E-05
     +,   4.4476892E-05,   4.2058113E-05,   3.9789855E-05
     +,   3.7662790E-05,   3.5667490E-05,   3.3795062E-05
     +,   3.2036696E-05,   3.0384221E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt90 = Yx/0.136833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5396463E-05,   8.0703394E-05
     +,   8.6226537E-05,   9.1955131E-05,   9.7876167E-05
     +,   1.0397435E-04,   1.1023210E-04,   1.1662965E-04
     +,   1.2314499E-04,   1.2975447E-04,   1.3643219E-04
     +,   1.4315070E-04,   1.4988126E-04,   1.5659384E-04
     +,   1.6325746E-04,   1.6984067E-04,   1.7631170E-04
     +,   1.8263895E-04,   1.8879103E-04,   1.9473757E-04
     +,   2.0044920E-04,   2.0589806E-04,   2.1105808E-04
     +,   2.1590556E-04,   2.2041851E-04,   2.2457851E-04
     +,   2.2836938E-04,   2.3177815E-04,   2.3479493E-04
     +,   2.3741323E-04,   2.3963000E-04,   2.4144494E-04
     +,   2.4286158E-04,   2.4388623E-04,   2.4452840E-04
     +,   2.4480026E-04,   2.4471665E-04,   2.4429482E-04
     +,   2.4355399E-04,   2.4251539E-04,   2.4120144E-04
     +,   2.3963604E-04,   2.3784381E-04,   2.3585004E-04
     +,   2.3368023E-04,   2.3135995E-04,   2.2891461E-04
     +,   2.2636885E-04,   2.2374697E-04,   2.2107206E-04
     +,   2.1836649E-04,   2.1565132E-04,   2.1294637E-04
     +,   2.1027027E-04,   2.0764027E-04,   2.0507223E-04
     +,   2.0258082E-04,   2.0017938E-04,   1.9788009E-04
     +,   1.9569382E-04,   1.9363058E-04,   1.9169920E-04
     +,   1.8990789E-04,   1.8826377E-04,   1.8677331E-04
     +,   1.8544246E-04,   1.8427645E-04,   1.8328012E-04
     +,   1.8245788E-04,   1.8181370E-04,   1.8135116E-04
     +,   1.8107372E-04,   1.8098438E-04,   1.8108610E-04
     +,   1.8138155E-04,   1.8187314E-04,   1.8256331E-04
     +,   1.8345442E-04,   1.8454873E-04,   1.8584866E-04
     +,   1.8735674E-04,   1.8907567E-04,   1.9100854E-04
     +,   1.9315910E-04,   1.9553136E-04,   1.9813041E-04
     +,   2.0096191E-04,   2.0403291E-04,   2.0735113E-04
     +,   2.1092583E-04,   2.1476782E-04,   2.1888860E-04
     +,   2.2330122E-04,   2.2801996E-04,   2.3306042E-04
     +,   2.3843847E-04,   2.4417107E-04,   2.5027449E-04
     +,   2.5676528E-04,   2.6365841E-04,   2.7096798E-04
     +,   2.7870445E-04,   2.8687657E-04,   2.9548773E-04
     +,   3.0453739E-04,   3.1401953E-04,   3.2392109E-04
     +,   3.3422219E-04,   3.4489585E-04,   3.5590734E-04
     +,   3.6721287E-04,   3.7876240E-04,   3.9049640E-04
     +,   4.0234992E-04,   4.1425027E-04,   4.2612167E-04
     +,   4.3788261E-04,   4.4945173E-04,   4.6074597E-04
     +,   4.7168569E-04,   4.8219535E-04,   4.9220567E-04
     +,   5.0165592E-04,   5.1049766E-04,   5.1869458E-04
     +,   5.2622554E-04,   5.3308619E-04,   5.3928903E-04
     +,   5.4486527E-04,   5.4986431E-04,   5.5435457E-04
     +,   5.5842136E-04,   5.6216837E-04,   5.6571327E-04
     +,   5.6918949E-04,   5.7274196E-04,   5.7652616E-04
     +,   5.8070570E-04,   5.8545114E-04,   5.9093733E-04
     +,   5.9734174E-04,   6.0484215E-04,   6.1361602E-04
     +,   6.2384014E-04,   6.3568540E-04,   6.4932171E-04
     +,   6.6491443E-04,   6.8262388E-04,   7.0260634E-04
     +,   7.2501699E-04,   7.5000752E-04,   7.7772624E-04
     +,   8.0831704E-04,   8.4191957E-04,   8.7866443E-04
     +,   9.1866276E-04,   9.6200110E-04,   1.0087311E-03
     +,   1.0588584E-03,   1.1123227E-03,   1.1689970E-03
     +,   1.2286763E-03,   1.2910713E-03,   1.3558199E-03
     +,   1.4225179E-03,   1.4907609E-03,   1.5602174E-03
     +,   1.6307407E-03,   1.7025229E-03,   1.7762567E-03
     +,   1.8533113E-03,   1.9358931E-03,   2.0271619E-03
     +,   2.1312525E-03,   2.2532155E-03,   2.3988746E-03
     +,   2.5745491E-03,   2.7866384E-03,   3.0410707E-03
     +,   3.3426874E-03,   3.6946912E-03,   4.0984289E-03
     +,   4.5538540E-03,   5.0605834E-03,   5.6189569E-03
     +,   6.2303087E-03,   6.8958714E-03,   7.6146899E-03
     +,   8.3821528E-03,   9.1912467E-03,   1.0037713E-02
     +,   1.0925925E-02,   1.1869752E-02,   1.2883483E-02
     +,   1.3963621E-02,   1.5073472E-02,   1.6146233E-02
     +,   1.7113429E-02,   1.7942974E-02,   1.8656386E-02
     +,   1.9304568E-02,   1.9912573E-02,   2.0432325E-02
     +,   2.0741230E-02,   2.0694030E-02,   2.0198865E-02
     +,   1.9271635E-02,   1.8036211E-02,   1.6671700E-02
     +,   1.5338693E-02,   1.4127321E-02,   1.3050151E-02
     +,   1.2072219E-02,   1.1151291E-02,   1.0263259E-02
     +,   9.4054788E-03,   8.5864076E-03,   7.8146420E-03
     +,   7.0944214E-03,   6.4266571E-03,   5.8111502E-03
     +,   5.2474053E-03,   4.7339480E-03,   4.2674737E-03
     +,   3.8430197E-03,   3.4551774E-03,   3.0994068E-03
     +,   2.7727748E-03,   2.4739490E-03,   2.2026750E-03
     +,   1.9590496E-03,   1.7428517E-03,   1.5531550E-03
     +,   1.3882506E-03,   1.2457806E-03,   1.1229547E-03
     +,   1.0168405E-03,   9.2461490E-04,   8.4372418E-04
     +,   7.7198207E-04,   7.0761115E-04,   6.4923259E-04
     +,   5.9581967E-04,   5.4663577E-04,   5.0117628E-04
     +,   4.5910809E-04,   4.2021138E-04,   3.8433375E-04
     +,   3.5135655E-04,   3.2117346E-04,   2.9366851E-04
     +,   2.6871060E-04,   2.4615324E-04,   2.2583333E-04
     +,   2.0757419E-04,   1.9119245E-04,   1.7650398E-04
     +,   1.6332789E-04,   1.5149004E-04,   1.4082767E-04
     +,   1.3119205E-04,   1.2244949E-04,   1.1448102E-04
     +,   1.0718337E-04,   1.0046858E-04,   9.4261755E-05
     +,   8.8500266E-05,   8.3132720E-05,   7.8117031E-05
     +,   7.3418531E-05,   6.9009009E-05,   6.4865744E-05
     +,   6.0970040E-05,   5.7306075E-05,   5.3860404E-05
     +,   5.0621700E-05,   4.7579400E-05,   4.4724278E-05
     +,   4.2047308E-05,   3.9540264E-05,   3.7194884E-05
     +,   3.5003432E-05,   3.2958062E-05,   3.1051364E-05
     +,   2.9275838E-05,   2.7624401E-05,   2.6089965E-05
     +,   2.4665678E-05,   2.3345048E-05,   2.2121631E-05
     +,   2.0989388E-05,   1.9942387E-05,   1.8975074E-05
     +,   1.8082037E-05,   1.7258224E-05,   1.6498730E-05
     +,   1.5798985E-05,   1.5154566E-05,   1.4561369E-05
     +,   1.4015433E-05,   1.3513090E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_hatt95 = Yx/0.151720930232558
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6114963E-05,   2.6741507E-05
     +,   2.7381790E-05,   2.8036417E-05,   2.8706008E-05
     +,   2.9391213E-05,   3.0092689E-05,   3.0811116E-05
     +,   3.1547163E-05,   3.2301534E-05,   3.3074914E-05
     +,   3.3867982E-05,   3.4681416E-05,   3.5515852E-05
     +,   3.6371919E-05,   3.7250215E-05,   3.8151284E-05
     +,   3.9075640E-05,   4.0023730E-05,   4.0995943E-05
     +,   4.1992607E-05,   4.3013966E-05,   4.4060151E-05
     +,   4.5131303E-05,   4.6227320E-05,   4.7348138E-05
     +,   4.8493494E-05,   4.9663071E-05,   5.0856379E-05
     +,   5.2072875E-05,   5.3311851E-05,   5.4572498E-05
     +,   5.5853878E-05,   5.7154946E-05,   5.8474532E-05
     +,   5.9811369E-05,   6.1164035E-05,   6.2531064E-05
     +,   6.3910906E-05,   6.5301814E-05,   6.6702123E-05
     +,   6.8110014E-05,   6.9523587E-05,   7.0940994E-05
     +,   7.2360264E-05,   7.3779513E-05,   7.5196804E-05
     +,   7.6610260E-05,   7.8018013E-05,   7.9418314E-05
     +,   8.0809412E-05,   8.2189777E-05,   8.3557876E-05
     +,   8.4912434E-05,   8.6252287E-05,   8.7576453E-05
     +,   8.8884197E-05,   9.0174995E-05,   9.1448543E-05
     +,   9.2704860E-05,   9.3944211E-05,   9.5167212E-05
     +,   9.6374686E-05,   9.7567943E-05,   9.8748591E-05
     +,   9.9918485E-05,   1.0108001E-04,   1.0223579E-04
     +,   1.0338886E-04,   1.0454260E-04,   1.0570085E-04
     +,   1.0686757E-04,   1.0804732E-04,   1.0924469E-04
     +,   1.1046475E-04,   1.1171279E-04,   1.1299417E-04
     +,   1.1431451E-04,   1.1567950E-04,   1.1709500E-04
     +,   1.1856660E-04,   1.2010009E-04,   1.2170084E-04
     +,   1.2337424E-04,   1.2512514E-04,   1.2695823E-04
     +,   1.2887738E-04,   1.3088630E-04,   1.3298762E-04
     +,   1.3518374E-04,   1.3747592E-04,   1.3986463E-04
     +,   1.4234940E-04,   1.4492900E-04,   1.4760118E-04
     +,   1.5036257E-04,   1.5320913E-04,   1.5613550E-04
     +,   1.5913602E-04,   1.6220378E-04,   1.6533164E-04
     +,   1.6851160E-04,   1.7173574E-04,   1.7499566E-04
     +,   1.7828330E-04,   1.8159107E-04,   1.8491177E-04
     +,   1.8823922E-04,   1.9156857E-04,   1.9489654E-04
     +,   1.9822145E-04,   2.0154411E-04,   2.0486725E-04
     +,   2.0819680E-04,   2.1154106E-04,   2.1491160E-04
     +,   2.1832279E-04,   2.2179223E-04,   2.2534016E-04
     +,   2.2898988E-04,   2.3276715E-04,   2.3669962E-04
     +,   2.4081660E-04,   2.4514849E-04,   2.4972635E-04
     +,   2.5458034E-04,   2.5974010E-04,   2.6523299E-04
     +,   2.7108437E-04,   2.7731521E-04,   2.8394378E-04
     +,   2.9098266E-04,   2.9844037E-04,   3.0631985E-04
     +,   3.1461925E-04,   3.2333223E-04,   3.3244758E-04
     +,   3.4195045E-04,   3.5182395E-04,   3.6205002E-04
     +,   3.7260968E-04,   3.8348511E-04,   3.9466209E-04
     +,   4.0612990E-04,   4.1788199E-04,   4.2991884E-04
     +,   4.4224621E-04,   4.5487529E-04,   4.6782222E-04
     +,   4.8110692E-04,   4.9475062E-04,   5.0877297E-04
     +,   5.2318833E-04,   5.3800462E-04,   5.5321999E-04
     +,   5.6881923E-04,   5.8477459E-04,   6.0104788E-04
     +,   6.1759545E-04,   6.3437142E-04,   6.5134483E-04
     +,   6.6850957E-04,   6.8590126E-04,   7.0361741E-04
     +,   7.2183606E-04,   7.4082986E-04,   7.6097698E-04
     +,   7.8276912E-04,   8.0680713E-04,   8.3379832E-04
     +,   8.6454587E-04,   8.9994655E-04,   9.4100187E-04
     +,   9.8884886E-04,   1.0448061E-03,   1.1104670E-03
     +,   1.1877959E-03,   1.2792288E-03,   1.3877525E-03
     +,   1.5169177E-03,   1.6707166E-03,   1.8532736E-03
     +,   2.0683447E-03,   2.3186558E-03,   2.6051207E-03
     +,   2.9261773E-03,   3.2775148E-03,   3.6524073E-03
     +,   4.0426529E-03,   4.4399370E-03,   4.8373048E-03
     +,   5.2300659E-03,   5.6162314E-03,   5.9972042E-03
     +,   6.3795284E-03,   6.7775710E-03,   7.2150249E-03
     +,   7.7213068E-03,   8.3204750E-03,   9.0156319E-03
     +,   9.7783003E-03,   1.0553706E-02,   1.1284120E-02
     +,   1.1938520E-02,   1.2528850E-02,   1.3100781E-02
     +,   1.3706006E-02,   1.4378224E-02,   1.5128807E-02
     +,   1.5955215E-02,   1.6843056E-02,   1.7754203E-02
     +,   1.8617734E-02,   1.9343065E-02,   1.9855842E-02
     +,   2.0137286E-02,   2.0243336E-02,   2.0285469E-02
     +,   2.0370224E-02,   2.0521758E-02,   2.0637739E-02
     +,   2.0523053E-02,   1.9996371E-02,   1.9005148E-02
     +,   1.7662292E-02,   1.6174112E-02,   1.4719446E-02
     +,   1.3376729E-02,   1.2141276E-02,   1.0992174E-02
     +,   9.9389218E-03,   9.0173967E-03,   8.2552973E-03
     +,   7.6456149E-03,   7.1474900E-03,   6.7072101E-03
     +,   6.2808348E-03,   5.8450643E-03,   5.3955182E-03
     +,   4.9388958E-03,   4.4856253E-03,   4.0455689E-03
     +,   3.6265105E-03,   3.2339727E-03,   2.8714803E-03
     +,   2.5407977E-03,   2.2421160E-03,   1.9743580E-03
     +,   1.7356018E-03,   1.5235106E-03,   1.3356201E-03
     +,   1.1695742E-03,   1.0232206E-03,   8.9460233E-04
     +,   7.8191323E-04,   6.8347005E-04,   5.9769262E-04
     +,   5.2308931E-04,   4.5826257E-04,   4.0193123E-04
     +,   3.5294617E-04,   3.1029494E-04,   2.7309873E-04
     +,   2.4060927E-04,   2.1219847E-04,   1.8733610E-04
     +,   1.6557596E-04,   1.4654142E-04,   1.2990899E-04
     +,   1.1539632E-04,   1.0275443E-04,   9.1762253E-05
     +,   8.2220839E-05,   7.3950359E-05,   6.6788860E-05
     +,   6.0591548E-05,   5.5228287E-05,   5.0584295E-05
     +,   4.6557860E-05,   4.3060478E-05,   4.0014816E-05
     +,   3.7354439E-05,   3.5021916E-05,   3.2968404E-05
     +,   3.1151994E-05,   2.9537261E-05,   2.8093978E-05
     +,   2.6796524E-05,   2.5623307E-05,   2.4555875E-05
     +,   2.3578757E-05,   2.2678701E-05,   2.1844611E-05
     +,   2.1066977E-05,   2.0337859E-05,   1.9650455E-05
     +,   1.8999101E-05,   1.8378965E-05,   1.7786060E-05
     +,   1.7216984E-05,   1.6668975E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt100 = Yx/0.173090909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4778225E-05,   2.5180738E-05
     +,   2.5580675E-05,   2.5977819E-05,   2.6371972E-05
     +,   2.6762955E-05,   2.7150603E-05,   2.7534783E-05
     +,   2.7915377E-05,   2.8292310E-05,   2.8665530E-05
     +,   2.9035011E-05,   2.9400762E-05,   2.9762836E-05
     +,   3.0121315E-05,   3.0476340E-05,   3.0828069E-05
     +,   3.1176729E-05,   3.1522570E-05,   3.1865919E-05
     +,   3.2207128E-05,   3.2546628E-05,   3.2884884E-05
     +,   3.3222423E-05,   3.3559820E-05,   3.3897737E-05
     +,   3.4236869E-05,   3.4577977E-05,   3.4921901E-05
     +,   3.5269510E-05,   3.5621768E-05,   3.5979683E-05
     +,   3.6344340E-05,   3.6716883E-05,   3.7098507E-05
     +,   3.7490496E-05,   3.7894195E-05,   3.8310984E-05
     +,   3.8742379E-05,   3.9189898E-05,   3.9655166E-05
     +,   4.0139876E-05,   4.0645824E-05,   4.1174866E-05
     +,   4.1728970E-05,   4.2310203E-05,   4.2920754E-05
     +,   4.3562930E-05,   4.4239176E-05,   4.4952121E-05
     +,   4.5704539E-05,   4.6499441E-05,   4.7340018E-05
     +,   4.8229784E-05,   4.9172442E-05,   5.0172119E-05
     +,   5.1233201E-05,   5.2360498E-05,   5.3559201E-05
     +,   5.4835004E-05,   5.6194058E-05,   5.7643050E-05
     +,   5.9189115E-05,   6.0840095E-05,   6.2604398E-05
     +,   6.4490843E-05,   6.6509114E-05,   6.8669171E-05
     +,   7.0981754E-05,   7.3457879E-05,   7.6109194E-05
     +,   7.8947400E-05,   8.1984756E-05,   8.5233245E-05
     +,   8.8705005E-05,   9.2411974E-05,   9.6365417E-05
     +,   1.0057580E-04,   1.0505299E-04,   1.0980554E-04
     +,   1.1484015E-04,   1.2016224E-04,   1.2577444E-04
     +,   1.3167775E-04,   1.3786963E-04,   1.4434532E-04
     +,   1.5109597E-04,   1.5811001E-04,   1.6537144E-04
     +,   1.7286089E-04,   1.8055522E-04,   1.8842673E-04
     +,   1.9644373E-04,   2.0457126E-04,   2.1277062E-04
     +,   2.2099909E-04,   2.2921177E-04,   2.3736009E-04
     +,   2.4539448E-04,   2.5326258E-04,   2.6091220E-04
     +,   2.6828988E-04,   2.7534334E-04,   2.8202066E-04
     +,   2.8827263E-04,   2.9405230E-04,   2.9931602E-04
     +,   3.0402403E-04,   3.0814178E-04,   3.1163997E-04
     +,   3.1449465E-04,   3.1668859E-04,   3.1821086E-04
     +,   3.1905781E-04,   3.1923223E-04,   3.1874413E-04
     +,   3.1761051E-04,   3.1585500E-04,   3.1350780E-04
     +,   3.1060496E-04,   3.0718834E-04,   3.0330475E-04
     +,   2.9900609E-04,   2.9434756E-04,   2.8938771E-04
     +,   2.8418837E-04,   2.7881248E-04,   2.7332542E-04
     +,   2.6779188E-04,   2.6227839E-04,   2.5684951E-04
     +,   2.5156999E-04,   2.4650246E-04,   2.4170814E-04
     +,   2.3724591E-04,   2.3317170E-04,   2.2953912E-04
     +,   2.2639833E-04,   2.2379584E-04,   2.2177456E-04
     +,   2.2037348E-04,   2.1962739E-04,   2.1956660E-04
     +,   2.2021678E-04,   2.2159872E-04,   2.2372832E-04
     +,   2.2661618E-04,   2.3026782E-04,   2.3468300E-04
     +,   2.3985669E-04,   2.4577879E-04,   2.5243423E-04
     +,   2.5980361E-04,   2.6786444E-04,   2.7659221E-04
     +,   2.8596053E-04,   2.9594378E-04,   3.0651956E-04
     +,   3.1767087E-04,   3.2938737E-04,   3.4167111E-04
     +,   3.5453818E-04,   3.6802187E-04,   3.8217637E-04
     +,   3.9708079E-04,   4.1284048E-04,   4.2958793E-04
     +,   4.4748257E-04,   4.6671208E-04,   4.8748683E-04
     +,   5.1003334E-04,   5.3458748E-04,   5.6138635E-04
     +,   5.9065560E-04,   6.2259310E-04,   6.5736100E-04
     +,   6.9506862E-04,   7.3575816E-04,   7.7939645E-04
     +,   8.2586921E-04,   8.7497779E-04,   9.2643575E-04
     +,   9.7988080E-04,   1.0348998E-03,   1.0910493E-03
     +,   1.1478938E-03,   1.2050660E-03,   1.2623458E-03
     +,   1.3197461E-03,   1.3776250E-03,   1.4368218E-03
     +,   1.4987845E-03,   1.5656969E-03,   1.6405703E-03
     +,   1.7272920E-03,   1.8305570E-03,   1.9556643E-03
     +,   2.1081420E-03,   2.2931634E-03,   2.5147456E-03
     +,   2.7747771E-03,   3.0720960E-03,   3.4018466E-03
     +,   3.7554086E-03,   4.1211504E-03,   4.4863010E-03
     +,   4.8394208E-03,   5.1731118E-03,   5.4863002E-03
     +,   5.7855039E-03,   6.0848650E-03,   6.4048083E-03
     +,   6.7692236E-03,   7.2006579E-03,   7.7133100E-03
     +,   8.3054602E-03,   8.9553362E-03,   9.6262451E-03
     +,   1.0284545E-02,   1.0926830E-02,   1.1601144E-02
     +,   1.2400234E-02,   1.3417711E-02,   1.4688915E-02
     +,   1.6163224E-02,   1.7736515E-02,   1.9321801E-02
     +,   2.0897117E-02,   2.2483647E-02,   2.4063434E-02
     +,   2.5510486E-02,   2.6622966E-02,   2.7256247E-02
     +,   2.7431687E-02,   2.7308613E-02,   2.7052475E-02
     +,   2.6721679E-02,   2.6250919E-02,   2.5524558E-02
     +,   2.4474215E-02,   2.3116356E-02,   2.1506542E-02
     +,   1.9682635E-02,   1.7671436E-02,   1.5535850E-02
     +,   1.3388925E-02,   1.1355432E-02,   9.5261205E-03
     +,   7.9430165E-03,   6.6106115E-03,   5.5109770E-03
     +,   4.6136263E-03,   3.8817970E-03,   3.2784482E-03
     +,   2.7718039E-03,   2.3386511E-03,   1.9645556E-03
     +,   1.6417439E-03,   1.3661686E-03,   1.1349639E-03
     +,   9.4486744E-04,   7.9163047E-04,   6.7016814E-04
     +,   5.7506707E-04,   5.0110708E-04,   4.4362000E-04
     +,   3.9868613E-04,   3.6316254E-04,   3.3460488E-04
     +,   3.1114920E-04,   2.9139422E-04,   2.7429682E-04
     +,   2.5908786E-04,   2.4520871E-04,   2.3226485E-04
     +,   2.1998932E-04,   2.0820946E-04,   1.9682509E-04
     +,   1.8578475E-04,   1.7507249E-04,   1.6469197E-04
     +,   1.5465985E-04,   1.4499635E-04,   1.3572330E-04
     +,   1.2685894E-04,   1.1841848E-04,   1.1041149E-04
     +,   1.0284262E-04,   9.5712450E-05,   8.9016205E-05
     +,   8.2746177E-05,   7.6890508E-05,   7.1435410E-05
     +,   6.6364206E-05,   6.1659215E-05,   5.7301011E-05
     +,   5.3269952E-05,   4.9545491E-05,   4.6107562E-05
     +,   4.2935808E-05,   4.0010793E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt105 = Yx/0.189477272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7840731E-05,   4.9291360E-05
     +,   5.0746698E-05,   5.2204188E-05,   5.3661191E-05
     +,   5.5115030E-05,   5.6562949E-05,   5.8002217E-05
     +,   5.9429989E-05,   6.0843551E-05,   6.2240069E-05
     +,   6.3616797E-05,   6.4971020E-05,   6.6300119E-05
     +,   6.7601475E-05,   6.8872614E-05,   7.0111142E-05
     +,   7.1314840E-05,   7.2481555E-05,   7.3609379E-05
     +,   7.4696480E-05,   7.5741285E-05,   7.6742370E-05
     +,   7.7698605E-05,   7.8608988E-05,   7.9472855E-05
     +,   8.0289698E-05,   8.1059363E-05,   8.1781895E-05
     +,   8.2457671E-05,   8.3087303E-05,   8.3671774E-05
     +,   8.4212261E-05,   8.4710344E-05,   8.5167871E-05
     +,   8.5586951E-05,   8.5970125E-05,   8.6320091E-05
     +,   8.6639971E-05,   8.6933149E-05,   8.7203283E-05
     +,   8.7454384E-05,   8.7690707E-05,   8.7916800E-05
     +,   8.8137473E-05,   8.8357825E-05,   8.8583154E-05
     +,   8.8819033E-05,   8.9071233E-05,   8.9345747E-05
     +,   8.9648733E-05,   8.9986490E-05,   9.0365524E-05
     +,   9.0792397E-05,   9.1273781E-05,   9.1816415E-05
     +,   9.2427072E-05,   9.3112547E-05,   9.3879571E-05
     +,   9.4734867E-05,   9.5685005E-05,   9.6736534E-05
     +,   9.7895703E-05,   9.9168639E-05,   1.0056129E-04
     +,   1.0207918E-04,   1.0372773E-04,   1.0551178E-04
     +,   1.0743610E-04,   1.0950472E-04,   1.1172151E-04
     +,   1.1408967E-04,   1.1661217E-04,   1.1929114E-04
     +,   1.2212843E-04,   1.2512546E-04,   1.2828279E-04
     +,   1.3160043E-04,   1.3507815E-04,   1.3871503E-04
     +,   1.4250937E-04,   1.4645937E-04,   1.5056213E-04
     +,   1.5481490E-04,   1.5921376E-04,   1.6375499E-04
     +,   1.6843369E-04,   1.7324528E-04,   1.7818407E-04
     +,   1.8324448E-04,   1.8842045E-04,   1.9370548E-04
     +,   1.9909246E-04,   2.0457458E-04,   2.1014454E-04
     +,   2.1579416E-04,   2.2151598E-04,   2.2730122E-04
     +,   2.3314187E-04,   2.3902864E-04,   2.4495294E-04
     +,   2.5090511E-04,   2.5687611E-04,   2.6285596E-04
     +,   2.6883485E-04,   2.7480314E-04,   2.8075054E-04
     +,   2.8666679E-04,   2.9254195E-04,   2.9836624E-04
     +,   3.0412932E-04,   3.0982212E-04,   3.1543482E-04
     +,   3.2095920E-04,   3.2638651E-04,   3.3170925E-04
     +,   3.3692041E-04,   3.4201427E-04,   3.4698527E-04
     +,   3.5182963E-04,   3.5654459E-04,   3.6112816E-04
     +,   3.6557997E-04,   3.6990069E-04,   3.7409269E-04
     +,   3.7815899E-04,   3.8210460E-04,   3.8593504E-04
     +,   3.8965777E-04,   3.9328088E-04,   3.9681391E-04
     +,   4.0026716E-04,   4.0365217E-04,   4.0698133E-04
     +,   4.1026823E-04,   4.1352713E-04,   4.1677424E-04
     +,   4.2002575E-04,   4.2329982E-04,   4.2661629E-04
     +,   4.2999661E-04,   4.3346343E-04,   4.3704326E-04
     +,   4.4076386E-04,   4.4465647E-04,   4.4875525E-04
     +,   4.5309865E-04,   4.5772764E-04,   4.6268752E-04
     +,   4.6802746E-04,   4.7380049E-04,   4.8006250E-04
     +,   4.8687198E-04,   4.9428968E-04,   5.0237752E-04
     +,   5.1119621E-04,   5.2080414E-04,   5.3125637E-04
     +,   5.4260122E-04,   5.5487728E-04,   5.6811218E-04
     +,   5.8231945E-04,   5.9749477E-04,   6.1361317E-04
     +,   6.3062867E-04,   6.4847094E-04,   6.6704373E-04
     +,   6.8622513E-04,   7.0587086E-04,   7.2581571E-04
     +,   7.4587704E-04,   7.6586503E-04,   7.8559114E-04
     +,   8.0488110E-04,   8.2358654E-04,   8.4160565E-04
     +,   8.5890066E-04,   8.7551144E-04,   8.9157978E-04
     +,   9.0736244E-04,   9.2324364E-04,   9.3974342E-04
     +,   9.5751946E-04,   9.7736344E-04,   1.0001896E-03
     +,   1.0270135E-03,   1.0589330E-03,   1.0970964E-03
     +,   1.1426745E-03,   1.1968220E-03,   1.2606467E-03
     +,   1.3351730E-03,   1.4212891E-03,   1.5197046E-03
     +,   1.6308898E-03,   1.7550105E-03,   1.8918316E-03
     +,   2.0406567E-03,   2.2002750E-03,   2.3689477E-03
     +,   2.5444578E-03,   2.7242808E-03,   2.9058803E-03
     +,   3.0870759E-03,   3.2664621E-03,   3.4438155E-03
     +,   3.6202741E-03,   3.7982189E-03,   3.9808704E-03
     +,   4.1716383E-03,   4.3735066E-03,   4.5888247E-03
     +,   4.8197214E-03,   5.0691562E-03,   5.3420877E-03
     +,   5.6461953E-03,   5.9915525E-03,   6.3892268E-03
     +,   6.8493346E-03,   7.3792012E-03,   7.9819318E-03
     +,   8.6547295E-03,   9.3868561E-03,   1.0159122E-02
     +,   1.0948237E-02,   1.1737440E-02,   1.2529836E-02
     +,   1.3354610E-02,   1.4256793E-02,   1.5272661E-02
     +,   1.6408136E-02,   1.7642653E-02,   1.8959962E-02
     +,   2.0374496E-02,   2.1913884E-02,   2.3555879E-02
     +,   2.5178742E-02,   2.6593104E-02,   2.7655110E-02
     +,   2.8364440E-02,   2.8839070E-02,   2.9166942E-02
     +,   2.9270560E-02,   2.8925080E-02,   2.7926514E-02
     +,   2.6255451E-02,   2.4094310E-02,   2.1705626E-02
     +,   1.9296603E-02,   1.6968088E-02,   1.4745915E-02
     +,   1.2636992E-02,   1.0662558E-02,   8.8590421E-03
     +,   7.2618672E-03,   5.8905454E-03,   4.7443151E-03
     +,   3.8067268E-03,   3.0531790E-03,   2.4564927E-03
     +,   1.9895721E-03,   1.6266211E-03,   1.3442939E-03
     +,   1.1228342E-03,   9.4669097E-04,   8.0434850E-04
     +,   6.8767084E-04,   5.9099955E-04,   5.1031914E-04
     +,   4.4264391E-04,   3.8564511E-04,   3.3744177E-04
     +,   2.9648971E-04,   2.6152324E-04,   2.3152035E-04
     +,   2.0566856E-04,   1.8332084E-04,   1.6396430E-04
     +,   1.4718002E-04,   1.3261946E-04,   1.1997966E-04
     +,   1.0899349E-04,   9.9419398E-05,   9.1041213E-05
     +,   8.3665102E-05,   7.7122233E-05,   7.1267175E-05
     +,   6.5978238E-05,   6.1156599E-05,   5.6723140E-05
     +,   5.2617161E-05,   4.8792361E-05,   4.5215213E-05
     +,   4.1861178E-05,   3.8713351E-05,   3.5759509E-05
     +,   3.2991262E-05,   3.0401978E-05,   2.7986498E-05
     +,   2.5739759E-05,   2.3656910E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt107 = Yx/0.198177777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9666584E-05,   3.0337582E-05
     +,   3.1015050E-05,   3.1698830E-05,   3.2388751E-05
     +,   3.3084638E-05,   3.3786317E-05,   3.4493605E-05
     +,   3.5206314E-05,   3.5924262E-05,   3.6647260E-05
     +,   3.7375092E-05,   3.8107566E-05,   3.8844471E-05
     +,   3.9585608E-05,   4.0330768E-05,   4.1079737E-05
     +,   4.1832307E-05,   4.2588294E-05,   4.3347471E-05
     +,   4.4109664E-05,   4.4874694E-05,   4.5642359E-05
     +,   4.6412551E-05,   4.7185076E-05,   4.7959846E-05
     +,   4.8736765E-05,   4.9515766E-05,   5.0296811E-05
     +,   5.1079922E-05,   5.1865136E-05,   5.2652569E-05
     +,   5.3442382E-05,   5.4234824E-05,   5.5030181E-05
     +,   5.5828852E-05,   5.6631328E-05,   5.7438177E-05
     +,   5.8250138E-05,   5.9067996E-05,   5.9892751E-05
     +,   6.0725506E-05,   6.1567531E-05,   6.2420302E-05
     +,   6.3285457E-05,   6.4164837E-05,   6.5060543E-05
     +,   6.5974862E-05,   6.6910347E-05,   6.7869827E-05
     +,   6.8856381E-05,   6.9873407E-05,   7.0924500E-05
     +,   7.2013740E-05,   7.3145304E-05,   7.4323842E-05
     +,   7.5554206E-05,   7.6841628E-05,   7.8191573E-05
     +,   7.9609825E-05,   8.1102386E-05,   8.2675579E-05
     +,   8.4335734E-05,   8.6089552E-05,   8.7943787E-05
     +,   8.9905123E-05,   9.1980415E-05,   9.4176248E-05
     +,   9.6499280E-05,   9.8955607E-05,   1.0155133E-04
     +,   1.0429178E-04,   1.0718200E-04,   1.1022611E-04
     +,   1.1342765E-04,   1.1678934E-04,   1.2031257E-04
     +,   1.2399767E-04,   1.2784397E-04,   1.3184933E-04
     +,   1.3600988E-04,   1.4032071E-04,   1.4477478E-04
     +,   1.4936390E-04,   1.5407761E-04,   1.5890424E-04
     +,   1.6382989E-04,   1.6883962E-04,   1.7391607E-04
     +,   1.7904087E-04,   1.8419420E-04,   1.8935466E-04
     +,   1.9449959E-04,   1.9960583E-04,   2.0464933E-04
     +,   2.0960516E-04,   2.1444888E-04,   2.1915536E-04
     +,   2.2370036E-04,   2.2806013E-04,   2.3221191E-04
     +,   2.3613412E-04,   2.3980724E-04,   2.4321307E-04
     +,   2.4633639E-04,   2.4916409E-04,   2.5168591E-04
     +,   2.5389469E-04,   2.5578684E-04,   2.5736209E-04
     +,   2.5862356E-04,   2.5957866E-04,   2.6023833E-04
     +,   2.6061738E-04,   2.6073487E-04,   2.6061319E-04
     +,   2.6027908E-04,   2.5976246E-04,   2.5909708E-04
     +,   2.5831969E-04,   2.5747024E-04,   2.5659121E-04
     +,   2.5572773E-04,   2.5492677E-04,   2.5423689E-04
     +,   2.5370799E-04,   2.5339075E-04,   2.5333604E-04
     +,   2.5359477E-04,   2.5421687E-04,   2.5525151E-04
     +,   2.5674616E-04,   2.5874653E-04,   2.6129585E-04
     +,   2.6443505E-04,   2.6820222E-04,   2.7263263E-04
     +,   2.7775895E-04,   2.8361104E-04,   2.9021740E-04
     +,   2.9760369E-04,   3.0579505E-04,   3.1481640E-04
     +,   3.2469386E-04,   3.3545328E-04,   3.4712433E-04
     +,   3.5973985E-04,   3.7333547E-04,   3.8795065E-04
     +,   4.0362965E-04,   4.2042008E-04,   4.3837063E-04
     +,   4.5752907E-04,   4.7794235E-04,   4.9965124E-04
     +,   5.2268489E-04,   5.4705667E-04,   5.7276170E-04
     +,   5.9977005E-04,   6.2801753E-04,   6.5740745E-04
     +,   6.8780419E-04,   7.1902812E-04,   7.5085839E-04
     +,   7.8303530E-04,   8.1526395E-04,   8.4721955E-04
     +,   8.7856239E-04,   9.0895128E-04,   9.3806215E-04
     +,   9.6560502E-04,   9.9134957E-04,   1.0151488E-03
     +,   1.0369631E-03,   1.0568757E-03,   1.0751180E-03
     +,   1.0920812E-03,   1.1083221E-03,   1.1245712E-03
     +,   1.1417302E-03,   1.1608704E-03,   1.1832285E-03
     +,   1.2101964E-03,   1.2433192E-03,   1.2842725E-03
     +,   1.3348307E-03,   1.3968064E-03,   1.4719600E-03
     +,   1.5618562E-03,   1.6676723E-03,   1.7899907E-03
     +,   1.9285898E-03,   2.0822403E-03,   2.2486455E-03
     +,   2.4245316E-03,   2.6059118E-03,   2.7885647E-03
     +,   2.9687246E-03,   3.1438400E-03,   3.3132823E-03
     +,   3.4788221E-03,   3.6447658E-03,   3.8176421E-03
     +,   4.0054875E-03,   4.2168461E-03,   4.4599166E-03
     +,   4.7417437E-03,   5.0676893E-03,   5.4407632E-03
     +,   5.8606761E-03,   6.3224905E-03,   6.8155895E-03
     +,   7.3242099E-03,   7.8305267E-03,   8.3198762E-03
     +,   8.7858876E-03,   9.2324344E-03,   9.6700871E-03
     +,   1.0107900E-02,   1.0545090E-02,   1.0968295E-02
     +,   1.1358494E-02,   1.1707787E-02,   1.2040152E-02
     +,   1.2423423E-02,   1.2956736E-02,   1.3727138E-02
     +,   1.4752062E-02,   1.5945954E-02,   1.7144667E-02
     +,   1.8185215E-02,   1.8994233E-02,   1.9623989E-02
     +,   2.0203885E-02,   2.0835752E-02,   2.1508982E-02
     +,   2.2103654E-02,   2.2483733E-02,   2.2606088E-02
     +,   2.2555370E-02,   2.2476360E-02,   2.2458948E-02
     +,   2.2465542E-02,   2.2356356E-02,   2.1989321E-02
     +,   2.1310743E-02,   2.0365329E-02,   1.9232633E-02
     +,   1.7960586E-02,   1.6552709E-02,   1.5002296E-02
     +,   1.3330601E-02,   1.1598197E-02,   9.8903496E-03
     +,   8.2930010E-03,   6.8727555E-03,   5.6660073E-03
     +,   4.6777125E-03,   3.8883092E-03,   3.2647392E-03
     +,   2.7709340E-03,   2.3746693E-03,   2.0504715E-03
     +,   1.7796928E-03,   1.5492821E-03,   1.3502578E-03
     +,   1.1765300E-03,   1.0240193E-03,   8.8998803E-04
     +,   7.7253778E-04,   6.7022291E-04,   5.8177538E-04
     +,   5.0592422E-04,   4.4132728E-04,   3.8659020E-04
     +,   3.4032841E-04,   3.0122275E-04,   2.6808711E-04
     +,   2.3989045E-04,   2.1577446E-04,   1.9503637E-04
     +,   1.7711427E-04,   1.6155676E-04,   1.4800287E-04
     +,   1.3615683E-04,   1.2577471E-04,   1.1664951E-04
     +,   1.0860404E-04,   1.0148561E-04,   9.5160744E-05
     +,   8.9514273E-05,   8.4445957E-05,   7.9870282E-05
     +,   7.5713688E-05,   7.1914459E-05,   6.8420195E-05
     +,   6.5187567E-05,   6.2180174E-05,   5.9368220E-05
     +,   5.6726822E-05,   5.4235807E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt110 = Yx/0.203155555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2955274E-05,   5.4088814E-05
     +,   5.5213546E-05,   5.6328157E-05,   5.7431283E-05
     +,   5.8521662E-05,   5.9598020E-05,   6.0659138E-05
     +,   6.1703802E-05,   6.2730949E-05,   6.3739455E-05
     +,   6.4728338E-05,   6.5696644E-05,   6.6643464E-05
     +,   6.7568006E-05,   6.8469526E-05,   6.9347378E-05
     +,   7.0200971E-05,   7.1029826E-05,   7.1833514E-05
     +,   7.2611743E-05,   7.3364245E-05,   7.4090887E-05
     +,   7.4791642E-05,   7.5466509E-05,   7.6115626E-05
     +,   7.6739248E-05,   7.7337638E-05,   7.7911172E-05
     +,   7.8460391E-05,   7.8985788E-05,   7.9488062E-05
     +,   7.9967889E-05,   8.0426107E-05,   8.0863567E-05
     +,   8.1281200E-05,   8.1680053E-05,   8.2061131E-05
     +,   8.2425649E-05,   8.2774692E-05,   8.3109589E-05
     +,   8.3431572E-05,   8.3741972E-05,   8.4042193E-05
     +,   8.4333587E-05,   8.4617626E-05,   8.4895779E-05
     +,   8.5169537E-05,   8.5440399E-05,   8.5709915E-05
     +,   8.5979613E-05,   8.6251122E-05,   8.6525972E-05
     +,   8.6805747E-05,   8.7092056E-05,   8.7386514E-05
     +,   8.7690714E-05,   8.8006287E-05,   8.8334811E-05
     +,   8.8677974E-05,   8.9037327E-05,   8.9414549E-05
     +,   8.9811270E-05,   9.0229078E-05,   9.0669681E-05
     +,   9.1134723E-05,   9.1625850E-05,   9.2144772E-05
     +,   9.2693190E-05,   9.3272785E-05,   9.3885392E-05
     +,   9.4532770E-05,   9.5216790E-05,   9.5939278E-05
     +,   9.6702235E-05,   9.7507735E-05,   9.8357843E-05
     +,   9.9254772E-05,   1.0020088E-04,   1.0119871E-04
     +,   1.0225081E-04,   1.0336014E-04,   1.0452962E-04
     +,   1.0576267E-04,   1.0706278E-04,   1.0843395E-04
     +,   1.0988030E-04,   1.1140660E-04,   1.1301789E-04
     +,   1.1471981E-04,   1.1651844E-04,   1.1842060E-04
     +,   1.2043353E-04,   1.2256537E-04,   1.2482498E-04
     +,   1.2722188E-04,   1.2976656E-04,   1.3247014E-04
     +,   1.3534504E-04,   1.3840407E-04,   1.4166137E-04
     +,   1.4513161E-04,   1.4883073E-04,   1.5277487E-04
     +,   1.5698146E-04,   1.6146850E-04,   1.6625416E-04
     +,   1.7135699E-04,   1.7679595E-04,   1.8259016E-04
     +,   1.8875774E-04,   1.9531717E-04,   2.0228521E-04
     +,   2.0967837E-04,   2.1751071E-04,   2.2579565E-04
     +,   2.3454326E-04,   2.4376220E-04,   2.5345720E-04
     +,   2.6363062E-04,   2.7428142E-04,   2.8540427E-04
     +,   2.9698963E-04,   3.0902502E-04,   3.2149345E-04
     +,   3.3437292E-04,   3.4763900E-04,   3.6126169E-04
     +,   3.7520964E-04,   3.8944662E-04,   4.0393608E-04
     +,   4.1863753E-04,   4.3351215E-04,   4.4851919E-04
     +,   4.6361989E-04,   4.7877838E-04,   4.9395999E-04
     +,   5.0913513E-04,   5.2427972E-04,   5.3937535E-04
     +,   5.5440963E-04,   5.6937709E-04,   5.8428012E-04
     +,   5.9912907E-04,   6.1393908E-04,   6.2873377E-04
     +,   6.4354140E-04,   6.5839424E-04,   6.7332684E-04
     +,   6.8837608E-04,   7.0357876E-04,   7.1896811E-04
     +,   7.3457282E-04,   7.5041817E-04,   7.6652248E-04
     +,   7.8289519E-04,   7.9953833E-04,   8.1644725E-04
     +,   8.3361031E-04,   8.5100846E-04,   8.6862239E-04
     +,   8.8643172E-04,   9.0441958E-04,   9.2257449E-04
     +,   9.4090094E-04,   9.5942139E-04,   9.7818126E-04
     +,   9.9725882E-04,   1.0167728E-03,   1.0368895E-03
     +,   1.0578312E-03,   1.0798838E-03,   1.1034053E-03
     +,   1.1288291E-03,   1.1566615E-03,   1.1874812E-03
     +,   1.2219263E-03,   1.2606718E-03,   1.3044006E-03
     +,   1.3537725E-03,   1.4093777E-03,   1.4716897E-03
     +,   1.5410238E-03,   1.6175113E-03,   1.7010740E-03
     +,   1.7914172E-03,   1.8880620E-03,   1.9903907E-03
     +,   2.0977100E-03,   2.2093146E-03,   2.3245991E-03
     +,   2.4431434E-03,   2.5648095E-03,   2.6898696E-03
     +,   2.8191223E-03,   2.9540050E-03,   3.0966580E-03
     +,   3.2499265E-03,   3.4172786E-03,   3.6025478E-03
     +,   3.8096362E-03,   4.0421668E-03,   4.3032439E-03
     +,   4.5952173E-03,   4.9194694E-03,   5.2761505E-03
     +,   5.6636781E-03,   6.0781594E-03,   6.5131150E-03
     +,   6.9598863E-03,   7.4088518E-03,   7.8511434E-03
     +,   8.2803108E-03,   8.6928634E-03,   9.0876464E-03
     +,   9.4648572E-03,   9.8262504E-03,   1.0177381E-02
     +,   1.0530545E-02,   1.0905809E-02,   1.1327187E-02
     +,   1.1814133E-02,   1.2373566E-02,   1.2998969E-02
     +,   1.3678148E-02,   1.4403286E-02,   1.5171643E-02
     +,   1.5972972E-02,   1.6772572E-02,   1.7507380E-02
     +,   1.8104875E-02,   1.8515917E-02,   1.8742565E-02
     +,   1.8844713E-02,   1.8924246E-02,   1.9093540E-02
     +,   1.9437620E-02,   1.9979771E-02,   2.0662557E-02
     +,   2.1357425E-02,   2.1903075E-02,   2.2158163E-02
     +,   2.2041121E-02,   2.1538071E-02,   2.0682871E-02
     +,   1.9532057E-02,   1.8155392E-02,   1.6640829E-02
     +,   1.5097152E-02,   1.3639658E-02,   1.2361815E-02
     +,   1.1309921E-02,   1.0474895E-02,   9.8042889E-03
     +,   9.2263641E-03,   8.6742919E-03,   8.1015481E-03
     +,   7.4866991E-03,   6.8300837E-03,   6.1468054E-03
     +,   5.4594330E-03,   4.7918530E-03,   4.1649886E-03
     +,   3.5942972E-03,   3.0887760E-03,   2.6509881E-03
     +,   2.2782271E-03,   1.9641845E-03,   1.7006607E-03
     +,   1.4790841E-03,   1.2915906E-03,   1.1315993E-03
     +,   9.9394401E-04,   8.7473396E-04,   7.7110034E-04
     +,   6.8090972E-04,   6.0248334E-04,   5.3443376E-04
     +,   4.7552251E-04,   4.2461566E-04,   3.8064527E-04
     +,   3.4262333E-04,   3.0964011E-04,   2.8088741E-04
     +,   2.5565698E-04,   2.3335137E-04,   2.1347356E-04
     +,   1.9562177E-04,   1.7947952E-04,   1.6479823E-04
     +,   1.5138835E-04,   1.3910321E-04,   1.2783102E-04
     +,   1.1748253E-04,   1.0798665E-04,   9.9281759E-05
     +,   9.1314250E-05,   8.4033418E-05,   7.7391865E-05
     +,   7.1342707E-05,   6.5840904E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt115 = Yx/0.212333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4859095E-05,   3.6290108E-05
     +,   3.7774174E-05,   3.9311821E-05,   4.0903349E-05
     +,   4.2548942E-05,   4.4248576E-05,   4.6002031E-05
     +,   4.7808870E-05,   4.9668488E-05,   5.1580006E-05
     +,   5.3542299E-05,   5.5554017E-05,   5.7613572E-05
     +,   5.9719107E-05,   6.1868494E-05,   6.4059386E-05
     +,   6.6289147E-05,   6.8554895E-05,   7.0853530E-05
     +,   7.3181669E-05,   7.5535732E-05,   7.7911856E-05
     +,   8.0306185E-05,   8.2714316E-05,   8.5132058E-05
     +,   8.7554836E-05,   8.9978043E-05,   9.2396986E-05
     +,   9.4806826E-05,   9.7202821E-05,   9.9580073E-05
     +,   1.0193383E-04,   1.0425932E-04,   1.0655190E-04
     +,   1.0880703E-04,   1.1102036E-04,   1.1318765E-04
     +,   1.1530503E-04,   1.1736871E-04,   1.1937536E-04
     +,   1.2132179E-04,   1.2320527E-04,   1.2502339E-04
     +,   1.2677415E-04,   1.2845590E-04,   1.3006745E-04
     +,   1.3160807E-04,   1.3307740E-04,   1.3447560E-04
     +,   1.3580322E-04,   1.3706123E-04,   1.3825118E-04
     +,   1.3937491E-04,   1.4043468E-04,   1.4143334E-04
     +,   1.4237384E-04,   1.4325966E-04,   1.4409462E-04
     +,   1.4488275E-04,   1.4562844E-04,   1.4633630E-04
     +,   1.4701103E-04,   1.4765775E-04,   1.4828143E-04
     +,   1.4888731E-04,   1.4948075E-04,   1.5006695E-04
     +,   1.5065118E-04,   1.5123867E-04,   1.5183458E-04
     +,   1.5244397E-04,   1.5307174E-04,   1.5372259E-04
     +,   1.5440107E-04,   1.5511150E-04,   1.5585797E-04
     +,   1.5664435E-04,   1.5747413E-04,   1.5835070E-04
     +,   1.5927706E-04,   1.6025592E-04,   1.6128975E-04
     +,   1.6238070E-04,   1.6353055E-04,   1.6474104E-04
     +,   1.6601334E-04,   1.6734857E-04,   1.6874741E-04
     +,   1.7021042E-04,   1.7173799E-04,   1.7333003E-04
     +,   1.7498639E-04,   1.7670661E-04,   1.7849021E-04
     +,   1.8033628E-04,   1.8224389E-04,   1.8421168E-04
     +,   1.8623838E-04,   1.8832224E-04,   1.9046171E-04
     +,   1.9265449E-04,   1.9489853E-04,   1.9719132E-04
     +,   1.9953019E-04,   2.0191231E-04,   2.0433443E-04
     +,   2.0679319E-04,   2.0928480E-04,   2.1180564E-04
     +,   2.1435115E-04,   2.1691709E-04,   2.1949873E-04
     +,   2.2209124E-04,   2.2468952E-04,   2.2728840E-04
     +,   2.2988247E-04,   2.3246673E-04,   2.3503588E-04
     +,   2.3758494E-04,   2.4010967E-04,   2.4260583E-04
     +,   2.4506991E-04,   2.4749956E-04,   2.4989358E-04
     +,   2.5225169E-04,   2.5457560E-04,   2.5686840E-04
     +,   2.5913588E-04,   2.6138581E-04,   2.6362875E-04
     +,   2.6587810E-04,   2.6815076E-04,   2.7046684E-04
     +,   2.7285016E-04,   2.7532858E-04,   2.7793404E-04
     +,   2.8070225E-04,   2.8367373E-04,   2.8689308E-04
     +,   2.9040899E-04,   2.9427421E-04,   2.9854570E-04
     +,   3.0328421E-04,   3.0855337E-04,   3.1442006E-04
     +,   3.2095364E-04,   3.2822468E-04,   3.3630451E-04
     +,   3.4526488E-04,   3.5517648E-04,   3.6610689E-04
     +,   3.7811979E-04,   3.9127428E-04,   4.0562256E-04
     +,   4.2120749E-04,   4.3806140E-04,   4.5620598E-04
     +,   4.7564949E-04,   4.9638440E-04,   5.1839033E-04
     +,   5.4163055E-04,   5.6605402E-04,   5.9159478E-04
     +,   6.1817776E-04,   6.4571999E-04,   6.7413115E-04
     +,   7.0332171E-04,   7.3320873E-04,   7.6372043E-04
     +,   7.9480035E-04,   8.2641368E-04,   8.5855817E-04
     +,   8.9126476E-04,   9.2459877E-04,   9.5867133E-04
     +,   9.9363818E-04,   1.0296954E-03,   1.0670818E-03
     +,   1.1060805E-03,   1.1470077E-03,   1.1902101E-03
     +,   1.2360534E-03,   1.2849235E-03,   1.3372091E-03
     +,   1.3932914E-03,   1.4535353E-03,   1.5182807E-03
     +,   1.5878291E-03,   1.6624224E-03,   1.7422464E-03
     +,   1.8274100E-03,   1.9179404E-03,   2.0137797E-03
     +,   2.1148103E-03,   2.2208586E-03,   2.3317202E-03
     +,   2.4472126E-03,   2.5672086E-03,   2.6916862E-03
     +,   2.8207377E-03,   2.9545932E-03,   3.0936040E-03
     +,   3.2381930E-03,   3.3887357E-03,   3.5454708E-03
     +,   3.7083272E-03,   3.8767483E-03,   4.0495778E-03
     +,   4.2250245E-03,   4.4007711E-03,   4.5742909E-03
     +,   4.7434140E-03,   4.9070548E-03,   5.0659506E-03
     +,   5.2232463E-03,   5.3847679E-03,   5.5588526E-03
     +,   5.7558753E-03,   5.9877001E-03,   6.2673623E-03
     +,   6.6090040E-03,   7.0275390E-03,   7.5373249E-03
     +,   8.1490688E-03,   8.8649541E-03,   9.6736485E-03
     +,   1.0547896E-02,   1.1446744E-02,   1.2322072E-02
     +,   1.3127087E-02,   1.3823768E-02,   1.4388186E-02
     +,   1.4815561E-02,   1.5127295E-02,   1.5377160E-02
     +,   1.5647803E-02,   1.6030390E-02,   1.6590523E-02
     +,   1.7338078E-02,   1.8220088E-02,   1.9140558E-02
     +,   1.9994073E-02,   2.0692592E-02,   2.1177828E-02
     +,   2.1422924E-02,   2.1430667E-02,   2.1230834E-02
     +,   2.0875368E-02,   2.0427393E-02,   1.9940959E-02
     +,   1.9437585E-02,   1.8894035E-02,   1.8253053E-02
     +,   1.7454142E-02,   1.6465945E-02,   1.5302675E-02
     +,   1.4019699E-02,   1.2695736E-02,   1.1411761E-02
     +,   1.0233391E-02,   9.1999462E-03,   8.3215246E-03
     +,   7.5837760E-03,   6.9574178E-03,   6.4084884E-03
     +,   5.9066992E-03,   5.4300879E-03,   4.9662846E-03
     +,   4.5113205E-03,   4.0673218E-03,   3.6398298E-03
     +,   3.2354211E-03,   2.8599338E-03,   2.5174937E-03
     +,   2.2101712E-03,   1.9380017E-03,   1.6994548E-03
     +,   1.4918527E-03,   1.3119266E-03,   1.1561749E-03
     +,   1.0212098E-03,   9.0391299E-04,   8.0157147E-04
     +,   7.1187800E-04,   6.3294318E-04,   5.6323060E-04
     +,   5.0150929E-04,   4.4679650E-04,   3.9828612E-04
     +,   3.5531333E-04,   3.1730169E-04,   2.8374585E-04
     +,   2.5418287E-04,   2.2819040E-04,   2.0537349E-04
     +,   1.8537055E-04,   1.6784688E-04,   1.5250077E-04
     +,   1.3905847E-04,   1.2727761E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt120 = Yx/0.206111111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0067979E-04,   9.2155038E-04
     +,   1.0563489E-03,   1.2057786E-03,   1.3703478E-03
     +,   1.5503124E-03,   1.7456433E-03,   1.9560461E-03
     +,   2.1810636E-03,   2.4203290E-03,   2.6739417E-03
     +,   2.9430145E-03,   3.2302630E-03,   3.5405152E-03
     +,   3.8808759E-03,   4.2603607E-03,   4.6888478E-03
     +,   5.1755011E-03,   5.7270755E-03,   6.3468344E-03
     +,   7.0347739E-03,   7.7894265E-03,   8.6106909E-03
     +,   9.5026139E-03,   1.0474390E-02,   1.1539592E-02
     +,   1.2712791E-02,   1.4004857E-02,   1.5417472E-02
     +,   1.6938323E-02,   1.8540785E-02,   2.0191623E-02
     +,   2.1865562E-02,   2.3557752E-02,   2.5280172E-02
     +,   2.7037097E-02,   2.8790800E-02,   3.0441485E-02
     +,   3.1837840E-02,   3.2812890E-02,   3.3227332E-02
     +,   3.3006113E-02,   3.2164998E-02,   3.0822674E-02
     +,   2.9179640E-02,   2.7457342E-02,   2.5821235E-02
     +,   2.4331877E-02,   2.2953071E-02,   2.1604285E-02
     +,   2.0219613E-02,   1.8780444E-02,   1.7314300E-02
     +,   1.5872650E-02,   1.4506713E-02,   1.3252009E-02
     +,   1.2124750E-02,   1.1125134E-02,   1.0243878E-02
     +,   9.4681652E-03,   8.7858401E-03,   8.1871487E-03
     +,   7.6644015E-03,   7.2102300E-03,   6.8159257E-03
     +,   6.4707394E-03,   6.1622947E-03,   5.8780629E-03
     +,   5.6070285E-03,   5.3410674E-03,   5.0755362E-03
     +,   4.8092520E-03,   4.5436732E-03,   4.2819874E-03
     +,   4.0280540E-03,   3.7855529E-03,   3.5574553E-03
     +,   3.3457053E-03,   3.1511739E-03,   2.9738124E-03
     +,   2.8128589E-03,   2.6670464E-03,   2.5348547E-03
     +,   2.4146410E-03,   2.3047961E-03,   2.2037891E-03
     +,   2.1102438E-03,   2.0229372E-03,   1.9408402E-03
     +,   1.8630952E-03,   1.7890350E-03,   1.7181641E-03
     +,   1.6501513E-03,   1.5848005E-03,   1.5220281E-03
     +,   1.4618466E-03,   1.4043223E-03,   1.3495620E-03
     +,   1.2976798E-03,   1.2487883E-03,   1.2029739E-03
     +,   1.1603022E-03,   1.1208009E-03,   1.0844682E-03
     +,   1.0512659E-03,   1.0211299E-03,   9.9397229E-04
     +,   9.6968602E-04,   9.4814703E-04,   9.2922413E-04
     +,   9.1277785E-04,   8.9866656E-04,   8.8674732E-04
     +,   8.7687833E-04,   8.6892024E-04,   8.6273625E-04
     +,   8.5819303E-04,   8.5515983E-04,   8.5350988E-04
     +,   8.5311750E-04,   8.5385883E-04,   8.5561129E-04
     +,   8.5825199E-04,   8.6165854E-04,   8.6570741E-04
     +,   8.7027397E-04,   8.7523507E-04,   8.8046351E-04
     +,   8.8583509E-04,   8.9122402E-04,   8.9650665E-04
     +,   9.0156216E-04,   9.0627192E-04,   9.1052271E-04
     +,   9.1420603E-04,   9.1722189E-04,   9.1947755E-04
     +,   9.2088827E-04,   9.2138135E-04,   9.2089368E-04
     +,   9.1937440E-04,   9.1678416E-04,   9.1309682E-04
     +,   9.0829789E-04,   9.0238696E-04,   8.9537405E-04
     +,   8.8728219E-04,   8.7814598E-04,   8.6801057E-04
     +,   8.5693051E-04,   8.4496889E-04,   8.3219830E-04
     +,   8.1869692E-04,   8.0454844E-04,   7.8984129E-04
     +,   7.7466777E-04,   7.5912179E-04,   7.4329833E-04
     +,   7.2729087E-04,   7.1119453E-04,   6.9509994E-04
     +,   6.7909539E-04,   6.6326535E-04,   6.4769061E-04
     +,   6.3244544E-04,   6.1759865E-04,   6.0321362E-04
     +,   5.8934756E-04,   5.7605049E-04,   5.6336512E-04
     +,   5.5132835E-04,   5.3997134E-04,   5.2931660E-04
     +,   5.1938160E-04,   5.1017781E-04,   5.0171040E-04
     +,   4.9397931E-04,   4.8697987E-04,   4.8070255E-04
     +,   4.7513298E-04,   4.7025355E-04,   4.6604325E-04
     +,   4.6247838E-04,   4.5953144E-04,   4.5717371E-04
     +,   4.5537433E-04,   4.5410040E-04,   4.5331797E-04
     +,   4.5299207E-04,   4.5308640E-04,   4.5356428E-04
     +,   4.5438836E-04,   4.5552073E-04,   4.5692298E-04
     +,   4.5855678E-04,   4.6038331E-04,   4.6236368E-04
     +,   4.6445886E-04,   4.6662972E-04,   4.6883710E-04
     +,   4.7104174E-04,   4.7320488E-04,   4.7528735E-04
     +,   4.7725122E-04,   4.7905746E-04,   4.8066914E-04
     +,   4.8204916E-04,   4.8316151E-04,   4.8397132E-04
     +,   4.8444502E-04,   4.8455060E-04,   4.8425782E-04
     +,   4.8353872E-04,   4.8236753E-04,   4.8072098E-04
     +,   4.7857879E-04,   4.7592371E-04,   4.7274196E-04
     +,   4.6902307E-04,   4.6476026E-04,   4.5995077E-04
     +,   4.5459517E-04,   4.4869876E-04,   4.4227028E-04
     +,   4.3532238E-04,   4.2787171E-04,   4.1993838E-04
     +,   4.1154670E-04,   4.0272321E-04,   3.9349790E-04
     +,   3.8390362E-04,   3.7397610E-04,   3.6375222E-04
     +,   3.5327033E-04,   3.4257135E-04,   3.3169595E-04
     +,   3.2068513E-04,   3.0958088E-04,   2.9842448E-04
     +,   2.8725606E-04,   2.7611465E-04,   2.6503840E-04
     +,   2.5406404E-04,   2.4322537E-04,   2.3255407E-04
     +,   2.2207995E-04,   2.1183051E-04,   2.0182964E-04
     +,   1.9209860E-04,   1.8265672E-04,   1.7351954E-04
     +,   1.6469990E-04,   1.5620833E-04,   1.4805292E-04
     +,   1.4023834E-04,   1.3276715E-04,   1.2563996E-04
     +,   1.1885532E-04,   1.1240942E-04,   1.0629664E-04
     +,   1.0051036E-04,   9.5042480E-05,   8.9883317E-05
     +,   8.5022388E-05,   8.0448692E-05,   7.6150282E-05
     +,   7.2114693E-05,   6.8329435E-05,   6.4781751E-05
     +,   6.1458726E-05,   5.8347403E-05,   5.5435266E-05
     +,   5.2710013E-05,   5.0159480E-05,   4.7771937E-05
     +,   4.5536341E-05,   4.3441767E-05,   4.1478168E-05
     +,   3.9635706E-05,   3.7905393E-05,   3.6278518E-05
     +,   3.4747176E-05,   3.3303801E-05,   3.1941519E-05
     +,   3.0653857E-05,   2.9434939E-05,   2.8279317E-05
     +,   2.7181957E-05,   2.6138367E-05,   2.5144338E-05
     +,   2.4196153E-05,   2.3290335E-05,   2.2423834E-05
     +,   2.1593800E-05,   2.0797763E-05,   2.0033394E-05
     +,   1.9298699E-05,   1.8591783E-05,   1.7911048E-05
     +,   1.7254959E-05,   1.6622227E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt60 = Yx/0.25736170212766
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1646137E-04,   2.3804347E-04
     +,   2.6150950E-04,   2.8700227E-04,   3.1468121E-04
     +,   3.4472690E-04,   3.7734624E-04,   4.1277829E-04
     +,   4.5129901E-04,   4.9322739E-04,   5.3892395E-04
     +,   5.8878982E-04,   6.4325921E-04,   7.0278358E-04
     +,   7.6781126E-04,   8.3875703E-04,   9.1597124E-04
     +,   9.9970389E-04,   1.0900786E-03,   1.1870789E-03
     +,   1.2905566E-03,   1.4002738E-03,   1.5159752E-03
     +,   1.6375092E-03,   1.7649337E-03,   1.8986831E-03
     +,   2.0396505E-03,   2.1892465E-03,   2.3493629E-03
     +,   2.5222402E-03,   2.7102728E-03,   2.9157882E-03
     +,   3.1409226E-03,   3.3876665E-03,   3.6581983E-03
     +,   3.9554564E-03,   4.2838543E-03,   4.6497677E-03
     +,   5.0614928E-03,   5.5281571E-03,   6.0578538E-03
     +,   6.6551487E-03,   7.3192129E-03,   8.0436459E-03
     +,   8.8186916E-03,   9.6354578E-03,   1.0490973E-02
     +,   1.1392089E-02,   1.2357096E-02,   1.3414393E-02
     +,   1.4597160E-02,   1.5933026E-02,   1.7428705E-02
     +,   1.9054284E-02,   2.0735702E-02,   2.2364838E-02
     +,   2.3826104E-02,   2.5028927E-02,   2.5929967E-02
     +,   2.6535809E-02,   2.6888033E-02,   2.7038336E-02
     +,   2.7020153E-02,   2.6823539E-02,   2.6388340E-02
     +,   2.5628041E-02,   2.4482021E-02,   2.2969147E-02
     +,   2.1206340E-02,   1.9377671E-02,   1.7670255E-02
     +,   1.6214520E-02,   1.5055194E-02,   1.4158951E-02
     +,   1.3443910E-02,   1.2814679E-02,   1.2190316E-02
     +,   1.1520140E-02,   1.0787553E-02,   1.0004369E-02
     +,   9.1997162E-03,   8.4078265E-03,   7.6588560E-03
     +,   6.9736219E-03,   6.3627730E-03,   5.8283503E-03
     +,   5.3665750E-03,   4.9703550E-03,   4.6312357E-03
     +,   4.3405145E-03,   4.0899408E-03,   3.8721357E-03
     +,   3.6807749E-03,   3.5106670E-03,   3.3577664E-03
     +,   3.2190336E-03,   3.0922054E-03,   2.9755796E-03
     +,   2.8677608E-03,   2.7675182E-03,   2.6736585E-03
     +,   2.5850157E-03,   2.5004628E-03,   2.4189781E-03
     +,   2.3396965E-03,   2.2619655E-03,   2.1853861E-03
     +,   2.1098070E-03,   2.0352837E-03,   1.9620601E-03
     +,   1.8905011E-03,   1.8210319E-03,   1.7541025E-03
     +,   1.6901215E-03,   1.6294523E-03,   1.5723689E-03
     +,   1.5190684E-03,   1.4696531E-03,   1.4241547E-03
     +,   1.3825281E-03,   1.3446722E-03,   1.3104446E-03
     +,   1.2796702E-03,   1.2521509E-03,   1.2276775E-03
     +,   1.2060374E-03,   1.1870177E-03,   1.1704087E-03
     +,   1.1560046E-03,   1.1436046E-03,   1.1330078E-03
     +,   1.1240152E-03,   1.1164250E-03,   1.1100310E-03
     +,   1.1046196E-03,   1.0999743E-03,   1.0958683E-03
     +,   1.0920727E-03,   1.0883566E-03,   1.0844897E-03
     +,   1.0802480E-03,   1.0754167E-03,   1.0697965E-03
     +,   1.0632082E-03,   1.0554953E-03,   1.0465318E-03
     +,   1.0362183E-03,   1.0244915E-03,   1.0113217E-03
     +,   9.9671062E-04,   9.8069594E-04,   9.6334534E-04
     +,   9.4475719E-04,   9.2505250E-04,   9.0437557E-04
     +,   8.8288891E-04,   8.6076796E-04,   8.3819637E-04
     +,   8.1536308E-04,   7.9245918E-04,   7.6967088E-04
     +,   7.4717909E-04,   7.2515599E-04,   7.0376485E-04
     +,   6.8315351E-04,   6.6345697E-04,   6.4479763E-04
     +,   6.2728219E-04,   6.1100349E-04,   5.9603940E-04
     +,   5.8245624E-04,   5.7030871E-04,   5.5963837E-04
     +,   5.5047654E-04,   5.4284692E-04,   5.3676264E-04
     +,   5.3222897E-04,   5.2924443E-04,   5.2779866E-04
     +,   5.2787503E-04,   5.2944833E-04,   5.3248613E-04
     +,   5.3694705E-04,   5.4278097E-04,   5.4992898E-04
     +,   5.5832136E-04,   5.6787720E-04,   5.7850609E-04
     +,   5.9010595E-04,   6.0256181E-04,   6.1574957E-04
     +,   6.2953401E-04,   6.4376852E-04,   6.5829768E-04
     +,   6.7295949E-04,   6.8758515E-04,   7.0200104E-04
     +,   7.1603095E-04,   7.2950026E-04,   7.4223609E-04
     +,   7.5406965E-04,   7.6484052E-04,   7.7439891E-04
     +,   7.8260724E-04,   7.8934181E-04,   7.9449662E-04
     +,   7.9798501E-04,   7.9973839E-04,   7.9970999E-04
     +,   7.9787563E-04,   7.9423148E-04,   7.8879588E-04
     +,   7.8160729E-04,   7.7272533E-04,   7.6222647E-04
     +,   7.5020414E-04,   7.3676696E-04,   7.2203483E-04
     +,   7.0613704E-04,   6.8921171E-04,   6.7140069E-04
     +,   6.5284665E-04,   6.3369441E-04,   6.1408617E-04
     +,   5.9415802E-04,   5.7403935E-04,   5.5385433E-04
     +,   5.3371675E-04,   5.1372888E-04,   4.9398287E-04
     +,   4.7456066E-04,   4.5553289E-04,   4.3695708E-04
     +,   4.1888075E-04,   4.0134211E-04,   3.8436821E-04
     +,   3.6797728E-04,   3.5218018E-04,   3.3698068E-04
     +,   3.2237580E-04,   3.0835738E-04,   2.9491336E-04
     +,   2.8202892E-04,   2.6968558E-04,   2.5786326E-04
     +,   2.4654123E-04,   2.3569862E-04,   2.2531359E-04
     +,   2.1536458E-04,   2.0583185E-04,   1.9669562E-04
     +,   1.8793697E-04,   1.7953890E-04,   1.7148563E-04
     +,   1.6376174E-04,   1.5635340E-04,   1.4924811E-04
     +,   1.4243426E-04,   1.3590087E-04,   1.2963774E-04
     +,   1.2363566E-04,   1.1788611E-04,   1.1238043E-04
     +,   1.0711057E-04,   1.0206919E-04,   9.7248609E-05
     +,   9.2641429E-05,   8.8240675E-05,   8.4039333E-05
     +,   8.0030273E-05,   7.6206401E-05,   7.2560899E-05
     +,   6.9086986E-05,   6.5777720E-05,   6.2626241E-05
     +,   5.9626080E-05,   5.6770474E-05,   5.4053118E-05
     +,   5.1467559E-05,   4.9007776E-05,   4.6667628E-05
     +,   4.4441491E-05,   4.2323580E-05,   4.0308663E-05
     +,   3.8391456E-05,   3.6567100E-05,   3.4830868E-05
     +,   3.3178185E-05,   3.1604934E-05,   3.0106959E-05
     +,   2.8680568E-05,   2.7322039E-05,   2.6028081E-05
     +,   2.4795436E-05,   2.3621173E-05,   2.2502374E-05
     +,   2.1436470E-05,   2.0420883E-05,   1.9453328E-05
     +,   1.8531529E-05,   1.7653456E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt65 = Yx/0.232065217391304
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.0263326E-05,   6.2822459E-05
     +,   6.5502849E-05,   6.8315698E-05,   7.1273658E-05
     +,   7.4390897E-05,   7.7683348E-05,   8.1169019E-05
     +,   8.4868021E-05,   8.8803332E-05,   9.3000686E-05
     +,   9.7489254E-05,   1.0230211E-04,   1.0747679E-04
     +,   1.1305578E-04,   1.1908734E-04,   1.2562599E-04
     +,   1.3273339E-04,   1.4047882E-04,   1.4893996E-04
     +,   1.5820331E-04,   1.6836438E-04,   1.7952795E-04
     +,   1.9180853E-04,   2.0532805E-04,   2.2021780E-04
     +,   2.3661515E-04,   2.5466323E-04,   2.7450966E-04
     +,   2.9630528E-04,   3.2020343E-04,   3.4635974E-04
     +,   3.7493356E-04,   4.0609000E-04,   4.4000338E-04
     +,   4.7686227E-04,   5.1687472E-04,   5.6027196E-04
     +,   6.0731859E-04,   6.5830495E-04,   7.1356125E-04
     +,   7.7345112E-04,   8.3838037E-04,   9.0881326E-04
     +,   9.8530110E-04,   1.0685399E-03,   1.1594525E-03
     +,   1.2593031E-03,   1.3698217E-03,   1.4933255E-03
     +,   1.6327895E-03,   1.7918269E-03,   1.9745270E-03
     +,   2.1851652E-03,   2.4277337E-03,   2.7055130E-03
     +,   3.0206479E-03,   3.3740189E-03,   3.7654266E-03
     +,   4.1940813E-03,   4.6592811E-03,   5.1609431E-03
     +,   5.6996848E-03,   6.2765279E-03,   6.8922560E-03
     +,   7.5469641E-03,   8.2406085E-03,   8.9743268E-03
     +,   9.7525315E-03,   1.0583933E-02,   1.1480570E-02
     +,   1.2452977E-02,   1.3502957E-02,   1.4615368E-02
     +,   1.5753947E-02,   1.6863678E-02,   1.7880546E-02
     +,   1.8746037E-02,   1.9420516E-02,   1.9889992E-02
     +,   2.0164045E-02,   2.0266993E-02,   2.0226512E-02
     +,   2.0065982E-02,   1.9801265E-02,   1.9441025E-02
     +,   1.8987447E-02,   1.8436048E-02,   1.7777445E-02
     +,   1.7002573E-02,   1.6111214E-02,   1.5119594E-02
     +,   1.4062302E-02,   1.2987151E-02,   1.1944807E-02
     +,   1.0977486E-02,   1.0110965E-02,   9.3527697E-03
     +,   8.6955950E-03,   8.1242453E-03,   7.6220781E-03
     +,   7.1754106E-03,   6.7745391E-03,   6.4127692E-03
     +,   6.0846186E-03,   5.7846489E-03,   5.5072168E-03
     +,   5.2470001E-03,   4.9996651E-03,   4.7623105E-03
     +,   4.5334594E-03,   4.3125697E-03,   4.0995991E-03
     +,   3.8944904E-03,   3.6970407E-03,   3.5068744E-03
     +,   3.3236421E-03,   3.1471453E-03,   2.9775316E-03
     +,   2.8152540E-03,   2.6610466E-03,   2.5157996E-03
     +,   2.3804056E-03,   2.2556076E-03,   2.1419150E-03
     +,   2.0395471E-03,   1.9483889E-03,   1.8680576E-03
     +,   1.7979168E-03,   1.7371632E-03,   1.6848859E-03
     +,   1.6401423E-03,   1.6019958E-03,   1.5695730E-03
     +,   1.5420754E-03,   1.5187942E-03,   1.4991137E-03
     +,   1.4824998E-03,   1.4684879E-03,   1.4566715E-03
     +,   1.4466912E-03,   1.4382248E-03,   1.4309806E-03
     +,   1.4246950E-03,   1.4191327E-03,   1.4140842E-03
     +,   1.4093700E-03,   1.4048344E-03,   1.4003506E-03
     +,   1.3958112E-03,   1.3911244E-03,   1.3862147E-03
     +,   1.3810083E-03,   1.3754324E-03,   1.3694076E-03
     +,   1.3628467E-03,   1.3556515E-03,   1.3477134E-03
     +,   1.3389121E-03,   1.3291253E-03,   1.3182302E-03
     +,   1.3061109E-03,   1.2926657E-03,   1.2778114E-03
     +,   1.2614945E-03,   1.2436891E-03,   1.2244080E-03
     +,   1.2037007E-03,   1.1816537E-03,   1.1583886E-03
     +,   1.1340628E-03,   1.1088622E-03,   1.0829940E-03
     +,   1.0566831E-03,   1.0301665E-03,   1.0036835E-03
     +,   9.7746786E-04,   9.5174985E-04,   9.2674250E-04
     +,   9.0264046E-04,   8.7961677E-04,   8.5782201E-04
     +,   8.3738216E-04,   8.1839511E-04,   8.0093602E-04
     +,   7.8505679E-04,   7.7078637E-04,   7.5813447E-04
     +,   7.4709213E-04,   7.3763623E-04,   7.2973018E-04
     +,   7.2332605E-04,   7.1836746E-04,   7.1479165E-04
     +,   7.1252760E-04,   7.1150064E-04,   7.1163179E-04
     +,   7.1283890E-04,   7.1503501E-04,   7.1813085E-04
     +,   7.2203251E-04,   7.2664302E-04,   7.3186052E-04
     +,   7.3758006E-04,   7.4369006E-04,   7.5007620E-04
     +,   7.5661903E-04,   7.6319429E-04,   7.6967443E-04
     +,   7.7592913E-04,   7.8182667E-04,   7.8723324E-04
     +,   7.9201709E-04,   7.9604867E-04,   7.9920300E-04
     +,   8.0136117E-04,   8.0241222E-04,   8.0225628E-04
     +,   8.0080569E-04,   7.9798576E-04,   7.9373899E-04
     +,   7.8802271E-04,   7.8081351E-04,   7.7210530E-04
     +,   7.6191139E-04,   7.5026252E-04,   7.3720765E-04
     +,   7.2281336E-04,   7.0716045E-04,   6.9034362E-04
     +,   6.7247043E-04,   6.5365841E-04,   6.3403224E-04
     +,   6.1372080E-04,   5.9285882E-04,   5.7157897E-04
     +,   5.5001298E-04,   5.2829046E-04,   5.0653564E-04
     +,   4.8486397E-04,   4.6338321E-04,   4.4219347E-04
     +,   4.2138406E-04,   4.0103274E-04,   3.8120645E-04
     +,   3.6196283E-04,   3.4334874E-04,   3.2539971E-04
     +,   3.0814164E-04,   2.9159317E-04,   2.7576354E-04
     +,   2.6065425E-04,   2.4626174E-04,   2.3257693E-04
     +,   2.1958489E-04,   2.0726729E-04,   1.9560329E-04
     +,   1.8456996E-04,   1.7414177E-04,   1.6429224E-04
     +,   1.5499517E-04,   1.4622374E-04,   1.3795127E-04
     +,   1.3015112E-04,   1.2279848E-04,   1.1586856E-04
     +,   1.0933758E-04,   1.0318324E-04,   9.7384516E-05
     +,   9.1920927E-05,   8.6773180E-05,   8.1923557E-05
     +,   7.7355158E-05,   7.3051917E-05,   6.8998677E-05
     +,   6.5181564E-05,   6.1586972E-05,   5.8202604E-05
     +,   5.5016353E-05,   5.2017193E-05,   4.9194296E-05
     +,   4.6537822E-05,   4.4038010E-05,   4.1685980E-05
     +,   3.9472940E-05,   3.7390870E-05,   3.5431891E-05
     +,   3.3588574E-05,   3.1853990E-05,   3.0221352E-05
     +,   2.8684442E-05,   2.7237154E-05,   2.5873889E-05
     +,   2.4589193E-05,   2.3378065E-05,   2.2235643E-05
     +,   2.1157499E-05,   2.0139332E-05,   1.9177249E-05
     +,   1.8267456E-05,   1.7406555E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt70 = Yx/0.193295454545455
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0109999E-05,   9.3389448E-05
     +,   9.6739604E-05,   1.0016367E-04,   1.0366541E-04
     +,   1.0724932E-04,   1.1092046E-04,   1.1468458E-04
     +,   1.1854802E-04,   1.2251796E-04,   1.2660200E-04
     +,   1.3080820E-04,   1.3514525E-04,   1.3962229E-04
     +,   1.4424858E-04,   1.4903386E-04,   1.5398781E-04
     +,   1.5912033E-04,   1.6444118E-04,   1.6996013E-04
     +,   1.7568676E-04,   1.8163060E-04,   1.8780114E-04
     +,   1.9420827E-04,   2.0086154E-04,   2.0777188E-04
     +,   2.1495098E-04,   2.2241204E-04,   2.3017095E-04
     +,   2.3824663E-04,   2.4666244E-04,   2.5544700E-04
     +,   2.6463595E-04,   2.7427319E-04,   2.8441215E-04
     +,   2.9511799E-04,   3.0646863E-04,   3.1855638E-04
     +,   3.3148983E-04,   3.4539291E-04,   3.6040755E-04
     +,   3.7669201E-04,   3.9441988E-04,   4.1377923E-04
     +,   4.3496874E-04,   4.5819365E-04,   4.8366108E-04
     +,   5.1157305E-04,   5.4211944E-04,   5.7546934E-04
     +,   6.1176321E-04,   6.5110356E-04,   6.9354882E-04
     +,   7.3911063E-04,   7.8774826E-04,   8.3937962E-04
     +,   8.9388940E-04,   9.5115154E-04,   1.0110595E-03
     +,   1.0735675E-03,   1.1387364E-03,   1.2067884E-03
     +,   1.2781495E-03,   1.3535033E-03,   1.4338058E-03
     +,   1.5202734E-03,   1.6143597E-03,   1.7176548E-03
     +,   1.8317857E-03,   1.9582373E-03,   2.0982032E-03
     +,   2.2523755E-03,   2.4208296E-03,   2.6029018E-03
     +,   2.7972441E-03,   3.0019830E-03,   3.2150354E-03
     +,   3.4346005E-03,   3.6597350E-03,   3.8908320E-03
     +,   4.1299304E-03,   4.3807523E-03,   4.6483935E-03
     +,   4.9390052E-03,   5.2595506E-03,   5.6181443E-03
     +,   6.0246219E-03,   6.4911917E-03,   7.0319003E-03
     +,   7.6603629E-03,   8.3852904E-03,   9.2049362E-03
     +,   1.0102898E-02,   1.1047494E-02,   1.1996247E-02
     +,   1.2904237E-02,   1.3734341E-02,   1.4464289E-02
     +,   1.5089381E-02,   1.5618227E-02,   1.6064681E-02
     +,   1.6437577E-02,   1.6732872E-02,   1.6930951E-02
     +,   1.7000351E-02,   1.6907346E-02,   1.6627846E-02
     +,   1.6157385E-02,   1.5515525E-02,   1.4743216E-02
     +,   1.3894702E-02,   1.3026491E-02,   1.2187201E-02
     +,   1.1410332E-02,   1.0711564E-02,   1.0090063E-02
     +,   9.5333271E-03,   9.0232054E-03,   8.5416371E-03
     +,   8.0744317E-03,   7.6130680E-03,   7.1548969E-03
     +,   6.7024757E-03,   6.2625799E-03,   5.8449931E-03
     +,   5.4609058E-03,   5.1208334E-03,   4.8326473E-03
     +,   4.5998297E-03,   4.4207405E-03,   4.2887684E-03
     +,   4.1935360E-03,   4.1226111E-03,   4.0634195E-03
     +,   4.0048426E-03,   3.9383383E-03,   3.8584375E-03
     +,   3.7626768E-03,   3.6511628E-03,   3.5259062E-03
     +,   3.3901175E-03,   3.2475789E-03,   3.1021258E-03
     +,   2.9573124E-03,   2.8162203E-03,   2.6813468E-03
     +,   2.5546039E-03,   2.4373850E-03,   2.3305987E-03
     +,   2.2347618E-03,   2.1500515E-03,   2.0763928E-03
     +,   2.0134866E-03,   1.9608571E-03,   1.9178947E-03
     +,   1.8838735E-03,   1.8579775E-03,   1.8393133E-03
     +,   1.8269224E-03,   1.8197971E-03,   1.8168866E-03
     +,   1.8171120E-03,   1.8193839E-03,   1.8226251E-03
     +,   1.8257917E-03,   1.8279009E-03,   1.8280566E-03
     +,   1.8254779E-03,   1.8195210E-03,   1.8096885E-03
     +,   1.7956533E-03,   1.7772500E-03,   1.7544797E-03
     +,   1.7274964E-03,   1.6965963E-03,   1.6621908E-03
     +,   1.6247923E-03,   1.5849847E-03,   1.5434069E-03
     +,   1.5007196E-03,   1.4575878E-03,   1.4146608E-03
     +,   1.3725607E-03,   1.3318541E-03,   1.2930526E-03
     +,   1.2565991E-03,   1.2228647E-03,   1.1921363E-03
     +,   1.1646221E-03,   1.1404512E-03,   1.1196698E-03
     +,   1.1022479E-03,   1.0880851E-03,   1.0770145E-03
     +,   1.0688084E-03,   1.0631904E-03,   1.0598408E-03
     +,   1.0584083E-03,   1.0585184E-03,   1.0597869E-03
     +,   1.0618268E-03,   1.0642603E-03,   1.0667270E-03
     +,   1.0688959E-03,   1.0704668E-03,   1.0711816E-03
     +,   1.0708257E-03,   1.0692327E-03,   1.0662831E-03
     +,   1.0619062E-03,   1.0560758E-03,   1.0488062E-03
     +,   1.0401501E-03,   1.0301891E-03,   1.0190282E-03
     +,   1.0067899E-03,   9.9360640E-04,   9.7961188E-04
     +,   9.6493709E-04,   9.4970601E-04,   9.3402679E-04
     +,   9.1799255E-04,   9.0167759E-04,   8.8513753E-04
     +,   8.6840725E-04,   8.5150241E-04,   8.3442457E-04
     +,   8.1716140E-04,   7.9968839E-04,   7.8197377E-04
     +,   7.6398434E-04,   7.4568612E-04,   7.2704750E-04
     +,   7.0804247E-04,   6.8865489E-04,   6.6887762E-04
     +,   6.4871390E-04,   6.2818034E-04,   6.0730608E-04
     +,   5.8612961E-04,   5.6470017E-04,   5.4307771E-04
     +,   5.2132952E-04,   4.9952784E-04,   4.7774854E-04
     +,   4.5607143E-04,   4.3457618E-04,   4.1334011E-04
     +,   3.9243736E-04,   3.7193971E-04,   3.5191193E-04
     +,   3.3241208E-04,   3.1349270E-04,   2.9519876E-04
     +,   2.7756646E-04,   2.6062448E-04,   2.4439505E-04
     +,   2.2889323E-04,   2.1412609E-04,   2.0009473E-04
     +,   1.8679525E-04,   1.7421895E-04,   1.6235151E-04
     +,   1.5117507E-04,   1.4066957E-04,   1.3081143E-04
     +,   1.2157507E-04,   1.1293405E-04,   1.0486085E-04
     +,   9.7326927E-05,   9.0303554E-05,   8.3762578E-05
     +,   7.7676304E-05,   7.2017196E-05,   6.6758599E-05
     +,   6.1875420E-05,   5.7342881E-05,   5.3138079E-05
     +,   4.9238664E-05,   4.5624085E-05,   4.2274514E-05
     +,   3.9171788E-05,   3.6298487E-05,   3.3638738E-05
     +,   3.1177373E-05,   2.8900586E-05,   2.6795318E-05
     +,   2.4849416E-05,   2.3051782E-05,   2.1391848E-05
     +,   1.9860014E-05,   1.8447130E-05,   1.7144886E-05
     +,   1.5945343E-05,   1.4841270E-05,   1.3825770E-05
     +,   1.2892541E-05,   1.2035568E-05,   1.1249340E-05
     +,   1.0528595E-05,   9.8685159E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt75 = Yx/0.178340909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.8462407E-05,   4.9779097E-05
     +,   5.1116614E-05,   5.2474756E-05,   5.3853280E-05
     +,   5.5251974E-05,   5.6670593E-05,   5.8108901E-05
     +,   5.9566682E-05,   6.1043807E-05,   6.2540108E-05
     +,   6.4055508E-05,   6.5589971E-05,   6.7143577E-05
     +,   6.8716494E-05,   7.0309034E-05,   7.1921619E-05
     +,   7.3554838E-05,   7.5209471E-05,   7.6886514E-05
     +,   7.8587160E-05,   8.0312871E-05,   8.2065308E-05
     +,   8.3846542E-05,   8.5658721E-05,   8.7504523E-05
     +,   8.9386733E-05,   9.1308546E-05,   9.3273411E-05
     +,   9.5285017E-05,   9.7347358E-05,   9.9464582E-05
     +,   1.0164116E-04,   1.0388150E-04,   1.0619031E-04
     +,   1.0857215E-04,   1.1103166E-04,   1.1357335E-04
     +,   1.1620169E-04,   1.1892071E-04,   1.2173445E-04
     +,   1.2464664E-04,   1.2766072E-04,   1.3077998E-04
     +,   1.3400779E-04,   1.3734754E-04,   1.4080304E-04
     +,   1.4437892E-04,   1.4808103E-04,   1.5191712E-04
     +,   1.5589751E-04,   1.6003607E-04,   1.6435119E-04
     +,   1.6886707E-04,   1.7361465E-04,   1.7863361E-04
     +,   1.8397321E-04,   1.8969398E-04,   1.9586910E-04
     +,   2.0258542E-04,   2.0994472E-04,   2.1806417E-04
     +,   2.2707603E-04,   2.3712873E-04,   2.4838521E-04
     +,   2.6102050E-04,   2.7522258E-04,   2.9118569E-04
     +,   3.0911161E-04,   3.2920137E-04,   3.5165576E-04
     +,   3.7666640E-04,   4.0441719E-04,   4.3507569E-04
     +,   4.6879603E-04,   5.0571922E-04,   5.4597191E-04
     +,   5.8967760E-04,   6.3696987E-04,   6.8800931E-04
     +,   7.4299768E-04,   8.0221845E-04,   8.6604722E-04
     +,   9.3499856E-04,   1.0097277E-03,   1.0910677E-03
     +,   1.1800100E-03,   1.2777231E-03,   1.3855093E-03
     +,   1.5048089E-03,   1.6371829E-03,   1.7842915E-03
     +,   1.9479159E-03,   2.1299606E-03,   2.3323975E-03
     +,   2.5571045E-03,   2.8056249E-03,   3.0786588E-03
     +,   3.3755302E-03,   3.6935229E-03,   4.0275282E-03
     +,   4.3699769E-03,   4.7116354E-03,   5.0429734E-03
     +,   5.3563961E-03,   5.6486446E-03,   5.9228516E-03
     +,   6.1895242E-03,   6.4656436E-03,   6.7714751E-03
     +,   7.1253357E-03,   7.5375023E-03,   8.0050537E-03
     +,   8.5104071E-03,   9.0249153E-03,   9.5180860E-03
     +,   9.9689206E-03,   1.0374960E-02,   1.0753209E-02
     +,   1.1131232E-02,   1.1531131E-02,   1.1954153E-02
     +,   1.2374256E-02,   1.2744966E-02,   1.3016173E-02
     +,   1.3152502E-02,   1.3143997E-02,   1.3005022E-02
     +,   1.2763963E-02,   1.2450748E-02,   1.2088417E-02
     +,   1.1691247E-02,   1.1267568E-02,   1.0823895E-02
     +,   1.0367029E-02,   9.9038305E-03,   9.4394842E-03
     +,   8.9759985E-03,   8.5121747E-03,   8.0453837E-03
     +,   7.5743520E-03,   7.1017193E-03,   6.6353385E-03
     +,   6.1878217E-03,   5.7744696E-03,   5.4100067E-03
     +,   5.1054414E-03,   4.8657153E-03,   4.6886425E-03
     +,   4.5654639E-03,   4.4826330E-03,   4.4243527E-03
     +,   4.3751793E-03,   4.3222569E-03,   4.2567388E-03
     +,   4.1743475E-03,   4.0750327E-03,   3.9620339E-03
     +,   3.8406143E-03,   3.7167368E-03,   3.5959347E-03
     +,   3.4825243E-03,   3.3792050E-03,   3.2869983E-03
     +,   3.2054342E-03,   3.1329156E-03,   3.0671291E-03
     +,   3.0054541E-03,   2.9453011E-03,   2.8843929E-03
     +,   2.8209642E-03,   2.7538536E-03,   2.6825466E-03
     +,   2.6071472E-03,   2.5283028E-03,   2.4470827E-03
     +,   2.3648434E-03,   2.2830863E-03,   2.2033195E-03
     +,   2.1269361E-03,   2.0551255E-03,   1.9888277E-03
     +,   1.9286975E-03,   1.8751087E-03,   1.8281912E-03
     +,   1.7878693E-03,   1.7539135E-03,   1.7259741E-03
     +,   1.7036330E-03,   1.6864296E-03,   1.6738739E-03
     +,   1.6654573E-03,   1.6606518E-03,   1.6588991E-03
     +,   1.6596144E-03,   1.6621754E-03,   1.6659264E-03
     +,   1.6701795E-03,   1.6742325E-03,   1.6773845E-03
     +,   1.6789552E-03,   1.6783121E-03,   1.6748921E-03
     +,   1.6682275E-03,   1.6579633E-03,   1.6438713E-03
     +,   1.6258556E-03,   1.6039575E-03,   1.5783475E-03
     +,   1.5493080E-03,   1.5172170E-03,   1.4825304E-03
     +,   1.4457509E-03,   1.4074016E-03,   1.3680009E-03
     +,   1.3280484E-03,   1.2879961E-03,   1.2482399E-03
     +,   1.2091043E-03,   1.1708515E-03,   1.1336653E-03
     +,   1.0976662E-03,   1.0629155E-03,   1.0294248E-03
     +,   9.9716370E-04,   9.6607109E-04,   9.3606859E-04
     +,   9.0706686E-04,   8.7896700E-04,   8.5167546E-04
     +,   8.2510308E-04,   7.9916941E-04,   7.7380118E-04
     +,   7.4893562E-04,   7.2452176E-04,   7.0051465E-04
     +,   6.7687902E-04,   6.5358722E-04,   6.3061918E-04
     +,   6.0795899E-04,   5.8559672E-04,   5.6352868E-04
     +,   5.4175616E-04,   5.2028388E-04,   4.9912091E-04
     +,   4.7828109E-04,   4.5778253E-04,   4.3764416E-04
     +,   4.1788863E-04,   3.9854107E-04,   3.7962661E-04
     +,   3.6117068E-04,   3.4319947E-04,   3.2573819E-04
     +,   3.0880980E-04,   2.9243447E-04,   2.7663147E-04
     +,   2.6141686E-04,   2.4680255E-04,   2.3279715E-04
     +,   2.1940679E-04,   2.0663404E-04,   1.9447731E-04
     +,   1.8293191E-04,   1.7199105E-04,   1.6164422E-04
     +,   1.5187824E-04,   1.4267836E-04,   1.3402772E-04
     +,   1.2590726E-04,   1.1829641E-04,   1.1117413E-04
     +,   1.0451844E-04,   9.8306256E-05,   9.2514223E-05
     +,   8.7119523E-05,   8.2098573E-05,   7.7428776E-05
     +,   7.3087445E-05,   6.9052920E-05,   6.5303837E-05
     +,   6.1820065E-05,   5.8581896E-05,   5.5571018E-05
     +,   5.2769687E-05,   5.0161554E-05,   4.7731031E-05
     +,   4.5463574E-05,   4.3345852E-05,   4.1365256E-05
     +,   3.9510403E-05,   3.7770569E-05,   3.6136149E-05
     +,   3.4598183E-05,   3.3148659E-05,   3.1780128E-05
     +,   3.0486020E-05,   2.9260213E-05,   2.8097336E-05
     +,   2.6992391E-05,   2.5941041E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt80 = Yx/0.157581395348837
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5118351E-05,   4.6546120E-05
     +,   4.8029313E-05,   4.9570674E-05,   5.1173127E-05
     +,   5.2839630E-05,   5.4573233E-05,   5.6376990E-05
     +,   5.8254001E-05,   6.0207545E-05,   6.2240753E-05
     +,   6.4356864E-05,   6.6559056E-05,   6.8850532E-05
     +,   7.1234441E-05,   7.3713883E-05,   7.6291893E-05
     +,   7.8971352E-05,   8.1755112E-05,   8.4645813E-05
     +,   8.7645967E-05,   9.0757865E-05,   9.3983574E-05
     +,   9.7325115E-05,   1.0078382E-04,   1.0436119E-04
     +,   1.0805816E-04,   1.1187539E-04,   1.1581319E-04
     +,   1.1987147E-04,   1.2404982E-04,   1.2834738E-04
     +,   1.3276300E-04,   1.3729501E-04,   1.4194151E-04
     +,   1.4670008E-04,   1.5156809E-04,   1.5654258E-04
     +,   1.6162047E-04,   1.6679814E-04,   1.7207238E-04
     +,   1.7743952E-04,   1.8289615E-04,   1.8843896E-04
     +,   1.9406484E-04,   1.9977127E-04,   2.0555603E-04
     +,   2.1141775E-04,   2.1735555E-04,   2.2336966E-04
     +,   2.2946137E-04,   2.3563282E-04,   2.4188761E-04
     +,   2.4823085E-04,   2.5466821E-04,   2.6120764E-04
     +,   2.6785795E-04,   2.7462936E-04,   2.8153340E-04
     +,   2.8858267E-04,   2.9579079E-04,   3.0317233E-04
     +,   3.1074166E-04,   3.1851430E-04,   3.2650566E-04
     +,   3.3472988E-04,   3.4320148E-04,   3.5193263E-04
     +,   3.6093534E-04,   3.7021836E-04,   3.7978913E-04
     +,   3.8965142E-04,   3.9980718E-04,   4.1025362E-04
     +,   4.2098499E-04,   4.3199203E-04,   4.4326048E-04
     +,   4.5477189E-04,   4.6650399E-04,   4.7843106E-04
     +,   4.9052143E-04,   5.0274201E-04,   5.1505427E-04
     +,   5.2741967E-04,   5.3979602E-04,   5.5214280E-04
     +,   5.6441955E-04,   5.7659019E-04,   5.8862381E-04
     +,   6.0049945E-04,   6.1221048E-04,   6.2376616E-04
     +,   6.3520164E-04,   6.4658368E-04,   6.5802003E-04
     +,   6.6966814E-04,   6.8175007E-04,   6.9456320E-04
     +,   7.0849463E-04,   7.2403374E-04,   7.4178353E-04
     +,   7.6246250E-04,   7.8690785E-04,   8.1605848E-04
     +,   8.5093529E-04,   8.9260790E-04,   9.4214472E-04
     +,   1.0005643E-03,   1.0687888E-03,   1.1475954E-03
     +,   1.2375755E-03,   1.3391323E-03,   1.4524476E-03
     +,   1.5775096E-03,   1.7140685E-03,   1.8616662E-03
     +,   2.0195895E-03,   2.1869440E-03,   2.3627223E-03
     +,   2.5461018E-03,   2.7368458E-03,   2.9358503E-03
     +,   3.1457052E-03,   3.3710392E-03,   3.6183165E-03
     +,   3.8948432E-03,   4.2070993E-03,   4.5583956E-03
     +,   4.9468619E-03,   5.3642378E-03,   5.7966667E-03
     +,   6.2273247E-03,   6.6410429E-03,   7.0291888E-03
     +,   7.3936339E-03,   7.7479803E-03,   8.1152534E-03
     +,   8.5223177E-03,   8.9923199E-03,   9.5371036E-03
     +,   1.0151721E-02,   1.0812839E-02,   1.1481700E-02
     +,   1.2110693E-02,   1.2652117E-02,   1.3066477E-02
     +,   1.3327537E-02,   1.3423783E-02,   1.3356606E-02
     +,   1.3137533E-02,   1.2786234E-02,   1.2329463E-02
     +,   1.1799404E-02,   1.1230161E-02,   1.0652241E-02
     +,   1.0087321E-02,   9.5454780E-03,   9.0266652E-03
     +,   8.5257394E-03,   8.0383718E-03,   7.5652651E-03
     +,   7.1132900E-03,   6.6934568E-03,   6.3170884E-03
     +,   5.9917620E-03,   5.7188622E-03,   5.4930649E-03
     +,   5.3038159E-03,   5.1379637E-03,   4.9826740E-03
     +,   4.8277029E-03,   4.6666497E-03,   4.4970894E-03
     +,   4.3199775E-03,   4.1386178E-03,   3.9574923E-03
     +,   3.7813326E-03,   3.6144061E-03,   3.4601041E-03
     +,   3.3207347E-03,   3.1975417E-03,   3.0908145E-03
     +,   3.0000256E-03,   2.9239948E-03,   2.8610909E-03
     +,   2.8093809E-03,   2.7667840E-03,   2.7312124E-03
     +,   2.7006883E-03,   2.6734555E-03,   2.6480216E-03
     +,   2.6232062E-03,   2.5981460E-03,   2.5722659E-03
     +,   2.5452431E-03,   2.5169596E-03,   2.4874574E-03
     +,   2.4569049E-03,   2.4255582E-03,   2.3937444E-03
     +,   2.3618487E-03,   2.3303116E-03,   2.2995893E-03
     +,   2.2701516E-03,   2.2424448E-03,   2.2168474E-03
     +,   2.1936235E-03,   2.1728873E-03,   2.1545568E-03
     +,   2.1383404E-03,   2.1237249E-03,   2.1099986E-03
     +,   2.0962914E-03,   2.0816282E-03,   2.0650025E-03
     +,   2.0454477E-03,   2.0221143E-03,   1.9943232E-03
     +,   1.9616203E-03,   1.9238003E-03,   1.8809084E-03
     +,   1.8332251E-03,   1.7812427E-03,   1.7256163E-03
     +,   1.6671063E-03,   1.6065353E-03,   1.5447327E-03
     +,   1.4824971E-03,   1.4205470E-03,   1.3595042E-03
     +,   1.2998820E-03,   1.2420772E-03,   1.1863637E-03
     +,   1.1329114E-03,   1.0817996E-03,   1.0330267E-03
     +,   9.8652916E-04,   9.4220351E-04,   8.9991774E-04
     +,   8.5952063E-04,   8.2085823E-04,   7.8378204E-04
     +,   7.4815343E-04,   7.1384595E-04,   6.8074767E-04
     +,   6.4876705E-04,   6.1782741E-04,   5.8786554E-04
     +,   5.5883208E-04,   5.3069222E-04,   5.0341850E-04
     +,   4.7699185E-04,   4.5140251E-04,   4.2664571E-04
     +,   4.0271913E-04,   3.7962425E-04,   3.5736538E-04
     +,   3.3594828E-04,   3.1537726E-04,   2.9565566E-04
     +,   2.7678758E-04,   2.5877444E-04,   2.4161434E-04
     +,   2.2530228E-04,   2.0983214E-04,   1.9519306E-04
     +,   1.8137069E-04,   1.6834882E-04,   1.5610812E-04
     +,   1.4462582E-04,   1.3387702E-04,   1.2383547E-04
     +,   1.1447348E-04,   1.0576154E-04,   9.7669326E-05
     +,   9.0167079E-05,   8.3223829E-05,   7.6809731E-05
     +,   7.0894530E-05,   6.5449414E-05,   6.0445487E-05
     +,   5.5855580E-05,   5.1652689E-05,   4.7811507E-05
     +,   4.4307213E-05,   4.1116553E-05,   3.8216971E-05
     +,   3.5587029E-05,   3.3206565E-05,   3.1056137E-05
     +,   2.9117617E-05,   2.7373571E-05,   2.5807813E-05
     +,   2.4404859E-05,   2.3150355E-05,   2.2030679E-05
     +,   2.1033247E-05,   2.0146175E-05,   1.9358549E-05
     +,   1.8660141E-05,   1.8041594E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt85 = Yx/0.149116279069767
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.7549848E-05,   8.1033701E-05
     +,   8.4589221E-05,   8.8209650E-05,   9.1887530E-05
     +,   9.5614843E-05,   9.9382873E-05,   1.0318237E-04
     +,   1.0700350E-04,   1.1083613E-04,   1.1466946E-04
     +,   1.1849244E-04,   1.2229367E-04,   1.2606157E-04
     +,   1.2978437E-04,   1.3345023E-04,   1.3704738E-04
     +,   1.4056408E-04,   1.4398893E-04,   1.4731075E-04
     +,   1.5051883E-04,   1.5360287E-04,   1.5655332E-04
     +,   1.5936134E-04,   1.6201871E-04,   1.6451831E-04
     +,   1.6685395E-04,   1.6902045E-04,   1.7101396E-04
     +,   1.7283161E-04,   1.7447193E-04,   1.7593475E-04
     +,   1.7722133E-04,   1.7833438E-04,   1.7927791E-04
     +,   1.8005747E-04,   1.8068014E-04,   1.8115426E-04
     +,   1.8148981E-04,   1.8169798E-04,   1.8179158E-04
     +,   1.8178446E-04,   1.8169206E-04,   1.8153068E-04
     +,   1.8131793E-04,   1.8107242E-04,   1.8081376E-04
     +,   1.8056227E-04,   1.8033914E-04,   1.8016605E-04
     +,   1.8006528E-04,   1.8005949E-04,   1.8017131E-04
     +,   1.8042375E-04,   1.8083971E-04,   1.8144178E-04
     +,   1.8225209E-04,   1.8329252E-04,   1.8458402E-04
     +,   1.8614664E-04,   1.8799954E-04,   1.9016050E-04
     +,   1.9264575E-04,   1.9547011E-04,   1.9864661E-04
     +,   2.0218588E-04,   2.0609683E-04,   2.1038536E-04
     +,   2.1505557E-04,   2.2010780E-04,   2.2554043E-04
     +,   2.3134779E-04,   2.3752189E-04,   2.4405050E-04
     +,   2.5091865E-04,   2.5810790E-04,   2.6559588E-04
     +,   2.7335685E-04,   2.8136204E-04,   2.8957982E-04
     +,   2.9797462E-04,   3.0650929E-04,   3.1514323E-04
     +,   3.2383503E-04,   3.3254075E-04,   3.4121645E-04
     +,   3.4981666E-04,   3.5829813E-04,   3.6661644E-04
     +,   3.7473073E-04,   3.8260224E-04,   3.9019538E-04
     +,   3.9747902E-04,   4.0442770E-04,   4.1102228E-04
     +,   4.1724989E-04,   4.2310689E-04,   4.2859762E-04
     +,   4.3373692E-04,   4.3855020E-04,   4.4307453E-04
     +,   4.4735908E-04,   4.5146677E-04,   4.5547320E-04
     +,   4.5946930E-04,   4.6356031E-04,   4.6786657E-04
     +,   4.7252307E-04,   4.7768111E-04,   4.8350674E-04
     +,   4.9018109E-04,   4.9790129E-04,   5.0687906E-04
     +,   5.1734335E-04,   5.2953773E-04,   5.4372469E-04
     +,   5.6018279E-04,   5.7921075E-04,   6.0112303E-04
     +,   6.2625308E-04,   6.5494824E-04,   6.8756432E-04
     +,   7.2445953E-04,   7.6599268E-04,   8.1251410E-04
     +,   8.6436013E-04,   9.2186633E-04,   9.8536455E-04
     +,   1.0552171E-03,   1.1318297E-03,   1.2156991E-03
     +,   1.3074201E-03,   1.4077255E-03,   1.5174620E-03
     +,   1.6375824E-03,   1.7690846E-03,   1.9129313E-03
     +,   2.0699902E-03,   2.2409833E-03,   2.4264790E-03
     +,   2.6269192E-03,   2.8427069E-03,   3.0743189E-03
     +,   3.3223536E-03,   3.5874606E-03,   3.8702372E-03
     +,   4.1709645E-03,   4.4893906E-03,   4.8247306E-03
     +,   5.1760394E-03,   5.5428543E-03,   5.9259385E-03
     +,   6.3276072E-03,   6.7510931E-03,   7.1985694E-03
     +,   7.6683103E-03,   8.1523629E-03,   8.6360266E-03
     +,   9.1001159E-03,   9.5256763E-03,   9.8992176E-03
     +,   1.0215672E-02,   1.0477460E-02,   1.0690029E-02
     +,   1.0856071E-02,   1.0971664E-02,   1.1026482E-02
     +,   1.1008330E-02,   1.0909891E-02,   1.0734818E-02
     +,   1.0500271E-02,   1.0234416E-02,   9.9697085E-03
     +,   9.7343726E-03,   9.5459269E-03,   9.4091976E-03
     +,   9.3194833E-03,   9.2683444E-03,   9.2485240E-03
     +,   9.2553217E-03,   9.2843920E-03,   9.3283374E-03
     +,   9.3750842E-03,   9.4093634E-03,   9.4165923E-03
     +,   9.3865637E-03,   9.3149422E-03,   9.2021003E-03
     +,   9.0504475E-03,   8.8622365E-03,   8.6391540E-03
     +,   8.3835283E-03,   8.1000198E-03,   7.7963411E-03
     +,   7.4822647E-03,   7.1673933E-03,   6.8588159E-03
     +,   6.5595978E-03,   6.2690186E-03,   5.9841052E-03
     +,   5.7017496E-03,   5.4204143E-03,   5.1409374E-03
     +,   4.8662927E-03,   4.6006781E-03,   4.3483456E-03
     +,   4.1126818E-03,   3.8957531E-03,   3.6981646E-03
     +,   3.5192966E-03,   3.3576183E-03,   3.2110433E-03
     +,   3.0772020E-03,   2.9536830E-03,   2.8382405E-03
     +,   2.7289544E-03,   2.6243289E-03,   2.5233293E-03
     +,   2.4253782E-03,   2.3302890E-03,   2.2381330E-03
     +,   2.1491419E-03,   2.0636027E-03,   1.9817799E-03
     +,   1.9038722E-03,   1.8300023E-03,   1.7602282E-03
     +,   1.6945591E-03,   1.6329571E-03,   1.5753563E-03
     +,   1.5216640E-03,   1.4717495E-03,   1.4254297E-03
     +,   1.3824598E-03,   1.3425349E-03,   1.3052739E-03
     +,   1.2702362E-03,   1.2369353E-03,   1.2048585E-03
     +,   1.1734873E-03,   1.1423262E-03,   1.1109292E-03
     +,   1.0789171E-03,   1.0459926E-03,   1.0119497E-03
     +,   9.7668206E-04,   9.4017491E-04,   9.0249779E-04
     +,   8.6379325E-04,   8.2426838E-04,   7.8417093E-04
     +,   7.4377732E-04,   7.0338201E-04,   6.6327973E-04
     +,   6.2375196E-04,   5.8506074E-04,   5.4744416E-04
     +,   5.1110843E-04,   4.7622289E-04,   4.4292171E-04
     +,   4.1130715E-04,   3.8144720E-04,   3.5337769E-04
     +,   3.2710691E-04,   3.0262201E-04,   2.7988650E-04
     +,   2.5884737E-04,   2.3943975E-04,   2.2158811E-04
     +,   2.0520817E-04,   1.9021127E-04,   1.7650699E-04
     +,   1.6400396E-04,   1.5261097E-04,   1.4223895E-04
     +,   1.3280295E-04,   1.2422055E-04,   1.1641491E-04
     +,   1.0931287E-04,   1.0284709E-04,   9.6954325E-05
     +,   9.1577240E-05,   8.6662440E-05,   8.2161954E-05
     +,   7.8031626E-05,   7.4232070E-05,   7.0727401E-05
     +,   6.7485445E-05,   6.4477666E-05,   6.1678227E-05
     +,   5.9064532E-05,   5.6616151E-05,   5.4315293E-05
     +,   5.2145999E-05,   5.0094510E-05,   4.8148417E-05
     +,   4.6297129E-05,   4.4531171E-05,   4.2842468E-05
     +,   4.1223833E-05,   3.9669190E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt90 = Yx/0.156116279069767
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8359077E-05,   6.9152600E-05
     +,   6.9884918E-05,   7.0555470E-05,   7.1164039E-05
     +,   7.1710798E-05,   7.2196228E-05,   7.2621180E-05
     +,   7.2986870E-05,   7.3294883E-05,   7.3547126E-05
     +,   7.3745876E-05,   7.3893694E-05,   7.3993520E-05
     +,   7.4048548E-05,   7.4062300E-05,   7.4038551E-05
     +,   7.3981326E-05,   7.3894851E-05,   7.3783609E-05
     +,   7.3652234E-05,   7.3505471E-05,   7.3348281E-05
     +,   7.3185598E-05,   7.3022558E-05,   7.2864212E-05
     +,   7.2715651E-05,   7.2581985E-05,   7.2468232E-05
     +,   7.2379320E-05,   7.2320065E-05,   7.2295137E-05
     +,   7.2309071E-05,   7.2366180E-05,   7.2470561E-05
     +,   7.2626033E-05,   7.2836228E-05,   7.3104449E-05
     +,   7.3433701E-05,   7.3826661E-05,   7.4285766E-05
     +,   7.4813004E-05,   7.5410135E-05,   7.6078504E-05
     +,   7.6819168E-05,   7.7632816E-05,   7.8519799E-05
     +,   7.9480196E-05,   8.0513790E-05,   8.1620048E-05
     +,   8.2798164E-05,   8.4047118E-05,   8.5365740E-05
     +,   8.6752669E-05,   8.8206361E-05,   8.9725276E-05
     +,   9.1307847E-05,   9.2952476E-05,   9.4657713E-05
     +,   9.6422358E-05,   9.8245218E-05,   1.0012567E-04
     +,   1.0206324E-04,   1.0405809E-04,   1.0611107E-04
     +,   1.0822342E-04,   1.1039741E-04,   1.1263591E-04
     +,   1.1494307E-04,   1.1732379E-04,   1.1978438E-04
     +,   1.2233209E-04,   1.2497575E-04,   1.2772526E-04
     +,   1.3059210E-04,   1.3358911E-04,   1.3673048E-04
     +,   1.4003148E-04,   1.4350908E-04,   1.4718121E-04
     +,   1.5106659E-04,   1.5518507E-04,   1.5955663E-04
     +,   1.6420201E-04,   1.6914123E-04,   1.7439459E-04
     +,   1.7998074E-04,   1.8591776E-04,   1.9222115E-04
     +,   1.9890464E-04,   2.0597929E-04,   2.1345221E-04
     +,   2.2132680E-04,   2.2960239E-04,   2.3827399E-04
     +,   2.4733023E-04,   2.5675588E-04,   2.6652846E-04
     +,   2.7662149E-04,   2.8700111E-04,   2.9762968E-04
     +,   3.0846262E-04,   3.1945229E-04,   3.3054562E-04
     +,   3.4168738E-04,   3.5282035E-04,   3.6388537E-04
     +,   3.7482413E-04,   3.8558111E-04,   3.9610412E-04
     +,   4.0634585E-04,   4.1626790E-04,   4.2583965E-04
     +,   4.3504292E-04,   4.4387163E-04,   4.5233496E-04
     +,   4.6045726E-04,   4.6828098E-04,   4.7586576E-04
     +,   4.8328959E-04,   4.9064937E-04,   4.9805915E-04
     +,   5.0565059E-04,   5.1357195E-04,   5.2198675E-04
     +,   5.3107215E-04,   5.4101838E-04,   5.5202574E-04
     +,   5.6430610E-04,   5.7807821E-04,   5.9357058E-04
     +,   6.1101466E-04,   6.3064881E-04,   6.5270904E-04
     +,   6.7743269E-04,   7.0505060E-04,   7.3577929E-04
     +,   7.6981552E-04,   8.0733141E-04,   8.4846193E-04
     +,   8.9329178E-04,   9.4184908E-04,   9.9409360E-04
     +,   1.0499097E-03,   1.1090909E-03,   1.1713401E-03
     +,   1.2362683E-03,   1.3033804E-03,   1.3720862E-03
     +,   1.4417084E-03,   1.5114871E-03,   1.5805921E-03
     +,   1.6481510E-03,   1.7132908E-03,   1.7751901E-03
     +,   1.8331606E-03,   1.8867437E-03,   1.9358603E-03
     +,   1.9809436E-03,   2.0231041E-03,   2.0642637E-03
     +,   2.1072871E-03,   2.1560458E-03,   2.2154443E-03
     +,   2.2914021E-03,   2.3907402E-03,   2.5209638E-03
     +,   2.6899020E-03,   2.9051092E-03,   3.1729371E-03
     +,   3.4972546E-03,   3.8778861E-03,   4.3089902E-03
     +,   4.7777384E-03,   5.2640662E-03,   5.7424037E-03
     +,   6.1858688E-03,   6.5729995E-03,   6.8959016E-03
     +,   7.1673160E-03,   7.4229958E-03,   7.7166841E-03
     +,   8.1070317E-03,   8.6398926E-03,   9.3326056E-03
     +,   1.0167015E-02,   1.1093983E-02,   1.2046980E-02
     +,   1.2958248E-02,   1.3772872E-02,   1.4458581E-02
     +,   1.5008658E-02,   1.5436155E-02,   1.5760081E-02
     +,   1.5991023E-02,   1.6128037E-02,   1.6171291E-02
     +,   1.6139075E-02,   1.6069751E-02,   1.6000474E-02
     +,   1.5936757E-02,   1.5838740E-02,   1.5638329E-02
     +,   1.5275741E-02,   1.4729197E-02,   1.4019417E-02
     +,   1.3193608E-02,   1.2306166E-02,   1.1408368E-02
     +,   1.0545975E-02,   9.7573241E-03,   9.0687498E-03
     +,   8.4901918E-03,   8.0153402E-03,   7.6263291E-03
     +,   7.3003722E-03,   7.0152092E-03,   6.7521948E-03
     +,   6.4973971E-03,   6.2413225E-03,   5.9782071E-03
     +,   5.7056048E-03,   5.4242006E-03,   5.1375641E-03
     +,   4.8514586E-03,   4.5726122E-03,   4.3072305E-03
     +,   4.0596663E-03,   3.8316762E-03,   3.6224551E-03
     +,   3.4292294E-03,   3.2481174E-03,   3.0750062E-03
     +,   2.9062643E-03,   2.7392069E-03,   2.5722655E-03
     +,   2.4050204E-03,   2.2380641E-03,   2.0727599E-03
     +,   1.9109290E-03,   1.7545640E-03,   1.6055603E-03
     +,   1.4654995E-03,   1.3355089E-03,   1.2162265E-03
     +,   1.1078292E-03,   1.0100933E-03,   9.2248461E-04
     +,   8.4426632E-04,   7.7459513E-04,   7.1258168E-04
     +,   6.5734994E-04,   6.0807553E-04,   5.6399987E-04
     +,   5.2443554E-04,   4.8877089E-04,   4.5646794E-04
     +,   4.2705674E-04,   4.0012694E-04,   3.7532605E-04
     +,   3.5235597E-04,   3.3096672E-04,   3.1095039E-04
     +,   2.9213802E-04,   2.7439641E-04,   2.5761910E-04
     +,   2.4172354E-04,   2.2664726E-04,   2.1234242E-04
     +,   1.9877093E-04,   1.8590258E-04,   1.7371312E-04
     +,   1.6218124E-04,   1.5128622E-04,   1.4100816E-04
     +,   1.3132798E-04,   1.2222465E-04,   1.1367777E-04
     +,   1.0566501E-04,   9.8164499E-05,   9.1152862E-05
     +,   8.4607324E-05,   7.8504156E-05,   7.2820461E-05
     +,   6.7532827E-05,   6.2618936E-05,   5.8056507E-05
     +,   5.3823947E-05,   4.9900766E-05,   4.6266818E-05
     +,   4.2903288E-05,   3.9791797E-05,   3.6915353E-05
     +,   3.4257464E-05,   3.1802945E-05,   2.9537176E-05
     +,   2.7446726E-05,   2.5518753E-05,   2.3741475E-05
     +,   2.2103653E-05,   2.0595025E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_htt95 = Yx/0.16625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.5529507E-05,   8.7408662E-05
     +,   8.9256791E-05,   9.1071990E-05,   9.2852599E-05
     +,   9.4597293E-05,   9.6305172E-05,   9.7975601E-05
     +,   9.9608391E-05,   1.0120380E-04,   1.0276247E-04
     +,   1.0428554E-04,   1.0577458E-04,   1.0723162E-04
     +,   1.0865917E-04,   1.1006016E-04,   1.1143805E-04
     +,   1.1279677E-04,   1.1414057E-04,   1.1547421E-04
     +,   1.1680285E-04,   1.1813194E-04,   1.1946724E-04
     +,   1.2081494E-04,   1.2218130E-04,   1.2357283E-04
     +,   1.2499621E-04,   1.2645812E-04,   1.2796522E-04
     +,   1.2952423E-04,   1.3114161E-04,   1.3282361E-04
     +,   1.3457621E-04,   1.3640510E-04,   1.3831549E-04
     +,   1.4031191E-04,   1.4239860E-04,   1.4457881E-04
     +,   1.4685531E-04,   1.4922989E-04,   1.5170361E-04
     +,   1.5427660E-04,   1.5694794E-04,   1.5971583E-04
     +,   1.6257743E-04,   1.6552887E-04,   1.6856531E-04
     +,   1.7168077E-04,   1.7486847E-04,   1.7812043E-04
     +,   1.8142801E-04,   1.8478167E-04,   1.8817095E-04
     +,   1.9158496E-04,   1.9501186E-04,   1.9843987E-04
     +,   2.0185646E-04,   2.0524896E-04,   2.0860473E-04
     +,   2.1191107E-04,   2.1515568E-04,   2.1832655E-04
     +,   2.2141202E-04,   2.2440140E-04,   2.2728476E-04
     +,   2.3005293E-04,   2.3269818E-04,   2.3521377E-04
     +,   2.3759446E-04,   2.3983649E-04,   2.4193760E-04
     +,   2.4389717E-04,   2.4571631E-04,   2.4739784E-04
     +,   2.4894645E-04,   2.5036835E-04,   2.5167174E-04
     +,   2.5286613E-04,   2.5396299E-04,   2.5497528E-04
     +,   2.5591717E-04,   2.5680414E-04,   2.5765283E-04
     +,   2.5848066E-04,   2.5930608E-04,   2.6014779E-04
     +,   2.6102475E-04,   2.6195630E-04,   2.6296123E-04
     +,   2.6405786E-04,   2.6526430E-04,   2.6659726E-04
     +,   2.6807241E-04,   2.6970377E-04,   2.7150434E-04
     +,   2.7348447E-04,   2.7565294E-04,   2.7801600E-04
     +,   2.8057804E-04,   2.8334046E-04,   2.8630235E-04
     +,   2.8946035E-04,   2.9280828E-04,   2.9633779E-04
     +,   3.0003759E-04,   3.0389492E-04,   3.0789408E-04
     +,   3.1201777E-04,   3.1624714E-04,   3.2056175E-04
     +,   3.2494025E-04,   3.2936054E-04,   3.3379992E-04
     +,   3.3823604E-04,   3.4264679E-04,   3.4701082E-04
     +,   3.5130841E-04,   3.5552122E-04,   3.5963304E-04
     +,   3.6363033E-04,   3.6750265E-04,   3.7124282E-04
     +,   3.7484700E-04,   3.7831618E-04,   3.8165561E-04
     +,   3.8487508E-04,   3.8798986E-04,   3.9102024E-04
     +,   3.9399244E-04,   3.9693792E-04,   3.9989431E-04
     +,   4.0290455E-04,   4.0601770E-04,   4.0928752E-04
     +,   4.1277354E-04,   4.1653911E-04,   4.2065166E-04
     +,   4.2518161E-04,   4.3020077E-04,   4.3578274E-04
     +,   4.4199949E-04,   4.4892082E-04,   4.5661352E-04
     +,   4.6513850E-04,   4.7454864E-04,   4.8488946E-04
     +,   4.9619569E-04,   5.0848915E-04,   5.2177941E-04
     +,   5.3606211E-04,   5.5131927E-04,   5.6751748E-04
     +,   5.8461004E-04,   6.0253829E-04,   6.2123325E-04
     +,   6.4061786E-04,   6.6060782E-04,   6.8112230E-04
     +,   7.0208247E-04,   7.2341633E-04,   7.4507075E-04
     +,   7.6701207E-04,   7.8923476E-04,   8.1176736E-04
     +,   8.3468104E-04,   8.5809664E-04,   8.8218792E-04
     +,   9.0719044E-04,   9.3340967E-04,   9.6122565E-04
     +,   9.9110161E-04,   1.0235937E-03,   1.0593684E-03
     +,   1.0992186E-03,   1.1440860E-03,   1.1951058E-03
     +,   1.2536469E-03,   1.3213649E-03,   1.4002664E-03
     +,   1.4927716E-03,   1.6017751E-03,   1.7306734E-03
     +,   1.8834039E-03,   2.0644704E-03,   2.2789354E-03
     +,   2.5323438E-03,   2.8305217E-03,   3.1791378E-03
     +,   3.5829081E-03,   4.0445202E-03,   4.5638806E-03
     +,   5.1380098E-03,   5.7621729E-03,   6.4321784E-03
     +,   7.1471659E-03,   7.9124924E-03,   8.7436642E-03
     +,   9.6720131E-03,   1.0748833E-02,   1.2038652E-02
     +,   1.3594688E-02,   1.5424713E-02,   1.7475564E-02
     +,   1.9656345E-02,   2.1884035E-02,   2.4113318E-02
     +,   2.6347313E-02,   2.8655956E-02,   3.1167140E-02
     +,   3.3963270E-02,   3.6953658E-02,   3.9879374E-02
     +,   4.2432435E-02,   4.4350162E-02,   4.5465544E-02
     +,   4.5749146E-02,   4.5326415E-02,   4.4433136E-02
     +,   4.3308385E-02,   4.2085141E-02,   4.0732734E-02
     +,   3.9093170E-02,   3.7041981E-02,   3.4645390E-02
     +,   3.2118332E-02,   2.9640729E-02,   2.7256789E-02
     +,   2.4922956E-02,   2.2601603E-02,   2.0312589E-02
     +,   1.8127643E-02,   1.6124390E-02,   1.4337229E-02
     +,   1.2743498E-02,   1.1292730E-02,   9.9474704E-03
     +,   8.7032206E-03,   7.5792973E-03,   6.5969806E-03
     +,   5.7636173E-03,   5.0694905E-03,   4.4931034E-03
     +,   4.0085558E-03,   3.5912213E-03,   3.2210511E-03
     +,   2.8839062E-03,   2.5714079E-03,   2.2798316E-03
     +,   2.0085175E-03,   1.7582823E-03,   1.5301229E-03
     +,   1.3245409E-03,   1.1413255E-03,   9.7960478E-04
     +,   8.3804061E-04,   7.1503944E-04,   6.0890609E-04
     +,   5.1792443E-04,   4.4039992E-04,   3.7469636E-04
     +,   3.1926236E-04,   2.7264564E-04,   2.3351268E-04
     +,   2.0066799E-04,   1.7306567E-04,   1.4980449E-04
     +,   1.3012537E-04,   1.1340044E-04,   9.9115692E-05
     +,   8.6853550E-05,   7.6277407E-05,   6.7116620E-05
     +,   5.9152335E-05,   5.2205953E-05,   4.6130990E-05
     +,   4.0806495E-05,   3.6130492E-05,   3.2017382E-05
     +,   2.8393713E-05,   2.5196990E-05,   2.2372991E-05
     +,   1.9875271E-05,   1.7663300E-05,   1.5702253E-05
     +,   1.3961661E-05,   1.2415304E-05,   1.1040224E-05
     +,   9.8164583E-06,   8.7267135E-06,   7.7557452E-06
     +,   6.8903273E-06,   6.1187466E-06,   5.4307884E-06
     +,   4.8173488E-06,   4.2704551E-06,   3.7829616E-06
     +,   3.3485778E-06,   2.9616424E-06,   2.6171508E-06
     +,   2.3105888E-06,   2.0379548E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz100 = Yx/0.302191489361702
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.7052472E-05,   5.8100752E-05
     +,   5.9153299E-05,   6.0212984E-05,   6.1283070E-05
     +,   6.2367217E-05,   6.3469473E-05,   6.4594286E-05
     +,   6.5746499E-05,   6.6931279E-05,   6.8154208E-05
     +,   6.9421199E-05,   7.0738432E-05,   7.2112365E-05
     +,   7.3549716E-05,   7.5057338E-05,   7.6642238E-05
     +,   7.8311437E-05,   8.0072001E-05,   8.1930899E-05
     +,   8.3894804E-05,   8.5970300E-05,   8.8163433E-05
     +,   9.0480062E-05,   9.2925024E-05,   9.5502975E-05
     +,   9.8217570E-05,   1.0107156E-04,   1.0406674E-04
     +,   1.0720388E-04,   1.1048269E-04,   1.1390143E-04
     +,   1.1745720E-04,   1.2114570E-04,   1.2496131E-04
     +,   1.2889688E-04,   1.3294400E-04,   1.3709255E-04
     +,   1.4133153E-04,   1.4564805E-04,   1.5002850E-04
     +,   1.5445788E-04,   1.5892020E-04,   1.6339867E-04
     +,   1.6787584E-04,   1.7233363E-04,   1.7675389E-04
     +,   1.8111804E-04,   1.8540808E-04,   1.8960604E-04
     +,   1.9369481E-04,   1.9765785E-04,   2.0148006E-04
     +,   2.0514768E-04,   2.0864795E-04,   2.1197055E-04
     +,   2.1510677E-04,   2.1804993E-04,   2.2079566E-04
     +,   2.2334194E-04,   2.2568907E-04,   2.2783986E-04
     +,   2.2979923E-04,   2.3157484E-04,   2.3317660E-04
     +,   2.3461634E-04,   2.3590794E-04,   2.3706742E-04
     +,   2.3811200E-04,   2.3906048E-04,   2.3993276E-04
     +,   2.4074943E-04,   2.4153147E-04,   2.4230042E-04
     +,   2.4307726E-04,   2.4388266E-04,   2.4473653E-04
     +,   2.4565746E-04,   2.4666302E-04,   2.4776877E-04
     +,   2.4898865E-04,   2.5033427E-04,   2.5181513E-04
     +,   2.5343819E-04,   2.5520788E-04,   2.5712617E-04
     +,   2.5919208E-04,   2.6140266E-04,   2.6375180E-04
     +,   2.6623119E-04,   2.6883051E-04,   2.7153693E-04
     +,   2.7433582E-04,   2.7721102E-04,   2.8014489E-04
     +,   2.8311840E-04,   2.8611222E-04,   2.8910590E-04
     +,   2.9207912E-04,   2.9501136E-04,   2.9788289E-04
     +,   3.0067388E-04,   3.0336634E-04,   3.0594261E-04
     +,   3.0838710E-04,   3.1068551E-04,   3.1282561E-04
     +,   3.1479643E-04,   3.1658995E-04,   3.1819995E-04
     +,   3.1962211E-04,   3.2085480E-04,   3.2189849E-04
     +,   3.2275566E-04,   3.2343090E-04,   3.2393090E-04
     +,   3.2426426E-04,   3.2444109E-04,   3.2447334E-04
     +,   3.2437406E-04,   3.2415747E-04,   3.2383908E-04
     +,   3.2343497E-04,   3.2296174E-04,   3.2243656E-04
     +,   3.2187672E-04,   3.2129957E-04,   3.2072226E-04
     +,   3.2016178E-04,   3.1963488E-04,   3.1915761E-04
     +,   3.1874556E-04,   3.1841412E-04,   3.1817751E-04
     +,   3.1804995E-04,   3.1804483E-04,   3.1817539E-04
     +,   3.1845405E-04,   3.1889367E-04,   3.1950636E-04
     +,   3.2030442E-04,   3.2130035E-04,   3.2250708E-04
     +,   3.2393780E-04,   3.2560618E-04,   3.2752680E-04
     +,   3.2971514E-04,   3.3218713E-04,   3.3496073E-04
     +,   3.3805400E-04,   3.4148694E-04,   3.4528068E-04
     +,   3.4945781E-04,   3.5404228E-04,   3.5906004E-04
     +,   3.6453840E-04,   3.7050614E-04,   3.7699493E-04
     +,   3.8403834E-04,   3.9167135E-04,   3.9993273E-04
     +,   4.0886385E-04,   4.1850880E-04,   4.2891473E-04
     +,   4.4013327E-04,   4.5221933E-04,   4.6523160E-04
     +,   4.7923182E-04,   4.9428694E-04,   5.1046681E-04
     +,   5.2784465E-04,   5.4649630E-04,   5.6650257E-04
     +,   5.8794854E-04,   6.1092258E-04,   6.3552306E-04
     +,   6.6185935E-04,   6.9005520E-04,   7.2025647E-04
     +,   7.5264066E-04,   7.8742736E-04,   8.2488242E-04
     +,   8.6533470E-04,   9.0918812E-04,   9.5692580E-04
     +,   1.0091173E-03,   1.0664193E-03,   1.1295789E-03
     +,   1.1994236E-03,   1.2768439E-03,   1.3627952E-03
     +,   1.4582821E-03,   1.5643472E-03,   1.6820739E-03
     +,   1.8126142E-03,   1.9572116E-03,   2.1172592E-03
     +,   2.2943765E-03,   2.4905612E-03,   2.7082856E-03
     +,   2.9505796E-03,   3.2210248E-03,   3.5235651E-03
     +,   3.8620434E-03,   4.2394437E-03,   4.6570823E-03
     +,   5.1137093E-03,   5.6048124E-03,   6.1224443E-03
     +,   6.6558085E-03,   7.1927230E-03,   7.7224597E-03
     +,   8.2398271E-03,   8.7495018E-03,   9.2688827E-03
     +,   9.8279556E-03,   1.0466553E-02,   1.1230549E-02
     +,   1.2167698E-02,   1.3321691E-02,   1.4724292E-02
     +,   1.6386885E-02,   1.8294923E-02,   2.0406978E-02
     +,   2.2664232E-02,   2.5026897E-02,   2.7537059E-02
     +,   3.0342763E-02,   3.3596292E-02,   3.7286460E-02
     +,   4.1224107E-02,   4.5227531E-02,   4.9211808E-02
     +,   5.2956272E-02,   5.5791341E-02,   5.6798249E-02
     +,   5.5690467E-02,   5.3383339E-02,   5.1221583E-02
     +,   4.9656700E-02,   4.7988500E-02,   4.5268968E-02
     +,   4.1173950E-02,   3.6113702E-02,   3.0815162E-02
     +,   2.5874190E-02,   2.1547640E-02,   1.7807359E-02
     +,   1.4528066E-02,   1.1635106E-02,   9.1295410E-03
     +,   7.0352159E-03,   5.3481860E-03,   4.0264088E-03
     +,   3.0073207E-03,   2.2282181E-03,   1.6365512E-03
     +,   1.1909980E-03,   8.5900957E-04,   6.1444083E-04
     +,   4.3621165E-04,   3.0759268E-04,   2.1564234E-04
     +,   1.5057261E-04,   1.0506612E-04,   7.3661082E-05
     +,   5.2292660E-05,   3.7955619E-05,   2.8456992E-05
     +,   2.2228662E-05,   1.8176337E-05,   1.5554120E-05
     +,   1.3863543E-05,   1.2776357E-05,   1.2078404E-05
     +,   1.1630407E-05,   1.1341617E-05,   1.1152909E-05
     +,   1.1025713E-05,   1.0935029E-05,   1.0864786E-05
     +,   1.0804816E-05,   1.0748818E-05,   1.0692986E-05
     +,   1.0635093E-05,   1.0573891E-05,   1.0508721E-05
     +,   1.0439272E-05,   1.0365438E-05,   1.0287220E-05
     +,   1.0204685E-05,   1.0117929E-05,   1.0027080E-05
     +,   9.9322606E-06,   9.8336222E-06,   9.7313014E-06
     +,   9.6254553E-06,   9.5162331E-06,   9.4037978E-06
     +,   9.2883001E-06,   9.1699130E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz105 = Yx/0.3058125
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1169881E-05,   9.3397677E-05
     +,   9.5620882E-05,   9.7837939E-05,   1.0004730E-04
     +,   1.0224760E-04,   1.0443750E-04,   1.0661572E-04
     +,   1.0878114E-04,   1.1093277E-04,   1.1306963E-04
     +,   1.1519087E-04,   1.1729577E-04,   1.1938373E-04
     +,   1.2145418E-04,   1.2350672E-04,   1.2554105E-04
     +,   1.2755691E-04,   1.2955425E-04,   1.3153306E-04
     +,   1.3349348E-04,   1.3543561E-04,   1.3735991E-04
     +,   1.3926675E-04,   1.4115660E-04,   1.4303025E-04
     +,   1.4488827E-04,   1.4673162E-04,   1.4856127E-04
     +,   1.5037823E-04,   1.5218377E-04,   1.5397918E-04
     +,   1.5576597E-04,   1.5754566E-04,   1.5932001E-04
     +,   1.6109076E-04,   1.6286012E-04,   1.6462998E-04
     +,   1.6640290E-04,   1.6818105E-04,   1.6996723E-04
     +,   1.7176410E-04,   1.7357471E-04,   1.7540193E-04
     +,   1.7724911E-04,   1.7911957E-04,   1.8101685E-04
     +,   1.8294442E-04,   1.8490614E-04,   1.8690575E-04
     +,   1.8894712E-04,   1.9103415E-04,   1.9317068E-04
     +,   1.9536068E-04,   1.9760798E-04,   1.9991628E-04
     +,   2.0228916E-04,   2.0472999E-04,   2.0724200E-04
     +,   2.0982795E-04,   2.1249043E-04,   2.1523162E-04
     +,   2.1805304E-04,   2.2095608E-04,   2.2394140E-04
     +,   2.2700884E-04,   2.3015813E-04,   2.3338775E-04
     +,   2.3669589E-04,   2.4007981E-04,   2.4353612E-04
     +,   2.4706050E-04,   2.5064810E-04,   2.5429286E-04
     +,   2.5798846E-04,   2.6172778E-04,   2.6550266E-04
     +,   2.6930444E-04,   2.7312405E-04,   2.7695176E-04
     +,   2.8077714E-04,   2.8458983E-04,   2.8837871E-04
     +,   2.9213290E-04,   2.9584099E-04,   2.9949177E-04
     +,   3.0307405E-04,   3.0657696E-04,   3.0998979E-04
     +,   3.1330239E-04,   3.1650494E-04,   3.1958832E-04
     +,   3.2254396E-04,   3.2536418E-04,   3.2804208E-04
     +,   3.3057164E-04,   3.3294785E-04,   3.3516646E-04
     +,   3.3722428E-04,   3.3911946E-04,   3.4085079E-04
     +,   3.4241806E-04,   3.4382218E-04,   3.4506494E-04
     +,   3.4614932E-04,   3.4707889E-04,   3.4785789E-04
     +,   3.4849162E-04,   3.4898584E-04,   3.4934701E-04
     +,   3.4958226E-04,   3.4969862E-04,   3.4970409E-04
     +,   3.4960659E-04,   3.4941421E-04,   3.4913531E-04
     +,   3.4877841E-04,   3.4835131E-04,   3.4786251E-04
     +,   3.4732005E-04,   3.4673134E-04,   3.4610415E-04
     +,   3.4544550E-04,   3.4476223E-04,   3.4406068E-04
     +,   3.4334662E-04,   3.4262604E-04,   3.4190406E-04
     +,   3.4118549E-04,   3.4047477E-04,   3.3977616E-04
     +,   3.3909339E-04,   3.3843014E-04,   3.3779009E-04
     +,   3.3717658E-04,   3.3659342E-04,   3.3604409E-04
     +,   3.3553282E-04,   3.3506419E-04,   3.3464350E-04
     +,   3.3427644E-04,   3.3397070E-04,   3.3373447E-04
     +,   3.3357801E-04,   3.3351331E-04,   3.3355458E-04
     +,   3.3371846E-04,   3.3402466E-04,   3.3449617E-04
     +,   3.3515936E-04,   3.3604447E-04,   3.3718624E-04
     +,   3.3862318E-04,   3.4039930E-04,   3.4256297E-04
     +,   3.4516686E-04,   3.4826886E-04,   3.5193030E-04
     +,   3.5621706E-04,   3.6119740E-04,   3.6694211E-04
     +,   3.7352322E-04,   3.8101256E-04,   3.8947977E-04
     +,   3.9899311E-04,   4.0961633E-04,   4.2140711E-04
     +,   4.3441763E-04,   4.4869314E-04,   4.6427248E-04
     +,   4.8118821E-04,   4.9946713E-04,   5.1913515E-04
     +,   5.4021960E-04,   5.6275021E-04,   5.8676803E-04
     +,   6.1233103E-04,   6.3951552E-04,   6.6842610E-04
     +,   6.9920206E-04,   7.3202414E-04,   7.6711609E-04
     +,   8.0475252E-04,   8.4526447E-04,   8.8904152E-04
     +,   9.3652902E-04,   9.8823011E-04,   1.0447053E-03
     +,   1.1065661E-03,   1.1744560E-03,   1.2490466E-03
     +,   1.3310169E-03,   1.4210201E-03,   1.5196607E-03
     +,   1.6274672E-03,   1.7448614E-03,   1.8721201E-03
     +,   2.0093550E-03,   2.1565154E-03,   2.3133734E-03
     +,   2.4795227E-03,   2.6543941E-03,   2.8372970E-03
     +,   3.0274731E-03,   3.2241503E-03,   3.4267753E-03
     +,   3.6352393E-03,   3.8502456E-03,   4.0737269E-03
     +,   4.3092123E-03,   4.5619621E-03,   4.8387046E-03
     +,   5.1469048E-03,   5.4936847E-03,   5.8846530E-03
     +,   6.3233362E-03,   6.8119401E-03,   7.3537580E-03
     +,   7.9565719E-03,   8.6349817E-03,   9.4085084E-03
     +,   1.0292540E-02,   1.1283447E-02,   1.2346489E-02
     +,   1.3419924E-02,   1.4443876E-02,   1.5403487E-02
     +,   1.6356133E-02,   1.7413901E-02,   1.8686416E-02
     +,   2.0226995E-02,   2.2020882E-02,   2.4012689E-02
     +,   2.6148025E-02,   2.8428420E-02,   3.0974792E-02
     +,   3.4024581E-02,   3.7769467E-02,   4.2102344E-02
     +,   4.6551507E-02,   5.0573550E-02,   5.3945061E-02
     +,   5.6782991E-02,   5.9114836E-02,   6.0467232E-02
     +,   5.9978649E-02,   5.6995321E-02,   5.1582668E-02
     +,   4.4494051E-02,   3.6736857E-02,   2.9183699E-02
     +,   2.2433171E-02,   1.6806845E-02,   1.2375888E-02
     +,   9.0229101E-03,   6.5414049E-03,   4.7234776E-03
     +,   3.3998040E-03,   2.4418677E-03,   1.7523570E-03
     +,   1.2574997E-03,   9.0248877E-04,   6.4780767E-04
     +,   4.6548527E-04,   3.3562223E-04,   2.4370715E-04
     +,   1.7893502E-04,   1.3322094E-04,   1.0061546E-04
     +,   7.6894947E-05,   5.9199145E-05,   4.5681849E-05
     +,   3.5191330E-05,   2.7010621E-05,   2.0670039E-05
     +,   1.5828336E-05,   1.2207012E-05,   9.5640344E-06
     +,   7.6852903E-06,   6.3858993E-06,   5.5115765E-06
     +,   4.9391542E-06,   4.5741940E-06,   4.3473028E-06
     +,   4.2093629E-06,   4.1269068E-06,   4.0778946E-06
     +,   4.0482964E-06,   4.0294699E-06,   4.0162486E-06
     +,   4.0056398E-06,   3.9959609E-06,   3.9862934E-06
     +,   3.9761512E-06,   3.9652891E-06,   3.9535835E-06
     +,   3.9409824E-06,   3.9274623E-06,   3.9130223E-06
     +,   3.8976632E-06,   3.8813964E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz107 = Yx/0.29668085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3741360E-04,   1.4331473E-04
     +,   1.4941751E-04,   1.5572384E-04,   1.6223472E-04
     +,   1.6895021E-04,   1.7586933E-04,   1.8298984E-04
     +,   1.9030803E-04,   1.9781926E-04,   2.0551682E-04
     +,   2.1339253E-04,   2.2143662E-04,   2.2963731E-04
     +,   2.3798110E-04,   2.4645260E-04,   2.5503454E-04
     +,   2.6370760E-04,   2.7245088E-04,   2.8124143E-04
     +,   2.9005486E-04,   2.9886494E-04,   3.0764387E-04
     +,   3.1636350E-04,   3.2499325E-04,   3.3350309E-04
     +,   3.4186151E-04,   3.5003727E-04,   3.5799894E-04
     +,   3.6571550E-04,   3.7315657E-04,   3.8029294E-04
     +,   3.8709686E-04,   3.9354217E-04,   3.9960450E-04
     +,   4.0526278E-04,   4.1049748E-04,   4.1529268E-04
     +,   4.1963591E-04,   4.2351717E-04,   4.2693136E-04
     +,   4.2987603E-04,   4.3235329E-04,   4.3436844E-04
     +,   4.3593152E-04,   4.3705525E-04,   4.3775767E-04
     +,   4.3805840E-04,   4.3798200E-04,   4.3755546E-04
     +,   4.3680877E-04,   4.3577395E-04,   4.3448585E-04
     +,   4.3298042E-04,   4.3129563E-04,   4.2946966E-04
     +,   4.2754147E-04,   4.2555013E-04,   4.2353428E-04
     +,   4.2153164E-04,   4.1957875E-04,   4.1771075E-04
     +,   4.1596053E-04,   4.1435903E-04,   4.1293411E-04
     +,   4.1171198E-04,   4.1071427E-04,   4.0996075E-04
     +,   4.0946729E-04,   4.0924689E-04,   4.0930894E-04
     +,   4.0965990E-04,   4.1030292E-04,   4.1123771E-04
     +,   4.1246158E-04,   4.1396928E-04,   4.1575279E-04
     +,   4.1780190E-04,   4.2010445E-04,   4.2264699E-04
     +,   4.2541433E-04,   4.2839081E-04,   4.3155931E-04
     +,   4.3490285E-04,   4.3840401E-04,   4.4204568E-04
     +,   4.4581079E-04,   4.4968334E-04,   4.5364760E-04
     +,   4.5768890E-04,   4.6179374E-04,   4.6594976E-04
     +,   4.7014529E-04,   4.7437075E-04,   4.7861689E-04
     +,   4.8287597E-04,   4.8714178E-04,   4.9140764E-04
     +,   4.9566984E-04,   4.9992342E-04,   5.0416542E-04
     +,   5.0839206E-04,   5.1260111E-04,   5.1678933E-04
     +,   5.2095402E-04,   5.2509207E-04,   5.2920019E-04
     +,   5.3327414E-04,   5.3730968E-04,   5.4130162E-04
     +,   5.4524443E-04,   5.4913171E-04,   5.5295648E-04
     +,   5.5671053E-04,   5.6038611E-04,   5.6397525E-04
     +,   5.6746794E-04,   5.7085638E-04,   5.7413150E-04
     +,   5.7728513E-04,   5.8030919E-04,   5.8319722E-04
     +,   5.8594340E-04,   5.8854360E-04,   5.9099513E-04
     +,   5.9329724E-04,   5.9545180E-04,   5.9746281E-04
     +,   5.9933710E-04,   6.0108484E-04,   6.0271891E-04
     +,   6.0425571E-04,   6.0571468E-04,   6.0711912E-04
     +,   6.0849625E-04,   6.0987554E-04,   6.1129179E-04
     +,   6.1278121E-04,   6.1438471E-04,   6.1614515E-04
     +,   6.1810808E-04,   6.2032224E-04,   6.2283722E-04
     +,   6.2570506E-04,   6.2897848E-04,   6.3271029E-04
     +,   6.3695421E-04,   6.4176350E-04,   6.4718944E-04
     +,   6.5328274E-04,   6.6009309E-04,   6.6766673E-04
     +,   6.7604810E-04,   6.8528054E-04,   6.9540419E-04
     +,   7.0645835E-04,   7.1847934E-04,   7.3150522E-04
     +,   7.4557326E-04,   7.6072180E-04,   7.7699177E-04
     +,   7.9442834E-04,   8.1307866E-04,   8.3299517E-04
     +,   8.5423468E-04,   8.7686157E-04,   9.0093911E-04
     +,   9.2653307E-04,   9.5371006E-04,   9.8253274E-04
     +,   1.0130542E-03,   1.0453142E-03,   1.0793393E-03
     +,   1.1151352E-03,   1.1526791E-03,   1.1919262E-03
     +,   1.2328065E-03,   1.2752205E-03,   1.3190546E-03
     +,   1.3641875E-03,   1.4105055E-03,   1.4579138E-03
     +,   1.5063667E-03,   1.5558925E-03,   1.6066175E-03
     +,   1.6587925E-03,   1.7128204E-03,   1.7692763E-03
     +,   1.8289189E-03,   1.8926882E-03,   1.9617034E-03
     +,   2.0372386E-03,   2.1206781E-03,   2.2134695E-03
     +,   2.3170724E-03,   2.4328849E-03,   2.5621615E-03
     +,   2.7059577E-03,   2.8650772E-03,   3.0400525E-03
     +,   3.2311270E-03,   3.4383123E-03,   3.6615026E-03
     +,   3.9005824E-03,   4.1555329E-03,   4.4266032E-03
     +,   4.7142920E-03,   5.0192545E-03,   5.3420407E-03
     +,   5.6827730E-03,   6.0407650E-03,   6.4143487E-03
     +,   6.8011289E-03,   7.1988525E-03,   7.6067224E-03
     +,   8.0270581E-03,   8.4668621E-03,   8.9387270E-03
     +,   9.4603775E-03,   1.0052480E-02,   1.0735017E-02
     +,   1.1522283E-02,   1.2418116E-02,   1.3413850E-02
     +,   1.4490775E-02,   1.5627353E-02,   1.6808044E-02
     +,   1.8028641E-02,   1.9293459E-02,   2.0605307E-02
     +,   2.1955324E-02,   2.3320179E-02,   2.4667054E-02
     +,   2.5960825E-02,   2.7170027E-02,   2.8276246E-02
     +,   2.9290551E-02,   3.0269440E-02,   3.1308096E-02
     +,   3.2496713E-02,   3.3858936E-02,   3.5314921E-02
     +,   3.6696315E-02,   3.7798394E-02,   3.8427539E-02
     +,   3.8421743E-02,   3.7656344E-02,   3.6059860E-02
     +,   3.3642687E-02,   3.0517470E-02,   2.6887821E-02
     +,   2.3008021E-02,   1.9132286E-02,   1.5475548E-02
     +,   1.2194010E-02,   9.3823392E-03,   7.0774728E-03
     +,   5.2657933E-03,   3.8944392E-03,   2.8870394E-03
     +,   2.1604844E-03,   1.6384246E-03,   1.2590830E-03
     +,   9.7727473E-04,   7.6246919E-04,   5.9514306E-04
     +,   4.6316686E-04,   3.5889121E-04,   2.7712641E-04
     +,   2.1392477E-04,   1.6595986E-04,   1.3027036E-04
     +,   1.0420097E-04,   8.5429798E-05,   7.2007853E-05
     +,   6.2372070E-05,   5.5324112E-05,   4.9989769E-05
     +,   4.5759825E-05,   4.2231248E-05,   3.9150305E-05
     +,   3.6366597E-05,   3.3795965E-05,   3.1394829E-05
     +,   2.9141755E-05,   2.7026792E-05,   2.5044375E-05
     +,   2.3190112E-05,   2.1459391E-05,   1.9846506E-05
     +,   1.8345178E-05,   1.6948443E-05,   1.5649381E-05
     +,   1.4441051E-05,   1.3317038E-05,   1.2271251E-05
     +,   1.1298286E-05,   1.0393129E-05,   9.5513824E-06
     +,   8.7689587E-06,   8.0422351E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz110 = Yx/0.27568085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9554528E-04,   2.0311811E-04
     +,   2.1090155E-04,   2.1890081E-04,   2.2712095E-04
     +,   2.3556688E-04,   2.4424354E-04,   2.5315542E-04
     +,   2.6230651E-04,   2.7170105E-04,   2.8134207E-04
     +,   2.9123249E-04,   3.0137447E-04,   3.1176928E-04
     +,   3.2241747E-04,   3.3331913E-04,   3.4447256E-04
     +,   3.5587582E-04,   3.6752541E-04,   3.7941695E-04
     +,   3.9154451E-04,   4.0390113E-04,   4.1647782E-04
     +,   4.2926581E-04,   4.4225284E-04,   4.5542684E-04
     +,   4.6877278E-04,   4.8227556E-04,   4.9591716E-04
     +,   5.0967879E-04,   5.2353932E-04,   5.3747674E-04
     +,   5.5146724E-04,   5.6548428E-04,   5.7950174E-04
     +,   5.9348979E-04,   6.0741830E-04,   6.2125496E-04
     +,   6.3496688E-04,   6.4851833E-04,   6.6187343E-04
     +,   6.7499519E-04,   6.8784406E-04,   7.0038094E-04
     +,   7.1256526E-04,   7.2435639E-04,   7.3571311E-04
     +,   7.4659399E-04,   7.5695763E-04,   7.6676306E-04
     +,   7.7597162E-04,   7.8454305E-04,   7.9244107E-04
     +,   7.9963059E-04,   8.0607837E-04,   8.1175490E-04
     +,   8.1663323E-04,   8.2068966E-04,   8.2390587E-04
     +,   8.2626706E-04,   8.2776381E-04,   8.2839059E-04
     +,   8.2814955E-04,   8.2704693E-04,   8.2509528E-04
     +,   8.2231354E-04,   8.1872620E-04,   8.1436557E-04
     +,   8.0926763E-04,   8.0347690E-04,   7.9704222E-04
     +,   7.9001882E-04,   7.8246609E-04,   7.7445066E-04
     +,   7.6604058E-04,   7.5731054E-04,   7.4833725E-04
     +,   7.3920097E-04,   7.2998455E-04,   7.2077091E-04
     +,   7.1164616E-04,   7.0269551E-04,   6.9400505E-04
     +,   6.8565836E-04,   6.7774026E-04,   6.7033013E-04
     +,   6.6350709E-04,   6.5734657E-04,   6.5191917E-04
     +,   6.4729166E-04,   6.4352521E-04,   6.4067612E-04
     +,   6.3879479E-04,   6.3792308E-04,   6.3809706E-04
     +,   6.3934468E-04,   6.4168591E-04,   6.4513093E-04
     +,   6.4968219E-04,   6.5533113E-04,   6.6206063E-04
     +,   6.6984160E-04,   6.7863672E-04,   6.8839634E-04
     +,   6.9906120E-04,   7.1056187E-04,   7.2281779E-04
     +,   7.3573960E-04,   7.4922742E-04,   7.6317537E-04
     +,   7.7746692E-04,   7.9198170E-04,   8.0659206E-04
     +,   8.2116772E-04,   8.3557464E-04,   8.4967818E-04
     +,   8.6334511E-04,   8.7644492E-04,   8.8884990E-04
     +,   9.0043910E-04,   9.1110135E-04,   9.2073099E-04
     +,   9.2923600E-04,   9.3653676E-04,   9.4256731E-04
     +,   9.4727561E-04,   9.5062534E-04,   9.5259666E-04
     +,   9.5318654E-04,   9.5240731E-04,   9.5028873E-04
     +,   9.4687677E-04,   9.4223063E-04,   9.3642541E-04
     +,   9.2954881E-04,   9.2170120E-04,   9.1299304E-04
     +,   9.0354483E-04,   8.9348364E-04,   8.8294392E-04
     +,   8.7206397E-04,   8.6098659E-04,   8.4985571E-04
     +,   8.3881553E-04,   8.2801114E-04,   8.1758376E-04
     +,   8.0767326E-04,   7.9841557E-04,   7.8994106E-04
     +,   7.8237569E-04,   7.7583786E-04,   7.7043771E-04
     +,   7.6627929E-04,   7.6345558E-04,   7.6205021E-04
     +,   7.6213491E-04,   7.6377031E-04,   7.6700310E-04
     +,   7.7186688E-04,   7.7838026E-04,   7.8654726E-04
     +,   7.9635554E-04,   8.0777967E-04,   8.2077814E-04
     +,   8.3529751E-04,   8.5127371E-04,   8.6863257E-04
     +,   8.8729517E-04,   9.0718106E-04,   9.2821551E-04
     +,   9.5032941E-04,   9.7346876E-04,   9.9760143E-04
     +,   1.0227213E-03,   1.0488529E-03,   1.0760601E-03
     +,   1.1044496E-03,   1.1341708E-03,   1.1654216E-03
     +,   1.1984491E-03,   1.2335458E-03,   1.2710468E-03
     +,   1.3113254E-03,   1.3547839E-03,   1.4018504E-03
     +,   1.4529602E-03,   1.5085454E-03,   1.5690271E-03
     +,   1.6347973E-03,   1.7061986E-03,   1.7835224E-03
     +,   1.8669992E-03,   1.9567912E-03,   2.0529998E-03
     +,   2.1556991E-03,   2.2649544E-03,   2.3808654E-03
     +,   2.5036151E-03,   2.6335192E-03,   2.7710656E-03
     +,   2.9169021E-03,   3.0718246E-03,   3.2367280E-03
     +,   3.4125003E-03,   3.5998742E-03,   3.7993824E-03
     +,   4.0112743E-03,   4.2355545E-03,   4.4721644E-03
     +,   4.7213002E-03,   4.9837348E-03,   5.2611646E-03
     +,   5.5563343E-03,   5.8729113E-03,   6.2149027E-03
     +,   6.5856986E-03,   6.9870334E-03,   7.4180937E-03
     +,   7.8751799E-03,   8.3519863E-03,   8.8409502E-03
     +,   9.3348818E-03,   9.8286578E-03,   1.0320465E-02
     +,   1.0812455E-02,   1.1310705E-02,   1.1825007E-02
     +,   1.2368673E-02,   1.2957956E-02,   1.3610519E-02
     +,   1.4342422E-02,   1.5163953E-02,   1.6075831E-02
     +,   1.7067133E-02,   1.8116640E-02,   1.9197136E-02
     +,   2.0280112E-02,   2.1339089E-02,   2.2349447E-02
     +,   2.3285761E-02,   2.4118681E-02,   2.4813013E-02
     +,   2.5328489E-02,   2.5621686E-02,   2.5648840E-02
     +,   2.5369165E-02,   2.4749907E-02,   2.3773689E-02
     +,   2.2446444E-02,   2.0803759E-02,   1.8910944E-02
     +,   1.6856628E-02,   1.4740461E-02,   1.2658848E-02
     +,   1.0692380E-02,   8.8986307E-03,   7.3106973E-03
     +,   5.9398650E-03,   4.7809267E-03,   3.8181380E-03
     +,   3.0302887E-03,   2.3941237E-03,   1.8865367E-03
     +,   1.4858135E-03,   1.1722398E-03,   9.2832604E-04
     +,   7.3902670E-04,   5.9180078E-04,   4.7654269E-04
     +,   3.8539778E-04,   3.1247947E-04,   2.5350926E-04
     +,   2.0543007E-04,   1.6606059E-04,   1.3381554E-04
     +,   1.0749883E-04,   8.6154498E-05,   6.8987487E-05
     +,   5.5309974E-05,   4.4522199E-05,   3.6098238E-05
     +,   2.9583818E-05,   2.4590578E-05,   2.0793774E-05
     +,   1.7925564E-05,   1.5769752E-05,   1.4154045E-05
     +,   1.2943397E-05,   1.2033393E-05,   1.1343992E-05
     +,   1.0814601E-05,   1.0399598E-05,   1.0065008E-05
     +,   9.7856318E-06,   9.5430105E-06,   9.3237159E-06
     +,   9.1181437E-06,   8.9195191E-06,   8.7232102E-06
     +,   8.5261254E-06,   8.3263485E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz115 = Yx/0.217777777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3554097E-04,   3.4945772E-04
     +,   3.6345734E-04,   3.7750788E-04,   3.9157682E-04
     +,   4.0563109E-04,   4.1963783E-04,   4.3356404E-04
     +,   4.4737762E-04,   4.6104725E-04,   4.7454215E-04
     +,   4.8783276E-04,   5.0089112E-04,   5.1369105E-04
     +,   5.2620767E-04,   5.3841888E-04,   5.5030448E-04
     +,   5.6184654E-04,   5.7302997E-04,   5.8384240E-04
     +,   5.9427368E-04,   6.0431758E-04,   6.1396969E-04
     +,   6.2322977E-04,   6.3209975E-04,   6.4058567E-04
     +,   6.4869539E-04,   6.5644080E-04,   6.6383614E-04
     +,   6.7089929E-04,   6.7764986E-04,   6.8411068E-04
     +,   6.9030700E-04,   6.9626607E-04,   7.0201675E-04
     +,   7.0759020E-04,   7.1301823E-04,   7.1833393E-04
     +,   7.2357064E-04,   7.2876189E-04,   7.3394069E-04
     +,   7.3914020E-04,   7.4439059E-04,   7.4972206E-04
     +,   7.5516175E-04,   7.6073408E-04,   7.6646020E-04
     +,   7.7235873E-04,   7.7844382E-04,   7.8472536E-04
     +,   7.9120888E-04,   7.9789560E-04,   8.0478092E-04
     +,   8.1185700E-04,   8.1910950E-04,   8.2652050E-04
     +,   8.3406817E-04,   8.4172288E-04,   8.4945536E-04
     +,   8.5722998E-04,   8.6500839E-04,   8.7275007E-04
     +,   8.8041200E-04,   8.8794949E-04,   8.9531811E-04
     +,   9.0247107E-04,   9.0936490E-04,   9.1595529E-04
     +,   9.2220050E-04,   9.2806126E-04,   9.3350146E-04
     +,   9.3848846E-04,   9.4299577E-04,   9.4699761E-04
     +,   9.5047842E-04,   9.5342362E-04,   9.5582829E-04
     +,   9.5769076E-04,   9.5901714E-04,   9.5981843E-04
     +,   9.6011203E-04,   9.5992134E-04,   9.5927576E-04
     +,   9.5820945E-04,   9.5676078E-04,   9.5497246E-04
     +,   9.5289102E-04,   9.5056690E-04,   9.4805268E-04
     +,   9.4539957E-04,   9.4266271E-04,   9.3989592E-04
     +,   9.3715155E-04,   9.3447999E-04,   9.3192916E-04
     +,   9.2954427E-04,   9.2736399E-04,   9.2542463E-04
     +,   9.2375313E-04,   9.2237373E-04,   9.2130207E-04
     +,   9.2054624E-04,   9.2010788E-04,   9.1998040E-04
     +,   9.2014967E-04,   9.2059432E-04,   9.2128618E-04
     +,   9.2219003E-04,   9.2326407E-04,   9.2446175E-04
     +,   9.2573167E-04,   9.2701759E-04,   9.2826202E-04
     +,   9.2940591E-04,   9.3038677E-04,   9.3114586E-04
     +,   9.3162473E-04,   9.3176693E-04,   9.3152095E-04
     +,   9.3083997E-04,   9.2968188E-04,   9.2801230E-04
     +,   9.2580303E-04,   9.2303439E-04,   9.1969332E-04
     +,   9.1577863E-04,   9.1129181E-04,   9.0624794E-04
     +,   9.0066664E-04,   8.9457602E-04,   8.8801165E-04
     +,   8.8101480E-04,   8.7363058E-04,   8.6591102E-04
     +,   8.5790944E-04,   8.4968220E-04,   8.4128749E-04
     +,   8.3278271E-04,   8.2422554E-04,   8.1567105E-04
     +,   8.0717128E-04,   7.9877826E-04,   7.9053617E-04
     +,   7.8248652E-04,   7.7466713E-04,   7.6710834E-04
     +,   7.5983885E-04,   7.5288152E-04,   7.4625475E-04
     +,   7.3997362E-04,   7.3405023E-04,   7.2849449E-04
     +,   7.2331604E-04,   7.1852253E-04,   7.1412459E-04
     +,   7.1013358E-04,   7.0656562E-04,   7.0343958E-04
     +,   7.0078130E-04,   6.9862197E-04,   6.9700181E-04
     +,   6.9596828E-04,   6.9557864E-04,   6.9589925E-04
     +,   6.9700764E-04,   6.9899019E-04,   7.0194545E-04
     +,   7.0598128E-04,   7.1121677E-04,   7.1778090E-04
     +,   7.2581158E-04,   7.3545572E-04,   7.4686890E-04
     +,   7.6021219E-04,   7.7564974E-04,   7.9334836E-04
     +,   8.1347307E-04,   8.3618239E-04,   8.6162303E-04
     +,   8.8992767E-04,   9.2120748E-04,   9.5554080E-04
     +,   9.9297636E-04,   1.0335199E-03,   1.0771388E-03
     +,   1.1237519E-03,   1.1732366E-03,   1.2254368E-03
     +,   1.2801707E-03,   1.3372444E-03,   1.3964751E-03
     +,   1.4577206E-03,   1.5208952E-03,   1.5860039E-03
     +,   1.6531789E-03,   1.7226894E-03,   1.7949642E-03
     +,   1.8705847E-03,   1.9502902E-03,   2.0349417E-03
     +,   2.1254751E-03,   2.2228428E-03,   2.3279600E-03
     +,   2.4416249E-03,   2.5644535E-03,   2.6968548E-03
     +,   2.8390056E-03,   2.9908766E-03,   3.1522852E-03
     +,   3.3230376E-03,   3.5030022E-03,   3.6922661E-03
     +,   3.8912126E-03,   4.1006226E-03,   4.3216241E-03
     +,   4.5555998E-03,   4.8039719E-03,   5.0680051E-03
     +,   5.3484654E-03,   5.6453575E-03,   5.9577962E-03
     +,   6.2839757E-03,   6.6213249E-03,   6.9669490E-03
     +,   7.3181414E-03,   7.6729888E-03,   8.0308598E-03
     +,   8.3925892E-03,   8.7604886E-03,   9.1377571E-03
     +,   9.5277736E-03,   9.9331206E-03,   1.0354958E-02
     +,   1.0792604E-02,   1.1243629E-02,   1.1704512E-02
     +,   1.2171383E-02,   1.2640740E-02,   1.3109803E-02
     +,   1.3576128E-02,   1.4036825E-02,   1.4486942E-02
     +,   1.4918250E-02,   1.5318086E-02,   1.5668975E-02
     +,   1.5949178E-02,   1.6134089E-02,   1.6198557E-02
     +,   1.6119558E-02,   1.5878918E-02,   1.5465848E-02
     +,   1.4878749E-02,   1.4126169E-02,   1.3226538E-02
     +,   1.2206856E-02,   1.1100382E-02,   9.9440217E-03
     +,   8.7751206E-03,   7.6285801E-03,   6.5346453E-03
     +,   5.5173659E-03,   4.5937891E-03,   3.7738625E-03
     +,   3.0611444E-03,   2.4538513E-03,   1.9459738E-03
     +,   1.5286464E-03,   1.1913572E-03,   9.2293054E-04
     +,   7.1231584E-04,   5.4917845E-04,   4.2425733E-04
     +,   3.2952032E-04,   2.5820200E-04,   2.0475543E-04
     +,   1.6473971E-04,   1.3466614E-04,   1.1185791E-04
     +,   9.4295399E-05,   8.0490841E-05,   6.9367168E-05
     +,   6.0164235E-05,   5.2355885E-05,   4.5588171E-05
     +,   3.9627186E-05,   3.4322598E-05,   2.9578148E-05
     +,   2.5331803E-05,   2.1542128E-05,   1.8177720E-05
     +,   1.5212324E-05,   1.2620410E-05,   1.0376169E-05
     +,   8.4521089E-06,   6.8197646E-06,   5.4496054E-06
     +,   4.3121358E-06,   3.3782269E-06,   2.6200762E-06
     +,   2.0115024E-06,   1.5285607E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz120 = Yx/0.1715
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1793182E-04,   4.5728733E-04
     +,   5.0018763E-04,   5.4701691E-04,   5.9822114E-04
     +,   6.5432832E-04,   7.1597518E-04,   7.8394113E-04
     +,   8.5918460E-04,   9.4289659E-04,   1.0365472E-03
     +,   1.1419667E-03,   1.2614318E-03,   1.3977706E-03
     +,   1.5544469E-03,   1.7355690E-03,   1.9457554E-03
     +,   2.1897738E-03,   2.4719532E-03,   2.7954744E-03
     +,   3.1618057E-03,   3.5706605E-03,   4.0208413E-03
     +,   4.5121768E-03,   5.0480217E-03,   5.6379018E-03
     +,   6.2986300E-03,   7.0531582E-03,   7.9264482E-03
     +,   8.9391395E-03,   1.0100805E-02,   1.1405751E-02
     +,   1.2833740E-02,   1.4356609E-02,   1.5948270E-02
     +,   1.7593279E-02,   1.9287098E-02,   2.1024821E-02
     +,   2.2781197E-02,   2.4492467E-02,   2.6054582E-02
     +,   2.7344635E-02,   2.8259572E-02,   2.8752001E-02
     +,   2.8841265E-02,   2.8594108E-02,   2.8086673E-02
     +,   2.7373256E-02,   2.6477477E-02,   2.5406914E-02
     +,   2.4175769E-02,   2.2819983E-02,   2.1396212E-02
     +,   1.9968143E-02,   1.8590314E-02,   1.7297139E-02
     +,   1.6101327E-02,   1.4998750E-02,   1.3975803E-02
     +,   1.3015581E-02,   1.2101755E-02,   1.1220981E-02
     +,   1.0364315E-02,   9.5284441E-03,   8.7160086E-03
     +,   7.9348311E-03,   7.1954434E-03,   6.5084337E-03
     +,   5.8816341E-03,   5.3187772E-03,   4.8191380E-03
     +,   4.3785479E-03,   3.9906427E-03,   3.6483959E-03
     +,   3.3450804E-03,   3.0749412E-03,   2.8334290E-03
     +,   2.6170947E-03,   2.4233737E-03,   2.2503496E-03
     +,   2.0964970E-03,   1.9604571E-03,   1.8409346E-03
     +,   1.7365753E-03,   1.6459778E-03,   1.5676711E-03
     +,   1.5001831E-03,   1.4420578E-03,   1.3919241E-03
     +,   1.3485166E-03,   1.3107006E-03,   1.2774909E-03
     +,   1.2480445E-03,   1.2216545E-03,   1.1977367E-03
     +,   1.1758166E-03,   1.1555107E-03,   1.1365153E-03
     +,   1.1185879E-03,   1.1015392E-03,   1.0852204E-03
     +,   1.0695169E-03,   1.0543385E-03,   1.0396185E-03
     +,   1.0253049E-03,   1.0113595E-03,   9.9775672E-04
     +,   9.8447758E-04,   9.7151217E-04,   9.5885427E-04
     +,   9.4650447E-04,   9.3446649E-04,   9.2274771E-04
     +,   9.1135508E-04,   9.0030197E-04,   8.8959903E-04
     +,   8.7925984E-04,   8.6929649E-04,   8.5972174E-04
     +,   8.5054600E-04,   8.4177864E-04,   8.3342672E-04
     +,   8.2549511E-04,   8.1798423E-04,   8.1089081E-04
     +,   8.0421026E-04,   7.9792930E-04,   7.9203391E-04
     +,   7.8650459E-04,   7.8131695E-04,   7.7644363E-04
     +,   7.7185314E-04,   7.6751091E-04,   7.6338009E-04
     +,   7.5942214E-04,   7.5559644E-04,   7.5186399E-04
     +,   7.4818422E-04,   7.4451929E-04,   7.4083207E-04
     +,   7.3709007E-04,   7.3326199E-04,   7.2932214E-04
     +,   7.2524836E-04,   7.2102394E-04,   7.1663666E-04
     +,   7.1207894E-04,   7.0734927E-04,   7.0245110E-04
     +,   6.9739111E-04,   6.9218205E-04,   6.8683934E-04
     +,   6.8138319E-04,   6.7583658E-04,   6.7022257E-04
     +,   6.6456944E-04,   6.5890502E-04,   6.5325701E-04
     +,   6.4765400E-04,   6.4212445E-04,   6.3669437E-04
     +,   6.3138950E-04,   6.2623312E-04,   6.2124623E-04
     +,   6.1644701E-04,   6.1185128E-04,   6.0747081E-04
     +,   6.0331594E-04,   5.9939211E-04,   5.9570279E-04
     +,   5.9224770E-04,   5.8902334E-04,   5.8602425E-04
     +,   5.8324164E-04,   5.8066368E-04,   5.7827815E-04
     +,   5.7606923E-04,   5.7402026E-04,   5.7211373E-04
     +,   5.7033048E-04,   5.6865107E-04,   5.6705647E-04
     +,   5.6552724E-04,   5.6404423E-04,   5.6258979E-04
     +,   5.6114729E-04,   5.5970129E-04,   5.5823848E-04
     +,   5.5674714E-04,   5.5521785E-04,   5.5364321E-04
     +,   5.5201876E-04,   5.5034197E-04,   5.4861262E-04
     +,   5.4683344E-04,   5.4500822E-04,   5.4314418E-04
     +,   5.4124923E-04,   5.3933362E-04,   5.3740817E-04
     +,   5.3548469E-04,   5.3357589E-04,   5.3169456E-04
     +,   5.2985293E-04,   5.2806229E-04,   5.2633358E-04
     +,   5.2467553E-04,   5.2309496E-04,   5.2159699E-04
     +,   5.2018347E-04,   5.1885459E-04,   5.1760644E-04
     +,   5.1643222E-04,   5.1532267E-04,   5.1426433E-04
     +,   5.1324099E-04,   5.1223399E-04,   5.1122112E-04
     +,   5.1017804E-04,   5.0907792E-04,   5.0789211E-04
     +,   5.0659111E-04,   5.0514337E-04,   5.0351827E-04
     +,   5.0168368E-04,   4.9960916E-04,   4.9726467E-04
     +,   4.9462193E-04,   4.9165473E-04,   4.8833888E-04
     +,   4.8465357E-04,   4.8058090E-04,   4.7610630E-04
     +,   4.7121901E-04,   4.6591277E-04,   4.6018453E-04
     +,   4.5403538E-04,   4.4747099E-04,   4.4050091E-04
     +,   4.3313816E-04,   4.2539916E-04,   4.1730455E-04
     +,   4.0887779E-04,   4.0014467E-04,   3.9113330E-04
     +,   3.8187447E-04,   3.7240048E-04,   3.6274406E-04
     +,   3.5293895E-04,   3.4302010E-04,   3.3302139E-04
     +,   3.2297630E-04,   3.1291816E-04,   3.0287937E-04
     +,   2.9289012E-04,   2.8297896E-04,   2.7317327E-04
     +,   2.6349834E-04,   2.5397670E-04,   2.4462881E-04
     +,   2.3547310E-04,   2.2652572E-04,   2.1780019E-04
     +,   2.0930721E-04,   2.0105658E-04,   1.9305483E-04
     +,   1.8530661E-04,   1.7781508E-04,   1.7058174E-04
     +,   1.6360602E-04,   1.5688589E-04,   1.5041835E-04
     +,   1.4419944E-04,   1.3822374E-04,   1.3248516E-04
     +,   1.2697732E-04,   1.2169283E-04,   1.1662435E-04
     +,   1.1176379E-04,   1.0710349E-04,   1.0263509E-04
     +,   9.8350909E-05,   9.4242692E-05,   9.0302958E-05
     +,   8.6523847E-05,   8.2898296E-05,   7.9419195E-05
     +,   7.6079639E-05,   7.2873452E-05,   6.9794354E-05
     +,   6.6836721E-05,   6.3994958E-05,   6.1264131E-05
     +,   5.8639227E-05,   5.6115910E-05,   5.3689775E-05
     +,   5.1357005E-05,   4.9113711E-05,   4.6956557E-05
     +,   4.4882090E-05,   4.2887368E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz60 = Yx/0.224466666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5184562E-05,   6.8683286E-05
     +,   7.2492199E-05,   7.6647331E-05,   8.1188555E-05
     +,   8.6159591E-05,   9.1608294E-05,   9.7586708E-05
     +,   1.0415130E-04,   1.1136375E-04,   1.1929077E-04
     +,   1.2800550E-04,   1.3758836E-04,   1.4812908E-04
     +,   1.5972892E-04,   1.7250367E-04,   1.8658821E-04
     +,   2.0214121E-04,   2.1935189E-04,   2.3844780E-04
     +,   2.5970387E-04,   2.8345402E-04,   3.1010274E-04
     +,   3.4014284E-04,   3.7416746E-04,   4.1289424E-04
     +,   4.5717962E-04,   5.0803926E-04,   5.6666246E-04
     +,   6.3442136E-04,   7.1287423E-04,   8.0375461E-04
     +,   9.0895750E-04,   1.0305140E-03,   1.1705604E-03
     +,   1.3313120E-03,   1.5150346E-03,   1.7240263E-03
     +,   1.9606454E-03,   2.2273401E-03,   2.5268968E-03
     +,   2.8627545E-03,   3.2396186E-03,   3.6641795E-03
     +,   4.1457731E-03,   4.6966202E-03,   5.3313519E-03
     +,   6.0657249E-03,   6.9148066E-03,   7.8910105E-03
     +,   9.0021482E-03,   1.0249064E-02,   1.1622790E-02
     +,   1.3101714E-02,   1.4651644E-02,   1.6232358E-02
     +,   1.7811541E-02,   1.9381775E-02,   2.0970298E-02
     +,   2.2630354E-02,   2.4411330E-02,   2.6317306E-02
     +,   2.8275544E-02,   3.0134609E-02,   3.1695150E-02
     +,   3.2758117E-02,   3.3169810E-02,   3.2853391E-02
     +,   3.1830378E-02,   3.0227434E-02,   2.8256841E-02
     +,   2.6161686E-02,   2.4144826E-02,   2.2318214E-02
     +,   2.0696905E-02,   1.9233281E-02,   1.7864676E-02
     +,   1.6547950E-02,   1.5270899E-02,   1.4045021E-02
     +,   1.2891425E-02,   1.1828993E-02,   1.0869210E-02
     +,   1.0014688E-02,   9.2602000E-03,   8.5939988E-03
     +,   8.0004307E-03,   7.4626599E-03,   6.9658193E-03
     +,   6.4988807E-03,   6.0555018E-03,   5.6334673E-03
     +,   5.2332790E-03,   4.8565571E-03,   4.5047766E-03
     +,   4.1785669E-03,   3.8774835E-03,   3.6003734E-03
     +,   3.3457205E-03,   3.1121247E-03,   2.8984344E-03
     +,   2.7038374E-03,   2.5276926E-03,   2.3694208E-03
     +,   2.2282887E-03,   2.1033629E-03,   1.9935013E-03
     +,   1.8973834E-03,   1.8135983E-03,   1.7407337E-03
     +,   1.6774647E-03,   1.6225748E-03,   1.5750023E-03
     +,   1.5338276E-03,   1.4982669E-03,   1.4676441E-03
     +,   1.4413693E-03,   1.4189181E-03,   1.3998045E-03
     +,   1.3835764E-03,   1.3698000E-03,   1.3580578E-03
     +,   1.3479476E-03,   1.3390797E-03,   1.3310839E-03
     +,   1.3236124E-03,   1.3163387E-03,   1.3089692E-03
     +,   1.3012398E-03,   1.2929227E-03,   1.2838286E-03
     +,   1.2738049E-03,   1.2627388E-03,   1.2505602E-03
     +,   1.2372327E-03,   1.2227616E-03,   1.2071873E-03
     +,   1.1905803E-03,   1.1730420E-03,   1.1546968E-03
     +,   1.1356932E-03,   1.1161939E-03,   1.0963738E-03
     +,   1.0764119E-03,   1.0564928E-03,   1.0367965E-03
     +,   1.0174966E-03,   9.9875976E-04,   9.8073785E-04
     +,   9.6356869E-04,   9.4737316E-04,   9.3225512E-04
     +,   9.1830007E-04,   9.0557407E-04,   8.9412398E-04
     +,   8.8397932E-04,   8.7515247E-04,   8.6763548E-04
     +,   8.6140668E-04,   8.5642823E-04,   8.5264671E-04
     +,   8.4999576E-04,   8.4839686E-04,   8.4775797E-04
     +,   8.4797939E-04,   8.4894989E-04,   8.5055153E-04
     +,   8.5266028E-04,   8.5514761E-04,   8.5788191E-04
     +,   8.6073030E-04,   8.6356286E-04,   8.6625101E-04
     +,   8.6867268E-04,   8.7071350E-04,   8.7226700E-04
     +,   8.7323959E-04,   8.7354856E-04,   8.7312597E-04
     +,   8.7191939E-04,   8.6989038E-04,   8.6701679E-04
     +,   8.6329330E-04,   8.5872714E-04,   8.5334090E-04
     +,   8.4717158E-04,   8.4026571E-04,   8.3268067E-04
     +,   8.2448148E-04,   8.1574067E-04,   8.0653362E-04
     +,   7.9693802E-04,   7.8703294E-04,   7.7689620E-04
     +,   7.6660153E-04,   7.5621955E-04,   7.4581499E-04
     +,   7.3544693E-04,   7.2516652E-04,   7.1501808E-04
     +,   7.0503802E-04,   6.9525582E-04,   6.8569300E-04
     +,   6.7636423E-04,   6.6727772E-04,   6.5843546E-04
     +,   6.4983376E-04,   6.4146565E-04,   6.3331937E-04
     +,   6.2537985E-04,   6.1762956E-04,   6.1004941E-04
     +,   6.0261891E-04,   5.9531722E-04,   5.8812124E-04
     +,   5.8101106E-04,   5.7396432E-04,   5.6696084E-04
     +,   5.5998057E-04,   5.5300473E-04,   5.4601551E-04
     +,   5.3899561E-04,   5.3193001E-04,   5.2480423E-04
     +,   5.1760493E-04,   5.1031960E-04,   5.0293771E-04
     +,   4.9544929E-04,   4.8784580E-04,   4.8011940E-04
     +,   4.7226439E-04,   4.6427580E-04,   4.5614954E-04
     +,   4.4788318E-04,   4.3947576E-04,   4.3092755E-04
     +,   4.2223986E-04,   4.1341572E-04,   4.0446018E-04
     +,   3.9537836E-04,   3.8617762E-04,   3.7686655E-04
     +,   3.6745524E-04,   3.5795447E-04,   3.4837614E-04
     +,   3.3873404E-04,   3.2904217E-04,   3.1931570E-04
     +,   3.0956979E-04,   2.9982108E-04,   2.9008606E-04
     +,   2.8038133E-04,   2.7072395E-04,   2.6113118E-04
     +,   2.5161932E-04,   2.4220449E-04,   2.3290284E-04
     +,   2.2372986E-04,   2.1469989E-04,   2.0582631E-04
     +,   1.9712237E-04,   1.8860027E-04,   1.8027064E-04
     +,   1.7214306E-04,   1.6422680E-04,   1.5652919E-04
     +,   1.4905655E-04,   1.4181448E-04,   1.3480752E-04
     +,   1.2803858E-04,   1.2150964E-04,   1.1522200E-04
     +,   1.0917607E-04,   1.0337086E-04,   9.7804586E-05
     +,   9.2475231E-05,   8.7379245E-05,   8.2513208E-05
     +,   7.7872326E-05,   7.3451971E-05,   6.9246453E-05
     +,   6.5250148E-05,   6.1456638E-05,   5.7859692E-05
     +,   5.4452375E-05,   5.1228031E-05,   4.8179536E-05
     +,   4.5299745E-05,   4.2581742E-05,   4.0018236E-05
     +,   3.7602371E-05,   3.5327037E-05,   3.3185519E-05
     +,   3.1170966E-05,   2.9276984E-05,   2.7497064E-05
     +,   2.5825146E-05,   2.4255165E-05,   2.2781476E-05
     +,   2.1398457E-05,   2.0100908E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz65 = Yx/0.236782608695652
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.6162006E-05,   8.9819769E-05
     +,   9.3669674E-05,   9.7725802E-05,   1.0200296E-04
     +,   1.0651682E-04,   1.1128373E-04,   1.1632076E-04
     +,   1.2164540E-04,   1.2727591E-04,   1.3323050E-04
     +,   1.3952750E-04,   1.4618509E-04,   1.5322091E-04
     +,   1.6065191E-04,   1.6849370E-04,   1.7676032E-04
     +,   1.8546374E-04,   1.9461352E-04,   2.0421609E-04
     +,   2.1427459E-04,   2.2478837E-04,   2.3575220E-04
     +,   2.4715741E-04,   2.5898966E-04,   2.7123123E-04
     +,   2.8385993E-04,   2.9685057E-04,   3.1017579E-04
     +,   3.2380741E-04,   3.3771971E-04,   3.5189133E-04
     +,   3.6631001E-04,   3.8097677E-04,   3.9591212E-04
     +,   4.1116378E-04,   4.2681349E-04,   4.4298687E-04
     +,   4.5986456E-04,   4.7768833E-04,   4.9677544E-04
     +,   5.1752303E-04,   5.4041611E-04,   5.6602852E-04
     +,   5.9502095E-04,   6.2813301E-04,   6.6616968E-04
     +,   7.0998073E-04,   7.6043903E-04,   8.1841392E-04
     +,   8.8475336E-04,   9.6027239E-04,   1.0457661E-03
     +,   1.1420639E-03,   1.2501120E-03,   1.3711558E-03
     +,   1.5069678E-03,   1.6601695E-03,   1.8346069E-03
     +,   2.0357464E-03,   2.2710136E-03,   2.5500273E-03
     +,   2.8846129E-03,   3.2886344E-03,   3.7774262E-03
     +,   4.3666437E-03,   5.0705816E-03,   5.8992621E-03
     +,   6.8554725E-03,   7.9322103E-03,   9.1135409E-03
     +,   1.0379787E-02,   1.1717834E-02,   1.3131191E-02
     +,   1.4643743E-02,   1.6289972E-02,   1.8094284E-02
     +,   2.0051463E-02,   2.2122087E-02,   2.4240542E-02
     +,   2.6320091E-02,   2.8247667E-02,   2.9887263E-02
     +,   3.1118110E-02,   3.1894110E-02,   3.2271512E-02
     +,   3.2362841E-02,   3.2244913E-02,   3.1903815E-02
     +,   3.1275064E-02,   3.0337738E-02,   2.9162612E-02
     +,   2.7868537E-02,   2.6545258E-02,   2.5222443E-02
     +,   2.3891326E-02,   2.2532288E-02,   2.1124234E-02
     +,   1.9650020E-02,   1.8114084E-02,   1.6558802E-02
     +,   1.5059848E-02,   1.3695513E-02,   1.2511932E-02
     +,   1.1505680E-02,   1.0634264E-02,   9.8435897E-03
     +,   9.0942457E-03,   8.3731832E-03,   7.6892460E-03
     +,   7.0602195E-03,   6.5004872E-03,   6.0150851E-03
     +,   5.5995327E-03,   5.2433442E-03,   4.9337926E-03
     +,   4.6588513E-03,   4.4085723E-03,   4.1755862E-03
     +,   3.9549796E-03,   3.7439030E-03,   3.5411657E-03
     +,   3.3467191E-03,   3.1611482E-03,   2.9852698E-03
     +,   2.8198117E-03,   2.6651912E-03,   2.5214944E-03
     +,   2.3884685E-03,   2.2656815E-03,   2.1525966E-03
     +,   2.0487285E-03,   1.9536780E-03,   1.8671982E-03
     +,   1.7891458E-03,   1.7194538E-03,   1.6580650E-03
     +,   1.6048718E-03,   1.5596438E-03,   1.5220057E-03
     +,   1.4914093E-03,   1.4671369E-03,   1.4483177E-03
     +,   1.4339570E-03,   1.4229830E-03,   1.4142884E-03
     +,   1.4067718E-03,   1.3993895E-03,   1.3911815E-03
     +,   1.3813127E-03,   1.3690866E-03,   1.3539662E-03
     +,   1.3355783E-03,   1.3137149E-03,   1.2883249E-03
     +,   1.2595071E-03,   1.2274955E-03,   1.1926313E-03
     +,   1.1553509E-03,   1.1161644E-03,   1.0756270E-03
     +,   1.0343189E-03,   9.9283119E-04,   9.5174112E-04
     +,   9.1159635E-04,   8.7290333E-04,   8.3611975E-04
     +,   8.0164435E-04,   7.6981145E-04,   7.4089062E-04
     +,   7.1509206E-04,   6.9256453E-04,   6.7339803E-04
     +,   6.5763440E-04,   6.4527331E-04,   6.3627528E-04
     +,   6.3057116E-04,   6.2806753E-04,   6.2865199E-04
     +,   6.3219789E-04,   6.3856866E-04,   6.4761925E-04
     +,   6.5919763E-04,   6.7314750E-04,   6.8930513E-04
     +,   7.0749986E-04,   7.2755158E-04,   7.4926956E-04
     +,   7.7245175E-04,   7.9687726E-04,   8.2231144E-04
     +,   8.4850204E-04,   8.7517622E-04,   9.0204354E-04
     +,   9.2879811E-04,   9.5512031E-04,   9.8067743E-04
     +,   1.0051300E-03,   1.0281386E-03,   1.0493689E-03
     +,   1.0684959E-03,   1.0852111E-03,   1.0992328E-03
     +,   1.1103095E-03,   1.1182261E-03,   1.1228091E-03
     +,   1.1239339E-03,   1.1215245E-03,   1.1155555E-03
     +,   1.1060570E-03,   1.0931072E-03,   1.0768364E-03
     +,   1.0574206E-03,   1.0350761E-03,   1.0100539E-03
     +,   9.8263740E-04,   9.5313194E-04,   9.2185644E-04
     +,   8.8913913E-04,   8.5531245E-04,   8.2070060E-04
     +,   7.8561757E-04,   7.5036311E-04,   7.1521726E-04
     +,   6.8043411E-04,   6.4624136E-04,   6.1284087E-04
     +,   5.8040593E-04,   5.4907915E-04,   5.1897421E-04
     +,   4.9017963E-04,   4.6275958E-04,   4.3675120E-04
     +,   4.1217153E-04,   3.8902077E-04,   3.6728015E-04
     +,   3.4691702E-04,   3.2788876E-04,   3.1014308E-04
     +,   2.9361947E-04,   2.7825232E-04,   2.6397340E-04
     +,   2.5071265E-04,   2.3839848E-04,   2.2696023E-04
     +,   2.1632934E-04,   2.0643957E-04,   1.9722710E-04
     +,   1.8863130E-04,   1.8059665E-04,   1.7307021E-04
     +,   1.6600332E-04,   1.5935184E-04,   1.5307555E-04
     +,   1.4713762E-04,   1.4150490E-04,   1.3614827E-04
     +,   1.3104147E-04,   1.2616134E-04,   1.2148711E-04
     +,   1.1700113E-04,   1.1268780E-04,   1.0853327E-04
     +,   1.0452568E-04,   1.0065499E-04,   9.6912307E-05
     +,   9.3289869E-05,   8.9781228E-05,   8.6381049E-05
     +,   8.3084378E-05,   7.9887017E-05,   7.6785625E-05
     +,   7.3777228E-05,   7.0859169E-05,   6.8029061E-05
     +,   6.5285152E-05,   6.2625528E-05,   6.0048806E-05
     +,   5.7553378E-05,   5.5138105E-05,   5.2801606E-05
     +,   5.0542843E-05,   4.8360449E-05,   4.6253463E-05
     +,   4.4220531E-05,   4.2260621E-05,   4.0372412E-05
     +,   3.8554586E-05,   3.6805926E-05,   3.5124940E-05
     +,   3.3510329E-05,   3.1960510E-05,   3.0474057E-05
     +,   2.9049277E-05,   2.7684655E-05,   2.6378442E-05
     +,   2.5129017E-05,   2.3934574E-05,   2.2793427E-05
     +,   2.1703743E-05,   2.0663812E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz70 = Yx/0.256565217391304
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.7648441E-05,   6.8674504E-05
     +,   6.9668436E-05,   7.0629554E-05,   7.1557501E-05
     +,   7.2452072E-05,   7.3313444E-05,   7.4142146E-05
     +,   7.4938987E-05,   7.5705306E-05,   7.6442797E-05
     +,   7.7153745E-05,   7.7840901E-05,   7.8507677E-05
     +,   7.9158119E-05,   7.9797028E-05,   8.0429891E-05
     +,   8.1063146E-05,   8.1703984E-05,   8.2360690E-05
     +,   8.3042440E-05,   8.3759536E-05,   8.4523330E-05
     +,   8.5346481E-05,   8.6242646E-05,   8.7226916E-05
     +,   8.8315581E-05,   8.9526256E-05,   9.0878020E-05
     +,   9.2391238E-05,   9.4087816E-05,   9.5991221E-05
     +,   9.8126438E-05,   1.0052022E-04,   1.0320126E-04
     +,   1.0620013E-04,   1.0954979E-04,   1.1328568E-04
     +,   1.1744638E-04,   1.2207335E-04,   1.2721228E-04
     +,   1.3291303E-04,   1.3923048E-04,   1.4622502E-04
     +,   1.5396345E-04,   1.6251931E-04,   1.7197378E-04
     +,   1.8241580E-04,   1.9394244E-04,   2.0665950E-04
     +,   2.2068051E-04,   2.3612722E-04,   2.5312835E-04
     +,   2.7182116E-04,   2.9234780E-04,   3.1486058E-04
     +,   3.3952083E-04,   3.6650320E-04,   3.9600278E-04
     +,   4.2824238E-04,   4.6348595E-04,   5.0205184E-04
     +,   5.4432696E-04,   5.9078942E-04,   6.4202107E-04
     +,   6.9871283E-04,   7.6168490E-04,   8.3186658E-04
     +,   9.1030181E-04,   9.9810818E-04,   1.0964675E-03
     +,   1.2065626E-03,   1.3295579E-03,   1.4665141E-03
     +,   1.6183412E-03,   1.7856976E-03,   1.9688725E-03
     +,   2.1677015E-03,   2.3815918E-03,   2.6097395E-03
     +,   2.8517307E-03,   3.1087503E-03,   3.3852365E-03
     +,   3.6909564E-03,   4.0425532E-03,   4.4637732E-03
     +,   4.9827234E-03,   5.6259301E-03,   6.4095291E-03
     +,   7.3315287E-03,   8.3695613E-03,   9.4877537E-03
     +,   1.0651139E-02,   1.1838940E-02,   1.3047892E-02
     +,   1.4286146E-02,   1.5569863E-02,   1.6930174E-02
     +,   1.8421311E-02,   2.0104948E-02,   2.2007857E-02
     +,   2.4080729E-02,   2.6195327E-02,   2.8182227E-02
     +,   2.9887654E-02,   3.1216454E-02,   3.2130681E-02
     +,   3.2597426E-02,   3.2549705E-02,   3.1937774E-02
     +,   3.0835042E-02,   2.9459203E-02,   2.8061030E-02
     +,   2.6793551E-02,   2.5682319E-02,   2.4676554E-02
     +,   2.3698883E-02,   2.2670358E-02,   2.1536965E-02
     +,   2.0295303E-02,   1.8992033E-02,   1.7694874E-02
     +,   1.6461622E-02,   1.5326958E-02,   1.4302993E-02
     +,   1.3383964E-02,   1.2550746E-02,   1.1777199E-02
     +,   1.1037443E-02,   1.0312686E-02,   9.5949573E-03
     +,   8.8873506E-03,   8.2008298E-03,   7.5495983E-03
     +,   6.9463779E-03,   6.3993135E-03,   5.9108771E-03
     +,   5.4784510E-03,   5.0960369E-03,   4.7562346E-03
     +,   4.4517820E-03,   4.1764108E-03,   3.9250623E-03
     +,   3.6937848E-03,   3.4795506E-03,   3.2800341E-03
     +,   3.0935612E-03,   2.9190835E-03,   2.7560792E-03
     +,   2.6044408E-03,   2.4642914E-03,   2.3358148E-03
     +,   2.2190828E-03,   2.1139218E-03,   2.0198820E-03
     +,   1.9362498E-03,   1.8621021E-03,   1.7963852E-03
     +,   1.7380182E-03,   1.6859672E-03,   1.6393047E-03
     +,   1.5972356E-03,   1.5591118E-03,   1.5244201E-03
     +,   1.4927530E-03,   1.4637911E-03,   1.4372719E-03
     +,   1.4129691E-03,   1.3906773E-03,   1.3701993E-03
     +,   1.3513501E-03,   1.3339482E-03,   1.3178228E-03
     +,   1.3028149E-03,   1.2887844E-03,   1.2756069E-03
     +,   1.2631775E-03,   1.2514107E-03,   1.2402390E-03
     +,   1.2296098E-03,   1.2194874E-03,   1.2098480E-03
     +,   1.2006796E-03,   1.1919861E-03,   1.1837803E-03
     +,   1.1760915E-03,   1.1689629E-03,   1.1624509E-03
     +,   1.1566280E-03,   1.1515802E-03,   1.1474015E-03
     +,   1.1441924E-03,   1.1420547E-03,   1.1410820E-03
     +,   1.1413569E-03,   1.1429373E-03,   1.1458518E-03
     +,   1.1500939E-03,   1.1556102E-03,   1.1623022E-03
     +,   1.1700210E-03,   1.1785656E-03,   1.1876873E-03
     +,   1.1970943E-03,   1.2064589E-03,   1.2154242E-03
     +,   1.2236183E-03,   1.2306650E-03,   1.2361964E-03
     +,   1.2398653E-03,   1.2413569E-03,   1.2404020E-03
     +,   1.2367826E-03,   1.2303435E-03,   1.2209931E-03
     +,   1.2087069E-03,   1.1935296E-03,   1.1755667E-03
     +,   1.1549841E-03,   1.1319985E-03,   1.1068691E-03
     +,   1.0798834E-03,   1.0513552E-03,   1.0216057E-03
     +,   9.9095586E-04,   9.5971487E-04,   9.2817540E-04
     +,   8.9660409E-04,   8.6523441E-04,   8.3426427E-04
     +,   8.0385670E-04,   7.7413768E-04,   7.4519485E-04
     +,   7.1708224E-04,   6.8982679E-04,   6.6342723E-04
     +,   6.3786085E-04,   6.1309093E-04,   5.8906939E-04
     +,   5.6574075E-04,   5.4304558E-04,   5.2092888E-04
     +,   4.9933861E-04,   4.7822812E-04,   4.5755884E-04
     +,   4.3730211E-04,   4.1743886E-04,   3.9795809E-04
     +,   3.7885646E-04,   3.6014119E-04,   3.4182356E-04
     +,   3.2392042E-04,   3.0645329E-04,   2.8944667E-04
     +,   2.7292487E-04,   2.5691220E-04,   2.4143334E-04
     +,   2.2651073E-04,   2.1216318E-04,   1.9840656E-04
     +,   1.8525359E-04,   1.7271339E-04,   1.6079014E-04
     +,   1.4948397E-04,   1.3879238E-04,   1.2870795E-04
     +,   1.1922009E-04,   1.1031563E-04,   1.0197871E-04
     +,   9.4190495E-05,   8.6930362E-05,   8.0176520E-05
     +,   7.3905911E-05,   6.8094341E-05,   6.2717001E-05
     +,   5.7749512E-05,   5.3166779E-05,   4.8944676E-05
     +,   4.5058980E-05,   4.1486641E-05,   3.8204962E-05
     +,   3.5192596E-05,   3.2428765E-05,   2.9894169E-05
     +,   2.7570259E-05,   2.5439922E-05,   2.3486935E-05
     +,   2.1696223E-05,   2.0053980E-05,   1.8547222E-05
     +,   1.7164193E-05,   1.5893915E-05,   1.4726502E-05
     +,   1.3652772E-05,   1.2664492E-05,   1.1754049E-05
     +,   1.0914637E-05,   1.0139982E-05,   9.4244951E-06
     +,   8.7630278E-06,   8.1510070E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz75 = Yx/0.263765957446809
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.5382785E-05,   5.6704084E-05
     +,   5.8037516E-05,   5.9383961E-05,   6.0744533E-05
     +,   6.2120547E-05,   6.3513631E-05,   6.4925574E-05
     +,   6.6358509E-05,   6.7814879E-05,   6.9297384E-05
     +,   7.0809045E-05,   7.2353250E-05,   7.3933705E-05
     +,   7.5554461E-05,   7.7219906E-05,   7.8934798E-05
     +,   8.0704231E-05,   8.2533654E-05,   8.4428830E-05
     +,   8.6395885E-05,   8.8441200E-05,   9.0571411E-05
     +,   9.2793576E-05,   9.5114730E-05,   9.7542354E-05
     +,   1.0008398E-04,   1.0274725E-04,   1.0553996E-04
     +,   1.0846990E-04,   1.1154493E-04,   1.1477287E-04
     +,   1.1816144E-04,   1.2171827E-04,   1.2545081E-04
     +,   1.2936642E-04,   1.3347212E-04,   1.3777471E-04
     +,   1.4228089E-04,   1.4699668E-04,   1.5192811E-04
     +,   1.5708072E-04,   1.6245958E-04,   1.6806951E-04
     +,   1.7391480E-04,   1.7999932E-04,   1.8632651E-04
     +,   1.9289916E-04,   1.9971970E-04,   2.0678998E-04
     +,   2.1411109E-04,   2.2168372E-04,   2.2950754E-04
     +,   2.3758209E-04,   2.4590539E-04,   2.5447525E-04
     +,   2.6328841E-04,   2.7234064E-04,   2.8162706E-04
     +,   2.9114145E-04,   3.0087706E-04,   3.1082614E-04
     +,   3.2097951E-04,   3.3132813E-04,   3.4186250E-04
     +,   3.5257181E-04,   3.6344677E-04,   3.7447771E-04
     +,   3.8565794E-04,   3.9698227E-04,   4.0845101E-04
     +,   4.2006993E-04,   4.3185451E-04,   4.4383027E-04
     +,   4.5603971E-04,   4.6854446E-04,   4.8142951E-04
     +,   4.9480930E-04,   5.0883420E-04,   5.2369497E-04
     +,   5.3962669E-04,   5.5691582E-04,   5.7590043E-04
     +,   5.9697445E-04,   6.2058232E-04,   6.4722210E-04
     +,   6.7743059E-04,   7.1178767E-04,   7.5090403E-04
     +,   7.9543056E-04,   8.4607385E-04,   9.0362754E-04
     +,   9.6903712E-04,   1.0434953E-03,   1.1285560E-03
     +,   1.2262543E-03,   1.3392452E-03,   1.4708480E-03
     +,   1.6250516E-03,   1.8063308E-03,   2.0193888E-03
     +,   2.2686932E-03,   2.5580975E-03,   2.8904823E-03
     +,   3.2678978E-03,   3.6921983E-03,   4.1663307E-03
     +,   4.6960958E-03,   5.2916235E-03,   5.9673702E-03
     +,   6.7396797E-03,   7.6227435E-03,   8.6245760E-03
     +,   9.7471392E-03,   1.0990867E-02,   1.2360868E-02
     +,   1.3865924E-02,   1.5504982E-02,   1.7242430E-02
     +,   1.8992882E-02,   2.0641401E-02,   2.2110088E-02
     +,   2.3434533E-02,   2.4777979E-02,   2.6342116E-02
     +,   2.8214121E-02,   3.0251665E-02,   3.2102633E-02
     +,   3.3385016E-02,   3.3913847E-02,   3.3779211E-02
     +,   3.3204623E-02,   3.2354977E-02,   3.1294644E-02
     +,   3.0078577E-02,   2.8809676E-02,   2.7581165E-02
     +,   2.6392695E-02,   2.5154030E-02,   2.3769502E-02
     +,   2.2207089E-02,   2.0500200E-02,   1.8718800E-02
     +,   1.6954711E-02,   1.5317421E-02,   1.3913955E-02
     +,   1.2812646E-02,   1.2014091E-02,   1.1450784E-02
     +,   1.1016021E-02,   1.0604230E-02,   1.0142709E-02
     +,   9.6034389E-03,   8.9962399E-03,   8.3521074E-03
     +,   7.7063208E-03,   7.0870146E-03,   6.5107392E-03
     +,   5.9832968E-03,   5.5032796E-03,   5.0658570E-03
     +,   4.6657878E-03,   4.2990125E-03,   3.9628595E-03
     +,   3.6556006E-03,   3.3757936E-03,   3.1218501E-03
     +,   2.8918802E-03,   2.6838623E-03,   2.4959364E-03
     +,   2.3266708E-03,   2.1751244E-03,   2.0407974E-03
     +,   1.9234450E-03,   1.8228852E-03,   1.7387766E-03
     +,   1.6705283E-03,   1.6172524E-03,   1.5777813E-03
     +,   1.5507366E-03,   1.5346128E-03,   1.5278599E-03
     +,   1.5289487E-03,   1.5364214E-03,   1.5489222E-03
     +,   1.5652054E-03,   1.5841452E-03,   1.6047229E-03
     +,   1.6260174E-03,   1.6471914E-03,   1.6674870E-03
     +,   1.6862174E-03,   1.7027615E-03,   1.7165709E-03
     +,   1.7271769E-03,   1.7341955E-03,   1.7373399E-03
     +,   1.7364270E-03,   1.7313814E-03,   1.7222394E-03
     +,   1.7091425E-03,   1.6923269E-03,   1.6721095E-03
     +,   1.6488656E-03,   1.6230131E-03,   1.5949808E-03
     +,   1.5651925E-03,   1.5340457E-03,   1.5018971E-03
     +,   1.4690501E-03,   1.4357481E-03,   1.4021839E-03
     +,   1.3684971E-03,   1.3347818E-03,   1.3010987E-03
     +,   1.2674925E-03,   1.2339950E-03,   1.2006353E-03
     +,   1.1674470E-03,   1.1344783E-03,   1.1017823E-03
     +,   1.0694230E-03,   1.0374731E-03,   1.0060061E-03
     +,   9.7508973E-04,   9.4478496E-04,   9.1514271E-04
     +,   8.8619645E-04,   8.5796166E-04,   8.3043514E-04
     +,   8.0359925E-04,   7.7741832E-04,   7.5184449E-04
     +,   7.2681857E-04,   7.0227945E-04,   6.7815953E-04
     +,   6.5439352E-04,   6.3092227E-04,   6.0769176E-04
     +,   5.8465742E-04,   5.6178414E-04,   5.3905044E-04
     +,   5.1644637E-04,   4.9397274E-04,   4.7164128E-04
     +,   4.4947624E-04,   4.2751065E-04,   4.0578394E-04
     +,   3.8434222E-04,   3.6323798E-04,   3.4252476E-04
     +,   3.2225720E-04,   3.0249133E-04,   2.8328106E-04
     +,   2.6467620E-04,   2.4672228E-04,   2.2946109E-04
     +,   2.1292812E-04,   1.9715143E-04,   1.8215246E-04
     +,   1.6794640E-04,   1.5454178E-04,   1.4193908E-04
     +,   1.3013277E-04,   1.1911226E-04,   1.0886049E-04
     +,   9.9355522E-05,   9.0571957E-05,   8.2480772E-05
     +,   7.5049524E-05,   6.8243775E-05,   6.2027917E-05
     +,   5.6365472E-05,   5.1219144E-05,   4.6551850E-05
     +,   4.2327527E-05,   3.8510476E-05,   3.5066721E-05
     +,   3.1963351E-05,   2.9169563E-05,   2.6655958E-05
     +,   2.4395404E-05,   2.2362405E-05,   2.0533687E-05
     +,   1.8887675E-05,   1.7404875E-05,   1.6067444E-05
     +,   1.4859289E-05,   1.3766027E-05,   1.2774656E-05
     +,   1.1873695E-05,   1.1052840E-05,   1.0303062E-05
     +,   9.6163049E-06,   8.9855648E-06,   8.4046169E-06
     +,   7.8680832E-06,   7.3711994E-06,   6.9098719E-06
     +,   6.4804799E-06,   6.0799211E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz80 = Yx/0.266
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7048343E-05,   3.7857495E-05
     +,   3.8673701E-05,   3.9496896E-05,   4.0327002E-05
     +,   4.1163923E-05,   4.2007541E-05,   4.2857722E-05
     +,   4.3714292E-05,   4.4577100E-05,   4.5445911E-05
     +,   4.6320471E-05,   4.7200494E-05,   4.8085643E-05
     +,   4.8975548E-05,   4.9869803E-05,   5.0767914E-05
     +,   5.1669362E-05,   5.2573581E-05,   5.3479926E-05
     +,   5.4387721E-05,   5.5296223E-05,   5.6204604E-05
     +,   5.7112080E-05,   5.8017653E-05,   5.8920406E-05
     +,   5.9819333E-05,   6.0713362E-05,   6.1601408E-05
     +,   6.2482344E-05,   6.3354986E-05,   6.4218177E-05
     +,   6.5070708E-05,   6.5911379E-05,   6.6738976E-05
     +,   6.7552326E-05,   6.8350259E-05,   6.9131616E-05
     +,   6.9895374E-05,   7.0640432E-05,   7.1365874E-05
     +,   7.2070812E-05,   7.2754490E-05,   7.3416231E-05
     +,   7.4055533E-05,   7.4672003E-05,   7.5265460E-05
     +,   7.5835917E-05,   7.6383621E-05,   7.6909113E-05
     +,   7.7413213E-05,   7.7897195E-05,   7.8362711E-05
     +,   7.8812031E-05,   7.9248020E-05,   7.9674377E-05
     +,   8.0095706E-05,   8.0517842E-05,   8.0947932E-05
     +,   8.1394835E-05,   8.1869410E-05,   8.2384824E-05
     +,   8.2957064E-05,   8.3605482E-05,   8.4353174E-05
     +,   8.5227548E-05,   8.6261207E-05,   8.7492102E-05
     +,   8.8964727E-05,   9.0730166E-05,   9.2847127E-05
     +,   9.5381976E-05,   9.8409379E-05,   1.0201210E-04
     +,   1.0628130E-04,   1.1131599E-04,   1.1722217E-04
     +,   1.2411164E-04,   1.3210149E-04,   1.4131177E-04
     +,   1.5186256E-04,   1.6387354E-04,   1.7745879E-04
     +,   1.9272679E-04,   2.0977453E-04,   2.2868816E-04
     +,   2.4953630E-04,   2.7237268E-04,   2.9722872E-04
     +,   3.2411783E-04,   3.5303208E-04,   3.8394085E-04
     +,   4.1679287E-04,   4.5152032E-04,   4.8803849E-04
     +,   5.2624510E-04,   5.6603295E-04,   6.0728303E-04
     +,   6.4988149E-04,   6.9371396E-04,   7.3868450E-04
     +,   7.8471203E-04,   8.3175098E-04,   8.7978930E-04
     +,   9.2887064E-04,   9.7910047E-04,   1.0306572E-03
     +,   1.0838088E-03,   1.1389365E-03,   1.1965539E-03
     +,   1.2573306E-03,   1.3221458E-03,   1.3921274E-03
     +,   1.4687394E-03,   1.5538675E-03,   1.6499468E-03
     +,   1.7600644E-03,   1.8880619E-03,   2.0384565E-03
     +,   2.2162269E-03,   2.4262799E-03,   2.6726385E-03
     +,   2.9576013E-03,   3.2811754E-03,   3.6412363E-03
     +,   4.0348326E-03,   4.4608065E-03,   4.9229292E-03
     +,   5.4325904E-03,   6.0090497E-03,   6.6762986E-03
     +,   7.4563185E-03,   8.3624180E-03,   9.3968082E-03
     +,   1.0556561E-02,   1.1844403E-02,   1.3275433E-02
     +,   1.4872134E-02,   1.6649058E-02,   1.8594500E-02
     +,   2.0654859E-02,   2.2727516E-02,   2.4674775E-02
     +,   2.6365913E-02,   2.7728815E-02,   2.8781878E-02
     +,   2.9637650E-02,   3.0478306E-02,   3.1476483E-02
     +,   3.2668769E-02,   3.3888243E-02,   3.4848474E-02
     +,   3.5319366E-02,   3.5265494E-02,   3.4855973E-02
     +,   3.4311026E-02,   3.3684954E-02,   3.2790698E-02
     +,   3.1346343E-02,   2.9224830E-02,   2.6597792E-02
     +,   2.3840416E-02,   2.1292245E-02,   1.9107016E-02
     +,   1.7281864E-02,   1.5752992E-02,   1.4444957E-02
     +,   1.3277228E-02,   1.2174962E-02,   1.1092442E-02
     +,   1.0028050E-02,   9.0169711E-03,   8.1080040E-03
     +,   7.3398734E-03,   6.7279157E-03,   6.2636524E-03
     +,   5.9231124E-03,   5.6768218E-03,   5.4968791E-03
     +,   5.3601214E-03,   5.2486048E-03,   5.1490148E-03
     +,   5.0520985E-03,   4.9522207E-03,   4.8467931E-03
     +,   4.7355876E-03,   4.6197646E-03,   4.5010406E-03
     +,   4.3810196E-03,   4.2608394E-03,   4.1410727E-03
     +,   4.0217941E-03,   3.9027676E-03,   3.7835978E-03
     +,   3.6638859E-03,   3.5433534E-03,   3.4219485E-03
     +,   3.2999422E-03,   3.1779471E-03,   3.0569783E-03
     +,   2.9384303E-03,   2.8239950E-03,   2.7155306E-03
     +,   2.6148865E-03,   2.5237151E-03,   2.4432591E-03
     +,   2.3741929E-03,   2.3165364E-03,   2.2696124E-03
     +,   2.2320892E-03,   2.2020962E-03,   2.1773875E-03
     +,   2.1555058E-03,   2.1339851E-03,   2.1105106E-03
     +,   2.0830727E-03,   2.0500731E-03,   2.0103881E-03
     +,   1.9634003E-03,   1.9089896E-03,   1.8474843E-03
     +,   1.7795891E-03,   1.7063086E-03,   1.6288469E-03
     +,   1.5485027E-03,   1.4665928E-03,   1.3843728E-03
     +,   1.3029784E-03,   1.2233785E-03,   1.1463565E-03
     +,   1.0725110E-03,   1.0022558E-03,   9.3583390E-04
     +,   8.7334513E-04,   8.1477885E-04,   7.6003117E-04
     +,   7.0893392E-04,   6.6128181E-04,   6.1684672E-04
     +,   5.7538989E-04,   5.3667626E-04,   5.0048431E-04
     +,   4.6660757E-04,   4.3485602E-04,   4.0505908E-04
     +,   3.7706731E-04,   3.5074967E-04,   3.2598973E-04
     +,   3.0268688E-04,   2.8075578E-04,   2.6012017E-04
     +,   2.4071368E-04,   2.2247859E-04,   2.0536342E-04
     +,   1.8932011E-04,   1.7430424E-04,   1.6027447E-04
     +,   1.4719088E-04,   1.3501332E-04,   1.2370203E-04
     +,   1.1321787E-04,   1.0352122E-04,   9.4571558E-05
     +,   8.6328102E-05,   7.8750723E-05,   7.1798568E-05
     +,   6.5431159E-05,   5.9608999E-05,   5.4293410E-05
     +,   4.9446408E-05,   4.5031393E-05,   4.1013667E-05
     +,   3.7360143E-05,   3.4039331E-05,   3.1021715E-05
     +,   2.8280047E-05,   2.5788708E-05,   2.3524395E-05
     +,   2.1465436E-05,   1.9592318E-05,   1.7887049E-05
     +,   1.6333563E-05,   1.4917155E-05,   1.3624774E-05
     +,   1.2444537E-05,   1.1365943E-05,   1.0379481E-05
     +,   9.4766592E-06,   8.6499567E-06,   7.8925405E-06
     +,   7.1983850E-06,   6.5619961E-06,   5.9785170E-06
     +,   5.4434963E-06,   4.9529822E-06,   4.5033298E-06
     +,   4.0912905E-06,   3.7138445E-06,   3.3682841E-06
     +,   3.0520832E-06,   2.7629610E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz85 = Yx/0.283127659574468
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5034019E-05,   4.6296427E-05
     +,   4.7554910E-05,   4.8807415E-05,   5.0051938E-05
     +,   5.1286530E-05,   5.2509302E-05,   5.3718493E-05
     +,   5.4912398E-05,   5.6089506E-05,   5.7248391E-05
     +,   5.8387821E-05,   5.9506699E-05,   6.0604158E-05
     +,   6.1679537E-05,   6.2732353E-05,   6.3762425E-05
     +,   6.4769760E-05,   6.5754670E-05,   6.6717708E-05
     +,   6.7659719E-05,   6.8581823E-05,   6.9485453E-05
     +,   7.0372364E-05,   7.1244503E-05,   7.2104282E-05
     +,   7.2954317E-05,   7.3797484E-05,   7.4637042E-05
     +,   7.5476455E-05,   7.6319520E-05,   7.7170269E-05
     +,   7.8032921E-05,   7.8912017E-05,   7.9812198E-05
     +,   8.0738355E-05,   8.1695471E-05,   8.2688661E-05
     +,   8.3723200E-05,   8.4804218E-05,   8.5937085E-05
     +,   8.7126995E-05,   8.8379093E-05,   8.9698486E-05
     +,   9.1090114E-05,   9.2558686E-05,   9.4108698E-05
     +,   9.5744457E-05,   9.7469929E-05,   9.9288809E-05
     +,   1.0120442E-04,   1.0321978E-04,   1.0533750E-04
     +,   1.0756002E-04,   1.0988914E-04,   1.1232669E-04
     +,   1.1487401E-04,   1.1753231E-04,   1.2030259E-04
     +,   1.2318576E-04,   1.2618271E-04,   1.2929454E-04
     +,   1.3252215E-04,   1.3586707E-04,   1.3933129E-04
     +,   1.4291676E-04,   1.4662665E-04,   1.5046429E-04
     +,   1.5443425E-04,   1.5854147E-04,   1.6279230E-04
     +,   1.6719350E-04,   1.7175332E-04,   1.7648024E-04
     +,   1.8138408E-04,   1.8647531E-04,   1.9176475E-04
     +,   1.9726332E-04,   2.0298264E-04,   2.0893391E-04
     +,   2.1512751E-04,   2.2157350E-04,   2.2828006E-04
     +,   2.3525437E-04,   2.4250076E-04,   2.5002201E-04
     +,   2.5781692E-04,   2.6588220E-04,   2.7420980E-04
     +,   2.8278868E-04,   2.9160359E-04,   3.0063468E-04
     +,   3.0985783E-04,   3.1924515E-04,   3.2876522E-04
     +,   3.3838171E-04,   3.4805670E-04,   3.5774815E-04
     +,   3.6741392E-04,   3.7700954E-04,   3.8649235E-04
     +,   3.9581972E-04,   4.0495364E-04,   4.1385967E-04
     +,   4.2251076E-04,   4.3088911E-04,   4.3898719E-04
     +,   4.4681202E-04,   4.5438737E-04,   4.6175736E-04
     +,   4.6898905E-04,   4.7617668E-04,   4.8344448E-04
     +,   4.9095193E-04,   4.9889431E-04,   5.0750951E-04
     +,   5.1707774E-04,   5.2792602E-04,   5.4042874E-04
     +,   5.5500865E-04,   5.7213748E-04,   5.9233321E-04
     +,   6.1615824E-04,   6.4421725E-04,   6.7715219E-04
     +,   7.1563234E-04,   7.6035515E-04,   8.1202824E-04
     +,   8.7137445E-04,   9.3911233E-04,   1.0159714E-03
     +,   1.1026852E-03,   1.2000313E-03,   1.3088583E-03
     +,   1.4301717E-03,   1.5652284E-03,   1.7156538E-03
     +,   1.8836091E-03,   2.0719909E-03,   2.2846416E-03
     +,   2.5265394E-03,   2.8039198E-03,   3.1241560E-03
     +,   3.4951291E-03,   3.9239037E-03,   4.4148741E-03
     +,   4.9675810E-03,   5.5749221E-03,   6.2227366E-03
     +,   6.8914266E-03,   7.5600613E-03,   8.2136597E-03
     +,   8.8536059E-03,   9.5084673E-03,   1.0238537E-02
     +,   1.1126189E-02,   1.2251395E-02,   1.3663027E-02
     +,   1.5362293E-02,   1.7304055E-02,   1.9407021E-02
     +,   2.1563064E-02,   2.3651814E-02,   2.5572324E-02
     +,   2.7282909E-02,   2.8801935E-02,   3.0124400E-02
     +,   3.1111276E-02,   3.1515546E-02,   3.1191934E-02
     +,   3.0269908E-02,   2.9063843E-02,   2.7827006E-02
     +,   2.6647145E-02,   2.5552653E-02,   2.4619188E-02
     +,   2.3925271E-02,   2.3450082E-02,   2.3063362E-02
     +,   2.2610262E-02,   2.1999761E-02,   2.1246865E-02
     +,   2.0462885E-02,   1.9788358E-02,   1.9291509E-02
     +,   1.8908083E-02,   1.8484931E-02,   1.7894045E-02
     +,   1.7116245E-02,   1.6233498E-02,   1.5356958E-02
     +,   1.4559901E-02,   1.3855136E-02,   1.3212802E-02
     +,   1.2593035E-02,   1.1971204E-02,   1.1345484E-02
     +,   1.0728725E-02,   1.0134628E-02,   9.5685096E-03
     +,   9.0270285E-03,   8.5037611E-03,   7.9948278E-03
     +,   7.5006247E-03,   7.0241182E-03,   6.5678642E-03
     +,   6.1325240E-03,   5.7171360E-03,   5.3204070E-03
     +,   4.9419370E-03,   4.5828233E-03,   4.2455383E-03
     +,   3.9332793E-03,   3.6492152E-03,   3.3958275E-03
     +,   3.1744975E-03,   2.9852004E-03,   2.8264837E-03
     +,   2.6955898E-03,   2.5887222E-03,   2.5013534E-03
     +,   2.4285973E-03,   2.3655738E-03,   2.3077126E-03
     +,   2.2510146E-03,   2.1922311E-03,   2.1289831E-03
     +,   2.0597789E-03,   1.9839748E-03,   1.9016810E-03
     +,   1.8136315E-03,   1.7210159E-03,   1.6253100E-03
     +,   1.5281189E-03,   1.4310525E-03,   1.3355925E-03
     +,   1.2430302E-03,   1.1544155E-03,   1.0705350E-03
     +,   9.9190965E-04,   9.1881707E-04,   8.5132750E-04
     +,   7.8933657E-04,   7.3259813E-04,   6.8076840E-04
     +,   6.3344429E-04,   5.9018744E-04,   5.5054965E-04
     +,   5.1409431E-04,   4.8041518E-04,   4.4913910E-04
     +,   4.1993681E-04,   3.9252674E-04,   3.6667366E-04
     +,   3.4218410E-04,   3.1890618E-04,   2.9672505E-04
     +,   2.7555702E-04,   2.5534298E-04,   2.3604392E-04
     +,   2.1763824E-04,   2.0011542E-04,   1.8347100E-04
     +,   1.6770445E-04,   1.5281826E-04,   1.3881207E-04
     +,   1.2568319E-04,   1.1342572E-04,   1.0202914E-04
     +,   9.1477072E-05,   8.1748301E-05,   7.2817347E-05
     +,   6.4654152E-05,   5.7224319E-05,   5.0490260E-05
     +,   4.4412613E-05,   3.8949409E-05,   3.4058470E-05
     +,   2.9696605E-05,   2.5821555E-05,   2.2391387E-05
     +,   1.9366000E-05,   1.6706588E-05,   1.4376751E-05
     +,   1.2341983E-05,   1.0570458E-05,   9.0325839E-06
     +,   7.7012619E-06,   6.5519434E-06,   5.5622595E-06
     +,   4.7122353E-06,   3.9838774E-06,   3.3612746E-06
     +,   2.8302459E-06,   2.3783566E-06,   1.9946190E-06
     +,   1.6694695E-06,   1.3945228E-06,   1.1625255E-06
     +,   9.6715917E-07,   8.0298992E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz90 = Yx/0.279553191489362
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_hzonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5904133E-05,   4.7565820E-05
     +,   4.9274127E-05,   5.1029347E-05,   5.2831620E-05
     +,   5.4681048E-05,   5.6577588E-05,   5.8521160E-05
     +,   6.0511389E-05,   6.2548024E-05,   6.4630520E-05
     +,   6.6758214E-05,   6.8930283E-05,   7.1145863E-05
     +,   7.3403819E-05,   7.5702948E-05,   7.8041820E-05
     +,   8.0418926E-05,   8.2832528E-05,   8.5280815E-05
     +,   8.7761808E-05,   9.0273315E-05,   9.2813105E-05
     +,   9.5378899E-05,   9.7968063E-05,   1.0057820E-04
     +,   1.0320664E-04,   1.0585073E-04,   1.0850774E-04
     +,   1.1117508E-04,   1.1385005E-04,   1.1653017E-04
     +,   1.1921287E-04,   1.2189590E-04,   1.2457704E-04
     +,   1.2725440E-04,   1.2992622E-04,   1.3259104E-04
     +,   1.3524783E-04,   1.3789562E-04,   1.4053420E-04
     +,   1.4316344E-04,   1.4578381E-04,   1.4839614E-04
     +,   1.5100160E-04,   1.5360206E-04,   1.5619969E-04
     +,   1.5879711E-04,   1.6139736E-04,   1.6400385E-04
     +,   1.6662048E-04,   1.6925132E-04,   1.7190061E-04
     +,   1.7457306E-04,   1.7727316E-04,   1.8000574E-04
     +,   1.8277537E-04,   1.8558640E-04,   1.8844301E-04
     +,   1.9134904E-04,   1.9430781E-04,   1.9732217E-04
     +,   2.0039394E-04,   2.0352456E-04,   2.0671451E-04
     +,   2.0996317E-04,   2.1326912E-04,   2.1662982E-04
     +,   2.2004203E-04,   2.2350106E-04,   2.2700163E-04
     +,   2.3053752E-04,   2.3410187E-04,   2.3768710E-04
     +,   2.4128560E-04,   2.4488982E-04,   2.4849179E-04
     +,   2.5208469E-04,   2.5566248E-04,   2.5922086E-04
     +,   2.6275666E-04,   2.6626952E-04,   2.6976143E-04
     +,   2.7323802E-04,   2.7670787E-04,   2.8018418E-04
     +,   2.8368382E-04,   2.8722905E-04,   2.9084587E-04
     +,   2.9456583E-04,   2.9842477E-04,   3.0246284E-04
     +,   3.0672434E-04,   3.1125674E-04,   3.1611059E-04
     +,   3.2133699E-04,   3.2698843E-04,   3.3311566E-04
     +,   3.3976784E-04,   3.4698902E-04,   3.5481856E-04
     +,   3.6328757E-04,   3.7241876E-04,   3.8222331E-04
     +,   3.9270095E-04,   4.0383820E-04,   4.1560695E-04
     +,   4.2796353E-04,   4.4085106E-04,   4.5419726E-04
     +,   4.6791625E-04,   4.8191083E-04,   4.9607264E-04
     +,   5.1028794E-04,   5.2443740E-04,   5.3840416E-04
     +,   5.5207458E-04,   5.6534662E-04,   5.7813281E-04
     +,   5.9036876E-04,   6.0201751E-04,   6.1307597E-04
     +,   6.2358152E-04,   6.3361792E-04,   6.4331945E-04
     +,   6.5287371E-04,   6.6252501E-04,   6.7257311E-04
     +,   6.8337115E-04,   6.9531886E-04,   7.0885458E-04
     +,   7.2444126E-04,   7.4255170E-04,   7.6364586E-04
     +,   7.8815350E-04,   8.1644562E-04,   8.4881269E-04
     +,   8.8543881E-04,   9.2638767E-04,   9.7158650E-04
     +,   1.0208179E-03,   1.0737263E-03,   1.1298453E-03
     +,   1.1886206E-03,   1.2494639E-03,   1.3118294E-03
     +,   1.3752970E-03,   1.4396773E-03,   1.5051331E-03
     +,   1.5723039E-03,   1.6424204E-03,   1.7173742E-03
     +,   1.7997561E-03,   1.8927908E-03,   2.0001731E-03
     +,   2.1257589E-03,   2.2731505E-03,   2.4452009E-03
     +,   2.6434485E-03,   2.8676046E-03,   3.1152347E-03
     +,   3.3816348E-03,   3.6600369E-03,   3.9422237E-03
     +,   4.2194477E-03,   4.4836169E-03,   4.7285776E-03
     +,   4.9513956E-03,   5.1534893E-03,   5.3413487E-03
     +,   5.5267592E-03,   5.7263202E-03,   5.9599308E-03
     +,   6.2483680E-03,   6.6105751E-03,   7.0627411E-03
     +,   7.6210122E-03,   8.3079776E-03,   9.1576921E-03
     +,   1.0209625E-02,   1.1486326E-02,   1.2968746E-02
     +,   1.4600758E-02,   1.6337922E-02,   1.8197881E-02
     +,   2.0240866E-02,   2.2482777E-02,   2.4856042E-02
     +,   2.7299820E-02,   2.9869547E-02,   3.2685112E-02
     +,   3.5740916E-02,   3.8805962E-02,   4.1527972E-02
     +,   4.3585598E-02,   4.4704411E-02,   4.4646300E-02
     +,   4.3367114E-02,   4.1173555E-02,   3.8603183E-02
     +,   3.6132641E-02,   3.3967935E-02,   3.2027464E-02
     +,   3.0121690E-02,   2.8194139E-02,   2.6379665E-02
     +,   2.4827469E-02,   2.3517607E-02,   2.2268096E-02
     +,   2.0883119E-02,   1.9284336E-02,   1.7540270E-02
     +,   1.5807891E-02,   1.4244019E-02,   1.2940156E-02
     +,   1.1903535E-02,   1.1076602E-02,   1.0373598E-02
     +,   9.7151874E-03,   9.0502445E-03,   8.3623752E-03
     +,   7.6639475E-03,   6.9830297E-03,   6.3494220E-03
     +,   5.7846252E-03,   5.2977228E-03,   4.8861504E-03
     +,   4.5391559E-03,   4.2419303E-03,   3.9791791E-03
     +,   3.7375784E-03,   3.5071054E-03,   3.2814059E-03
     +,   3.0575024E-03,   2.8350514E-03,   2.6153871E-03
     +,   2.4006653E-03,   2.1932027E-03,   1.9950229E-03
     +,   1.8076341E-03,   1.6320068E-03,   1.4686427E-03
     +,   1.3176721E-03,   1.1789510E-03,   1.0521607E-03
     +,   9.3687465E-04,   8.3258509E-04,   7.3871500E-04
     +,   6.5463537E-04,   5.7967810E-04,   5.1312940E-04
     +,   4.5425064E-04,   4.0229774E-04,   3.5653429E-04
     +,   3.1624740E-04,   2.8076710E-04,   2.4948118E-04
     +,   2.2184034E-04,   1.9736006E-04,   1.7562337E-04
     +,   1.5627728E-04,   1.3902520E-04,   1.2361868E-04
     +,   1.0985054E-04,   9.7548429E-05,   8.6564847E-05
     +,   7.6772827E-05,   6.8061650E-05,   6.0332120E-05
     +,   5.3493583E-05,   4.7462603E-05,   4.2162123E-05
     +,   3.7520167E-05,   3.3469176E-05,   2.9946294E-05
     +,   2.6893462E-05,   2.4256648E-05,   2.1986605E-05
     +,   2.0038085E-05,   1.8370360E-05,   1.6946506E-05
     +,   1.5733694E-05,   1.4702560E-05,   1.3827291E-05
     +,   1.3085068E-05,   1.2456042E-05,   1.1922878E-05
     +,   1.1470572E-05,   1.1086226E-05,   1.0758721E-05
     +,   1.0478596E-05,   1.0237743E-05,   1.0029325E-05
     +,   9.8475175E-06,   9.6874410E-06,   9.5449677E-06
     +,   9.4166580E-06,   9.2996215E-06,   9.1914653E-06
     +,   9.0901885E-06,   8.9941504E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_hzonly_ttz95 = Yx/0.304872340425532
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.3443827E-08,   6.1505325E-08
     +,   7.0663198E-08,   8.1047403E-08,   9.2800605E-08
     +,   1.0607867E-07,   1.2105173E-07,   1.3790498E-07
     +,   1.5683884E-07,   1.7807155E-07,   2.0183744E-07
     +,   2.2838887E-07,   2.5799710E-07,   2.9095202E-07
     +,   3.2756284E-07,   3.6815874E-07,   4.1308815E-07
     +,   4.6271970E-07,   5.1744144E-07,   5.7766022E-07
     +,   6.4380203E-07,   7.1631069E-07,   7.9564467E-07
     +,   8.8228416E-07,   9.7671261E-07,   1.0794374E-06
     +,   1.1909682E-06,   1.3118253E-06,   1.4425332E-06
     +,   1.5836195E-06,   1.7356107E-06,   1.8990302E-06
     +,   2.0743926E-06,   2.2622019E-06,   2.4629489E-06
     +,   2.6771045E-06,   2.9051182E-06,   3.1474101E-06
     +,   3.4043865E-06,   3.6763936E-06,   3.9637725E-06
     +,   4.2668084E-06,   4.5857537E-06,   4.9208206E-06
     +,   5.2721794E-06,   5.6399608E-06,   6.0242610E-06
     +,   6.4251353E-06,   6.8426116E-06,   7.2766929E-06
     +,   7.7273617E-06,   8.1945891E-06,   8.6783375E-06
     +,   9.1786133E-06,   9.6953881E-06,   1.0228726E-05
     +,   1.0778711E-05,   1.1345502E-05,   1.1929344E-05
     +,   1.2530582E-05,   1.3149681E-05,   1.3787248E-05
     +,   1.4444004E-05,   1.5120886E-05,   1.5819005E-05
     +,   1.6539610E-05,   1.7284225E-05,   1.8054474E-05
     +,   1.8852283E-05,   1.9679672E-05,   2.0538939E-05
     +,   2.1432450E-05,   2.2362807E-05,   2.3332639E-05
     +,   2.4344723E-05,   2.5401901E-05,   2.6506968E-05
     +,   2.7662656E-05,   2.8871724E-05,   3.0136802E-05
     +,   3.1460262E-05,   3.2844462E-05,   3.4291399E-05
     +,   3.5803048E-05,   3.7381025E-05,   3.9026982E-05
     +,   4.0742285E-05,   4.2528540E-05,   4.4387252E-05
     +,   4.6320391E-05,   4.8330417E-05,   5.0420414E-05
     +,   5.2594431E-05,   5.4857996E-05,   5.7218265E-05
     +,   5.9684244E-05,   6.2267609E-05,   6.4982516E-05
     +,   6.7846609E-05,   7.0880698E-05,   7.4109739E-05
     +,   7.7562203E-05,   8.1271093E-05,   8.5272877E-05
     +,   8.9608075E-05,   9.4320574E-05,   9.9456454E-05
     +,   1.0506347E-04,   1.1119009E-04,   1.1788391E-04
     +,   1.2518905E-04,   1.3314607E-04,   1.4178784E-04
     +,   1.5113951E-04,   1.6121451E-04,   1.7201449E-04
     +,   1.8352551E-04,   1.9571940E-04,   2.0855018E-04
     +,   2.2195664E-04,   2.3586281E-04,   2.5017839E-04
     +,   2.6480382E-04,   2.7963545E-04,   2.9457212E-04
     +,   3.0952075E-04,   3.2441042E-04,   3.3919944E-04
     +,   3.5389076E-04,   3.6854090E-04,   3.8327358E-04
     +,   3.9828426E-04,   4.1384689E-04,   4.3030627E-04
     +,   4.4806907E-04,   4.6758135E-04,   4.8929389E-04
     +,   5.1362399E-04,   5.4091041E-04,   5.7136663E-04
     +,   6.0503802E-04,   6.4177648E-04,   6.8123848E-04
     +,   7.2290312E-04,   7.6612068E-04,   8.1020204E-04
     +,   8.5451815E-04,   8.9861598E-04,   9.4233261E-04
     +,   9.8588865E-04,   1.0299279E-03,   1.0754950E-03
     +,   1.1239453E-03,   1.1767843E-03,   1.2354484E-03
     +,   1.3010760E-03,   1.3743247E-03,   1.4552842E-03
     +,   1.5435263E-03,   1.6382904E-03,   1.7388165E-03
     +,   1.8447061E-03,   1.9562496E-03,   2.0746961E-03
     +,   2.2024573E-03,   2.3433019E-03,   2.5026856E-03
     +,   2.6882074E-03,   2.9100275E-03,   3.1807483E-03
     +,   3.5141942E-03,   3.9227679E-03,   4.4139693E-03
     +,   4.9872440E-03,   5.6327013E-03,   6.3337046E-03
     +,   7.0763975E-03,   7.8692213E-03,   8.7647997E-03
     +,   9.8620858E-03,   1.1274667E-02,   1.3081904E-02
     +,   1.5309648E-02,   1.8006772E-02,   2.1353232E-02
     +,   2.5601558E-02,   3.1049423E-02,   3.7955716E-02
     +,   4.6134301E-02,   5.6034118E-02,   6.8152055E-02
     +,   8.0288768E-02,   9.7062953E-02,   0.1137515    
     +,   0.1203163    ,   0.1245159    ,   0.1156510    
     +,   0.1066065    ,   9.7954378E-02,   8.6245097E-02
     +,   7.1956173E-02,   5.6008868E-02,   4.6121847E-02
     +,   4.1211952E-02,   3.6387168E-02,   3.0646153E-02
     +,   2.5319925E-02,   2.0699102E-02,   1.6507605E-02
     +,   1.2754677E-02,   9.5534036E-03,   6.9269054E-03
     +,   4.8480723E-03,   3.2733942E-03,   2.1354170E-03
     +,   1.3480919E-03,   8.2439912E-04,   4.8895000E-04
     +,   2.8213553E-04,   1.5956280E-04,   8.9776615E-05
     +,   5.1604195E-05,   3.1518070E-05,   2.1314614E-05
     +,   1.6267590E-05,   1.3786429E-05,   1.2518459E-05
     +,   1.1790976E-05,   1.1286039E-05,   1.0861515E-05
     +,   1.0457963E-05,   1.0052852E-05,   9.6392559E-06
     +,   9.2165019E-06,   8.7863054E-06,   8.3511377E-06
     +,   7.9136562E-06,   7.4765303E-06,   7.0423021E-06
     +,   6.6133225E-06,   6.1917649E-06,   5.7796256E-06
     +,   5.3786907E-06,   4.9904988E-06,   4.6163718E-06
     +,   4.2574370E-06,   3.9145989E-06,   3.5885337E-06
     +,   3.2797141E-06,   2.9884554E-06,   2.7148646E-06
     +,   2.4588880E-06,   2.2203417E-06,   1.9989086E-06
     +,   1.7941411E-06,   1.6054963E-06,   1.4323610E-06
     +,   1.2740539E-06,   1.1298318E-06,   9.9891520E-07
     +,   8.8050899E-07,   7.7380508E-07,   6.7798442E-07
     +,   5.9223845E-07,   5.1578189E-07,   4.4784315E-07
     +,   3.8768098E-07,   3.3459037E-07,   2.8790220E-07
     +,   2.4698315E-07,   2.1124076E-07,   1.8012706E-07
     +,   1.5313449E-07,   1.2979487E-07,   1.0968066E-07
     +,   9.2405088E-08,   7.7615674E-08,   6.4997423E-08
     +,   5.4266405E-08,   4.5170928E-08,   3.7486483E-08
     +,   3.1015858E-08,   2.5584729E-08,   2.1041220E-08
     +,   1.7252374E-08,   1.4103280E-08,   1.1494291E-08
     +,   9.3396739E-09,   7.5661424E-09,   6.1109002E-09
     +,   4.9207309E-09,   3.9504000E-09,   3.1618876E-09
     +,   2.5231277E-09,   2.0073621E-09,   1.5922064E-09
     +,   1.2591184E-09,   9.9270858E-10,   7.8031620E-10
     +,   6.1151423E-10,   4.7778947E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt100 = Yx/0.41832
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8202152E-08,   3.2468815E-08
     +,   3.7325172E-08,   4.2843983E-08,   4.9105566E-08
     +,   5.6198608E-08,   6.4220735E-08,   7.3279210E-08
     +,   8.3491400E-08,   9.4986426E-08,   1.0790459E-07
     +,   1.2239899E-07,   1.3863617E-07,   1.5679676E-07
     +,   1.7707629E-07,   1.9968613E-07,   2.2485403E-07
     +,   2.5282489E-07,   2.8386174E-07,   3.1824609E-07
     +,   3.5627863E-07,   3.9828012E-07,   4.4459046E-07
     +,   4.9557394E-07,   5.5161001E-07,   6.1310544E-07
     +,   6.8048547E-07,   7.5419791E-07,   8.3471150E-07
     +,   9.2251759E-07,   1.0181280E-06,   1.1220767E-06
     +,   1.2349163E-06,   1.3572217E-06,   1.4895852E-06
     +,   1.6326200E-06,   1.7869553E-06,   1.9532363E-06
     +,   2.1321353E-06,   2.3243201E-06,   2.5304962E-06
     +,   2.7513699E-06,   2.9876671E-06,   3.2401267E-06
     +,   3.5095027E-06,   3.7965665E-06,   4.1021040E-06
     +,   4.4269191E-06,   4.7718345E-06,   5.1376992E-06
     +,   5.5253822E-06,   5.9357867E-06,   6.3698399E-06
     +,   6.8285340E-06,   7.3128599E-06,   7.8239073E-06
     +,   8.3627929E-06,   8.9307096E-06,   9.5289170E-06
     +,   1.0158757E-05,   1.0821662E-05,   1.1519167E-05
     +,   1.2252866E-05,   1.3024515E-05,   1.3835990E-05
     +,   1.4689207E-05,   1.5586307E-05,   1.6529437E-05
     +,   1.7520984E-05,   1.8563316E-05,   1.9659044E-05
     +,   2.0810723E-05,   2.2021139E-05,   2.3292976E-05
     +,   2.4629078E-05,   2.6032298E-05,   2.7505384E-05
     +,   2.9051014E-05,   3.0671887E-05,   3.2370557E-05
     +,   3.4149260E-05,   3.6010249E-05,   3.7955284E-05
     +,   3.9986080E-05,   4.2103780E-05,   4.4309458E-05
     +,   4.6603520E-05,   4.8986338E-05,   5.1457569E-05
     +,   5.4016811E-05,   5.6663350E-05,   5.9396094E-05
     +,   6.2213847E-05,   6.5115542E-05,   6.8100351E-05
     +,   7.1167458E-05,   7.4317024E-05,   7.7549659E-05
     +,   8.0867489E-05,   8.4273634E-05,   8.7773340E-05
     +,   9.1373520E-05,   9.5083829E-05,   9.8916127E-05
     +,   1.0288540E-04,   1.0700968E-04,   1.1130970E-04
     +,   1.1580915E-04,   1.2053480E-04,   1.2551571E-04
     +,   1.3078233E-04,   1.3636684E-04,   1.4230104E-04
     +,   1.4861653E-04,   1.5534226E-04,   1.6250482E-04
     +,   1.7012532E-04,   1.7822014E-04,   1.8679776E-04
     +,   1.9585941E-04,   2.0539774E-04,   2.1539544E-04
     +,   2.2582586E-04,   2.3665382E-04,   2.4783559E-04
     +,   2.5931883E-04,   2.7104691E-04,   2.8295722E-04
     +,   2.9498726E-04,   3.0707355E-04,   3.1915834E-04
     +,   3.3118937E-04,   3.4312656E-04,   3.5494380E-04
     +,   3.6663434E-04,   3.7821481E-04,   3.8972922E-04
     +,   4.0125326E-04,   4.1289948E-04,   4.2482076E-04
     +,   4.3721159E-04,   4.5031070E-04,   4.6440319E-04
     +,   4.7981722E-04,   4.9691967E-04,   5.1611429E-04
     +,   5.3783046E-04,   5.6250941E-04,   5.9059146E-04
     +,   6.2249636E-04,   6.5859838E-04,   6.9919479E-04
     +,   7.4447825E-04,   7.9450756E-04,   8.4918295E-04
     +,   9.0822327E-04,   9.7116857E-04,   1.0374064E-03
     +,   1.1062112E-03,   1.1768141E-03,   1.2485151E-03
     +,   1.3208123E-03,   1.3935495E-03,   1.4670992E-03
     +,   1.5425461E-03,   1.6218406E-03,   1.7079046E-03
     +,   1.8046454E-03,   1.9168422E-03,   2.0498752E-03
     +,   2.2093111E-03,   2.4003729E-03,   2.6273236E-03
     +,   2.8926979E-03,   3.1963738E-03,   3.5346632E-03
     +,   3.8998208E-03,   4.2808028E-03,   4.6663242E-03
     +,   5.0501437E-03,   5.4373499E-03,   5.8497651E-03
     +,   6.3287723E-03,   6.9328463E-03,   7.7233491E-03
     +,   8.7327473E-03,   9.9257901E-03,   1.1190485E-02
     +,   1.2393486E-02,   1.3475806E-02,   1.4502892E-02
     +,   1.5634006E-02,   1.7112304E-02,   1.9258054E-02
     +,   2.2129118E-02,   2.5136389E-02,   2.7921120E-02
     +,   3.1718101E-02,   3.8545478E-02,   4.9674779E-02
     +,   6.5367818E-02,   8.1724368E-02,   9.7382918E-02
     +,   0.1173513    ,   0.1412747    ,   0.1542661    
     +,   0.1484131    ,   0.1392925    ,   0.1232025    
     +,   9.8535508E-02,   7.1876593E-02,   4.6708222E-02
     +,   2.6602039E-02,   1.2641157E-02,   4.8051360E-03
     +,   1.4710042E-03,   3.6610584E-04,   7.2500363E-05
     +,   1.1066089E-05,   1.2733569E-06,   1.0924129E-07
     +,   7.0148345E-09,   3.9797787E-10,   7.1103991E-11
     +,   4.8569870E-11,   3.8838047E-11,   3.1208990E-11
     +,   2.5065706E-11,   2.0117076E-11,   1.6132274E-11
     +,   1.2925432E-11,   1.0346387E-11,   8.2736812E-12
     +,   6.6092240E-12,   5.2738734E-12,   4.2035524E-12
     +,   3.3465071E-12,   2.6609979E-12,   2.1133243E-12
     +,   1.6762587E-12,   1.3278764E-12,   1.0505326E-12
     +,   8.3002854E-13,   6.5493054E-13,   5.1607189E-13
     +,   4.0610001E-13,   3.1912645E-13,   2.5043330E-13
     +,   1.9625183E-13,   1.5357816E-13,   1.2001454E-13
     +,   9.3652801E-14,   7.2977601E-14,   5.6786176E-14
     +,   4.4123871E-14,   3.4235632E-14,   2.6525032E-14
     +,   2.0521574E-14,   1.5853875E-14,   1.2230008E-14
     +,   9.4207606E-15,   7.2463033E-15,   5.5655968E-15
     +,   4.2684226E-15,   3.2688208E-15,   2.4996306E-15
     +,   1.9086132E-15,   1.4551916E-15,   1.1078611E-15
     +,   8.4218469E-16,   6.3926826E-16,   4.8452317E-16
     +,   3.6669483E-16,   2.7710770E-16,   2.0909403E-16
     +,   1.5753992E-16,   1.1851872E-16,   8.9030177E-17
     +,   6.6777841E-17,   5.0012617E-17,   3.7399903E-17
     +,   2.7926240E-17,   2.0820675E-17,   1.5499816E-17
     +,   1.1521198E-17,   8.5509879E-18,   6.3368996E-18
     +,   4.6889358E-18,   3.4643089E-18,   2.5556086E-18
     +,   1.8824157E-18,   1.3844255E-18,   1.0166361E-18
     +,   7.4540714E-19,   5.4571142E-19,   3.9889823E-19
     +,   2.9113901E-19,   2.1216215E-19,   1.5437279E-19
     +,   1.1215120E-19,   8.1352800E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt105 = Yx/0.409857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0610078E-11,   5.2123104E-11
     +,   6.6741869E-11,   8.5258536E-11,   1.0865493E-10
     +,   1.3814395E-10,   1.7522109E-10,   2.2172381E-10
     +,   2.7990352E-10,   3.5251499E-10,   4.4291315E-10
     +,   5.5517657E-10,   6.9424949E-10,   8.6610646E-10
     +,   1.0779514E-09,   1.3384397E-09,   1.6579446E-09
     +,   2.0488649E-09,   2.5259719E-09,   3.1068166E-09
     +,   3.8121892E-09,   4.6666542E-09,   5.6991150E-09
     +,   6.9435915E-09,   8.4397636E-09,   1.0234112E-08
     +,   1.2380625E-08,   1.4941957E-08,   1.7990567E-08
     +,   2.1610028E-08,   2.5896345E-08,   3.0959562E-08
     +,   3.6925318E-08,   4.3936687E-08,   5.2155954E-08
     +,   6.1766713E-08,   7.2975844E-08,   8.6015618E-08
     +,   1.0114691E-07,   1.1865904E-07,   1.3887559E-07
     +,   1.6215378E-07,   1.8888825E-07,   2.1951286E-07
     +,   2.5450308E-07,   2.9437751E-07,   3.3970008E-07
     +,   3.9108136E-07,   4.4917962E-07,   5.1470158E-07
     +,   5.8840277E-07,   6.7108749E-07,   7.6360629E-07
     +,   8.6686265E-07,   9.8179316E-07,   1.1093877E-06
     +,   1.2506684E-06,   1.4066928E-06,   1.5785480E-06
     +,   1.7673457E-06,   1.9742156E-06,   2.2003030E-06
     +,   2.4467427E-06,   2.7146873E-06,   3.0052850E-06
     +,   3.3196422E-06,   3.6588888E-06,   4.0240920E-06
     +,   4.4163476E-06,   4.8366910E-06,   5.2862056E-06
     +,   5.7659345E-06,   6.2770191E-06,   6.8206150E-06
     +,   7.3980518E-06,   8.0108584E-06,   8.6607979E-06
     +,   9.3500148E-06,   1.0081213E-05,   1.0857776E-05
     +,   1.1683877E-05,   1.2564881E-05,   1.3507375E-05
     +,   1.4519691E-05,   1.5611951E-05,   1.6796665E-05
     +,   1.8088745E-05,   1.9506157E-05,   2.1069825E-05
     +,   2.2804177E-05,   2.4737168E-05,   2.6900116E-05
     +,   2.9327659E-05,   3.2057582E-05,   3.5130150E-05
     +,   3.8586935E-05,   4.2470489E-05,   4.6822093E-05
     +,   5.1681182E-05,   5.7082361E-05,   6.3054737E-05
     +,   6.9618451E-05,   7.6784076E-05,   8.4549072E-05
     +,   9.2897615E-05,   1.0179869E-04,   1.1120467E-04
     +,   1.2105153E-04,   1.3126025E-04,   1.4173743E-04
     +,   1.5237649E-04,   1.6306290E-04,   1.7367513E-04
     +,   1.8409155E-04,   1.9419238E-04,   2.0386721E-04
     +,   2.1301684E-04,   2.2156051E-04,   2.2943714E-04
     +,   2.3661026E-04,   2.4306931E-04,   2.4882957E-04
     +,   2.5393302E-04,   2.5844632E-04,   2.6245834E-04
     +,   2.6607592E-04,   2.6942042E-04,   2.7262280E-04
     +,   2.7581965E-04,   2.7914855E-04,   2.8274627E-04
     +,   2.8674625E-04,   2.9127975E-04,   2.9647740E-04
     +,   3.0247448E-04,   3.0941705E-04,   3.1746936E-04
     +,   3.2682228E-04,   3.3770208E-04,   3.5037514E-04
     +,   3.6514769E-04,   3.8236100E-04,   4.0237856E-04
     +,   4.2556247E-04,   4.5223802E-04,   4.8265836E-04
     +,   5.1695830E-04,   5.5510836E-04,   5.9688394E-04
     +,   6.4184854E-04,   6.8936130E-04,   7.3861278E-04
     +,   7.8870344E-04,   8.3875871E-04,   8.8806538E-04
     +,   9.3622511E-04,   9.8331145E-04,   1.0299982E-03
     +,   1.0776294E-03,   1.1282073E-03,   1.1842885E-03
     +,   1.2487582E-03,   1.3244827E-03,   1.4138825E-03
     +,   1.5184524E-03,   1.6382969E-03,   1.7717702E-03
     +,   1.9153738E-03,   2.0640146E-03,   2.2116988E-03
     +,   2.3527066E-03,   2.4832084E-03,   2.6030724E-03
     +,   2.7174989E-03,   2.8379199E-03,   2.9815834E-03
     +,   3.1690670E-03,   3.4194908E-03,   3.7440085E-03
     +,   4.1393605E-03,   4.5845704E-03,   5.0442219E-03
     +,   5.4801926E-03,   5.8694696E-03,   6.2206164E-03
     +,   6.5794988E-03,   7.0194621E-03,   7.6192389E-03
     +,   8.4361862E-03,   9.4806114E-03,   1.0701087E-02
     +,   1.1997375E-02,   1.3264058E-02,   1.4444954E-02
     +,   1.5595448E-02,   1.6942782E-02,   1.8806823E-02
     +,   2.1289300E-02,   2.4117487E-02,   2.7130883E-02
     +,   3.0729644E-02,   3.5145763E-02,   4.0274989E-02
     +,   4.7174729E-02,   5.8681317E-02,   7.5650111E-02
     +,   9.5743679E-02,   0.1205542    ,   0.1416421    
     +,   0.1701344    ,   0.1897909    ,   0.1612164    
     +,   9.6635394E-02,   4.0604141E-02,   1.0238231E-02
     +,   1.4364073E-03,   1.9332973E-04,   6.2026113E-05
     +,   3.3512231E-05,   2.7156937E-05,   2.6388432E-05
     +,   2.6375190E-05,   2.6334463E-05,   2.6197275E-05
     +,   2.5963256E-05,   2.5636935E-05,   2.5224150E-05
     +,   2.4731758E-05,   2.4167446E-05,   2.3539542E-05
     +,   2.2856884E-05,   2.2128561E-05,   2.1363699E-05
     +,   2.0571291E-05,   1.9760124E-05,   1.8938459E-05
     +,   1.8113988E-05,   1.7293782E-05,   1.6484149E-05
     +,   1.5690548E-05,   1.4917590E-05,   1.4169103E-05
     +,   1.3448093E-05,   1.2756729E-05,   1.2096453E-05
     +,   1.1468086E-05,   1.0871850E-05,   1.0307415E-05
     +,   9.7740276E-06,   9.2706332E-06,   8.7958624E-06
     +,   8.3481509E-06,   7.9258407E-06,   7.5272064E-06
     +,   7.1504846E-06,   6.7939459E-06,   6.4559536E-06
     +,   6.1349624E-06,   5.8295227E-06,   5.5383130E-06
     +,   5.2601663E-06,   4.9940481E-06,   4.7390427E-06
     +,   4.4943586E-06,   4.2593474E-06,   4.0334435E-06
     +,   3.8161775E-06,   3.6071779E-06,   3.4061409E-06
     +,   3.2128105E-06,   3.0269773E-06,   2.8484810E-06
     +,   2.6771893E-06,   2.5129768E-06,   2.3557311E-06
     +,   2.2053623E-06,   2.0617604E-06,   1.9248334E-06
     +,   1.7944650E-06,   1.6705478E-06,   1.5529497E-06
     +,   1.4415430E-06,   1.3361766E-06,   1.2367017E-06
     +,   1.1429468E-06,   1.0547448E-06,   9.7190969E-07
     +,   8.9425049E-07,   8.2157680E-07,   7.5368519E-07
     +,   6.9037628E-07,   6.3144137E-07,   5.7667825E-07
     +,   5.2587728E-07,   4.7883731E-07,   4.3535275E-07
     +,   3.9522732E-07,   3.5826307E-07,   3.2427178E-07
     +,   2.9306611E-07,   2.6446864E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt107 = Yx/0.379714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2060349E-06,   2.3235095E-06
     +,   2.4454914E-06,   2.5720474E-06,   2.7032393E-06
     +,   2.8391235E-06,   2.9797511E-06,   3.1251668E-06
     +,   3.2754076E-06,   3.4305115E-06,   3.5905020E-06
     +,   3.7553989E-06,   3.9252163E-06,   4.0999603E-06
     +,   4.2796300E-06,   4.4642188E-06,   4.6537120E-06
     +,   4.8480883E-06,   5.0473191E-06,   5.2513719E-06
     +,   5.4602042E-06,   5.6737704E-06,   5.8920123E-06
     +,   6.1148858E-06,   6.3423081E-06,   6.5742270E-06
     +,   6.8105651E-06,   7.0512465E-06,   7.2961948E-06
     +,   7.5453304E-06,   7.7985706E-06,   8.0558375E-06
     +,   8.3170480E-06,   8.5821266E-06,   8.8509942E-06
     +,   9.1235825E-06,   9.3998224E-06,   9.6796512E-06
     +,   9.9630288E-06,   1.0249893E-05,   1.0540227E-05
     +,   1.0834001E-05,   1.1131209E-05,   1.1431855E-05
     +,   1.1735960E-05,   1.2043561E-05,   1.2354715E-05
     +,   1.2669497E-05,   1.2988001E-05,   1.3310346E-05
     +,   1.3636670E-05,   1.3967138E-05,   1.4301931E-05
     +,   1.4641283E-05,   1.4985410E-05,   1.5334599E-05
     +,   1.5689142E-05,   1.6049367E-05,   1.6415641E-05
     +,   1.6788361E-05,   1.7167955E-05,   1.7554912E-05
     +,   1.7949729E-05,   1.8352994E-05,   1.8765340E-05
     +,   1.9187439E-05,   1.9620067E-05,   2.0064044E-05
     +,   2.0520332E-05,   2.0989944E-05,   2.1474083E-05
     +,   2.1974010E-05,   2.2491244E-05,   2.3027393E-05
     +,   2.3584354E-05,   2.4164254E-05,   2.4769470E-05
     +,   2.5402696E-05,   2.6067024E-05,   2.6765987E-05
     +,   2.7503504E-05,   2.8284152E-05,   2.9113049E-05
     +,   2.9996145E-05,   3.0940144E-05,   3.1952874E-05
     +,   3.3043161E-05,   3.4221364E-05,   3.5499266E-05
     +,   3.6890600E-05,   3.8411268E-05,   4.0079558E-05
     +,   4.1916552E-05,   4.3946748E-05,   4.6198267E-05
     +,   4.8703099E-05,   5.1498035E-05,   5.4624328E-05
     +,   5.8128793E-05,   6.2063162E-05,   6.6485016E-05
     +,   7.1456685E-05,   7.7046061E-05,   8.3324623E-05
     +,   9.0367714E-05,   9.8252938E-05,   1.0705789E-04
     +,   1.1685851E-04,   1.2772762E-04,   1.3973164E-04
     +,   1.5292664E-04,   1.6735826E-04,   1.8305518E-04
     +,   2.0003054E-04,   2.1827518E-04,   2.3776079E-04
     +,   2.5843401E-04,   2.8022227E-04,   3.0302923E-04
     +,   3.2674306E-04,   3.5123868E-04,   3.7638159E-04
     +,   4.0203723E-04,   4.2808001E-04,   4.5440148E-04
     +,   4.8091629E-04,   5.0757773E-04,   5.3437881E-04
     +,   5.6136557E-04,   5.8863370E-04,   6.1633985E-04
     +,   6.4469117E-04,   6.7394954E-04,   7.0441980E-04
     +,   7.3644461E-04,   7.7039551E-04,   8.0665859E-04
     +,   8.4562821E-04,   8.8770146E-04,   9.3327009E-04
     +,   9.8271249E-04,   1.0363909E-03,   1.0946502E-03
     +,   1.1578021E-03,   1.2260980E-03,   1.2997128E-03
     +,   1.3787003E-03,   1.4629452E-03,   1.5521337E-03
     +,   1.6457392E-03,   1.7430390E-03,   1.8431668E-03
     +,   1.9452235E-03,   2.0484193E-03,   2.1522101E-03
     +,   2.2563972E-03,   2.3611721E-03,   2.4670775E-03
     +,   2.5748627E-03,   2.6853026E-03,   2.7990616E-03
     +,   2.9166411E-03,   3.0384560E-03,   3.1650856E-03
     +,   3.2975748E-03,   3.4375926E-03,   3.5873698E-03
     +,   3.7493792E-03,   3.9259926E-03,   4.1195047E-03
     +,   4.3329108E-03,   4.5714602E-03,   4.8441486E-03
     +,   5.1637688E-03,   5.5441200E-03,   5.9942985E-03
     +,   6.5115532E-03,   7.0762630E-03,   7.6531428E-03
     +,   8.2009230E-03,   8.6887153E-03,   9.1126012E-03
     +,   9.5024090E-03,   9.9106655E-03,   1.0386624E-02
     +,   1.0954771E-02,   1.1623716E-02,   1.2424288E-02
     +,   1.3424196E-02,   1.4659996E-02,   1.6029613E-02
     +,   1.7304979E-02,   1.8344702E-02,   1.9313382E-02
     +,   2.0604786E-02,   2.2469413E-02,   2.4759753E-02
     +,   2.7145695E-02,   2.9555419E-02,   3.2240510E-02
     +,   3.5450071E-02,   3.9559748E-02,   4.5368310E-02
     +,   5.2318353E-02,   5.7762727E-02,   6.1973255E-02
     +,   6.8628170E-02,   7.7854834E-02,   8.6231567E-02
     +,   9.1674961E-02,   9.3103334E-02,   8.6352699E-02
     +,   6.6791646E-02,   3.9686751E-02,   1.7168626E-02
     +,   5.2463403E-03,   1.1448298E-03,   2.0417478E-04
     +,   4.1186839E-05,   1.0210956E-05,   2.3351986E-06
     +,   4.2773326E-07,   7.2815986E-08,   2.2968123E-08
     +,   1.6395491E-08,   1.4392989E-08,   1.2878004E-08
     +,   1.1528174E-08,   1.0312899E-08,   9.2189536E-09
     +,   8.2349461E-09,   7.3504975E-09,   6.5560943E-09
     +,   5.8430794E-09,   5.2036384E-09,   4.6305946E-09
     +,   4.1174406E-09,   3.6582883E-09,   3.2477925E-09
     +,   2.8810792E-09,   2.5537277E-09,   2.2617617E-09
     +,   2.0015773E-09,   1.7698935E-09,   1.5637561E-09
     +,   1.3805055E-09,   1.2177408E-09,   1.0732887E-09
     +,   9.4519303E-10,   8.3170437E-10,   7.3123996E-10
     +,   6.4237743E-10,   5.6384647E-10,   4.9450777E-10
     +,   4.3333626E-10,   3.7941417E-10,   3.3192521E-10
     +,   2.9013891E-10,   2.5340149E-10,   2.2112949E-10
     +,   1.9280616E-10,   1.6797043E-10,   1.4621102E-10
     +,   1.2716303E-10,   1.1050411E-10,   9.5946869E-11
     +,   8.3236813E-11,   7.2149696E-11,   6.2486898E-11
     +,   5.4072680E-11,   4.6751748E-11,   4.0387898E-11
     +,   3.4861048E-11,   3.0065086E-11,   2.5906902E-11
     +,   2.2305054E-11,   1.9187643E-11,   1.6492061E-11
     +,   1.4163113E-11,   1.2152822E-11,   1.0418985E-11
     +,   8.9249936E-12,   7.6387308E-12,   6.5323298E-12
     +,   5.5814233E-12,   4.7649254E-12,   4.0644254E-12
     +,   3.4639500E-12,   2.9497045E-12,   2.5096581E-12
     +,   2.1334599E-12,   1.8121069E-12,   1.5378598E-12
     +,   1.3040053E-12,   1.1047790E-12,   9.3519149E-13
     +,   7.9096831E-13,   6.6841747E-13,   5.6437667E-13
     +,   4.7612370E-13,   4.0133194E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt110 = Yx/0.329291666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8819810E-07,   7.5746817E-07
     +,   8.3281873E-07,   9.1467831E-07,   1.0034945E-06
     +,   1.0997326E-06,   1.2038755E-06,   1.3164237E-06
     +,   1.4378908E-06,   1.5688112E-06,   1.7097281E-06
     +,   1.8611968E-06,   2.0237837E-06,   2.1980643E-06
     +,   2.3846192E-06,   2.5840313E-06,   2.7968870E-06
     +,   3.0237704E-06,   3.2652590E-06,   3.5219241E-06
     +,   3.7943244E-06,   4.0830050E-06,   4.3884843E-06
     +,   4.7112821E-06,   5.0518529E-06,   5.4106586E-06
     +,   5.7881043E-06,   6.1845617E-06,   6.6003613E-06
     +,   7.0357873E-06,   7.4910690E-06,   7.9663896E-06
     +,   8.4618669E-06,   8.9775613E-06,   9.5134710E-06
     +,   1.0069529E-05,   1.0645597E-05,   1.1241460E-05
     +,   1.1856870E-05,   1.2491442E-05,   1.3144785E-05
     +,   1.3816402E-05,   1.4505738E-05,   1.5212169E-05
     +,   1.5935006E-05,   1.6673503E-05,   1.7426857E-05
     +,   1.8194223E-05,   1.8974697E-05,   1.9767349E-05
     +,   2.0571219E-05,   2.1385318E-05,   2.2208640E-05
     +,   2.3040227E-05,   2.3879038E-05,   2.4724128E-05
     +,   2.5574553E-05,   2.6429401E-05,   2.7287828E-05
     +,   2.8149037E-05,   2.9012328E-05,   2.9877079E-05
     +,   3.0742725E-05,   3.1608877E-05,   3.2475258E-05
     +,   3.3341632E-05,   3.4208028E-05,   3.5074474E-05
     +,   3.5941292E-05,   3.6808815E-05,   3.7677662E-05
     +,   3.8548493E-05,   3.9422219E-05,   4.0299823E-05
     +,   4.1182502E-05,   4.2071599E-05,   4.2968564E-05
     +,   4.3874963E-05,   4.4792549E-05,   4.5723209E-05
     +,   4.6668854E-05,   4.7631620E-05,   4.8613627E-05
     +,   4.9617229E-05,   5.0644750E-05,   5.1698775E-05
     +,   5.2781823E-05,   5.3896758E-05,   5.5046381E-05
     +,   5.6233846E-05,   5.7462512E-05,   5.8735950E-05
     +,   6.0058082E-05,   6.1433362E-05,   6.2866871E-05
     +,   6.4364249E-05,   6.5932290E-05,   6.7578825E-05
     +,   6.9313472E-05,   7.1147653E-05,   7.3095660E-05
     +,   7.5174787E-05,   7.7406919E-05,   7.9819023E-05
     +,   8.2444938E-05,   8.5326988E-05,   8.8517510E-05
     +,   9.2081187E-05,   9.6097720E-05,   1.0066397E-04
     +,   1.0589597E-04,   1.1193207E-04,   1.1893308E-04
     +,   1.2708468E-04,   1.3659504E-04,   1.4769453E-04
     +,   1.6062908E-04,   1.7565671E-04,   1.9303485E-04
     +,   2.1301258E-04,   2.3581611E-04,   2.6163252E-04
     +,   2.9059572E-04,   3.2277530E-04,   3.5816245E-04
     +,   3.9665983E-04,   4.3808654E-04,   4.8217250E-04
     +,   5.2858063E-04,   5.7691243E-04,   6.2674511E-04
     +,   6.7764590E-04,   7.2921778E-04,   7.8111462E-04
     +,   8.3308009E-04,   8.8496454E-04,   9.3673059E-04
     +,   9.8846108E-04,   1.0403499E-03,   1.0926784E-03
     +,   1.1457754E-03,   1.1999842E-03,   1.2556146E-03
     +,   1.3128995E-03,   1.3719493E-03,   1.4327446E-03
     +,   1.4951329E-03,   1.5588556E-03,   1.6236157E-03
     +,   1.6891753E-03,   1.7554697E-03,   1.8227404E-03
     +,   1.8916994E-03,   1.9636939E-03,   2.0408581E-03
     +,   2.1262257E-03,   2.2237692E-03,   2.3383049E-03
     +,   2.4751881E-03,   2.6397966E-03,   2.8368365E-03
     +,   3.0694443E-03,   3.3382252E-03,   3.6403451E-03
     +,   3.9688931E-03,   4.3127406E-03,   4.6572289E-03
     +,   4.9861176E-03,   5.2848798E-03,   5.5450210E-03
     +,   5.7685454E-03,   5.9711360E-03,   6.1821905E-03
     +,   6.4405245E-03,   6.7856093E-03,   7.2456072E-03
     +,   7.8249518E-03,   8.4962845E-03,   9.2020938E-03
     +,   9.8687084E-03,   1.0428003E-02,   1.0837271E-02
     +,   1.1089694E-02,   1.1215345E-02,   1.1278374E-02
     +,   1.1374100E-02,   1.1624511E-02,   1.2162443E-02
     +,   1.3084110E-02,   1.4363839E-02,   1.5798207E-02
     +,   1.7104363E-02,   1.8176412E-02,   1.9255698E-02
     +,   2.0746931E-02,   2.2786079E-02,   2.5085216E-02
     +,   2.7352355E-02,   2.9660732E-02,   3.2208975E-02
     +,   3.5004959E-02,   3.7693817E-02,   3.9600529E-02
     +,   4.0550571E-02,   4.1164272E-02,   4.1750919E-02
     +,   4.2044412E-02,   4.1849431E-02,   4.0880501E-02
     +,   3.8686253E-02,   3.5067368E-02,   2.9917309E-02
     +,   2.3220006E-02,   1.5771287E-02,   9.1135073E-03
     +,   4.4123568E-03,   1.7758362E-03,   5.9079373E-04
     +,   1.6155781E-04,   3.6117286E-05,   6.5736540E-06
     +,   9.7664906E-07,   1.2431299E-07,   1.9310656E-08
     +,   8.1493665E-09,   6.4810028E-09,   5.6628218E-09
     +,   4.9810329E-09,   4.3801802E-09,   3.8491663E-09
     +,   3.3801353E-09,   2.9661462E-09,   2.6009881E-09
     +,   2.2791200E-09,   1.9956286E-09,   1.7461149E-09
     +,   1.5266574E-09,   1.3337859E-09,   1.1644115E-09
     +,   1.0157791E-09,   8.8544166E-10,   7.7123946E-10
     +,   6.7125389E-10,   5.8378019E-10,   5.0730947E-10
     +,   4.4051246E-10,   3.8221276E-10,   3.3136779E-10
     +,   2.8705835E-10,   2.4847732E-10,   2.1491017E-10
     +,   1.8572802E-10,   1.6037918E-10,   1.3837884E-10
     +,   1.1929951E-10,   1.0276664E-10,   8.8452377E-11
     +,   7.6069852E-11,   6.5366781E-11,   5.6122891E-11
     +,   4.8146209E-11,   4.1269023E-11,   3.5344588E-11
     +,   3.0245060E-11,   2.5859618E-11,   2.2091350E-11
     +,   1.8856118E-11,   1.6080972E-11,   1.3702643E-11
     +,   1.1666066E-11,   9.9235889E-12,   8.4341171E-12
     +,   7.1620596E-12,   6.0765889E-12,   5.1511347E-12
     +,   4.3628543E-12,   3.6919625E-12,   3.1215237E-12
     +,   2.6368942E-12,   2.2255683E-12,   1.8767407E-12
     +,   1.5812027E-12,   1.3310197E-12,   1.1194389E-12
     +,   9.4065099E-13,   7.8972164E-13,   6.6242069E-13
     +,   5.5514198E-13,   4.6482528E-13,   3.8885309E-13
     +,   3.2500887E-13,   2.7140258E-13,   2.2643602E-13
     +,   1.8874960E-13,   1.5719460E-13,   1.3079689E-13
     +,   1.0873475E-13,   9.0312103E-14,   7.4943612E-14
     +,   6.2133899E-14,   5.1467504E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt115 = Yx/0.24104347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.8449001E-07,   6.3144444E-07
     +,   6.8159602E-07,   7.3511183E-07,   7.9216431E-07
     +,   8.5292925E-07,   9.1758830E-07,   9.8632609E-07
     +,   1.0593299E-06,   1.1367950E-06,   1.2189161E-06
     +,   1.3058914E-06,   1.3979225E-06,   1.4952144E-06
     +,   1.5979729E-06,   1.7064064E-06,   1.8207255E-06
     +,   1.9411427E-06,   2.0678710E-06,   2.2011259E-06
     +,   2.3411260E-06,   2.4880894E-06,   2.6422356E-06
     +,   2.8037971E-06,   2.9729918E-06,   3.1500626E-06
     +,   3.3352453E-06,   3.5287878E-06,   3.7309474E-06
     +,   3.9419933E-06,   4.1622070E-06,   4.3918931E-06
     +,   4.6313717E-06,   4.8809920E-06,   5.1411312E-06
     +,   5.4122006E-06,   5.6946528E-06,   5.9889826E-06
     +,   6.2957561E-06,   6.6155635E-06,   6.9490980E-06
     +,   7.2971084E-06,   7.6604274E-06,   8.0399841E-06
     +,   8.4367994E-06,   8.8520046E-06,   9.2868449E-06
     +,   9.7426837E-06,   1.0221017E-05,   1.0723472E-05
     +,   1.1251812E-05,   1.1807943E-05,   1.2393907E-05
     +,   1.3011925E-05,   1.3664287E-05,   1.4353497E-05
     +,   1.5082140E-05,   1.5852936E-05,   1.6668711E-05
     +,   1.7532391E-05,   1.8446965E-05,   1.9415505E-05
     +,   2.0441052E-05,   2.1526723E-05,   2.2675637E-05
     +,   2.3890736E-05,   2.5175059E-05,   2.6531356E-05
     +,   2.7962418E-05,   2.9470679E-05,   3.1058571E-05
     +,   3.2728087E-05,   3.4481192E-05,   3.6319343E-05
     +,   3.8243870E-05,   4.0255822E-05,   4.2355783E-05
     +,   4.4544016E-05,   4.6820594E-05,   4.9185284E-05
     +,   5.1637322E-05,   5.4175965E-05,   5.6799876E-05
     +,   5.9507805E-05,   6.2297957E-05,   6.5168693E-05
     +,   6.8117864E-05,   7.1143593E-05,   7.4243515E-05
     +,   7.7415549E-05,   8.0657584E-05,   8.3967330E-05
     +,   8.7342589E-05,   9.0781410E-05,   9.4281997E-05
     +,   9.7842349E-05,   1.0146112E-04,   1.0513666E-04
     +,   1.0886806E-04,   1.1265417E-04,   1.1649460E-04
     +,   1.2038882E-04,   1.2433714E-04,   1.2833987E-04
     +,   1.3239813E-04,   1.3651358E-04,   1.4068840E-04
     +,   1.4492542E-04,   1.4922868E-04,   1.5360335E-04
     +,   1.5805544E-04,   1.6259310E-04,   1.6722562E-04
     +,   1.7196516E-04,   1.7682597E-04,   1.8182598E-04
     +,   1.8698632E-04,   1.9233346E-04,   1.9789849E-04
     +,   2.0371964E-04,   2.0984276E-04,   2.1632221E-04
     +,   2.2322290E-04,   2.3062181E-04,   2.3860933E-04
     +,   2.4728975E-04,   2.5678379E-04,   2.6722765E-04
     +,   2.7877471E-04,   2.9159227E-04,   3.0586336E-04
     +,   3.2178036E-04,   3.3954560E-04,   3.5936414E-04
     +,   3.8144272E-04,   4.0598644E-04,   4.3319448E-04
     +,   4.6326063E-04,   4.9637782E-04,   5.3274160E-04
     +,   5.7255320E-04,   6.1602949E-04,   6.6341565E-04
     +,   7.1498804E-04,   7.7105092E-04,   8.3193864E-04
     +,   8.9798949E-04,   9.6949743E-04,   1.0466492E-03
     +,   1.1294351E-03,   1.2175305E-03,   1.3101668E-03
     +,   1.4060311E-03,   1.5032217E-03,   1.5992842E-03
     +,   1.6913698E-03,   1.7765778E-03,   1.8524330E-03
     +,   1.9174707E-03,   1.9718439E-03,   2.0178461E-03
     +,   2.0601435E-03,   2.1056095E-03,   2.1626705E-03
     +,   2.2401970E-03,   2.3461541E-03,   2.4862853E-03
     +,   2.6631905E-03,   2.8759462E-03,   3.1202384E-03
     +,   3.3888079E-03,   3.6722480E-03,   3.9602695E-03
     +,   4.2438321E-03,   4.5181210E-03,   4.7853892E-03
     +,   5.0554122E-03,   5.3417701E-03,   5.6550279E-03
     +,   5.9978096E-03,   6.3676117E-03,   6.7672003E-03
     +,   7.2136647E-03,   7.7366931E-03,   8.3685312E-03
     +,   9.1368789E-03,   1.0062247E-02,   1.1148164E-02
     +,   1.2359163E-02,   1.3598547E-02,   1.4706725E-02
     +,   1.5505914E-02,   1.5896745E-02,   1.5929392E-02
     +,   1.5756771E-02,   1.5541323E-02,   1.5462953E-02
     +,   1.5764339E-02,   1.6655950E-02,   1.8125637E-02
     +,   1.9860191E-02,   2.1411024E-02,   2.2562524E-02
     +,   2.3548899E-02,   2.4760971E-02,   2.6289754E-02
     +,   2.7837900E-02,   2.8805111E-02,   2.8431335E-02
     +,   2.6246522E-02,   2.2431334E-02,   1.7637184E-02
     +,   1.2638598E-02,   8.1529235E-03,   4.6838578E-03
     +,   2.3790444E-03,   1.0626020E-03,   4.1507749E-04
     +,   1.4093351E-04,   4.1336978E-05,   1.0413023E-05
     +,   2.2416968E-06,   4.1097584E-07,   6.4203341E-08
     +,   8.7628722E-09,   1.2628119E-09,   3.7425685E-10
     +,   2.5362318E-10,   2.1204928E-10,   1.8126600E-10
     +,   1.5510009E-10,   1.3261016E-10,   1.1328109E-10
     +,   9.6683203E-11,   8.2444558E-11,   7.0240848E-11
     +,   5.9790568E-11,   5.0850303E-11,   4.3209294E-11
     +,   3.6684374E-11,   3.1117491E-11,   2.6372458E-11
     +,   2.2331748E-11,   1.8893841E-11,   1.5971315E-11
     +,   1.3489257E-11,   1.1383229E-11,   9.5977774E-12
     +,   8.0854360E-12,   6.8056233E-12,   5.7235167E-12
     +,   4.8093539E-12,   4.0377805E-12,   3.3871382E-12
     +,   2.8389376E-12,   2.3774394E-12,   1.9892837E-12
     +,   1.6631099E-12,   1.3892432E-12,   1.1594920E-12
     +,   9.6692153E-13,   8.0566066E-13,   6.7072948E-13
     +,   5.5792317E-13,   4.6370210E-13,   3.8506833E-13
     +,   3.1949741E-13,   2.6486956E-13,   2.1939777E-13
     +,   1.8157928E-13,   1.5015188E-13,   1.2405909E-13
     +,   1.0241440E-13,   8.4474264E-14,   6.9617292E-14
     +,   5.7324988E-14,   4.7162656E-14,   3.8769016E-14
     +,   3.1841805E-14,   2.6130121E-14,   2.1424519E-14
     +,   1.7551338E-14,   1.4365911E-14,   1.1748547E-14
     +,   9.5997115E-15,   7.8371639E-15,   6.3926779E-15
     +,   5.2098777E-15,   4.2422608E-15,   3.4513092E-15
     +,   2.8053996E-15,   2.2783558E-15,   1.8487155E-15
     +,   1.4987659E-15,   1.2139973E-15,   9.8245689E-16
     +,   7.9438201E-16,   6.4173466E-16,   5.1796366E-16
     +,   4.1768838E-16,   3.3652833E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt120 = Yx/0.158395348837209
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5083099E-05,   6.8056906E-05
     +,   7.1128117E-05,   7.4295451E-05,   7.7557270E-05
     +,   8.0911574E-05,   8.4356128E-05,   8.7888366E-05
     +,   9.1505528E-05,   9.5204814E-05,   9.8983241E-05
     +,   1.0283789E-04,   1.0676598E-04,   1.1076489E-04
     +,   1.1483242E-04,   1.1896680E-04,   1.2316694E-04
     +,   1.2743246E-04,   1.3176387E-04,   1.3616278E-04
     +,   1.4063204E-04,   1.4517570E-04,   1.4979932E-04
     +,   1.5451027E-04,   1.5931697E-04,   1.6423008E-04
     +,   1.6926185E-04,   1.7442599E-04,   1.7973810E-04
     +,   1.8521526E-04,   1.9087596E-04,   1.9674002E-04
     +,   2.0282835E-04,   2.0916303E-04,   2.1576675E-04
     +,   2.2266322E-04,   2.2987676E-04,   2.3743272E-04
     +,   2.4535792E-04,   2.5368051E-04,   2.6243157E-04
     +,   2.7164572E-04,   2.8136277E-04,   2.9162911E-04
     +,   3.0250064E-04,   3.1404494E-04,   3.2634469E-04
     +,   3.3950084E-04,   3.5363704E-04,   3.6890502E-04
     +,   3.8548917E-04,   4.0361317E-04,   4.2354694E-04
     +,   4.4561687E-04,   4.7021080E-04,   4.9779448E-04
     +,   5.2891864E-04,   5.6423486E-04,   6.0450844E-04
     +,   6.5063126E-04,   7.0363557E-04,   7.6470425E-04
     +,   8.3516742E-04,   9.1650593E-04,   1.0103246E-03
     +,   1.1182958E-03,   1.2421118E-03,   1.3833523E-03
     +,   1.5433867E-03,   1.7231778E-03,   1.9231542E-03
     +,   2.1429984E-03,   2.3815604E-03,   2.6367011E-03
     +,   2.9053092E-03,   3.1833118E-03,   3.4657479E-03
     +,   3.7469857E-03,   4.0209861E-03,   4.2816908E-03
     +,   4.5234398E-03,   4.7416575E-03,   4.9334443E-03
     +,   5.0982968E-03,   5.2386364E-03,   5.3601759E-03
     +,   5.4718703E-03,   5.5854735E-03,   5.7146116E-03
     +,   5.8734184E-03,   6.0748160E-03,   6.3286717E-03
     +,   6.6399453E-03,   7.0074028E-03,   7.4230568E-03
     +,   7.8727249E-03,   8.3379606E-03,   8.7988488E-03
     +,   9.2375679E-03,   9.6413149E-03,   1.0004175E-02
     +,   1.0326601E-02,   1.0613526E-02,   1.0871695E-02
     +,   1.1108022E-02,   1.1329033E-02,   1.1540131E-02
     +,   1.1744007E-02,   1.1938698E-02,   1.2118478E-02
     +,   1.2279383E-02,   1.2426904E-02,   1.2579647E-02
     +,   1.2764870E-02,   1.3008164E-02,   1.3323826E-02
     +,   1.3711965E-02,   1.4161406E-02,   1.4654108E-02
     +,   1.5169583E-02,   1.5690949E-02,   1.6214002E-02
     +,   1.6755071E-02,   1.7351242E-02,   1.8048584E-02
     +,   1.8884260E-02,   1.9872990E-02,   2.1004518E-02
     +,   2.2243232E-02,   2.3513962E-02,   2.4681609E-02
     +,   2.5558544E-02,   2.5969505E-02,   2.5842724E-02
     +,   2.5255358E-02,   2.4386592E-02,   2.3411630E-02
     +,   2.2418166E-02,   2.1397643E-02,   2.0295767E-02
     +,   1.9071709E-02,   1.7729722E-02,   1.6319484E-02
     +,   1.4916473E-02,   1.3594655E-02,   1.2402690E-02
     +,   1.1354864E-02,   1.0437758E-02,   9.6255429E-03
     +,   8.8936286E-03,   8.2252296E-03,   7.6117804E-03
     +,   7.0506004E-03,   6.5427679E-03,   6.0915146E-03
     +,   5.7006464E-03,   5.3726691E-03,   5.1071513E-03
     +,   4.8998911E-03,   4.7429963E-03,   4.6257381E-03
     +,   4.5358851E-03,   4.4610985E-03,   4.3901210E-03
     +,   4.3136021E-03,   4.2245663E-03,   4.1185501E-03
     +,   3.9934716E-03,   3.8493711E-03,   3.6880521E-03
     +,   3.5127292E-03,   3.3276239E-03,   3.1375359E-03
     +,   2.9474795E-03,   2.7623074E-03,   2.5863578E-03
     +,   2.4232091E-03,   2.2755177E-03,   2.1449192E-03
     +,   2.0320246E-03,   1.9365129E-03,   1.8572741E-03
     +,   1.7925737E-03,   1.7402377E-03,   1.6978421E-03
     +,   1.6628805E-03,   1.6329008E-03,   1.6056162E-03
     +,   1.5789896E-03,   1.5512864E-03,   1.5211072E-03
     +,   1.4873932E-03,   1.4494318E-03,   1.4068284E-03
     +,   1.3594826E-03,   1.3075500E-03,   1.2514066E-03
     +,   1.1916020E-03,   1.1288078E-03,   1.0637811E-03
     +,   9.9732261E-04,   9.3024014E-04,   8.6330867E-04
     +,   7.9724978E-04,   7.3272036E-04,   6.7028264E-04
     +,   6.1040791E-04,   5.5347360E-04,   4.9976370E-04
     +,   4.4946888E-04,   4.0269882E-04,   3.5949383E-04
     +,   3.1983128E-04,   2.8363374E-04,   2.5078107E-04
     +,   2.2112287E-04,   1.9448326E-04,   1.7066789E-04
     +,   1.4947259E-04,   1.3069021E-04,   1.1411196E-04
     +,   9.9533230E-05,   8.6757602E-05,   7.5597891E-05
     +,   6.5877255E-05,   5.7431429E-05,   5.0109742E-05
     +,   4.3774551E-05,   3.8300976E-05,   3.3576973E-05
     +,   2.9503026E-05,   2.5990983E-05,   2.2963033E-05
     +,   2.0351166E-05,   1.8096413E-05,   1.6147396E-05
     +,   1.4459817E-05,   1.2995655E-05,   1.1722284E-05
     +,   1.0611704E-05,   9.6400227E-06,   8.7869385E-06
     +,   8.0351683E-06,   7.3699762E-06,   6.7788501E-06
     +,   6.2512277E-06,   5.7781444E-06,   5.3519789E-06
     +,   4.9662854E-06,   4.6156488E-06,   4.2954562E-06
     +,   4.0018112E-06,   3.7314421E-06,   3.4815862E-06
     +,   3.2498929E-06,   3.0343797E-06,   2.8333841E-06
     +,   2.6454957E-06,   2.4695103E-06,   2.3044031E-06
     +,   2.1493088E-06,   2.0034856E-06,   1.8662845E-06
     +,   1.7371417E-06,   1.6155745E-06,   1.5011450E-06
     +,   1.3934607E-06,   1.2921748E-06,   1.1969692E-06
     +,   1.1075437E-06,   1.0236183E-06,   9.4493561E-07
     +,   8.7124920E-07,   8.0231899E-07,   7.3791477E-07
     +,   6.7781997E-07,   6.2181670E-07,   5.6970100E-07
     +,   5.2126774E-07,   4.7632346E-07,   4.3467475E-07
     +,   3.9613897E-07,   3.6053405E-07,   3.2768835E-07
     +,   2.9743143E-07,   2.6960345E-07,   2.4404724E-07
     +,   2.2061216E-07,   1.9915653E-07,   1.7954150E-07
     +,   1.6163791E-07,   1.4532019E-07,   1.3047143E-07
     +,   1.1697914E-07,   1.0473880E-07,   9.3650414E-08
     +,   8.3621451E-08,   7.4563850E-08,   6.6396382E-08
     +,   5.9042236E-08,   5.2430813E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt60 = Yx/0.272404255319149
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1496154E-05,   4.3598509E-05
     +,   4.5804460E-05,   4.8118196E-05,   5.0543931E-05
     +,   5.3085838E-05,   5.5748031E-05,   5.8534530E-05
     +,   6.1449231E-05,   6.4496002E-05,   6.7678411E-05
     +,   7.0999900E-05,   7.4463715E-05,   7.8072808E-05
     +,   8.1829960E-05,   8.5737607E-05,   8.9798079E-05
     +,   9.4013303E-05,   9.8385011E-05,   1.0291470E-04
     +,   1.0760370E-04,   1.1245320E-04,   1.1746414E-04
     +,   1.2263774E-04,   1.2797478E-04,   1.3347664E-04
     +,   1.3914464E-04,   1.4498059E-04,   1.5098663E-04
     +,   1.5716562E-04,   1.6352115E-04,   1.7005778E-04
     +,   1.7678118E-04,   1.8369824E-04,   1.9081734E-04
     +,   1.9814855E-04,   2.0570379E-04,   2.1349693E-04
     +,   2.2154427E-04,   2.2986393E-04,   2.3847721E-04
     +,   2.4740747E-04,   2.5668117E-04,   2.6632726E-04
     +,   2.7637760E-04,   2.8686732E-04,   2.9783399E-04
     +,   3.0931877E-04,   3.2136583E-04,   3.3402262E-04
     +,   3.4734051E-04,   3.6137478E-04,   3.7618485E-04
     +,   3.9183648E-04,   4.0839918E-04,   4.2595062E-04
     +,   4.4457504E-04,   4.6436404E-04,   4.8541834E-04
     +,   5.0784618E-04,   5.3176534E-04,   5.5730244E-04
     +,   5.8459037E-04,   6.1377347E-04,   6.4500608E-04
     +,   6.7845086E-04,   7.1428943E-04,   7.5271906E-04
     +,   7.9396967E-04,   8.3829893E-04,   8.8601402E-04
     +,   9.3746401E-04,   9.9306018E-04,   1.0532578E-03
     +,   1.1185654E-03,   1.1895266E-03,   1.2667003E-03
     +,   1.3506399E-03,   1.4418861E-03,   1.5409380E-03
     +,   1.6482318E-03,   1.7641603E-03,   1.8890384E-03
     +,   2.0231474E-03,   2.1667199E-03,   2.3200077E-03
     +,   2.4833202E-03,   2.6571678E-03,   2.8424058E-03
     +,   3.0405198E-03,   3.2539477E-03,   3.4864775E-03
     +,   3.7436131E-03,   4.0328018E-03,   4.3631447E-03
     +,   4.7444324E-03,   5.1852958E-03,   5.6903902E-03
     +,   6.2575215E-03,   6.8752375E-03,   7.5226193E-03
     +,   8.1715761E-03,   8.7919133E-03,   9.3574161E-03
     +,   9.8512415E-03,   1.0268497E-02,   1.0616065E-02
     +,   1.0911039E-02,   1.1179718E-02,   1.1457531E-02
     +,   1.1788311E-02,   1.2219712E-02,   1.2792592E-02
     +,   1.3526049E-02,   1.4403637E-02,   1.5371840E-02
     +,   1.6356679E-02,   1.7292863E-02,   1.8142438E-02
     +,   1.8885760E-02,   1.9496236E-02,   1.9935148E-02
     +,   2.0186391E-02,   2.0300983E-02,   2.0399874E-02
     +,   2.0623146E-02,   2.1069143E-02,   2.1774290E-02
     +,   2.2739036E-02,   2.3959445E-02,   2.5416676E-02
     +,   2.7015194E-02,   2.8545162E-02,   2.9769571E-02
     +,   3.0604128E-02,   3.1187033E-02,   3.1728290E-02
     +,   3.2310568E-02,   3.2853846E-02,   3.3190612E-02
     +,   3.3105057E-02,   3.2381643E-02,   3.0947888E-02
     +,   2.8983332E-02,   2.6829887E-02,   2.4779379E-02
     +,   2.2943718E-02,   2.1285098E-02,   1.9723708E-02
     +,   1.8215328E-02,   1.6758952E-02,   1.5365938E-02
     +,   1.4038525E-02,   1.2773440E-02,   1.1575349E-02
     +,   1.0461057E-02,   9.4524575E-03,   8.5663162E-03
     +,   7.8087500E-03,   7.1756220E-03,   6.6559645E-03
     +,   6.2358347E-03,   5.9007881E-03,   5.6369952E-03
     +,   5.4315873E-03,   5.2726385E-03,   5.1489277E-03
     +,   5.0496971E-03,   4.9645235E-03,   4.8835780E-03
     +,   4.7981679E-03,   4.7013662E-03,   4.5886338E-03
     +,   4.4580949E-03,   4.3105651E-03,   4.1490984E-03
     +,   3.9783781E-03,   3.8039119E-03,   3.6312144E-03
     +,   3.4650741E-03,   3.3090203E-03,   3.1650786E-03
     +,   3.0337102E-03,   2.9140089E-03,   2.8040267E-03
     +,   2.7012178E-03,   2.6028110E-03,   2.5061732E-03
     +,   2.4090547E-03,   2.3097680E-03,   2.2072259E-03
     +,   2.1009457E-03,   1.9909923E-03,   1.8778783E-03
     +,   1.7624483E-03,   1.6457742E-03,   1.5290615E-03
     +,   1.4135474E-03,   1.3004219E-03,   1.1907717E-03
     +,   1.0855496E-03,   9.8553882E-04,   8.9133496E-04
     +,   8.0335251E-04,   7.2184432E-04,   6.4689521E-04
     +,   5.7845411E-04,   5.1635911E-04,   4.6035403E-04
     +,   4.1010749E-04,   3.6523803E-04,   3.2533504E-04
     +,   2.8997104E-04,   2.5871367E-04,   2.3114006E-04
     +,   2.0684674E-04,   1.8545364E-04,   1.6660799E-04
     +,   1.4998853E-04,   1.3530772E-04,   1.2230876E-04
     +,   1.1076594E-04,   1.0048369E-04,   9.1293332E-05
     +,   8.3049868E-05,   7.5630072E-05,   6.8930276E-05
     +,   6.2863000E-05,   5.7354264E-05,   5.2341824E-05
     +,   4.7773538E-05,   4.3605185E-05,   3.9798724E-05
     +,   3.6321471E-05,   3.3145305E-05,   3.0245168E-05
     +,   2.7598762E-05,   2.5186198E-05,   2.2989341E-05
     +,   2.0991392E-05,   1.9176836E-05,   1.7531354E-05
     +,   1.6041546E-05,   1.4694766E-05,   1.3479165E-05
     +,   1.2383714E-05,   1.1398056E-05,   1.0512445E-05
     +,   9.7177699E-06,   9.0056246E-06,   8.3681171E-06
     +,   7.7979339E-06,   7.2883613E-06,   6.8331956E-06
     +,   6.4267210E-06,   6.0636939E-06,   5.7393609E-06
     +,   5.4493894E-06,   5.1898287E-06,   4.9571136E-06
     +,   4.7480394E-06,   4.5597308E-06,   4.3895980E-06
     +,   4.2353295E-06,   4.0948862E-06,   3.9664419E-06
     +,   3.8483877E-06,   3.7393111E-06,   3.6379738E-06
     +,   3.5432872E-06,   3.4543018E-06,   3.3702022E-06
     +,   3.2902810E-06,   3.2139271E-06,   3.1406155E-06
     +,   3.0699089E-06,   3.0014239E-06,   2.9348503E-06
     +,   2.8699164E-06,   2.8064064E-06,   2.7441356E-06
     +,   2.6829587E-06,   2.6227522E-06,   2.5634249E-06
     +,   2.5048969E-06,   2.4471149E-06,   2.3900343E-06
     +,   2.3336220E-06,   2.2778606E-06,   2.2227343E-06
     +,   2.1682399E-06,   2.1143728E-06,   2.0611408E-06
     +,   2.0085456E-06,   1.9566012E-06,   1.9053136E-06
     +,   1.8546986E-06,   1.8047663E-06,   1.7555323E-06
     +,   1.7070068E-06,   1.6592060E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt65 = Yx/0.3241875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5536003E-05,   3.6977326E-05
     +,   3.8469549E-05,   4.0012634E-05,   4.1606356E-05
     +,   4.3250297E-05,   4.4943874E-05,   4.6686284E-05
     +,   4.8476577E-05,   5.0313716E-05,   5.2196439E-05
     +,   5.4123393E-05,   5.6093155E-05,   5.8104215E-05
     +,   6.0155056E-05,   6.2244151E-05,   6.4370048E-05
     +,   6.6531378E-05,   6.8726884E-05,   7.0955546E-05
     +,   7.3216528E-05,   7.5509328E-05,   7.7833720E-05
     +,   8.0190017E-05,   8.2578699E-05,   8.5000946E-05
     +,   8.7458371E-05,   8.9953086E-05,   9.2487840E-05
     +,   9.5065858E-05,   9.7691074E-05,   1.0036791E-04
     +,   1.0310138E-04,   1.0589705E-04,   1.0876099E-04
     +,   1.1169965E-04,   1.1471994E-04,   1.1782904E-04
     +,   1.2103445E-04,   1.2434358E-04,   1.2776413E-04
     +,   1.3130360E-04,   1.3496933E-04,   1.3876846E-04
     +,   1.4270761E-04,   1.4679313E-04,   1.5103079E-04
     +,   1.5542601E-04,   1.5998361E-04,   1.6470805E-04
     +,   1.6960379E-04,   1.7467518E-04,   1.7992720E-04
     +,   1.8536611E-04,   1.9099945E-04,   1.9683826E-04
     +,   2.0289696E-04,   2.0919558E-04,   2.1576106E-04
     +,   2.2262921E-04,   2.2984667E-04,   2.3747305E-04
     +,   2.4558249E-04,   2.5426640E-04,   2.6363498E-04
     +,   2.7381643E-04,   2.8495994E-04,   2.9723233E-04
     +,   3.1081890E-04,   3.2591747E-04,   3.4273902E-04
     +,   3.6149748E-04,   3.8241010E-04,   4.0568766E-04
     +,   4.3153280E-04,   4.6013569E-04,   4.9166946E-04
     +,   5.2628940E-04,   5.6413747E-04,   6.0534093E-04
     +,   6.5001228E-04,   6.9825811E-04,   7.5017189E-04
     +,   8.0584461E-04,   8.6535158E-04,   9.2876813E-04
     +,   9.9615473E-04,   1.0675861E-03,   1.1431486E-03
     +,   1.2229877E-03,   1.3073393E-03,   1.3965757E-03
     +,   1.4912584E-03,   1.5921844E-03,   1.7004024E-03
     +,   1.8171876E-03,   1.9440169E-03,   2.0824627E-03
     +,   2.2341355E-03,   2.4005980E-03,   2.5834169E-03
     +,   2.7842936E-03,   3.0054424E-03,   3.2500862E-03
     +,   3.5231544E-03,   3.8318723E-03,   4.1860216E-03
     +,   4.5975009E-03,   5.0789989E-03,   5.6416104E-03
     +,   6.2918602E-03,   7.0291371E-03,   7.8439983E-03
     +,   8.7185558E-03,   9.6284840E-03,   1.0547074E-02
     +,   1.1450123E-02,   1.2322104E-02,   1.3160277E-02
     +,   1.3974892E-02,   1.4782988E-02,   1.5599365E-02
     +,   1.6431537E-02,   1.7281383E-02,   1.8148784E-02
     +,   1.9029940E-02,   1.9918445E-02,   2.0836530E-02
     +,   2.1908082E-02,   2.3387048E-02,   2.5498878E-02
     +,   2.8138617E-02,   3.0788384E-02,   3.2906335E-02
     +,   3.4397464E-02,   3.5534933E-02,   3.6468524E-02
     +,   3.7110142E-02,   3.7614629E-02,   3.8664706E-02
     +,   4.0875219E-02,   4.3955434E-02,   4.6857260E-02
     +,   4.8763983E-02,   4.9597159E-02,   4.9625184E-02
     +,   4.8863150E-02,   4.6994783E-02,   4.3951828E-02
     +,   4.0239096E-02,   3.6455151E-02,   3.2865237E-02
     +,   2.9527541E-02,   2.6488977E-02,   2.3784447E-02
     +,   2.1390000E-02,   1.9238450E-02,   1.7277122E-02
     +,   1.5502999E-02,   1.3947280E-02,   1.2637761E-02
     +,   1.1574848E-02,   1.0728332E-02,   1.0046714E-02
     +,   9.4717825E-03,   8.9535024E-03,   8.4605040E-03
     +,   7.9832152E-03,   7.5292606E-03,   7.1140956E-03
     +,   6.7511215E-03,   6.4451401E-03,   6.1909030E-03
     +,   5.9757829E-03,   5.7843975E-03,   5.6028538E-03
     +,   5.4213926E-03,   5.2350755E-03,   5.0429641E-03
     +,   4.8465370E-03,   4.6480838E-03,   4.4494546E-03
     +,   4.2514023E-03,   4.0535321E-03,   3.8546852E-03
     +,   3.6535906E-03,   3.4494295E-03,   3.2422703E-03
     +,   3.0332268E-03,   2.8243740E-03,   2.6184104E-03
     +,   2.4182741E-03,   2.2267466E-03,   2.0461145E-03
     +,   1.8779574E-03,   1.7230842E-03,   1.5815911E-03
     +,   1.4529756E-03,   1.3363058E-03,   1.2304067E-03
     +,   1.1340264E-03,   1.0459526E-03,   9.6508156E-04
     +,   8.9047011E-04,   8.2134642E-04,   7.5708446E-04
     +,   6.9718796E-04,   6.4126699E-04,   5.8900920E-04
     +,   5.4015574E-04,   4.9449038E-04,   4.5183138E-04
     +,   4.1202048E-04,   3.7491514E-04,   3.4038816E-04
     +,   3.0832586E-04,   2.7862217E-04,   2.5117391E-04
     +,   2.2588084E-04,   2.0264556E-04,   1.8136705E-04
     +,   1.6194263E-04,   1.4426869E-04,   1.2823963E-04
     +,   1.1374748E-04,   1.0068438E-04,   8.8944245E-05
     +,   7.8422803E-05,   6.9018206E-05,   6.0632698E-05
     +,   5.3173753E-05,   4.6553956E-05,   4.0691069E-05
     +,   3.5508707E-05,   3.0936822E-05,   2.6910611E-05
     +,   2.3370951E-05,   2.0264328E-05,   1.7542256E-05
     +,   1.5160839E-05,   1.3080644E-05,   1.1266478E-05
     +,   9.6868616E-06,   8.3136229E-06,   7.1217096E-06
     +,   6.0889520E-06,   5.1956754E-06,   4.4244025E-06
     +,   3.7596917E-06,   3.1879647E-06,   2.6971875E-06
     +,   2.2767665E-06,   1.9174076E-06,   1.6109410E-06
     +,   1.3501773E-06,   1.1288238E-06,   9.4139187E-07
     +,   7.8308659E-07,   6.4972090E-07,   5.3765689E-07
     +,   4.4374707E-07,   3.6526595E-07,   2.9985665E-07
     +,   2.4549198E-07,   2.0043677E-07,   1.6320153E-07
     +,   1.3251578E-07,   1.0730110E-07,   8.6642629E-08
     +,   6.9765576E-08,   5.6017615E-08,   4.4851781E-08
     +,   3.5810011E-08,   2.8509600E-08,   2.2632422E-08
     +,   1.7915365E-08,   1.4140443E-08,   1.1128700E-08
     +,   8.7328740E-09,   6.8328694E-09,   5.3305067E-09
     +,   4.1462469E-09,   3.2155056E-09,   2.4862887E-09
     +,   1.9166733E-09,   1.4731262E-09,   1.1287982E-09
     +,   8.6231650E-10,   6.5673722E-10,   4.9862747E-10
     +,   3.7741757E-10,   2.8478234E-10,   2.1421569E-10
     +,   1.6062801E-10,   1.2006733E-10,   8.9463478E-11
     +,   6.6448819E-11,   4.9196390E-11,   3.6306597E-11
     +,   2.6707327E-11,   1.9582554E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt70 = Yx/0.378571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0438913E-05,   2.0914575E-05
     +,   2.1418826E-05,   2.1953863E-05,   2.2521939E-05
     +,   2.3125363E-05,   2.3766486E-05,   2.4447680E-05
     +,   2.5171335E-05,   2.5939860E-05,   2.6755608E-05
     +,   2.7620912E-05,   2.8538043E-05,   2.9509183E-05
     +,   3.0536434E-05,   3.1621763E-05,   3.2766984E-05
     +,   3.3973782E-05,   3.5243633E-05,   3.6577811E-05
     +,   3.7977410E-05,   3.9443254E-05,   4.0975938E-05
     +,   4.2575881E-05,   4.4243101E-05,   4.5977547E-05
     +,   4.7778809E-05,   4.9646296E-05,   5.1579205E-05
     +,   5.3576547E-05,   5.5637203E-05,   5.7759917E-05
     +,   5.9943381E-05,   6.2186293E-05,   6.4487394E-05
     +,   6.6845540E-05,   6.9259819E-05,   7.1729519E-05
     +,   7.4254465E-05,   7.6834680E-05,   7.9470963E-05
     +,   8.2164690E-05,   8.4917905E-05,   8.7733591E-05
     +,   9.0615627E-05,   9.3568859E-05,   9.6599317E-05
     +,   9.9714118E-05,   1.0292167E-04,   1.0623162E-04
     +,   1.0965492E-04,   1.1320390E-04,   1.1689210E-04
     +,   1.2073466E-04,   1.2474756E-04,   1.2894852E-04
     +,   1.3335617E-04,   1.3799031E-04,   1.4287180E-04
     +,   1.4802258E-04,   1.5346537E-04,   1.5922391E-04
     +,   1.6532236E-04,   1.7178596E-04,   1.7864072E-04
     +,   1.8591253E-04,   1.9362889E-04,   2.0181661E-04
     +,   2.1050396E-04,   2.1971831E-04,   2.2948823E-04
     +,   2.3984068E-04,   2.5080299E-04,   2.6239996E-04
     +,   2.7465497E-04,   2.8758860E-04,   3.0121623E-04
     +,   3.1554746E-04,   3.3058558E-04,   3.4632543E-04
     +,   3.6274971E-04,   3.7983124E-04,   3.9752779E-04
     +,   4.1578524E-04,   4.3453326E-04,   4.5369173E-04
     +,   4.7316746E-04,   4.9286516E-04,   5.1268796E-04
     +,   5.3255347E-04,   5.5240438E-04,   5.7222426E-04
     +,   5.9205899E-04,   6.1204407E-04,   6.3242915E-04
     +,   6.5360242E-04,   6.7612668E-04,   7.0075382E-04
     +,   7.2844810E-04,   7.6038763E-04,   7.9796329E-04
     +,   8.4274751E-04,   8.9646853E-04,   9.6094573E-04
     +,   1.0380378E-03,   1.1295686E-03,   1.2372446E-03
     +,   1.3625683E-03,   1.5067551E-03,   1.6706118E-03
     +,   1.8543989E-03,   2.0577461E-03,   2.2795380E-03
     +,   2.5179954E-03,   2.7708213E-03,   3.0356727E-03
     +,   3.3107300E-03,   3.5956020E-03,   3.8921942E-03
     +,   4.2058062E-03,   4.5461054E-03,   4.9281963E-03
     +,   5.3738658E-03,   5.9129279E-03,   6.5831533E-03
     +,   7.4253865E-03,   8.4705381E-03,   9.7203562E-03
     +,   1.1138319E-02,   1.2671678E-02,   1.4308233E-02
     +,   1.6121496E-02,   1.8231535E-02,   2.0663956E-02
     +,   2.3233276E-02,   2.5621984E-02,   2.7618947E-02
     +,   2.9247837E-02,   3.0700019E-02,   3.2306582E-02
     +,   3.4558039E-02,   3.7870236E-02,   4.2148326E-02
     +,   4.6567954E-02,   5.0100774E-02,   5.2676767E-02
     +,   5.5285640E-02,   5.8409352E-02,   6.1075203E-02
     +,   6.2299147E-02,   6.2763713E-02,   6.2958702E-02
     +,   6.1569426E-02,   5.7957616E-02,   5.3258784E-02
     +,   4.8606280E-02,   4.4198785E-02,   3.9842743E-02
     +,   3.5633519E-02,   3.2080859E-02,   2.9521659E-02
     +,   2.7630620E-02,   2.5781553E-02,   2.3632536E-02
     +,   2.1246128E-02,   1.8875722E-02,   1.6730996E-02
     +,   1.4879245E-02,   1.3296929E-02,   1.1961406E-02
     +,   1.0878599E-02,   1.0050727E-02,   9.4446586E-03
     +,   8.9938771E-03,   8.6243665E-03,   8.2799690E-03
     +,   7.9321498E-03,   7.5740255E-03,   7.2080041E-03
     +,   6.8360278E-03,   6.4562564E-03,   6.0649132E-03
     +,   5.6600706E-03,   5.2446406E-03,   4.8271674E-03
     +,   4.4203363E-03,   4.0379902E-03,   3.6919534E-03
     +,   3.3897436E-03,   3.1337149E-03,   2.9214704E-03
     +,   2.7472700E-03,   2.6037169E-03,   2.4831728E-03
     +,   2.3787348E-03,   2.2846805E-03,   2.1965462E-03
     +,   2.1109711E-03,   2.0254655E-03,   1.9382312E-03
     +,   1.8480384E-03,   1.7541434E-03,   1.6562553E-03
     +,   1.5545131E-03,   1.4494637E-03,   1.3419887E-03
     +,   1.2332399E-03,   1.1245547E-03,   1.0173529E-03
     +,   9.1303181E-04,   8.1288983E-04,   7.1806280E-04
     +,   6.2946760E-04,   5.4776738E-04,   4.7337179E-04
     +,   4.0645059E-04,   3.4695011E-04,   2.9462445E-04
     +,   2.4907867E-04,   2.0981382E-04,   1.7625673E-04
     +,   1.4780092E-04,   1.2383801E-04,   1.0377825E-04
     +,   8.7067296E-05,   7.3199262E-05,   6.1723098E-05
     +,   5.2243231E-05,   4.4418102E-05,   3.7957536E-05
     +,   3.2618183E-05,   2.8197512E-05,   2.4528266E-05
     +,   2.1473406E-05,   1.8921466E-05,   1.6781602E-05
     +,   1.4980221E-05,   1.3457796E-05,   1.2166060E-05
     +,   1.1065727E-05,   1.0124838E-05,   9.3173076E-06
     +,   8.6217160E-06,   8.0203154E-06,   7.4983809E-06
     +,   7.0436449E-06,   6.6457997E-06,   6.2961235E-06
     +,   5.9872336E-06,   5.7128796E-06,   5.4677189E-06
     +,   5.2471946E-06,   5.0474409E-06,   4.8651632E-06
     +,   4.6975515E-06,   4.5422253E-06,   4.3971831E-06
     +,   4.2607430E-06,   4.1314884E-06,   4.0082377E-06
     +,   3.8900257E-06,   3.7760547E-06,   3.6656743E-06
     +,   3.5583535E-06,   3.4536833E-06,   3.3513302E-06
     +,   3.2510345E-06,   3.1526088E-06,   3.0559102E-06
     +,   2.9608354E-06,   2.8673132E-06,   2.7753040E-06
     +,   2.6847906E-06,   2.5957652E-06,   2.5082322E-06
     +,   2.4222136E-06,   2.3377265E-06,   2.2548036E-06
     +,   2.1734681E-06,   2.0937541E-06,   2.0156870E-06
     +,   1.9392996E-06,   1.8646127E-06,   1.7916554E-06
     +,   1.7204442E-06,   1.6510006E-06,   1.5833376E-06
     +,   1.5174644E-06,   1.4533927E-06,   1.3911233E-06
     +,   1.3306608E-06,   1.2719997E-06,   1.2151378E-06
     +,   1.1600632E-06,   1.1067683E-06,   1.0552349E-06
     +,   1.0054499E-06,   9.5739051E-07,   9.1103794E-07
     +,   8.6636578E-07,   8.2335072E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt75 = Yx/0.409714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.7187245E-06,   8.9760715E-06
     +,   9.2378150E-06,   9.5041705E-06,   9.7753937E-06
     +,   1.0051795E-05,   1.0333732E-05,   1.0621613E-05
     +,   1.0915915E-05,   1.1217197E-05,   1.1526075E-05
     +,   1.1843273E-05,   1.2169593E-05,   1.2505962E-05
     +,   1.2853420E-05,   1.3213157E-05,   1.3586500E-05
     +,   1.3974956E-05,   1.4380235E-05,   1.4804249E-05
     +,   1.5249155E-05,   1.5717387E-05,   1.6211668E-05
     +,   1.6735083E-05,   1.7291028E-05,   1.7883365E-05
     +,   1.8516370E-05,   1.9194797E-05,   1.9923944E-05
     +,   2.0709644E-05,   2.1558366E-05,   2.2477192E-05
     +,   2.3473885E-05,   2.4556912E-05,   2.5735459E-05
     +,   2.7019452E-05,   2.8419559E-05,   2.9947152E-05
     +,   3.1614451E-05,   3.3434117E-05,   3.5419682E-05
     +,   3.7585105E-05,   3.9944865E-05,   4.2513770E-05
     +,   4.5306897E-05,   4.8339367E-05,   5.1626237E-05
     +,   5.5182241E-05,   5.9021619E-05,   6.3157822E-05
     +,   6.7603374E-05,   7.2369439E-05,   7.7465622E-05
     +,   8.2899925E-05,   8.8677727E-05,   9.4802599E-05
     +,   1.0127506E-04,   1.0809289E-04,   1.1525066E-04
     +,   1.2273969E-04,   1.3054800E-04,   1.3866009E-04
     +,   1.4705666E-04,   1.5571572E-04,   1.6461214E-04
     +,   1.7371707E-04,   1.8300068E-04,   1.9242993E-04
     +,   2.0197209E-04,   2.1159300E-04,   2.2126079E-04
     +,   2.3094437E-04,   2.4061765E-04,   2.5025857E-04
     +,   2.5985297E-04,   2.6939635E-04,   2.7889447E-04
     +,   2.8836727E-04,   2.9785174E-04,   3.0740362E-04
     +,   3.1709889E-04,   3.2703939E-04,   3.3735068E-04
     +,   3.4818731E-04,   3.5973074E-04,   3.7219172E-04
     +,   3.8580596E-04,   4.0083411E-04,   4.1755399E-04
     +,   4.3625612E-04,   4.5723384E-04,   4.8077060E-04
     +,   5.0712662E-04,   5.3652597E-04,   5.6913862E-04
     +,   6.0505985E-04,   6.4430060E-04,   6.8676722E-04
     +,   7.3225831E-04,   7.8045152E-04,   8.3091803E-04
     +,   8.8312075E-04,   9.3644968E-04,   9.9023711E-04
     +,   1.0438100E-03,   1.0965315E-03,   1.1478470E-03
     +,   1.1973397E-03,   1.2447847E-03,   1.2901881E-03
     +,   1.3338135E-03,   1.3762180E-03,   1.4182415E-03
     +,   1.4610133E-03,   1.5059166E-03,   1.5545732E-03
     +,   1.6087944E-03,   1.6705635E-03,   1.7420165E-03
     +,   1.8254882E-03,   1.9235947E-03,   2.0393915E-03
     +,   2.1766047E-03,   2.3398893E-03,   2.5349867E-03
     +,   2.7686507E-03,   3.0481853E-03,   3.3802446E-03
     +,   3.7690762E-03,   4.2141220E-03,   4.7081970E-03
     +,   5.2372357E-03,   5.7835486E-03,   6.3326270E-03
     +,   6.8827779E-03,   7.4546784E-03,   8.0985315E-03
     +,   8.8953068E-03,   9.9456375E-03,   1.1343737E-02
     +,   1.3150503E-02,   1.5389487E-02,   1.8057041E-02
     +,   2.1108439E-02,   2.4435427E-02,   2.7907269E-02
     +,   3.1499058E-02,   3.5441183E-02,   4.0119216E-02
     +,   4.5552772E-02,   5.1396921E-02,   5.7835996E-02
     +,   6.4514607E-02,   6.9340743E-02,   7.2738051E-02
     +,   7.7132411E-02,   7.9817176E-02,   7.8947797E-02
     +,   7.8453779E-02,   7.8326710E-02,   7.5362340E-02
     +,   6.9881611E-02,   6.2861338E-02,   5.4831427E-02
     +,   4.6898417E-02,   4.0250342E-02,   3.5421837E-02
     +,   3.2035317E-02,   2.9465431E-02,   2.7292611E-02
     +,   2.5299953E-02,   2.3361286E-02,   2.1414543E-02
     +,   1.9479843E-02,   1.7597571E-02,   1.5776683E-02
     +,   1.4043587E-02,   1.2489838E-02,   1.1227504E-02
     +,   1.0301550E-02,   9.6501019E-03,   9.1390004E-03
     +,   8.6326720E-03,   8.0494313E-03,   7.3767388E-03
     +,   6.6528418E-03,   5.9358547E-03,   5.2781398E-03
     +,   4.7133234E-03,   4.2543686E-03,   3.8975258E-03
     +,   3.6282788E-03,   3.4267285E-03,   3.2717006E-03
     +,   3.1435688E-03,   3.0259476E-03,   2.9064948E-03
     +,   2.7770493E-03,   2.6333355E-03,   2.4744114E-03
     +,   2.3019537E-03,   2.1194452E-03,   1.9313768E-03
     +,   1.7425449E-03,   1.5575094E-03,   1.3801567E-03
     +,   1.2134941E-03,   1.0595975E-03,   9.1964367E-04
     +,   7.9403084E-04,   6.8255357E-04,   5.8457523E-04
     +,   4.9917342E-04,   4.2525830E-04,   3.6167630E-04
     +,   3.0727725E-04,   2.6095266E-04,   2.2165985E-04
     +,   1.8843942E-04,   1.6042471E-04,   1.3683688E-04
     +,   1.1698785E-04,   1.0027784E-04,   8.6189051E-05
     +,   7.4279174E-05,   6.4175787E-05,   5.5569373E-05
     +,   4.8204594E-05,   4.1872230E-05,   3.6402449E-05
     +,   3.1658146E-05,   2.7528469E-05,   2.3923298E-05
     +,   2.0769288E-05,   1.8006447E-05,   1.5584703E-05
     +,   1.3462003E-05,   1.1602667E-05,   9.9759609E-06
     +,   8.5549991E-06,   7.3161659E-06,   6.2386189E-06
     +,   5.3037761E-06,   4.4949588E-06,   3.7972316E-06
     +,   3.1972445E-06,   2.6830073E-06,   2.2437457E-06
     +,   1.8698294E-06,   1.5527008E-06,   1.2847145E-06
     +,   1.0590959E-06,   8.6987586E-07,   7.1179949E-07
     +,   5.8025188E-07,   4.7121063E-07,   3.8118907E-07
     +,   3.0717143E-07,   2.4655782E-07,   1.9712287E-07
     +,   1.5697279E-07,   1.2450045E-07,   9.8346796E-08
     +,   7.7370615E-08,   6.0619506E-08,   4.7299217E-08
     +,   3.6752336E-08,   2.8437919E-08,   2.1912159E-08
     +,   1.6812516E-08,   1.2844787E-08,   9.7715063E-09
     +,   7.4017033E-09,   5.5824554E-09,   4.1920827E-09
     +,   3.1343410E-09,   2.3332389E-09,   1.7293021E-09
     +,   1.2760457E-09,   9.3745234E-10,   6.8565542E-10
     +,   4.9927501E-10,   3.6194200E-10,   2.6122085E-10
     +,   1.8768714E-10,   1.3425328E-10,   9.5603157E-11
     +,   6.7774827E-11,   4.7832311E-11,   3.3606281E-11
     +,   2.3505706E-11,   1.6366956E-11,   1.1345268E-11
     +,   7.8289198E-12,   5.3782256E-12,   3.6780344E-12
     +,   2.5040434E-12,   1.6970967E-12,   1.1450409E-12
     +,   7.6908402E-13,   5.1425449E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt80 = Yx/0.44156
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8059256E-07,   7.3784418E-07
     +,   7.9949416E-07,   8.6588108E-07,   9.3737452E-07
     +,   1.0143798E-06,   1.0973404E-06,   1.1867438E-06
     +,   1.2831225E-06,   1.3870682E-06,   1.4992253E-06
     +,   1.6203038E-06,   1.7510853E-06,   1.8924259E-06
     +,   2.0452687E-06,   2.2106435E-06,   2.3896816E-06
     +,   2.5836173E-06,   2.7937995E-06,   3.0216963E-06
     +,   3.2689036E-06,   3.5371522E-06,   3.8283083E-06
     +,   4.1444077E-06,   4.4876042E-06,   4.8602433E-06
     +,   5.2648170E-06,   5.7039861E-06,   6.1805817E-06
     +,   6.6976068E-06,   7.2582338E-06,   7.8658104E-06
     +,   8.5238507E-06,   9.2360433E-06,   1.0006235E-05
     +,   1.0838449E-05,   1.1736856E-05,   1.2705781E-05
     +,   1.3749764E-05,   1.4873390E-05,   1.6081507E-05
     +,   1.7379067E-05,   1.8771188E-05,   2.0263162E-05
     +,   2.1860442E-05,   2.3568688E-05,   2.5393734E-05
     +,   2.7341652E-05,   2.9418721E-05,   3.1631480E-05
     +,   3.3986733E-05,   3.6491572E-05,   3.9153318E-05
     +,   4.1979787E-05,   4.4978777E-05,   4.8158679E-05
     +,   5.1527983E-05,   5.5095406E-05,   5.8869868E-05
     +,   6.2860301E-05,   6.7075598E-05,   7.1524591E-05
     +,   7.6215358E-05,   8.1155835E-05,   8.6353211E-05
     +,   9.1813054E-05,   9.7540389E-05,   1.0353787E-04
     +,   1.0980704E-04,   1.1634655E-04,   1.2315344E-04
     +,   1.3022141E-04,   1.3754237E-04,   1.4510451E-04
     +,   1.5289422E-04,   1.6089546E-04,   1.6908972E-04
     +,   1.7745694E-04,   1.8597674E-04,   1.9462890E-04
     +,   2.0339334E-04,   2.1225328E-04,   2.2119425E-04
     +,   2.3020765E-04,   2.3928926E-04,   2.4844342E-04
     +,   2.5768077E-04,   2.6702162E-04,   2.7649390E-04
     +,   2.8613483E-04,   2.9599006E-04,   3.0611086E-04
     +,   3.1655424E-04,   3.2738145E-04,   3.3865511E-04
     +,   3.5043611E-04,   3.6278431E-04,   3.7575388E-04
     +,   3.8939604E-04,   4.0375479E-04,   4.1887286E-04
     +,   4.3478972E-04,   4.5154913E-04,   4.6920148E-04
     +,   4.8781361E-04,   5.0747639E-04,   5.2831462E-04
     +,   5.5049994E-04,   5.7426892E-04,   5.9993839E-04
     +,   6.2792178E-04,   6.5875705E-04,   6.9311331E-04
     +,   7.3181128E-04,   7.7580847E-04,   8.2618138E-04
     +,   8.8405999E-04,   9.5054478E-04,   1.0265636E-03
     +,   1.1127266E-03,   1.2091568E-03,   1.3153289E-03
     +,   1.4299940E-03,   1.5511971E-03,   1.6764215E-03
     +,   1.8028911E-03,   1.9280504E-03,   2.0501057E-03
     +,   2.1686470E-03,   2.2851287E-03,   2.4031620E-03
     +,   2.5283713E-03,   2.6678196E-03,   2.8288206E-03
     +,   3.0174244E-03,   3.2367469E-03,   3.4857048E-03
     +,   3.7587802E-03,   4.0473789E-03,   4.3429481E-03
     +,   4.6414584E-03,   4.9479990E-03,   5.2795107E-03
     +,   5.6639444E-03,   6.1354530E-03,   6.7274985E-03
     +,   7.4668792E-03,   8.3721383E-03,   9.4591491E-03
     +,   1.0753885E-02,   1.2311029E-02,   1.4241138E-02
     +,   1.6723631E-02,   1.9912584E-02,   2.3736879E-02
     +,   2.7932134E-02,   3.2493230E-02,   3.7957475E-02
     +,   4.5095105E-02,   5.4481391E-02,   6.5623537E-02
     +,   7.6625481E-02,   8.5108504E-02,   9.0414889E-02
     +,   9.2342734E-02,   9.0246104E-02,   8.7396532E-02
     +,   8.6025044E-02,   8.7207645E-02,   8.6271316E-02
     +,   7.8482643E-02,   6.7364916E-02,   5.6703221E-02
     +,   4.9063604E-02,   4.4227682E-02,   3.9219350E-02
     +,   3.3290558E-02,   2.7915586E-02,   2.3853067E-02
     +,   2.0712839E-02,   1.7961845E-02,   1.5471222E-02
     +,   1.3396898E-02,   1.1854132E-02,   1.0773174E-02
     +,   9.9753411E-03,   9.2984382E-03,   8.6548394E-03
     +,   8.0235312E-03,   7.4195936E-03,   6.8684779E-03
     +,   6.3899606E-03,   5.9892274E-03,   5.6540756E-03
     +,   5.3586345E-03,   5.0719706E-03,   4.7679427E-03
     +,   4.4321762E-03,   4.0640831E-03,   3.6742808E-03
     +,   3.2793696E-03,   2.8964146E-03,   2.5389574E-03
     +,   2.2152502E-03,   1.9283821E-03,   1.6774775E-03
     +,   1.4593371E-03,   1.2698501E-03,   1.1049149E-03
     +,   9.6091331E-04,   8.3486584E-04,   7.2438782E-04
     +,   6.2755775E-04,   5.4278615E-04,   4.6872383E-04
     +,   4.0419539E-04,   3.4814782E-04,   2.9962067E-04
     +,   2.5773601E-04,   2.2169296E-04,   1.9075671E-04
     +,   1.6426119E-04,   1.4161000E-04,   1.2227226E-04
     +,   1.0577950E-04,   9.1723217E-05,   7.9750753E-05
     +,   6.9558213E-05,   6.0884169E-05,   5.3504686E-05
     +,   4.7228434E-05,   4.1891210E-05,   3.7351623E-05
     +,   3.3488308E-05,   3.0197245E-05,   2.7388665E-05
     +,   2.4985637E-05,   2.2922412E-05,   2.1142874E-05
     +,   1.9599202E-05,   1.8250939E-05,   1.7064100E-05
     +,   1.6010226E-05,   1.5065562E-05,   1.4210475E-05
     +,   1.3428911E-05,   1.2707801E-05,   1.2036558E-05
     +,   1.1406726E-05,   1.0811689E-05,   1.0246230E-05
     +,   9.7063376E-06,   9.1890115E-06,   8.6920281E-06
     +,   8.2137431E-06,   7.7529921E-06,   7.3090068E-06
     +,   6.8812819E-06,   6.4694782E-06,   6.0733873E-06
     +,   5.6929130E-06,   5.3279964E-06,   4.9785735E-06
     +,   4.6445743E-06,   4.3259415E-06,   4.0225500E-06
     +,   3.7342406E-06,   3.4608292E-06,   3.2020880E-06
     +,   2.9577266E-06,   2.7274180E-06,   2.5108104E-06
     +,   2.3075168E-06,   2.1171065E-06,   1.9391234E-06
     +,   1.7731089E-06,   1.6185633E-06,   1.4749949E-06
     +,   1.3418847E-06,   1.2187265E-06,   1.1049967E-06
     +,   1.0001892E-06,   9.0378819E-07,   8.1530050E-07
     +,   7.3423001E-07,   6.6010489E-07,   5.9245968E-07
     +,   5.3084545E-07,   4.7483630E-07,   4.2401695E-07
     +,   3.7799754E-07,   3.3640185E-07,   2.9887835E-07
     +,   2.6509034E-07,   2.3472546E-07,   2.0748656E-07
     +,   1.8309926E-07,   1.6130456E-07,   1.4186456E-07
     +,   1.2455597E-07,   1.0917478E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt85 = Yx/0.44464
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4125625E-05,   1.4506603E-05
     +,   1.4888066E-05,   1.5269876E-05,   1.5651958E-05
     +,   1.6034250E-05,   1.6416776E-05,   1.6799591E-05
     +,   1.7182829E-05,   1.7566676E-05,   1.7951388E-05
     +,   1.8337287E-05,   1.8724759E-05,   1.9114277E-05
     +,   1.9506366E-05,   1.9901639E-05,   2.0300782E-05
     +,   2.0704543E-05,   2.1113745E-05,   2.1529277E-05
     +,   2.1952084E-05,   2.2383190E-05,   2.2823628E-05
     +,   2.3274537E-05,   2.3737035E-05,   2.4212304E-05
     +,   2.4701540E-05,   2.5205940E-05,   2.5726700E-05
     +,   2.6265005E-05,   2.6822010E-05,   2.7398832E-05
     +,   2.7996535E-05,   2.8616112E-05,   2.9258481E-05
     +,   2.9924462E-05,   3.0614789E-05,   3.1330041E-05
     +,   3.2070744E-05,   3.2837204E-05,   3.3629665E-05
     +,   3.4448210E-05,   3.5292749E-05,   3.6163092E-05
     +,   3.7058908E-05,   3.7979724E-05,   3.8924980E-05
     +,   3.9894021E-05,   4.0886098E-05,   4.1900414E-05
     +,   4.2936164E-05,   4.3992532E-05,   4.5068729E-05
     +,   4.6164099E-05,   4.7277998E-05,   4.8410009E-05
     +,   4.9559883E-05,   5.0727562E-05,   5.1913288E-05
     +,   5.3117576E-05,   5.4341268E-05,   5.5585573E-05
     +,   5.6852001E-05,   5.8142552E-05,   5.9459602E-05
     +,   6.0805814E-05,   6.2184394E-05,   6.3598745E-05
     +,   6.5052816E-05,   6.6550660E-05,   6.8096808E-05
     +,   6.9695823E-05,   7.1352653E-05,   7.3072217E-05
     +,   7.4859607E-05,   7.6720062E-05,   7.8658697E-05
     +,   8.0680591E-05,   8.2790997E-05,   8.4995198E-05
     +,   8.7298329E-05,   8.9705973E-05,   9.2223723E-05
     +,   9.4857867E-05,   9.7614997E-05,   1.0050298E-04
     +,   1.0353037E-04,   1.0670766E-04,   1.1004671E-04
     +,   1.1356183E-04,   1.1726994E-04,   1.2119066E-04
     +,   1.2534679E-04,   1.2976496E-04,   1.3447553E-04
     +,   1.3951237E-04,   1.4491376E-04,   1.5072117E-04
     +,   1.5698028E-04,   1.6373956E-04,   1.7105126E-04
     +,   1.7896981E-04,   1.8755377E-04,   1.9686396E-04
     +,   2.0696687E-04,   2.1793506E-04,   2.2984974E-04
     +,   2.4280400E-04,   2.5690836E-04,   2.7229520E-04
     +,   2.8912100E-04,   3.0757446E-04,   3.2787365E-04
     +,   3.5026952E-04,   3.7503429E-04,   4.0245580E-04
     +,   4.3281197E-04,   4.6635256E-04,   5.0325983E-04
     +,   5.4361986E-04,   5.8738474E-04,   6.3433597E-04
     +,   6.8406662E-04,   7.3597679E-04,   7.8928634E-04
     +,   8.4306707E-04,   8.9632208E-04,   9.4805908E-04
     +,   9.9741225E-04,   1.0437422E-03,   1.0867595E-03
     +,   1.1266033E-03,   1.1639078E-03,   1.1998079E-03
     +,   1.2359142E-03,   1.2742344E-03,   1.3170709E-03
     +,   1.3669160E-03,   1.4263657E-03,   1.4980705E-03
     +,   1.5847198E-03,   1.6890775E-03,   1.8140245E-03
     +,   1.9625861E-03,   2.1379127E-03,   2.3433315E-03
     +,   2.5824651E-03,   2.8595787E-03,   3.1802820E-03
     +,   3.5524452E-03,   3.9869817E-03,   4.4981185E-03
     +,   5.1031248E-03,   5.8218334E-03,   6.6752010E-03
     +,   7.6792906E-03,   8.8300994E-03,   1.0086754E-02
     +,   1.1384548E-02,   1.2706378E-02,   1.4176195E-02
     +,   1.6072547E-02,   1.8693144E-02,   2.2100687E-02
     +,   2.5971336E-02,   2.9950231E-02,   3.4266490E-02
     +,   3.9660227E-02,   4.7166493E-02,   5.7489619E-02
     +,   6.9336765E-02,   8.0894262E-02,   9.2236370E-02
     +,   0.1018611    ,   0.1066684    ,   0.1090711    
     +,   0.1098826    ,   0.1035915    ,   8.9825422E-02
     +,   7.6300412E-02,   6.7449428E-02,   5.8410849E-02
     +,   4.9360678E-02,   4.2595927E-02,   3.7499592E-02
     +,   3.3542387E-02,   3.0401519E-02,   2.7476246E-02
     +,   2.4314579E-02,   2.0969514E-02,   1.7900720E-02
     +,   1.5541398E-02,   1.3990279E-02,   1.3021348E-02
     +,   1.2283024E-02,   1.1508025E-02,   1.0612278E-02
     +,   9.6577406E-03,   8.7485723E-03,   7.9505527E-03
     +,   7.2701378E-03,   6.6756913E-03,   6.1272797E-03
     +,   5.5951038E-03,   5.0639361E-03,   4.5297779E-03
     +,   3.9954144E-03,   3.4676297E-03,   2.9559887E-03
     +,   2.4718470E-03,   2.0268159E-03,   1.6306984E-03
     +,   1.2896202E-03,   1.0051278E-03,   7.7451766E-04
     +,   5.9201103E-04,   4.5022721E-04,   3.4150897E-04
     +,   2.5884065E-04,   1.9629142E-04,   1.4908945E-04
     +,   1.1352324E-04,   8.6755354E-05,   6.6630244E-05
     +,   5.1514475E-05,   4.0173371E-05,   3.1675740E-05
     +,   2.5319661E-05,   2.0576204E-05,   1.7046939E-05
     +,   1.4431222E-05,   1.2501124E-05,   1.1083283E-05
     +,   1.0045706E-05,   9.2879836E-06,   8.7338067E-06
     +,   8.3256136E-06,   8.0203654E-06,   7.7861914E-06
     +,   7.5998041E-06,   7.4444392E-06,   7.3082369E-06
     +,   7.1829559E-06,   7.0629862E-06,   6.9446132E-06
     +,   6.8254622E-06,   6.7040851E-06,   6.5796630E-06
     +,   6.4517976E-06,   6.3203879E-06,   6.1855021E-06
     +,   6.0473240E-06,   5.9061194E-06,   5.7622001E-06
     +,   5.6158942E-06,   5.4675434E-06,   5.3175031E-06
     +,   5.1661318E-06,   5.0137751E-06,   4.8607717E-06
     +,   4.7074632E-06,   4.5541819E-06,   4.4012418E-06
     +,   4.2489414E-06,   4.0975860E-06,   3.9474517E-06
     +,   3.7987984E-06,   3.6518832E-06,   3.5069488E-06
     +,   3.3642109E-06,   3.2238715E-06,   3.0861249E-06
     +,   2.9511491E-06,   2.8190975E-06,   2.6901082E-06
     +,   2.5643142E-06,   2.4418184E-06,   2.3227228E-06
     +,   2.2071006E-06,   2.0950229E-06,   1.9865336E-06
     +,   1.8816773E-06,   1.7804707E-06,   1.6829324E-06
     +,   1.5890552E-06,   1.4988333E-06,   1.4122415E-06
     +,   1.3292450E-06,   1.2498080E-06,   1.1738750E-06
     +,   1.1013940E-06,   1.0322951E-06,   9.6651183E-07
     +,   9.0396344E-07,   8.4457247E-07,   7.8824849E-07
     +,   7.3490560E-07,   6.8444791E-07,   6.3678300E-07
     +,   5.9181059E-07,   5.4943513E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt90 = Yx/0.45486
      RETURN
      END
      DOUBLE PRECISION FUNCTION A1995N_tt_asha_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1426435E-06,   6.4750561E-06
     +,   6.8282347E-06,   7.2037651E-06,   7.6033180E-06
     +,   8.0286427E-06,   8.4815565E-06,   8.9639479E-06
     +,   9.4777397E-06,   1.0024929E-05,   1.0607509E-05
     +,   1.1227492E-05,   1.1886880E-05,   1.2587649E-05
     +,   1.3331726E-05,   1.4120967E-05,   1.4957137E-05
     +,   1.5841877E-05,   1.6776696E-05,   1.7762932E-05
     +,   1.8801742E-05,   1.9894065E-05,   2.1040601E-05
     +,   2.2241878E-05,   2.3498025E-05,   2.4809027E-05
     +,   2.6174523E-05,   2.7593866E-05,   2.9066123E-05
     +,   3.0590083E-05,   3.2164247E-05,   3.3786866E-05
     +,   3.5455909E-05,   3.7169142E-05,   3.8924125E-05
     +,   4.0718234E-05,   4.2548709E-05,   4.4412631E-05
     +,   4.6307148E-05,   4.8229133E-05,   5.0175680E-05
     +,   5.2143805E-05,   5.4130578E-05,   5.6133198E-05
     +,   5.8148977E-05,   6.0175367E-05,   6.2209983E-05
     +,   6.4250620E-05,   6.6295273E-05,   6.8342109E-05
     +,   7.0389513E-05,   7.2436058E-05,   7.4480500E-05
     +,   7.6521836E-05,   7.8559118E-05,   8.0591737E-05
     +,   8.2619074E-05,   8.4640807E-05,   8.6656699E-05
     +,   8.8666733E-05,   9.0671005E-05,   9.2669914E-05
     +,   9.4663956E-05,   9.6654017E-05,   9.8641314E-05
     +,   1.0062721E-04,   1.0261370E-04,   1.0460307E-04
     +,   1.0659826E-04,   1.0860265E-04,   1.1062044E-04
     +,   1.1265622E-04,   1.1471561E-04,   1.1680468E-04
     +,   1.1893045E-04,   1.2110065E-04,   1.2332368E-04
     +,   1.2560848E-04,   1.2796484E-04,   1.3040313E-04
     +,   1.3293374E-04,   1.3556781E-04,   1.3831627E-04
     +,   1.4119044E-04,   1.4420113E-04,   1.4735936E-04
     +,   1.5067523E-04,   1.5415902E-04,   1.5781984E-04
     +,   1.6166661E-04,   1.6570785E-04,   1.6995126E-04
     +,   1.7440428E-04,   1.7907447E-04,   1.8396971E-04
     +,   1.8909790E-04,   1.9446838E-04,   2.0009141E-04
     +,   2.0597967E-04,   2.1214732E-04,   2.1861189E-04
     +,   2.2539303E-04,   2.3251418E-04,   2.4000116E-04
     +,   2.4788303E-04,   2.5619115E-04,   2.6495810E-04
     +,   2.7421641E-04,   2.8399876E-04,   2.9433565E-04
     +,   3.0525256E-04,   3.1677168E-04,   3.2890725E-04
     +,   3.4166884E-04,   3.5505899E-04,   3.6907740E-04
     +,   3.8372239E-04,   3.9899905E-04,   4.1492432E-04
     +,   4.3153978E-04,   4.4892341E-04,   4.6720076E-04
     +,   4.8656139E-04,   5.0727127E-04,   5.2968145E-04
     +,   5.5422843E-04,   5.8143295E-04,   6.1187730E-04
     +,   6.4618024E-04,   6.8494881E-04,   7.2872854E-04
     +,   7.7793252E-04,   8.3278836E-04,   8.9326478E-04
     +,   9.5904467E-04,   1.0294986E-03,   1.1036942E-03
     +,   1.1804510E-03,   1.2584246E-03,   1.3362191E-03
     +,   1.4125117E-03,   1.4862032E-03,   1.5565654E-03
     +,   1.6233609E-03,   1.6869511E-03,   1.7483850E-03
     +,   1.8094237E-03,   1.8725147E-03,   1.9406802E-03
     +,   2.0173034E-03,   2.1057974E-03,   2.2091896E-03
     +,   2.3297307E-03,   2.4686360E-03,   2.6261630E-03
     +,   2.8021468E-03,   2.9970321E-03,   3.2131898E-03
     +,   3.4560007E-03,   3.7340727E-03,   4.0584835E-03
     +,   4.4415356E-03,   4.8968685E-03,   5.4428000E-03
     +,   6.1084996E-03,   6.9390009E-03,   7.9922052E-03
     +,   9.3211588E-03,   1.0937786E-02,   1.2769612E-02
     +,   1.4661370E-02,   1.6508635E-02,   1.8515961E-02
     +,   2.1269701E-02,   2.5249973E-02,   3.0170290E-02
     +,   3.5186585E-02,   4.0274933E-02,   4.7082581E-02
     +,   5.6755487E-02,   6.8692930E-02,   8.2283869E-02
     +,   9.4260417E-02,   0.1027320    ,   0.1105337    
     +,   0.1130640    ,   0.1081951    ,   9.9915065E-02
     +,   8.9115269E-02,   7.8295268E-02,   7.0358463E-02
     +,   6.2953316E-02,   5.3358864E-02,   4.2709935E-02
     +,   3.3943910E-02,   2.8605958E-02,   2.5735561E-02
     +,   2.3615159E-02,   2.1288970E-02,   1.8656598E-02
     +,   1.5982850E-02,   1.3509713E-02,   1.1353178E-02
     +,   9.5327124E-03,   8.0121038E-03,   6.7371465E-03
     +,   5.6609944E-03,   4.7486429E-03,   3.9723683E-03
     +,   3.3094087E-03,   2.7420332E-03,   2.2569350E-03
     +,   1.8436889E-03,   1.4934686E-03,   1.1985087E-03
     +,   9.5197157E-04,   7.4782036E-04,   5.8063032E-04
     +,   4.4541911E-04,   3.3754102E-04,   2.5264622E-04
     +,   1.8674808E-04,   1.3628734E-04,   9.8166071E-05
     +,   6.9754286E-05,   4.8870785E-05,   3.3741031E-05
     +,   2.2943710E-05,   1.5358119E-05,   1.0115325E-05
     +,   6.5528616E-06,   4.1741364E-06,   2.6138418E-06
     +,   1.6087416E-06,   9.7307463E-07,   5.7837730E-07
     +,   3.3778500E-07,   1.9382585E-07,   1.0927054E-07
     +,   6.0516228E-08,   3.2920696E-08,   1.7589608E-08
     +,   9.2297272E-09,   4.7555742E-09,   2.4056526E-09
     +,   1.1946503E-09,   5.8238625E-10,   2.7870894E-10
     +,   1.3096357E-10,   6.0464043E-11,   2.7463700E-11
     +,   1.2305689E-11,   5.4686069E-12,   2.4350021E-12
     +,   1.1061999E-12,   5.2757804E-13,   2.7377400E-13
     +,   1.5897479E-13,   1.0351593E-13,   7.3780303E-14
     +,   5.5714968E-14,   4.3426390E-14,   3.4375680E-14
     +,   2.7395556E-14,   2.1886284E-14,   1.7491952E-14
     +,   1.3972445E-14,   1.1150570E-14,   8.8887172E-15
     +,   7.0772008E-15,   5.6279118E-15,   4.4698627E-15
     +,   3.5457178E-15,   2.8091310E-15,   2.2227686E-15
     +,   1.7566216E-15,   1.3864862E-15,   1.0929836E-15
     +,   8.6053322E-16,   6.7667715E-16,   5.3143535E-16
     +,   4.1684956E-16,   3.2656016E-16,   2.5550947E-16
     +,   1.9966715E-16,   1.5583545E-16,   1.2147424E-16
     +,   9.4570441E-17,   7.3534153E-17,   5.7105360E-17
     +,   4.4291938E-17,   3.4310532E-17,   2.6545506E-17
     +,   2.0512072E-17,   1.5830257E-17,   1.2201685E-17
     +,   9.3932281E-18,   7.2220817E-18,   5.5459151E-18
     +,   4.2533950E-18,   3.2580777E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A1995N_tt_asha_htt95 = Yx/0.4382
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4118991E-06,   1.5063837E-06
     +,   1.6057277E-06,   1.7100667E-06,   1.8195325E-06
     +,   1.9342531E-06,   2.0543496E-06,   2.1799372E-06
     +,   2.3111227E-06,   2.4480128E-06,   2.5906998E-06
     +,   2.7392709E-06,   2.8938036E-06,   3.0543699E-06
     +,   3.2210319E-06,   3.3938434E-06,   3.5728522E-06
     +,   3.7580967E-06,   3.9496108E-06,   4.1474214E-06
     +,   4.3515515E-06,   4.5620209E-06,   4.7788453E-06
     +,   5.0020544E-06,   5.2316559E-06,   5.4676921E-06
     +,   5.7101965E-06,   5.9592217E-06,   6.2148351E-06
     +,   6.4771298E-06,   6.7462229E-06,   7.0222645E-06
     +,   7.3054425E-06,   7.5959892E-06,   7.8941921E-06
     +,   8.2003926E-06,   8.5149986E-06,   8.8384877E-06
     +,   9.1714428E-06,   9.5144960E-06,   9.8684159E-06
     +,   1.0234057E-05,   1.0612392E-05,   1.1004518E-05
     +,   1.1411653E-05,   1.1835162E-05,   1.2276546E-05
     +,   1.2737452E-05,   1.3219682E-05,   1.3725192E-05
     +,   1.4256099E-05,   1.4814671E-05,   1.5403342E-05
     +,   1.6024742E-05,   1.6681588E-05,   1.7376842E-05
     +,   1.8113580E-05,   1.8895060E-05,   1.9724703E-05
     +,   2.0606099E-05,   2.1543023E-05,   2.2539452E-05
     +,   2.3599483E-05,   2.4727518E-05,   2.5928206E-05
     +,   2.7206330E-05,   2.8567121E-05,   3.0015955E-05
     +,   3.1558768E-05,   3.3201646E-05,   3.4951354E-05
     +,   3.6814872E-05,   3.8799917E-05,   4.0914492E-05
     +,   4.3167285E-05,   4.5567573E-05,   4.8124970E-05
     +,   5.0849576E-05,   5.3752050E-05,   5.6843426E-05
     +,   6.0134669E-05,   6.3637206E-05,   6.7361972E-05
     +,   7.1320042E-05,   7.5521551E-05,   7.9976409E-05
     +,   8.4693100E-05,   8.9679459E-05,   9.4941359E-05
     +,   1.0048364E-04,   1.0630947E-04,   1.1241986E-04
     +,   1.1881410E-04,   1.2549003E-04,   1.3244408E-04
     +,   1.3967046E-04,   1.4716321E-04,   1.5491464E-04
     +,   1.6291760E-04,   1.7116389E-04,   1.7964665E-04
     +,   1.8835883E-04,   1.9729519E-04,   2.0645082E-04
     +,   2.1582270E-04,   2.2540908E-04,   2.3520856E-04
     +,   2.4522006E-04,   2.5544289E-04,   2.6587583E-04
     +,   2.7651459E-04,   2.8735385E-04,   2.9838312E-04
     +,   3.0958909E-04,   3.2095189E-04,   3.3244785E-04
     +,   3.4404604E-04,   3.5571199E-04,   3.6740550E-04
     +,   3.7908542E-04,   3.9070987E-04,   4.0223968E-04
     +,   4.1364305E-04,   4.2490268E-04,   4.3602235E-04
     +,   4.4703449E-04,   4.5801650E-04,   4.6910092E-04
     +,   4.8049839E-04,   4.9251335E-04,   5.0557178E-04
     +,   5.2023889E-04,   5.3724129E-04,   5.5747281E-04
     +,   5.8199081E-04,   6.1198522E-04,   6.4871478E-04
     +,   6.9341226E-04,   7.4715476E-04,   8.1070221E-04
     +,   8.8431773E-04,   9.6760411E-04,   1.0593886E-03
     +,   1.1576633E-03,   1.2596293E-03,   1.3618793E-03
     +,   1.4606804E-03,   1.5523455E-03,   1.6336784E-03
     +,   1.7024003E-03,   1.7574859E-03,   1.7993600E-03
     +,   1.8299035E-03,   1.8522493E-03,   1.8703849E-03
     +,   1.8886116E-03,   1.9109681E-03,   1.9406943E-03
     +,   1.9798456E-03,   2.0291265E-03,   2.0879849E-03
     +,   2.1549459E-03,   2.2281085E-03,   2.3057237E-03
     +,   2.3867206E-03,   2.4710514E-03,   2.5597957E-03
     +,   2.6550116E-03,   2.7593286E-03,   2.8753760E-03
     +,   3.0051291E-03,   3.1493322E-03,   3.3070534E-03
     +,   3.4754886E-03,   3.6500429E-03,   3.8247590E-03
     +,   3.9929864E-03,   4.1482300E-03,   4.2850566E-03
     +,   4.3998398E-03,   4.4912142E-03,   4.5601050E-03
     +,   4.6093334E-03,   4.6429229E-03,   4.6653221E-03
     +,   4.6809432E-03,   4.6942709E-03,   4.7107106E-03
     +,   4.7379928E-03,   4.7878018E-03,   4.8772935E-03
     +,   5.0300113E-03,   5.2754967E-03,   5.6461585E-03
     +,   6.1711473E-03,   6.8711778E-03,   7.7655800E-03
     +,   8.9031653E-03,   1.0404155E-02,   1.2465095E-02
     +,   1.5342624E-02,   1.9441107E-02,   2.5427826E-02
     +,   3.4222618E-02,   4.7344781E-02,   6.9743462E-02
     +,   0.1127678    ,   0.1759730    ,   0.2438207    
     +,   0.2987663    ,   0.2802504    ,   0.1947687    
     +,   0.1150600    ,   5.8769252E-02,   2.7894802E-02
     +,   1.3279161E-02,   5.8706980E-03,   2.3486193E-03
     +,   9.3054248E-04,   4.3081993E-04,   2.5594523E-04
     +,   1.8641289E-04,   1.4978398E-04,   1.2355651E-04
     +,   1.0190679E-04,   8.3468520E-05,   6.7734698E-05
     +,   5.4412052E-05,   4.3316293E-05,   3.4287023E-05
     +,   2.7127835E-05,   2.1595011E-05,   1.7418932E-05
     +,   1.4332983E-05,   1.2094913E-05,   1.0497263E-05
     +,   9.3706931E-06,   8.5819529E-06,   8.0293148E-06
     +,   7.6372635E-06,   7.3512979E-06,   7.1331369E-06
     +,   6.9566140E-06,   6.8043300E-06,   6.6650750E-06
     +,   6.5318577E-06,   6.4004948E-06,   6.2685895E-06
     +,   6.1348796E-06,   5.9988074E-06,   5.8602077E-06
     +,   5.7191510E-06,   5.5758483E-06,   5.4305810E-06
     +,   5.2836567E-06,   5.1353963E-06,   4.9861378E-06
     +,   4.8362144E-06,   4.6859454E-06,   4.5356423E-06
     +,   4.3856157E-06,   4.2361685E-06,   4.0875784E-06
     +,   3.9401143E-06,   3.7940438E-06,   3.6496072E-06
     +,   3.5070309E-06,   3.3665374E-06,   3.2283310E-06
     +,   3.0925949E-06,   2.9594953E-06,   2.8291929E-06
     +,   2.7018323E-06,   2.5775344E-06,   2.4564060E-06
     +,   2.3385508E-06,   2.2240424E-06,   2.1129554E-06
     +,   2.0053362E-06,   1.9012315E-06,   1.8006629E-06
     +,   1.7036516E-06,   1.6101957E-06,   1.5202943E-06
     +,   1.4339239E-06,   1.3510632E-06,   1.2716733E-06
     +,   1.1957071E-06,   1.1231177E-06,   1.0538409E-06
     +,   9.8781618E-07,   9.2496748E-07,   8.6522294E-07
     +,   8.0849799E-07,   7.5471183E-07,   7.0377308E-07
     +,   6.5559465E-07,   6.1008086E-07,   5.6714055E-07
     +,   5.2667576E-07,   4.8859289E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt100 = Yx/0.4613
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8570496E-05,   1.9611622E-05
     +,   2.0700349E-05,   2.1837215E-05,   2.3022614E-05
     +,   2.4256784E-05,   2.5539786E-05,   2.6871528E-05
     +,   2.8251705E-05,   2.9679892E-05,   3.1155410E-05
     +,   3.2677399E-05,   3.4244807E-05,   3.5856381E-05
     +,   3.7510668E-05,   3.9205999E-05,   4.0940555E-05
     +,   4.2712290E-05,   4.4519016E-05,   4.6358375E-05
     +,   4.8227848E-05,   5.0124792E-05,   5.2046435E-05
     +,   5.3990043E-05,   5.5952612E-05,   5.7931327E-05
     +,   5.9923248E-05,   6.1925581E-05,   6.3935520E-05
     +,   6.5950531E-05,   6.7968183E-05,   6.9986338E-05
     +,   7.2003138E-05,   7.4017167E-05,   7.6027405E-05
     +,   7.8033365E-05,   8.0035199E-05,   8.2033643E-05
     +,   8.4030369E-05,   8.6027692E-05,   8.8029177E-05
     +,   9.0039102E-05,   9.2063106E-05,   9.4108051E-05
     +,   9.6182106E-05,   9.8294928E-05,   1.0045776E-04
     +,   1.0268346E-04,   1.0498668E-04,   1.0738404E-04
     +,   1.0989400E-04,   1.1253722E-04,   1.1533639E-04
     +,   1.1831663E-04,   1.2150507E-04,   1.2493147E-04
     +,   1.2862774E-04,   1.3262829E-04,   1.3696986E-04
     +,   1.4169136E-04,   1.4683408E-04,   1.5244131E-04
     +,   1.5855780E-04,   1.6523061E-04,   1.7250796E-04
     +,   1.8043871E-04,   1.8907302E-04,   1.9846045E-04
     +,   2.0865115E-04,   2.1969348E-04,   2.3163555E-04
     +,   2.4452197E-04,   2.5839609E-04,   2.7329626E-04
     +,   2.8925797E-04,   3.0631188E-04,   3.2448204E-04
     +,   3.4378658E-04,   3.6423746E-04,   3.8584031E-04
     +,   4.0859156E-04,   4.3248234E-04,   4.5749443E-04
     +,   4.8360642E-04,   5.1078812E-04,   5.3900818E-04
     +,   5.6822883E-04,   5.9841608E-04,   6.2953215E-04
     +,   6.6154549E-04,   6.9442892E-04,   7.2815997E-04
     +,   7.6272443E-04,   7.9811807E-04,   8.3434663E-04
     +,   8.7142410E-04,   9.0937893E-04,   9.4824866E-04
     +,   9.8809192E-04,   1.0289802E-03,   1.0710168E-03
     +,   1.1143280E-03,   1.1590831E-03,   1.2054874E-03
     +,   1.2537948E-03,   1.3043026E-03,   1.3573385E-03
     +,   1.4132468E-03,   1.4723670E-03,   1.5349906E-03
     +,   1.6013158E-03,   1.6714050E-03,   1.7451295E-03
     +,   1.8221394E-03,   1.9018301E-03,   1.9833546E-03
     +,   2.0656439E-03,   2.1474853E-03,   2.2276102E-03
     +,   2.3048399E-03,   2.3782353E-03,   2.4472526E-03
     +,   2.5119015E-03,   2.5728629E-03,   2.6315588E-03
     +,   2.6901318E-03,   2.7513679E-03,   2.8184801E-03
     +,   2.8948581E-03,   2.9837114E-03,   3.0877381E-03
     +,   3.2088037E-03,   3.3477729E-03,   3.5044304E-03
     +,   3.6776566E-03,   3.8656727E-03,   4.0664100E-03
     +,   4.2778468E-03,   4.4982359E-03,   4.7261282E-03
     +,   4.9602021E-03,   5.1990147E-03,   5.4408084E-03
     +,   5.6835352E-03,   5.9251143E-03,   6.1640134E-03
     +,   6.3997097E-03,   6.6328272E-03,   6.8645957E-03
     +,   7.0958952E-03,   7.3261592E-03,   7.5531527E-03
     +,   7.7742995E-03,   7.9895509E-03,   8.2047656E-03
     +,   8.4336456E-03,   8.6962851E-03,   9.0135625E-03
     +,   9.3991561E-03,   9.8528303E-03,   1.0359675E-02
     +,   1.0896415E-02,   1.1441800E-02,   1.1984041E-02
     +,   1.2519201E-02,   1.3040771E-02,   1.3528676E-02
     +,   1.3948877E-02,   1.4267398E-02,   1.4471169E-02
     +,   1.4580909E-02,   1.4645159E-02,   1.4717837E-02
     +,   1.4833202E-02,   1.4994238E-02,   1.5180511E-02
     +,   1.5369701E-02,   1.5557357E-02,   1.5761053E-02
     +,   1.6005186E-02,   1.6298411E-02,   1.6621714E-02
     +,   1.6935740E-02,   1.7200802E-02,   1.7395033E-02
     +,   1.7522560E-02,   1.7610637E-02,   1.7697304E-02
     +,   1.7812358E-02,   1.7960314E-02,   1.8115951E-02
     +,   1.8234957E-02,   1.8271668E-02,   1.8197313E-02
     +,   1.8015180E-02,   1.7767005E-02,   1.7519474E-02
     +,   1.7331194E-02,   1.7222207E-02,   1.7170412E-02
     +,   1.7133750E-02,   1.7072638E-02,   1.6951732E-02
     +,   1.6726427E-02,   1.6336409E-02,   1.5720025E-02
     +,   1.4841364E-02,   1.3710768E-02,   1.2385088E-02
     +,   1.0949424E-02,   9.4924988E-03,   8.0874274E-03
     +,   6.7831990E-03,   5.6057614E-03,   4.5643817E-03
     +,   3.6585447E-03,   2.8828983E-03,   2.2297788E-03
     +,   1.6901575E-03,   1.2537615E-03,   9.0902945E-04
     +,   6.4348965E-04,   4.4433112E-04,   2.9904064E-04
     +,   1.9602061E-04,   1.2506683E-04,   7.7625577E-05
     +,   4.6844252E-05,   2.7469727E-05,   1.5644348E-05
     +,   8.6486170E-06,   4.6389728E-06,   2.4132517E-06
     +,   1.2172571E-06,   5.9543686E-07,   2.8269858E-07
     +,   1.3058255E-07,   5.9029876E-08,   2.6464255E-08
     +,   1.2100299E-08,   5.9361889E-09,   3.3379735E-09
     +,   2.2380653E-09,   1.7481092E-09,   1.5004360E-09
     +,   1.3483201E-09,   1.2351750E-09,   1.1398101E-09
     +,   1.0544112E-09,   9.7604780E-10,   9.0350211E-10
     +,   8.3614987E-10,   7.7357776E-10,   7.1545009E-10
     +,   6.6146244E-10,   6.1133570E-10,   5.6481181E-10
     +,   5.2164939E-10,   4.8161830E-10,   4.4450327E-10
     +,   4.1010625E-10,   3.7824122E-10,   3.4873043E-10
     +,   3.2140995E-10,   2.9612793E-10,   2.7273969E-10
     +,   2.5111055E-10,   2.3111689E-10,   2.1264154E-10
     +,   1.9557543E-10,   1.7981588E-10,   1.6526903E-10
     +,   1.5184660E-10,   1.3946574E-10,   1.2804963E-10
     +,   1.1752756E-10,   1.0783224E-10,   9.8902581E-11
     +,   9.0680838E-11,   8.3113794E-11,   7.6151530E-11
     +,   6.9748526E-11,   6.3861499E-11,   5.8451223E-11
     +,   5.3480536E-11,   4.8915760E-11,   4.4725029E-11
     +,   4.0879057E-11,   3.7350879E-11,   3.4115297E-11
     +,   3.1149246E-11,   2.8431148E-11,   2.5941273E-11
     +,   2.3661170E-11,   2.1574045E-11,   1.9664121E-11
     +,   1.7917130E-11,   1.6319614E-11,   1.4859431E-11
     +,   1.3525139E-11,   1.2306431E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt105 = Yx/0.2555
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1629428E-05,   1.2143882E-05
     +,   1.2683236E-05,   1.3248289E-05,   1.3839832E-05
     +,   1.4458651E-05,   1.5105512E-05,   1.5781179E-05
     +,   1.6486392E-05,   1.7221917E-05,   1.7988483E-05
     +,   1.8786830E-05,   1.9617704E-05,   2.0481870E-05
     +,   2.1380098E-05,   2.2313217E-05,   2.3282080E-05
     +,   2.4287621E-05,   2.5330844E-05,   2.6412863E-05
     +,   2.7534908E-05,   2.8698405E-05,   2.9904906E-05
     +,   3.1156284E-05,   3.2454551E-05,   3.3802160E-05
     +,   3.5201851E-05,   3.6656777E-05,   3.8170609E-05
     +,   3.9747487E-05,   4.1392195E-05,   4.3110143E-05
     +,   4.4907498E-05,   4.6791192E-05,   4.8769030E-05
     +,   5.0849761E-05,   5.3043110E-05,   5.5359826E-05
     +,   5.7811867E-05,   6.0412083E-05,   6.3174761E-05
     +,   6.6115164E-05,   6.9249814E-05,   7.2596296E-05
     +,   7.6173324E-05,   8.0000587E-05,   8.4098690E-05
     +,   8.8489040E-05,   9.3193557E-05,   9.8234668E-05
     +,   1.0363494E-04,   1.0941683E-04,   1.1560242E-04
     +,   1.2221345E-04,   1.2926999E-04,   1.3679139E-04
     +,   1.4479503E-04,   1.5329618E-04,   1.6230764E-04
     +,   1.7183959E-04,   1.8189900E-04,   1.9248966E-04
     +,   2.0361123E-04,   2.1526030E-04,   2.2742977E-04
     +,   2.4010768E-04,   2.5327993E-04,   2.6692750E-04
     +,   2.8102970E-04,   2.9556188E-04,   3.1049925E-04
     +,   3.2581371E-04,   3.4147911E-04,   3.5746788E-04
     +,   3.7375593E-04,   3.9032209E-04,   4.0714830E-04
     +,   4.2422247E-04,   4.4153983E-04,   4.5910408E-04
     +,   4.7692595E-04,   4.9502874E-04,   5.1344396E-04
     +,   5.3221633E-04,   5.5139832E-04,   5.7105615E-04
     +,   5.9126061E-04,   6.1209302E-04,   6.3363556E-04
     +,   6.5597345E-04,   6.7918788E-04,   7.0335186E-04
     +,   7.2852627E-04,   7.5475732E-04,   7.8207109E-04
     +,   8.1046979E-04,   8.3993591E-04,   8.7042700E-04
     +,   9.0188516E-04,   9.3423878E-04,   9.6741517E-04
     +,   1.0013446E-03,   1.0359784E-03,   1.0712899E-03
     +,   1.1072919E-03,   1.1440376E-03,   1.1816167E-03
     +,   1.2201563E-03,   1.2598091E-03,   1.3007370E-03
     +,   1.3430892E-03,   1.3869891E-03,   1.4325088E-03
     +,   1.4796651E-03,   1.5283981E-03,   1.5785944E-03
     +,   1.6300771E-03,   1.6826480E-03,   1.7361008E-03
     +,   1.7902757E-03,   1.8451029E-03,   1.9006582E-03
     +,   1.9572342E-03,   2.0154228E-03,   2.0761988E-03
     +,   2.1409902E-03,   2.2117400E-03,   2.2908961E-03
     +,   2.3813557E-03,   2.4862497E-03,   2.6086848E-03
     +,   2.7513045E-03,   2.9158704E-03,   3.1027868E-03
     +,   3.3108022E-03,   3.5368467E-03,   3.7761219E-03
     +,   4.0224688E-03,   4.2689801E-03,   4.5087337E-03
     +,   4.7355220E-03,   4.9445648E-03,   5.1330086E-03
     +,   5.3001004E-03,   5.4470040E-03,   5.5763922E-03
     +,   5.6916527E-03,   5.7961186E-03,   5.8923746E-03
     +,   5.9820409E-03,   6.0661160E-03,   6.1461502E-03
     +,   6.2259496E-03,   6.3133994E-03,   6.4215716E-03
     +,   6.5682302E-03,   6.7731161E-03,   7.0532695E-03
     +,   7.4177575E-03,   7.8638401E-03,   8.3768237E-03
     +,   8.9338236E-03,   9.5099406E-03,   1.0083909E-02
     +,   1.0639690E-02,   1.1163829E-02,   1.1640904E-02
     +,   1.2051702E-02,   1.2377330E-02,   1.2608403E-02
     +,   1.2755032E-02,   1.2852007E-02,   1.2954884E-02
     +,   1.3126479E-02,   1.3417245E-02,   1.3847247E-02
     +,   1.4397503E-02,   1.5014534E-02,   1.5624714E-02
     +,   1.6152265E-02,   1.6536484E-02,   1.6748378E-02
     +,   1.6805250E-02,   1.6775673E-02,   1.6765356E-02
     +,   1.6880808E-02,   1.7183024E-02,   1.7651433E-02
     +,   1.8176675E-02,   1.8588318E-02,   1.8711267E-02
     +,   1.8430345E-02,   1.7737724E-02,   1.6741149E-02
     +,   1.5628612E-02,   1.4605124E-02,   1.3827729E-02
     +,   1.3361896E-02,   1.3172579E-02,   1.3148957E-02
     +,   1.3148841E-02,   1.3043802E-02,   1.2749888E-02
     +,   1.2238327E-02,   1.1528996E-02,   1.0673382E-02
     +,   9.7346520E-03,   8.7708756E-03,   7.8249304E-03
     +,   6.9220020E-03,   6.0730348E-03,   5.2807638E-03
     +,   4.5451554E-03,   3.8667403E-03,   3.2476250E-03
     +,   2.6908503E-03,   2.1990051E-03,   1.7730364E-03
     +,   1.4116437E-03,   1.1112383E-03,   8.6626346E-04
     +,   6.6989305E-04,   5.1476847E-04,   3.9364139E-04
     +,   2.9986058E-04,   2.2767577E-04,   1.7233496E-04
     +,   1.3003514E-04,   9.7795921E-05,   7.3308889E-05
     +,   5.4789762E-05,   4.0852694E-05,   3.0416197E-05
     +,   2.2636170E-05,   1.6856502E-05,   1.2570196E-05
     +,   9.3907602E-06,   7.0276842E-06,   5.2653099E-06
     +,   3.9453207E-06,   2.9525431E-06,   2.2034769E-06
     +,   1.6373758E-06,   1.2096809E-06,   8.8735186E-07
     +,   6.4555519E-07,   4.6535095E-07,   3.3213081E-07
     +,   2.3456769E-07,   1.6386717E-07,   1.1320515E-07
     +,   7.7328437E-08,   5.2232103E-08,   3.4895358E-08
     +,   2.3068901E-08,   1.5102593E-08,   9.8037631E-09
     +,   6.3226122E-09,   4.0627550E-09,   2.6122557E-09
     +,   1.6908924E-09,   1.1108060E-09,   7.4792678E-10
     +,   5.2156218E-10,   3.8000053E-10,   2.9054709E-10
     +,   2.3283647E-10,   1.9435471E-10,   1.6750981E-10
     +,   1.4774881E-10,   1.3237264E-10,   1.1979383E-10
     +,   1.0908167E-10,   9.9689194E-11,   9.1290732E-11
     +,   8.3688396E-11,   7.6754894E-11,   7.0404564E-11
     +,   6.4574436E-11,   5.9215986E-11,   5.4288178E-11
     +,   4.9756119E-11,   4.5588137E-11,   4.1756043E-11
     +,   3.8233489E-11,   3.4996731E-11,   3.2023408E-11
     +,   2.9292905E-11,   2.6786426E-11,   2.4486219E-11
     +,   2.2376172E-11,   2.0441133E-11,   1.8667290E-11
     +,   1.7041656E-11,   1.5552500E-11,   1.4188708E-11
     +,   1.2940248E-11,   1.1797701E-11,   1.0752486E-11
     +,   9.7966010E-12,   8.9227575E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt107 = Yx/0.220577777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1209461E-05,   1.1638758E-05
     +,   1.2085129E-05,   1.2549444E-05,   1.3032660E-05
     +,   1.3535843E-05,   1.4060176E-05,   1.4606980E-05
     +,   1.5177721E-05,   1.5774061E-05,   1.6397831E-05
     +,   1.7051085E-05,   1.7736105E-05,   1.8455448E-05
     +,   1.9211944E-05,   2.0008743E-05,   2.0849324E-05
     +,   2.1737540E-05,   2.2677630E-05,   2.3674238E-05
     +,   2.4732464E-05,   2.5857857E-05,   2.7056429E-05
     +,   2.8334764E-05,   2.9699815E-05,   3.1159194E-05
     +,   3.2720942E-05,   3.4393615E-05,   3.6186288E-05
     +,   3.8108472E-05,   4.0170136E-05,   4.2381624E-05
     +,   4.4753611E-05,   4.7297053E-05,   5.0023078E-05
     +,   5.2942869E-05,   5.6067645E-05,   5.9408369E-05
     +,   6.2975938E-05,   6.6780463E-05,   7.0831811E-05
     +,   7.5138865E-05,   7.9709636E-05,   8.4550913E-05
     +,   8.9668247E-05,   9.5065574E-05,   1.0074514E-04
     +,   1.0670732E-04,   1.1295037E-04,   1.1947032E-04
     +,   1.2626080E-04,   1.3331308E-04,   1.4061568E-04
     +,   1.4815504E-04,   1.5591420E-04,   1.6387465E-04
     +,   1.7201494E-04,   1.8031172E-04,   1.8873966E-04
     +,   1.9727202E-04,   2.0588082E-04,   2.1453772E-04
     +,   2.2321384E-04,   2.3188148E-04,   2.4051456E-04
     +,   2.4908813E-04,   2.5758141E-04,   2.6597641E-04
     +,   2.7426088E-04,   2.8242712E-04,   2.9047506E-04
     +,   2.9841054E-04,   3.0624852E-04,   3.1401109E-04
     +,   3.2172987E-04,   3.2944541E-04,   3.3720650E-04
     +,   3.4507044E-04,   3.5310336E-04,   3.6137787E-04
     +,   3.6997275E-04,   3.7897253E-04,   3.8846425E-04
     +,   3.9853872E-04,   4.0928568E-04,   4.2079607E-04
     +,   4.3315731E-04,   4.4645515E-04,   4.6076911E-04
     +,   4.7617595E-04,   4.9274653E-04,   5.1054545E-04
     +,   5.2963122E-04,   5.5005809E-04,   5.7187461E-04
     +,   5.9512182E-04,   6.1983790E-04,   6.4605364E-04
     +,   6.7379733E-04,   7.0308940E-04,   7.3395181E-04
     +,   7.6639984E-04,   8.0045534E-04,   8.3614263E-04
     +,   8.7349833E-04,   9.1257680E-04,   9.5345371E-04
     +,   9.9623331E-04,   1.0410583E-03,   1.0881085E-03
     +,   1.1375983E-03,   1.1897795E-03,   1.2449253E-03
     +,   1.3033256E-03,   1.3652567E-03,   1.4309726E-03
     +,   1.5006607E-03,   1.5744345E-03,   1.6522834E-03
     +,   1.7340676E-03,   1.8194943E-03,   1.9081136E-03
     +,   1.9993407E-03,   2.0925021E-03,   2.1869068E-03
     +,   2.2819112E-03,   2.3770554E-03,   2.4721085E-03
     +,   2.5671683E-03,   2.6626296E-03,   2.7591463E-03
     +,   2.8574730E-03,   2.9582877E-03,   3.0619684E-03
     +,   3.1684134E-03,   3.2769400E-03,   3.3862847E-03
     +,   3.4947449E-03,   3.6004651E-03,   3.7017644E-03
     +,   3.7974797E-03,   3.8872773E-03,   3.9717993E-03
     +,   4.0526199E-03,   4.1319821E-03,   4.2123417E-03
     +,   4.2957780E-03,   4.3834052E-03,   4.4749938E-03
     +,   4.5689405E-03,   4.6627000E-03,   4.7537722E-03
     +,   4.8410045E-03,   4.9260068E-03,   5.0141695E-03
     +,   5.1148739E-03,   5.2405023E-03,   5.4043070E-03
     +,   5.6174714E-03,   5.8861696E-03,   6.2097032E-03
     +,   6.5804753E-03,   6.9863107E-03,   7.4150139E-03
     +,   7.8596333E-03,   8.3222399E-03,   8.8135460E-03
     +,   9.3470886E-03,   9.9291960E-03,   1.0548750E-02
     +,   1.1171972E-02,   1.1746378E-02,   1.2214522E-02
     +,   1.2533576E-02,   1.2692843E-02,   1.2719094E-02
     +,   1.2664378E-02,   1.2580702E-02,   1.2496641E-02
     +,   1.2411103E-02,   1.2306843E-02,   1.2171991E-02
     +,   1.2012482E-02,   1.1848213E-02,   1.1699270E-02
     +,   1.1574649E-02,   1.1471395E-02,   1.1383459E-02
     +,   1.1313076E-02,   1.1275890E-02,   1.1295095E-02
     +,   1.1387183E-02,   1.1548362E-02,   1.1751080E-02
     +,   1.1953331E-02,   1.2114224E-02,   1.2205871E-02
     +,   1.2215659E-02,   1.2140109E-02,   1.1976740E-02
     +,   1.1719978E-02,   1.1362912E-02,   1.0902484E-02
     +,   1.0343849E-02,   9.7008934E-03,   8.9928331E-03
     +,   8.2396325E-03,   7.4589886E-03,   6.6660466E-03
     +,   5.8750357E-03,   5.1010353E-03,   4.3603163E-03
     +,   3.6689111E-03,   3.0403440E-03,   2.4837623E-03
     +,   2.0030241E-03,   1.5969514E-03,   1.2604351E-03
     +,   9.8596129E-04,   7.6503190E-04,   5.8915425E-04
     +,   4.5051181E-04,   3.4225426E-04,   2.5853477E-04
     +,   1.9443803E-04,   1.4587266E-04,   1.0945603E-04
     +,   8.2409562E-05,   6.2477360E-05,   4.7859237E-05
     +,   3.7147405E-05,   2.9264291E-05,   2.3404195E-05
     +,   1.8979370E-05,   1.5570908E-05,   1.2885739E-05
     +,   1.0722638E-05,   8.9453179E-06,   7.4619138E-06
     +,   6.2102222E-06,   5.1474990E-06,   4.2434599E-06
     +,   3.4755342E-06,   2.8258592E-06,   2.2795275E-06
     +,   1.8235443E-06,   1.4462024E-06,   1.1367887E-06
     +,   8.8551076E-07,   6.8348669E-07,   5.2270002E-07
     +,   3.9603964E-07,   2.9729188E-07,   2.2110092E-07
     +,   1.6291663E-07,   1.1893810E-07,   8.6037780E-08
     +,   6.1676126E-08,   4.3818687E-08,   3.0859990E-08
     +,   2.1550171E-08,   1.4927942E-08,   1.0263109E-08
     +,   7.0084845E-09,   4.7591611E-09,   3.2186616E-09
     +,   2.1727189E-09,   1.4683273E-09,   9.9740260E-10
     +,   6.8445588E-10,   4.7738452E-10,   3.4063138E-10
     +,   2.5017829E-10,   1.8997343E-10,   1.4940629E-10
     +,   1.2153592E-10,   1.0185865E-10,   8.7483687E-11
     +,   7.6566808E-11,   6.7940945E-11,   6.0869226E-11
     +,   5.4887827E-11,   4.9702770E-11,   4.5126253E-11
     +,   4.1035401E-11,   3.7347847E-11,   3.4005604E-11
     +,   3.0966049E-11,   2.8196376E-11,   2.5669659E-11
     +,   2.3363561E-11,   2.1258250E-11,   1.9336487E-11
     +,   1.7582449E-11,   1.5982007E-11,   1.4522092E-11
     +,   1.3190857E-11,   1.1977343E-11,   1.0871607E-11
     +,   9.8643706E-12,   8.9472561E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt110 = Yx/0.175159090909091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.0509483E-05,   6.2549479E-05
     +,   6.4678396E-05,   6.6900378E-05,   6.9219488E-05
     +,   7.1639559E-05,   7.4164192E-05,   7.6796612E-05
     +,   7.9539677E-05,   8.2395913E-05,   8.5367195E-05
     +,   8.8454864E-05,   9.1659647E-05,   9.4981537E-05
     +,   9.8419790E-05,   1.0197285E-04,   1.0563830E-04
     +,   1.0941277E-04,   1.1329202E-04,   1.1727079E-04
     +,   1.2134294E-04,   1.2550116E-04,   1.2973727E-04
     +,   1.3404232E-04,   1.3840599E-04,   1.4281746E-04
     +,   1.4726495E-04,   1.5173593E-04,   1.5621720E-04
     +,   1.6069507E-04,   1.6515529E-04,   1.6958348E-04
     +,   1.7396496E-04,   1.7828512E-04,   1.8252952E-04
     +,   1.8668415E-04,   1.9073531E-04,   1.9467034E-04
     +,   1.9847750E-04,   2.0214602E-04,   2.0566677E-04
     +,   2.0903221E-04,   2.1223658E-04,   2.1527635E-04
     +,   2.1815028E-04,   2.2085985E-04,   2.2340915E-04
     +,   2.2580563E-04,   2.2805996E-04,   2.3018624E-04
     +,   2.3220267E-04,   2.3413102E-04,   2.3599775E-04
     +,   2.3783345E-04,   2.3967314E-04,   2.4155677E-04
     +,   2.4352883E-04,   2.4563857E-04,   2.4793984E-04
     +,   2.5049114E-04,   2.5335499E-04,   2.5659802E-04
     +,   2.6028999E-04,   2.6450356E-04,   2.6931340E-04
     +,   2.7479432E-04,   2.8102199E-04,   2.8806922E-04
     +,   2.9600703E-04,   3.0490017E-04,   3.1480790E-04
     +,   3.2577990E-04,   3.3785665E-04,   3.5106446E-04
     +,   3.6541672E-04,   3.8091029E-04,   3.9752334E-04
     +,   4.1521550E-04,   4.3392659E-04,   4.5357665E-04
     +,   4.7406321E-04,   4.9526728E-04,   5.1704823E-04
     +,   5.3925219E-04,   5.6170882E-04,   5.8424100E-04
     +,   6.0666236E-04,   6.2878855E-04,   6.5043604E-04
     +,   6.7143334E-04,   6.9162418E-04,   7.1087247E-04
     +,   7.2906853E-04,   7.4613711E-04,   7.6203857E-04
     +,   7.7677332E-04,   7.9038617E-04,   8.0296467E-04
     +,   8.1464299E-04,   8.2559488E-04,   8.3603436E-04
     +,   8.4620708E-04,   8.5638394E-04,   8.6685119E-04
     +,   8.7790028E-04,   8.8981615E-04,   9.0286357E-04
     +,   9.1727520E-04,   9.3324156E-04,   9.5089892E-04
     +,   9.7032060E-04,   9.9151675E-04,   1.0144257E-03
     +,   1.0389248E-03,   1.0648317E-03,   1.0919239E-03
     +,   1.1199496E-03,   1.1486561E-03,   1.1778094E-03
     +,   1.2072328E-03,   1.2368348E-03,   1.2666393E-03
     +,   1.2968242E-03,   1.3277468E-03,   1.3599686E-03
     +,   1.3942590E-03,   1.4316053E-03,   1.4731759E-03
     +,   1.5202855E-03,   1.5743135E-03,   1.6366179E-03
     +,   1.7083966E-03,   1.7905752E-03,   1.8836445E-03
     +,   1.9875602E-03,   2.1016563E-03,   2.2246060E-03
     +,   2.3544871E-03,   2.4889223E-03,   2.6252887E-03
     +,   2.7609812E-03,   2.8937166E-03,   3.0218128E-03
     +,   3.1443608E-03,   3.2612965E-03,   3.3733395E-03
     +,   3.4818086E-03,   3.5883037E-03,   3.6944342E-03
     +,   3.8015156E-03,   3.9103706E-03,   4.0212101E-03
     +,   4.1335877E-03,   4.2464333E-03,   4.3580756E-03
     +,   4.4663381E-03,   4.5687226E-03,   4.6627815E-03
     +,   4.7466462E-03,   4.8197135E-03,   4.8833811E-03
     +,   4.9415464E-03,   5.0007077E-03,   5.0694603E-03
     +,   5.1573771E-03,   5.2733417E-03,   5.4236618E-03
     +,   5.6104017E-03,   5.8303494E-03,   6.0750586E-03
     +,   6.3320608E-03,   6.5873810E-03,   6.8288711E-03
     +,   7.0497287E-03,   7.2512836E-03,   7.4440106E-03
     +,   7.6457616E-03,   7.8770220E-03,   8.1538819E-03
     +,   8.4809316E-03,   8.8468026E-03,   9.2246719E-03
     +,   9.5786387E-03,   9.8737786E-03,   1.0086253E-02
     +,   1.0209261E-02,   1.0252710E-02,   1.0236936E-02
     +,   1.0183957E-02,   1.0110312E-02,   1.0024377E-02
     +,   9.9282730E-03,   9.8219430E-03,   9.7059300E-03
     +,   9.5810965E-03,   9.4457399E-03,   9.2927134E-03
     +,   9.1090286E-03,   8.8789165E-03,   8.5888971E-03
     +,   8.2323384E-03,   7.8115058E-03,   7.3363897E-03
     +,   6.8215150E-03,   6.2823612E-03,   5.7325698E-03
     +,   5.1829861E-03,   4.6419040E-03,   4.1160276E-03
     +,   3.6113809E-03,   3.1338378E-03,   2.6890840E-03
     +,   2.2820896E-03,   1.9165146E-03,   1.5942696E-03
     +,   1.3153706E-03,   1.0780430E-03,   8.7908510E-04
     +,   7.1437389E-04,   5.7936477E-04,   4.6947500E-04
     +,   3.8040764E-04,   3.0834373E-04,   2.5001742E-04
     +,   2.0272422E-04,   1.6428293E-04,   1.3296548E-04
     +,   1.0741256E-04,   8.6553679E-05,   6.9541187E-05
     +,   5.5695829E-05,   4.4463552E-05,   3.5385547E-05
     +,   2.8078732E-05,   2.2222210E-05,   1.7545948E-05
     +,   1.3824489E-05,   1.0871075E-05,   8.5321799E-06
     +,   6.6827188E-06,   5.2218716E-06,   4.0691061E-06
     +,   3.1603927E-06,   2.4449928E-06,   1.8828363E-06
     +,   1.4422860E-06,   1.0982604E-06,   8.3079783E-07
     +,   6.2397157E-07,   4.6504678E-07,   3.4378760E-07
     +,   2.5198426E-07,   1.8306659E-07,   1.3179069E-07
     +,   9.3994103E-08,   6.6400972E-08,   4.6456908E-08
     +,   3.2187319E-08,   2.2081824E-08,   1.4999159E-08
     +,   1.0087011E-08,   6.7160211E-09,   4.4268611E-09
     +,   2.8886800E-09,   1.8660684E-09,   1.1933534E-09
     +,   7.5546430E-10,   4.7344045E-10,   2.9371655E-10
     +,   1.8038300E-10,   1.0966266E-10,   6.5996854E-11
     +,   3.9318479E-11,   2.3188439E-11,   1.3537544E-11
     +,   7.8237894E-12,   4.4759660E-12,   2.5349297E-12
     +,   1.4211397E-12,   7.8871003E-13,   4.3330083E-13
     +,   2.3565224E-13,   1.2686601E-13,   6.7612799E-14
     +,   3.5670089E-14,   1.8629009E-14,   9.6311161E-15
     +,   4.9289682E-15,   2.4971632E-15,   1.2523661E-15
     +,   6.2177263E-16,   3.0558379E-16,   1.4867963E-16
     +,   7.1611964E-17,   3.4148070E-17,   1.6121305E-17
     +,   7.5362308E-18,   3.4888940E-18,   1.6001713E-18
     +,   7.2748881E-19,   3.2820929E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt115 = Yx/0.130833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0803232E-05,   3.1506337E-05
     +,   3.2221626E-05,   3.2949985E-05,   3.3692420E-05
     +,   3.4450033E-05,   3.5224042E-05,   3.6015779E-05
     +,   3.6826703E-05,   3.7658432E-05,   3.8512699E-05
     +,   3.9391394E-05,   4.0296567E-05,   4.1230414E-05
     +,   4.2195348E-05,   4.3193922E-05,   4.4228880E-05
     +,   4.5303186E-05,   4.6419958E-05,   4.7582558E-05
     +,   4.8794511E-05,   5.0059582E-05,   5.1381689E-05
     +,   5.2765055E-05,   5.4213924E-05,   5.5732926E-05
     +,   5.7326721E-05,   5.9000184E-05,   6.0758321E-05
     +,   6.2606283E-05,   6.4549276E-05,   6.6592627E-05
     +,   6.8741603E-05,   7.1001574E-05,   7.3377778E-05
     +,   7.5875374E-05,   7.8499354E-05,   8.1254504E-05
     +,   8.4145453E-05,   8.7176224E-05,   9.0350717E-05
     +,   9.3672199E-05,   9.7143406E-05,   1.0076645E-04
     +,   1.0454277E-04,   1.0847297E-04,   1.1255682E-04
     +,   1.1679314E-04,   1.2117974E-04,   1.2571343E-04
     +,   1.3038973E-04,   1.3520312E-04,   1.4014664E-04
     +,   1.4521246E-04,   1.5039084E-04,   1.5567128E-04
     +,   1.6104167E-04,   1.6648869E-04,   1.7199769E-04
     +,   1.7755291E-04,   1.8313742E-04,   1.8873338E-04
     +,   1.9432169E-04,   1.9988297E-04,   2.0539731E-04
     +,   2.1084382E-04,   2.1620236E-04,   2.2145206E-04
     +,   2.2657345E-04,   2.3154684E-04,   2.3635471E-04
     +,   2.4098008E-04,   2.4540862E-04,   2.4962804E-04
     +,   2.5362891E-04,   2.5740537E-04,   2.6095472E-04
     +,   2.6427911E-04,   2.6738518E-04,   2.7028512E-04
     +,   2.7299643E-04,   2.7554331E-04,   2.7795599E-04
     +,   2.8027201E-04,   2.8253571E-04,   2.8479914E-04
     +,   2.8712105E-04,   2.8956763E-04,   2.9221174E-04
     +,   2.9513202E-04,   2.9841316E-04,   3.0214310E-04
     +,   3.0641301E-04,   3.1131553E-04,   3.1694243E-04
     +,   3.2338197E-04,   3.3071826E-04,   3.3902688E-04
     +,   3.4837369E-04,   3.5881097E-04,   3.7037686E-04
     +,   3.8309034E-04,   3.9695291E-04,   4.1194289E-04
     +,   4.2801854E-04,   4.4511587E-04,   4.6314835E-04
     +,   4.8200876E-04,   5.0157378E-04,   5.2170490E-04
     +,   5.4225151E-04,   5.6306098E-04,   5.8397971E-04
     +,   6.0486613E-04,   6.2559452E-04,   6.4606994E-04
     +,   6.6623499E-04,   6.8608479E-04,   7.0567557E-04
     +,   7.2514266E-04,   7.4470963E-04,   7.6469948E-04
     +,   7.8554580E-04,   8.0780167E-04,   8.3214114E-04
     +,   8.5935241E-04,   8.9033094E-04,   9.2604884E-04
     +,   9.6752594E-04,   1.0157686E-03,   1.0717147E-03
     +,   1.1361424E-03,   1.2095977E-03,   1.2922896E-03
     +,   1.3840240E-03,   1.4841284E-03,   1.5914027E-03
     +,   1.7041112E-03,   1.8200091E-03,   1.9363923E-03
     +,   2.0501751E-03,   2.1580225E-03,   2.2564977E-03
     +,   2.3422409E-03,   2.4121462E-03,   2.4636139E-03
     +,   2.4947736E-03,   2.5047222E-03,   2.4937396E-03
     +,   2.4634439E-03,   2.4168559E-03,   2.3583416E-03
     +,   2.2934291E-03,   2.2284677E-03,   2.1702296E-03
     +,   2.1254625E-03,   2.1004933E-03,   2.1009208E-03
     +,   2.1314686E-03,   2.1959231E-03,   2.2971372E-03
     +,   2.4369576E-03,   2.6160532E-03,   2.8336279E-03
     +,   3.0871520E-03,   3.3722417E-03,   3.6828064E-03
     +,   4.0115840E-03,   4.3508946E-03,   4.6933894E-03
     +,   5.0325561E-03,   5.3629926E-03,   5.6803632E-03
     +,   5.9811054E-03,   6.2621259E-03,   6.5205116E-03
     +,   6.7533562E-03,   6.9578043E-03,   7.1315784E-03
     +,   7.2738789E-03,   7.3866625E-03,   7.4759601E-03
     +,   7.5525399E-03,   7.6309266E-03,   7.7259964E-03
     +,   7.8471014E-03,   7.9916781E-03,   8.1418213E-03
     +,   8.2671074E-03,   8.3342781E-03,   8.3202021E-03
     +,   8.2216812E-03,   8.0569237E-03,   7.8578442E-03
     +,   7.6572709E-03,   7.4775345E-03,   7.3249205E-03
     +,   7.1907309E-03,   7.0567038E-03,   6.9015166E-03
     +,   6.7061372E-03,   6.4573972E-03,   6.1499807E-03
     +,   5.7870583E-03,   5.3795888E-03,   4.9440204E-03
     +,   4.4990228E-03,   4.0619303E-03,   3.6458548E-03
     +,   3.2582907E-03,   2.9014174E-03,   2.5736277E-03
     +,   2.2715048E-03,   1.9915977E-03,   1.7315763E-03
     +,   1.4906083E-03,   1.2690934E-03,   1.0680772E-03
     +,   8.8864332E-04,   7.3143397E-04,   5.9633510E-04
     +,   4.8243470E-04,   3.8812825E-04,   3.1130630E-04
     +,   2.4958310E-04,   2.0051966E-04,   1.6179828E-04
     +,   1.3133464E-04,   1.0733997E-04,   8.8341389E-05
     +,   7.3167510E-05,   6.0912058E-05,   5.0889867E-05
     +,   4.2593267E-05,   3.5651388E-05,   2.9793571E-05
     +,   2.4822217E-05,   2.0591306E-05,   1.6989998E-05
     +,   1.3931054E-05,   1.1343323E-05,   9.1666616E-06
     +,   7.3484211E-06,   5.8414334E-06,   4.6030814E-06
     +,   3.5947967E-06,   2.7816984E-06,   2.1324415E-06
     +,   1.6192358E-06,   1.2177687E-06,   9.0697421E-07
     +,   6.6889862E-07,   4.8846726E-07,   3.5318405E-07
     +,   2.5283271E-07,   1.7918912E-07,   1.2572713E-07
     +,   8.7333760E-08,   6.0056401E-08,   4.0883826E-08
     +,   2.7552550E-08,   1.8382131E-08,   1.2140845E-08
     +,   7.9381035E-09,   5.1382445E-09,   3.2926106E-09
     +,   2.0887736E-09,   1.3118329E-09,   8.1566720E-10
     +,   5.0210575E-10,   3.0600084E-10,   1.8463296E-10
     +,   1.1029863E-10,   6.5238995E-11,   3.8205449E-11
     +,   2.2154164E-11,   1.2720517E-11,   7.2330705E-12
     +,   4.0732890E-12,   2.2723112E-12,   1.2560339E-12
     +,   6.8828293E-13,   3.7417609E-13,   2.0205951E-13
     +,   1.0859805E-13,   5.8278557E-14,   3.1384468E-14
     +,   1.7090084E-14,   9.5132108E-15,   5.4885376E-15
     +,   3.3307822E-15,   2.1503918E-15,   1.4821417E-15
     +,   1.0842591E-15,   8.3178080E-16,   6.6008245E-16
     +,   5.3558317E-16,   4.4051359E-16,   3.6519111E-16
     +,   3.0405833E-16,   2.5371535E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt120 = Yx/0.097475
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5656844E-04,   1.6764816E-04
     +,   1.7973028E-04,   1.9293853E-04,   2.0740938E-04
     +,   2.2330126E-04,   2.4081315E-04,   2.6022003E-04
     +,   2.8192910E-04,   3.0656654E-04,   3.3509344E-04
     +,   3.6895651E-04,   4.1026124E-04,   4.6194866E-04
     +,   5.2794063E-04,   6.1320886E-04,   7.2371523E-04
     +,   8.6620450E-04,   1.0478885E-03,   1.2761686E-03
     +,   1.5586149E-03,   1.9033636E-03,   2.3197855E-03
     +,   2.8189262E-03,   3.4129503E-03,   4.1143303E-03
     +,   4.9370215E-03,   5.9042051E-03,   7.0635462E-03
     +,   8.5014571E-03,   1.0336506E-02,   1.2676171E-02
     +,   1.5552477E-02,   1.8890729E-02,   2.2555770E-02
     +,   2.6432378E-02,   3.0420544E-02,   3.4314800E-02
     +,   3.7748642E-02,   4.0385585E-02,   4.2201377E-02
     +,   4.3483321E-02,   4.4494260E-02,   4.5155138E-02
     +,   4.5040783E-02,   4.3673955E-02,   4.0921528E-02
     +,   3.7193105E-02,   3.3216882E-02,   2.9570622E-02
     +,   2.6429534E-02,   2.3699872E-02,   2.1268696E-02
     +,   1.9094294E-02,   1.7151825E-02,   1.5387850E-02
     +,   1.3744966E-02,   1.2202051E-02,   1.0778827E-02
     +,   9.5103486E-03,   8.4224064E-03,   7.5220456E-03
     +,   6.7986590E-03,   6.2282672E-03,   5.7786405E-03
     +,   5.4148794E-03,   5.1046233E-03,   4.8220116E-03
     +,   4.5494414E-03,   4.2774957E-03,   4.0034521E-03
     +,   3.7293173E-03,   3.4596301E-03,   3.1997506E-03
     +,   2.9545252E-03,   2.7275856E-03,   2.5211044E-03
     +,   2.3358385E-03,   2.1713858E-03,   2.0265351E-03
     +,   1.8995850E-03,   1.7885872E-03,   1.6915596E-03
     +,   1.6065857E-03,   1.5319021E-03,   1.4659085E-03
     +,   1.4071974E-03,   1.3545303E-03,   1.3068446E-03
     +,   1.2632329E-03,   1.2229386E-03,   1.1853481E-03
     +,   1.1499791E-03,   1.1164633E-03,   1.0845372E-03
     +,   1.0540317E-03,   1.0248465E-03,   9.9694368E-04
     +,   9.7032479E-04,   9.4501872E-04,   9.2106889E-04
     +,   8.9851976E-04,   8.7740866E-04,   8.5776049E-04
     +,   8.3957904E-04,   8.2284916E-04,   8.0753554E-04
     +,   7.9358486E-04,   7.8092678E-04,   7.6947949E-04
     +,   7.5915607E-04,   7.4986514E-04,   7.4151915E-04
     +,   7.3403725E-04,   7.2734751E-04,   7.2139158E-04
     +,   7.1612466E-04,   7.1151613E-04,   7.0755027E-04
     +,   7.0422346E-04,   7.0154294E-04,   6.9952320E-04
     +,   6.9818355E-04,   6.9754379E-04,   6.9762015E-04
     +,   6.9842185E-04,   6.9994817E-04,   7.0218381E-04
     +,   7.0509786E-04,   7.0863997E-04,   7.1274198E-04
     +,   7.1731390E-04,   7.2224799E-04,   7.2741701E-04
     +,   7.3267816E-04,   7.3787535E-04,   7.4284180E-04
     +,   7.4740604E-04,   7.5139332E-04,   7.5463421E-04
     +,   7.5696473E-04,   7.5823453E-04,   7.5830868E-04
     +,   7.5707375E-04,   7.5443927E-04,   7.5034139E-04
     +,   7.4474380E-04,   7.3763926E-04,   7.2905084E-04
     +,   7.1902864E-04,   7.0765050E-04,   6.9501874E-04
     +,   6.8125763E-04,   6.6650967E-04,   6.5093092E-04
     +,   6.3468865E-04,   6.1795645E-04,   6.0090929E-04
     +,   5.8371894E-04,   5.6655431E-04,   5.4957229E-04
     +,   5.3291919E-04,   5.1672716E-04,   5.0111301E-04
     +,   4.8617538E-04,   4.7199501E-04,   4.5863635E-04
     +,   4.4614577E-04,   4.3455276E-04,   4.2387089E-04
     +,   4.1410077E-04,   4.0522989E-04,   3.9723408E-04
     +,   3.9008044E-04,   3.8372847E-04,   3.7813120E-04
     +,   3.7323692E-04,   3.6899056E-04,   3.6533523E-04
     +,   3.6221213E-04,   3.5956214E-04,   3.5732621E-04
     +,   3.5544625E-04,   3.5386486E-04,   3.5252568E-04
     +,   3.5137427E-04,   3.5035730E-04,   3.4942332E-04
     +,   3.4852224E-04,   3.4760608E-04,   3.4662828E-04
     +,   3.4554410E-04,   3.4431118E-04,   3.4288914E-04
     +,   3.4123950E-04,   3.3932680E-04,   3.3711840E-04
     +,   3.3458453E-04,   3.3169860E-04,   3.2843772E-04
     +,   3.2478312E-04,   3.2072002E-04,   3.1623762E-04
     +,   3.1132984E-04,   3.0599532E-04,   3.0023698E-04
     +,   2.9406260E-04,   2.8748455E-04,   2.8051969E-04
     +,   2.7318890E-04,   2.6551663E-04,   2.5753165E-04
     +,   2.4926587E-04,   2.4075348E-04,   2.3203097E-04
     +,   2.2313706E-04,   2.1411190E-04,   2.0499570E-04
     +,   1.9582896E-04,   1.8665272E-04,   1.7750634E-04
     +,   1.6842793E-04,   1.5945456E-04,   1.5062114E-04
     +,   1.4195971E-04,   1.3349959E-04,   1.2526776E-04
     +,   1.1728817E-04,   1.0958110E-04,   1.0216357E-04
     +,   9.5049894E-05,   8.8251269E-05,   8.1775244E-05
     +,   7.5626551E-05,   6.9807691E-05,   6.4317945E-05
     +,   5.9154332E-05,   5.4312026E-05,   4.9784241E-05
     +,   4.5562258E-05,   4.1635936E-05,   3.7994290E-05
     +,   3.4625282E-05,   3.1515985E-05,   2.8652965E-05
     +,   2.6022672E-05,   2.3611386E-05,   2.1405227E-05
     +,   1.9390513E-05,   1.7554012E-05,   1.5882664E-05
     +,   1.4363893E-05,   1.2985745E-05,   1.1736824E-05
     +,   1.0606247E-05,   9.5837877E-06,   8.6599312E-06
     +,   7.8257854E-06,   7.0730534E-06,   6.3940633E-06
     +,   5.7818024E-06,   5.2298246E-06,   4.7322019E-06
     +,   4.2835331E-06,   3.8789531E-06,   3.5140138E-06
     +,   3.1846907E-06,   2.8873785E-06,   2.6188284E-06
     +,   2.3761045E-06,   2.1565709E-06,   1.9578833E-06
     +,   1.7779413E-06,   1.6148540E-06,   1.4669328E-06
     +,   1.3326829E-06,   1.2107537E-06,   1.0999503E-06
     +,   9.9919475E-07,   9.0753372E-07,   8.2410344E-07
     +,   7.4814062E-07,   6.7895121E-07,   6.1592095E-07
     +,   5.5848892E-07,   5.0615859E-07,   4.5847548E-07
     +,   4.1503046E-07,   3.7545621E-07,   3.3941518E-07
     +,   3.0660510E-07,   2.7674676E-07,   2.4958976E-07
     +,   2.2490163E-07,   2.0247346E-07,   1.8211094E-07
     +,   1.6363867E-07,   1.4689340E-07,   1.3172763E-07
     +,   1.1800368E-07,   1.0559702E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt60 = Yx/0.246978260869565
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9279759E-05,   4.2433439E-05
     +,   4.5943725E-05,   4.9849714E-05,   5.4193315E-05
     +,   5.9019174E-05,   6.4374326E-05,   7.0308059E-05
     +,   7.6871263E-05,   8.4116567E-05,   9.2097151E-05
     +,   1.0086669E-04,   1.1047882E-04,   1.2098692E-04
     +,   1.3244362E-04,   1.4490115E-04,   1.5841144E-04
     +,   1.7302691E-04,   1.8880145E-04,   2.0579173E-04
     +,   2.2405935E-04,   2.4367281E-04,   2.6470976E-04
     +,   2.8726185E-04,   3.1143392E-04,   3.3735353E-04
     +,   3.6517213E-04,   3.9507510E-04,   4.2729368E-04
     +,   4.6212273E-04,   4.9995078E-04,   5.4130296E-04
     +,   5.8690720E-04,   6.3778646E-04,   6.9538632E-04
     +,   7.6173549E-04,   8.3962484E-04,   9.3278306E-04
     +,   1.0460470E-03,   1.1855245E-03,   1.3589853E-03
     +,   1.5766418E-03,   1.8526001E-03,   2.2067600E-03
     +,   2.6662794E-03,   3.2653667E-03,   4.0426399E-03
     +,   5.0365524E-03,   6.2798350E-03,   7.7921003E-03
     +,   9.5693655E-03,   1.1575838E-02,   1.3758489E-02
     +,   1.6111344E-02,   1.8772874E-02,   2.2057574E-02
     +,   2.6307156E-02,   3.1598963E-02,   3.7554648E-02
     +,   4.3529369E-02,   4.9050968E-02,   5.3907488E-02
     +,   5.7815343E-02,   6.0435925E-02,   6.1713297E-02
     +,   6.1604194E-02,   5.9727598E-02,   5.5973139E-02
     +,   5.0929084E-02,   4.5411661E-02,   4.0106993E-02
     +,   3.5402901E-02,   3.1342164E-02,   2.7856886E-02
     +,   2.4840409E-02,   2.2130027E-02,   1.9654155E-02
     +,   1.7462639E-02,   1.5578030E-02,   1.3934528E-02
     +,   1.2448958E-02,   1.1079936E-02,   9.8239873E-03
     +,   8.6894631E-03,   7.6831873E-03,   6.8083280E-03
     +,   6.0654418E-03,   5.4511866E-03,   4.9565891E-03
     +,   4.5664208E-03,   4.2610401E-03,   4.0194634E-03
     +,   3.8221995E-03,   3.6530169E-03,   3.4997072E-03
     +,   3.3540081E-03,   3.2111169E-03,   3.0690234E-03
     +,   2.9276786E-03,   2.7882683E-03,   2.6524861E-03
     +,   2.5220646E-03,   2.3984329E-03,   2.2826097E-03
     +,   2.1751798E-03,   2.0763837E-03,   1.9862284E-03
     +,   1.9045726E-03,   1.8311840E-03,   1.7657705E-03
     +,   1.7079926E-03,   1.6574298E-03,   1.6135813E-03
     +,   1.5758422E-03,   1.5435211E-03,   1.5158512E-03
     +,   1.4920279E-03,   1.4712415E-03,   1.4527304E-03
     +,   1.4358091E-03,   1.4198987E-03,   1.4045422E-03
     +,   1.3894009E-03,   1.3742407E-03,   1.3589073E-03
     +,   1.3432957E-03,   1.3273129E-03,   1.3108542E-03
     +,   1.2937754E-03,   1.2758853E-03,   1.2569426E-03
     +,   1.2366704E-03,   1.2147716E-03,   1.1909638E-03
     +,   1.1650015E-03,   1.1367087E-03,   1.1060045E-03
     +,   1.0729198E-03,   1.0376030E-03,   1.0003167E-03
     +,   9.6143346E-04,   9.2140987E-04,   8.8076096E-04
     +,   8.4003247E-04,   7.9977332E-04,   7.6050160E-04
     +,   7.2268141E-04,   6.8670715E-04,   6.5288797E-04
     +,   6.2143715E-04,   5.9247582E-04,   5.6603923E-04
     +,   5.4208323E-04,   5.2049651E-04,   5.0111668E-04
     +,   4.8374585E-04,   4.6816442E-04,   4.5414327E-04
     +,   4.4145610E-04,   4.2989047E-04,   4.1925217E-04
     +,   4.0937049E-04,   4.0010258E-04,   3.9133246E-04
     +,   3.8297070E-04,   3.7495253E-04,   3.6723676E-04
     +,   3.5980114E-04,   3.5263909E-04,   3.4575610E-04
     +,   3.3916795E-04,   3.3289642E-04,   3.2696591E-04
     +,   3.2140160E-04,   3.1622799E-04,   3.1146556E-04
     +,   3.0713013E-04,   3.0323202E-04,   2.9977478E-04
     +,   2.9675430E-04,   2.9415949E-04,   2.9197175E-04
     +,   2.9016519E-04,   2.8870709E-04,   2.8755845E-04
     +,   2.8667485E-04,   2.8600724E-04,   2.8550258E-04
     +,   2.8510502E-04,   2.8475723E-04,   2.8440074E-04
     +,   2.8397772E-04,   2.8343109E-04,   2.8270652E-04
     +,   2.8175244E-04,   2.8052137E-04,   2.7897034E-04
     +,   2.7706180E-04,   2.7476385E-04,   2.7205062E-04
     +,   2.6890289E-04,   2.6530799E-04,   2.6125976E-04
     +,   2.5675833E-04,   2.5181079E-04,   2.4642955E-04
     +,   2.4063278E-04,   2.3444410E-04,   2.2789178E-04
     +,   2.2100782E-04,   2.1382740E-04,   2.0638897E-04
     +,   1.9873315E-04,   1.9090144E-04,   1.8293604E-04
     +,   1.7487977E-04,   1.6677512E-04,   1.5866291E-04
     +,   1.5058269E-04,   1.4257261E-04,   1.3466783E-04
     +,   1.2690097E-04,   1.1930215E-04,   1.1189856E-04
     +,   1.0471365E-04,   9.7767625E-05,   9.1077978E-05
     +,   8.4658932E-05,   7.8521109E-05,   7.2672257E-05
     +,   6.7117566E-05,   6.1859639E-05,   5.6898181E-05
     +,   5.2230760E-05,   4.7853391E-05,   4.3759839E-05
     +,   3.9942417E-05,   3.6392383E-05,   3.3099892E-05
     +,   3.0054036E-05,   2.7243297E-05,   2.4655883E-05
     +,   2.2279684E-05,   2.0102309E-05,   1.8111388E-05
     +,   1.6294833E-05,   1.4640755E-05,   1.3137480E-05
     +,   1.1773748E-05,   1.0538883E-05,   9.4225643E-06
     +,   8.4150142E-06,   7.5070716E-06,   6.6901189E-06
     +,   5.9560448E-06,   5.2973014E-06,   4.7069320E-06
     +,   4.1784970E-06,   3.7060297E-06,   3.2840560E-06
     +,   2.9075904E-06,   2.5720751E-06,   2.2733379E-06
     +,   2.0075895E-06,   1.7714182E-06,   1.5617121E-06
     +,   1.3756620E-06,   1.2107474E-06,   1.0646959E-06
     +,   9.3545435E-07,   8.2118180E-07,   7.2023357E-07
     +,   6.3113458E-07,   5.5255947E-07,   4.8332362E-07
     +,   4.2237511E-07,   3.6876682E-07,   3.2166110E-07
     +,   2.8030527E-07,   2.4403423E-07,   2.1225144E-07
     +,   1.8443082E-07,   1.6010088E-07,   1.3884672E-07
     +,   1.2029707E-07,   1.0412569E-07,   9.0041695E-08
     +,   7.7788151E-08,   6.7139084E-08,   5.7893462E-08
     +,   4.9875307E-08,   4.2928477E-08,   3.6916475E-08
     +,   3.1718567E-08,   2.7229387E-08,   2.3355950E-08
     +,   2.0017367E-08,   1.7142389E-08,   1.4669191E-08
     +,   1.2543460E-08,   1.0718173E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt65 = Yx/0.301291666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3840184E-05,   3.5250865E-05
     +,   3.6737147E-05,   3.8301554E-05,   3.9946346E-05
     +,   4.1673520E-05,   4.3484713E-05,   4.5381224E-05
     +,   4.7363861E-05,   4.9433133E-05,   5.1588846E-05
     +,   5.3830398E-05,   5.6156561E-05,   5.8565540E-05
     +,   6.1054925E-05,   6.3621679E-05,   6.6262233E-05
     +,   6.8972389E-05,   7.1747549E-05,   7.4582655E-05
     +,   7.7472483E-05,   8.0411723E-05,   8.3395294E-05
     +,   8.6418957E-05,   8.9479203E-05,   9.2574621E-05
     +,   9.5706157E-05,   9.8878256E-05,   1.0210021E-04
     +,   1.0538742E-04,   1.0876326E-04,   1.1226095E-04
     +,   1.1592587E-04,   1.1981800E-04,   1.2401456E-04
     +,   1.2861280E-04,   1.3373280E-04,   1.3952050E-04
     +,   1.4615123E-04,   1.5383166E-04,   1.6280520E-04
     +,   1.7335481E-04,   1.8580916E-04,   2.0054955E-04
     +,   2.1801905E-04,   2.3873469E-04,   2.6330218E-04
     +,   2.9243436E-04,   3.2697141E-04,   3.6790301E-04
     +,   4.1639010E-04,   4.7378259E-04,   5.4163311E-04
     +,   6.2170369E-04,   7.1594218E-04,   8.2646089E-04
     +,   9.5544470E-04,   1.1050265E-03,   1.2771032E-03
     +,   1.4731570E-03,   1.6942570E-03,   1.9415573E-03
     +,   2.2177368E-03,   2.5297333E-03,   2.8922465E-03
     +,   3.3304119E-03,   3.8795467E-03,   4.5813886E-03
     +,   5.4819328E-03,   6.6366754E-03,   8.1196483E-03
     +,   1.0012385E-02,   1.2359826E-02,   1.5135225E-02
     +,   1.8304544E-02,   2.2003571E-02,   2.6650248E-02
     +,   3.2689471E-02,   4.0029801E-02,   4.7927339E-02
     +,   5.5614449E-02,   6.2705189E-02,   6.8694226E-02
     +,   7.2360009E-02,   7.3059440E-02,   7.2687626E-02
     +,   7.3369369E-02,   7.3807761E-02,   7.1073107E-02
     +,   6.4663410E-02,   5.6827776E-02,   4.9780920E-02
     +,   4.4065125E-02,   3.9157312E-02,   3.4603901E-02
     +,   3.0423362E-02,   2.6847918E-02,   2.3996130E-02
     +,   2.1716647E-02,   1.9720545E-02,   1.7822707E-02
     +,   1.6001943E-02,   1.4306712E-02,   1.2780459E-02
     +,   1.1445107E-02,   1.0303999E-02,   9.3456544E-03
     +,   8.5488884E-03,   7.8879716E-03,   7.3360745E-03
     +,   6.8681207E-03,   6.4637391E-03,   6.1088442E-03
     +,   5.7943594E-03,   5.5136262E-03,   5.2601090E-03
     +,   5.0271279E-03,   4.8087253E-03,   4.6008690E-03
     +,   4.4019008E-03,   4.2120903E-03,   4.0326170E-03
     +,   3.8644779E-03,   3.7077307E-03,   3.5612585E-03
     +,   3.4230037E-03,   3.2903985E-03,   3.1609645E-03
     +,   3.0327197E-03,   2.9045159E-03,   2.7760775E-03
     +,   2.6479412E-03,   2.5212185E-03,   2.3973486E-03
     +,   2.2778064E-03,   2.1638861E-03,   2.0565595E-03
     +,   1.9563930E-03,   1.8635215E-03,   1.7777206E-03
     +,   1.6984730E-03,   1.6250721E-03,   1.5567128E-03
     +,   1.4925853E-03,   1.4319649E-03,   1.3742489E-03
     +,   1.3190062E-03,   1.2659940E-03,   1.2151488E-03
     +,   1.1665631E-03,   1.1204553E-03,   1.0771257E-03
     +,   1.0369094E-03,   1.0001239E-03,   9.6703111E-04
     +,   9.3780644E-04,   9.1250992E-04,   8.9107308E-04
     +,   8.7330106E-04,   8.5888017E-04,   8.4739033E-04
     +,   8.3833048E-04,   8.3114544E-04,   8.2525145E-04
     +,   8.2006573E-04,   8.1503036E-04,   8.0963789E-04
     +,   8.0344698E-04,   7.9609698E-04,   7.8731694E-04
     +,   7.7693048E-04,   7.6485373E-04,   7.5109029E-04
     +,   7.3572469E-04,   7.1891100E-04,   7.0085918E-04
     +,   6.8182143E-04,   6.6207931E-04,   6.4192881E-04
     +,   6.2166550E-04,   6.0157303E-04,   5.8191561E-04
     +,   5.6292641E-04,   5.4480159E-04,   5.2769581E-04
     +,   5.1172206E-04,   4.9694948E-04,   4.8340260E-04
     +,   4.7106727E-04,   4.5989346E-04,   4.4979871E-04
     +,   4.4067416E-04,   4.3239101E-04,   4.2480594E-04
     +,   4.1776494E-04,   4.1111125E-04,   4.0468937E-04
     +,   3.9834972E-04,   3.9195211E-04,   3.8536947E-04
     +,   3.7849063E-04,   3.7122201E-04,   3.6348897E-04
     +,   3.5523606E-04,   3.4642851E-04,   3.3705006E-04
     +,   3.2710287E-04,   3.1660651E-04,   3.0559633E-04
     +,   2.9412025E-04,   2.8223798E-04,   2.7001862E-04
     +,   2.5753843E-04,   2.4487771E-04,   2.3211872E-04
     +,   2.1934537E-04,   2.0663957E-04,   1.9407949E-04
     +,   1.8173826E-04,   1.6968431E-04,   1.5797805E-04
     +,   1.4667207E-04,   1.3581172E-04,   1.2543378E-04
     +,   1.1556624E-04,   1.0622884E-04,   9.7434262E-05
     +,   8.9187954E-05,   8.1488091E-05,   7.4327087E-05
     +,   6.7692708E-05,   6.1568309E-05,   5.5933189E-05
     +,   5.0764014E-05,   4.6035824E-05,   4.1721796E-05
     +,   3.7794322E-05,   3.4225890E-05,   3.0989104E-05
     +,   2.8057029E-05,   2.5403668E-05,   2.3004435E-05
     +,   2.0836060E-05,   1.8876648E-05,   1.7105904E-05
     +,   1.5505253E-05,   1.4057706E-05,   1.2747721E-05
     +,   1.1561269E-05,   1.0485849E-05,   9.5101514E-06
     +,   8.6240861E-06,   7.8187431E-06,   7.0861884E-06
     +,   6.4193423E-06,   5.8119308E-06,   5.2584210E-06
     +,   4.7539011E-06,   4.2939591E-06,   3.8746675E-06
     +,   3.4925320E-06,   3.1444122E-06,   2.8274492E-06
     +,   2.5390580E-06,   2.2769116E-06,   2.0388584E-06
     +,   1.8229274E-06,   1.6273187E-06,   1.4503703E-06
     +,   1.2905336E-06,   1.1463750E-06,   1.0165742E-06
     +,   8.9990397E-07,   7.9521777E-07,   7.0145182E-07
     +,   6.1762830E-07,   5.4283021E-07,   4.7621825E-07
     +,   4.1700841E-07,   3.6448517E-07,   3.1798334E-07
     +,   2.7689742E-07,   2.4066767E-07,   2.0878662E-07
     +,   1.8078747E-07,   1.5624919E-07,   1.3478707E-07
     +,   1.1605314E-07,   9.9735026E-08,   8.5549331E-08
     +,   7.3243214E-08,   6.2588725E-08,   5.3383562E-08
     +,   4.5446196E-08,   3.8616317E-08,   3.2750929E-08
     +,   2.7724308E-08,   2.3424944E-08,   1.9755227E-08
     +,   1.6629034E-08,   1.3971372E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt70 = Yx/0.374
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2088577E-05,   1.2731565E-05
     +,   1.3398187E-05,   1.4088630E-05,   1.4803055E-05
     +,   1.5541624E-05,   1.6304492E-05,   1.7091808E-05
     +,   1.7903738E-05,   1.8740493E-05,   1.9602290E-05
     +,   2.0489391E-05,   2.1402133E-05,   2.2340895E-05
     +,   2.3306167E-05,   2.4298495E-05,   2.5318555E-05
     +,   2.6367126E-05,   2.7445118E-05,   2.8553570E-05
     +,   2.9693683E-05,   3.0866799E-05,   3.2074422E-05
     +,   3.3318323E-05,   3.4600296E-05,   3.5922516E-05
     +,   3.7287300E-05,   3.8697250E-05,   4.0155250E-05
     +,   4.1664516E-05,   4.3228654E-05,   4.4851724E-05
     +,   4.6538327E-05,   4.8293710E-05,   5.0123868E-05
     +,   5.2035743E-05,   5.4037337E-05,   5.6137935E-05
     +,   5.8348498E-05,   6.0681552E-05,   6.3151980E-05
     +,   6.5776941E-05,   6.8576563E-05,   7.1574163E-05
     +,   7.4796793E-05,   7.8275807E-05,   8.2047220E-05
     +,   8.6152475E-05,   9.0638954E-05,   9.5560703E-05
     +,   1.0097902E-04,   1.0696325E-04,   1.1359128E-04
     +,   1.2095092E-04,   1.2913940E-04,   1.3826572E-04
     +,   1.4845007E-04,   1.5982529E-04,   1.7253777E-04
     +,   1.8674825E-04,   2.0263292E-04,   2.2038518E-04
     +,   2.4021577E-04,   2.6235796E-04,   2.8706936E-04
     +,   3.1463424E-04,   3.4537734E-04,   3.7966814E-04
     +,   4.1794652E-04,   4.6074012E-04,   5.0870999E-04
     +,   5.6268688E-04,   6.2374450E-04,   6.9325423E-04
     +,   7.7297492E-04,   8.6512783E-04,   9.7246893E-04
     +,   1.0983795E-03,   1.2469859E-03,   1.4233168E-03
     +,   1.6335088E-03,   1.8851076E-03,   2.1871233E-03
     +,   2.5497423E-03,   2.9829075E-03,   3.4937442E-03
     +,   4.0829391E-03,   4.7433185E-03,   5.4659559E-03
     +,   6.2620933E-03,   7.2025182E-03,   8.4573012E-03
     +,   1.0292850E-02,   1.2992069E-02,   1.6732529E-02
     +,   2.1507464E-02,   2.7167091E-02,   3.3668701E-02
     +,   4.1305289E-02,   5.0247453E-02,   6.0236599E-02
     +,   7.1483806E-02,   8.3769843E-02,   9.4411768E-02
     +,   9.8996557E-02,   9.7523555E-02,   9.5583655E-02
     +,   9.4474204E-02,   9.2021905E-02,   8.4997550E-02
     +,   7.5302668E-02,   6.8199746E-02,   6.2950574E-02
     +,   5.6055356E-02,   4.7724824E-02,   3.9916117E-02
     +,   3.3655815E-02,   2.9025797E-02,   2.5649458E-02
     +,   2.3040665E-02,   2.0734094E-02,   1.8512663E-02
     +,   1.6477998E-02,   1.4807289E-02,   1.3540791E-02
     +,   1.2585785E-02,   1.1820839E-02,   1.1165271E-02
     +,   1.0579129E-02,   1.0030982E-02,   9.4794417E-03
     +,   8.8848015E-03,   8.2317842E-03,   7.5394930E-03
     +,   6.8502519E-03,   6.2085046E-03,   5.6441952E-03
     +,   5.1675336E-03,   4.7731809E-03,   4.4478229E-03
     +,   4.1763396E-03,   3.9449208E-03,   3.7419791E-03
     +,   3.5581084E-03,   3.3859697E-03,   3.2202660E-03
     +,   3.0578354E-03,   2.8975543E-03,   2.7400013E-03
     +,   2.5868898E-03,   2.4404749E-03,   2.3029784E-03
     +,   2.1761607E-03,   2.0610732E-03,   1.9580144E-03
     +,   1.8666100E-03,   1.7859353E-03,   1.7146894E-03
     +,   1.6513602E-03,   1.5943666E-03,   1.5421596E-03
     +,   1.4933185E-03,   1.4466150E-03,   1.4010544E-03
     +,   1.3558939E-03,   1.3106536E-03,   1.2650933E-03
     +,   1.2191862E-03,   1.1730668E-03,   1.1269825E-03
     +,   1.0812483E-03,   1.0361975E-03,   9.9214062E-04
     +,   9.4934425E-04,   9.0801751E-04,   8.6830120E-04
     +,   8.3027460E-04,   7.9396635E-04,   7.5936574E-04
     +,   7.2643388E-04,   6.9511798E-04,   6.6536409E-04
     +,   6.3712097E-04,   6.1034330E-04,   5.8499374E-04
     +,   5.6104321E-04,   5.3846592E-04,   5.1723351E-04
     +,   4.9731287E-04,   4.7866395E-04,   4.6123273E-04
     +,   4.4495173E-04,   4.2974064E-04,   4.1550584E-04
     +,   4.0214098E-04,   3.8953181E-04,   3.7755992E-04
     +,   3.6610494E-04,   3.5504898E-04,   3.4428021E-04
     +,   3.3369684E-04,   3.2320945E-04,   3.1274208E-04
     +,   3.0223475E-04,   2.9164442E-04,   2.8094370E-04
     +,   2.7012083E-04,   2.5917921E-04,   2.4813550E-04
     +,   2.3701657E-04,   2.2585878E-04,   2.1470585E-04
     +,   2.0360645E-04,   1.9261113E-04,   1.8177101E-04
     +,   1.7113707E-04,   1.6075745E-04,   1.5067584E-04
     +,   1.4093108E-04,   1.3155716E-04,   1.2258123E-04
     +,   1.1402411E-04,   1.0590092E-04,   9.8220626E-05
     +,   9.0985995E-05,   8.4194595E-05,   7.7839781E-05
     +,   7.1910814E-05,   6.6393237E-05,   6.1269937E-05
     +,   5.6522098E-05,   5.2129424E-05,   4.8070455E-05
     +,   4.4323377E-05,   4.0866842E-05,   3.7679481E-05
     +,   3.4740686E-05,   3.2030985E-05,   2.9531935E-05
     +,   2.7226131E-05,   2.5097443E-05,   2.3131153E-05
     +,   2.1313772E-05,   1.9632893E-05,   1.8077282E-05
     +,   1.6636879E-05,   1.5302599E-05,   1.4066150E-05
     +,   1.2920093E-05,   1.1857795E-05,   1.0873161E-05
     +,   9.9606732E-06,   9.1153715E-06,   8.3327095E-06
     +,   7.6084666E-06,   6.9387670E-06,   6.3200519E-06
     +,   5.7490133E-06,   5.2225237E-06,   4.7376566E-06
     +,   4.2916886E-06,   3.8820567E-06,   3.5063038E-06
     +,   3.1621173E-06,   2.8473376E-06,   2.5598872E-06
     +,   2.2978004E-06,   2.0592388E-06,   1.8424558E-06
     +,   1.6457902E-06,   1.4676763E-06,   1.3066502E-06
     +,   1.1613348E-06,   1.0304266E-06,   9.1270596E-07
     +,   8.0704456E-07,   7.1237451E-07,   6.2771511E-07
     +,   5.5214400E-07,   4.8481627E-07,   4.2494167E-07
     +,   3.7179976E-07,   3.2472033E-07,   2.8309393E-07
     +,   2.4635744E-07,   2.1400113E-07,   1.8555670E-07
     +,   1.6059896E-07,   1.3874468E-07,   1.1964394E-07
     +,   1.0298359E-07,   8.8479339E-08,   7.5877807E-08
     +,   6.4950157E-08,   5.5493402E-08,   4.7325109E-08
     +,   4.0284196E-08,   3.4226613E-08,   2.9025715E-08
     +,   2.4568903E-08,   2.0757540E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt75 = Yx/0.4466
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.2328710E-06,   9.3763574E-06
     +,   9.5198848E-06,   9.6639315E-06,   9.8090404E-06
     +,   9.9558238E-06,   1.0104961E-05,   1.0257209E-05
     +,   1.0413399E-05,   1.0574443E-05,   1.0741333E-05
     +,   1.0915139E-05,   1.1097014E-05,   1.1288203E-05
     +,   1.1490023E-05,   1.1703889E-05,   1.1931294E-05
     +,   1.2173815E-05,   1.2433124E-05,   1.2710967E-05
     +,   1.3009188E-05,   1.3329714E-05,   1.3674561E-05
     +,   1.4045856E-05,   1.4445795E-05,   1.4876731E-05
     +,   1.5341107E-05,   1.5841531E-05,   1.6380754E-05
     +,   1.6961747E-05,   1.7587699E-05,   1.8262099E-05
     +,   1.8988760E-05,   1.9771918E-05,   2.0616300E-05
     +,   2.1527236E-05,   2.2510751E-05,   2.3573706E-05
     +,   2.4723982E-05,   2.5970490E-05,   2.7323536E-05
     +,   2.8794828E-05,   3.0397701E-05,   3.2147269E-05
     +,   3.4060547E-05,   3.6156591E-05,   3.8456496E-05
     +,   4.0983483E-05,   4.3762739E-05,   4.6821355E-05
     +,   5.0187977E-05,   5.3892476E-05,   5.7965415E-05
     +,   6.2437692E-05,   6.7339031E-05,   7.2698196E-05
     +,   7.8541030E-05,   8.4889951E-05,   9.1762595E-05
     +,   9.9170844E-05,   1.0711971E-04,   1.1560652E-04
     +,   1.2461946E-04,   1.3413839E-04,   1.4413390E-04
     +,   1.5456660E-04,   1.6538987E-04,   1.7654848E-04
     +,   1.8798267E-04,   1.9962757E-04,   2.1141861E-04
     +,   2.2329119E-04,   2.3518737E-04,   2.4705590E-04
     +,   2.5885884E-04,   2.7057371E-04,   2.8219720E-04
     +,   2.9374904E-04,   3.0527700E-04,   3.1686033E-04
     +,   3.2861324E-04,   3.4069372E-04,   3.5330807E-04
     +,   3.6672392E-04,   3.8128090E-04,   3.9741254E-04
     +,   4.1566469E-04,   4.3672737E-04,   4.6145907E-04
     +,   4.9091893E-04,   5.2638270E-04,   5.6934083E-04
     +,   6.2147138E-04,   6.8457919E-04,   7.6049939E-04
     +,   8.5097417E-04,   9.5758319E-04,   1.0817135E-03
     +,   1.2247484E-03,   1.3884444E-03,   1.5757339E-03
     +,   1.7918705E-03,   2.0461353E-03,   2.3537716E-03
     +,   2.7378178E-03,   3.2293980E-03,   3.8647947E-03
     +,   4.6785907E-03,   5.6968168E-03,   6.9407984E-03
     +,   8.4493598E-03,   1.0300978E-02,   1.2587468E-02
     +,   1.5327707E-02,   1.8403590E-02,   2.1669790E-02
     +,   2.5366148E-02,   3.0675845E-02,   3.9334811E-02
     +,   5.1384088E-02,   6.3885197E-02,   7.4856944E-02
     +,   8.7683000E-02,   0.1035035    ,   0.1190513    
     +,   0.1292702    ,   0.1319872    ,   0.1298943    
     +,   0.1224588    ,   0.1130409    ,   9.8295376E-02
     +,   8.1645921E-02,   7.1573287E-02,   6.3711412E-02
     +,   5.5433765E-02,   4.7061615E-02,   3.8614050E-02
     +,   3.1438630E-02,   2.6370009E-02,   2.2981593E-02
     +,   2.0658892E-02,   1.8987324E-02,   1.7630614E-02
     +,   1.6334957E-02,   1.4992224E-02,   1.3621946E-02
     +,   1.2300520E-02,   1.1099134E-02,   1.0051208E-02
     +,   9.1469474E-03,   8.3485181E-03,   7.6149674E-03
     +,   6.9218529E-03,   6.2663234E-03,   5.6600589E-03
     +,   5.1186024E-03,   4.6537942E-03,   4.2704977E-03
     +,   3.9664363E-03,   3.7334249E-03,   3.5592988E-03
     +,   3.4302482E-03,   3.3328617E-03,   3.2555007E-03
     +,   3.1888613E-03,   3.1259253E-03,   3.0616105E-03
     +,   2.9923795E-03,   2.9159654E-03,   2.8311794E-03
     +,   2.7377817E-03,   2.6362948E-03,   2.5278076E-03
     +,   2.4137322E-03,   2.2956016E-03,   2.1748801E-03
     +,   2.0528834E-03,   1.9307550E-03,   1.8094860E-03
     +,   1.6899419E-03,   1.5729116E-03,   1.4591339E-03
     +,   1.3492921E-03,   1.2439997E-03,   1.1437910E-03
     +,   1.0491154E-03,   9.6032216E-04,   8.7765278E-04
     +,   8.0124853E-04,   7.3116168E-04,   6.6734274E-04
     +,   6.0965400E-04,   5.5787730E-04,   5.1171705E-04
     +,   4.7080583E-04,   4.3472339E-04,   4.0301250E-04
     +,   3.7519293E-04,   3.5077808E-04,   3.2929343E-04
     +,   3.1029092E-04,   2.9335829E-04,   2.7812537E-04
     +,   2.6426953E-04,   2.5151734E-04,   2.3964087E-04
     +,   2.2845523E-04,   2.1781532E-04,   2.0761001E-04
     +,   1.9775610E-04,   1.8819459E-04,   1.7888617E-04
     +,   1.6980722E-04,   1.6094511E-04,   1.5229615E-04
     +,   1.4386374E-04,   1.3565541E-04,   1.2768104E-04
     +,   1.1995179E-04,   1.1247988E-04,   1.0527633E-04
     +,   9.8351054E-05,   9.1712915E-05,   8.5368898E-05
     +,   7.9323509E-05,   7.3579227E-05,   6.8136818E-05
     +,   6.2995001E-05,   5.8150232E-05,   5.3597269E-05
     +,   4.9329628E-05,   4.5339435E-05,   4.1617379E-05
     +,   3.8153263E-05,   3.4936493E-05,   3.1955573E-05
     +,   2.9198673E-05,   2.6653937E-05,   2.4309415E-05
     +,   2.2153057E-05,   2.0173000E-05,   1.8357758E-05
     +,   1.6696164E-05,   1.5177306E-05,   1.3790730E-05
     +,   1.2526532E-05,   1.1375279E-05,   1.0327959E-05
     +,   9.3760809E-06,   8.5117545E-06,   7.7274990E-06
     +,   7.0163373E-06,   6.3718239E-06,   5.7879774E-06
     +,   5.2592209E-06,   4.7804260E-06,   4.3469008E-06
     +,   3.9543470E-06,   3.5988030E-06,   3.2766636E-06
     +,   2.9846715E-06,   2.7198671E-06,   2.4795559E-06
     +,   2.2613074E-06,   2.0629516E-06,   1.8825179E-06
     +,   1.7182389E-06,   1.5685397E-06,   1.4320103E-06
     +,   1.3073819E-06,   1.1935206E-06,   1.0894203E-06
     +,   9.9418287E-07,   9.0699814E-07,   8.2714303E-07
     +,   7.5397668E-07,   6.8691554E-07,   6.2544382E-07
     +,   5.6908937E-07,   5.1743257E-07,   4.7008791E-07
     +,   4.2671098E-07,   3.8698280E-07,   3.5061748E-07
     +,   3.1734885E-07,   2.8693640E-07,   2.5915614E-07
     +,   2.3380173E-07,   2.1068452E-07,   1.8962727E-07
     +,   1.7046837E-07,   1.5305505E-07,   1.3724821E-07
     +,   1.2291626E-07,   1.0993885E-07,   9.8202491E-08
     +,   8.7603297E-08,   7.8043492E-08,   6.9433689E-08
     +,   6.1689740E-08,   5.4735018E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt80 = Yx/0.507843137254902
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6989950E-05,   1.7426173E-05
     +,   1.7872835E-05,   1.8329672E-05,   1.8796325E-05
     +,   1.9272326E-05,   1.9757079E-05,   2.0249889E-05
     +,   2.0749912E-05,   2.1256243E-05,   2.1767813E-05
     +,   2.2283471E-05,   2.2801953E-05,   2.3321903E-05
     +,   2.3841871E-05,   2.4360334E-05,   2.4875693E-05
     +,   2.5386300E-05,   2.5890449E-05,   2.6386415E-05
     +,   2.6872447E-05,   2.7346794E-05,   2.7807715E-05
     +,   2.8253522E-05,   2.8682520E-05,   2.9093124E-05
     +,   2.9483803E-05,   2.9853119E-05,   3.0199742E-05
     +,   3.0522482E-05,   3.0820262E-05,   3.1092175E-05
     +,   3.1337484E-05,   3.1555617E-05,   3.1746207E-05
     +,   3.1909101E-05,   3.2044343E-05,   3.2152217E-05
     +,   3.2233249E-05,   3.2288201E-05,   3.2318101E-05
     +,   3.2324242E-05,   3.2308188E-05,   3.2271790E-05
     +,   3.2217184E-05,   3.2146800E-05,   3.2063377E-05
     +,   3.1969965E-05,   3.1869928E-05,   3.1766969E-05
     +,   3.1665124E-05,   3.1568779E-05,   3.1482690E-05
     +,   3.1411993E-05,   3.1362251E-05,   3.1339445E-05
     +,   3.1350050E-05,   3.1401058E-05,   3.1500032E-05
     +,   3.1655200E-05,   3.1875483E-05,   3.2170632E-05
     +,   3.2551285E-05,   3.3029115E-05,   3.3616943E-05
     +,   3.4328783E-05,   3.5180110E-05,   3.6187786E-05
     +,   3.7370381E-05,   3.8747974E-05,   4.0342537E-05
     +,   4.2177591E-05,   4.4278528E-05,   4.6672139E-05
     +,   4.9386847E-05,   5.2452386E-05,   5.5899320E-05
     +,   5.9758844E-05,   6.4062755E-05,   6.8842906E-05
     +,   7.4130250E-05,   7.9955629E-05,   8.6348067E-05
     +,   9.3335817E-05,   1.0094464E-04,   1.0919923E-04
     +,   1.1812108E-04,   1.2773044E-04,   1.3804379E-04
     +,   1.4907574E-04,   1.6083772E-04,   1.7333704E-04
     +,   1.8657692E-04,   2.0055643E-04,   2.1526990E-04
     +,   2.3070420E-04,   2.4684265E-04,   2.6366086E-04
     +,   2.8113258E-04,   2.9922804E-04,   3.1792212E-04
     +,   3.3719715E-04,   3.5705589E-04,   3.7752971E-04
     +,   3.9869765E-04,   4.2070434E-04,   4.4378056E-04
     +,   4.6826963E-04,   4.9465604E-04,   5.2359008E-04
     +,   5.5591081E-04,   5.9267366E-04,   6.3515891E-04
     +,   6.8489491E-04,   7.4365980E-04,   8.1350975E-04
     +,   8.9679012E-04,   9.9619455E-04,   1.1148088E-03
     +,   1.2562278E-03,   1.4246625E-03,   1.6250144E-03
     +,   1.8628326E-03,   2.1440138E-03,   2.4741946E-03
     +,   2.8581251E-03,   3.3000594E-03,   3.8065610E-03
     +,   4.3945094E-03,   5.1050908E-03,   6.0188374E-03
     +,   7.2533051E-03,   8.9248270E-03,   1.1088627E-02
     +,   1.3717218E-02,   1.6777003E-02,   2.0464242E-02
     +,   2.5385246E-02,   3.2153565E-02,   4.1398451E-02
     +,   5.4392446E-02,   7.0334300E-02,   8.7233305E-02
     +,   0.1048066    ,   0.1169767    ,   0.1277602    
     +,   0.1433812    ,   0.1512223    ,   0.1454023    
     +,   0.1359987    ,   0.1207217    ,   0.1075930    
     +,   9.6823528E-02,   7.7731200E-02,   6.1414633E-02
     +,   5.3127859E-02,   4.7190286E-02,   4.0637452E-02
     +,   3.3884961E-02,   2.8107941E-02,   2.3647862E-02
     +,   2.0218633E-02,   1.7629988E-02,   1.5701691E-02
     +,   1.4175029E-02,   1.2839867E-02,   1.1600344E-02
     +,   1.0444698E-02,   9.3895691E-03,   8.4457286E-03
     +,   7.6124738E-03,   6.8827025E-03,   6.2454529E-03
     +,   5.6860466E-03,   5.1877587E-03,   4.7351522E-03
     +,   4.3172664E-03,   3.9286483E-03,   3.5682928E-03
     +,   3.2377408E-03,   2.9392778E-03,   2.6746455E-03
     +,   2.4441818E-03,   2.2464013E-03,   2.0780102E-03
     +,   1.9342894E-03,   1.8097366E-03,   1.6988326E-03
     +,   1.5967335E-03,   1.4997371E-03,   1.4054537E-03
     +,   1.3127447E-03,   1.2214913E-03,   1.1322555E-03
     +,   1.0459411E-03,   9.6350984E-04,   8.8577910E-04
     +,   8.1329368E-04,   7.4627809E-04,   6.8466243E-04
     +,   6.2814634E-04,   5.7627278E-04,   5.2850734E-04
     +,   4.8431475E-04,   4.4321481E-04,   4.0480765E-04
     +,   3.6879099E-04,   3.3496044E-04,   3.0319334E-04
     +,   2.7342685E-04,   2.4563886E-04,   2.1982903E-04
     +,   1.9599944E-04,   1.7414027E-04,   1.5422326E-04
     +,   1.3619920E-04,   1.1999546E-04,   1.0551746E-04
     +,   9.2654082E-05,   8.1283273E-05,   7.1274684E-05
     +,   6.2496038E-05,   5.4817596E-05,   4.8114827E-05
     +,   4.2270611E-05,   3.7177393E-05,   3.2738320E-05
     +,   2.8867005E-05,   2.5487156E-05,   2.2532244E-05
     +,   1.9944871E-05,   1.7675575E-05,   1.5681744E-05
     +,   1.3926909E-05,   1.2379975E-05,   1.1014129E-05
     +,   9.8063456E-06,   8.7368762E-06,   7.7886552E-06
     +,   6.9468465E-06,   6.1985770E-06,   5.5327096E-06
     +,   4.9395217E-06,   4.4104981E-06,   3.9382080E-06
     +,   3.5161859E-06,   3.1387674E-06,   2.8009724E-06
     +,   2.4984370E-06,   2.2273612E-06,   1.9843742E-06
     +,   1.7665136E-06,   1.5711770E-06,   1.3960602E-06
     +,   1.2391077E-06,   1.0984927E-06,   9.7259397E-07
     +,   8.5995845E-07,   7.5927579E-07,   6.6936661E-07
     +,   5.8917345E-07,   5.1773986E-07,   4.5419435E-07
     +,   3.9774829E-07,   3.4769070E-07,   3.0337043E-07
     +,   2.6419747E-07,   2.2963758E-07,   1.9920580E-07
     +,   1.7246013E-07,   1.4900012E-07,   1.2846495E-07
     +,   1.1052820E-07,   9.4893842E-08,   8.1295624E-08
     +,   6.9495258E-08,   5.9277337E-08,   5.0450300E-08
     +,   4.2841894E-08,   3.6299525E-08,   3.0686628E-08
     +,   2.5882906E-08,   2.1781190E-08,   1.8287551E-08
     +,   1.5318838E-08,   1.2802440E-08,   1.0674578E-08
     +,   8.8796073E-09,   7.3692688E-09,   6.1014700E-09
     +,   5.0399631E-09,   4.1533235E-09,   3.4146233E-09
     +,   2.8006677E-09,   2.2916926E-09,   1.8707698E-09
     +,   1.5235532E-09,   1.2378313E-09,   1.0033157E-09
     +,   8.1129503E-10,   6.5447181E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt85 = Yx/0.529392156862745
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4126283E-06,   3.7063453E-06
     +,   4.0190366E-06,   4.3512819E-06,   4.7036146E-06
     +,   5.0765088E-06,   5.4703783E-06,   5.8855621E-06
     +,   6.3223169E-06,   6.7808296E-06,   7.2611720E-06
     +,   7.7633213E-06,   8.2871420E-06,   8.8323850E-06
     +,   9.3986728E-06,   9.9855024E-06,   1.0592235E-05
     +,   1.1218093E-05,   1.1862154E-05,   1.2523358E-05
     +,   1.3200494E-05,   1.3892211E-05,   1.4596997E-05
     +,   1.5313248E-05,   1.6039148E-05,   1.6772825E-05
     +,   1.7512244E-05,   1.8255267E-05,   1.8999657E-05
     +,   1.9743084E-05,   2.0483141E-05,   2.1217371E-05
     +,   2.1943270E-05,   2.2658320E-05,   2.3359986E-05
     +,   2.4045763E-05,   2.4713201E-05,   2.5359894E-05
     +,   2.5983569E-05,   2.6582013E-05,   2.7153224E-05
     +,   2.7695351E-05,   2.8206752E-05,   2.8686010E-05
     +,   2.9132001E-05,   2.9543893E-05,   2.9921190E-05
     +,   3.0263769E-05,   3.0571908E-05,   3.0846346E-05
     +,   3.1088286E-05,   3.1299460E-05,   3.1482166E-05
     +,   3.1639323E-05,   3.1774467E-05,   3.1891879E-05
     +,   3.1996529E-05,   3.2094220E-05,   3.2191561E-05
     +,   3.2296055E-05,   3.2416097E-05,   3.2561053E-05
     +,   3.2741238E-05,   3.2967964E-05,   3.3253546E-05
     +,   3.3611250E-05,   3.4055305E-05,   3.4600813E-05
     +,   3.5263711E-05,   3.6060566E-05,   3.7008605E-05
     +,   3.8125316E-05,   3.9428498E-05,   4.0935720E-05
     +,   4.2664338E-05,   4.4631113E-05,   4.6851696E-05
     +,   4.9340440E-05,   5.2110143E-05,   5.5171673E-05
     +,   5.8533275E-05,   6.2200954E-05,   6.6177388E-05
     +,   7.0462651E-05,   7.5053118E-05,   7.9942416E-05
     +,   8.5120482E-05,   9.0574795E-05,   9.6289514E-05
     +,   1.0224704E-04,   1.0842800E-04,   1.1481156E-04
     +,   1.2137649E-04,   1.2810249E-04,   1.3497069E-04
     +,   1.4196400E-04,   1.4906964E-04,   1.5627826E-04
     +,   1.6358723E-04,   1.7099947E-04,   1.7852662E-04
     +,   1.8618841E-04,   1.9401584E-04,   2.0205053E-04
     +,   2.1034799E-04,   2.1897884E-04,   2.2802970E-04
     +,   2.3760574E-04,   2.4783303E-04,   2.5885916E-04
     +,   2.7085247E-04,   2.8400373E-04,   2.9852017E-04
     +,   3.1462387E-04,   3.3253909E-04,   3.5248545E-04
     +,   3.7465847E-04,   3.9921666E-04,   4.2625805E-04
     +,   4.5580603E-04,   4.8779190E-04,   5.2204292E-04
     +,   5.5828231E-04,   5.9614051E-04,   6.3517777E-04
     +,   6.7491329E-04,   7.1488321E-04,   7.5468555E-04
     +,   7.9405418E-04,   8.3290995E-04,   8.7143190E-04
     +,   9.1011019E-04,   9.4981736E-04,   9.9187624E-04
     +,   1.0381551E-03,   1.0911603E-03,   1.1540975E-03
     +,   1.2308414E-03,   1.3257038E-03,   1.4429131E-03
     +,   1.5857877E-03,   1.7557786E-03,   1.9517675E-03
     +,   2.1701080E-03,   2.4059296E-03,   2.6559702E-03
     +,   2.9224164E-03,   3.2167381E-03,   3.5621340E-03
     +,   3.9933245E-03,   4.5533613E-03,   5.2876659E-03
     +,   6.2357606E-03,   7.4240142E-03,   8.8698696E-03
     +,   1.0626005E-02,   1.2922612E-02,   1.6348816E-02
     +,   2.1656374E-02,   2.9197333E-02,   3.8990069E-02
     +,   5.0738484E-02,   6.5018848E-02,   8.6996131E-02
     +,   0.1125400    ,   0.1348301    ,   0.1540566    
     +,   0.1738279    ,   0.1703647    ,   0.1620457    
     +,   0.1488843    ,   0.1334123    ,   0.1110586    
     +,   8.8852920E-02,   7.3272288E-02,   5.8862399E-02
     +,   4.5409434E-02,   3.5771433E-02,   3.0135544E-02
     +,   2.6604470E-02,   2.3862915E-02,   2.1398826E-02
     +,   1.8911351E-02,   1.6217824E-02,   1.3446385E-02
     +,   1.0938788E-02,   8.9438464E-03,   7.4908342E-03
     +,   6.4693363E-03,   5.7438854E-03,   5.2086567E-03
     +,   4.7911406E-03,   4.4415779E-03,   4.1264081E-03
     +,   3.8252745E-03,   3.5280373E-03,   3.2312933E-03
     +,   2.9354827E-03,   2.6430611E-03,   2.3575926E-03
     +,   2.0832112E-03,   1.8240865E-03,   1.5838897E-03
     +,   1.3653780E-03,   1.1701597E-03,   9.9862053E-04
     +,   8.5009442E-04,   7.2311488E-04,   6.1567541E-04
     +,   5.2547525E-04,   4.5013378E-04,   3.8734850E-04
     +,   3.3499126E-04,   2.9117143E-04,   2.5426774E-04
     +,   2.2293263E-04,   1.9607200E-04,   1.7281542E-04
     +,   1.5248462E-04,   1.3455992E-04,   1.1864367E-04
     +,   1.0443428E-04,   9.1703172E-05,   8.0274796E-05
     +,   7.0011447E-05,   6.0803002E-05,   5.2559222E-05
     +,   4.5202913E-05,   3.8665166E-05,   3.2882934E-05
     +,   2.7797245E-05,   2.3351429E-05,   1.9490186E-05
     +,   1.6159680E-05,   1.3307859E-05,   1.0884043E-05
     +,   8.8396782E-06,   7.1288482E-06,   5.7084681E-06
     +,   4.5385600E-06,   3.5826274E-06,   2.8078114E-06
     +,   2.1848368E-06,   1.6879259E-06,   1.2947071E-06
     +,   9.8601470E-07,   7.4559193E-07,   5.5979632E-07
     +,   4.1732653E-07,   3.0892869E-07,   2.2708232E-07
     +,   1.6575189E-07,   1.2014317E-07,   8.6481066E-08
     +,   6.1820273E-08,   4.3886814E-08,   3.0941788E-08
     +,   2.1666043E-08,   1.5067483E-08,   1.0407149E-08
     +,   7.1394566E-09,   4.8646696E-09,   3.2922789E-09
     +,   2.2130708E-09,   1.4776229E-09,   9.7994157E-10
     +,   6.4550792E-10,   4.2235268E-10,   2.7449071E-10
     +,   1.7719595E-10,   1.1361771E-10,   7.2361742E-11
     +,   4.5777014E-11,   2.8764187E-11,   1.7951987E-11
     +,   1.1128551E-11,   6.8519162E-12,   4.1902688E-12
     +,   2.5451201E-12,   1.5353981E-12,   9.1993795E-13
     +,   5.4743162E-13,   3.2352877E-13,   1.8989721E-13
     +,   1.1069367E-13,   6.4081946E-14,   3.6842000E-14
     +,   2.1034367E-14,   1.1926277E-14,   6.7149905E-15
     +,   3.7545993E-15,   2.0846595E-15,   1.1493967E-15
     +,   6.2928407E-16,   3.4211767E-16,   1.8468603E-16
     +,   9.8999854E-17,   5.2693030E-17,   2.7848640E-17
     +,   1.4613770E-17,   7.6145292E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt90 = Yx/0.528294117647059
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8420611E-06,   2.0675782E-06
     +,   2.3157027E-06,   2.5879958E-06,   2.8860377E-06
     +,   3.2114140E-06,   3.5657051E-06,   3.9504648E-06
     +,   4.3672103E-06,   4.8174206E-06,   5.3024942E-06
     +,   5.8237415E-06,   6.3823763E-06,   6.9794896E-06
     +,   7.6160363E-06,   8.2928209E-06,   9.0104795E-06
     +,   9.7694638E-06,   1.0570037E-05,   1.1412259E-05
     +,   1.2295973E-05,   1.3220809E-05,   1.4186167E-05
     +,   1.5191289E-05,   1.6235086E-05,   1.7316381E-05
     +,   1.8433737E-05,   1.9585550E-05,   2.0770047E-05
     +,   2.1985321E-05,   2.3229339E-05,   2.4499988E-05
     +,   2.5795098E-05,   2.7112463E-05,   2.8449902E-05
     +,   2.9805280E-05,   3.1176562E-05,   3.2561824E-05
     +,   3.3959408E-05,   3.5367739E-05,   3.6785645E-05
     +,   3.8212194E-05,   3.9646839E-05,   4.1089406E-05
     +,   4.2540214E-05,   4.4000015E-05,   4.5470097E-05
     +,   4.6952311E-05,   4.8449037E-05,   4.9963295E-05
     +,   5.1498679E-05,   5.3059390E-05,   5.4650234E-05
     +,   5.6276691E-05,   5.7944606E-05,   5.9660539E-05
     +,   6.1431390E-05,   6.3264466E-05,   6.5167362E-05
     +,   6.7147841E-05,   6.9213638E-05,   7.1372589E-05
     +,   7.3631891E-05,   7.5998585E-05,   7.8478930E-05
     +,   8.1078186E-05,   8.3800682E-05,   8.6649117E-05
     +,   8.9624977E-05,   9.2727489E-05,   9.5954347E-05
     +,   9.9300632E-05,   1.0275946E-04,   1.0632117E-04
     +,   1.0997389E-04,   1.1370330E-04,   1.1749256E-04
     +,   1.2132251E-04,   1.2517236E-04,   1.2901964E-04
     +,   1.3284045E-04,   1.3661057E-04,   1.4030532E-04
     +,   1.4390110E-04,   1.4737518E-04,   1.5070730E-04
     +,   1.5387984E-04,   1.5687906E-04,   1.5969557E-04
     +,   1.6232514E-04,   1.6476933E-04,   1.6703576E-04
     +,   1.6913850E-04,   1.7109822E-04,   1.7294205E-04
     +,   1.7470286E-04,   1.7641908E-04,   1.7813336E-04
     +,   1.7989161E-04,   1.8174123E-04,   1.8373037E-04
     +,   1.8590495E-04,   1.8830807E-04,   1.9097747E-04
     +,   1.9394427E-04,   1.9723190E-04,   2.0085447E-04
     +,   2.0481680E-04,   2.0911431E-04,   2.1373399E-04
     +,   2.1865508E-04,   2.2385202E-04,   2.2929632E-04
     +,   2.3496061E-04,   2.4082109E-04,   2.4686276E-04
     +,   2.5308153E-04,   2.5948865E-04,   2.6611207E-04
     +,   2.7299859E-04,   2.8021345E-04,   2.8783787E-04
     +,   2.9596555E-04,   3.0469816E-04,   3.1413697E-04
     +,   3.2437459E-04,   3.3548666E-04,   3.4752194E-04
     +,   3.6049663E-04,   3.7438609E-04,   3.8912630E-04
     +,   4.0461161E-04,   4.2070515E-04,   4.3724646E-04
     +,   4.5406944E-04,   4.7101983E-04,   4.8797586E-04
     +,   5.0486915E-04,   5.2170682E-04,   5.3858611E-04
     +,   5.5570516E-04,   5.7336991E-04,   5.9199362E-04
     +,   6.1208842E-04,   6.3424878E-04,   6.5913191E-04
     +,   6.8742788E-04,   7.1982021E-04,   7.5694051E-04
     +,   7.9931924E-04,   8.4732339E-04,   9.0109662E-04
     +,   9.6051017E-04,   1.0251370E-03,   1.0942518E-03
     +,   1.1668667E-03,   1.2418297E-03,   1.3179607E-03
     +,   1.3942145E-03,   1.4698602E-03,   1.5447108E-03
     +,   1.6193778E-03,   1.6956584E-03,   1.7771651E-03
     +,   1.8702871E-03,   1.9854296E-03,   2.1381401E-03
     +,   2.3492097E-03,   2.6423205E-03,   3.0380443E-03
     +,   3.5445215E-03,   4.1483692E-03,   4.8122355E-03
     +,   5.4860762E-03,   6.1382013E-03,   6.8098609E-03
     +,   7.6798066E-03,   9.0719480E-03,   1.1323762E-02
     +,   1.4697125E-02,   1.9688318E-02,   2.7456699E-02
     +,   3.9836194E-02,   5.7593431E-02,   8.0579109E-02
     +,   0.1054320    ,   0.1359358    ,   0.1794196    
     +,   0.2058081    ,   0.2202537    ,   0.2087185    
     +,   0.1741906    ,   0.1356275    ,   0.1077909    
     +,   8.3285891E-02,   5.9621643E-02,   4.3012913E-02
     +,   3.1195790E-02,   2.1946546E-02,   1.5800519E-02
     +,   1.2121976E-02,   9.8752351E-03,   8.3330516E-03
     +,   7.1176803E-03,   6.0841893E-03,   5.1784404E-03
     +,   4.3725115E-03,   3.6516634E-03,   3.0098874E-03
     +,   2.4451755E-03,   1.9564410E-03,   1.5419009E-03
     +,   1.1980837E-03,   9.1938738E-04,   6.9832860E-04
     +,   5.2631646E-04,   3.9457384E-04,   2.9491974E-04
     +,   2.2025080E-04,   1.6470259E-04,   1.2358892E-04
     +,   9.3260482E-05,   7.0924834E-05,   5.4471133E-05
     +,   4.2321033E-05,   3.3307668E-05,   2.6576476E-05
     +,   2.1505690E-05,   1.7645178E-05,   1.4670126E-05
     +,   1.2346221E-05,   1.0503778E-05,   9.0194171E-06
     +,   7.8032681E-06,   6.7898932E-06,   5.9315394E-06
     +,   5.1935840E-06,   4.5510901E-06,   3.9861329E-06
     +,   3.4858133E-06,   3.0407994E-06,   2.6442488E-06
     +,   2.2909535E-06,   1.9767474E-06,   1.6981438E-06
     +,   1.4520882E-06,   1.2357809E-06,   1.0465739E-06
     +,   8.8194815E-07,   7.3950878E-07,   6.1695471E-07
     +,   5.1210651E-07,   4.2292243E-07,   3.4749863E-07
     +,   2.8407436E-07,   2.3104319E-07,   1.8695552E-07
     +,   1.5051148E-07,   1.2055476E-07,   9.6067971E-08
     +,   7.6165001E-08,   6.0078413E-08,   4.7148077E-08
     +,   3.6811937E-08,   2.8595618E-08,   2.2100036E-08
     +,   1.6992814E-08,   1.2999303E-08,   9.8937578E-09
     +,   7.4917876E-09,   5.6440124E-09,   4.2303174E-09
     +,   3.1546010E-09,   2.3404472E-09,   1.7275537E-09
     +,   1.2686766E-09,   9.2693370E-10,   6.7380385E-10
     +,   4.8729981E-10,   3.5062789E-10,   2.5100005E-10
     +,   1.7876770E-10,   1.2667246E-10,   8.9302260E-11
     +,   6.2635459E-11,   4.3708502E-11,   3.0345514E-11
     +,   2.0960433E-11,   1.4404341E-11,   9.8483643E-12
     +,   6.6991963E-12,   4.5337549E-12,   3.0526857E-12
     +,   2.0449523E-12,   1.3629245E-12,   9.0372761E-13
     +,   5.9620066E-13,   3.9131204E-13,   2.5553022E-13
     +,   1.6601145E-13,   1.0730573E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_hatt95 = Yx/0.502901960784314
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3358709E-07,   1.4995602E-07
     +,   1.6807716E-07,   1.8810495E-07,   2.1020328E-07
     +,   2.3454589E-07,   2.6131653E-07,   2.9070853E-07
     +,   3.2292456E-07,   3.5817914E-07,   3.9669445E-07
     +,   4.3870278E-07,   4.8444542E-07,   5.3417267E-07
     +,   5.8814288E-07,   6.4662231E-07,   7.0988409E-07
     +,   7.7820840E-07,   8.5188049E-07,   9.3119075E-07
     +,   1.0164338E-06,   1.1079068E-06,   1.2059081E-06
     +,   1.3107427E-06,   1.4227053E-06,   1.5421017E-06
     +,   1.6692285E-06,   1.8043818E-06,   1.9478555E-06
     +,   2.0999389E-06,   2.2609197E-06,   2.4310775E-06
     +,   2.6106923E-06,   2.8000379E-06,   2.9993889E-06
     +,   3.2090161E-06,   3.4291911E-06,   3.6601850E-06
     +,   3.9022921E-06,   4.1557851E-06,   4.4209792E-06
     +,   4.6981909E-06,   4.9877649E-06,   5.2900727E-06
     +,   5.6055246E-06,   5.9345721E-06,   6.2777208E-06
     +,   6.6355324E-06,   7.0086417E-06,   7.3977626E-06
     +,   7.8037001E-06,   8.2273536E-06,   8.6697391E-06
     +,   9.1320080E-06,   9.6154081E-06,   1.0121372E-05
     +,   1.0651459E-05,   1.1207397E-05,   1.1791085E-05
     +,   1.2404598E-05,   1.3050191E-05,   1.3730316E-05
     +,   1.4447563E-05,   1.5204770E-05,   1.6004939E-05
     +,   1.6851194E-05,   1.7746916E-05,   1.8695524E-05
     +,   1.9700696E-05,   2.0766100E-05,   2.1895625E-05
     +,   2.3093095E-05,   2.4362513E-05,   2.5707739E-05
     +,   2.7132726E-05,   2.8641360E-05,   3.0237328E-05
     +,   3.1924181E-05,   3.3705353E-05,   3.5584078E-05
     +,   3.7563110E-05,   3.9645132E-05,   4.1832198E-05
     +,   4.4126216E-05,   4.6528334E-05,   4.9039532E-05
     +,   5.1659921E-05,   5.4389340E-05,   5.7226749E-05
     +,   6.0170671E-05,   6.3219057E-05,   6.6368972E-05
     +,   6.9616857E-05,   7.2958697E-05,   7.6389908E-05
     +,   7.9905032E-05,   8.3498599E-05,   8.7164299E-05
     +,   9.0896072E-05,   9.4687341E-05,   9.8532168E-05
     +,   1.0242460E-04,   1.0635982E-04,   1.1033373E-04
     +,   1.1434401E-04,   1.1839033E-04,   1.2247454E-04
     +,   1.2660130E-04,   1.3077912E-04,   1.3502035E-04
     +,   1.3934121E-04,   1.4376341E-04,   1.4831297E-04
     +,   1.5302187E-04,   1.5792684E-04,   1.6307054E-04
     +,   1.6850016E-04,   1.7426883E-04,   1.8043378E-04
     +,   1.8705758E-04,   1.9420779E-04,   2.0195666E-04
     +,   2.1038184E-04,   2.1956801E-04,   2.2960705E-04
     +,   2.4059800E-04,   2.5265029E-04,   2.6588043E-04
     +,   2.8041494E-04,   2.9638392E-04,   3.1392113E-04
     +,   3.3315358E-04,   3.5419787E-04,   3.7714560E-04
     +,   4.0205737E-04,   4.2895248E-04,   4.5779732E-04
     +,   4.8850605E-04,   5.2094378E-04,   5.5493647E-04
     +,   5.9028645E-04,   6.2680134E-04,   6.6432782E-04
     +,   7.0278457E-04,   7.4218900E-04,   7.8269106E-04
     +,   8.2458119E-04,   8.6828583E-04,   9.1435364E-04
     +,   9.6342608E-04,   1.0161969E-03,   1.0733685E-03
     +,   1.1356149E-03,   1.2035564E-03,   1.2777441E-03
     +,   1.3586424E-03,   1.4466515E-03,   1.5421404E-03
     +,   1.6454932E-03,   1.7571790E-03,   1.8778725E-03
     +,   2.0085610E-03,   2.1506238E-03,   2.3058690E-03
     +,   2.4764887E-03,   2.6649123E-03,   2.8736726E-03
     +,   3.1054683E-03,   3.3634375E-03,   3.6515195E-03
     +,   3.9745313E-03,   4.3377439E-03,   4.7461307E-03
     +,   5.2038529E-03,   5.7142461E-03,   6.2793903E-03
     +,   6.8979589E-03,   7.5648567E-03,   8.2834680E-03
     +,   9.1036512E-03,   1.0183068E-02,   1.1822925E-02
     +,   1.4380010E-02,   1.8033277E-02,   2.2611907E-02
     +,   2.7793564E-02,   3.3586618E-02,   4.0289108E-02
     +,   4.8114698E-02,   5.7902880E-02,   6.9727361E-02
     +,   8.3360270E-02,   9.7879104E-02,   0.1048790    
     +,   0.1109202    ,   0.1211415    ,   0.1205473    
     +,   0.1113499    ,   0.1011568    ,   8.5336074E-02
     +,   6.9023848E-02,   5.6441620E-02,   4.7111157E-02
     +,   3.9741904E-02,   3.3124309E-02,   2.7188597E-02
     +,   2.2250051E-02,   1.8379731E-02,   1.5306908E-02
     +,   1.2776877E-02,   1.0701640E-02,   9.0506133E-03
     +,   7.7537089E-03,   6.6799941E-03,   5.6916405E-03
     +,   4.7119111E-03,   3.7437286E-03,   2.8394831E-03
     +,   2.0574287E-03,   1.4319188E-03,   9.6533779E-04
     +,   6.3637900E-04,   4.1362160E-04,   2.6638486E-04
     +,   1.7014044E-04,   1.0748259E-04,   6.6845932E-05
     +,   4.0717594E-05,   2.4178995E-05,   1.3945169E-05
     +,   7.7900049E-06,   4.2063721E-06,   2.1922283E-06
     +,   1.1015222E-06,   5.3321799E-07,   2.4851937E-07
     +,   1.1147343E-07,   4.8109801E-08,   1.9975312E-08
     +,   7.9783558E-09,   3.0653804E-09,   1.1330586E-09
     +,   4.0299308E-10,   1.3795218E-10,   4.5476563E-11
     +,   1.4457969E-11,   4.4494113E-12,   1.3385851E-12
     +,   4.0410253E-13,   1.3033904E-13,   5.0136741E-14
     +,   2.5129841E-14,   1.5813766E-14,   1.1229588E-14
     +,   8.3550000E-15,   6.3079971E-15,   4.7790878E-15
     +,   3.6205149E-15,   2.7396798E-15,   2.0701057E-15
     +,   1.5617499E-15,   1.1763840E-15,   8.8469547E-16
     +,   6.6425896E-16,   4.9794896E-16,   3.7267374E-16
     +,   2.7845951E-16,   2.0772374E-16,   1.5470435E-16
     +,   1.1502832E-16,   8.5386096E-17,   6.3277490E-17
     +,   4.6816160E-17,   3.4579634E-17,   2.5498562E-17
     +,   1.8771102E-17,   1.3795304E-17,   1.0121584E-17
     +,   7.4136261E-18,   5.4210692E-18,   3.9573177E-18
     +,   2.8839462E-18,   2.0981310E-18,   1.5238639E-18
     +,   1.1048862E-18,   7.9974996E-19,   5.7789784E-19
     +,   4.1687295E-19,   3.0020463E-19,   2.1581726E-19
     +,   1.5488680E-19,   1.1096746E-19,   7.9366364E-20
     +,   5.6666848E-20,   4.0390509E-20,   2.8739566E-20
     +,   2.0414449E-20,   1.4475817E-20,   1.0247295E-20
     +,   7.2413459E-21,   5.1084316E-21
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt100 = Yx/0.42252
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1046025E-05,   1.1142778E-05
     +,   1.1232148E-05,   1.1314402E-05,   1.1389842E-05
     +,   1.1458801E-05,   1.1521650E-05,   1.1578783E-05
     +,   1.1630617E-05,   1.1677592E-05,   1.1720153E-05
     +,   1.1758761E-05,   1.1793880E-05,   1.1825968E-05
     +,   1.1855488E-05,   1.1882885E-05,   1.1908593E-05
     +,   1.1933030E-05,   1.1956587E-05,   1.1979638E-05
     +,   1.2002520E-05,   1.2025547E-05,   1.2048998E-05
     +,   1.2073116E-05,   1.2098110E-05,   1.2124155E-05
     +,   1.2151382E-05,   1.2179899E-05,   1.2209768E-05
     +,   1.2241022E-05,   1.2273663E-05,   1.2307662E-05
     +,   1.2342963E-05,   1.2379484E-05,   1.2417132E-05
     +,   1.2455783E-05,   1.2495309E-05,   1.2535568E-05
     +,   1.2576418E-05,   1.2617708E-05,   1.2659294E-05
     +,   1.2701039E-05,   1.2742810E-05,   1.2784499E-05
     +,   1.2826004E-05,   1.2867249E-05,   1.2908180E-05
     +,   1.2948771E-05,   1.2989018E-05,   1.3028958E-05
     +,   1.3068650E-05,   1.3108191E-05,   1.3147715E-05
     +,   1.3187389E-05,   1.3227412E-05,   1.3268028E-05
     +,   1.3309512E-05,   1.3352185E-05,   1.3396392E-05
     +,   1.3442535E-05,   1.3491044E-05,   1.3542396E-05
     +,   1.3597110E-05,   1.3655756E-05,   1.3718944E-05
     +,   1.3787351E-05,   1.3861706E-05,   1.3942803E-05
     +,   1.4031513E-05,   1.4128786E-05,   1.4235668E-05
     +,   1.4353300E-05,   1.4482958E-05,   1.4626027E-05
     +,   1.4784054E-05,   1.4958749E-05,   1.5152005E-05
     +,   1.5365893E-05,   1.5602742E-05,   1.5865120E-05
     +,   1.6155827E-05,   1.6477990E-05,   1.6835020E-05
     +,   1.7230679E-05,   1.7669048E-05,   1.8154640E-05
     +,   1.8692283E-05,   1.9287298E-05,   1.9945352E-05
     +,   2.0672618E-05,   2.1475720E-05,   2.2361723E-05
     +,   2.3338149E-05,   2.4413084E-05,   2.5595142E-05
     +,   2.6893349E-05,   2.8317441E-05,   2.9877589E-05
     +,   3.1584779E-05,   3.3450502E-05,   3.5487246E-05
     +,   3.7708109E-05,   4.0127470E-05,   4.2760574E-05
     +,   4.5624125E-05,   4.8736412E-05,   5.2117175E-05
     +,   5.5787972E-05,   5.9772632E-05,   6.4097178E-05
     +,   6.8789450E-05,   7.3880066E-05,   7.9401041E-05
     +,   8.5386753E-05,   9.1872142E-05,   9.8893288E-05
     +,   1.0648498E-04,   1.1468113E-04,   1.2351143E-04
     +,   1.3300148E-04,   1.4317015E-04,   1.5402715E-04
     +,   1.6557156E-04,   1.7779117E-04,   1.9066015E-04
     +,   2.0413716E-04,   2.1816778E-04,   2.3268184E-04
     +,   2.4759822E-04,   2.6282345E-04,   2.7825939E-04
     +,   2.9380282E-04,   3.0935497E-04,   3.2482287E-04
     +,   3.4012870E-04,   3.5521417E-04,   3.7004464E-04
     +,   3.8461527E-04,   3.9895525E-04,   4.1313001E-04
     +,   4.2724164E-04,   4.4143025E-04,   4.5587515E-04
     +,   4.7079317E-04,   4.8643418E-04,   5.0308363E-04
     +,   5.2105536E-04,   5.4068415E-04,   5.6231557E-04
     +,   5.8629009E-04,   6.1291887E-04,   6.4245035E-04
     +,   6.7503488E-04,   7.1068591E-04,   7.4924488E-04
     +,   7.9035340E-04,   8.3345862E-04,   8.7785017E-04
     +,   9.2274370E-04,   9.6741260E-04,   1.0113968E-03
     +,   1.0547459E-03,   1.0983016E-03,   1.1439685E-03
     +,   1.1949125E-03,   1.2555766E-03,   1.3314070E-03
     +,   1.4282240E-03,   1.5512290E-03,   1.7037709E-03
     +,   1.8861954E-03,   2.0952290E-03,   2.3243302E-03
     +,   2.5651613E-03,   2.8099802E-03,   3.0542805E-03
     +,   3.2985292E-03,   3.5481304E-03,   3.8113822E-03
     +,   4.0962808E-03,   4.4078440E-03,   4.7481521E-03
     +,   5.1198988E-03,   5.5319290E-03,   6.0024867E-03
     +,   6.5565878E-03,   7.2194687E-03,   8.0142105E-03
     +,   8.9698648E-03,   1.0137576E-02,   1.1603742E-02
     +,   1.3471199E-02,   1.5774662E-02,   1.8403456E-02
     +,   2.1246260E-02,   2.4530208E-02,   2.8890338E-02
     +,   3.5174455E-02,   4.3839406E-02,   5.2684307E-02
     +,   6.0512584E-02,   7.2120473E-02,   8.5895203E-02
     +,   0.1037234    ,   0.1249345    ,   0.1330256    
     +,   0.1374541    ,   0.1287196    ,   0.1099392    
     +,   9.2236735E-02,   7.9088263E-02,   6.4870417E-02
     +,   5.0435394E-02,   3.7280723E-02,   2.6262715E-02
     +,   1.7578427E-02,   1.1132246E-02,   6.7352830E-03
     +,   3.9499635E-03,   2.2621460E-03,   1.2618833E-03
     +,   6.8244513E-04,   3.6072364E-04,   1.9276365E-04
     +,   1.1010106E-04,   7.0303286E-05,   5.0218292E-05
     +,   3.8837145E-05,   3.1461546E-05,   2.6181051E-05
     +,   2.2189086E-05,   1.9099160E-05,   1.6690459E-05
     +,   1.4813451E-05,   1.3352898E-05,   1.2213080E-05
     +,   1.1313246E-05,   1.0586651E-05,   9.9801828E-06
     +,   9.4535681E-06,   8.9778769E-06,   8.5335168E-06
     +,   8.1080489E-06,   7.6941878E-06,   7.2881758E-06
     +,   6.8885697E-06,   6.4952965E-06,   6.1090268E-06
     +,   5.7308034E-06,   5.3618396E-06,   5.0033027E-06
     +,   4.6562736E-06,   4.3217310E-06,   4.0005002E-06
     +,   3.6932322E-06,   3.4004254E-06,   3.1224483E-06
     +,   2.8595248E-06,   2.6117273E-06,   2.3790071E-06
     +,   2.1612200E-06,   1.9581178E-06,   1.7693511E-06
     +,   1.5944942E-06,   1.4330748E-06,   1.2845469E-06
     +,   1.1483255E-06,   1.0237998E-06,   9.1033689E-07
     +,   8.0728068E-07,   7.1397125E-07,   6.2975539E-07
     +,   5.5398795E-07,   4.8603096E-07,   4.2526648E-07
     +,   3.7110394E-07,   3.2297072E-07,   2.8032912E-07
     +,   2.4266464E-07,   2.0949898E-07,   1.8038108E-07
     +,   1.5489492E-07,   1.3265281E-07,   1.1330091E-07
     +,   9.6512409E-08,   8.1991857E-08,   6.9469422E-08
     +,   5.8701538E-08,   4.9470103E-08,   4.1578524E-08
     +,   3.4852459E-08,   2.9136025E-08,   2.4292101E-08
     +,   2.0199110E-08,   1.6750883E-08,   1.3854025E-08
     +,   1.1427516E-08,   9.4007042E-09,   7.7127096E-09
     +,   6.3108256E-09,   5.1499556E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt105 = Yx/0.407714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1917132E-06,   1.2966470E-06
     +,   1.4084220E-06,   1.5272323E-06,   1.6532499E-06
     +,   1.7866238E-06,   1.9274762E-06,   2.0758994E-06
     +,   2.2319500E-06,   2.3956572E-06,   2.5670035E-06
     +,   2.7459330E-06,   2.9323464E-06,   3.1260979E-06
     +,   3.3269951E-06,   3.5347934E-06,   3.7491995E-06
     +,   3.9698680E-06,   4.1964004E-06,   4.4283447E-06
     +,   4.6651990E-06,   4.9064083E-06,   5.1513648E-06
     +,   5.3994290E-06,   5.6498875E-06,   5.9020140E-06
     +,   6.1550295E-06,   6.4081246E-06,   6.6604616E-06
     +,   6.9111834E-06,   7.1594127E-06,   7.4042664E-06
     +,   7.6448605E-06,   7.8803168E-06,   8.1097742E-06
     +,   8.3323957E-06,   8.5473794E-06,   8.7539665E-06
     +,   8.9514624E-06,   9.1392239E-06,   9.3167000E-06
     +,   9.4834204E-06,   9.6390204E-06,   9.7832490E-06
     +,   9.9159788E-06,   1.0037221E-05,   1.0147141E-05
     +,   1.0246066E-05,   1.0334504E-05,   1.0413150E-05
     +,   1.0482901E-05,   1.0544871E-05,   1.0600406E-05
     +,   1.0651089E-05,   1.0698749E-05,   1.0745485E-05
     +,   1.0793665E-05,   1.0845929E-05,   1.0905212E-05
     +,   1.0974733E-05,   1.1058002E-05,   1.1158821E-05
     +,   1.1281265E-05,   1.1429697E-05,   1.1608739E-05
     +,   1.1823241E-05,   1.2078285E-05,   1.2379115E-05
     +,   1.2731154E-05,   1.3139880E-05,   1.3610865E-05
     +,   1.4149609E-05,   1.4761598E-05,   1.5452084E-05
     +,   1.6226124E-05,   1.7088467E-05,   1.8043376E-05
     +,   1.9094585E-05,   2.0245270E-05,   2.1497897E-05
     +,   2.2853988E-05,   2.4314329E-05,   2.5878518E-05
     +,   2.7545277E-05,   2.9311957E-05,   3.1174972E-05
     +,   3.3129250E-05,   3.5168745E-05,   3.7285910E-05
     +,   3.9472216E-05,   4.1717976E-05,   4.4012351E-05
     +,   4.6343514E-05,   4.8699021E-05,   5.1065788E-05
     +,   5.3430020E-05,   5.5778015E-05,   5.8095786E-05
     +,   6.0369839E-05,   6.2586922E-05,   6.4734828E-05
     +,   6.6802182E-05,   6.8779125E-05,   7.0657232E-05
     +,   7.2430143E-05,   7.4093674E-05,   7.5645949E-05
     +,   7.7087781E-05,   7.8423007E-05,   7.9658581E-05
     +,   8.0804755E-05,   8.1875391E-05,   8.2888095E-05
     +,   8.3864375E-05,   8.4829808E-05,   8.5814288E-05
     +,   8.6852015E-05,   8.7981869E-05,   8.9247296E-05
     +,   9.0696718E-05,   9.2383540E-05,   9.4366274E-05
     +,   9.6708492E-05,   9.9479294E-05,   1.0275297E-04
     +,   1.0660866E-04,   1.1113086E-04,   1.1640789E-04
     +,   1.2253238E-04,   1.2959899E-04,   1.3770470E-04
     +,   1.4694520E-04,   1.5741512E-04,   1.6920330E-04
     +,   1.8239225E-04,   1.9705480E-04,   2.1324963E-04
     +,   2.3101950E-04,   2.5038919E-04,   2.7136187E-04
     +,   2.9391525E-04,   3.1799998E-04,   3.4353981E-04
     +,   3.7042852E-04,   3.9852643E-04,   4.2766638E-04
     +,   4.5765360E-04,   4.8826839E-04,   5.1927764E-04
     +,   5.5045064E-04,   5.8157765E-04,   6.1249640E-04
     +,   6.4312760E-04,   6.7352084E-04,   7.0389744E-04
     +,   7.3469436E-04,   7.6660683E-04,   8.0061355E-04
     +,   8.3797547E-04,   8.8019500E-04,   9.2894275E-04
     +,   9.8592113E-04,   1.0526737E-03,   1.1303570E-03
     +,   1.2194890E-03,   1.3196911E-03,   1.4294782E-03
     +,   1.5461537E-03,   1.6658666E-03,   1.7838350E-03
     +,   1.8947639E-03,   1.9934452E-03,   2.0754435E-03
     +,   2.1377488E-03,   2.1793018E-03,   2.2013471E-03
     +,   2.2075404E-03,   2.2039122E-03,   2.1987874E-03
     +,   2.2028324E-03,   2.2294286E-03,   2.2956177E-03
     +,   2.4237265E-03,   2.6432141E-03,   2.9908326E-03
     +,   3.5055340E-03,   4.2149201E-03,   5.1147081E-03
     +,   6.1519668E-03,   7.2296616E-03,   8.2444698E-03
     +,   9.1454117E-03,   9.9745821E-03,   1.0843889E-02
     +,   1.1843211E-02,   1.2972169E-02,   1.4232573E-02
     +,   1.5838014E-02,   1.8235963E-02,   2.1869935E-02
     +,   2.7035682E-02,   3.3697039E-02,   4.1446581E-02
     +,   4.9314313E-02,   5.5585064E-02,   6.5651894E-02
     +,   8.3510265E-02,   0.1023059    ,   0.1301690    
     +,   0.1486526    ,   0.1605376    ,   0.1586593    
     +,   0.1315650    ,   0.1052700    ,   7.7017002E-02
     +,   5.0059792E-02,   3.0489255E-02,   1.6700320E-02
     +,   7.5133811E-03,   2.7215721E-03,   8.4664929E-04
     +,   2.7425407E-04,   1.3212327E-04,   1.0134150E-04
     +,   9.2437229E-05,   8.5858839E-05,   7.8638135E-05
     +,   7.0790076E-05,   6.2697014E-05,   5.4720920E-05
     +,   4.7147016E-05,   4.0172567E-05,   3.3910605E-05
     +,   2.8403283E-05,   2.3639515E-05,   1.9571651E-05
     +,   1.6131800E-05,   1.3244177E-05,   1.0833164E-05
     +,   8.8282259E-06,   7.1665013E-06,   5.7935272E-06
     +,   4.6627219E-06,   3.7345171E-06,   2.9754985E-06
     +,   2.3575026E-06,   1.8567389E-06,   1.4530847E-06
     +,   1.1295670E-06,   8.7190722E-07,   6.6806678E-07
     +,   5.0795290E-07,   3.8314474E-07,   2.8663700E-07
     +,   2.1263286E-07,   1.5637552E-07,   1.1399327E-07
     +,   8.2357936E-08,   5.8964883E-08,   4.1830837E-08
     +,   2.9402702E-08,   2.0475964E-08,   1.4126770E-08
     +,   9.6552046E-09,   6.5373169E-09,   4.3847344E-09
     +,   2.9132659E-09,   1.9173987E-09,   1.2500949E-09
     +,   8.0735724E-10,   5.1650456E-10,   3.2732311E-10
     +,   2.0548661E-10,   1.2778871E-10,   7.8723424E-11
     +,   4.8044381E-11,   2.9047514E-11,   1.7399483E-11
     +,   1.0326163E-11,   6.0725335E-12,   3.5389155E-12
     +,   2.0442389E-12,   1.1707091E-12,   6.6495827E-13
     +,   3.7477839E-13,   2.0976156E-13,   1.1670572E-13
     +,   6.4641082E-14,   3.5718539E-14,   1.9745868E-14
     +,   1.0963278E-14,   6.1434762E-15,   3.4954202E-15
     +,   2.0324520E-15,   1.2153484E-15,   7.5088306E-16
     +,   4.8033147E-16,   3.1777751E-16,   2.1661187E-16
     +,   1.5130636E-16,   1.0768156E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt107 = Yx/0.397571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.6042113E-06,   9.9388117E-06
     +,   1.0277370E-05,   1.0619611E-05,   1.0965253E-05
     +,   1.1314015E-05,   1.1665606E-05,   1.2019738E-05
     +,   1.2376113E-05,   1.2734453E-05,   1.3094463E-05
     +,   1.3455854E-05,   1.3818343E-05,   1.4181646E-05
     +,   1.4545488E-05,   1.4909599E-05,   1.5273707E-05
     +,   1.5637554E-05,   1.6000888E-05,   1.6363458E-05
     +,   1.6725024E-05,   1.7085353E-05,   1.7444216E-05
     +,   1.7801402E-05,   1.8156685E-05,   1.8509865E-05
     +,   1.8860746E-05,   1.9209123E-05,   1.9554813E-05
     +,   1.9897627E-05,   2.0237389E-05,   2.0573912E-05
     +,   2.0907031E-05,   2.1236570E-05,   2.1562364E-05
     +,   2.1884240E-05,   2.2202032E-05,   2.2515569E-05
     +,   2.2824703E-05,   2.3129252E-05,   2.3429069E-05
     +,   2.3723982E-05,   2.4013832E-05,   2.4298468E-05
     +,   2.4577739E-05,   2.4851486E-05,   2.5119572E-05
     +,   2.5381869E-05,   2.5638245E-05,   2.5888585E-05
     +,   2.6132799E-05,   2.6370801E-05,   2.6602520E-05
     +,   2.6827942E-05,   2.7047034E-05,   2.7259817E-05
     +,   2.7466358E-05,   2.7666738E-05,   2.7861084E-05
     +,   2.8049588E-05,   2.8232473E-05,   2.8410030E-05
     +,   2.8582590E-05,   2.8750583E-05,   2.8914479E-05
     +,   2.9074818E-05,   2.9232249E-05,   2.9387456E-05
     +,   2.9541268E-05,   2.9694531E-05,   2.9848254E-05
     +,   3.0003488E-05,   3.0161433E-05,   3.0323356E-05
     +,   3.0490635E-05,   3.0664785E-05,   3.0847423E-05
     +,   3.1040261E-05,   3.1245159E-05,   3.1464115E-05
     +,   3.1699215E-05,   3.1952721E-05,   3.2227013E-05
     +,   3.2524626E-05,   3.2848231E-05,   3.3200708E-05
     +,   3.3585031E-05,   3.4004446E-05,   3.4462304E-05
     +,   3.4962210E-05,   3.5508001E-05,   3.6103702E-05
     +,   3.6753590E-05,   3.7462250E-05,   3.8234564E-05
     +,   3.9075629E-05,   3.9990999E-05,   4.0986426E-05
     +,   4.2068154E-05,   4.3242668E-05,   4.4516972E-05
     +,   4.5898283E-05,   4.7394366E-05,   4.9013142E-05
     +,   5.0763003E-05,   5.2652635E-05,   5.4690820E-05
     +,   5.6886493E-05,   5.9248676E-05,   6.1786450E-05
     +,   6.4508393E-05,   6.7423040E-05,   7.0538081E-05
     +,   7.3860945E-05,   7.7397708E-05,   8.1153987E-05
     +,   8.5133703E-05,   8.9340116E-05,   9.3774681E-05
     +,   9.8438024E-05,   1.0332972E-04,   1.0844833E-04
     +,   1.1379182E-04,   1.1935879E-04,   1.2514867E-04
     +,   1.3116226E-04,   1.3740391E-04,   1.4388179E-04
     +,   1.5061037E-04,   1.5761102E-04,   1.6491536E-04
     +,   1.7256540E-04,   1.8061804E-04,   1.8914502E-04
     +,   1.9823734E-04,   2.0800732E-04,   2.1859046E-04
     +,   2.3014910E-04,   2.4287563E-04,   2.5699544E-04
     +,   2.7276832E-04,   2.9049197E-04,   3.1050527E-04
     +,   3.3319069E-04,   3.5897209E-04,   3.8832097E-04
     +,   4.2175353E-04,   4.5982449E-04,   5.0311990E-04
     +,   5.5224507E-04,   6.0779607E-04,   6.7031482E-04
     +,   7.4023916E-04,   8.1783737E-04,   9.0312969E-04
     +,   9.9580234E-04,   1.0951504E-03,   1.2000484E-03
     +,   1.3089576E-03,   1.4199864E-03,   1.5310437E-03
     +,   1.6400180E-03,   1.7449909E-03,   1.8444741E-03
     +,   1.9375886E-03,   2.0241640E-03,   2.1047427E-03
     +,   2.1805041E-03,   2.2531641E-03,   2.3249253E-03
     +,   2.3985680E-03,   2.4777760E-03,   2.5675939E-03
     +,   2.6748125E-03,   2.8079031E-03,   2.9761381E-03
     +,   3.1875523E-03,   3.4460025E-03,   3.7480735E-03
     +,   4.0811705E-03,   4.4239713E-03,   4.7499598E-03
     +,   5.0337003E-03,   5.2583097E-03,   5.4224376E-03
     +,   5.5454136E-03,   5.6696185E-03,   5.8588171E-03
     +,   6.1907112E-03,   6.7422381E-03,   7.5678760E-03
     +,   8.6744158E-03,   1.0000810E-02,   1.1417557E-02
     +,   1.2756894E-02,   1.3870011E-02,   1.4689187E-02
     +,   1.5266125E-02,   1.5769545E-02,   1.6457317E-02
     +,   1.7633066E-02,   1.9525414E-02,   2.2115365E-02
     +,   2.5165362E-02,   2.8498679E-02,   3.2299593E-02
     +,   3.7189227E-02,   4.3556847E-02,   5.0827969E-02
     +,   5.8715362E-02,   6.7931719E-02,   8.0714583E-02
     +,   9.9294052E-02,   0.1235739    ,   0.1521710    
     +,   0.1681740    ,   0.1547317    ,   0.1051309    
     +,   4.2672895E-02,   8.7246103E-03,   8.2523300E-04
     +,   3.4396173E-05,   6.1573309E-07,   9.3875938E-09
     +,   4.2399790E-09,   3.6611025E-09,   3.1721614E-09
     +,   2.7488034E-09,   2.3818940E-09,   2.0636928E-09
     +,   1.7876108E-09,   1.5479984E-09,   1.3399947E-09
     +,   1.1594129E-09,   1.0026573E-09,   8.6660185E-10
     +,   7.4854190E-10,   6.4613487E-10,   5.5734706E-10
     +,   4.8040216E-10,   4.1375681E-10,   3.5606887E-10
     +,   3.0616981E-10,   2.6303723E-10,   2.2578082E-10
     +,   1.9362648E-10,   1.6589936E-10,   1.4200954E-10
     +,   1.2144345E-10,   1.0375613E-10,   8.8558244E-11
     +,   7.5511333E-11,   6.4322242E-11,   5.4736209E-11
     +,   4.6531435E-11,   3.9515884E-11,   3.3523455E-11
     +,   2.8410465E-11,   2.4052215E-11,   2.0341123E-11
     +,   1.7184545E-11,   1.4502588E-11,   1.2226239E-11
     +,   1.0296195E-11,   8.6616391E-12,   7.2788086E-12
     +,   6.1101753E-12,   5.1236667E-12,   4.2918486E-12
     +,   3.5912089E-12,   3.0016981E-12,   2.5062498E-12
     +,   2.0903351E-12,   1.7415601E-12,   1.4494000E-12
     +,   1.2049542E-12,   1.0006444E-12,   8.3008269E-13
     +,   6.8784225E-13,   5.6936059E-13,   4.7077332E-13
     +,   3.8883705E-13,   3.2081087E-13,   2.6440010E-13
     +,   2.1766993E-13,   1.7900545E-13,   1.4704880E-13
     +,   1.2066505E-13,   9.8908180E-14,   8.0985396E-14
     +,   6.6238674E-14,   5.4117813E-14,   4.4167215E-14
     +,   3.6006710E-14,   2.9322231E-14,   2.3852555E-14
     +,   1.9382155E-14,   1.5732344E-14,   1.2756014E-14
     +,   1.0331432E-14,   8.3586185E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt110 = Yx/0.371428571428571
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2181162E-06,   2.3358689E-06
     +,   2.4581216E-06,   2.5849452E-06,   2.7164058E-06
     +,   2.8525683E-06,   2.9934915E-06,   3.1392331E-06
     +,   3.2898438E-06,   3.4453797E-06,   3.6058861E-06
     +,   3.7714065E-06,   3.9419870E-06,   4.1176668E-06
     +,   4.2984871E-06,   4.4844860E-06,   4.6757045E-06
     +,   4.8721813E-06,   5.0739568E-06,   5.2810751E-06
     +,   5.4935822E-06,   5.7115244E-06,   5.9349541E-06
     +,   6.1639425E-06,   6.3985390E-06,   6.6388266E-06
     +,   6.8848858E-06,   7.1368058E-06,   7.3946853E-06
     +,   7.6586393E-06,   7.9287902E-06,   8.2052738E-06
     +,   8.4882413E-06,   8.7778562E-06,   9.0742969E-06
     +,   9.3777553E-06,   9.6884442E-06,   1.0006578E-05
     +,   1.0332413E-05,   1.0666184E-05,   1.1008172E-05
     +,   1.1358658E-05,   1.1717935E-05,   1.2086314E-05
     +,   1.2464110E-05,   1.2851657E-05,   1.3249284E-05
     +,   1.3657342E-05,   1.4076171E-05,   1.4506126E-05
     +,   1.4947557E-05,   1.5400810E-05,   1.5866230E-05
     +,   1.6344176E-05,   1.6834949E-05,   1.7338894E-05
     +,   1.7856326E-05,   1.8387538E-05,   1.8932826E-05
     +,   1.9492461E-05,   2.0066715E-05,   2.0655845E-05
     +,   2.1260073E-05,   2.1879658E-05,   2.2514858E-05
     +,   2.3165869E-05,   2.3833001E-05,   2.4516487E-05
     +,   2.5216679E-05,   2.5933899E-05,   2.6668626E-05
     +,   2.7421325E-05,   2.8192706E-05,   2.8983490E-05
     +,   2.9794686E-05,   3.0627529E-05,   3.1483483E-05
     +,   3.2364354E-05,   3.3272416E-05,   3.4210425E-05
     +,   3.5181631E-05,   3.6190060E-05,   3.7240385E-05
     +,   3.8338301E-05,   3.9490333E-05,   4.0704304E-05
     +,   4.1989093E-05,   4.3355096E-05,   4.4813987E-05
     +,   4.6379133E-05,   4.8065547E-05,   4.9889783E-05
     +,   5.1870054E-05,   5.4026350E-05,   5.6380271E-05
     +,   5.8954538E-05,   6.1773455E-05,   6.4861917E-05
     +,   6.8245812E-05,   7.1950839E-05,   7.6002878E-05
     +,   8.0426573E-05,   8.5245789E-05,   9.0482012E-05
     +,   9.6154639E-05,   1.0228029E-04,   1.0887169E-04
     +,   1.1593779E-04,   1.2348378E-04,   1.3151082E-04
     +,   1.4001509E-04,   1.4898989E-04,   1.5842392E-04
     +,   1.6830409E-04,   1.7861406E-04,   1.8933756E-04
     +,   2.0045697E-04,   2.1195703E-04,   2.2382324E-04
     +,   2.3604583E-04,   2.4861912E-04,   2.6154242E-04
     +,   2.7482075E-04,   2.8846684E-04,   3.0250030E-04
     +,   3.1694674E-04,   3.3184077E-04,   3.4722223E-04
     +,   3.6314069E-04,   3.7965123E-04,   3.9682005E-04
     +,   4.1472117E-04,   4.3344393E-04,   4.5309152E-04
     +,   4.7378946E-04,   4.9569015E-04,   5.1897735E-04
     +,   5.4387411E-04,   5.7065132E-04,   5.9963006E-04
     +,   6.3118170E-04,   6.6572736E-04,   7.0372946E-04
     +,   7.4567588E-04,   7.9205161E-04,   8.4331410E-04
     +,   8.9985778E-04,   9.6197327E-04,   1.0298219E-03
     +,   1.1034257E-03,   1.1826815E-03,   1.2673950E-03
     +,   1.3573690E-03,   1.4525233E-03,   1.5530109E-03
     +,   1.6593223E-03,   1.7723369E-03,   1.8932797E-03
     +,   2.0235223E-03,   2.1642509E-03,   2.3160628E-03
     +,   2.4785141E-03,   2.6497573E-03,   2.8264457E-03
     +,   3.0039819E-03,   3.1771732E-03,   3.3412806E-03
     +,   3.4934026E-03,   3.6338712E-03,   3.7674098E-03
     +,   3.9036358E-03,   4.0566428E-03,   4.2434251E-03
     +,   4.4812351E-03,   4.7842180E-03,   5.1600365E-03
     +,   5.6069037E-03,   6.1115627E-03,   6.6487892E-03
     +,   7.1831094E-03,   7.6737907E-03,   8.0838790E-03
     +,   8.3925510E-03,   8.6075282E-03,   8.7721115E-03
     +,   8.9608980E-03,   9.2606628E-03,   9.7407782E-03
     +,   1.0430330E-02,   1.1326288E-02,   1.2437641E-02
     +,   1.3819942E-02,   1.5523187E-02,   1.7445626E-02
     +,   1.9244721E-02,   2.0502163E-02,   2.1097362E-02
     +,   2.1455603E-02,   2.2393690E-02,   2.4569755E-02
     +,   2.7848702E-02,   3.1217268E-02,   3.3518862E-02
     +,   3.4164459E-02,   3.3312604E-02,   3.2280214E-02
     +,   3.3282842E-02,   3.7144795E-02,   4.2044666E-02
     +,   4.5698080E-02,   4.7480207E-02,   4.8004705E-02
     +,   4.8182376E-02,   4.8027247E-02,   4.6093050E-02
     +,   4.0978469E-02,   3.2556832E-02,   2.2308463E-02
     +,   1.2835111E-02,   6.1193919E-03,   2.4045473E-03
     +,   7.7502755E-04,   2.0362507E-04,   4.3302178E-05
     +,   7.4037521E-06,   1.0156075E-06,   1.1610329E-07
     +,   1.5787748E-08,   6.3865171E-09,   5.1076698E-09
     +,   4.4602508E-09,   3.9134052E-09,   3.4312357E-09
     +,   3.0056053E-09,   2.6302567E-09,   2.2995739E-09
     +,   2.0085267E-09,   1.7526331E-09,   1.5278826E-09
     +,   1.3306772E-09,   1.1578102E-09,   1.0064383E-09
     +,   8.7402474E-10,   7.5830919E-10,   6.5728556E-10
     +,   5.6917937E-10,   4.9241844E-10,   4.2560735E-10
     +,   3.6751271E-10,   3.1705108E-10,   2.7326169E-10
     +,   2.3529906E-10,   2.0242145E-10,   1.7397700E-10
     +,   1.4939135E-10,   1.2816097E-10,   1.0984678E-10
     +,   9.4064007E-11,   8.0475508E-11,   6.8787205E-11
     +,   5.8743441E-11,   5.0121279E-11,   4.2726427E-11
     +,   3.6389974E-11,   3.0965890E-11,   2.6327067E-11
     +,   2.2363408E-11,   1.8979924E-11,   1.6094443E-11
     +,   1.3635866E-11,   1.1542879E-11,   9.7628025E-12
     +,   8.2502824E-12,   6.9662141E-12,   5.8770345E-12
     +,   4.9540489E-12,   4.1725343E-12,   3.5114405E-12
     +,   2.9526531E-12,   2.4807871E-12,   2.0826372E-12
     +,   1.7469971E-12,   1.4642730E-12,   1.2263403E-12
     +,   1.0262587E-12,   8.5815486E-13,   7.1703076E-13
     +,   5.9864960E-13,   4.9943540E-13,   4.1634423E-13
     +,   3.4681700E-13,   2.8868260E-13,   2.4011525E-13
     +,   1.9957014E-13,   1.6575051E-13,   1.3756066E-13
     +,   1.1408292E-13,   9.4543609E-14,   7.8295043E-14
     +,   6.4792511E-14,   5.3580855E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt115 = Yx/0.258255319148936
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3906319E-08,   4.8677911E-08
     +,   5.3913222E-08,   5.9650887E-08,   6.5932156E-08
     +,   7.2800759E-08,   8.0303238E-08,   8.8488868E-08
     +,   9.7409632E-08,   1.0712092E-07,   1.1768069E-07
     +,   1.2915004E-07,   1.4159322E-07,   1.5507743E-07
     +,   1.6967317E-07,   1.8545406E-07,   2.0249666E-07
     +,   2.2088084E-07,   2.4068919E-07,   2.6200735E-07
     +,   2.8492403E-07,   3.0953015E-07,   3.3591922E-07
     +,   3.6418862E-07,   3.9443501E-07,   4.2675984E-07
     +,   4.6126485E-07,   4.9805317E-07,   5.3722943E-07
     +,   5.7889895E-07,   6.2316695E-07,   6.7013957E-07
     +,   7.1992179E-07,   7.7261745E-07,   8.2832992E-07
     +,   8.8716052E-07,   9.4920773E-07,   1.0145665E-06
     +,   1.0833332E-06,   1.1555924E-06,   1.2314318E-06
     +,   1.3109320E-06,   1.3941681E-06,   1.4812102E-06
     +,   1.5721240E-06,   1.6669699E-06,   1.7658037E-06
     +,   1.8686765E-06,   1.9756344E-06,   2.0867224E-06
     +,   2.2019829E-06,   2.3214600E-06,   2.4451965E-06
     +,   2.5732511E-06,   2.7056753E-06,   2.8425511E-06
     +,   2.9839678E-06,   3.1300438E-06,   3.2809285E-06
     +,   3.4368127E-06,   3.5979360E-06,   3.7646018E-06
     +,   3.9371757E-06,   4.1161234E-06,   4.3020113E-06
     +,   4.4955073E-06,   4.6974383E-06,   4.9087594E-06
     +,   5.1306261E-06,   5.3643603E-06,   5.6115264E-06
     +,   5.8738947E-06,   6.1535229E-06,   6.4527067E-06
     +,   6.7740616E-06,   7.1205095E-06,   7.4952659E-06
     +,   7.9018737E-06,   8.3442155E-06,   8.8265124E-06
     +,   9.3532426E-06,   9.9292456E-06,   1.0559561E-05
     +,   1.1249550E-05,   1.2004676E-05,   1.2830668E-05
     +,   1.3733234E-05,   1.4718256E-05,   1.5791478E-05
     +,   1.6958671E-05,   1.8225492E-05,   1.9597373E-05
     +,   2.1079519E-05,   2.2677044E-05,   2.4394865E-05
     +,   2.6237609E-05,   2.8210066E-05,   3.0316804E-05
     +,   3.2562937E-05,   3.4953755E-05,   3.7495600E-05
     +,   4.0195620E-05,   4.3062864E-05,   4.6108074E-05
     +,   4.9344908E-05,   5.2790347E-05,   5.6465160E-05
     +,   6.0394905E-05,   6.4611042E-05,   6.9151589E-05
     +,   7.4061420E-05,   7.9394391E-05,   8.5212414E-05
     +,   9.1587681E-05,   9.8601158E-05,   1.0634418E-04
     +,   1.1491575E-04,   1.2442333E-04,   1.3497807E-04
     +,   1.4669391E-04,   1.5968256E-04,   1.7404718E-04
     +,   1.8987690E-04,   2.0724104E-04,   2.2618109E-04
     +,   2.4670133E-04,   2.6876674E-04,   2.9229259E-04
     +,   3.1714671E-04,   3.4314362E-04,   3.7005328E-04
     +,   3.9760207E-04,   4.2548974E-04,   4.5339705E-04
     +,   4.8100919E-04,   5.0803251E-04,   5.3421222E-04
     +,   5.5935333E-04,   5.8334012E-04,   6.0614588E-04
     +,   6.2784087E-04,   6.4859813E-04,   6.6869223E-04
     +,   6.8849255E-04,   7.0845144E-04,   7.2909513E-04
     +,   7.5100828E-04,   7.7481766E-04,   8.0117804E-04
     +,   8.3076552E-04,   8.6426764E-04,   9.0238481E-04
     +,   9.4584317E-04,   9.9542248E-04,   1.0519834E-03
     +,   1.1164948E-03,   1.1900554E-03,   1.2738833E-03
     +,   1.3692491E-03,   1.4773464E-03,   1.5991241E-03
     +,   1.7350692E-03,   1.8849877E-03,   2.0478859E-03
     +,   2.2219885E-03,   2.4049708E-03,   2.5944479E-03
     +,   2.7888028E-03,   2.9882577E-03,   3.1958956E-03
     +,   3.4181958E-03,   3.6645147E-03,   3.9449842E-03
     +,   4.2670332E-03,   4.6315086E-03,   5.0301389E-03
     +,   5.4458370E-03,   5.8563878E-03,   6.2404685E-03
     +,   6.5831738E-03,   6.8781991E-03,   7.1266270E-03
     +,   7.3365602E-03,   7.5283325E-03,   7.7419463E-03
     +,   8.0320453E-03,   8.4413439E-03,   8.9753475E-03
     +,   9.6205305E-03,   1.0401331E-02,   1.1390872E-02
     +,   1.2606293E-02,   1.3877346E-02,   1.4874873E-02
     +,   1.5330234E-02,   1.5234259E-02,   1.4822012E-02
     +,   1.4412084E-02,   1.4290332E-02,   1.4662893E-02
     +,   1.5589185E-02,   1.6940221E-02,   1.8503042E-02
     +,   2.0189559E-02,   2.2110330E-02,   2.4351472E-02
     +,   2.6747208E-02,   2.8905293E-02,   3.0286549E-02
     +,   3.0503176E-02,   2.9732861E-02,   2.8417125E-02
     +,   2.6652610E-02,   2.4283540E-02,   2.1282328E-02
     +,   1.7776774E-02,   1.3964937E-02,   1.0143197E-02
     +,   6.6910614E-03,   3.9425064E-03,   2.0464549E-03
     +,   9.2674792E-04,   3.6411395E-04,   1.2379207E-04
     +,   3.6373447E-05,   9.2288119E-06,   2.0212765E-06
     +,   3.8316855E-07,   6.4266843E-08,   1.0935634E-08
     +,   3.1065612E-09,   1.9346964E-09,   1.6137678E-09
     +,   1.4059204E-09,   1.2293920E-09,   1.0743808E-09
     +,   9.3798525E-10,   8.1807422E-10,   7.1277173E-10
     +,   6.2039202E-10,   5.3943483E-10,   4.6856496E-10
     +,   4.0659454E-10,   3.5246089E-10,   3.0522326E-10
     +,   2.6404773E-10,   2.2819563E-10,   1.9701134E-10
     +,   1.6991489E-10,   1.4639703E-10,   1.2600598E-10
     +,   1.0834440E-10,   9.3063682E-11,   7.9857301E-11
     +,   6.8455359E-11,   5.8621476E-11,   5.0149208E-11
     +,   4.2858092E-11,   3.6589728E-11,   3.1206312E-11
     +,   2.6587879E-11,   2.2630054E-11,   1.9241827E-11
     +,   1.6344164E-11,   1.3868849E-11,   1.1756450E-11
     +,   9.9556145E-12,   8.4220608E-12,   7.1175418E-12
     +,   6.0089616E-12,   5.0678715E-12,   4.2698184E-12
     +,   3.5938032E-12,   3.0217465E-12,   2.5381502E-12
     +,   2.1297961E-12,   1.7853127E-12,   1.4950356E-12
     +,   1.2506761E-12,   1.0451992E-12,   8.7258732E-13
     +,   7.2774724E-13,   6.0632760E-13,   5.0465659E-13
     +,   4.1960410E-13,   3.4853349E-13,   2.8920629E-13
     +,   2.3973255E-13,   1.9852138E-13,   1.6422629E-13
     +,   1.3571900E-13,   1.1204536E-13,   9.2407683E-14
     +,   7.6133795E-14,   6.2662623E-14,   5.1522365E-14
     +,   4.2319745E-14,   3.4725400E-14,   2.8465023E-14
     +,   2.3309439E-14,   1.9068384E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt120 = Yx/0.173727272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.6608768E-05,   9.9493060E-05
     +,   1.0242339E-04,   1.0540423E-04,   1.0844076E-04
     +,   1.1153884E-04,   1.1470515E-04,   1.1794705E-04
     +,   1.2127248E-04,   1.2469030E-04,   1.2820972E-04
     +,   1.3184061E-04,   1.3559315E-04,   1.3947804E-04
     +,   1.4350629E-04,   1.4768894E-04,   1.5203728E-04
     +,   1.5656246E-04,   1.6127576E-04,   1.6618810E-04
     +,   1.7131033E-04,   1.7665299E-04,   1.8222652E-04
     +,   1.8804130E-04,   1.9410721E-04,   2.0043478E-04
     +,   2.0703417E-04,   2.1391657E-04,   2.2109348E-04
     +,   2.2857757E-04,   2.3638293E-04,   2.4452523E-04
     +,   2.5302274E-04,   2.6189571E-04,   2.7116766E-04
     +,   2.8086556E-04,   2.9102017E-04,   3.0166624E-04
     +,   3.1284420E-04,   3.2459875E-04,   3.3698155E-04
     +,   3.5005101E-04,   3.6387341E-04,   3.7852454E-04
     +,   3.9409249E-04,   4.1067769E-04,   4.2839805E-04
     +,   4.4739142E-04,   4.6781916E-04,   4.8987166E-04
     +,   5.1377178E-04,   5.3978065E-04,   5.6820147E-04
     +,   5.9938419E-04,   6.3372444E-04,   6.7166926E-04
     +,   7.1370963E-04,   7.6037954E-04,   8.1224361E-04
     +,   8.6989009E-04,   9.3391229E-04,   1.0048934E-03
     +,   1.0833803E-03,   1.1698749E-03,   1.2648128E-03
     +,   1.3685357E-03,   1.4813186E-03,   1.6033570E-03
     +,   1.7348370E-03,   1.8759641E-03,   2.0270916E-03
     +,   2.1887685E-03,   2.3618743E-03,   2.5475931E-03
     +,   2.7473944E-03,   2.9628221E-03,   3.1951605E-03
     +,   3.4449985E-03,   3.7118020E-03,   3.9935475E-03
     +,   4.2865928E-03,   4.5860186E-03,   4.8862239E-03
     +,   5.1819705E-03,   5.4693408E-03,   5.7465858E-03
     +,   6.0142092E-03,   6.2745092E-03,   6.5302695E-03
     +,   6.7833425E-03,   7.0334505E-03,   7.2778352E-03
     +,   7.5120940E-03,   7.7319513E-03,   7.9353973E-03
     +,   8.1242183E-03,   8.3043939E-03,   8.4848255E-03
     +,   8.6751711E-03,   8.8832742E-03,   9.1136424E-03
     +,   9.3670962E-03,   9.6419621E-03,   9.9354889E-03
     +,   1.0245130E-02,   1.0568232E-02,   1.0900868E-02
     +,   1.1236557E-02,   1.1566432E-02,   1.1881306E-02
     +,   1.2174310E-02,   1.2442340E-02,   1.2684382E-02
     +,   1.2898432E-02,   1.3079774E-02,   1.3223669E-02
     +,   1.3332421E-02,   1.3424191E-02,   1.3539570E-02
     +,   1.3742243E-02,   1.4109961E-02,   1.4712757E-02
     +,   1.5582053E-02,   1.6683979E-02,   1.7915037E-02
     +,   1.9133046E-02,   2.0215662E-02,   2.1117007E-02
     +,   2.1886298E-02,   2.2627667E-02,   2.3419350E-02
     +,   2.4243651E-02,   2.4979895E-02,   2.5469095E-02
     +,   2.5604825E-02,   2.5384467E-02,   2.4888217E-02
     +,   2.4208153E-02,   2.3382954E-02,   2.2384973E-02
     +,   2.1167239E-02,   1.9730231E-02,   1.8152429E-02
     +,   1.6560651E-02,   1.5068251E-02,   1.3732285E-02
     +,   1.2554818E-02,   1.1511322E-02,   1.0576966E-02
     +,   9.7355107E-03,   8.9766383E-03,   8.2923137E-03
     +,   7.6768701E-03,   7.1289488E-03,   6.6515910E-03
     +,   6.2493812E-03,   5.9242547E-03,   5.6724446E-03
     +,   5.4838476E-03,   5.3435341E-03,   5.2343491E-03
     +,   5.1395353E-03,   5.0447001E-03,   4.9389279E-03
     +,   4.8151407E-03,   4.6700155E-03,   4.5035644E-03
     +,   4.3184953E-03,   4.1194656E-03,   3.9122514E-03
     +,   3.7029895E-03,   3.4974893E-03,   3.3007036E-03
     +,   3.1164642E-03,   2.9473684E-03,   2.7948106E-03
     +,   2.6591541E-03,   2.5399528E-03,   2.4361555E-03
     +,   2.3463166E-03,   2.2687789E-03,   2.2017942E-03
     +,   2.1436187E-03,   2.0925589E-03,   2.0470107E-03
     +,   2.0054760E-03,   1.9665624E-03,   1.9289870E-03
     +,   1.8915792E-03,   1.8532983E-03,   1.8132386E-03
     +,   1.7706398E-03,   1.7249153E-03,   1.6756572E-03
     +,   1.6226403E-03,   1.5658307E-03,   1.5053818E-03
     +,   1.4416145E-03,   1.3749956E-03,   1.3061091E-03
     +,   1.2356327E-03,   1.1642943E-03,   1.0928370E-03
     +,   1.0219887E-03,   9.5243938E-04,   8.8480493E-04
     +,   8.1961654E-04,   7.5731211E-04,   6.9822668E-04
     +,   6.4258935E-04,   5.9053407E-04,   5.4210814E-04
     +,   4.9728283E-04,   4.5596270E-04,   4.1800248E-04
     +,   3.8322300E-04,   3.5141912E-04,   3.2237099E-04
     +,   2.9585380E-04,   2.7164858E-04,   2.4954186E-04
     +,   2.2933297E-04,   2.1083758E-04,   1.9388708E-04
     +,   1.7832863E-04,   1.6402554E-04,   1.5085758E-04
     +,   1.3871837E-04,   1.2751350E-04,   1.1716013E-04
     +,   1.0758580E-04,   9.8726858E-05,   9.0526170E-05
     +,   8.2933133E-05,   7.5903277E-05,   6.9395865E-05
     +,   6.3374122E-05,   5.7804951E-05,   5.2658019E-05
     +,   4.7905040E-05,   4.3519867E-05,   3.9478444E-05
     +,   3.5758254E-05,   3.2337946E-05,   2.9197477E-05
     +,   2.6318157E-05,   2.3682323E-05,   2.1273090E-05
     +,   1.9074529E-05,   1.7071765E-05,   1.5250528E-05
     +,   1.3597341E-05,   1.2099575E-05,   1.0745292E-05
     +,   9.5231480E-06,   8.4224694E-06,   7.4332947E-06
     +,   6.5462609E-06,   5.7525363E-06,   5.0438703E-06
     +,   4.4126105E-06,   3.8516241E-06,   3.3542453E-06
     +,   2.9143062E-06,   2.5261427E-06,   2.1844946E-06
     +,   1.8845283E-06,   1.6218316E-06,   1.3923684E-06
     +,   1.1924434E-06,   1.0187009E-06,   8.6811332E-07
     +,   7.3794325E-07,   6.2571695E-07,   5.2921672E-07
     +,   4.4646711E-07,   3.7569586E-07,   3.1533699E-07
     +,   2.6399533E-07,   2.2044574E-07,   1.8360446E-07
     +,   1.5252570E-07,   1.2637852E-07,   1.0444244E-07
     +,   8.6088775E-08,   7.0775961E-08,   5.8035024E-08
     +,   4.7463029E-08,   3.8715601E-08,   3.1497411E-08
     +,   2.5558007E-08,   2.0684048E-08,   1.6695756E-08
     +,   1.3440995E-08,   1.0792392E-08,   8.6428642E-09
     +,   6.9033192E-09,   5.4993485E-09,   4.3694235E-09
     +,   3.4624996E-09,   2.7366207E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt60 = Yx/0.281489361702128
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5346492E-05,   7.8263940E-05
     +,   8.1220780E-05,   8.4210464E-05,   8.7226319E-05
     +,   9.0261456E-05,   9.3309005E-05,   9.6362048E-05
     +,   9.9413774E-05,   1.0245766E-04,   1.0548728E-04
     +,   1.0849666E-04,   1.1148018E-04,   1.1443278E-04
     +,   1.1734998E-04,   1.2022795E-04,   1.2306361E-04
     +,   1.2585468E-04,   1.2859979E-04,   1.3129832E-04
     +,   1.3395080E-04,   1.3655864E-04,   1.3912415E-04
     +,   1.4165101E-04,   1.4414340E-04,   1.4660686E-04
     +,   1.4904774E-04,   1.5147329E-04,   1.5389154E-04
     +,   1.5631141E-04,   1.5874235E-04,   1.6119448E-04
     +,   1.6367830E-04,   1.6620470E-04,   1.6878480E-04
     +,   1.7142968E-04,   1.7415061E-04,   1.7695862E-04
     +,   1.7986466E-04,   1.8287922E-04,   1.8601288E-04
     +,   1.8927567E-04,   1.9267765E-04,   1.9622882E-04
     +,   1.9993936E-04,   2.0382008E-04,   2.0788259E-04
     +,   2.1213999E-04,   2.1660747E-04,   2.2130298E-04
     +,   2.2624814E-04,   2.3146960E-04,   2.3699969E-04
     +,   2.4287913E-04,   2.4915705E-04,   2.5589450E-04
     +,   2.6316624E-04,   2.7106347E-04,   2.7969698E-04
     +,   2.8920121E-04,   2.9973831E-04,   3.1150377E-04
     +,   3.2473099E-04,   3.3970055E-04,   3.5674681E-04
     +,   3.7626619E-04,   3.9873077E-04,   4.2469415E-04
     +,   4.5480838E-04,   4.8982725E-04,   5.3062139E-04
     +,   5.7817134E-04,   6.3357258E-04,   6.9800590E-04
     +,   7.7271671E-04,   8.5896411E-04,   9.5794047E-04
     +,   1.0706908E-03,   1.1980201E-03,   1.3403856E-03
     +,   1.4978009E-03,   1.6698285E-03,   1.8555700E-03
     +,   2.0538485E-03,   2.2633947E-03,   2.4832382E-03
     +,   2.7130183E-03,   2.9533580E-03,   3.2059455E-03
     +,   3.4734381E-03,   3.7589294E-03,   4.0651229E-03
     +,   4.3933787E-03,   4.7428492E-03,   5.1099532E-03
     +,   5.4883924E-03,   5.8699339E-03,   6.2456424E-03
     +,   6.6077276E-03,   6.9514010E-03,   7.2766775E-03
     +,   7.5894278E-03,   7.9013743E-03,   8.2286531E-03
     +,   8.5891727E-03,   8.9989668E-03,   9.4681680E-03
     +,   9.9974899E-03,   1.0575975E-02,   1.1181686E-02
     +,   1.1786254E-02,   1.2363307E-02,   1.2897601E-02
     +,   1.3391597E-02,   1.3865969E-02,   1.4354521E-02
     +,   1.4895345E-02,   1.5521744E-02,   1.6254671E-02
     +,   1.7098445E-02,   1.8038450E-02,   1.9040283E-02
     +,   2.0048823E-02,   2.0987684E-02,   2.1766927E-02
     +,   2.2310715E-02,   2.2608005E-02,   2.2759816E-02
     +,   2.2977216E-02,   2.3495896E-02,   2.4437280E-02
     +,   2.5715251E-02,   2.7100828E-02,   2.8437238E-02
     +,   2.9817944E-02,   3.1512745E-02,   3.3660501E-02
     +,   3.6006868E-02,   3.7944697E-02,   3.8839396E-02
     +,   3.8374677E-02,   3.6669414E-02,   3.4141760E-02
     +,   3.1283628E-02,   2.8495640E-02,   2.6024345E-02
     +,   2.3970429E-02,   2.2318592E-02,   2.0971308E-02
     +,   1.9793542E-02,   1.8661622E-02,   1.7495364E-02
     +,   1.6267071E-02,   1.4996336E-02,   1.3737164E-02
     +,   1.2556604E-02,   1.1508880E-02,   1.0615870E-02
     +,   9.8639876E-03,   9.2171524E-03,   8.6356746E-03
     +,   8.0906078E-03,   7.5682122E-03,   7.0670312E-03
     +,   6.5920595E-03,   6.1497921E-03,   5.7453350E-03
     +,   5.3811450E-03,   5.0569782E-03,   4.7705011E-03
     +,   4.5180437E-03,   4.2953412E-03,   4.0980866E-03
     +,   3.9222944E-03,   3.7645099E-03,   3.6217901E-03
     +,   3.4917090E-03,   3.3723104E-03,   3.2620355E-03
     +,   3.1596473E-03,   3.0641605E-03,   2.9747898E-03
     +,   2.8908553E-03,   2.8117036E-03,   2.7366742E-03
     +,   2.6650371E-03,   2.5959646E-03,   2.5285252E-03
     +,   2.4616995E-03,   2.3944352E-03,   2.3256948E-03
     +,   2.2545299E-03,   2.1801637E-03,   2.1020437E-03
     +,   2.0198796E-03,   1.9336648E-03,   1.8436718E-03
     +,   1.7504219E-03,   1.6546290E-03,   1.5571496E-03
     +,   1.4589285E-03,   1.3609356E-03,   1.2641072E-03
     +,   1.1693143E-03,   1.0773382E-03,   9.8883454E-04
     +,   9.0433256E-04,   8.2423794E-04,   7.4883294E-04
     +,   6.7828025E-04,   6.1264256E-04,   5.5189937E-04
     +,   4.9595837E-04,   4.4466625E-04,   3.9782721E-04
     +,   3.5521665E-04,   3.1658940E-04,   2.8168512E-04
     +,   2.5023913E-04,   2.2199099E-04,   1.9668149E-04
     +,   1.7406049E-04,   1.5388992E-04,   1.3594342E-04
     +,   1.2000671E-04,   1.0587960E-04,   9.3377035E-05
     +,   8.2328064E-05,   7.2574920E-05,   6.3973894E-05
     +,   5.6395034E-05,   4.9720933E-05,   4.3845772E-05
     +,   3.8674913E-05,   3.4124638E-05,   3.0120224E-05
     +,   2.6595621E-05,   2.3492863E-05,   2.0760874E-05
     +,   1.8354594E-05,   1.6234508E-05,   1.4366066E-05
     +,   1.2718943E-05,   1.1266392E-05,   9.9849594E-06
     +,   8.8541155E-06,   7.8557905E-06,   6.9740340E-06
     +,   6.1948158E-06,   5.5058645E-06,   4.8963088E-06
     +,   4.3565965E-06,   3.8783610E-06,   3.4542475E-06
     +,   3.0777710E-06,   2.7432475E-06,   2.4457167E-06
     +,   2.1808303E-06,   1.9447673E-06,   1.7341833E-06
     +,   1.5461696E-06,   1.3781765E-06,   1.2279621E-06
     +,   1.0935645E-06,   9.7327313E-07,   8.6557338E-07
     +,   7.6913238E-07,   6.8278018E-07,   6.0547961E-07
     +,   5.3630612E-07,   4.7443694E-07,   4.1914174E-07
     +,   3.6976579E-07,   3.2571833E-07,   2.8646764E-07
     +,   2.5153813E-07,   2.2049468E-07,   1.9294809E-07
     +,   1.6854146E-07,   1.4695433E-07,   1.2789334E-07
     +,   1.1109448E-07,   9.6316199E-08,   8.3341497E-08
     +,   7.1972096E-08,   6.2030182E-08,   5.3354199E-08
     +,   4.5798515E-08,   3.9232869E-08,   3.3539390E-08
     +,   2.8613211E-08,   2.4359917E-08,   2.0695897E-08
     +,   1.7546251E-08,   1.4844949E-08,   1.2533135E-08
     +,   1.0559197E-08,   8.8774010E-09,   7.4477979E-09
     +,   6.2352159E-09,   5.2090727E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt65 = Yx/0.336875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0927360E-05,   4.2475949E-05
     +,   4.4066670E-05,   4.5700643E-05,   4.7379086E-05
     +,   4.9103386E-05,   5.0875013E-05,   5.2695632E-05
     +,   5.4566990E-05,   5.6491121E-05,   5.8470083E-05
     +,   6.0506201E-05,   6.2601925E-05,   6.4759901E-05
     +,   6.6982946E-05,   6.9274050E-05,   7.1636336E-05
     +,   7.4073148E-05,   7.6587923E-05,   7.9184261E-05
     +,   8.1865823E-05,   8.4636376E-05,   8.7499677E-05
     +,   9.0459725E-05,   9.3520146E-05,   9.6684824E-05
     +,   9.9957382E-05,   1.0334132E-04,   1.0683995E-04
     +,   1.1045627E-04,   1.1419302E-04,   1.1805258E-04
     +,   1.2203692E-04,   1.2614753E-04,   1.3038542E-04
     +,   1.3475111E-04,   1.3924448E-04,   1.4386495E-04
     +,   1.4861161E-04,   1.5348263E-04,   1.5847625E-04
     +,   1.6359017E-04,   1.6882202E-04,   1.7416956E-04
     +,   1.7963084E-04,   1.8520463E-04,   1.9089054E-04
     +,   1.9668984E-04,   2.0260579E-04,   2.0864433E-04
     +,   2.1481466E-04,   2.2113015E-04,   2.2760901E-04
     +,   2.3427594E-04,   2.4116138E-04,   2.4830434E-04
     +,   2.5575192E-04,   2.6356068E-04,   2.7179698E-04
     +,   2.8053729E-04,   2.8986836E-04,   2.9988645E-04
     +,   3.1069628E-04,   3.2241031E-04,   3.3514653E-04
     +,   3.4902376E-04,   3.6416174E-04,   3.8067382E-04
     +,   3.9866622E-04,   4.1822926E-04,   4.3943804E-04
     +,   4.6234202E-04,   4.8696759E-04,   5.1330897E-04
     +,   5.4133078E-04,   5.7096709E-04,   6.0212036E-04
     +,   6.3466653E-04,   6.6846621E-04,   7.0336927E-04
     +,   7.3922734E-04,   7.7591732E-04,   8.1335194E-04
     +,   8.5151283E-04,   8.9046365E-04,   9.3038770E-04
     +,   9.7159977E-04,   1.0145805E-03,   1.0599808E-03
     +,   1.1086466E-03,   1.1616240E-03,   1.2201635E-03
     +,   1.2857408E-03,   1.3600802E-03,   1.4452105E-03
     +,   1.5435257E-03,   1.6579232E-03,   1.7919154E-03
     +,   1.9497944E-03,   2.1366565E-03,   2.3583670E-03
     +,   2.6211552E-03,   2.9310223E-03,   3.2926595E-03
     +,   3.7083218E-03,   4.1766446E-03,   4.6918881E-03
     +,   5.2439980E-03,   5.8197174E-03,   6.4046602E-03
     +,   6.9862735E-03,   7.5573791E-03,   8.1190290E-03
     +,   8.6819790E-03,   9.2647830E-03,   9.8883780E-03
     +,   1.0567915E-02,   1.1306831E-02,   1.2097134E-02
     +,   1.2927686E-02,   1.3793300E-02,   1.4695827E-02
     +,   1.5634550E-02,   1.6597833E-02,   1.7573021E-02
     +,   1.8577568E-02,   1.9687964E-02,   2.1029636E-02
     +,   2.2712676E-02,   2.4746096E-02,   2.7000893E-02
     +,   2.9246222E-02,   3.1199256E-02,   3.2548070E-02
     +,   3.3071544E-02,   3.2944843E-02,   3.2902293E-02
     +,   3.3772346E-02,   3.5665829E-02,   3.7847973E-02
     +,   3.9644174E-02,   4.1253779E-02,   4.3294545E-02
     +,   4.5709096E-02,   4.7691733E-02,   4.8716001E-02
     +,   4.9047299E-02,   4.9058288E-02,   4.8456896E-02
     +,   4.6468243E-02,   4.2689037E-02,   3.7644889E-02
     +,   3.2504711E-02,   2.8254004E-02,   2.5123641E-02
     +,   2.2742631E-02,   2.0668669E-02,   1.8698059E-02
     +,   1.6832629E-02,   1.5140338E-02,   1.3673563E-02
     +,   1.2450343E-02,   1.1459793E-02,   1.0673886E-02
     +,   1.0059106E-02,   9.5829964E-03,   9.2149060E-03
     +,   8.9245904E-03,   8.6817015E-03,   8.4566921E-03
     +,   8.2224505E-03,   7.9564098E-03,   7.6427730E-03
     +,   7.2745439E-03,   6.8545332E-03,   6.3945558E-03
     +,   5.9130290E-03,   5.4312870E-03,   4.9696206E-03
     +,   4.5440076E-03,   4.1643563E-03,   3.8342306E-03
     +,   3.5518149E-03,   3.3116033E-03,   3.1063207E-03
     +,   2.9285077E-03,   2.7715934E-03,   2.6303909E-03
     +,   2.5011678E-03,   2.3814156E-03,   2.2694666E-03
     +,   2.1641490E-03,   2.0645324E-03,   1.9697610E-03
     +,   1.8789829E-03,   1.7913711E-03,   1.7061722E-03
     +,   1.6227573E-03,   1.5406623E-03,   1.4596136E-03
     +,   1.3795336E-03,   1.3005115E-03,   1.2227646E-03
     +,   1.1466002E-03,   1.0723757E-03,   1.0004472E-03
     +,   9.3114318E-04,   8.6474622E-04,   8.0147461E-04
     +,   7.4147107E-04,   6.8480935E-04,   6.3150347E-04
     +,   5.8151223E-04,   5.3474674E-04,   4.9108674E-04
     +,   4.5039222E-04,   4.1251097E-04,   3.7728311E-04
     +,   3.4455091E-04,   3.1416563E-04,   2.8598373E-04
     +,   2.5987165E-04,   2.3570778E-04,   2.1337970E-04
     +,   1.9278229E-04,   1.7381758E-04,   1.5639482E-04
     +,   1.4042767E-04,   1.2583219E-04,   1.1252719E-04
     +,   1.0043450E-04,   8.9477289E-05,   7.9579528E-05
     +,   7.0666676E-05,   6.2666753E-05,   5.5508743E-05
     +,   4.9123901E-05,   4.3446416E-05,   3.8413171E-05
     +,   3.3963825E-05,   3.0041405E-05,   2.6592696E-05
     +,   2.3568042E-05,   2.0921256E-05,   1.8609860E-05
     +,   1.6595141E-05,   1.4841868E-05,   1.3318037E-05
     +,   1.1994899E-05,   1.0846837E-05,   9.8508935E-06
     +,   8.9867290E-06,   8.2364468E-06,   7.5842895E-06
     +,   7.0164124E-06,   6.5207469E-06,   6.0868219E-06
     +,   5.7055663E-06,   5.3691219E-06,   5.0707245E-06
     +,   4.8045958E-06,   4.5657916E-06,   4.3500822E-06
     +,   4.1538833E-06,   3.9741763E-06,   3.8083983E-06
     +,   3.6544031E-06,   3.5104008E-06,   3.3749022E-06
     +,   3.2466635E-06,   3.1246605E-06,   3.0080566E-06
     +,   2.8961729E-06,   2.7884482E-06,   2.6844309E-06
     +,   2.5837674E-06,   2.4861672E-06,   2.3914099E-06
     +,   2.2993120E-06,   2.2097433E-06,   2.1225919E-06
     +,   2.0377827E-06,   1.9552499E-06,   1.8749510E-06
     +,   1.7968471E-06,   1.7209159E-06,   1.6471344E-06
     +,   1.5754812E-06,   1.5059485E-06,   1.4385154E-06
     +,   1.3731725E-06,   1.3099011E-06,   1.2486887E-06
     +,   1.1895129E-06,   1.1323580E-06,   1.0771987E-06
     +,   1.0240135E-06,   9.7277280E-07,   9.2345135E-07
     +,   8.7601524E-07,   8.3043466E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt70 = Yx/0.384571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6817743E-05,   1.7763890E-05
     +,   1.8754235E-05,   1.9789632E-05,   2.0870842E-05
     +,   2.1998558E-05,   2.3173363E-05,   2.4395753E-05
     +,   2.5666104E-05,   2.6984742E-05,   2.8351835E-05
     +,   2.9767438E-05,   3.1231524E-05,   3.2743948E-05
     +,   3.4304438E-05,   3.5912610E-05,   3.7567985E-05
     +,   3.9269962E-05,   4.1017825E-05,   4.2810774E-05
     +,   4.4647888E-05,   4.6528137E-05,   4.8450398E-05
     +,   5.0413575E-05,   5.2416257E-05,   5.4457232E-05
     +,   5.6535049E-05,   5.8648322E-05,   6.0795592E-05
     +,   6.2975429E-05,   6.5186432E-05,   6.7427252E-05
     +,   6.9696645E-05,   7.1993541E-05,   7.4316951E-05
     +,   7.6666263E-05,   7.9041100E-05,   8.1441416E-05
     +,   8.3867773E-05,   8.6321044E-05,   8.8802968E-05
     +,   9.1315866E-05,   9.3862953E-05,   9.6448377E-05
     +,   9.9077421E-05,   1.0175652E-04,   1.0449351E-04
     +,   1.0729763E-04,   1.1017978E-04,   1.1315254E-04
     +,   1.1623036E-04,   1.1942960E-04,   1.2276854E-04
     +,   1.2626786E-04,   1.2994978E-04,   1.3383912E-04
     +,   1.3796230E-04,   1.4234774E-04,   1.4702548E-04
     +,   1.5202693E-04,   1.5738445E-04,   1.6313113E-04
     +,   1.6929983E-04,   1.7592327E-04,   1.8303306E-04
     +,   1.9065823E-04,   1.9882622E-04,   2.0756018E-04
     +,   2.1688032E-04,   2.2680119E-04,   2.3733375E-04
     +,   2.4848239E-04,   2.6024840E-04,   2.7262693E-04
     +,   2.8561102E-04,   2.9919244E-04,   3.1336254E-04
     +,   3.2811638E-04,   3.4345768E-04,   3.5940224E-04
     +,   3.7598217E-04,   3.9325489E-04,   4.1130593E-04
     +,   4.3025924E-04,   4.5027930E-04,   4.7158112E-04
     +,   4.9442874E-04,   5.1914301E-04,   5.4609519E-04
     +,   5.7570735E-04,   6.0844445E-04,   6.4480089E-04
     +,   6.8528758E-04,   7.3041930E-04,   7.8069372E-04
     +,   8.3656493E-04,   8.9843699E-04,   9.6662599E-04
     +,   1.0413574E-03,   1.1227319E-03,   1.2107305E-03
     +,   1.3051840E-03,   1.4058010E-03,   1.5121482E-03
     +,   1.6236925E-03,   1.7398144E-03,   1.8598216E-03
     +,   1.9829846E-03,   2.1085944E-03,   2.2360655E-03
     +,   2.3651458E-03,   2.4963536E-03,   2.6315718E-03
     +,   2.7749026E-03,   2.9335874E-03,   3.1189257E-03
     +,   3.3467941E-03,   3.6375481E-03,   4.0145712E-03
     +,   4.5012194E-03,   5.1159714E-03,   5.8669019E-03
     +,   6.7477264E-03,   7.7377059E-03,   8.8055013E-03
     +,   9.9153779E-03,   1.1035425E-02,   1.2150136E-02
     +,   1.3280547E-02,   1.4498306E-02,   1.5904577E-02
     +,   1.7552618E-02,   1.9354003E-02,   2.1072183E-02
     +,   2.2495009E-02,   2.3704389E-02,   2.5140535E-02
     +,   2.7243858E-02,   3.0010989E-02,   3.3086065E-02
     +,   3.6254525E-02,   3.9509021E-02,   4.2716928E-02
     +,   4.5674693E-02,   4.8320178E-02,   5.0664607E-02
     +,   5.2799918E-02,   5.5119067E-02,   5.8235724E-02
     +,   6.1755877E-02,   6.3690647E-02,   6.2753327E-02
     +,   6.0197297E-02,   5.7538599E-02,   5.4500394E-02
     +,   5.0765306E-02,   4.7268447E-02,   4.4518393E-02
     +,   4.1677754E-02,   3.7869889E-02,   3.3106811E-02
     +,   2.8057564E-02,   2.3574021E-02,   2.0242499E-02
     +,   1.8081518E-02,   1.6676594E-02,   1.5570335E-02
     +,   1.4495044E-02,   1.3374287E-02,   1.2246154E-02
     +,   1.1193832E-02,   1.0288514E-02,   9.5524751E-03
     +,   8.9563038E-03,   8.4437719E-03,   7.9625864E-03
     +,   7.4829003E-03,   6.9990973E-03,   6.5206927E-03
     +,   6.0609141E-03,   5.6292182E-03,   5.2293120E-03
     +,   4.8608258E-03,   4.5220610E-03,   4.2118225E-03
     +,   3.9298460E-03,   3.6761656E-03,   3.4503457E-03
     +,   3.2509670E-03,   3.0755482E-03,   2.9207547E-03
     +,   2.7828282E-03,   2.6579958E-03,   2.5427872E-03
     +,   2.4342381E-03,   2.3299847E-03,   2.2282817E-03
     +,   2.1279440E-03,   2.0282618E-03,   1.9289220E-03
     +,   1.8299164E-03,   1.7314539E-03,   1.6338753E-03
     +,   1.5376016E-03,   1.4430879E-03,   1.3507712E-03
     +,   1.2610517E-03,   1.1742831E-03,   1.0907567E-03
     +,   1.0106950E-03,   9.3425519E-04,   8.6154137E-04
     +,   7.9260150E-04,   7.2743290E-04,   6.6599640E-04
     +,   6.0822623E-04,   5.5403408E-04,   5.0331507E-04
     +,   4.5595563E-04,   4.1184356E-04,   3.7086059E-04
     +,   3.3289002E-04,   2.9781830E-04,   2.6553209E-04
     +,   2.3591549E-04,   2.0885082E-04,   1.8421959E-04
     +,   1.6189924E-04,   1.4176172E-04,   1.2367558E-04
     +,   1.0750721E-04,   9.3120849E-05,   8.0378755E-05
     +,   6.9144189E-05,   5.9283699E-05,   5.0666556E-05
     +,   4.3167380E-05,   3.6667618E-05,   3.1055948E-05
     +,   2.6228588E-05,   2.2090213E-05,   1.8554319E-05
     +,   1.5542751E-05,   1.2985327E-05,   1.0819728E-05
     +,   8.9910627E-06,   7.4511422E-06,   6.1577944E-06
     +,   5.0744015E-06,   4.1693861E-06,   3.4154273E-06
     +,   2.7890619E-06,   2.2702302E-06,   1.8417803E-06
     +,   1.4890647E-06,   1.1996353E-06,   9.6295025E-07
     +,   7.7008553E-07,   6.1349539E-07,   4.8683336E-07
     +,   3.8478149E-07,   3.0288942E-07,   2.3744147E-07
     +,   1.8535370E-07,   1.4407887E-07,   1.1151361E-07
     +,   8.5932967E-08,   6.5929839E-08,   5.0359514E-08
     +,   3.8294878E-08,   2.8989572E-08,   2.1846303E-08
     +,   1.6388617E-08,   1.2238328E-08,   9.0971417E-09
     +,   6.7311960E-09,   4.9575695E-09,   3.6344465E-09
     +,   2.6520814E-09,   1.9262782E-09,   1.3925853E-09
     +,   1.0020789E-09,   7.1770551E-10,   5.1163723E-10
     +,   3.6302630E-10,   2.5637892E-10,   1.8021375E-10
     +,   1.2608081E-10,   8.7795972E-11,   6.0848999E-11
     +,   4.1975572E-11,   2.8819849E-11,   1.9694781E-11
     +,   1.3395674E-11,   9.0686703E-12,   6.1105296E-12
     +,   4.0981229E-12,   2.7356099E-12,   1.8176216E-12
     +,   1.2020668E-12,   7.9132030E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt75 = Yx/0.4158
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4382110E-05,   1.4980979E-05
     +,   1.5594173E-05,   1.6221347E-05,   1.6862110E-05
     +,   1.7516053E-05,   1.8182716E-05,   1.8861625E-05
     +,   1.9552273E-05,   2.0254172E-05,   2.0966776E-05
     +,   2.1689571E-05,   2.2422029E-05,   2.3163662E-05
     +,   2.3913997E-05,   2.4672599E-05,   2.5439102E-05
     +,   2.6213191E-05,   2.6994650E-05,   2.7783361E-05
     +,   2.8579319E-05,   2.9382656E-05,   3.0193667E-05
     +,   3.1012863E-05,   3.1840871E-05,   3.2678632E-05
     +,   3.3527271E-05,   3.4388224E-05,   3.5263187E-05
     +,   3.6154186E-05,   3.7063579E-05,   3.7994098E-05
     +,   3.8948820E-05,   3.9931248E-05,   4.0945273E-05
     +,   4.1995208E-05,   4.3085813E-05,   4.4222244E-05
     +,   4.5410216E-05,   4.6655678E-05,   4.7965234E-05
     +,   4.9345766E-05,   5.0804632E-05,   5.2349558E-05
     +,   5.3988664E-05,   5.5730405E-05,   5.7583555E-05
     +,   5.9557176E-05,   6.1660583E-05,   6.3903288E-05
     +,   6.6295033E-05,   6.8845598E-05,   7.1564915E-05
     +,   7.4463089E-05,   7.7549907E-05,   8.0835547E-05
     +,   8.4329884E-05,   8.8042849E-05,   9.1984250E-05
     +,   9.6163822E-05,   1.0059128E-04,   1.0527628E-04
     +,   1.1022831E-04,   1.1545721E-04,   1.2097298E-04
     +,   1.2678528E-04,   1.3290484E-04,   1.3934207E-04
     +,   1.4610861E-04,   1.5321594E-04,   1.6067717E-04
     +,   1.6850526E-04,   1.7671498E-04,   1.8532104E-04
     +,   1.9433962E-04,   2.0378790E-04,   2.1368302E-04
     +,   2.2404257E-04,   2.3488516E-04,   2.4622938E-04
     +,   2.5809297E-04,   2.7049446E-04,   2.8345041E-04
     +,   2.9697869E-04,   3.1109434E-04,   3.2581386E-04
     +,   3.4115135E-04,   3.5712210E-04,   3.7373946E-04
     +,   3.9101770E-04,   4.0897127E-04,   4.2761260E-04
     +,   4.4695390E-04,   4.6700734E-04,   4.8778360E-04
     +,   5.0928938E-04,   5.3153164E-04,   5.5451214E-04
     +,   5.7823432E-04,   6.0269888E-04,   6.2791299E-04
     +,   6.5388967E-04,   6.8066141E-04,   7.0828473E-04
     +,   7.3685916E-04,   7.6654518E-04,   7.9758378E-04
     +,   8.3032978E-04,   8.6528604E-04,   9.0314285E-04
     +,   9.4480912E-04,   9.9145365E-04,   1.0445078E-03
     +,   1.1056627E-03,   1.1767945E-03,   1.2598681E-03
     +,   1.3567476E-03,   1.4689998E-03,   1.5976381E-03
     +,   1.7429481E-03,   1.9043749E-03,   2.0805751E-03
     +,   2.2696690E-03,   2.4697252E-03,   2.6793438E-03
     +,   2.8982405E-03,   3.1277793E-03,   3.3710923E-03
     +,   3.6329560E-03,   3.9193090E-03,   4.2370772E-03
     +,   4.5947148E-03,   5.0043608E-03,   5.4852180E-03
     +,   6.0674576E-03,   6.7940257E-03,   7.7181105E-03
     +,   8.8939741E-03,   1.0360057E-02,   1.2117829E-02
     +,   1.4124805E-02,   1.6339244E-02,   1.8830756E-02
     +,   2.1845885E-02,   2.5607666E-02,   2.9932598E-02
     +,   3.4342386E-02,   3.8815938E-02,   4.3705940E-02
     +,   4.8333615E-02,   5.1121291E-02,   5.2311193E-02
     +,   5.4413304E-02,   5.8461417E-02,   6.3189097E-02
     +,   6.8379514E-02,   7.3847428E-02,   7.6655261E-02
     +,   7.5870052E-02,   7.4533828E-02,   7.2488137E-02
     +,   6.9035508E-02,   6.5895617E-02,   6.1806150E-02
     +,   5.5011272E-02,   4.7339838E-02,   4.1310530E-02
     +,   3.7251841E-02,   3.4120128E-02,   3.1077351E-02
     +,   2.7906088E-02,   2.4713691E-02,   2.1660063E-02
     +,   1.8850787E-02,   1.6347568E-02,   1.4204009E-02
     +,   1.2453949E-02,   1.1086646E-02,   1.0052137E-02
     +,   9.2831329E-03,   8.7105511E-03,   8.2704872E-03
     +,   7.9082549E-03,   7.5815632E-03,   7.2618993E-03
     +,   6.9341259E-03,   6.5941690E-03,   6.2456732E-03
     +,   5.8962652E-03,   5.5545652E-03,   5.2282102E-03
     +,   4.9231793E-03,   4.6435948E-03,   4.3916204E-03
     +,   4.1671754E-03,   3.9678221E-03,   3.7888591E-03
     +,   3.6238749E-03,   3.4656825E-03,   3.3073912E-03
     +,   3.1433727E-03,   2.9698627E-03,   2.7851830E-03
     +,   2.5896458E-03,   2.3852400E-03,   2.1751490E-03
     +,   1.9632876E-03,   1.7538710E-03,   1.5509973E-03
     +,   1.3583102E-03,   1.1787725E-03,   1.0145310E-03
     +,   8.6685148E-04,   7.3614728E-04,   6.2209956E-04
     +,   5.2381511E-04,   4.3999148E-04,   3.6908340E-04
     +,   3.0945975E-04,   2.5952453E-04,   2.1778778E-04
     +,   1.8292012E-04,   1.5377396E-04,   1.2937971E-04
     +,   1.0893081E-04,   9.1764799E-05,   7.7340752E-05
     +,   6.5215463E-05,   5.5023433E-05,   4.6461755E-05
     +,   3.9277722E-05,   3.3258173E-05,   2.8221828E-05
     +,   2.4014193E-05,   2.0503594E-05,   1.7577020E-05
     +,   1.5138011E-05,   1.3104535E-05,   1.1406983E-05
     +,   9.9864592E-06,   8.7935632E-06,   7.7871500E-06
     +,   6.9331022E-06,   6.2032905E-06,   5.5747296E-06
     +,   5.0288077E-06,   4.5505171E-06,   4.1278140E-06
     +,   3.7511168E-06,   3.4128775E-06,   3.1071163E-06
     +,   2.8291331E-06,   2.5752531E-06,   2.3425816E-06
     +,   2.1288095E-06,   1.9320919E-06,   1.7509396E-06
     +,   1.5841201E-06,   1.4305774E-06,   1.2893951E-06
     +,   1.1597662E-06,   1.0409545E-06,   9.3226828E-07
     +,   8.3305667E-07,   7.4270952E-07,   6.6063058E-07
     +,   5.8624869E-07,   5.1901742E-07,   4.5840986E-07
     +,   4.0391669E-07,   3.5505013E-07,   3.1134840E-07
     +,   2.7237201E-07,   2.3770230E-07,   2.0694569E-07
     +,   1.7973579E-07,   1.5572672E-07,   1.3460019E-07
     +,   1.1605865E-07,   9.9830373E-08,   8.5663714E-08
     +,   7.3330369E-08,   6.2620913E-08,   5.3346763E-08
     +,   4.5336197E-08,   3.8435697E-08,   3.2506883E-08
     +,   2.7426072E-08,   2.3083690E-08,   1.9381835E-08
     +,   1.6234440E-08,   1.3565250E-08,   1.1307625E-08
     +,   9.4029211E-09,   7.8002289E-09,   6.4550552E-09
     +,   5.3289972E-09,   4.3887294E-09,   3.6056664E-09
     +,   2.9551521E-09,   2.4161702E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt80 = Yx/0.44324
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3232540E-06,   4.4826461E-06
     +,   4.6438195E-06,   4.8065872E-06,   4.9707573E-06
     +,   5.1361362E-06,   5.3025269E-06,   5.4697343E-06
     +,   5.6375593E-06,   5.8058172E-06,   5.9743174E-06
     +,   6.1428800E-06,   6.3113334E-06,   6.4795177E-06
     +,   6.6472849E-06,   6.8145077E-06,   6.9810694E-06
     +,   7.1468830E-06,   7.3118808E-06,   7.4760246E-06
     +,   7.6393098E-06,   7.8017620E-06,   7.9634447E-06
     +,   8.1244762E-06,   8.2850001E-06,   8.4452322E-06
     +,   8.6054324E-06,   8.7659246E-06,   8.9270989E-06
     +,   9.0894164E-06,   9.2534165E-06,   9.4197212E-06
     +,   9.5890427E-06,   9.7621878E-06,   9.9400686E-06
     +,   1.0123704E-05,   1.0314233E-05,   1.0512919E-05
     +,   1.0721167E-05,   1.0940506E-05,   1.1172637E-05
     +,   1.1419407E-05,   1.1682839E-05,   1.1965138E-05
     +,   1.2268703E-05,   1.2596137E-05,   1.2950267E-05
     +,   1.3334148E-05,   1.3751090E-05,   1.4204675E-05
     +,   1.4698763E-05,   1.5237542E-05,   1.5825521E-05
     +,   1.6467602E-05,   1.7169015E-05,   1.7935499E-05
     +,   1.8773195E-05,   1.9688758E-05,   2.0689378E-05
     +,   2.1782818E-05,   2.2977458E-05,   2.4282341E-05
     +,   2.5707119E-05,   2.7262238E-05,   2.8958926E-05
     +,   3.0808947E-05,   3.2825072E-05,   3.5020501E-05
     +,   3.7409402E-05,   4.0006234E-05,   4.2826305E-05
     +,   4.5884932E-05,   4.9198086E-05,   5.2781314E-05
     +,   5.6650315E-05,   6.0820421E-05,   6.5305954E-05
     +,   7.0120172E-05,   7.5275355E-05,   8.0782178E-05
     +,   8.6648834E-05,   9.2882205E-05,   9.9485980E-05
     +,   1.0646231E-04,   1.1381009E-04,   1.2152699E-04
     +,   1.2960790E-04,   1.3804760E-04,   1.4683945E-04
     +,   1.5597847E-04,   1.6546196E-04,   1.7529045E-04
     +,   1.8547036E-04,   1.9601645E-04,   2.0695398E-04
     +,   2.1831908E-04,   2.3016366E-04,   2.4255387E-04
     +,   2.5557404E-04,   2.6932327E-04,   2.8391823E-04
     +,   2.9948636E-04,   3.1616606E-04,   3.3409704E-04
     +,   3.5341669E-04,   3.7425008E-04,   3.9669970E-04
     +,   4.2083635E-04,   4.4669287E-04,   4.7425562E-04
     +,   5.0345861E-04,   5.3419225E-04,   5.6630373E-04
     +,   5.9962453E-04,   6.3398888E-04,   6.6928280E-04
     +,   7.0548273E-04,   7.4272329E-04,   7.8134268E-04
     +,   8.2194147E-04,   8.6540839E-04,   9.1291079E-04
     +,   9.6584507E-04,   1.0257341E-03,   1.0940628E-03
     +,   1.1720752E-03,   1.2605891E-03,   1.3598162E-03
     +,   1.4693293E-03,   1.5881400E-03,   1.7150426E-03
     +,   1.8491170E-03,   1.9905018E-03,   2.1411867E-03
     +,   2.3057798E-03,   2.4918506E-03,   2.7095391E-03
     +,   2.9701991E-03,   3.2840483E-03,   3.6573855E-03
     +,   4.0908307E-03,   4.5806286E-03,   5.1242402E-03
     +,   5.7283523E-03,   6.4136903E-03,   7.2101946E-03
     +,   8.1426706E-03,   9.2214188E-03,   1.0461234E-02
     +,   1.1931683E-02,   1.3784347E-02,   1.6176037E-02
     +,   1.9135397E-02,   2.2603573E-02,   2.6666349E-02
     +,   3.1482946E-02,   3.6839668E-02,   4.2469159E-02
     +,   4.8972387E-02,   5.6558158E-02,   6.4111777E-02
     +,   7.1935087E-02,   8.0986232E-02,   9.0804696E-02
     +,   9.7473852E-02,   9.4910890E-02,   8.8659026E-02
     +,   8.7084964E-02,   8.5092381E-02,   8.0874428E-02
     +,   7.8385241E-02,   7.4203044E-02,   6.5531634E-02
     +,   5.4448470E-02,   4.4521146E-02,   3.7579570E-02
     +,   3.3180188E-02,   2.9727058E-02,   2.6327047E-02
     +,   2.3092626E-02,   2.0259496E-02,   1.7853301E-02
     +,   1.5770981E-02,   1.3901422E-02,   1.2220479E-02
     +,   1.0784236E-02,   9.6512279E-03,   8.8246819E-03
     +,   8.2496675E-03,   7.8464141E-03,   7.5451243E-03
     +,   7.2997948E-03,   7.0811249E-03,   6.8636970E-03
     +,   6.6208253E-03,   6.3295150E-03,   5.9791538E-03
     +,   5.5762376E-03,   5.1418673E-03,   4.7039720E-03
     +,   4.2884666E-03,   3.9127893E-03,   3.5833742E-03
     +,   3.2967739E-03,   3.0430374E-03,   2.8097618E-03
     +,   2.5857501E-03,   2.3633826E-03,   2.1395010E-03
     +,   1.9150004E-03,   1.6936368E-03,   1.4805360E-03
     +,   1.2807871E-03,   1.0984283E-03,   9.3594560E-04
     +,   7.9418632E-04,   6.7257136E-04,   5.6948297E-04
     +,   4.8271488E-04,   4.0986532E-04,   3.4860938E-04
     +,   2.9688593E-04,   2.5297748E-04,   2.1550900E-04
     +,   1.8340665E-04,   1.5584118E-04,   1.3216758E-04
     +,   1.1186968E-04,   9.4518538E-05,   7.9746118E-05
     +,   6.7228153E-05,   5.6672870E-05,   4.7815269E-05
     +,   4.0415842E-05,   3.4259894E-05,   2.9155603E-05
     +,   2.4934072E-05,   2.1448514E-05,   1.8572426E-05
     +,   1.6197895E-05,   1.4233939E-05,   1.2604694E-05
     +,   1.1247286E-05,   1.0109961E-05,   9.1504935E-06
     +,   8.3346904E-06,   7.6349361E-06,   7.0289934E-06
     +,   6.4990700E-06,   6.0310035E-06,   5.6134681E-06
     +,   5.2374589E-06,   4.8958450E-06,   4.5829656E-06
     +,   4.2943129E-06,   4.0263089E-06,   3.7761347E-06
     +,   3.5415555E-06,   3.3207821E-06,   3.1123948E-06
     +,   2.9152768E-06,   2.7285337E-06,   2.5514391E-06
     +,   2.3834039E-06,   2.2239592E-06,   2.0727020E-06
     +,   1.9292879E-06,   1.7934245E-06,   1.6648523E-06
     +,   1.5433205E-06,   1.4285946E-06,   1.3204549E-06
     +,   1.2186839E-06,   1.1230592E-06,   1.0333576E-06
     +,   9.4936257E-07,   8.7084425E-07,   7.9758092E-07
     +,   7.2933972E-07,   6.6589610E-07,   6.0701569E-07
     +,   5.5247421E-07,   5.0204051E-07,   4.5549339E-07
     +,   4.1260907E-07,   3.7317380E-07,   3.3697481E-07
     +,   3.0380568E-07,   2.7346977E-07,   2.4577318E-07
     +,   2.2053342E-07,   1.9757233E-07,   1.7672261E-07
     +,   1.5782274E-07,   1.4072197E-07,   1.2527518E-07
     +,   1.1134822E-07,   9.8812635E-08,   8.7550063E-08
     +,   7.7448270E-08,   6.8403963E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt85 = Yx/0.46172
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0448873E-06,   1.1760840E-06
     +,   1.3214606E-06,   1.4822344E-06,   1.6596869E-06
     +,   1.8551621E-06,   2.0700647E-06,   2.3058583E-06
     +,   2.5640522E-06,   2.8462212E-06,   3.1539682E-06
     +,   3.4889379E-06,   3.8528042E-06,   4.2472620E-06
     +,   4.6740156E-06,   5.1347743E-06,   5.6312347E-06
     +,   6.1650726E-06,   6.7379324E-06,   7.3514116E-06
     +,   8.0070440E-06,   8.7063017E-06,   9.4505458E-06
     +,   1.0241100E-05,   1.1079082E-05,   1.1965586E-05
     +,   1.2901515E-05,   1.3887648E-05,   1.4924620E-05
     +,   1.6012902E-05,   1.7152830E-05,   1.8344568E-05
     +,   1.9588138E-05,   2.0883412E-05,   2.2230139E-05
     +,   2.3627921E-05,   2.5076295E-05,   2.6574657E-05
     +,   2.8122457E-05,   2.9718947E-05,   3.1363536E-05
     +,   3.3055592E-05,   3.4794582E-05,   3.6580070E-05
     +,   3.8411781E-05,   4.0289644E-05,   4.2213811E-05
     +,   4.4184711E-05,   4.6203106E-05,   4.8270056E-05
     +,   5.0387069E-05,   5.2555963E-05,   5.4779008E-05
     +,   5.7059020E-05,   5.9398983E-05,   6.1802573E-05
     +,   6.4273707E-05,   6.6816770E-05,   6.9436457E-05
     +,   7.2137802E-05,   7.4926116E-05,   7.7806959E-05
     +,   8.0785860E-05,   8.3868727E-05,   8.7061431E-05
     +,   9.0369562E-05,   9.3799004E-05,   9.7355027E-05
     +,   1.0104312E-04,   1.0486793E-04,   1.0883425E-04
     +,   1.1294589E-04,   1.1720662E-04,   1.2161907E-04
     +,   1.2618554E-04,   1.3090757E-04,   1.3578558E-04
     +,   1.4081891E-04,   1.4600615E-04,   1.5134490E-04
     +,   1.5683092E-04,   1.6245939E-04,   1.6822350E-04
     +,   1.7411582E-04,   1.8012713E-04,   1.8624781E-04
     +,   1.9246638E-04,   1.9877203E-04,   2.0515294E-04
     +,   2.1159845E-04,   2.1809959E-04,   2.2464931E-04
     +,   2.3124467E-04,   2.3788822E-04,   2.4458999E-04
     +,   2.5136885E-04,   2.5825607E-04,   2.6529675E-04
     +,   2.7255385E-04,   2.8010953E-04,   2.8806963E-04
     +,   2.9656384E-04,   3.0574974E-04,   3.1581111E-04
     +,   3.2695977E-04,   3.3943215E-04,   3.5348494E-04
     +,   3.6938890E-04,   3.8742195E-04,   4.0785762E-04
     +,   4.3095052E-04,   4.5692796E-04,   4.8596974E-04
     +,   5.1820220E-04,   5.5367878E-04,   5.9238082E-04
     +,   6.3420378E-04,   6.7896821E-04,   7.2641275E-04
     +,   7.7621656E-04,   8.2800863E-04,   8.8138174E-04
     +,   9.3591446E-04,   9.9119556E-04,   1.0468353E-03
     +,   1.1024773E-03,   1.1578156E-03,   1.2125866E-03
     +,   1.2665821E-03,   1.3196263E-03,   1.3715896E-03
     +,   1.4223710E-03,   1.4719270E-03,   1.5202949E-03
     +,   1.5676587E-03,   1.6144379E-03,   1.6613828E-03
     +,   1.7096979E-03,   1.7611432E-03,   1.8180892E-03
     +,   1.8835157E-03,   1.9609469E-03,   2.0543104E-03
     +,   2.1677401E-03,   2.3053493E-03,   2.4711152E-03
     +,   2.6688857E-03,   2.9026933E-03,   3.1773227E-03
     +,   3.4989773E-03,   3.8754628E-03,   4.3156049E-03
     +,   4.8280600E-03,   5.4207002E-03,   6.1014988E-03
     +,   6.8802470E-03,   7.7676824E-03,   8.7703206E-03
     +,   9.8868292E-03,   1.1117349E-02,   1.2492864E-02
     +,   1.4118048E-02,   1.6197242E-02,   1.8997001E-02
     +,   2.2752455E-02,   2.7541507E-02,   3.3260237E-02
     +,   4.0112365E-02,   4.8672598E-02,   5.8560804E-02
     +,   6.8821408E-02,   7.9335809E-02,   8.9361347E-02
     +,   9.6283570E-02,   9.7940542E-02,   9.7773165E-02
     +,   9.8260917E-02,   9.5769748E-02,   9.0125166E-02
     +,   8.1771299E-02,   7.0309728E-02,   5.8265436E-02
     +,   4.8663799E-02,   4.1078817E-02,   3.4672003E-02
     +,   2.9535715E-02,   2.5796082E-02,   2.3207190E-02
     +,   2.1415502E-02,   2.0035585E-02,   1.8687041E-02
     +,   1.7178124E-02,   1.5572404E-02,   1.4058816E-02
     +,   1.2782929E-02,   1.1772420E-02,   1.0964448E-02
     +,   1.0268310E-02,   9.6067283E-03,   8.9271571E-03
     +,   8.2010971E-03,   7.4232458E-03,   6.6103060E-03
     +,   5.7946849E-03,   5.0132293E-03,   4.2954409E-03
     +,   3.6571447E-03,   3.1008173E-03,   2.6203436E-03
     +,   2.2064834E-03,   1.8505111E-03,   1.5454565E-03
     +,   1.2857429E-03,   1.0664428E-03,   8.8279881E-04
     +,   7.3011080E-04,   6.0384028E-04,   4.9978937E-04
     +,   4.1423726E-04,   3.4399296E-04,   2.8635285E-04
     +,   2.3905597E-04,   2.0021939E-04,   1.6827548E-04
     +,   1.4192305E-04,   1.2009170E-04,   1.0191053E-04
     +,   8.6677770E-05,   7.3833398E-05,   6.2936051E-05
     +,   5.3640455E-05,   4.5676501E-05,   3.8831782E-05
     +,   3.2938155E-05,   2.7861055E-05,   2.3489931E-05
     +,   1.9732621E-05,   1.6510970E-05,   1.3757372E-05
     +,   1.1412416E-05,   9.4236229E-06,   7.7444865E-06
     +,   6.3335560E-06,   5.1538318E-06,   4.1724788E-06
     +,   3.3604981E-06,   2.6923278E-06,   2.1455273E-06
     +,   1.7005617E-06,   1.3405609E-06,   1.0509780E-06
     +,   8.1939510E-07,   6.3529467E-07,   4.8981423E-07
     +,   3.7553389E-07,   2.8629745E-07,   2.1703742E-07
     +,   1.6360661E-07,   1.2263364E-07,   9.1401937E-08
     +,   6.7739386E-08,   4.9919667E-08,   3.6579888E-08
     +,   2.6653241E-08,   1.9310958E-08,   1.3912342E-08
     +,   9.9663211E-09,   7.0992447E-09,   5.0284958E-09
     +,   3.5416503E-09,   2.4803326E-09,   1.7272430E-09
     +,   1.1960237E-09,   8.2349433E-10,   5.6377675E-10
     +,   3.8378295E-10,   2.5976521E-10,   1.7482299E-10
     +,   1.1698248E-10,   7.7831165E-11,   5.1484615E-11
     +,   3.3860779E-11,   2.2140744E-11,   1.4393531E-11
     +,   9.3025301E-12,   5.9771970E-12,   3.8180444E-12
     +,   2.4244654E-12,   1.5304749E-12,   9.6039626E-13
     +,   5.9908914E-13,   3.7147247E-13,   2.2896087E-13
     +,   1.4027265E-13,   8.5421233E-14,   5.1703264E-14
     +,   3.1105425E-14,   1.8599302E-14,   1.1053703E-14
     +,   6.5289948E-15,   3.8328436E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt90 = Yx/0.44072
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9277644E-06,   3.1362631E-06
     +,   3.3560561E-06,   3.5874705E-06,   3.8308222E-06
     +,   4.0864134E-06,   4.3545333E-06,   4.6354530E-06
     +,   4.9294181E-06,   5.2366731E-06,   5.5574242E-06
     +,   5.8918577E-06,   6.2401382E-06,   6.6023981E-06
     +,   6.9787511E-06,   7.3692750E-06,   7.7740178E-06
     +,   8.1930020E-06,   8.6262125E-06,   9.0736057E-06
     +,   9.5351052E-06,   1.0010599E-05,   1.0499935E-05
     +,   1.1002968E-05,   1.1519453E-05,   1.2049179E-05
     +,   1.2591869E-05,   1.3147227E-05,   1.3714928E-05
     +,   1.4294626E-05,   1.4885952E-05,   1.5488506E-05
     +,   1.6101883E-05,   1.6725660E-05,   1.7359396E-05
     +,   1.8002647E-05,   1.8654970E-05,   1.9315894E-05
     +,   1.9985011E-05,   2.0661833E-05,   2.1345975E-05
     +,   2.2037002E-05,   2.2734539E-05,   2.3438222E-05
     +,   2.4147734E-05,   2.4862788E-05,   2.5583158E-05
     +,   2.6308679E-05,   2.7039252E-05,   2.7774868E-05
     +,   2.8515624E-05,   2.9261731E-05,   3.0013534E-05
     +,   3.0771596E-05,   3.1536612E-05,   3.2309577E-05
     +,   3.3091750E-05,   3.3884731E-05,   3.4690518E-05
     +,   3.5511570E-05,   3.6350895E-05,   3.7212139E-05
     +,   3.8099603E-05,   3.9018498E-05,   3.9974901E-05
     +,   4.0975861E-05,   4.2029653E-05,   4.3145621E-05
     +,   4.4334523E-05,   4.5608343E-05,   4.6980571E-05
     +,   4.8465929E-05,   5.0080624E-05,   5.1841955E-05
     +,   5.3768421E-05,   5.5879431E-05,   5.8194877E-05
     +,   6.0734837E-05,   6.3519350E-05,   6.6567802E-05
     +,   6.9898029E-05,   7.3526353E-05,   7.7466160E-05
     +,   8.1728023E-05,   8.6318127E-05,   9.1238609E-05
     +,   9.6485848E-05,   1.0205112E-04,   1.0791887E-04
     +,   1.1406771E-04,   1.2046969E-04,   1.2709005E-04
     +,   1.3388775E-04,   1.4081653E-04,   1.4782505E-04
     +,   1.5485725E-04,   1.6185490E-04,   1.6875706E-04
     +,   1.7550332E-04,   1.8203359E-04,   1.8829128E-04
     +,   1.9422322E-04,   1.9978314E-04,   2.0493146E-04
     +,   2.0963824E-04,   2.1388402E-04,   2.1766071E-04
     +,   2.2097361E-04,   2.2384254E-04,   2.2630247E-04
     +,   2.2840458E-04,   2.3021759E-04,   2.3182810E-04
     +,   2.3334178E-04,   2.3488316E-04,   2.3659691E-04
     +,   2.3864716E-04,   2.4121760E-04,   2.4451010E-04
     +,   2.4874342E-04,   2.5415103E-04,   2.6097661E-04
     +,   2.6947079E-04,   2.7988508E-04,   2.9246596E-04
     +,   3.0744556E-04,   3.2503606E-04,   3.4541736E-04
     +,   3.6873246E-04,   3.9507364E-04,   4.2448103E-04
     +,   4.5692880E-04,   4.9233023E-04,   5.3052738E-04
     +,   5.7130319E-04,   6.1438716E-04,   6.5946655E-04
     +,   7.0621009E-04,   7.5430109E-04,   8.0346817E-04
     +,   8.5352280E-04,   9.0440578E-04,   9.5623429E-04
     +,   1.0093375E-03,   1.0642842E-03,   1.1219226E-03
     +,   1.1833952E-03,   1.2501609E-03,   1.3240320E-03
     +,   1.4072224E-03,   1.5023940E-03,   1.6126508E-03
     +,   1.7414528E-03,   1.8923427E-03,   2.0684125E-03
     +,   2.2715030E-03,   2.5012740E-03,   2.7544324E-03
     +,   3.0246142E-03,   3.3037164E-03,   3.5856818E-03
     +,   3.8730293E-03,   4.1852011E-03,   4.5652897E-03
     +,   5.0795134E-03,   5.8046957E-03,   6.8033827E-03
     +,   8.0927229E-03,   9.6207540E-03,   1.1277918E-02
     +,   1.2984586E-02,   1.4836194E-02,   1.7122878E-02
     +,   2.0108309E-02,   2.4027184E-02,   2.9496511E-02
     +,   3.6972314E-02,   4.5745075E-02,   5.4764446E-02
     +,   6.3937455E-02,   7.5464986E-02,   8.8138580E-02
     +,   9.8571382E-02,   0.1057478    ,   0.1080255    
     +,   0.1062550    ,   0.1011383    ,   9.3992822E-02
     +,   8.7481372E-02,   7.8080222E-02,   6.5291479E-02
     +,   5.5643406E-02,   4.8098974E-02,   4.0772468E-02
     +,   3.5241537E-02,   3.1639282E-02,   2.8677883E-02
     +,   2.5559967E-02,   2.2172894E-02,   1.8819129E-02
     +,   1.5888089E-02,   1.3586250E-02,   1.1918949E-02
     +,   1.0750198E-02,   9.8639140E-03,   9.0532089E-03
     +,   8.1954198E-03,   7.2665694E-03,   6.3078213E-03
     +,   5.3813201E-03,   4.5387936E-03,   3.8073401E-03
     +,   3.1889810E-03,   2.6688962E-03,   2.2264251E-03
     +,   1.8436225E-03,   1.5089426E-03,   1.2167733E-03
     +,   9.6499827E-04,   7.5250352E-04,   5.7752361E-04
     +,   4.3707382E-04,   3.2707019E-04,   2.4277660E-04
     +,   1.7933396E-04,   1.3221233E-04,   9.7494085E-05
     +,   7.1988849E-05,   5.3224845E-05,   3.9361847E-05
     +,   2.9067682E-05,   2.1391352E-05,   1.5655243E-05
     +,   1.1372439E-05,   8.1871649E-06,   5.8335440E-06
     +,   4.1096409E-06,   2.8603090E-06,   1.9656547E-06
     +,   1.3331688E-06,   8.9205207E-07,   5.8872240E-07
     +,   3.8314101E-07,   2.4583974E-07,   1.5549578E-07
     +,   9.6940902E-08,   5.9562375E-08,   3.6062676E-08
     +,   2.1513484E-08,   1.2644456E-08,   7.3210886E-09
     +,   4.1753037E-09,   2.3453370E-09,   1.2974765E-09
     +,   7.0685330E-10,   3.7918940E-10,   2.0029257E-10
     +,   1.0417154E-10,   5.3344953E-11,   2.6896527E-11
     +,   1.3353616E-11,   6.5294779E-12,   3.1452089E-12
     +,   1.4932152E-12,   6.9935691E-13,   3.2360795E-13
     +,   1.4831288E-13,   6.7615272E-14,   3.0879220E-14
     +,   1.4281697E-14,   6.7948602E-15,   3.3905454E-15
     +,   1.8072079E-15,   1.0391645E-15,   6.4247603E-16
     +,   4.2114695E-16,   2.8756769E-16,   2.0142893E-16
     +,   1.4315998E-16,   1.0253122E-16,   7.3700840E-17
     +,   5.3053849E-17,   3.8200815E-17,   2.7497690E-17
     +,   1.9781693E-17,   1.4221301E-17,   1.0216812E-17
     +,   7.3350051E-18,   5.2629114E-18,   3.7740996E-18
     +,   2.7052007E-18,   1.9382281E-18,   1.3882590E-18
     +,   9.9406068E-19,   7.1165740E-19,   5.0939948E-19
     +,   3.6459446E-19,   2.6093694E-19,   1.8675173E-19
     +,   1.3365958E-19,   9.5668039E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_htt95 = Yx/0.43694
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.5697319E-06,   5.8923242E-06
     +,   6.2227200E-06,   6.5602421E-06,   6.9041548E-06
     +,   7.2536686E-06,   7.6079391E-06,   7.9660813E-06
     +,   8.3271634E-06,   8.6902355E-06,   9.0543072E-06
     +,   9.4183724E-06,   9.7814209E-06,   1.0142431E-05
     +,   1.0500396E-05,   1.0854318E-05,   1.1203222E-05
     +,   1.1546168E-05,   1.1882251E-05,   1.2210616E-05
     +,   1.2530462E-05,   1.2841043E-05,   1.3141685E-05
     +,   1.3431792E-05,   1.3710818E-05,   1.3978326E-05
     +,   1.4233940E-05,   1.4477375E-05,   1.4708421E-05
     +,   1.4926953E-05,   1.5132930E-05,   1.5326386E-05
     +,   1.5507423E-05,   1.5676218E-05,   1.5833015E-05
     +,   1.5978110E-05,   1.6111864E-05,   1.6234679E-05
     +,   1.6347001E-05,   1.6449309E-05,   1.6542128E-05
     +,   1.6625992E-05,   1.6701471E-05,   1.6769147E-05
     +,   1.6829623E-05,   1.6883516E-05,   1.6931459E-05
     +,   1.6974100E-05,   1.7012107E-05,   1.7046174E-05
     +,   1.7077018E-05,   1.7105391E-05,   1.7132092E-05
     +,   1.7157967E-05,   1.7183918E-05,   1.7210932E-05
     +,   1.7240069E-05,   1.7272487E-05,   1.7309447E-05
     +,   1.7352335E-05,   1.7402666E-05,   1.7462093E-05
     +,   1.7532424E-05,   1.7615614E-05,   1.7713810E-05
     +,   1.7829305E-05,   1.7964585E-05,   1.8122277E-05
     +,   1.8305227E-05,   1.8516401E-05,   1.8758958E-05
     +,   1.9036157E-05,   1.9351430E-05,   1.9708286E-05
     +,   2.0110319E-05,   2.0561218E-05,   2.1064665E-05
     +,   2.1624304E-05,   2.2243792E-05,   2.2926719E-05
     +,   2.3676457E-05,   2.4496316E-05,   2.5389294E-05
     +,   2.6358208E-05,   2.7405476E-05,   2.8533259E-05
     +,   2.9743169E-05,   3.1036536E-05,   3.2414013E-05
     +,   3.3875825E-05,   3.5421675E-05,   3.7050533E-05
     +,   3.8760751E-05,   4.0550123E-05,   4.2415846E-05
     +,   4.4354285E-05,   4.6361398E-05,   4.8432328E-05
     +,   5.0561899E-05,   5.2744155E-05,   5.4972988E-05
     +,   5.7241603E-05,   5.9543236E-05,   6.1870604E-05
     +,   6.4216561E-05,   6.6573950E-05,   6.8935566E-05
     +,   7.1294402E-05,   7.3643925E-05,   7.5978001E-05
     +,   7.8290679E-05,   8.0576880E-05,   8.2831764E-05
     +,   8.5051361E-05,   8.7232009E-05,   8.9370835E-05
     +,   9.1465183E-05,   9.3513088E-05,   9.5512609E-05
     +,   9.7462209E-05,   9.9360412E-05,   1.0120557E-04
     +,   1.0299590E-04,   1.0472957E-04,   1.0640444E-04
     +,   1.0801799E-04,   1.0956793E-04,   1.1105179E-04
     +,   1.1246792E-04,   1.1381543E-04,   1.1509544E-04
     +,   1.1631143E-04,   1.1747095E-04,   1.1858650E-04
     +,   1.1967753E-04,   1.2077215E-04,   1.2190922E-04
     +,   1.2314074E-04,   1.2453432E-04,   1.2617563E-04
     +,   1.2817074E-04,   1.3064811E-04,   1.3376059E-04
     +,   1.3768590E-04,   1.4262593E-04,   1.4880528E-04
     +,   1.5646714E-04,   1.6586618E-04,   1.7725922E-04
     +,   1.9089421E-04,   2.0699436E-04,   2.2573983E-04
     +,   2.4724923E-04,   2.7156278E-04,   2.9862451E-04
     +,   3.2826865E-04,   3.6021532E-04,   3.9407754E-04
     +,   4.2937428E-04,   4.6555424E-04,   5.0204189E-04
     +,   5.3828326E-04,   5.7380396E-04,   6.0828059E-04
     +,   6.4162287E-04,   6.7406736E-04,   7.0628821E-04
     +,   7.3953264E-04,   7.7576033E-04,   8.1776414E-04
     +,   8.6923991E-04,   9.3478465E-04,   1.0198359E-03
     +,   1.1306134E-03,   1.2741565E-03,   1.4585471E-03
     +,   1.6930286E-03,   1.9872678E-03,   2.3485553E-03
     +,   2.7764023E-03,   3.2576425E-03,   3.7712909E-03
     +,   4.3118009E-03,   4.9185008E-03,   5.6711999E-03
     +,   6.6374014E-03,   7.8514544E-03,   9.4107762E-03
     +,   1.1534023E-02,   1.4292649E-02,   1.7360006E-02
     +,   2.0706929E-02,   2.5070895E-02,   3.0327821E-02
     +,   3.5585389E-02,   4.0500361E-02,   4.3731712E-02
     +,   4.3594282E-02,   4.0893342E-02,   3.6873139E-02
     +,   3.1367883E-02,   2.5335761E-02,   2.0413870E-02
     +,   1.6710324E-02,   1.3796492E-02,   1.1531049E-02
     +,   9.7639831E-03,   8.3091538E-03,   7.0304302E-03
     +,   5.8619441E-03,   4.8133414E-03,   3.9200634E-03
     +,   3.1880604E-03,   2.5927855E-03,   2.1040565E-03
     +,   1.6988799E-03,   1.3612271E-03,   1.0797104E-03
     +,   8.4642513E-04,   6.5570191E-04,   5.0255336E-04
     +,   3.8178501E-04,   2.8796113E-04,   2.1583225E-04
     +,   1.6075798E-04,   1.1890953E-04,   8.7257838E-05
     +,   6.3450731E-05,   4.5669756E-05,   3.2506199E-05
     +,   2.2863180E-05,   1.5882581E-05,   1.0893526E-05
     +,   7.3752772E-06,   4.9281939E-06,   3.2494499E-06
     +,   2.1136198E-06,   1.3557872E-06,   8.5726168E-07
     +,   5.3401322E-07,   3.2752200E-07,   1.9765719E-07
     +,   1.1730169E-07,   6.8414515E-08,   3.9191864E-08
     +,   2.2041318E-08,   1.2164485E-08,   6.5856032E-09
     +,   3.4962691E-09,   1.8198811E-09,   9.2863345E-10
     +,   4.6450654E-10,   2.2780107E-10,   1.0957568E-10
     +,   5.1735886E-11,   2.4009726E-11,   1.0979515E-11
     +,   4.9684853E-12,   2.2405268E-12,   1.0181167E-12
     +,   4.7387100E-13,   2.3061433E-13,   1.1972206E-13
     +,   6.7063000E-14,   4.0422377E-14,   2.5838354E-14
     +,   1.7194826E-14,   1.1725152E-14,   8.1019743E-15
     +,   5.6340939E-15,   3.9274419E-15,   2.7386439E-15
     +,   1.9082367E-15,   1.3278785E-15,   9.2256827E-16
     +,   6.3989835E-16,   4.4306380E-16,   3.0624513E-16
     +,   2.1130436E-16,   1.4554461E-16,   1.0007473E-16
     +,   6.8691725E-17,   4.7067967E-17,   3.2195785E-17
     +,   2.1984303E-17,   1.4985593E-17,   1.0197020E-17
     +,   6.9262877E-18,   4.6963729E-18,   3.1786378E-18
     +,   2.1475346E-18,   1.4482364E-18,   9.7486409E-19
     +,   6.5498606E-19,   4.3924614E-19,   2.9400051E-19
     +,   1.9640689E-19,   1.3095188E-19,   8.7139193E-20
     +,   5.7868347E-20,   3.8352866E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz100 = Yx/0.143093023255814
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6528404E-17,   2.6108631E-17
     +,   4.1085068E-17,   6.4406857E-17,   1.0058353E-16
     +,   1.5648398E-16,   2.4252621E-16,   3.7445161E-16
     +,   5.7594063E-16,   8.8248805E-16,   1.3470639E-15
     +,   2.0484010E-15,   3.1030419E-15,   4.6828399E-15
     +,   7.0400809E-15,   1.0543709E-14,   1.5731009E-14
     +,   2.3381177E-14,   3.4619863E-14,   5.1065780E-14
     +,   7.5038154E-14,   1.0984536E-13,   1.6018694E-13
     +,   2.3271527E-13,   3.3679334E-13,   4.8557106E-13
     +,   6.9741245E-13,   9.9787008E-13,   1.4223449E-12
     +,   2.0196872E-12,   2.8570009E-12,   4.0260959E-12
     +,   5.6520309E-12,   7.9044800E-12,   1.1012571E-11
     +,   1.5284544E-11,   2.1133092E-11,   2.9108424E-11
     +,   3.9941730E-11,   5.4598177E-11,   7.4349693E-11
     +,   1.0086200E-10,   1.3630887E-10,   1.8351341E-10
     +,   2.4612729E-10,   3.2885150E-10,   4.3771087E-10
     +,   5.8039534E-10,   7.6666967E-10,   1.0088862E-09
     +,   1.3225868E-09,   1.7272513E-09,   2.2471620E-09
     +,   2.9125098E-09,   3.7605097E-09,   4.8370290E-09
     +,   6.1981580E-09,   7.9122238E-09,   1.0062083E-08
     +,   1.2747684E-08,   1.6089038E-08,   2.0229590E-08
     +,   2.5339558E-08,   3.1620655E-08,   3.9310464E-08
     +,   4.8686246E-08,   6.0072367E-08,   7.3843104E-08
     +,   9.0431890E-08,   1.1033355E-07,   1.3411537E-07
     +,   1.6241754E-07,   1.9596693E-07,   2.3557465E-07
     +,   2.8215021E-07,   3.3670409E-07,   4.0034931E-07
     +,   4.7430726E-07,   5.5991768E-07,   6.5863748E-07
     +,   7.7203225E-07,   9.0180043E-07,   1.0497432E-06
     +,   1.2177985E-06,   1.4079991E-06,   1.6225156E-06
     +,   1.8636016E-06,   2.1336502E-06,   2.4351245E-06
     +,   2.7706155E-06,   3.1428190E-06,   3.5545045E-06
     +,   4.0085361E-06,   4.5079005E-06,   5.0556919E-06
     +,   5.6550525E-06,   6.3093007E-06,   7.0217829E-06
     +,   7.7960412E-06,   8.6356322E-06,   9.5443256E-06
     +,   1.0525883E-05,   1.1584286E-05,   1.2723464E-05
     +,   1.3947522E-05,   1.5260617E-05,   1.6666841E-05
     +,   1.8170249E-05,   1.9774941E-05,   2.1484930E-05
     +,   2.3303912E-05,   2.5235600E-05,   2.7283235E-05
     +,   2.9449997E-05,   3.1738429E-05,   3.4150933E-05
     +,   3.6689125E-05,   3.9354356E-05,   4.2146963E-05
     +,   4.5066783E-05,   4.8112750E-05,   5.1282565E-05
     +,   5.4572691E-05,   5.7978352E-05,   6.1493272E-05
     +,   6.5108965E-05,   6.8815563E-05,   7.2600698E-05
     +,   7.6450568E-05,   8.0349120E-05,   8.4279411E-05
     +,   8.8223271E-05,   9.2163165E-05,   9.6082353E-05
     +,   9.9967227E-05,   1.0380875E-04,   1.0760372E-04
     +,   1.1135718E-04,   1.1508437E-04,   1.1881181E-04
     +,   1.2257809E-04,   1.2643436E-04,   1.3044392E-04
     +,   1.3468029E-04,   1.3922405E-04,   1.4416000E-04
     +,   1.4957192E-04,   1.5553719E-04,   1.6212102E-04
     +,   1.6937175E-04,   1.7731533E-04,   1.8595070E-04
     +,   1.9524721E-04,   2.0514420E-04,   2.1555052E-04
     +,   2.2634593E-04,   2.3738481E-04,   2.4850157E-04
     +,   2.5951557E-04,   2.7023564E-04,   2.8046954E-04
     +,   2.9002933E-04,   2.9873781E-04,   3.0643723E-04
     +,   3.1299700E-04,   3.1832265E-04,   3.2236549E-04
     +,   3.2513574E-04,   3.2671940E-04,   3.2729883E-04
     +,   3.2718244E-04,   3.2684021E-04,   3.2694775E-04
     +,   3.2843227E-04,   3.3251531E-04,   3.4074186E-04
     +,   3.5499106E-04,   3.7746143E-04,   4.1064114E-04
     +,   4.5727359E-04,   5.2030740E-04,   6.0278288E-04
     +,   7.0757192E-04,   8.3685003E-04,   9.9123036E-04
     +,   1.1687116E-03,   1.3639333E-03,   1.5683770E-03
     +,   1.7720050E-03,   1.9663963E-03,   2.1493274E-03
     +,   2.3310566E-03,   2.5419891E-03,   2.8355825E-03
     +,   3.2762364E-03,   3.9228355E-03,   4.8616743E-03
     +,   6.2975916E-03,   8.4831165E-03,   1.1298876E-02
     +,   1.4266695E-02,   1.7486723E-02,   2.1120669E-02
     +,   2.6699621E-02,   3.7214626E-02,   4.7927912E-02
     +,   5.2192513E-02,   5.1823698E-02,   4.9414173E-02
     +,   4.3367360E-02,   3.7487626E-02,   3.1265464E-02
     +,   2.2836646E-02,   1.4195470E-02,   8.4828930E-03
     +,   5.2590468E-03,   3.2697152E-03,   1.9912384E-03
     +,   1.2017487E-03,   7.2893105E-04,   4.4363321E-04
     +,   2.6910295E-04,   1.6378044E-04,   1.0280586E-04
     +,   6.9415262E-05,   5.2194773E-05,   4.3810327E-05
     +,   3.9888015E-05,   3.8013091E-05,   3.6955913E-05
     +,   3.6143560E-05,   3.5335917E-05,   3.4446293E-05
     +,   3.3452176E-05,   3.2355572E-05,   3.1166983E-05
     +,   2.9899742E-05,   2.8568165E-05,   2.7186737E-05
     +,   2.5769639E-05,   2.4330606E-05,   2.2882790E-05
     +,   2.1438538E-05,   2.0009118E-05,   1.8604727E-05
     +,   1.7234514E-05,   1.5906431E-05,   1.4627128E-05
     +,   1.3402074E-05,   1.2235695E-05,   1.1131187E-05
     +,   1.0090717E-05,   9.1155616E-06,   8.2061297E-06
     +,   7.3619881E-06,   6.5820464E-06,   5.8646883E-06
     +,   5.2078121E-06,   4.6088817E-06,   4.0650725E-06
     +,   3.5733692E-06,   3.1306031E-06,   2.7334902E-06
     +,   2.3787231E-06,   2.0630491E-06,   1.7832417E-06
     +,   1.5361732E-06,   1.3188562E-06,   1.1284419E-06
     +,   9.6222709E-07,   8.1768155E-07,   6.9245959E-07
     +,   5.8439099E-07,   4.9147525E-07,   4.1188736E-07
     +,   3.4397846E-07,   2.8625053E-07,   2.3736742E-07
     +,   1.9612914E-07,   1.6147547E-07,   1.3246485E-07
     +,   1.0827358E-07,   8.8177707E-08,   7.1549685E-08
     +,   5.7843675E-08,   4.6591083E-08,   3.7388556E-08
     +,   2.9891918E-08,   2.3809426E-08,   1.8893450E-08
     +,   1.4936264E-08,   1.1763315E-08,   9.2294545E-09
     +,   7.2138953E-09,   5.6171161E-09,   4.3570858E-09
     +,   3.3668337E-09,   2.5916649E-09,   1.9873407E-09
     +,   1.5180700E-09,   1.1551576E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz105 = Yx/0.131166666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0403413E-10,   1.4007299E-10
     +,   1.8800757E-10,   2.5155211E-10,   3.3550759E-10
     +,   4.4605550E-10,   5.9112432E-10,   7.8084178E-10
     +,   1.0280899E-09,   1.3492109E-09,   1.7648160E-09
     +,   2.3008226E-09,   2.9896732E-09,   3.8718220E-09
     +,   4.9974913E-09,   6.4287793E-09,   8.2421225E-09
     +,   1.0531231E-08,   1.3410471E-08,   1.7018817E-08
     +,   2.1524402E-08,   2.7129737E-08,   3.4077505E-08
     +,   4.2657877E-08,   5.3214567E-08,   6.6155167E-08
     +,   8.1958689E-08,   1.0118628E-07,   1.2449213E-07
     +,   1.5263494E-07,   1.8649021E-07,   2.2706324E-07
     +,   2.7550217E-07,   3.3311136E-07,   4.0136518E-07
     +,   4.8191993E-07,   5.7662641E-07,   6.8753889E-07
     +,   8.1693327E-07,   9.6729241E-07,   1.1413399E-06
     +,   1.3420147E-06,   1.5724809E-06,   1.8361176E-06
     +,   2.1365017E-06,   2.4773965E-06,   2.8627182E-06
     +,   3.2965081E-06,   3.7828954E-06,   4.3260493E-06
     +,   4.9301252E-06,   5.5992086E-06,   6.3372318E-06
     +,   7.1479731E-06,   8.0348309E-06,   9.0009335E-06
     +,   1.0048907E-05,   1.1180863E-05,   1.2398297E-05
     +,   1.3702019E-05,   1.5092068E-05,   1.6567676E-05
     +,   1.8127095E-05,   1.9767755E-05,   2.1486130E-05
     +,   2.3277540E-05,   2.5136545E-05,   2.7056505E-05
     +,   2.9030092E-05,   3.1048850E-05,   3.3103785E-05
     +,   3.5184923E-05,   3.7281992E-05,   3.9383973E-05
     +,   4.1479736E-05,   4.3558011E-05,   4.5607401E-05
     +,   4.7616697E-05,   4.9575192E-05,   5.1472725E-05
     +,   5.3299675E-05,   5.5047534E-05,   5.6708632E-05
     +,   5.8276695E-05,   5.9746541E-05,   6.1114610E-05
     +,   6.2378647E-05,   6.3538100E-05,   6.4593820E-05
     +,   6.5548382E-05,   6.6405897E-05,   6.7171764E-05
     +,   6.7852976E-05,   6.8457739E-05,   6.8995396E-05
     +,   6.9476264E-05,   6.9911490E-05,   7.0312824E-05
     +,   7.0692411E-05,   7.1062546E-05,   7.1435519E-05
     +,   7.1823291E-05,   7.2237359E-05,   7.2688446E-05
     +,   7.3186384E-05,   7.3739844E-05,   7.4356169E-05
     +,   7.5041193E-05,   7.5799217E-05,   7.6632838E-05
     +,   7.7542783E-05,   7.8528079E-05,   7.9585865E-05
     +,   8.0711579E-05,   8.1898892E-05,   8.3140039E-05
     +,   8.4425657E-05,   8.5745451E-05,   8.7087865E-05
     +,   8.8440873E-05,   8.9792011E-05,   9.1128626E-05
     +,   9.2438444E-05,   9.3709896E-05,   9.4932417E-05
     +,   9.6096810E-05,   9.7195836E-05,   9.8224344E-05
     +,   9.9179924E-05,   1.0006303E-04,   1.0087762E-04
     +,   1.0163125E-04,   1.0233566E-04,   1.0300690E-04
     +,   1.0366583E-04,   1.0433842E-04,   1.0505598E-04
     +,   1.0585561E-04,   1.0678045E-04,   1.0787995E-04
     +,   1.0921009E-04,   1.1083324E-04,   1.1281852E-04
     +,   1.1524122E-04,   1.1818194E-04,   1.2172615E-04
     +,   1.2596264E-04,   1.3098140E-04,   1.3687152E-04
     +,   1.4371920E-04,   1.5160489E-04,   1.6059988E-04
     +,   1.7076443E-04,   1.8214688E-04,   1.9478241E-04
     +,   2.0869289E-04,   2.2388910E-04,   2.4037574E-04
     +,   2.5815537E-04,   2.7723159E-04,   2.9761824E-04
     +,   3.1934216E-04,   3.4244335E-04,   3.6697471E-04
     +,   3.9299755E-04,   4.2056906E-04,   4.4972435E-04
     +,   4.8045974E-04,   5.1271386E-04,   5.4634834E-04
     +,   5.8113335E-04,   6.1674579E-04,   6.5277959E-04
     +,   6.8876421E-04,   7.2419114E-04,   7.5855956E-04
     +,   7.9140917E-04,   8.2235126E-04,   8.5108978E-04
     +,   8.7742344E-04,   9.0122491E-04,   9.2240807E-04
     +,   9.4089803E-04,   9.5662038E-04,   9.6954545E-04
     +,   9.7984669E-04,   9.8823884E-04,   9.9657127E-04
     +,   1.0087109E-03,   1.0316372E-03,   1.0765018E-03
     +,   1.1591840E-03,   1.2997482E-03,   1.5201343E-03
     +,   1.8393496E-03,   2.2658028E-03,   2.7894410E-03
     +,   3.3832407E-03,   4.0269019E-03,   4.7489237E-03
     +,   5.6534805E-03,   6.9126599E-03,   8.7649375E-03
     +,   1.1521406E-02,   1.5455052E-02,   2.0570563E-02
     +,   2.6239101E-02,   3.1092223E-02,   3.5442252E-02
     +,   4.2335801E-02,   5.0083514E-02,   5.2373104E-02
     +,   4.8340477E-02,   3.9619859E-02,   2.9063394E-02
     +,   2.0255150E-02,   1.3313688E-02,   7.7033429E-03
     +,   3.8053046E-03,   1.6270279E-03,   6.2613474E-04
     +,   2.2989913E-04,   8.3757986E-05,   2.9496663E-05
     +,   9.4218576E-06,   2.5984036E-06,   6.0472701E-07
     +,   1.1871536E-07,   2.0617385E-08,   4.0531902E-09
     +,   1.5201082E-09,   1.0054099E-09,   7.6921314E-10
     +,   5.9876981E-10,   4.6583265E-10,   3.6154235E-10
     +,   2.7987981E-10,   2.1610143E-10,   1.6642319E-10
     +,   1.2782923E-10,   9.7925480E-11,   7.4818651E-11
     +,   5.7012603E-11,   4.3328251E-11,   3.2839967E-11
     +,   2.4823678E-11,   1.8713789E-11,   1.4069657E-11
     +,   1.0549336E-11,   7.8884442E-12,   5.8826988E-12
     +,   4.3749722E-12,   3.2448139E-12,   2.4000621E-12
     +,   1.7703861E-12,   1.3023316E-12,   9.5539820E-13
     +,   6.9897549E-13,   5.0997433E-13,   3.7105440E-13
     +,   2.6923648E-13,   1.9482330E-13,   1.4058969E-13
     +,   1.0117350E-13,   7.2608565E-14,   5.1965244E-14
     +,   3.7088222E-14,   2.6397451E-14,   1.8736792E-14
     +,   1.3262629E-14,   9.3618088E-15,   6.5900959E-15
     +,   4.6262475E-15,   3.2386745E-15,   2.2609950E-15
     +,   1.5741197E-15,   1.0928760E-15,   7.5667311E-16
     +,   5.2244405E-16,   3.5973015E-16,   2.4700632E-16
     +,   1.6913926E-16,   1.1549838E-16,   7.8652396E-17
     +,   5.3412591E-17,   3.6172744E-17,   2.4429886E-17
     +,   1.6453441E-17,   1.1050967E-17,   7.4018413E-18
     +,   4.9441230E-18,   3.2933499E-18,   2.1877496E-18
     +,   1.4492944E-18,   9.5748007E-19,   6.3082164E-19
     +,   4.1447521E-19,   2.7157810E-19,   1.7746408E-19
     +,   1.1564718E-19,   7.5158923E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz107 = Yx/0.122585365853659
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.2352950E-09,   8.7173042E-09
     +,   1.0480443E-08,   1.2573292E-08,   1.5051866E-08
     +,   1.7980579E-08,   2.1433326E-08,   2.5494598E-08
     +,   3.0260669E-08,   3.5841243E-08,   4.2360508E-08
     +,   4.9958899E-08,   5.8794701E-08,   6.9045889E-08
     +,   8.0911860E-08,   9.4615210E-08,   1.1040406E-07
     +,   1.2855367E-07,   1.4936867E-07,   1.7318519E-07
     +,   2.0037271E-07,   2.3133593E-07,   2.6651642E-07
     +,   3.0639706E-07,   3.5149665E-07,   4.0238103E-07
     +,   4.5965587E-07,   5.2397161E-07,   5.9602269E-07
     +,   6.7654793E-07,   7.6632978E-07,   8.6619326E-07
     +,   9.7700422E-07,   1.0996674E-06,   1.2351232E-06
     +,   1.3843439E-06,   1.5483303E-06,   1.7280996E-06
     +,   1.9246991E-06,   2.1391627E-06,   2.3725484E-06
     +,   2.6258915E-06,   2.9002138E-06,   3.1965114E-06
     +,   3.5157391E-06,   3.8588037E-06,   4.2265456E-06
     +,   4.6197347E-06,   5.0390504E-06,   5.4850716E-06
     +,   5.9582640E-06,   6.4589658E-06,   6.9873677E-06
     +,   7.5435473E-06,   8.1273529E-06,   8.7385342E-06
     +,   9.3766166E-06,   1.0040952E-05,   1.0730704E-05
     +,   1.1444839E-05,   1.2182130E-05,   1.2941170E-05
     +,   1.3720318E-05,   1.4517812E-05,   1.5331721E-05
     +,   1.6159880E-05,   1.7000102E-05,   1.7849970E-05
     +,   1.8707084E-05,   1.9568884E-05,   2.0432877E-05
     +,   2.1296482E-05,   2.2157265E-05,   2.3012781E-05
     +,   2.3860814E-05,   2.4699335E-05,   2.5526508E-05
     +,   2.6340795E-05,   2.7141081E-05,   2.7926679E-05
     +,   2.8697263E-05,   2.9453206E-05,   3.0195331E-05
     +,   3.0925250E-05,   3.1645133E-05,   3.2358039E-05
     +,   3.3067670E-05,   3.3778681E-05,   3.4496396E-05
     +,   3.5227084E-05,   3.5977810E-05,   3.6756403E-05
     +,   3.7571393E-05,   3.8432063E-05,   3.9348310E-05
     +,   4.0330422E-05,   4.1389205E-05,   4.2535547E-05
     +,   4.3780597E-05,   4.5135250E-05,   4.6610327E-05
     +,   4.8215992E-05,   4.9961996E-05,   5.1857041E-05
     +,   5.3908981E-05,   5.6124489E-05,   5.8508755E-05
     +,   6.1065432E-05,   6.3796702E-05,   6.6703054E-05
     +,   6.9782880E-05,   7.3033123E-05,   7.6448450E-05
     +,   8.0022117E-05,   8.3745166E-05,   8.7607332E-05
     +,   9.1596346E-05,   9.5698852E-05,   9.9899698E-05
     +,   1.0418292E-04,   1.0853153E-04,   1.1292749E-04
     +,   1.1735200E-04,   1.2178615E-04,   1.2621073E-04
     +,   1.3060594E-04,   1.3495267E-04,   1.3923153E-04
     +,   1.4342400E-04,   1.4751154E-04,   1.5147707E-04
     +,   1.5530366E-04,   1.5897615E-04,   1.6247996E-04
     +,   1.6580246E-04,   1.6893243E-04,   1.7186042E-04
     +,   1.7457909E-04,   1.7708358E-04,   1.7937171E-04
     +,   1.8144412E-04,   1.8330508E-04,   1.8496273E-04
     +,   1.8642966E-04,   1.8772346E-04,   1.8886755E-04
     +,   1.8989173E-04,   1.9083294E-04,   1.9173622E-04
     +,   1.9265538E-04,   1.9365370E-04,   1.9480479E-04
     +,   1.9619284E-04,   1.9791342E-04,   2.0007334E-04
     +,   2.0279076E-04,   2.0619469E-04,   2.1042490E-04
     +,   2.1563076E-04,   2.2196940E-04,   2.2960451E-04
     +,   2.3870365E-04,   2.4943362E-04,   2.6195563E-04
     +,   2.7641951E-04,   2.9295450E-04,   3.1165755E-04
     +,   3.3258190E-04,   3.5572596E-04,   3.8102118E-04
     +,   4.0832168E-04,   4.3740423E-04,   4.6797711E-04
     +,   4.9969729E-04,   5.3219800E-04,   5.6513766E-04
     +,   5.9824763E-04,   6.3138426E-04,   6.6459063E-04
     +,   6.9816341E-04,   7.3273911E-04,   7.6942286E-04
     +,   8.0998358E-04,   8.5710653E-04,   9.1462873E-04
     +,   9.8761963E-04,   1.0820925E-03,   1.2041715E-03
     +,   1.3586211E-03,   1.5469965E-03,   1.7660396E-03
     +,   2.0070178E-03,   2.2567045E-03,   2.5002325E-03
     +,   2.7253183E-03,   2.9268390E-03,   3.1107503E-03
     +,   3.2966670E-03,   3.5183944E-03,   3.8203194E-03
     +,   4.2456314E-03,   4.8147696E-03,   5.5044312E-03
     +,   6.2505058E-03,   6.9931657E-03,   7.7545871E-03
     +,   8.7157069E-03,   1.0238052E-02,   1.2709292E-02
     +,   1.6271245E-02,   2.0815853E-02,   2.5872728E-02
     +,   3.0780990E-02,   3.6277227E-02,   4.3160543E-02
     +,   4.8289526E-02,   4.5545742E-02,   3.3130895E-02
     +,   1.7828135E-02,   7.2772088E-03,   2.5871485E-03
     +,   1.0396178E-03,   5.3155760E-04,   3.0683787E-04
     +,   1.8581616E-04,   1.1939231E-04,   8.3495150E-05
     +,   6.4563821E-05,   5.5027253E-05,   5.0275765E-05
     +,   4.7492871E-05,   4.5208566E-05,   4.2836669E-05
     +,   4.0239935E-05,   3.7457288E-05,   3.4578479E-05
     +,   3.1698477E-05,   2.8902083E-05,   2.6258103E-05
     +,   2.3816985E-05,   2.1610922E-05,   1.9655223E-05
     +,   1.7950428E-05,   1.6485199E-05,   1.5239657E-05
     +,   1.4188563E-05,   1.3304021E-05,   1.2557733E-05
     +,   1.1922833E-05,   1.1375115E-05,   1.0893576E-05
     +,   1.0460744E-05,   1.0062638E-05,   9.6884587E-06
     +,   9.3301487E-06,   8.9819850E-06,   8.6401324E-06
     +,   8.3022087E-06,   7.9668916E-06,   7.6336510E-06
     +,   7.3025226E-06,   6.9739053E-06,   6.6484017E-06
     +,   6.3267439E-06,   6.0097468E-06,   5.6982012E-06
     +,   5.3928738E-06,   5.0945023E-06,   4.8037646E-06
     +,   4.5212487E-06,   4.2474703E-06,   3.9828883E-06
     +,   3.7278853E-06,   3.4827524E-06,   3.2477092E-06
     +,   3.0229310E-06,   2.8084958E-06,   2.6044490E-06
     +,   2.4107508E-06,   2.2273348E-06,   2.0540590E-06
     +,   1.8907626E-06,   1.7372222E-06,   1.5932006E-06
     +,   1.4584102E-06,   1.3325568E-06,   1.2153109E-06
     +,   1.1063261E-06,   1.0052535E-06,   9.1172166E-07
     +,   8.2536428E-07,   7.4580163E-07,   6.7266359E-07
     +,   6.0557289E-07,   5.4416665E-07,   4.8808039E-07
     +,   4.3696622E-07,   3.9047956E-07,   3.4829378E-07
     +,   3.1008940E-07,   2.7556590E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz110 = Yx/0.106024390243902
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5133488E-06,   4.7249246E-06
     +,   4.9424852E-06,   5.1659558E-06,   5.3952431E-06
     +,   5.6302388E-06,   5.8708138E-06,   6.1168225E-06
     +,   6.3680986E-06,   6.6244702E-06,   6.8857348E-06
     +,   7.1516783E-06,   7.4220698E-06,   7.6966635E-06
     +,   7.9752008E-06,   8.2574079E-06,   8.5430020E-06
     +,   8.8316892E-06,   9.1231714E-06,   9.4171428E-06
     +,   9.7133006E-06,   1.0011343E-05,   1.0310967E-05
     +,   1.0611904E-05,   1.0913865E-05,   1.1216620E-05
     +,   1.1519945E-05,   1.1823657E-05,   1.2127618E-05
     +,   1.2431740E-05,   1.2735998E-05,   1.3040440E-05
     +,   1.3345186E-05,   1.3650467E-05,   1.3956605E-05
     +,   1.4264051E-05,   1.4573387E-05,   1.4885334E-05
     +,   1.5200803E-05,   1.5520840E-05,   1.5846716E-05
     +,   1.6179902E-05,   1.6522081E-05,   1.6875179E-05
     +,   1.7241364E-05,   1.7623066E-05,   1.8022982E-05
     +,   1.8444083E-05,   1.8889612E-05,   1.9363097E-05
     +,   1.9868334E-05,   2.0409390E-05,   2.0990568E-05
     +,   2.1616464E-05,   2.2291793E-05,   2.3021534E-05
     +,   2.3810768E-05,   2.4664680E-05,   2.5588512E-05
     +,   2.6587501E-05,   2.7666818E-05,   2.8831495E-05
     +,   3.0086299E-05,   3.1435789E-05,   3.2884160E-05
     +,   3.4435008E-05,   3.6091602E-05,   3.7856353E-05
     +,   3.9731203E-05,   4.1717096E-05,   4.3814358E-05
     +,   4.6022175E-05,   4.8339065E-05,   5.0762279E-05
     +,   5.3288317E-05,   5.5912729E-05,   5.8629947E-05
     +,   6.1433479E-05,   6.4316235E-05,   6.7270383E-05
     +,   7.0287235E-05,   7.3358024E-05,   7.6473283E-05
     +,   7.9623853E-05,   8.2800274E-05,   8.5993786E-05
     +,   8.9195775E-05,   9.2398717E-05,   9.5595700E-05
     +,   9.8781238E-05,   1.0195126E-04,   1.0510292E-04
     +,   1.0823508E-04,   1.1134851E-04,   1.1444581E-04
     +,   1.1753108E-04,   1.2061052E-04,   1.2369170E-04
     +,   1.2678398E-04,   1.2989767E-04,   1.3304452E-04
     +,   1.3623660E-04,   1.3948679E-04,   1.4280753E-04
     +,   1.4621121E-04,   1.4970941E-04,   1.5331228E-04
     +,   1.5702839E-04,   1.6086454E-04,   1.6482529E-04
     +,   1.6891224E-04,   1.7312473E-04,   1.7745869E-04
     +,   1.8190772E-04,   1.8646185E-04,   1.9110912E-04
     +,   1.9583428E-04,   2.0062039E-04,   2.0544816E-04
     +,   2.1029741E-04,   2.1514691E-04,   2.1997497E-04
     +,   2.2476020E-04,   2.2948238E-04,   2.3412314E-04
     +,   2.3866592E-04,   2.4309794E-04,   2.4740957E-04
     +,   2.5159624E-04,   2.5565788E-04,   2.5960067E-04
     +,   2.6343641E-04,   2.6718414E-04,   2.7086897E-04
     +,   2.7452331E-04,   2.7818617E-04,   2.8190282E-04
     +,   2.8572395E-04,   2.8970544E-04,   2.9390678E-04
     +,   2.9838952E-04,   3.0321637E-04,   3.0845005E-04
     +,   3.1415161E-04,   3.2037889E-04,   3.2718698E-04
     +,   3.3462729E-04,   3.4274711E-04,   3.5158981E-04
     +,   3.6119614E-04,   3.7160426E-04,   3.8284794E-04
     +,   3.9495659E-04,   4.0795410E-04,   4.2185458E-04
     +,   4.3665763E-04,   4.5234433E-04,   4.6887310E-04
     +,   4.8617687E-04,   5.0416047E-04,   5.2270986E-04
     +,   5.4170057E-04,   5.6101591E-04,   5.8057439E-04
     +,   6.0036284E-04,   6.2047341E-04,   6.4113567E-04
     +,   6.6274818E-04,   6.8589393E-04,   7.1133295E-04
     +,   7.3996914E-04,   7.7279174E-04,   8.1079506E-04
     +,   8.5487717E-04,   9.0573693E-04,   9.6379692E-04
     +,   1.0291530E-03,   1.1015659E-03,   1.1805173E-03
     +,   1.2653306E-03,   1.3553288E-03,   1.4500356E-03
     +,   1.5493999E-03,   1.6540101E-03,   1.7652049E-03
     +,   1.8850568E-03,   2.0161695E-03,   2.1612972E-03
     +,   2.3228440E-03,   2.5023890E-03,   2.7005302E-03
     +,   2.9171610E-03,   3.1523919E-03,   3.4079929E-03
     +,   3.6888150E-03,   4.0030614E-03,   4.3600495E-03
     +,   4.7649713E-03,   5.2127289E-03,   5.6862342E-03
     +,   6.1651282E-03,   6.6438150E-03,   7.1468623E-03
     +,   7.7263117E-03,   8.4373290E-03,   9.3055228E-03
     +,   1.0306164E-02,   1.1372932E-02,   1.2441271E-02
     +,   1.3498177E-02,   1.4573576E-02,   1.5640685E-02
     +,   1.6504589E-02,   1.6818678E-02,   1.6261702E-02
     +,   1.4740428E-02,   1.2457889E-02,   9.8169306E-03
     +,   7.2500184E-03,   5.0772922E-03,   3.4429685E-03
     +,   2.3319281E-03,   1.6341774E-03,   1.2152640E-03
     +,   9.6241274E-04,   7.9968729E-04,   6.8312715E-04
     +,   5.8987975E-04,   5.0914980E-04,   4.3657440E-04
     +,   3.7100073E-04,   3.1258242E-04,   2.6167621E-04
     +,   2.1832075E-04,   1.8211894E-04,   1.5233326E-04
     +,   1.2806377E-04,   1.0839743E-04,   9.2496455E-05
     +,   7.9634978E-05,   6.9204638E-05,   6.0703831E-05
     +,   5.3722255E-05,   4.7927326E-05,   4.3053526E-05
     +,   3.8892638E-05,   3.5284196E-05,   3.2106709E-05
     +,   2.9270084E-05,   2.6708793E-05,   2.4375391E-05
     +,   2.2235936E-05,   2.0266290E-05,   1.8448993E-05
     +,   1.6770957E-05,   1.5222010E-05,   1.3793862E-05
     +,   1.2479220E-05,   1.1271242E-05,   1.0163371E-05
     +,   9.1492648E-06,   8.2226807E-06,   7.3774413E-06
     +,   6.6075677E-06,   5.9073895E-06,   5.2714463E-06
     +,   4.6946079E-06,   4.1721241E-06,   3.6995816E-06
     +,   3.2728713E-06,   2.8882107E-06,   2.5421361E-06
     +,   2.2314505E-06,   1.9531767E-06,   1.7045588E-06
     +,   1.4830586E-06,   1.2862830E-06,   1.1120246E-06
     +,   9.5819939E-07,   8.2288022E-07,   7.0425136E-07
     +,   6.0063718E-07,   5.1046635E-07,   4.3229639E-07
     +,   3.6478554E-07,   3.0671089E-07,   2.5694763E-07
     +,   2.1447363E-07,   1.7836747E-07,   1.4779498E-07
     +,   1.2201336E-07,   1.0035757E-07,   8.2241414E-08
     +,   6.7146097E-08,   5.4619189E-08,   4.4264617E-08
     +,   3.5740452E-08,   2.8750692E-08,   2.3042380E-08
     +,   1.8398820E-08,   1.4636684E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz115 = Yx/0.0773589743589744
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1944973E-06,   4.4705826E-06
     +,   4.7614353E-06,   5.0676117E-06,   5.3896720E-06
     +,   5.7281850E-06,   6.0837228E-06,   6.4568621E-06
     +,   6.8481836E-06,   7.2582839E-06,   7.6877486E-06
     +,   8.1371718E-06,   8.6071477E-06,   9.0982767E-06
     +,   9.6111535E-06,   1.0146380E-05,   1.0704555E-05
     +,   1.1286280E-05,   1.1892150E-05,   1.2522763E-05
     +,   1.3178709E-05,   1.3860586E-05,   1.4568966E-05
     +,   1.5304471E-05,   1.6067635E-05,   1.6859065E-05
     +,   1.7679322E-05,   1.8528965E-05,   1.9408553E-05
     +,   2.0318634E-05,   2.1259742E-05,   2.2232414E-05
     +,   2.3237168E-05,   2.4274503E-05,   2.5344931E-05
     +,   2.6448928E-05,   2.7586962E-05,   2.8759479E-05
     +,   2.9966975E-05,   3.1209809E-05,   3.2488460E-05
     +,   3.3803306E-05,   3.5154746E-05,   3.6543170E-05
     +,   3.7968963E-05,   3.9432503E-05,   4.0934185E-05
     +,   4.2474414E-05,   4.4053602E-05,   4.5672234E-05
     +,   4.7330803E-05,   4.9029888E-05,   5.0770133E-05
     +,   5.2552379E-05,   5.4377433E-05,   5.6246467E-05
     +,   5.8160724E-05,   6.0121714E-05,   6.2131272E-05
     +,   6.4191525E-05,   6.6304987E-05,   6.8474641E-05
     +,   7.0703813E-05,   7.2996518E-05,   7.5357399E-05
     +,   7.7791454E-05,   8.0304679E-05,   8.2903432E-05
     +,   8.5595115E-05,   8.8387511E-05,   9.1289461E-05
     +,   9.4310024E-05,   9.7459357E-05,   1.0074756E-04
     +,   1.0418556E-04,   1.0778440E-04,   1.1155500E-04
     +,   1.1550800E-04,   1.1965380E-04,   1.2400215E-04
     +,   1.2856114E-04,   1.3333811E-04,   1.3833793E-04
     +,   1.4356391E-04,   1.4901621E-04,   1.5469256E-04
     +,   1.6058692E-04,   1.6669033E-04,   1.7298924E-04
     +,   1.7946675E-04,   1.8610194E-04,   1.9286944E-04
     +,   1.9974002E-04,   2.0668124E-04,   2.1365739E-04
     +,   2.2062969E-04,   2.2755832E-04,   2.3440135E-04
     +,   2.4111802E-04,   2.4766746E-04,   2.5401244E-04
     +,   2.6011834E-04,   2.6595671E-04,   2.7150483E-04
     +,   2.7674841E-04,   2.8168221E-04,   2.8631126E-04
     +,   2.9065181E-04,   2.9473231E-04,   2.9859363E-04
     +,   3.0228839E-04,   3.0588193E-04,   3.0945020E-04
     +,   3.1307968E-04,   3.1686461E-04,   3.2090614E-04
     +,   3.2530926E-04,   3.3018095E-04,   3.3562648E-04
     +,   3.4174763E-04,   3.4863994E-04,   3.5638912E-04
     +,   3.6506954E-04,   3.7474176E-04,   3.8545154E-04
     +,   3.9722619E-04,   4.1007626E-04,   4.2399159E-04
     +,   4.3894371E-04,   4.5488199E-04,   4.7173662E-04
     +,   4.8941455E-04,   5.0780369E-04,   5.2676717E-04
     +,   5.4614863E-04,   5.6576979E-04,   5.8542989E-04
     +,   6.0490874E-04,   6.2396930E-04,   6.4235972E-04
     +,   6.5981614E-04,   6.7606976E-04,   6.9085381E-04
     +,   7.0391031E-04,   7.1499776E-04,   7.2390167E-04
     +,   7.3044380E-04,   7.3448993E-04,   7.3595834E-04
     +,   7.3482731E-04,   7.3113834E-04,   7.2500017E-04
     +,   7.1658957E-04,   7.0614862E-04,   6.9398113E-04
     +,   6.8044907E-04,   6.6596473E-04,   6.5098330E-04
     +,   6.3599565E-04,   6.2152359E-04,   6.0811028E-04
     +,   5.9631624E-04,   5.8671628E-04,   5.7989603E-04
     +,   5.7644839E-04,   5.7697401E-04,   5.8208051E-04
     +,   5.9237721E-04,   6.0847081E-04,   6.3095539E-04
     +,   6.6039333E-04,   6.9729576E-04,   7.4209872E-04
     +,   7.9514622E-04,   8.5666700E-04,   9.2678901E-04
     +,   1.0055474E-03,   1.0928970E-03,   1.1887143E-03
     +,   1.2927643E-03,   1.4045867E-03,   1.5233119E-03
     +,   1.6474500E-03,   1.7747192E-03,   1.9019985E-03
     +,   2.0255605E-03,   2.1416517E-03,   2.2474173E-03
     +,   2.3419701E-03,   2.4273389E-03,   2.5089395E-03
     +,   2.5951641E-03,   2.6960084E-03,   2.8208210E-03
     +,   2.9757179E-03,   3.1613472E-03,   3.3718930E-03
     +,   3.5959384E-03,   3.8194819E-03,   4.0306281E-03
     +,   4.2248941E-03,   4.4094711E-03,   4.6044388E-03
     +,   4.8393128E-03,   5.1449127E-03,   5.5423034E-03
     +,   6.0323738E-03,   6.5900669E-03,   7.1660685E-03
     +,   7.6955771E-03,   8.1110308E-03,   8.3545176E-03
     +,   8.3867339E-03,   8.1912465E-03,   7.7749998E-03
     +,   7.1663279E-03,   6.4110230E-03,   5.5663078E-03
     +,   4.6930858E-03,   3.8475138E-03,   3.0735848E-03
     +,   2.3991044E-03,   1.8354832E-03,   1.3806871E-03
     +,   1.0239078E-03,   7.5026962E-04,   5.4434768E-04
     +,   3.9214187E-04,   2.8181242E-04,   2.0367579E-04
     +,   1.4988179E-04,   1.1407114E-04,   9.1131347E-05
     +,   7.7038349E-05,   6.8728586E-05,   6.3966603E-05
     +,   6.1202460E-05,   5.9419926E-05,   5.7992558E-05
     +,   5.6561847E-05,   5.4942706E-05,   5.3056665E-05
     +,   5.0887538E-05,   4.8453981E-05,   4.5793447E-05
     +,   4.2953056E-05,   3.9983977E-05,   3.6937865E-05
     +,   3.3864730E-05,   3.0811680E-05,   2.7821066E-05
     +,   2.4929959E-05,   2.2169723E-05,   1.9565554E-05
     +,   1.7136259E-05,   1.4894652E-05,   1.2848051E-05
     +,   1.0998654E-05,   9.3440585E-06,   7.8781331E-06
     +,   6.5918261E-06,   5.4737607E-06,   4.5108850E-06
     +,   3.6891925E-06,   2.9943353E-06,   2.4119440E-06
     +,   1.9280974E-06,   1.5296399E-06,   1.2043485E-06
     +,   9.4105559E-07,   7.2975206E-07,   5.6161269E-07
     +,   4.2894746E-07,   3.2514296E-07,   2.4459305E-07
     +,   1.8260901E-07,   1.3530109E-07,   9.9492524E-08
     +,   7.2607584E-08,   5.2587868E-08,   3.7800056E-08
     +,   2.6965816E-08,   1.9091488E-08,   1.3414726E-08
     +,   9.3547143E-09,   6.4743642E-09,   4.4471058E-09
     +,   3.0315670E-09,   2.0510562E-09,   1.3772052E-09
     +,   9.1778912E-10,   6.0701522E-10,   3.9845713E-10
     +,   2.5958377E-10,   1.6784227E-10,   1.0770635E-10
     +,   6.8597864E-11,   4.3360791E-11,   2.7202971E-11
     +,   1.6937738E-11,   1.0467143E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz120 = Yx/0.0561944444444444
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.6658625E-06,   8.1281214E-06
     +,   8.6134050E-06,   9.1225256E-06,   9.6563008E-06
     +,   1.0215561E-05,   1.0801169E-05,   1.1414050E-05
     +,   1.2055226E-05,   1.2725925E-05,   1.3427604E-05
     +,   1.4162101E-05,   1.4931787E-05,   1.5739748E-05
     +,   1.6590035E-05,   1.7487941E-05,   1.8440369E-05
     +,   1.9456245E-05,   2.0546981E-05,   2.1727044E-05
     +,   2.3014514E-05,   2.4431758E-05,   2.6006021E-05
     +,   2.7770235E-05,   2.9763285E-05,   3.2030941E-05
     +,   3.4625868E-05,   3.7607864E-05,   4.1043746E-05
     +,   4.5006775E-05,   4.9575814E-05,   5.4833930E-05
     +,   6.0866620E-05,   6.7759560E-05,   7.5596050E-05
     +,   8.4454143E-05,   9.4403840E-05,   1.0550428E-04
     +,   1.1780253E-04,   1.3133019E-04,   1.4610609E-04
     +,   1.6213552E-04,   1.7941464E-04,   1.9793524E-04
     +,   2.1769204E-04,   2.3869135E-04,   2.6096101E-04
     +,   2.8456101E-04,   3.0959272E-04,   3.3620730E-04
     +,   3.6461119E-04,   3.9506663E-04,   4.2788812E-04
     +,   4.6343601E-04,   5.0209760E-04,   5.4427708E-04
     +,   5.9037167E-04,   6.4075459E-04,   6.9575984E-04
     +,   7.5567106E-04,   8.2071731E-04,   8.9107529E-04
     +,   9.6686441E-04,   1.0481642E-03,   1.1349970E-03
     +,   1.2273046E-03,   1.3249250E-03,   1.4275137E-03
     +,   1.5344915E-03,   1.6449420E-03,   1.7575647E-03
     +,   1.8706120E-03,   1.9819282E-03,   2.0889908E-03
     +,   2.1890826E-03,   2.2794751E-03,   2.3576654E-03
     +,   2.4216152E-03,   2.4699569E-03,   2.5021147E-03
     +,   2.5183435E-03,   2.5196560E-03,   2.5076850E-03
     +,   2.4844653E-03,   2.4522406E-03,   2.4132796E-03
     +,   2.3697712E-03,   2.3237932E-03,   2.2773622E-03
     +,   2.2325055E-03,   2.1913485E-03,   2.1561524E-03
     +,   2.1292579E-03,   2.1129418E-03,   2.1091772E-03
     +,   2.1193388E-03,   2.1438969E-03,   2.1821824E-03
     +,   2.2322622E-03,   2.2909704E-03,   2.3541299E-03
     +,   2.4169006E-03,   2.4742619E-03,   2.5215037E-03
     +,   2.5547019E-03,   2.5710652E-03,   2.5691325E-03
     +,   2.5488089E-03,   2.5112252E-03,   2.4584790E-03
     +,   2.3933181E-03,   2.3187909E-03,   2.2379681E-03
     +,   2.1537000E-03,   2.0685075E-03,   1.9845173E-03
     +,   1.9035120E-03,   1.8269798E-03,   1.7562072E-03
     +,   1.6923308E-03,   1.6363700E-03,   1.5892177E-03
     +,   1.5515770E-03,   1.5238816E-03,   1.5062070E-03
     +,   1.4981973E-03,   1.4990102E-03,   1.5073171E-03
     +,   1.5213486E-03,   1.5389877E-03,   1.5579045E-03
     +,   1.5757140E-03,   1.5901488E-03,   1.5992094E-03
     +,   1.6013072E-03,   1.5953610E-03,   1.5808443E-03
     +,   1.5578014E-03,   1.5268028E-03,   1.4888728E-03
     +,   1.4453891E-03,   1.3979608E-03,   1.3482996E-03
     +,   1.2981023E-03,   1.2489514E-03,   1.2022177E-03
     +,   1.1590074E-03,   1.1201320E-03,   1.0860916E-03
     +,   1.0570898E-03,   1.0330629E-03,   1.0137260E-03
     +,   9.9861796E-04,   9.8715327E-04,   9.7867334E-04
     +,   9.7249332E-04,   9.6794037E-04,   9.6438295E-04
     +,   9.6125645E-04,   9.5807784E-04,   9.5445436E-04
     +,   9.5008471E-04,   9.4475510E-04,   9.3833311E-04
     +,   9.3075586E-04,   9.2201878E-04,   9.1216248E-04
     +,   9.0126030E-04,   8.8940503E-04,   8.7670045E-04
     +,   8.6325203E-04,   8.4916130E-04,   8.3451899E-04
     +,   8.1940537E-04,   8.0388802E-04,   7.8802358E-04
     +,   7.7185739E-04,   7.5542810E-04,   7.3877018E-04
     +,   7.2191440E-04,   7.0489210E-04,   6.8773713E-04
     +,   6.7048817E-04,   6.5318518E-04,   6.3587417E-04
     +,   6.1860448E-04,   6.0142827E-04,   5.8439694E-04
     +,   5.6756096E-04,   5.5096898E-04,   5.3466315E-04
     +,   5.1867851E-04,   5.0304289E-04,   4.8777580E-04
     +,   4.7288561E-04,   4.5837148E-04,   4.4422544E-04
     +,   4.3043101E-04,   4.1696476E-04,   4.0379830E-04
     +,   3.9090114E-04,   3.7824106E-04,   3.6578544E-04
     +,   3.5350336E-04,   3.4136823E-04,   3.2935609E-04
     +,   3.1744799E-04,   3.0563120E-04,   2.9389831E-04
     +,   2.8224676E-04,   2.7067927E-04,   2.5920387E-04
     +,   2.4783300E-04,   2.3658184E-04,   2.2546831E-04
     +,   2.1451310E-04,   2.0373805E-04,   1.9316487E-04
     +,   1.8281525E-04,   1.7271104E-04,   1.6287192E-04
     +,   1.5331588E-04,   1.4405976E-04,   1.3511795E-04
     +,   1.2650204E-04,   1.1822119E-04,   1.1028264E-04
     +,   1.0269127E-04,   9.5449141E-05,   8.8556262E-05
     +,   8.2011109E-05,   7.5810356E-05,   6.9948626E-05
     +,   6.4419284E-05,   5.9214970E-05,   5.4326792E-05
     +,   4.9745100E-05,   4.5459845E-05,   4.1460433E-05
     +,   3.7735561E-05,   3.4273722E-05,   3.1063428E-05
     +,   2.8093053E-05,   2.5350748E-05,   2.2824703E-05
     +,   2.0503379E-05,   1.8375344E-05,   1.6429181E-05
     +,   1.4653728E-05,   1.3038227E-05,   1.1572028E-05
     +,   1.0244808E-05,   9.0466629E-06,   7.9680312E-06
     +,   6.9996590E-06,   6.1326973E-06,   5.3587692E-06
     +,   4.6699106E-06,   4.0585428E-06,   3.5175310E-06
     +,   3.0402209E-06,   2.6203895E-06,   2.2522183E-06
     +,   1.9303216E-06,   1.6497617E-06,   1.4059733E-06
     +,   1.1947841E-06,   1.0124070E-06,   8.5540506E-07
     +,   7.2066376E-07,   6.0538412E-07,   5.0706700E-07
     +,   4.2348142E-07,   3.5264051E-07,   2.9278775E-07
     +,   2.4238096E-07,   2.0006019E-07,   1.6464250E-07
     +,   1.3509343E-07,   1.1051981E-07,   9.0147068E-08
     +,   7.3311483E-08,   5.9441927E-08,   4.8052716E-08
     +,   3.8729237E-08,   3.1121441E-08,   2.4933028E-08
     +,   1.9914971E-08,   1.5859078E-08,   1.2591033E-08
     +,   9.9663131E-09,   7.8648243E-09,   6.1877024E-09
     +,   4.8534181E-09,   3.7953169E-09,   2.9588474E-09
     +,   2.2997277E-09,   1.7819727E-09,   1.3765810E-09
     +,   1.0601563E-09,   8.1397572E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz60 = Yx/0.0521111111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2231339E-05,   1.2474849E-05
     +,   1.2724149E-05,   1.2980324E-05,   1.3244625E-05
     +,   1.3518499E-05,   1.3803599E-05,   1.4101822E-05
     +,   1.4415313E-05,   1.4746517E-05,   1.5098191E-05
     +,   1.5473426E-05,   1.5875696E-05,   1.6308879E-05
     +,   1.6777296E-05,   1.7285722E-05,   1.7839449E-05
     +,   1.8444289E-05,   1.9106612E-05,   1.9833376E-05
     +,   2.0632140E-05,   2.1511081E-05,   2.2478993E-05
     +,   2.3545381E-05,   2.4720246E-05,   2.6014357E-05
     +,   2.7438986E-05,   2.9005996E-05,   3.0727770E-05
     +,   3.2617132E-05,   3.4687258E-05,   3.6951613E-05
     +,   3.9423769E-05,   4.2117299E-05,   4.5045563E-05
     +,   4.8221522E-05,   5.1657480E-05,   5.5364773E-05
     +,   5.9353741E-05,   6.3632739E-05,   6.8208683E-05
     +,   7.3086005E-05,   7.8266610E-05,   8.3749575E-05
     +,   8.9530848E-05,   9.5603194E-05,   1.0195616E-04
     +,   1.0857638E-04,   1.1544787E-04,   1.2255300E-04
     +,   1.2987334E-04,   1.3739124E-04,   1.4509152E-04
     +,   1.5296428E-04,   1.6100606E-04,   1.6922443E-04
     +,   1.7763957E-04,   1.8628806E-04,   1.9522558E-04
     +,   2.0452953E-04,   2.1430122E-04,   2.2466746E-04
     +,   2.3578016E-04,   2.4781737E-04,   2.6098161E-04
     +,   2.7549634E-04,   2.9160714E-04,   3.0957739E-04
     +,   3.2969430E-04,   3.5227078E-04,   3.7766353E-04
     +,   4.0628872E-04,   4.3866097E-04,   4.7542664E-04
     +,   5.1742286E-04,   5.6573306E-04,   6.2174402E-04
     +,   6.8720966E-04,   7.6431682E-04,   8.5573958E-04
     +,   9.6468488E-04,   1.0949604E-03,   1.2509607E-03
     +,   1.4376272E-03,   1.6601696E-03,   1.9235600E-03
     +,   2.2315194E-03,   2.5851855E-03,   2.9813477E-03
     +,   3.4109852E-03,   3.8584543E-03,   4.3020742E-03
     +,   4.7164964E-03,   5.0766189E-03,   5.3620278E-03
     +,   5.5608517E-03,   5.6718877E-03,   5.7041547E-03
     +,   5.6743310E-03,   5.6028198E-03,   5.5096485E-03
     +,   5.4112598E-03,   5.3187101E-03,   5.2375072E-03
     +,   5.1686335E-03,   5.1102876E-03,   5.0595137E-03
     +,   5.0132009E-03,   4.9681291E-03,   4.9204109E-03
     +,   4.8649814E-03,   4.7958116E-03,   4.7072121E-03
     +,   4.5958008E-03,   4.4624326E-03,   4.3130228E-03
     +,   4.1579735E-03,   4.0101190E-03,   3.8820358E-03
     +,   3.7834435E-03,   3.7195263E-03,   3.6904083E-03
     +,   3.6917364E-03,   3.7159864E-03,   3.7541219E-03
     +,   3.7971579E-03,   3.8374939E-03,   3.8697398E-03
     +,   3.8910813E-03,   3.9010304E-03,   3.9007361E-03
     +,   3.8919626E-03,   3.8760593E-03,   3.8532107E-03
     +,   3.8221455E-03,   3.7804267E-03,   3.7251441E-03
     +,   3.6537878E-03,   3.5649948E-03,   3.4589546E-03
     +,   3.3374242E-03,   3.2033669E-03,   3.0603567E-03
     +,   2.9120266E-03,   2.7616189E-03,   2.6117498E-03
     +,   2.4643850E-03,   2.3209914E-03,   2.1826860E-03
     +,   2.0503863E-03,   1.9248932E-03,   1.8069176E-03
     +,   1.6970386E-03,   1.5956379E-03,   1.5028847E-03
     +,   1.4187306E-03,   1.3429296E-03,   1.2750763E-03
     +,   1.2146760E-03,   1.1611988E-03,   1.1141102E-03
     +,   1.0728990E-03,   1.0370885E-03,   1.0062188E-03
     +,   9.7983528E-04,   9.5746963E-04,   9.3863043E-04
     +,   9.2279137E-04,   9.0939488E-04,   8.9786283E-04
     +,   8.8761159E-04,   8.7807194E-04,   8.6870801E-04
     +,   8.5903780E-04,   8.4865105E-04,   8.3721848E-04
     +,   8.2450279E-04,   8.1036059E-04,   7.9474214E-04
     +,   7.7768246E-04,   7.5929251E-04,   7.3974824E-04
     +,   7.1927288E-04,   6.9811946E-04,   6.7655498E-04
     +,   6.5484451E-04,   6.3323573E-04,   6.1194587E-04
     +,   5.9115241E-04,   5.7099084E-04,   5.5154663E-04
     +,   5.3285988E-04,   5.1492866E-04,   4.9771543E-04
     +,   4.8115230E-04,   4.6515156E-04,   4.4961533E-04
     +,   4.3444237E-04,   4.1953512E-04,   4.0480547E-04
     +,   3.9018170E-04,   3.7560868E-04,   3.6104920E-04
     +,   3.4648445E-04,   3.3191437E-04,   3.1735247E-04
     +,   3.0282498E-04,   2.8836846E-04,   2.7402648E-04
     +,   2.5984549E-04,   2.4587338E-04,   2.3215848E-04
     +,   2.1874641E-04,   2.0567857E-04,   1.9299163E-04
     +,   1.8071827E-04,   1.6888576E-04,   1.5751517E-04
     +,   1.4662274E-04,   1.3622089E-04,   1.2631644E-04
     +,   1.1691242E-04,   1.0800869E-04,   9.9601952E-05
     +,   9.1685441E-05,   8.4250009E-05,   7.7284807E-05
     +,   7.0777045E-05,   6.4711909E-05,   5.9073202E-05
     +,   5.3844044E-05,   4.9006539E-05,   4.4541765E-05
     +,   4.0430346E-05,   3.6652968E-05,   3.3189790E-05
     +,   3.0021054E-05,   2.7127444E-05,   2.4489942E-05
     +,   2.2089867E-05,   1.9909168E-05,   1.7930692E-05
     +,   1.6138018E-05,   1.4515487E-05,   1.3048378E-05
     +,   1.1722990E-05,   1.0526550E-05,   9.4471543E-06
     +,   8.4738276E-06,   7.5965918E-06,   6.8062213E-06
     +,   6.0943212E-06,   5.4533089E-06,   4.8763009E-06
     +,   4.3570390E-06,   3.8898725E-06,   3.4697352E-06
     +,   3.0920594E-06,   2.7527017E-06,   2.4479314E-06
     +,   2.1744074E-06,   1.9291117E-06,   1.7093031E-06
     +,   1.5125078E-06,   1.3365055E-06,   1.1792674E-06
     +,   1.0389567E-06,   9.1391547E-07,   8.0263811E-07
     +,   7.0374836E-07,   6.1599843E-07,   5.3825886E-07
     +,   4.6950356E-07,   4.0879576E-07,   3.5528601E-07
     +,   3.0820920E-07,   2.6686624E-07,   2.3062952E-07
     +,   1.9892765E-07,   1.7124948E-07,   1.4713089E-07
     +,   1.2615799E-07,   1.0795672E-07,   9.2194618E-08
     +,   7.8572533E-08,   6.6825578E-08,   5.6716942E-08
     +,   4.8036657E-08,   4.0599513E-08,   3.4241054E-08
     +,   2.8817121E-08,   2.4200355E-08,   2.0279638E-08
     +,   1.6957278E-08,   1.4148502E-08,   1.1779138E-08
     +,   9.7851371E-09,   8.1107441E-09,   6.7080581E-09
     +,   5.5356280E-09,   4.5579793E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz65 = Yx/0.0775384615384615
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2490467E-05,   1.2826990E-05
     +,   1.3164833E-05,   1.3503781E-05,   1.3843627E-05
     +,   1.4184182E-05,   1.4525275E-05,   1.4866741E-05
     +,   1.5208451E-05,   1.5550291E-05,   1.5892170E-05
     +,   1.6234029E-05,   1.6575834E-05,   1.6917580E-05
     +,   1.7259305E-05,   1.7601076E-05,   1.7943004E-05
     +,   1.8285242E-05,   1.8627979E-05,   1.8971466E-05
     +,   1.9315996E-05,   1.9661917E-05,   2.0009629E-05
     +,   2.0359626E-05,   2.0712416E-05,   2.1068627E-05
     +,   2.1428945E-05,   2.1794136E-05,   2.2165061E-05
     +,   2.2542688E-05,   2.2928076E-05,   2.3322400E-05
     +,   2.3726967E-05,   2.4143208E-05,   2.4572695E-05
     +,   2.5017156E-05,   2.5478459E-05,   2.5958652E-05
     +,   2.6459978E-05,   2.6984791E-05,   2.7535711E-05
     +,   2.8115493E-05,   2.8727109E-05,   2.9373698E-05
     +,   3.0058603E-05,   3.0785373E-05,   3.1557742E-05
     +,   3.2379630E-05,   3.3255219E-05,   3.4188877E-05
     +,   3.5185298E-05,   3.6249447E-05,   3.7386737E-05
     +,   3.8603106E-05,   3.9905059E-05,   4.1300034E-05
     +,   4.2796470E-05,   4.4404140E-05,   4.6134486E-05
     +,   4.8000966E-05,   5.0019506E-05,   5.2208961E-05
     +,   5.4591412E-05,   5.7192967E-05,   6.0044029E-05
     +,   6.3179410E-05,   6.6639259E-05,   7.0468406E-05
     +,   7.4717304E-05,   7.9440848E-05,   8.4699197E-05
     +,   9.0556059E-05,   9.7079530E-05,   1.0434017E-04
     +,   1.1241199E-04,   1.2137224E-04,   1.3130158E-04
     +,   1.4228656E-04,   1.5442426E-04,   1.6782791E-04
     +,   1.8263496E-04,   1.9902345E-04,   2.1722565E-04
     +,   2.3755335E-04,   2.6041549E-04,   2.8634325E-04
     +,   3.1599627E-04,   3.5016669E-04,   3.8975169E-04
     +,   4.3572561E-04,   4.8909785E-04,   5.5088074E-04
     +,   6.2210724E-04,   7.0391304E-04,   7.9770066E-04
     +,   9.0540183E-04,   1.0299083E-03,   1.1756155E-03
     +,   1.3492033E-03,   1.5604361E-03,   1.8228606E-03
     +,   2.1536672E-03,   2.5721544E-03,   3.0957060E-03
     +,   3.7333034E-03,   4.4773282E-03,   5.2968375E-03
     +,   6.1371960E-03,   6.9299676E-03,   7.6119658E-03
     +,   8.1459433E-03,   8.5318601E-03,   8.8002617E-03
     +,   8.9906920E-03,   9.1274073E-03,   9.2097595E-03
     +,   9.2259394E-03,   9.1818832E-03,   9.1203293E-03
     +,   9.1069043E-03,   9.1860192E-03,   9.3402462E-03
     +,   9.4907982E-03,   9.5421774E-03,   9.4340974E-03
     +,   9.1616632E-03,   8.7606041E-03,   8.2850093E-03
     +,   7.7966200E-03,   7.3588993E-03,   7.0215096E-03
     +,   6.7995475E-03,   6.6666300E-03,   6.5726740E-03
     +,   6.4753522E-03,   6.3624466E-03,   6.2507894E-03
     +,   6.1659398E-03,   6.1192606E-03,   6.0968916E-03
     +,   6.0644094E-03,   5.9811976E-03,   5.8159432E-03
     +,   5.5568367E-03,   5.2141827E-03,   4.8159128E-03
     +,   4.3987259E-03,   3.9982246E-03,   3.6410401E-03
     +,   3.3407791E-03,   3.0981728E-03,   2.9043865E-03
     +,   2.7457713E-03,   2.6083717E-03,   2.4809914E-03
     +,   2.3564356E-03,   2.2313050E-03,   2.1050174E-03
     +,   1.9787005E-03,   1.8542821E-03,   1.7338311E-03
     +,   1.6191780E-03,   1.5117181E-03,   1.4123128E-03
     +,   1.3212933E-03,   1.2385424E-03,   1.1636120E-03
     +,   1.0958462E-03,   1.0344893E-03,   9.7878196E-04
     +,   9.2802133E-04,   8.8158343E-04,   8.3892915E-04
     +,   7.9960114E-04,   7.6321437E-04,   7.2943716E-04
     +,   6.9798518E-04,   6.6861504E-04,   6.4111635E-04
     +,   6.1530649E-04,   5.9102842E-04,   5.6814816E-04
     +,   5.4654939E-04,   5.2612752E-04,   5.0678878E-04
     +,   4.8844708E-04,   4.7102038E-04,   4.5442855E-04
     +,   4.3859356E-04,   4.2344059E-04,   4.0889584E-04
     +,   3.9488843E-04,   3.8135212E-04,   3.6822562E-04
     +,   3.5545189E-04,   3.4297985E-04,   3.3076506E-04
     +,   3.1876954E-04,   3.0696034E-04,   2.9531057E-04
     +,   2.8379963E-04,   2.7241214E-04,   2.6113761E-04
     +,   2.4996977E-04,   2.3890831E-04,   2.2795581E-04
     +,   2.1711893E-04,   2.0640832E-04,   1.9583784E-04
     +,   1.8542311E-04,   1.7518192E-04,   1.6513420E-04
     +,   1.5530104E-04,   1.4570319E-04,   1.3636137E-04
     +,   1.2729630E-04,   1.1852766E-04,   1.1007289E-04
     +,   1.0194771E-04,   9.4166331E-05,   8.6739827E-05
     +,   7.9676625E-05,   7.2983006E-05,   6.6662462E-05
     +,   6.0715400E-05,   5.5139652E-05,   4.9931015E-05
     +,   4.5082939E-05,   4.0586503E-05,   3.6430996E-05
     +,   3.2604403E-05,   2.9093322E-05,   2.5883068E-05
     +,   2.2958147E-05,   2.0302750E-05,   1.7900442E-05
     +,   1.5734633E-05,   1.3788939E-05,   1.2047137E-05
     +,   1.0493231E-05,   9.1117245E-06,   7.8877947E-06
     +,   6.8072573E-06,   5.8565824E-06,   5.0230301E-06
     +,   4.2947231E-06,   3.6605879E-06,   3.1103375E-06
     +,   2.6345058E-06,   2.2244760E-06,   1.8723538E-06
     +,   1.5709935E-06,   1.3139748E-06,   1.0955345E-06
     +,   9.1051447E-07,   7.5433553E-07,   6.2295925E-07
     +,   5.1282962E-07,   4.2082411E-07,   3.4422095E-07
     +,   2.8066276E-07,   2.2810984E-07,   1.8480382E-07
     +,   1.4923839E-07,   1.2013170E-07,   9.6391247E-08
     +,   7.7093091E-08,   6.1460078E-08,   4.8839556E-08
     +,   3.8685329E-08,   3.0543010E-08,   2.4036412E-08
     +,   1.8854763E-08,   1.4742133E-08,   1.1488989E-08
     +,   8.9246317E-09,   6.9099650E-09,   5.3326494E-09
     +,   4.1018700E-09,   3.1448246E-09,   2.4031301E-09
     +,   1.8303228E-09,   1.3894320E-09,   1.0512600E-09
     +,   7.9274831E-10,   5.9582189E-10,   4.4632087E-10
     +,   3.3321013E-10,   2.4793334E-10,   1.8385882E-10
     +,   1.3588508E-10,   1.0008842E-10,   7.3472610E-11
     +,   5.3750737E-11,   3.9189020E-11,   2.8474305E-11
     +,   2.0618450E-11,   1.4878486E-11,   1.0699577E-11
     +,   7.6677432E-12,   5.4760285E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz70 = Yx/0.095375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6955179E-06,   1.6728989E-06
     +,   1.6555192E-06,   1.6434110E-06,   1.6366042E-06
     +,   1.6351260E-06,   1.6390018E-06,   1.6482542E-06
     +,   1.6629051E-06,   1.6829752E-06,   1.7084832E-06
     +,   1.7394465E-06,   1.7758852E-06,   1.8178154E-06
     +,   1.8652561E-06,   1.9182266E-06,   1.9767479E-06
     +,   2.0408434E-06,   2.1105386E-06,   2.1858641E-06
     +,   2.2668551E-06,   2.3535517E-06,   2.4460007E-06
     +,   2.5442632E-06,   2.6483992E-06,   2.7584915E-06
     +,   2.8746292E-06,   2.9969192E-06,   3.1254842E-06
     +,   3.2604673E-06,   3.4020338E-06,   3.5503729E-06
     +,   3.7057018E-06,   3.8682679E-06,   4.0383538E-06
     +,   4.2162796E-06,   4.4024100E-06,   4.5971551E-06
     +,   4.8009865E-06,   5.0144245E-06,   5.2380765E-06
     +,   5.4726179E-06,   5.7188208E-06,   5.9775643E-06
     +,   6.2498466E-06,   6.5368117E-06,   6.8397685E-06
     +,   7.1602153E-06,   7.4998738E-06,   7.8607209E-06
     +,   8.2450324E-06,   8.6554182E-06,   9.0948652E-06
     +,   9.5668329E-06,   1.0075210E-05,   1.0624489E-05
     +,   1.1219731E-05,   1.1866657E-05,   1.2571694E-05
     +,   1.3342024E-05,   1.4185609E-05,   1.5111237E-05
     +,   1.6128462E-05,   1.7247725E-05,   1.8480278E-05
     +,   1.9838006E-05,   2.1333652E-05,   2.2980403E-05
     +,   2.4792163E-05,   2.6783060E-05,   2.8967774E-05
     +,   3.1360960E-05,   3.3977714E-05,   3.6832895E-05
     +,   3.9941689E-05,   4.3319400E-05,   4.6981313E-05
     +,   5.0942985E-05,   5.5220786E-05,   5.9831968E-05
     +,   6.4794629E-05,   7.0129186E-05,   7.5857803E-05
     +,   8.2006489E-05,   8.8604385E-05,   9.5686526E-05
     +,   1.0329307E-04,   1.1147250E-04,   1.2028076E-04
     +,   1.2978456E-04,   1.4006197E-04,   1.5120345E-04
     +,   1.6331459E-04,   1.7652049E-04,   1.9097063E-04
     +,   2.0684702E-04,   2.2438199E-04,   2.4387745E-04
     +,   2.6574318E-04,   2.9053944E-04,   3.1904958E-04
     +,   3.5235923E-04,   3.9197115E-04,   4.3991345E-04
     +,   4.9885752E-04,   5.7217892E-04,   6.6391809E-04
     +,   7.7859400E-04,   9.2083105E-04,   1.0947746E-03
     +,   1.3033381E-03,   1.5474574E-03,   1.8253137E-03
     +,   2.1319059E-03,   2.4589596E-03,   2.7958886E-03
     +,   3.1321668E-03,   3.4620590E-03,   3.7913853E-03
     +,   4.1449876E-03,   4.5704148E-03,   5.1314514E-03
     +,   5.8856984E-03,   6.8486175E-03,   7.9627233E-03
     +,   9.1048991E-03,   1.0151276E-02,   1.1063958E-02
     +,   1.1916599E-02,   1.2808046E-02,   1.3734418E-02
     +,   1.4557275E-02,   1.5114748E-02,   1.5362273E-02
     +,   1.5406563E-02,   1.5412519E-02,   1.5467057E-02
     +,   1.5508086E-02,   1.5387496E-02,   1.5015537E-02
     +,   1.4428047E-02,   1.3709203E-02,   1.2899478E-02
     +,   1.2019055E-02,   1.1146611E-02,   1.0415958E-02
     +,   9.9220406E-03,   9.6458448E-03,   9.4733788E-03
     +,   9.2775365E-03,   8.9838589E-03,   8.5787568E-03
     +,   8.0781737E-03,   7.4987276E-03,   6.8534445E-03
     +,   6.1629904E-03,   5.4624304E-03,   4.7947969E-03
     +,   4.1975304E-03,   3.6919471E-03,   3.2809738E-03
     +,   2.9541997E-03,   2.6954541E-03,   2.4890203E-03
     +,   2.3227753E-03,   2.1886728E-03,   2.0817069E-03
     +,   1.9985414E-03,   1.9364569E-03,   1.8927542E-03
     +,   1.8644996E-03,   1.8484814E-03,   1.8412726E-03
     +,   1.8393635E-03,   1.8393263E-03,   1.8379948E-03
     +,   1.8326306E-03,   1.8210517E-03,   1.8017105E-03
     +,   1.7736987E-03,   1.7367080E-03,   1.6909525E-03
     +,   1.6370632E-03,   1.5759766E-03,   1.5088295E-03
     +,   1.4368740E-03,   1.3613953E-03,   1.2836494E-03
     +,   1.2048250E-03,   1.1260216E-03,   1.0482178E-03
     +,   9.7227003E-04,   8.9891371E-04,   8.2875765E-04
     +,   7.6228200E-04,   6.9984782E-04,   6.4170366E-04
     +,   5.8798899E-04,   5.3873751E-04,   4.9388985E-04
     +,   4.5330732E-04,   4.1678114E-04,   3.8404245E-04
     +,   3.5478058E-04,   3.2865923E-04,   3.0532439E-04
     +,   2.8442044E-04,   2.6560295E-04,   2.4854642E-04
     +,   2.3295176E-04,   2.1855232E-04,   2.0511924E-04
     +,   1.9246158E-04,   1.8042534E-04,   1.6889295E-04
     +,   1.5778074E-04,   1.4703437E-04,   1.3662345E-04
     +,   1.2653758E-04,   1.1678266E-04,   1.0737407E-04
     +,   9.8333767E-05,   8.9687172E-05,   8.1459606E-05
     +,   7.3673407E-05,   6.6346875E-05,   5.9493585E-05
     +,   5.3121177E-05,   4.7230867E-05,   4.1818053E-05
     +,   3.6873073E-05,   3.2381362E-05,   2.8323979E-05
     +,   2.4678731E-05,   2.1421291E-05,   1.8525228E-05
     +,   1.5963178E-05,   1.3707585E-05,   1.1731061E-05
     +,   1.0006764E-05,   8.5089196E-06,   7.2132025E-06
     +,   6.0968068E-06,   5.1385218E-06,   4.3189089E-06
     +,   3.6203501E-06,   3.0269493E-06,   2.5244472E-06
     +,   2.1001870E-06,   1.7430405E-06,   1.4432087E-06
     +,   1.1921539E-06,   9.8248540E-07,   8.0782041E-07
     +,   6.6266171E-07,   5.4230770E-07,   4.4275771E-07
     +,   3.6061027E-07,   2.9297976E-07,   2.3743067E-07
     +,   1.9191599E-07,   1.5471561E-07,   1.2438595E-07
     +,   9.9720943E-08,   7.9717346E-08,   6.3537939E-08
     +,   5.0488325E-08,   3.9994095E-08,   3.1580523E-08
     +,   2.4855726E-08,   1.9497724E-08,   1.5242854E-08
     +,   1.1875451E-08,   9.2194767E-09,   7.1319355E-09
     +,   5.4971592E-09,   4.2215391E-09,   3.2299305E-09
     +,   2.4619597E-09,   1.8695012E-09,   1.4141811E-09
     +,   1.0656456E-09,   7.9988988E-10,   5.9807281E-10
     +,   4.4541648E-10,   3.3042027E-10,   2.4414279E-10
     +,   1.7967414E-10,   1.3170286E-10,   9.6151975E-11
     +,   6.9916281E-11,   5.0634181E-11,   3.6522351E-11
     +,   2.6236869E-11,   1.8771956E-11,   1.3376423E-11
     +,   9.4931866E-12,   6.7098644E-12,   4.7233927E-12
     +,   3.3114906E-12,   2.3122307E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz75 = Yx/0.121560975609756
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0956491E-06,   8.9801488E-06
     +,   8.8624720E-06,   8.7436038E-06,   8.6245609E-06
     +,   8.5063857E-06,   8.3901432E-06,   8.2769211E-06
     +,   8.1678190E-06,   8.0639456E-06,   7.9664205E-06
     +,   7.8763615E-06,   7.7948853E-06,   7.7230989E-06
     +,   7.6621018E-06,   7.6129727E-06,   7.5767671E-06
     +,   7.5545190E-06,   7.5472271E-06,   7.5558551E-06
     +,   7.5813250E-06,   7.6245142E-06,   7.6862443E-06
     +,   7.7672921E-06,   7.8683606E-06,   7.9901001E-06
     +,   8.1330845E-06,   8.2978195E-06,   8.4847279E-06
     +,   8.6941563E-06,   8.9263658E-06,   9.1815282E-06
     +,   9.4597281E-06,   9.7609536E-06,   1.0085100E-05
     +,   1.0431969E-05,   1.0801262E-05,   1.1192577E-05
     +,   1.1605445E-05,   1.2039250E-05,   1.2493335E-05
     +,   1.2966922E-05,   1.3459156E-05,   1.3969096E-05
     +,   1.4495731E-05,   1.5037977E-05,   1.5594693E-05
     +,   1.6164680E-05,   1.6746711E-05,   1.7339518E-05
     +,   1.7941824E-05,   1.8552360E-05,   1.9169853E-05
     +,   1.9793113E-05,   2.0420934E-05,   2.1052258E-05
     +,   2.1686086E-05,   2.2321554E-05,   2.2957951E-05
     +,   2.3594750E-05,   2.4231624E-05,   2.4868503E-05
     +,   2.5505527E-05,   2.6143207E-05,   2.6782378E-05
     +,   2.7424165E-05,   2.8070175E-05,   2.8722343E-05
     +,   2.9383122E-05,   3.0055340E-05,   3.0742383E-05
     +,   3.1448020E-05,   3.2176598E-05,   3.2932843E-05
     +,   3.3721986E-05,   3.4549703E-05,   3.5421999E-05
     +,   3.6345195E-05,   3.7325957E-05,   3.8371159E-05
     +,   3.9487677E-05,   4.0682567E-05,   4.1962678E-05
     +,   4.3334850E-05,   4.4805518E-05,   4.6380945E-05
     +,   4.8066828E-05,   4.9868620E-05,   5.1791110E-05
     +,   5.3838809E-05,   5.6015939E-05,   5.8326365E-05
     +,   6.0773938E-05,   6.3363012E-05,   6.6098655E-05
     +,   6.8986905E-05,   7.2036004E-05,   7.5256547E-05
     +,   7.8663063E-05,   8.2274506E-05,   8.6116554E-05
     +,   9.0222340E-05,   9.4635914E-05,   9.9413941E-05
     +,   1.0463063E-04,   1.1038255E-04,   1.1679503E-04
     +,   1.2403158E-04,   1.3230617E-04,   1.4189738E-04
     +,   1.5316423E-04,   1.6656652E-04,   1.8267857E-04
     +,   2.0220497E-04,   2.2597880E-04,   2.5495567E-04
     +,   2.9017840E-04,   3.3273865E-04,   3.8370831E-04
     +,   4.4409250E-04,   5.1479490E-04,   5.9663819E-04
     +,   6.9047592E-04,   7.9740322E-04,   9.1900979E-04
     +,   1.0575831E-03,   1.2161939E-03,   1.3985424E-03
     +,   1.6090045E-03,   1.8534310E-03,   2.1417644E-03
     +,   2.4924567E-03,   2.9374331E-03,   3.5238543E-03
     +,   4.3078810E-03,   5.3342455E-03,   6.6016666E-03
     +,   8.0371499E-03,   9.5267463E-03,   1.1013188E-02
     +,   1.2564536E-02,   1.4314200E-02,   1.6355798E-02
     +,   1.8720662E-02,   2.1352027E-02,   2.4039991E-02
     +,   2.6491432E-02,   2.8391605E-02,   2.9259147E-02
     +,   2.8779790E-02,   2.7460391E-02,   2.6060790E-02
     +,   2.4699960E-02,   2.3290897E-02,   2.2016702E-02
     +,   2.0910667E-02,   1.9685447E-02,   1.8173583E-02
     +,   1.6492646E-02,   1.4829093E-02,   1.3337892E-02
     +,   1.2107751E-02,   1.1081022E-02,   1.0097306E-02
     +,   9.0476945E-03,   7.9520131E-03,   6.9107907E-03
     +,   6.0181497E-03,   5.3108288E-03,   4.7686771E-03
     +,   4.3430817E-03,   3.9848615E-03,   3.6588125E-03
     +,   3.3466017E-03,   3.0437149E-03,   2.7542349E-03
     +,   2.4856406E-03,   2.2447763E-03,   2.0356216E-03
     +,   1.8587866E-03,   1.7121227E-03,   1.5917153E-03
     +,   1.4927945E-03,   1.4104287E-03,   1.3400096E-03
     +,   1.2775662E-03,   1.2199387E-03,   1.1648413E-03
     +,   1.1108309E-03,   1.0572091E-03,   1.0038632E-03
     +,   9.5111021E-04,   8.9954323E-04,   8.4988610E-04
     +,   8.0287154E-04,   7.5915328E-04,   7.1924255E-04
     +,   6.8346359E-04,   6.5193354E-04,   6.2456849E-04
     +,   6.0110108E-04,   5.8110594E-04,   5.6403258E-04
     +,   5.4924475E-04,   5.3605926E-04,   5.2377908E-04
     +,   5.1173021E-04,   4.9929228E-04,   4.8592631E-04
     +,   4.7119410E-04,   4.5477715E-04,   4.3648621E-04
     +,   4.1626455E-04,   3.9418144E-04,   3.7042241E-04
     +,   3.4527350E-04,   3.1909809E-04,   2.9231011E-04
     +,   2.6534911E-04,   2.3865729E-04,   2.1265104E-04
     +,   1.8770406E-04,   1.6413377E-04,   1.4219007E-04
     +,   1.2204927E-04,   1.0381633E-04,   8.7530098E-05
     +,   7.3169620E-05,   6.0663042E-05,   4.9899758E-05
     +,   4.0742023E-05,   3.3034496E-05,   2.6613263E-05
     +,   2.1314487E-05,   1.6980872E-05,   1.3465185E-05
     +,   1.0633825E-05,   8.3684581E-06,   6.5662166E-06
     +,   5.1392317E-06,   4.0138057E-06,   3.1290588E-06
     +,   2.4352601E-06,   1.8922037E-06,   1.4677369E-06
     +,   1.1363571E-06,   8.7792625E-07,   6.7659630E-07
     +,   5.1994817E-07,   3.9827066E-07,   3.0394654E-07
     +,   2.3101060E-07,   1.7478820E-07,   1.3160698E-07
     +,   9.8578013E-08,   7.3430542E-08,   5.4381935E-08
     +,   4.0032663E-08,   2.9286136E-08,   2.1287123E-08
     +,   1.5371574E-08,   1.1025969E-08,   7.8552915E-09
     +,   5.5579190E-09,   3.9052255E-09,   2.7247902E-09
     +,   1.8877644E-09,   1.2986121E-09,   8.8698970E-10
     +,   6.0152111E-10,   4.0500589E-10,   2.7073771E-10
     +,   1.7968602E-10,   1.1839901E-10,   7.7453446E-11
     +,   5.0304070E-11,   3.2435485E-11,   2.0763703E-11
     +,   1.3196056E-11,   8.3262815E-12,   5.2157163E-12
     +,   3.2437555E-12,   2.0028241E-12,   1.2277725E-12
     +,   7.4724938E-13,   4.5155148E-13,   2.7092469E-13
     +,   1.6139871E-13,   9.5477100E-14,   5.6087350E-14
     +,   3.2723390E-14,   1.8963904E-14,   1.0918920E-14
     +,   6.2477853E-15,   3.5543789E-15,   2.0115410E-15
     +,   1.1334426E-15,   6.3659100E-16,   3.5697004E-16
     +,   2.0028904E-16,   1.1278377E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz80 = Yx/0.152860465116279
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7313193E-08,   5.5505414E-08
     +,   6.4982103E-08,   7.5920326E-08,   8.8517382E-08
     +,   1.0299245E-07,   1.1958842E-07,   1.3857337E-07
     +,   1.6024231E-07,   1.8491993E-07,   2.1296036E-07
     +,   2.4475020E-07,   2.8070957E-07,   3.2129336E-07
     +,   3.6699288E-07,   4.1833627E-07,   4.7589009E-07
     +,   5.4025872E-07,   6.1208596E-07,   6.9205345E-07
     +,   7.8088112E-07,   8.7932614E-07,   9.8817929E-07
     +,   1.1082734E-06,   1.2404579E-06,   1.3856272E-06
     +,   1.5446925E-06,   1.7185882E-06,   1.9082684E-06
     +,   2.1146991E-06,   2.3388561E-06,   2.5817185E-06
     +,   2.8442660E-06,   3.1274685E-06,   3.4322877E-06
     +,   3.7596676E-06,   4.1105304E-06,   4.4857698E-06
     +,   4.8862757E-06,   5.3128661E-06,   5.7663701E-06
     +,   6.2475642E-06,   6.7572028E-06,   7.2960183E-06
     +,   7.8647245E-06,   8.4640269E-06,   9.0946342E-06
     +,   9.7572720E-06,   1.0452699E-05,   1.1181721E-05
     +,   1.1945226E-05,   1.2744197E-05,   1.3579735E-05
     +,   1.4453152E-05,   1.5365855E-05,   1.6319582E-05
     +,   1.7316272E-05,   1.8358183E-05,   1.9447911E-05
     +,   2.0588432E-05,   2.1783126E-05,   2.3035831E-05
     +,   2.4350751E-05,   2.5732679E-05,   2.7186881E-05
     +,   2.8718963E-05,   3.0335128E-05,   3.2041797E-05
     +,   3.3845903E-05,   3.5754427E-05,   3.7774658E-05
     +,   3.9913648E-05,   4.2178490E-05,   4.4575630E-05
     +,   4.7111102E-05,   4.9790120E-05,   5.2616637E-05
     +,   5.5593184E-05,   5.8720918E-05,   6.1999104E-05
     +,   6.5424596E-05,   6.8992413E-05,   7.2694667E-05
     +,   7.6521465E-05,   8.0459926E-05,   8.4495281E-05
     +,   8.8609930E-05,   9.2784954E-05,   9.6999262E-05
     +,   1.0123113E-04,   1.0545838E-04,   1.0965860E-04
     +,   1.1381041E-04,   1.1789436E-04,   1.2189340E-04
     +,   1.2579341E-04,   1.2958476E-04,   1.3326206E-04
     +,   1.3682563E-04,   1.4028116E-04,   1.4364095E-04
     +,   1.4692309E-04,   1.5015257E-04,   1.5336023E-04
     +,   1.5658319E-04,   1.5986434E-04,   1.6325139E-04
     +,   1.6679647E-04,   1.7055585E-04,   1.7458855E-04
     +,   1.7895519E-04,   1.8371771E-04,   1.8893699E-04
     +,   1.9467298E-04,   2.0098142E-04,   2.0791424E-04
     +,   2.1551611E-04,   2.2382506E-04,   2.3286982E-04
     +,   2.4267157E-04,   2.5324494E-04,   2.6460062E-04
     +,   2.7675208E-04,   2.8972773E-04,   3.0358718E-04
     +,   3.1844660E-04,   3.3452449E-04,   3.5220018E-04
     +,   3.7210895E-04,   3.9525895E-04,   4.2318460E-04
     +,   4.5809525E-04,   5.0300639E-04,   5.6175841E-04
     +,   6.3889171E-04,   7.3928299E-04,   8.6753420E-04
     +,   1.0272143E-03,   1.2201547E-03,   1.4460469E-03
     +,   1.7025716E-03,   1.9860801E-03,   2.2925534E-03
     +,   2.6186546E-03,   2.9637439E-03,   3.3361611E-03
     +,   3.7687516E-03,   4.3426864E-03,   5.1943664E-03
     +,   6.4618983E-03,   8.1772460E-03,   1.0204612E-02
     +,   1.2316237E-02,   1.4395551E-02,   1.6691539E-02
     +,   1.9791119E-02,   2.3846919E-02,   2.7902383E-02
     +,   3.0917149E-02,   3.3218950E-02,   3.6118902E-02
     +,   3.9595835E-02,   4.1609846E-02,   4.1516237E-02
     +,   3.9441325E-02,   3.5490654E-02,   3.1883784E-02
     +,   2.9604597E-02,   2.7661243E-02,   2.5232531E-02
     +,   2.2056874E-02,   1.8353440E-02,   1.4583571E-02
     +,   1.1338437E-02,   9.0513304E-03,   7.6322104E-03
     +,   6.6620079E-03,   5.8424650E-03,   5.1228809E-03
     +,   4.5547504E-03,   4.1634571E-03,   3.9219642E-03
     +,   3.7727985E-03,   3.6538723E-03,   3.5163909E-03
     +,   3.3339562E-03,   3.1031542E-03,   2.8373450E-03
     +,   2.5574095E-03,   2.2835131E-03,   2.0302467E-03
     +,   1.8055593E-03,   1.6120326E-03,   1.4488574E-03
     +,   1.3134765E-03,   1.2025572E-03,   1.1124193E-03
     +,   1.0392057E-03,   9.7903796E-04,   9.2823879E-04
     +,   8.8356703E-04,   8.4240362E-04,   8.0284453E-04
     +,   7.6368736E-04,   7.2433625E-04,   6.8464520E-04
     +,   6.4475945E-04,   6.0497574E-04,   5.6562840E-04
     +,   5.2701641E-04,   4.8937014E-04,   4.5284638E-04
     +,   4.1753720E-04,   3.8348843E-04,   3.5072432E-04
     +,   3.1926887E-04,   2.8915657E-04,   2.6043601E-04
     +,   2.3317165E-04,   2.0744107E-04,   1.8332149E-04
     +,   1.6088334E-04,   1.4018342E-04,   1.2125627E-04
     +,   1.0410905E-04,   8.8720706E-05,   7.5043798E-05
     +,   6.3005420E-05,   5.2510510E-05,   4.3447686E-05
     +,   3.5694793E-05,   2.9123203E-05,   2.3602188E-05
     +,   1.9003583E-05,   1.5205331E-05,   1.2093048E-05
     +,   9.5622245E-06,   7.5192620E-06,   5.8815376E-06
     +,   4.5771876E-06,   3.5447192E-06,   2.7322355E-06
     +,   2.0963846E-06,   1.6013252E-06,   1.2177693E-06
     +,   9.2201435E-07,   6.9500766E-07,   5.2153962E-07
     +,   3.8956614E-07,   2.8961432E-07,   2.1425406E-07
     +,   1.5769713E-07,   1.1545752E-07,   8.4069619E-08
     +,   6.0866476E-08,   4.3807145E-08,   3.1336825E-08
     +,   2.2275563E-08,   1.5731922E-08,   1.1036586E-08
     +,   7.6899545E-09,   5.3209788E-09,   3.6557528E-09
     +,   2.4935816E-09,   1.6884862E-09,   1.1348914E-09
     +,   7.5709783E-10,   5.0126486E-10,   3.2936584E-10
     +,   2.1476226E-10,   1.3895683E-10,   8.9214081E-11
     +,   5.6834350E-11,   3.5924794E-11,   2.2530236E-11
     +,   1.4019463E-11,   8.6550541E-12,   5.3013796E-12
     +,   3.2215845E-12,   1.9423252E-12,   1.1617921E-12
     +,   6.8944584E-13,   4.0590239E-13,   2.3708501E-13
     +,   1.3738221E-13,   7.8980245E-14,   4.5046005E-14
     +,   2.5487948E-14,   1.4307711E-14,   7.9679525E-15
     +,   4.4023030E-15,   2.4129709E-15,   1.3121404E-15
     +,   7.0785982E-16,   3.7885391E-16,   2.0115611E-16
     +,   1.0596233E-16,   5.5374362E-17,   2.8709358E-17
     +,   1.4766481E-17,   7.5351058E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz85 = Yx/0.177704545454545
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0152486E-06,   8.2841179E-06
     +,   8.5516485E-06,   8.8173620E-06,   9.0808053E-06
     +,   9.3415611E-06,   9.5992600E-06,   9.8535793E-06
     +,   1.0104252E-05,   1.0351085E-05,   1.0593945E-05
     +,   1.0832779E-05,   1.1067617E-05,   1.1298577E-05
     +,   1.1525873E-05,   1.1749811E-05,   1.1970813E-05
     +,   1.2189396E-05,   1.2406199E-05,   1.2621967E-05
     +,   1.2837564E-05,   1.3053968E-05,   1.3272280E-05
     +,   1.3493714E-05,   1.3719592E-05,   1.3951369E-05
     +,   1.4190588E-05,   1.4438907E-05,   1.4698079E-05
     +,   1.4969954E-05,   1.5256462E-05,   1.5559604E-05
     +,   1.5881453E-05,   1.6224125E-05,   1.6589787E-05
     +,   1.6980619E-05,   1.7398816E-05,   1.7846563E-05
     +,   1.8326054E-05,   1.8839382E-05,   1.9388635E-05
     +,   1.9975801E-05,   2.0602771E-05,   2.1271315E-05
     +,   2.1983073E-05,   2.2739530E-05,   2.3541985E-05
     +,   2.4391553E-05,   2.5289135E-05,   2.6235397E-05
     +,   2.7230772E-05,   2.8275432E-05,   2.9369266E-05
     +,   3.0511963E-05,   3.1702784E-05,   3.2940847E-05
     +,   3.4224908E-05,   3.5553443E-05,   3.6924648E-05
     +,   3.8336446E-05,   3.9786482E-05,   4.1272189E-05
     +,   4.2790653E-05,   4.4338853E-05,   4.5913595E-05
     +,   4.7511341E-05,   4.9128612E-05,   5.0761650E-05
     +,   5.2406736E-05,   5.4059979E-05,   5.5717621E-05
     +,   5.7375772E-05,   5.9030765E-05,   6.0678871E-05
     +,   6.2316642E-05,   6.3940846E-05,   6.5548367E-05
     +,   6.7136367E-05,   6.8702480E-05,   7.0244641E-05
     +,   7.1761133E-05,   7.3250820E-05,   7.4712923E-05
     +,   7.6147364E-05,   7.7554432E-05,   7.8935220E-05
     +,   8.0291240E-05,   8.1624778E-05,   8.2938597E-05
     +,   8.4236228E-05,   8.5521744E-05,   8.6799773E-05
     +,   8.8075416E-05,   8.9354391E-05,   9.0642810E-05
     +,   9.1947019E-05,   9.3273753E-05,   9.4629766E-05
     +,   9.6022042E-05,   9.7457305E-05,   9.8942321E-05
     +,   1.0048340E-04,   1.0208661E-04,   1.0375736E-04
     +,   1.0550058E-04,   1.0732057E-04,   1.0922069E-04
     +,   1.1120357E-04,   1.1327106E-04,   1.1542426E-04
     +,   1.1766324E-04,   1.1998761E-04,   1.2239619E-04
     +,   1.2488772E-04,   1.2746076E-04,   1.3011445E-04
     +,   1.3284884E-04,   1.3566655E-04,   1.3857317E-04
     +,   1.4157980E-04,   1.4470516E-04,   1.4797862E-04
     +,   1.5144415E-04,   1.5516568E-04,   1.5923235E-04
     +,   1.6376468E-04,   1.6892185E-04,   1.7490661E-04
     +,   1.8197128E-04,   1.9041734E-04,   2.0059498E-04
     +,   2.1289158E-04,   2.2771840E-04,   2.4548345E-04
     +,   2.6656277E-04,   2.9126368E-04,   3.1978529E-04
     +,   3.5218883E-04,   3.8838288E-04,   4.2812945E-04
     +,   4.7108115E-04,   5.1686121E-04,   5.6518347E-04
     +,   6.1599677E-04,   6.6963909E-04,   7.2699651E-04
     +,   7.8961410E-04,   8.5974933E-04,   9.4036653E-04
     +,   1.0350577E-03,   1.1478884E-03,   1.2832093E-03
     +,   1.4455853E-03,   1.6400858E-03,   1.8732375E-03
     +,   2.1546991E-03,   2.4990512E-03,   2.9259177E-03
     +,   3.4563367E-03,   4.1055507E-03,   4.8781852E-03
     +,   5.7769120E-03,   6.8300441E-03,   8.1127286E-03
     +,   9.7167399E-03,   1.1694279E-02,   1.4066585E-02
     +,   1.6898522E-02,   2.0383690E-02,   2.4674885E-02
     +,   2.9298153E-02,   3.3435833E-02,   3.6997028E-02
     +,   3.9896376E-02,   4.0776804E-02,   3.8675722E-02
     +,   3.5620142E-02,   3.3874992E-02,   3.2390550E-02
     +,   2.9531052E-02,   2.5835397E-02,   2.2301035E-02
     +,   1.8857151E-02,   1.5436159E-02,   1.2602554E-02
     +,   1.0774799E-02,   9.8016923E-03,   9.2533194E-03
     +,   8.7547572E-03,   8.1198169E-03,   7.3434846E-03
     +,   6.5166140E-03,   5.7310872E-03,   5.0341580E-03
     +,   4.4355774E-03,   3.9311484E-03,   3.5146666E-03
     +,   3.1770696E-03,   2.9039658E-03,   2.6775373E-03
     +,   2.4810061E-03,   2.3017973E-03,   2.1321473E-03
     +,   1.9680650E-03,   1.8079892E-03,   1.6517519E-03
     +,   1.4999717E-03,   1.3536616E-03,   1.2139451E-03
     +,   1.0818728E-03,   9.5833681E-04,   8.4402849E-04
     +,   7.3938956E-04,   6.4457965E-04,   5.5947300E-04
     +,   4.8368372E-04,   4.1661152E-04,   3.5751317E-04
     +,   3.0559060E-04,   2.6006519E-04,   2.2021617E-04
     +,   1.8541039E-04,   1.5510673E-04,   1.2884123E-04
     +,   1.0620790E-04,   8.6842760E-05,   7.0410257E-05
     +,   5.6592362E-05,   4.5083954E-05,   3.5594010E-05
     +,   2.7848026E-05,   2.1590220E-05,   1.6586095E-05
     +,   1.2625107E-05,   9.5218093E-06,   7.1149661E-06
     +,   5.2670557E-06,   3.8626422E-06,   2.8060952E-06
     +,   2.0192670E-06,   1.4392335E-06,   1.0160144E-06
     +,   7.1037528E-07,   4.9189975E-07,   3.3732579E-07
     +,   2.2908830E-07,   1.5407613E-07,   1.0262095E-07
     +,   6.7685072E-08,   4.4209123E-08,   2.8594387E-08
     +,   1.8314019E-08,   1.1614925E-08,   7.2941120E-09
     +,   4.5355328E-09,   2.7922784E-09,   1.7019570E-09
     +,   1.0270221E-09,   6.1350680E-10,   3.6276918E-10
     +,   2.1231909E-10,   1.2299060E-10,   7.0507870E-11
     +,   3.9998723E-11,   2.2453242E-11,   1.2470852E-11
     +,   6.8526209E-12,   3.7250945E-12,   2.0031715E-12
     +,   1.0655194E-12,   5.6057183E-13,   2.9168505E-13
     +,   1.5010486E-13,   7.6391611E-14,   3.8445043E-14
     +,   1.9133051E-14,   9.4156657E-15,   4.5820514E-15
     +,   2.2049358E-15,   1.0493110E-15,   4.9386256E-16
     +,   2.2993252E-16,   1.0592481E-16,   4.8309902E-17
     +,   2.1829889E-17,   9.7869570E-18,   4.3627346E-18
     +,   1.9403277E-18,   8.6570795E-19,   3.9060306E-19
     +,   1.8025147E-19,   8.6264185E-20,   4.3425273E-20
     +,   2.3223960E-20,   1.3219475E-20,   7.9533109E-21
     +,   4.9958922E-21,   3.2337019E-21,   2.1332929E-21
     +,   1.4229832E-21,   9.5474081E-22
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz90 = Yx/0.169272727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_asha_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7706703E-05,   1.8145771E-05
     +,   1.8566439E-05,   1.8966975E-05,   1.9345711E-05
     +,   1.9701047E-05,   2.0031481E-05,   2.0335594E-05
     +,   2.0612093E-05,   2.0859796E-05,   2.1077652E-05
     +,   2.1264750E-05,   2.1420330E-05,   2.1543776E-05
     +,   2.1634647E-05,   2.1692656E-05,   2.1717702E-05
     +,   2.1709850E-05,   2.1669339E-05,   2.1596594E-05
     +,   2.1492207E-05,   2.1356951E-05,   2.1191780E-05
     +,   2.0997797E-05,   2.0776299E-05,   2.0528714E-05
     +,   2.0256646E-05,   1.9961828E-05,   1.9646148E-05
     +,   1.9311612E-05,   1.8960352E-05,   1.8594610E-05
     +,   1.8216735E-05,   1.7829161E-05,   1.7434406E-05
     +,   1.7035058E-05,   1.6633769E-05,   1.6233242E-05
     +,   1.5836196E-05,   1.5445428E-05,   1.5063702E-05
     +,   1.4693823E-05,   1.4338583E-05,   1.4000771E-05
     +,   1.3683147E-05,   1.3388450E-05,   1.3119376E-05
     +,   1.2878576E-05,   1.2668645E-05,   1.2492116E-05
     +,   1.2351443E-05,   1.2248999E-05,   1.2187073E-05
     +,   1.2167845E-05,   1.2193391E-05,   1.2265667E-05
     +,   1.2386506E-05,   1.2557595E-05,   1.2780481E-05
     +,   1.3056550E-05,   1.3387020E-05,   1.3772939E-05
     +,   1.4215142E-05,   1.4714287E-05,   1.5270845E-05
     +,   1.5885003E-05,   1.6556796E-05,   1.7285936E-05
     +,   1.8071993E-05,   1.8914167E-05,   1.9811518E-05
     +,   2.0762722E-05,   2.1766298E-05,   2.2820395E-05
     +,   2.3922963E-05,   2.5071700E-05,   2.6263968E-05
     +,   2.7496857E-05,   2.8767310E-05,   3.0072015E-05
     +,   3.1407322E-05,   3.2769556E-05,   3.4154669E-05
     +,   3.5558653E-05,   3.6977159E-05,   3.8405949E-05
     +,   3.9840510E-05,   4.1276489E-05,   4.2709366E-05
     +,   4.4134766E-05,   4.5548448E-05,   4.6946188E-05
     +,   4.8323964E-05,   4.9678074E-05,   5.1005096E-05
     +,   5.2301824E-05,   5.3565655E-05,   5.4794218E-05
     +,   5.5985874E-05,   5.7139354E-05,   5.8254187E-05
     +,   5.9330428E-05,   6.0369024E-05,   6.1371546E-05
     +,   6.2340499E-05,   6.3279222E-05,   6.4191910E-05
     +,   6.5083623E-05,   6.5960419E-05,   6.6829227E-05
     +,   6.7697780E-05,   6.8574736E-05,   6.9469388E-05
     +,   7.0391849E-05,   7.1352675E-05,   7.2362986E-05
     +,   7.3434101E-05,   7.4577598E-05,   7.5804899E-05
     +,   7.7127341E-05,   7.8555880E-05,   8.0100857E-05
     +,   8.1771897E-05,   8.3577987E-05,   8.5527252E-05
     +,   8.7626824E-05,   8.9883390E-05,   9.2302864E-05
     +,   9.4891315E-05,   9.7654796E-05,   1.0060064E-04
     +,   1.0373755E-04,   1.0707707E-04,   1.1063390E-04
     +,   1.1442751E-04,   1.1848261E-04,   1.2282972E-04
     +,   1.2750569E-04,   1.3255417E-04,   1.3802493E-04
     +,   1.4397305E-04,   1.5045832E-04,   1.5754539E-04
     +,   1.6530434E-04,   1.7381263E-04,   1.8316231E-04
     +,   1.9346966E-04,   2.0488939E-04,   2.1763529E-04
     +,   2.3200612E-04,   2.4841132E-04,   2.6739523E-04
     +,   2.8965547E-04,   3.1604894E-04,   3.4757640E-04
     +,   3.8534647E-04,   4.3052889E-04,   4.8432531E-04
     +,   5.4799404E-04,   6.2300632E-04,   7.1144052E-04
     +,   8.1662595E-04,   9.4394939E-04,   1.1015375E-03
     +,   1.3003118E-03,   1.5529901E-03,   1.8720416E-03
     +,   2.2669702E-03,   2.7407899E-03,   3.2848278E-03
     +,   3.8728912E-03,   4.4630640E-03,   5.0242818E-03
     +,   5.5974554E-03,   6.3547799E-03,   7.5630015E-03
     +,   9.3991170E-03,   1.1750857E-02,   1.4265677E-02
     +,   1.6802253E-02,   1.9969875E-02,   2.4766769E-02
     +,   3.1048510E-02,   3.7235387E-02,   4.2561270E-02
     +,   4.6978343E-02,   4.8828457E-02,   4.7139008E-02
     +,   4.3058790E-02,   3.7654251E-02,   3.1143008E-02
     +,   2.4855375E-02,   2.0202301E-02,   1.6933350E-02
     +,   1.4249808E-02,   1.1970482E-02,   1.0218334E-02
     +,   8.8731330E-03,   7.7482192E-03,   6.8180063E-03
     +,   6.1188410E-03,   5.6259404E-03,   5.2560368E-03
     +,   4.9192985E-03,   4.5551173E-03,   4.1416707E-03
     +,   3.6879941E-03,   3.2190178E-03,   2.7619314E-03
     +,   2.3379049E-03,   1.9592464E-03,   1.6301341E-03
     +,   1.3489460E-03,   1.1108812E-03,   9.1012934E-04
     +,   7.4121379E-04,   5.9952185E-04,   4.8129330E-04
     +,   3.8338365E-04,   3.0302128E-04,   2.3765255E-04
     +,   1.8492932E-04,   1.4273913E-04,   1.0923141E-04
     +,   8.2823244E-05,   6.2184656E-05,   4.6207118E-05
     +,   3.3967022E-05,   2.4695322E-05,   1.7755116E-05
     +,   1.2623324E-05,   8.8750576E-06,   6.1702631E-06
     +,   4.2416264E-06,   2.8826851E-06,   1.9363370E-06
     +,   1.2850733E-06,   8.4229362E-07,   5.4499833E-07
     +,   3.4794485E-07,   2.1907807E-07,   1.3598012E-07
     +,   8.3171287E-08,   5.0111019E-08,   2.9731666E-08
     +,   1.7367338E-08,   9.9862270E-09,   5.6514260E-09
     +,   3.1474650E-09,   1.7251200E-09,   9.3057773E-10
     +,   4.9411153E-10,   2.5833743E-10,   1.3307581E-10
     +,   6.7604207E-11,   3.3923385E-11,   1.6858926E-11
     +,   8.3333358E-12,   4.1242331E-12,   2.0639272E-12
     +,   1.0586858E-12,   5.6564681E-13,   3.1951487E-13
     +,   1.9241041E-13,   1.2331522E-13,   8.3234194E-14
     +,   5.8333404E-14,   4.1891627E-14,   3.0518651E-14
     +,   2.2402221E-14,   1.6499851E-14,   1.2163684E-14
     +,   8.9627970E-15,   6.5958964E-15,   4.8458873E-15
     +,   3.5534798E-15,   2.6005023E-15,   1.8991828E-15
     +,   1.3840796E-15,   1.0065661E-15,   7.3046554E-16
     +,   5.2898081E-16,   3.8225427E-16,   2.7564361E-16
     +,   1.9834184E-16,   1.4241774E-16,   1.0204467E-16
     +,   7.2960817E-17,   5.2055899E-17,   3.7061549E-17
     +,   2.6330482E-17,   1.8666676E-17,   1.3205608E-17
     +,   9.3222527E-18,   6.5669947E-18,   4.6162208E-18
     +,   3.2380885E-18,   2.2665439E-18,   1.5831541E-18
     +,   1.1034568E-18,   7.6748759E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_asha_ttz95 = Yx/0.163068181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.7619574E-05,   5.9404196E-05
     +,   6.1206811E-05,   6.3027182E-05,   6.4865337E-05
     +,   6.6721608E-05,   6.8596673E-05,   7.0491580E-05
     +,   7.2407827E-05,   7.4347423E-05,   7.6312754E-05
     +,   7.8306926E-05,   8.0333470E-05,   8.2396582E-05
     +,   8.4501218E-05,   8.6652792E-05,   8.8857625E-05
     +,   9.1122638E-05,   9.3455521E-05,   9.5864663E-05
     +,   9.8359094E-05,   1.0094873E-04,   1.0364390E-04
     +,   1.0645574E-04,   1.0939583E-04,   1.1247629E-04
     +,   1.1570955E-04,   1.1910847E-04,   1.2268595E-04
     +,   1.2645498E-04,   1.3042848E-04,   1.3461897E-04
     +,   1.3903869E-04,   1.4369919E-04,   1.4861107E-04
     +,   1.5378419E-04,   1.5922674E-04,   1.6494581E-04
     +,   1.7094682E-04,   1.7723293E-04,   1.8380578E-04
     +,   1.9066433E-04,   1.9780532E-04,   2.0522295E-04
     +,   2.1290855E-04,   2.2085082E-04,   2.2903561E-04
     +,   2.3744583E-04,   2.4606159E-04,   2.5486012E-04
     +,   2.6381609E-04,   2.7290150E-04,   2.8208562E-04
     +,   2.9133659E-04,   3.0061931E-04,   3.0989814E-04
     +,   3.1913567E-04,   3.2829383E-04,   3.3733406E-04
     +,   3.4621765E-04,   3.5490640E-04,   3.6336298E-04
     +,   3.7155105E-04,   3.7943647E-04,   3.8698735E-04
     +,   3.9417378E-04,   4.0096958E-04,   4.0735095E-04
     +,   4.1329901E-04,   4.1879775E-04,   4.2383603E-04
     +,   4.2840655E-04,   4.3250661E-04,   4.3613798E-04
     +,   4.3930742E-04,   4.4202540E-04,   4.4430728E-04
     +,   4.4617211E-04,   4.4764348E-04,   4.4874844E-04
     +,   4.4951757E-04,   4.4998471E-04,   4.5018611E-04
     +,   4.5016108E-04,   4.4995107E-04,   4.4959906E-04
     +,   4.4914935E-04,   4.4864818E-04,   4.4814244E-04
     +,   4.4767949E-04,   4.4730800E-04,   4.4707634E-04
     +,   4.4703373E-04,   4.4723012E-04,   4.4771499E-04
     +,   4.4853924E-04,   4.4975439E-04,   4.5141223E-04
     +,   4.5356611E-04,   4.5627047E-04,   4.5958115E-04
     +,   4.6355507E-04,   4.6825173E-04,   4.7372992E-04
     +,   4.8005171E-04,   4.8727880E-04,   4.9547310E-04
     +,   5.0469511E-04,   5.1500520E-04,   5.2645936E-04
     +,   5.3910818E-04,   5.5299833E-04,   5.6816492E-04
     +,   5.8463513E-04,   6.0242199E-04,   6.2152534E-04
     +,   6.4192584E-04,   6.6358817E-04,   6.8645453E-04
     +,   7.1044650E-04,   7.3546538E-04,   7.6138758E-04
     +,   7.8806886E-04,   8.1534567E-04,   8.4303739E-04
     +,   8.7094435E-04,   8.9885911E-04,   9.2656194E-04
     +,   9.5383386E-04,   9.8045252E-04,   1.0062054E-03
     +,   1.0308855E-03,   1.0543058E-03,   1.0762924E-03
     +,   1.0966959E-03,   1.1153927E-03,   1.1322802E-03
     +,   1.1472851E-03,   1.1603573E-03,   1.1714742E-03
     +,   1.1806318E-03,   1.1878471E-03,   1.1931513E-03
     +,   1.1965899E-03,   1.1982161E-03,   1.1980883E-03
     +,   1.1962662E-03,   1.1928091E-03,   1.1877767E-03
     +,   1.1812237E-03,   1.1732012E-03,   1.1637607E-03
     +,   1.1529528E-03,   1.1408301E-03,   1.1274505E-03
     +,   1.1128809E-03,   1.0972020E-03,   1.0805103E-03
     +,   1.0629218E-03,   1.0445771E-03,   1.0256412E-03
     +,   1.0063061E-03,   9.8679622E-04,   9.6736266E-04
     +,   9.4828574E-04,   9.2987454E-04,   9.1246178E-04
     +,   8.9640555E-04,   8.8207895E-04,   8.6987129E-04
     +,   8.6017972E-04,   8.5340539E-04,   8.4994658E-04
     +,   8.5019093E-04,   8.5451105E-04,   8.6325657E-04
     +,   8.7675010E-04,   8.9527929E-04,   9.1909262E-04
     +,   9.4839791E-04,   9.8336302E-04,   1.0241132E-03
     +,   1.0707374E-03,   1.1233002E-03,   1.1818552E-03
     +,   1.2464565E-03,   1.3171907E-03,   1.3942048E-03
     +,   1.4777422E-03,   1.5681639E-03,   1.6660029E-03
     +,   1.7719866E-03,   1.8870366E-03,   2.0122814E-03
     +,   2.1490261E-03,   2.2986738E-03,   2.4626211E-03
     +,   2.6421135E-03,   2.8380882E-03,   3.0509902E-03
     +,   3.2805919E-03,   3.5258932E-03,   3.7851341E-03
     +,   4.0559033E-03,   4.3354090E-03,   4.6210261E-03
     +,   4.9109468E-03,   5.2049197E-03,   5.5049388E-03
     +,   5.8156052E-03,   6.1437623E-03,   6.4972965E-03
     +,   6.8832384E-03,   7.3058014E-03,   7.7653257E-03
     +,   8.2595423E-03,   8.7878993E-03,   9.3584815E-03
     +,   9.9952007E-03,   1.0741951E-02,   1.1660640E-02
     +,   1.2822295E-02,   1.4292195E-02,   1.6111411E-02
     +,   1.8276850E-02,   2.0737259E-02,   2.3451092E-02
     +,   2.6543757E-02,   3.0481368E-02,   3.6012661E-02
     +,   4.3697439E-02,   5.3306103E-02,   6.3803561E-02
     +,   7.4092545E-02,   8.3540440E-02,   9.1628440E-02
     +,   9.7531654E-02,   0.1004537    ,   0.1003551    
     +,   9.8055273E-02,   9.4312496E-02,   8.9037858E-02
     +,   8.1770569E-02,   7.2677001E-02,   6.2787786E-02
     +,   5.3424053E-02,   4.5429859E-02,   3.8790505E-02
     +,   3.2964520E-02,   2.7510161E-02,   2.2364493E-02
     +,   1.7716408E-02,   1.3766843E-02,   1.0587574E-02
     +,   8.1158839E-03,   6.2206220E-03,   4.7667637E-03
     +,   3.6466687E-03,   2.7831327E-03,   2.1207330E-03
     +,   1.6169857E-03,   1.2371914E-03,   9.5242955E-04
     +,   7.3904794E-04,   5.7841523E-04,   4.5639917E-04
     +,   3.6265524E-04,   2.8978466E-04,   2.3254097E-04
     +,   1.8719272E-04,   1.5105534E-04,   1.2215832E-04
     +,   9.9013778E-05,   8.0465674E-05,   6.5595530E-05
     +,   5.3663574E-05,   4.4068005E-05,   3.6323490E-05
     +,   3.0040226E-05,   2.4910678E-05,   2.0694040E-05
     +,   1.7204813E-05,   1.4300244E-05,   1.1871312E-05
     +,   9.8337341E-06,   8.1220642E-06,   6.6842431E-06
     +,   5.4781749E-06,   4.4691997E-06,   3.6280376E-06
     +,   2.9298235E-06,   2.3530458E-06,   1.8791459E-06
     +,   1.4919581E-06,   1.1775180E-06,   9.2371670E-07
     +,   7.2017349E-07,   5.5798438E-07,   4.2960903E-07
     +,   3.2867058E-07,   2.4984678E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt100 = Yx/0.4613
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2983139E-04,   2.4249476E-04
     +,   2.5574036E-04,   2.6958116E-04,   2.8402841E-04
     +,   2.9909067E-04,   3.1477420E-04,   3.3108256E-04
     +,   3.4801557E-04,   3.6557057E-04,   3.8374052E-04
     +,   4.0251459E-04,   4.2187775E-04,   4.4181111E-04
     +,   4.6229121E-04,   4.8329021E-04,   5.0477585E-04
     +,   5.2671297E-04,   5.4906041E-04,   5.7177478E-04
     +,   5.9480901E-04,   6.1811303E-04,   6.4163364E-04
     +,   6.6531752E-04,   6.8910653E-04,   7.1294548E-04
     +,   7.3677581E-04,   7.6054136E-04,   7.8418682E-04
     +,   8.0765667E-04,   8.3090109E-04,   8.5386942E-04
     +,   8.7651896E-04,   8.9880795E-04,   9.2070125E-04
     +,   9.4216829E-04,   9.6318586E-04,   9.8373508E-04
     +,   1.0038065E-03,   1.0233953E-03,   1.0425067E-03
     +,   1.0611530E-03,   1.0793530E-03,   1.0971357E-03
     +,   1.1145377E-03,   1.1316028E-03,   1.1483828E-03
     +,   1.1649369E-03,   1.1813325E-03,   1.1976408E-03
     +,   1.2139421E-03,   1.2303176E-03,   1.2468525E-03
     +,   1.2636387E-03,   1.2807647E-03,   1.2983214E-03
     +,   1.3163976E-03,   1.3350812E-03,   1.3544543E-03
     +,   1.3745965E-03,   1.3955808E-03,   1.4174754E-03
     +,   1.4403394E-03,   1.4642287E-03,   1.4891924E-03
     +,   1.5152686E-03,   1.5424963E-03,   1.5709070E-03
     +,   1.6005309E-03,   1.6313966E-03,   1.6635348E-03
     +,   1.6969753E-03,   1.7317602E-03,   1.7679331E-03
     +,   1.8055531E-03,   1.8446916E-03,   1.8854375E-03
     +,   1.9278934E-03,   1.9721878E-03,   2.0184687E-03
     +,   2.0669012E-03,   2.1176739E-03,   2.1709830E-03
     +,   2.2270426E-03,   2.2860526E-03,   2.3482107E-03
     +,   2.4136894E-03,   2.4826149E-03,   2.5550618E-03
     +,   2.6310398E-03,   2.7104712E-03,   2.7931966E-03
     +,   2.8789572E-03,   2.9674142E-03,   3.0581581E-03
     +,   3.1507020E-03,   3.2445409E-03,   3.3391386E-03
     +,   3.4339835E-03,   3.5285857E-03,   3.6225116E-03
     +,   3.7153638E-03,   3.8068241E-03,   3.8965931E-03
     +,   3.9844173E-03,   4.0700380E-03,   4.1531986E-03
     +,   4.2336080E-03,   4.3109613E-03,   4.3849326E-03
     +,   4.4551836E-03,   4.5214384E-03,   4.5834575E-03
     +,   4.6411250E-03,   4.6944427E-03,   4.7435923E-03
     +,   4.7888951E-03,   4.8308461E-03,   4.8700371E-03
     +,   4.9071629E-03,   4.9429080E-03,   4.9779168E-03
     +,   5.0127204E-03,   5.0476687E-03,   5.0829044E-03
     +,   5.1182951E-03,   5.1534795E-03,   5.1878425E-03
     +,   5.2205496E-03,   5.2506342E-03,   5.2770269E-03
     +,   5.2986569E-03,   5.3145285E-03,   5.3237663E-03
     +,   5.3257234E-03,   5.3199762E-03,   5.3063636E-03
     +,   5.2849725E-03,   5.2561169E-03,   5.2202856E-03
     +,   5.1780823E-03,   5.1301797E-03,   5.0772284E-03
     +,   5.0198389E-03,   4.9585300E-03,   4.8937057E-03
     +,   4.8256502E-03,   4.7545508E-03,   4.6804901E-03
     +,   4.6034968E-03,   4.5235353E-03,   4.4405544E-03
     +,   4.3545025E-03,   4.2653261E-03,   4.1729887E-03
     +,   4.0774811E-03,   3.9788368E-03,   3.8771406E-03
     +,   3.7725398E-03,   3.6652901E-03,   3.5557614E-03
     +,   3.4444612E-03,   3.3320740E-03,   3.2194683E-03
     +,   3.1076926E-03,   2.9979781E-03,   2.8917347E-03
     +,   2.7905125E-03,   2.6959712E-03,   2.6098313E-03
     +,   2.5338582E-03,   2.4698109E-03,   2.4194105E-03
     +,   2.3843206E-03,   2.3661372E-03,   2.3663768E-03
     +,   2.3864619E-03,   2.4277114E-03,   2.4913116E-03
     +,   2.5782678E-03,   2.6893464E-03,   2.8249614E-03
     +,   2.9850923E-03,   3.1691447E-03,   3.3758860E-03
     +,   3.6033171E-03,   3.8487045E-03,   4.1086585E-03
     +,   4.3793046E-03,   4.6565547E-03,   4.9365540E-03
     +,   5.2161394E-03,   5.4932898E-03,   5.7676076E-03
     +,   6.0405754E-03,   6.3156481E-03,   6.5979562E-03
     +,   6.8938346E-03,   7.2100181E-03,   7.5526685E-03
     +,   7.9263374E-03,   8.3331279E-03,   8.7721189E-03
     +,   9.2391940E-03,   9.7272294E-03,   1.0226868E-02
     +,   1.0727435E-02,   1.1217896E-02,   1.1687896E-02
     +,   1.2128460E-02,   1.2532359E-02,   1.2894052E-02
     +,   1.3209544E-02,   1.3476127E-02,   1.3691937E-02
     +,   1.3855803E-02,   1.3967274E-02,   1.4026631E-02
     +,   1.4034933E-02,   1.3994028E-02,   1.3906400E-02
     +,   1.3774849E-02,   1.3602239E-02,   1.3391092E-02
     +,   1.3143538E-02,   1.2861396E-02,   1.2546275E-02
     +,   1.2200093E-02,   1.1825100E-02,   1.1424269E-02
     +,   1.1001219E-02,   1.0560158E-02,   1.0105510E-02
     +,   9.6416818E-03,   9.1728242E-03,   8.7024951E-03
     +,   8.2336348E-03,   7.7685565E-03,   7.3090368E-03
     +,   6.8563977E-03,   6.4117536E-03,   5.9761573E-03
     +,   5.5507310E-03,   5.1366505E-03,   4.7352528E-03
     +,   4.3479679E-03,   3.9762459E-03,   3.6214336E-03
     +,   3.2847247E-03,   2.9671069E-03,   2.6692618E-03
     +,   2.3915793E-03,   2.1341695E-03,   1.8968820E-03
     +,   1.6793143E-03,   1.4808775E-03,   1.3008396E-03
     +,   1.1383453E-03,   9.9243387E-04,   8.6207862E-04
     +,   7.4621278E-04,   6.4374035E-04,   5.5354595E-04
     +,   4.7452454E-04,   4.0560254E-04,   3.4573729E-04
     +,   2.9393873E-04,   2.4928313E-04,   2.1091416E-04
     +,   1.7804687E-04,   1.4997128E-04,   1.2605290E-04
     +,   1.0572727E-04,   8.8495195E-05,   7.3918643E-05
     +,   6.1616753E-05,   5.1256775E-05,   4.2551786E-05
     +,   3.5252906E-05,   2.9146730E-05,   2.4049114E-05
     +,   1.9802936E-05,   1.6273339E-05,   1.3345788E-05
     +,   1.0922518E-05,   8.9209343E-06,   7.2709745E-06
     +,   5.9135764E-06,   4.7991862E-06,   3.8860835E-06
     +,   3.1394825E-06,   2.5302479E-06,   2.0341913E-06
     +,   1.6311462E-06,   1.3044404E-06,   1.0402271E-06
     +,   8.2709767E-07,   6.5561466E-07,   5.1802851E-07
     +,   4.0795109E-07,   3.2015649E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt105 = Yx/0.2555
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2534030E-04,   1.3242730E-04
     +,   1.3997885E-04,   1.4801939E-04,   1.5657343E-04
     +,   1.6566491E-04,   1.7531756E-04,   1.8555425E-04
     +,   1.9639690E-04,   2.0786667E-04,   2.1998306E-04
     +,   2.3276427E-04,   2.4622623E-04,   2.6038344E-04
     +,   2.7524782E-04,   2.9082896E-04,   3.0713397E-04
     +,   3.2416679E-04,   3.4192859E-04,   3.6041759E-04
     +,   3.7962873E-04,   3.9955377E-04,   4.2018123E-04
     +,   4.4149751E-04,   4.6348403E-04,   4.8612143E-04
     +,   5.0938746E-04,   5.3325784E-04,   5.5770634E-04
     +,   5.8270746E-04,   6.0823321E-04,   6.3425815E-04
     +,   6.6075736E-04,   6.8770832E-04,   7.1509159E-04
     +,   7.4289169E-04,   7.7109737E-04,   7.9970394E-04
     +,   8.2871300E-04,   8.5812982E-04,   8.8796997E-04
     +,   9.1825437E-04,   9.4900955E-04,   9.8026928E-04
     +,   1.0120717E-03,   1.0444607E-03,   1.0774810E-03
     +,   1.1111806E-03,   1.1456058E-03,   1.1808051E-03
     +,   1.2168192E-03,   1.2536889E-03,   1.2914451E-03
     +,   1.3301161E-03,   1.3697189E-03,   1.4102656E-03
     +,   1.4517549E-03,   1.4941839E-03,   1.5375305E-03
     +,   1.5817722E-03,   1.6268711E-03,   1.6727799E-03
     +,   1.7194380E-03,   1.7667729E-03,   1.8146976E-03
     +,   1.8631044E-03,   1.9118703E-03,   1.9608436E-03
     +,   2.0098581E-03,   2.0587167E-03,   2.1072063E-03
     +,   2.1550874E-03,   2.2021080E-03,   2.2480038E-03
     +,   2.2925155E-03,   2.3353943E-03,   2.3764079E-03
     +,   2.4153683E-03,   2.4521349E-03,   2.4866341E-03
     +,   2.5188650E-03,   2.5489191E-03,   2.5769738E-03
     +,   2.6033123E-03,   2.6283090E-03,   2.6524281E-03
     +,   2.6762274E-03,   2.7003284E-03,   2.7254152E-03
     +,   2.7522112E-03,   2.7814587E-03,   2.8138948E-03
     +,   2.8502299E-03,   2.8911117E-03,   2.9370976E-03
     +,   2.9886295E-03,   3.0459862E-03,   3.1092621E-03
     +,   3.1783336E-03,   3.2528271E-03,   3.3321320E-03
     +,   3.4153503E-03,   3.5013622E-03,   3.5888231E-03
     +,   3.6762229E-03,   3.7619558E-03,   3.8443946E-03
     +,   3.9219791E-03,   3.9933249E-03,   4.0573007E-03
     +,   4.1130986E-03,   4.1603041E-03,   4.1988967E-03
     +,   4.2292830E-03,   4.2522256E-03,   4.2687873E-03
     +,   4.2802654E-03,   4.2880573E-03,   4.2935675E-03
     +,   4.2981086E-03,   4.3027960E-03,   4.3085017E-03
     +,   4.3157986E-03,   4.3249563E-03,   4.3359511E-03
     +,   4.3484932E-03,   4.3620938E-03,   4.3760817E-03
     +,   4.3897042E-03,   4.4021355E-03,   4.4125281E-03
     +,   4.4200597E-03,   4.4239280E-03,   4.4234009E-03
     +,   4.4177887E-03,   4.4064866E-03,   4.3889754E-03
     +,   4.3648346E-03,   4.3337648E-03,   4.2955889E-03
     +,   4.2502708E-03,   4.1979239E-03,   4.1388054E-03
     +,   4.0732911E-03,   4.0018889E-03,   3.9251777E-03
     +,   3.8438041E-03,   3.7584479E-03,   3.6697902E-03
     +,   3.5784934E-03,   3.4851932E-03,   3.3904905E-03
     +,   3.2949653E-03,   3.1991601E-03,   3.1036208E-03
     +,   3.0089014E-03,   2.9155926E-03,   2.8243037E-03
     +,   2.7357000E-03,   2.6504882E-03,   2.5694105E-03
     +,   2.4932337E-03,   2.4227402E-03,   2.3587127E-03
     +,   2.3018997E-03,   2.2530111E-03,   2.2127181E-03
     +,   2.1816292E-03,   2.1602940E-03,   2.1492050E-03
     +,   2.1487952E-03,   2.1594469E-03,   2.1814830E-03
     +,   2.2151759E-03,   2.2607238E-03,   2.3182430E-03
     +,   2.3877530E-03,   2.4691303E-03,   2.5621129E-03
     +,   2.6662787E-03,   2.7810589E-03,   2.9057630E-03
     +,   3.0396483E-03,   3.1820380E-03,   3.3324598E-03
     +,   3.4907993E-03,   3.6574807E-03,   3.8336474E-03
     +,   4.0212441E-03,   4.2230166E-03,   4.4424050E-03
     +,   4.6832594E-03,   4.9493900E-03,   5.2439841E-03
     +,   5.5689593E-03,   5.9243562E-03,   6.3077379E-03
     +,   6.7139938E-03,   7.1354453E-03,   7.5622629E-03
     +,   7.9833679E-03,   8.3875991E-03,   8.7650232E-03
     +,   9.1081038E-03,   9.4125662E-03,   9.6778311E-03
     +,   9.9068014E-03,   1.0105029E-02,   1.0279584E-02
     +,   1.0437527E-02,   1.0584527E-02,   1.0723700E-02
     +,   1.0854984E-02,   1.0975048E-02,   1.1077884E-02
     +,   1.1155779E-02,   1.1200583E-02,   1.1205078E-02
     +,   1.1164038E-02,   1.1075067E-02,   1.0938728E-02
     +,   1.0758475E-02,   1.0540009E-02,   1.0290554E-02
     +,   1.0017956E-02,   9.7299395E-03,   9.4334912E-03
     +,   9.1344519E-03,   8.8372175E-03,   8.5446369E-03
     +,   8.2580745E-03,   7.9774428E-03,   7.7013876E-03
     +,   7.4276142E-03,   7.1531823E-03,   6.8748873E-03
     +,   6.5897084E-03,   6.2951916E-03,   5.9897634E-03
     +,   5.6729363E-03,   5.3454172E-03,   5.0090635E-03
     +,   4.6667433E-03,   4.3220478E-03,   3.9790026E-03
     +,   3.6417684E-03,   3.3143272E-03,   3.0002007E-03
     +,   2.7022962E-03,   2.4228301E-03,   2.1632349E-03
     +,   1.9242263E-03,   1.7059033E-03,   1.5078263E-03
     +,   1.3291389E-03,   1.1687039E-03,   1.0252189E-03
     +,   8.9729781E-04,   7.8353850E-04,   6.8258448E-04
     +,   5.9316447E-04,   5.1410723E-04,   4.4434002E-04
     +,   3.8289806E-04,   3.2892040E-04,   2.8162886E-04
     +,   2.4032332E-04,   2.0437381E-04,   1.7320659E-04
     +,   1.4629589E-04,   1.2316022E-04,   1.0335922E-04
     +,   8.6488697E-05,   7.2178278E-05,   6.0091243E-05
     +,   4.9924343E-05,   4.1404339E-05,   3.4289267E-05
     +,   2.8364897E-05,   2.3444802E-05,   1.9366877E-05
     +,   1.5992462E-05,   1.3203025E-05,   1.0898763E-05
     +,   8.9956056E-06,   7.4236727E-06,   6.1248247E-06
     +,   5.0510525E-06,   4.1629214E-06,   3.4279178E-06
     +,   2.8194584E-06,   2.3156506E-06,   1.8985817E-06
     +,   1.5534622E-06,   1.2681423E-06,   1.0325379E-06
     +,   8.3831674E-07,   6.7852284E-07,   5.4737558E-07
     +,   4.4002545E-07,   3.5242732E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt107 = Yx/0.220577777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1402251E-04,   2.2488958E-04
     +,   2.3619451E-04,   2.4794994E-04,   2.6016813E-04
     +,   2.7286078E-04,   2.8603850E-04,   2.9971168E-04
     +,   3.1388857E-04,   3.2857692E-04,   3.4378178E-04
     +,   3.5950664E-04,   3.7575219E-04,   3.9251690E-04
     +,   4.0979608E-04,   4.2758157E-04,   4.4586201E-04
     +,   4.6462231E-04,   4.8384393E-04,   5.0350412E-04
     +,   5.2357640E-04,   5.4403103E-04,   5.6483381E-04
     +,   5.8594899E-04,   6.0733547E-04,   6.2895211E-04
     +,   6.5075437E-04,   6.7269697E-04,   6.9473399E-04
     +,   7.1681902E-04,   7.3890795E-04,   7.6095655E-04
     +,   7.8292424E-04,   8.0477406E-04,   8.2647271E-04
     +,   8.4799115E-04,   8.6930761E-04,   8.9040567E-04
     +,   9.1127655E-04,   9.3191752E-04,   9.5233571E-04
     +,   9.7254489E-04,   9.9256809E-04,   1.0124361E-03
     +,   1.0321898E-03,   1.0518773E-03,   1.0715555E-03
     +,   1.0912896E-03,   1.1111521E-03,   1.1312228E-03
     +,   1.1515885E-03,   1.1723409E-03,   1.1935775E-03
     +,   1.2154001E-03,   1.2379123E-03,   1.2612211E-03
     +,   1.2854333E-03,   1.3106550E-03,   1.3369902E-03
     +,   1.3645403E-03,   1.3934008E-03,   1.4236628E-03
     +,   1.4554043E-03,   1.4886971E-03,   1.5236026E-03
     +,   1.5601632E-03,   1.5984087E-03,   1.6383468E-03
     +,   1.6799666E-03,   1.7232287E-03,   1.7680671E-03
     +,   1.8143838E-03,   1.8620455E-03,   1.9108811E-03
     +,   1.9606818E-03,   2.0111976E-03,   2.0621396E-03
     +,   2.1131828E-03,   2.1639697E-03,   2.2141291E-03
     +,   2.2632666E-03,   2.3109931E-03,   2.3569337E-03
     +,   2.4007428E-03,   2.4421213E-03,   2.4808308E-03
     +,   2.5167041E-03,   2.5496648E-03,   2.5797174E-03
     +,   2.6069595E-03,   2.6315802E-03,   2.6538349E-03
     +,   2.6740448E-03,   2.6925683E-03,   2.7097824E-03
     +,   2.7260508E-03,   2.7417077E-03,   2.7570308E-03
     +,   2.7722211E-03,   2.7873924E-03,   2.8025683E-03
     +,   2.8176827E-03,   2.8325994E-03,   2.8471174E-03
     +,   2.8610211E-03,   2.8740976E-03,   2.8861854E-03
     +,   2.8971971E-03,   2.9071725E-03,   2.9162902E-03
     +,   2.9248900E-03,   2.9334810E-03,   2.9427230E-03
     +,   2.9534115E-03,   2.9664263E-03,   2.9826881E-03
     +,   3.0030946E-03,   3.0284545E-03,   3.0594070E-03
     +,   3.0963889E-03,   3.1395473E-03,   3.1887423E-03
     +,   3.2435029E-03,   3.3030440E-03,   3.3662929E-03
     +,   3.4319323E-03,   3.4984543E-03,   3.5642511E-03
     +,   3.6276763E-03,   3.6871124E-03,   3.7410764E-03
     +,   3.7882358E-03,   3.8274841E-03,   3.8579477E-03
     +,   3.8790109E-03,   3.8903004E-03,   3.8916694E-03
     +,   3.8831795E-03,   3.8650564E-03,   3.8376527E-03
     +,   3.8014413E-03,   3.7569522E-03,   3.7047702E-03
     +,   3.6455109E-03,   3.5798107E-03,   3.5083124E-03
     +,   3.4316604E-03,   3.3504993E-03,   3.2654831E-03
     +,   3.1772438E-03,   3.0864009E-03,   2.9935753E-03
     +,   2.8993536E-03,   2.8042952E-03,   2.7089261E-03
     +,   2.6137435E-03,   2.5192166E-03,   2.4257649E-03
     +,   2.3337840E-03,   2.2436478E-03,   2.1557019E-03
     +,   2.0702791E-03,   1.9877083E-03,   1.9083188E-03
     +,   1.8324374E-03,   1.7604001E-03,   1.6925581E-03
     +,   1.6292776E-03,   1.5709380E-03,   1.5179330E-03
     +,   1.4706810E-03,   1.4296223E-03,   1.3952116E-03
     +,   1.3679364E-03,   1.3483103E-03,   1.3368829E-03
     +,   1.3342371E-03,   1.3410019E-03,   1.3578386E-03
     +,   1.3854532E-03,   1.4245803E-03,   1.4759679E-03
     +,   1.5403489E-03,   1.6184243E-03,   1.7108049E-03
     +,   1.8179612E-03,   1.9401710E-03,   2.0774622E-03
     +,   2.2295588E-03,   2.3958269E-03,   2.5752808E-03
     +,   2.7665845E-03,   2.9680955E-03,   3.1779560E-03
     +,   3.3942622E-03,   3.6151784E-03,   3.8391361E-03
     +,   4.0649795E-03,   4.2921249E-03,   4.5206109E-03
     +,   4.7510359E-03,   4.9844952E-03,   5.2223317E-03
     +,   5.4658637E-03,   5.7159811E-03,   5.9728795E-03
     +,   6.2357225E-03,   6.5024206E-03,   6.7695570E-03
     +,   7.0325532E-03,   7.2858674E-03,   7.5234352E-03
     +,   7.7391891E-03,   7.9277251E-03,   8.0848206E-03
     +,   8.2079284E-03,   8.2964636E-03,   8.3518904E-03
     +,   8.3774487E-03,   8.3777700E-03,   8.3581768E-03
     +,   8.3239386E-03,   8.2795816E-03,   8.2282489E-03
     +,   8.1713814E-03,   8.1085898E-03,   8.0377935E-03
     +,   7.9556759E-03,   7.8581311E-03,   7.7409362E-03
     +,   7.6002497E-03,   7.4331025E-03,   7.2376984E-03
     +,   7.0135752E-03,   6.7616510E-03,   6.4840969E-03
     +,   6.1841370E-03,   5.8658565E-03,   5.5338969E-03
     +,   5.1931487E-03,   4.8485380E-03,   4.5047952E-03
     +,   4.1662506E-03,   3.8366681E-03,   3.5191849E-03
     +,   3.2162718E-03,   2.9297329E-03,   2.6607239E-03
     +,   2.4098412E-03,   2.1772296E-03,   1.9626352E-03
     +,   1.7655159E-03,   1.5851457E-03,   1.4206627E-03
     +,   1.2711206E-03,   1.1355431E-03,   1.0129601E-03
     +,   9.0241682E-04,   8.0298062E-04,   7.1375351E-04
     +,   6.3388067E-04,   5.6254567E-04,   4.9896695E-04
     +,   4.4240468E-04,   3.9216765E-04,   3.4760268E-04
     +,   3.0810371E-04,   2.7311457E-04,   2.4212601E-04
     +,   2.1467468E-04,   1.9034417E-04,   1.6876515E-04
     +,   1.4961018E-04,   1.3259002E-04,   1.1745175E-04
     +,   1.0397611E-04,   9.1970622E-05,   8.1269493E-05
     +,   7.1727118E-05,   6.3217791E-05,   5.5630586E-05
     +,   4.8869118E-05,   4.2847576E-05,   3.7490721E-05
     +,   3.2730928E-05,   2.8508353E-05,   2.4768828E-05
     +,   2.1463560E-05,   1.8548730E-05,   1.5984213E-05
     +,   1.3733893E-05,   1.1764600E-05,   1.0046380E-05
     +,   8.5517286E-06,   7.2558041E-06,   6.1358478E-06
     +,   5.1713469E-06,   4.3435944E-06,   3.6358094E-06
     +,   3.0327835E-06,   2.5209595E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt110 = Yx/0.175159090909091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1876770E-04,   1.2656141E-04
     +,   1.3492079E-04,   1.4389491E-04,   1.5353596E-04
     +,   1.6389953E-04,   1.7504393E-04,   1.8702973E-04
     +,   1.9991894E-04,   2.1377541E-04,   2.2866191E-04
     +,   2.4464054E-04,   2.6177100E-04,   2.8010941E-04
     +,   2.9970633E-04,   3.2060617E-04,   3.4284484E-04
     +,   3.6644837E-04,   3.9143144E-04,   4.1779585E-04
     +,   4.4552927E-04,   4.7460382E-04,   5.0497497E-04
     +,   5.3658313E-04,   5.6934857E-04,   6.0317700E-04
     +,   6.3795637E-04,   6.7355862E-04,   7.0984178E-04
     +,   7.4665056E-04,   7.8381895E-04,   8.2117337E-04
     +,   8.5853413E-04,   8.9571939E-04,   9.3254715E-04
     +,   9.6884090E-04,   1.0044303E-03,   1.0391555E-03
     +,   1.0728713E-03,   1.1054460E-03,   1.1367693E-03
     +,   1.1667495E-03,   1.1953164E-03,   1.2224227E-03
     +,   1.2480441E-03,   1.2721765E-03,   1.2948393E-03
     +,   1.3160672E-03,   1.3359151E-03,   1.3544504E-03
     +,   1.3717517E-03,   1.3879058E-03,   1.4030018E-03
     +,   1.4171322E-03,   1.4303852E-03,   1.4428460E-03
     +,   1.4545911E-03,   1.4656896E-03,   1.4762001E-03
     +,   1.4861726E-03,   1.4956471E-03,   1.5046573E-03
     +,   1.5132342E-03,   1.5214022E-03,   1.5291928E-03
     +,   1.5366370E-03,   1.5437797E-03,   1.5506720E-03
     +,   1.5573847E-03,   1.5640008E-03,   1.5706238E-03
     +,   1.5773720E-03,   1.5843811E-03,   1.5918008E-03
     +,   1.5997884E-03,   1.6085106E-03,   1.6181313E-03
     +,   1.6288075E-03,   1.6406839E-03,   1.6538907E-03
     +,   1.6685287E-03,   1.6846728E-03,   1.7023648E-03
     +,   1.7216109E-03,   1.7423829E-03,   1.7646191E-03
     +,   1.7882225E-03,   1.8130725E-03,   1.8390222E-03
     +,   1.8659127E-03,   1.8935743E-03,   1.9218370E-03
     +,   1.9505306E-03,   1.9795045E-03,   2.0086174E-03
     +,   2.0377464E-03,   2.0667959E-03,   2.0956821E-03
     +,   2.1243417E-03,   2.1527240E-03,   2.1807889E-03
     +,   2.2084895E-03,   2.2357849E-03,   2.2626140E-03
     +,   2.2888985E-03,   2.3145408E-03,   2.3394164E-03
     +,   2.3633710E-03,   2.3862328E-03,   2.4078051E-03
     +,   2.4278762E-03,   2.4462289E-03,   2.4626474E-03
     +,   2.4769295E-03,   2.4888979E-03,   2.4984030E-03
     +,   2.5053378E-03,   2.5096505E-03,   2.5113323E-03
     +,   2.5104405E-03,   2.5070766E-03,   2.5014058E-03
     +,   2.4936344E-03,   2.4840056E-03,   2.4727990E-03
     +,   2.4603065E-03,   2.4468354E-03,   2.4326770E-03
     +,   2.4181115E-03,   2.4033906E-03,   2.3887276E-03
     +,   2.3742851E-03,   2.3601723E-03,   2.3464384E-03
     +,   2.3330688E-03,   2.3199876E-03,   2.3070546E-03
     +,   2.2940729E-03,   2.2807973E-03,   2.2669390E-03
     +,   2.2521804E-03,   2.2361844E-03,   2.2186141E-03
     +,   2.1991415E-03,   2.1774704E-03,   2.1533398E-03
     +,   2.1265519E-03,   2.0969694E-03,   2.0645326E-03
     +,   2.0292657E-03,   1.9912680E-03,   1.9507316E-03
     +,   1.9079200E-03,   1.8631659E-03,   1.8168598E-03
     +,   1.7694385E-03,   1.7213743E-03,   1.6731475E-03
     +,   1.6252430E-03,   1.5781374E-03,   1.5322785E-03
     +,   1.4880793E-03,   1.4459201E-03,   1.4061315E-03
     +,   1.3690008E-03,   1.3347719E-03,   1.3036545E-03
     +,   1.2758233E-03,   1.2514311E-03,   1.2306137E-03
     +,   1.2135007E-03,   1.2002209E-03,   1.1909063E-03
     +,   1.1856965E-03,   1.1847398E-03,   1.1881868E-03
     +,   1.1961865E-03,   1.2088749E-03,   1.2263700E-03
     +,   1.2487508E-03,   1.2760526E-03,   1.3082494E-03
     +,   1.3452463E-03,   1.3868766E-03,   1.4329007E-03
     +,   1.4830055E-03,   1.5368218E-03,   1.5939435E-03
     +,   1.6539533E-03,   1.7164386E-03,   1.7810431E-03
     +,   1.8474902E-03,   1.9156024E-03,   1.9853474E-03
     +,   2.0568464E-03,   2.1303920E-03,   2.2064247E-03
     +,   2.2855522E-03,   2.3685058E-03,   2.4561135E-03
     +,   2.5492620E-03,   2.6488453E-03,   2.7557178E-03
     +,   2.8706477E-03,   2.9942424E-03,   3.1269256E-03
     +,   3.2688736E-03,   3.4199627E-03,   3.5797369E-03
     +,   3.7473848E-03,   3.9217188E-03,   4.1011577E-03
     +,   4.2837569E-03,   4.4672629E-03,   4.6491846E-03
     +,   4.8268507E-03,   4.9975575E-03,   5.1586912E-03
     +,   5.3078677E-03,   5.4429895E-03,   5.5624289E-03
     +,   5.6650271E-03,   5.7501444E-03,   5.8176261E-03
     +,   5.8677378E-03,   5.9010633E-03,   5.9183678E-03
     +,   5.9204483E-03,   5.9080021E-03,   5.8814818E-03
     +,   5.8410657E-03,   5.7865726E-03,   5.7174978E-03
     +,   5.6330920E-03,   5.5324761E-03,   5.4147686E-03
     +,   5.2792756E-03,   5.1256167E-03,   4.9538929E-03
     +,   4.7647450E-03,   4.5594149E-03,   4.3397467E-03
     +,   4.1081100E-03,   3.8672970E-03,   3.6203875E-03
     +,   3.3706205E-03,   3.1212214E-03,   2.8752403E-03
     +,   2.6354520E-03,   2.4042882E-03,   2.1837216E-03
     +,   1.9752763E-03,   1.7800314E-03,   1.5986371E-03
     +,   1.4313463E-03,   1.2780837E-03,   1.1385132E-03
     +,   1.0120905E-03,   8.9810923E-04,   7.9576438E-04
     +,   7.0420158E-04,   6.2254362E-04,   5.4991274E-04
     +,   4.8546042E-04,   4.2838333E-04,   3.7792174E-04
     +,   3.3337111E-04,   2.9408649E-04,   2.5947887E-04
     +,   2.2901119E-04,   2.0219947E-04,   1.7861063E-04
     +,   1.5785699E-04,   1.3959191E-04,   1.2350795E-04
     +,   1.0933488E-04,   9.6832788E-05,   8.5792897E-05
     +,   7.6031189E-05,   6.7388697E-05,   5.9726091E-05
     +,   5.2923748E-05,   4.6877260E-05,   4.1497293E-05
     +,   3.6705915E-05,   3.2436448E-05,   2.8630639E-05
     +,   2.5237923E-05,   2.2214490E-05,   1.9521523E-05
     +,   1.7125156E-05,   1.4995000E-05,   1.3104238E-05
     +,   1.1428554E-05,   9.9462559E-06,   8.6375103E-06
     +,   7.4844938E-06,   6.4708511E-06,   5.5818350E-06
     +,   4.8039033E-06,   4.1248559E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt115 = Yx/0.130833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0347877E-04,   1.0840008E-04
     +,   1.1348675E-04,   1.1874109E-04,   1.2416553E-04
     +,   1.2976267E-04,   1.3553520E-04,   1.4148612E-04
     +,   1.4761856E-04,   1.5393626E-04,   1.6044313E-04
     +,   1.6714384E-04,   1.7404321E-04,   1.8114693E-04
     +,   1.8846134E-04,   1.9599350E-04,   2.0375117E-04
     +,   2.1174290E-04,   2.1997819E-04,   2.2846730E-04
     +,   2.3722110E-04,   2.4625164E-04,   2.5557113E-04
     +,   2.6519317E-04,   2.7513102E-04,   2.8539900E-04
     +,   2.9601157E-04,   3.0698310E-04,   3.1832836E-04
     +,   3.3006136E-04,   3.4219629E-04,   3.5474665E-04
     +,   3.6772556E-04,   3.8114504E-04,   3.9501683E-04
     +,   4.0935169E-04,   4.2415946E-04,   4.3944948E-04
     +,   4.5523082E-04,   4.7151133E-04,   4.8829941E-04
     +,   5.0560327E-04,   5.2343076E-04,   5.4179068E-04
     +,   5.6069234E-04,   5.8014569E-04,   6.0016103E-04
     +,   6.2074937E-04,   6.4192223E-04,   6.6369190E-04
     +,   6.8606879E-04,   7.0906390E-04,   7.3268416E-04
     +,   7.5693690E-04,   7.8182243E-04,   8.0733781E-04
     +,   8.3347358E-04,   8.6021319E-04,   8.8753324E-04
     +,   9.1540010E-04,   9.4377151E-04,   9.7259728E-04
     +,   1.0018152E-03,   1.0313583E-03,   1.0611526E-03
     +,   1.0911156E-03,   1.1211658E-03,   1.1512162E-03
     +,   1.1811865E-03,   1.2109971E-03,   1.2405765E-03
     +,   1.2698626E-03,   1.2988050E-03,   1.3273647E-03
     +,   1.3555138E-03,   1.3832431E-03,   1.4105469E-03
     +,   1.4374311E-03,   1.4639060E-03,   1.4899860E-03
     +,   1.5156746E-03,   1.5409737E-03,   1.5658665E-03
     +,   1.5903210E-03,   1.6142779E-03,   1.6376644E-03
     +,   1.6603729E-03,   1.6822778E-03,   1.7032315E-03
     +,   1.7230725E-03,   1.7416346E-03,   1.7587467E-03
     +,   1.7742511E-03,   1.7880122E-03,   1.7999227E-03
     +,   1.8099169E-03,   1.8179754E-03,   1.8241308E-03
     +,   1.8284703E-03,   1.8311369E-03,   1.8323225E-03
     +,   1.8322596E-03,   1.8312165E-03,   1.8294794E-03
     +,   1.8273393E-03,   1.8250771E-03,   1.8229443E-03
     +,   1.8211566E-03,   1.8198722E-03,   1.8191875E-03
     +,   1.8191311E-03,   1.8196595E-03,   1.8206593E-03
     +,   1.8219622E-03,   1.8233450E-03,   1.8245535E-03
     +,   1.8253146E-03,   1.8253565E-03,   1.8244276E-03
     +,   1.8223153E-03,   1.8188627E-03,   1.8139801E-03
     +,   1.8076523E-03,   1.7999437E-03,   1.7909958E-03
     +,   1.7810229E-03,   1.7702937E-03,   1.7591262E-03
     +,   1.7478591E-03,   1.7368377E-03,   1.7263872E-03
     +,   1.7167993E-03,   1.7083073E-03,   1.7010740E-03
     +,   1.6951787E-03,   1.6906122E-03,   1.6872758E-03
     +,   1.6849787E-03,   1.6834559E-03,   1.6823708E-03
     +,   1.6813377E-03,   1.6799385E-03,   1.6777370E-03
     +,   1.6743058E-03,   1.6692424E-03,   1.6621855E-03
     +,   1.6528313E-03,   1.6409452E-03,   1.6263713E-03
     +,   1.6090339E-03,   1.5889429E-03,   1.5661868E-03
     +,   1.5409327E-03,   1.5134111E-03,   1.4839080E-03
     +,   1.4527573E-03,   1.4203219E-03,   1.3869829E-03
     +,   1.3531271E-03,   1.3191369E-03,   1.2853788E-03
     +,   1.2521923E-03,   1.2198916E-03,   1.1887556E-03
     +,   1.1590233E-03,   1.1308998E-03,   1.1045523E-03
     +,   1.0801186E-03,   1.0577032E-03,   1.0373850E-03
     +,   1.0192227E-03,   1.0032580E-03,   9.8951801E-04
     +,   9.7802037E-04,   9.6877740E-04,   9.6179638E-04
     +,   9.5708523E-04,   9.5465279E-04,   9.5451076E-04
     +,   9.5667888E-04,   9.6118508E-04,   9.6806814E-04
     +,   9.7738451E-04,   9.8920322E-04,   1.0036177E-03
     +,   1.0207397E-03,   1.0407049E-03,   1.0636693E-03
     +,   1.0898093E-03,   1.1193168E-03,   1.1523900E-03
     +,   1.1892314E-03,   1.2300290E-03,   1.2749501E-03
     +,   1.3241288E-03,   1.3776477E-03,   1.4355287E-03
     +,   1.4977151E-03,   1.5640699E-03,   1.6343655E-03
     +,   1.7082809E-03,   1.7854011E-03,   1.8652390E-03
     +,   1.9472424E-03,   2.0308096E-03,   2.1153276E-03
     +,   2.2002067E-03,   2.2848921E-03,   2.3689207E-03
     +,   2.4519421E-03,   2.5337574E-03,   2.6143130E-03
     +,   2.6937320E-03,   2.7723031E-03,   2.8504604E-03
     +,   2.9287455E-03,   3.0077656E-03,   3.0881332E-03
     +,   3.1703953E-03,   3.2549496E-03,   3.3419791E-03
     +,   3.4313821E-03,   3.5226943E-03,   3.6150834E-03
     +,   3.7073039E-03,   3.7977442E-03,   3.8844424E-03
     +,   3.9651794E-03,   4.0375916E-03,   4.0992815E-03
     +,   4.1479515E-03,   4.1815499E-03,   4.1983803E-03
     +,   4.1972175E-03,   4.1773659E-03,   4.1386904E-03
     +,   4.0816227E-03,   4.0071108E-03,   3.9165397E-03
     +,   3.8116395E-03,   3.6943676E-03,   3.5668062E-03
     +,   3.4310455E-03,   3.2890928E-03,   3.1428032E-03
     +,   2.9938428E-03,   2.8436622E-03,   2.6934829E-03
     +,   2.5443172E-03,   2.3970190E-03,   2.2522744E-03
     +,   2.1106540E-03,   1.9726532E-03,   1.8386978E-03
     +,   1.7091576E-03,   1.5843614E-03,   1.4646108E-03
     +,   1.3501655E-03,   1.2412374E-03,   1.1379925E-03
     +,   1.0405526E-03,   9.4898470E-04,   8.6329592E-04
     +,   7.8343955E-04,   7.0932729E-04,   6.4081681E-04
     +,   5.7772681E-04,   5.1984657E-04,   4.6693804E-04
     +,   4.1873928E-04,   3.7497492E-04,   3.3536422E-04
     +,   2.9962262E-04,   2.6746342E-04,   2.3860541E-04
     +,   2.1277752E-04,   1.8971498E-04,   1.6916807E-04
     +,   1.5089750E-04,   1.3468090E-04,   1.2030821E-04
     +,   1.0758683E-04,   9.6337571E-05,   8.6397660E-05
     +,   7.7617624E-05,   6.9863301E-05,   6.3012878E-05
     +,   5.6957255E-05,   5.1599629E-05,   4.6853263E-05
     +,   4.2642041E-05,   3.8898299E-05,   3.5563084E-05
     +,   3.2584383E-05,   2.9917181E-05,   2.7521932E-05
     +,   2.5364632E-05,   2.3415538E-05,   2.1649166E-05
     +,   2.0043299E-05,   1.8578963E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt120 = Yx/0.097475
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1722149E-03,   2.4912457E-03
     +,   2.8325592E-03,   3.1931398E-03,   3.5693410E-03
     +,   3.9573074E-03,   4.3536057E-03,   4.7560385E-03
     +,   5.1645283E-03,   5.5819070E-03,   6.0142023E-03
     +,   6.4702695E-03,   6.9603776E-03,   7.4937544E-03
     +,   8.0753919E-03,   8.7028435E-03,   9.3643526E-03
     +,   1.0039584E-02,   1.0704101E-02,   1.1337234E-02
     +,   1.1931467E-02,   1.2499675E-02,   1.3075911E-02
     +,   1.3707614E-02,   1.4439979E-02,   1.5298808E-02
     +,   1.6278528E-02,   1.7341847E-02,   1.8430756E-02
     +,   1.9483667E-02,   2.0450169E-02,   2.1298025E-02
     +,   2.2012083E-02,   2.2589322E-02,   2.3033837E-02
     +,   2.3353389E-02,   2.3556191E-02,   2.3646528E-02
     +,   2.3620972E-02,   2.3467332E-02,   2.3167958E-02
     +,   2.2706747E-02,   2.2076972E-02,   2.1286381E-02
     +,   2.0358060E-02,   1.9326521E-02,   1.8230557E-02
     +,   1.7105235E-02,   1.5976693E-02,   1.4861763E-02
     +,   1.3771864E-02,   1.2718594E-02,   1.1717167E-02
     +,   1.0785731E-02,   9.9415034E-03,   9.1956910E-03
     +,   8.5506057E-03,   7.9997433E-03,   7.5308080E-03
     +,   7.1296724E-03,   6.7836698E-03,   6.4833332E-03
     +,   6.2222742E-03,   5.9960419E-03,   5.8006295E-03
     +,   5.6313933E-03,   5.4826019E-03,   5.3476803E-03
     +,   5.2198665E-03,   5.0930018E-03,   4.9621905E-03
     +,   4.8241969E-03,   4.6774689E-03,   4.5219748E-03
     +,   4.3587587E-03,   4.1895281E-03,   4.0162825E-03
     +,   3.8410032E-03,   3.6654784E-03,   3.4912692E-03
     +,   3.3197366E-03,   3.1520796E-03,   2.9894384E-03
     +,   2.8328940E-03,   2.6835289E-03,   2.5423702E-03
     +,   2.4103797E-03,   2.2883650E-03,   2.1769544E-03
     +,   2.0765220E-03,   1.9871725E-03,   1.9087431E-03
     +,   1.8408004E-03,   1.7826693E-03,   1.7334956E-03
     +,   1.6922809E-03,   1.6579432E-03,   1.6293717E-03
     +,   1.6054671E-03,   1.5851818E-03,   1.5675513E-03
     +,   1.5517109E-03,   1.5369056E-03,   1.5224993E-03
     +,   1.5079703E-03,   1.4929060E-03,   1.4769960E-03
     +,   1.4600214E-03,   1.4418453E-03,   1.4224007E-03
     +,   1.4016824E-03,   1.3797365E-03,   1.3566483E-03
     +,   1.3325363E-03,   1.3075469E-03,   1.2818398E-03
     +,   1.2555877E-03,   1.2289644E-03,   1.2021469E-03
     +,   1.1753038E-03,   1.1485908E-03,   1.1221542E-03
     +,   1.0961223E-03,   1.0706049E-03,   1.0456920E-03
     +,   1.0214554E-03,   9.9794602E-04,   9.7519805E-04
     +,   9.5322437E-04,   9.3202590E-04,   9.1158517E-04
     +,   8.9187571E-04,   8.7285740E-04,   8.5448584E-04
     +,   8.3670567E-04,   8.1945932E-04,   8.0268813E-04
     +,   7.8633073E-04,   7.7032740E-04,   7.5461925E-04
     +,   7.3915196E-04,   7.2387542E-04,   7.0874474E-04
     +,   6.9371943E-04,   6.7876827E-04,   6.6386425E-04
     +,   6.4898835E-04,   6.3412817E-04,   6.1928038E-04
     +,   6.0444593E-04,   5.8963330E-04,   5.7485676E-04
     +,   5.6013814E-04,   5.4550252E-04,   5.3097855E-04
     +,   5.1660085E-04,   5.0240639E-04,   4.8843346E-04
     +,   4.7472180E-04,   4.6131393E-04,   4.4824983E-04
     +,   4.3557031E-04,   4.2331518E-04,   4.1152182E-04
     +,   4.0022618E-04,   3.8946018E-04,   3.7925498E-04
     +,   3.6963756E-04,   3.6063150E-04,   3.5225681E-04
     +,   3.4453094E-04,   3.3746820E-04,   3.3107886E-04
     +,   3.2537035E-04,   3.2034711E-04,   3.1601137E-04
     +,   3.1236201E-04,   3.0939595E-04,   3.0710804E-04
     +,   3.0549086E-04,   3.0453518E-04,   3.0423014E-04
     +,   3.0456364E-04,   3.0552177E-04,   3.0708965E-04
     +,   3.0925093E-04,   3.1198797E-04,   3.1528226E-04
     +,   3.1911413E-04,   3.2346247E-04,   3.2830500E-04
     +,   3.3361875E-04,   3.3937866E-04,   3.4555863E-04
     +,   3.5213149E-04,   3.5906842E-04,   3.6633908E-04
     +,   3.7391117E-04,   3.8175171E-04,   3.8982581E-04
     +,   3.9809689E-04,   4.0652641E-04,   4.1507557E-04
     +,   4.2370358E-04,   4.3236834E-04,   4.4102612E-04
     +,   4.4963401E-04,   4.5814656E-04,   4.6651764E-04
     +,   4.7470239E-04,   4.8265551E-04,   4.9033092E-04
     +,   4.9768342E-04,   5.0466968E-04,   5.1124668E-04
     +,   5.1737315E-04,   5.2300934E-04,   5.2811851E-04
     +,   5.3266587E-04,   5.3661899E-04,   5.3994945E-04
     +,   5.4263195E-04,   5.4464448E-04,   5.4596900E-04
     +,   5.4659171E-04,   5.4650201E-04,   5.4569461E-04
     +,   5.4416817E-04,   5.4192526E-04,   5.3897261E-04
     +,   5.3532148E-04,   5.3098710E-04,   5.2598829E-04
     +,   5.2034704E-04,   5.1408994E-04,   5.0724571E-04
     +,   4.9984583E-04,   4.9192453E-04,   4.8351841E-04
     +,   4.7466546E-04,   4.6540480E-04,   4.5577681E-04
     +,   4.4582327E-04,   4.3558472E-04,   4.2510251E-04
     +,   4.1441768E-04,   4.0357065E-04,   3.9260017E-04
     +,   3.8154388E-04,   3.7043844E-04,   3.5931839E-04
     +,   3.4821604E-04,   3.3716240E-04,   3.2618621E-04
     +,   3.1531352E-04,   3.0456809E-04,   2.9397206E-04
     +,   2.8354506E-04,   2.7330412E-04,   2.6326382E-04
     +,   2.5343755E-04,   2.4383637E-04,   2.3446903E-04
     +,   2.2534229E-04,   2.1646218E-04,   2.0783236E-04
     +,   1.9945500E-04,   1.9133143E-04,   1.8346203E-04
     +,   1.7584540E-04,   1.6847937E-04,   1.6136147E-04
     +,   1.5448846E-04,   1.4785607E-04,   1.4145968E-04
     +,   1.3529482E-04,   1.2935587E-04,   1.2363786E-04
     +,   1.1813481E-04,   1.1284134E-04,   1.0775141E-04
     +,   1.0285951E-04,   9.8159559E-05,   9.3646064E-05
     +,   8.9313107E-05,   8.5155290E-05,   8.1166960E-05
     +,   7.7342564E-05,   7.3677023E-05,   7.0164882E-05
     +,   6.6801265E-05,   6.3580970E-05,   6.0499340E-05
     +,   5.7551413E-05,   5.4732722E-05,   5.2038551E-05
     +,   4.9464656E-05,   4.7006510E-05,   4.4660086E-05
     +,   4.2421067E-05,   4.0285577E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt60 = Yx/0.246978260869565
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.2021212E-04,   9.2136970E-04
     +,   1.0298461E-03,   1.1454272E-03,   1.2678121E-03
     +,   1.3966262E-03,   1.5314460E-03,   1.6718382E-03
     +,   1.8174046E-03,   1.9678655E-03,   2.1231265E-03
     +,   2.2833890E-03,   2.4492487E-03,   2.6217878E-03
     +,   2.8026393E-03,   2.9940160E-03,   3.1986770E-03
     +,   3.4198323E-03,   3.6610153E-03,   3.9259149E-03
     +,   4.2182016E-03,   4.5413566E-03,   4.8984629E-03
     +,   5.2920110E-03,   5.7234853E-03,   6.1930185E-03
     +,   6.6987793E-03,   7.2364616E-03,   7.7988761E-03
     +,   8.3759911E-03,   8.9558847E-03,   9.5270146E-03
     +,   1.0082375E-02,   1.0624880E-02,   1.1172422E-02
     +,   1.1759503E-02,   1.2431907E-02,   1.3233271E-02
     +,   1.4186773E-02,   1.5280211E-02,   1.6465142E-02
     +,   1.7674122E-02,   1.8850794E-02,   1.9976735E-02
     +,   2.1076983E-02,   2.2196295E-02,   2.3358662E-02
     +,   2.4536200E-02,   2.5654560E-02,   2.6636956E-02
     +,   2.7455783E-02,   2.8148131E-02,   2.8775411E-02
     +,   2.9357057E-02,   2.9833963E-02,   3.0096585E-02
     +,   3.0053118E-02,   2.9683679E-02,   2.9041842E-02
     +,   2.8211581E-02,   2.7257258E-02,   2.6200308E-02
     +,   2.5029225E-02,   2.3727482E-02,   2.2299629E-02
     +,   2.0782894E-02,   1.9241557E-02,   1.7750807E-02
     +,   1.6376294E-02,   1.5159388E-02,   1.4112457E-02
     +,   1.3225127E-02,   1.2475104E-02,   1.1837883E-02
     +,   1.1291048E-02,   1.0813992E-02,   1.0386144E-02
     +,   9.9861259E-03,   9.5933573E-03,   9.1909384E-03
     +,   8.7685436E-03,   8.3236340E-03,   7.8609176E-03
     +,   7.3899445E-03,   6.9222893E-03,   6.4687775E-03
     +,   6.0378201E-03,   5.6346459E-03,   5.2616540E-03
     +,   4.9190326E-03,   4.6056909E-03,   4.3199803E-03
     +,   4.0601161E-03,   3.8243842E-03,   3.6111758E-03
     +,   3.4189487E-03,   3.2460899E-03,   3.0909122E-03
     +,   2.9516001E-03,   2.8262879E-03,   2.7130768E-03
     +,   2.6101512E-03,   2.5158054E-03,   2.4285442E-03
     +,   2.3470845E-03,   2.2703914E-03,   2.1976752E-03
     +,   2.1283689E-03,   2.0620942E-03,   1.9986378E-03
     +,   1.9379084E-03,   1.8798900E-03,   1.8246243E-03
     +,   1.7721540E-03,   1.7225239E-03,   1.6757332E-03
     +,   1.6317497E-03,   1.5904773E-03,   1.5517744E-03
     +,   1.5154456E-03,   1.4812541E-03,   1.4489343E-03
     +,   1.4182025E-03,   1.3887621E-03,   1.3603276E-03
     +,   1.3326276E-03,   1.3054122E-03,   1.2784643E-03
     +,   1.2515986E-03,   1.2246679E-03,   1.1975581E-03
     +,   1.1701933E-03,   1.1425288E-03,   1.1145516E-03
     +,   1.0862722E-03,   1.0577254E-03,   1.0289650E-03
     +,   1.0000616E-03,   9.7109517E-04,   9.4215159E-04
     +,   9.1332506E-04,   8.8471267E-04,   8.5640809E-04
     +,   8.2850305E-04,   8.0108742E-04,   7.7424292E-04
     +,   7.4804341E-04,   7.2255882E-04,   6.9785019E-04
     +,   6.7396864E-04,   6.5095787E-04,   6.2885543E-04
     +,   6.0769200E-04,   5.8748986E-04,   5.6826597E-04
     +,   5.5003358E-04,   5.3280196E-04,   5.1657466E-04
     +,   5.0135364E-04,   4.8713942E-04,   4.7392937E-04
     +,   4.6172008E-04,   4.5050794E-04,   4.4028860E-04
     +,   4.3105651E-04,   4.2280686E-04,   4.1553390E-04
     +,   4.0923234E-04,   4.0389638E-04,   3.9951893E-04
     +,   3.9609362E-04,   3.9361237E-04,   3.9206617E-04
     +,   3.9144454E-04,   3.9173540E-04,   3.9292464E-04
     +,   3.9499535E-04,   3.9792861E-04,   4.0170146E-04
     +,   4.0628872E-04,   4.1166085E-04,   4.1778380E-04
     +,   4.2462067E-04,   4.3212879E-04,   4.4026223E-04
     +,   4.4896943E-04,   4.5819409E-04,   4.6787632E-04
     +,   4.7795154E-04,   4.8834970E-04,   4.9899833E-04
     +,   5.0982111E-04,   5.2073842E-04,   5.3166784E-04
     +,   5.4252555E-04,   5.5322726E-04,   5.6368776E-04
     +,   5.7382125E-04,   5.8354554E-04,   5.9277914E-04
     +,   6.0144428E-04,   6.0946640E-04,   6.1677652E-04
     +,   6.2331167E-04,   6.2901346E-04,   6.3383230E-04
     +,   6.3772517E-04,   6.4065692E-04,   6.4260070E-04
     +,   6.4353860E-04,   6.4346008E-04,   6.4236479E-04
     +,   6.4025895E-04,   6.3715823E-04,   6.3308486E-04
     +,   6.2806875E-04,   6.2214630E-04,   6.1535992E-04
     +,   6.0775626E-04,   5.9938797E-04,   5.9031049E-04
     +,   5.8058131E-04,   5.7026115E-04,   5.5941200E-04
     +,   5.4809533E-04,   5.3637265E-04,   5.2430492E-04
     +,   5.1195250E-04,   4.9937196E-04,   4.8661797E-04
     +,   4.7374310E-04,   4.6079714E-04,   4.4782498E-04
     +,   4.3486856E-04,   4.2196747E-04,   4.0915635E-04
     +,   3.9646614E-04,   3.8392548E-04,   3.7155923E-04
     +,   3.5938868E-04,   3.4743175E-04,   3.3570459E-04
     +,   3.2422045E-04,   3.1298964E-04,   3.0202040E-04
     +,   2.9131953E-04,   2.8089219E-04,   2.7074129E-04
     +,   2.6086858E-04,   2.5127511E-04,   2.4196062E-04
     +,   2.3292328E-04,   2.2416172E-04,   2.1567350E-04
     +,   2.0745516E-04,   1.9950279E-04,   1.9181258E-04
     +,   1.8438033E-04,   1.7720104E-04,   1.7026944E-04
     +,   1.6358052E-04,   1.5712908E-04,   1.5090909E-04
     +,   1.4491477E-04,   1.3914045E-04,   1.3357999E-04
     +,   1.2822710E-04,   1.2307578E-04,   1.1812001E-04
     +,   1.1335334E-04,   1.0876949E-04,   1.0436234E-04
     +,   1.0012597E-04,   9.6054042E-05,   9.2140508E-05
     +,   8.8379711E-05,   8.4765641E-05,   8.1292877E-05
     +,   7.7955730E-05,   7.4749114E-05,   7.1667637E-05
     +,   6.8706599E-05,   6.5860964E-05,   6.3126397E-05
     +,   6.0498296E-05,   5.7972669E-05,   5.5545406E-05
     +,   5.3212640E-05,   5.0970881E-05,   4.8816572E-05
     +,   4.6746569E-05,   4.4757606E-05,   4.2846867E-05
     +,   4.1011415E-05,   3.9248720E-05,   3.7556092E-05
     +,   3.5931207E-05,   3.4371671E-05,   3.2875316E-05
     +,   3.1439922E-05,   3.0063537E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt65 = Yx/0.301291666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9992257E-04,   4.3429897E-04
     +,   4.7117169E-04,   5.1070971E-04,   5.5310549E-04
     +,   5.9858052E-04,   6.4738921E-04,   6.9982535E-04
     +,   7.5622683E-04,   8.1698422E-04,   8.8253792E-04
     +,   9.5338543E-04,   1.0300775E-03,   1.1132155E-03
     +,   1.2034402E-03,   1.3014170E-03,   1.4078107E-03
     +,   1.5232605E-03,   1.6483463E-03,   1.7835513E-03
     +,   1.9292292E-03,   2.0855761E-03,   2.2526141E-03
     +,   2.4302029E-03,   2.6180304E-03,   2.8156997E-03
     +,   3.0227508E-03,   3.2387523E-03,   3.4633745E-03
     +,   3.6964468E-03,   3.9380067E-03,   4.1883094E-03
     +,   4.4478294E-03,   4.7172350E-03,   4.9974117E-03
     +,   5.2895434E-03,   5.5952482E-03,   5.9167990E-03
     +,   6.2572984E-03,   6.6207028E-03,   7.0115426E-03
     +,   7.4341819E-03,   7.8917509E-03,   8.3848955E-03
     +,   8.9108199E-03,   9.4633531E-03,   1.0034530E-02
     +,   1.0618161E-02,   1.1214872E-02,   1.1837098E-02
     +,   1.2510784E-02,   1.3270874E-02,   1.4149177E-02
     +,   1.5157877E-02,   1.6276665E-02,   1.7453074E-02
     +,   1.8619975E-02,   1.9723997E-02,   2.0749023E-02
     +,   2.1718871E-02,   2.2676723E-02,   2.3657519E-02
     +,   2.4675811E-02,   2.5739232E-02,   2.6871322E-02
     +,   2.8116412E-02,   2.9510524E-02,   3.1033786E-02
     +,   3.2587808E-02,   3.4026828E-02,   3.5228573E-02
     +,   3.6144819E-02,   3.6787786E-02,   3.7174270E-02
     +,   3.7291851E-02,   3.7116427E-02,   3.6644544E-02
     +,   3.5903536E-02,   3.4945384E-02,   3.3845447E-02
     +,   3.2693494E-02,   3.1556312E-02,   3.0432733E-02
     +,   2.9246030E-02,   2.7893428E-02,   2.6318457E-02
     +,   2.4555342E-02,   2.2715736E-02,   2.0935025E-02
     +,   1.9314161E-02,   1.7889479E-02,   1.6638149E-02
     +,   1.5506466E-02,   1.4440936E-02,   1.3407658E-02
     +,   1.2395846E-02,   1.1410603E-02,   1.0463563E-02
     +,   9.5658600E-03,   8.7255929E-03,   7.9475483E-03
     +,   7.2343918E-03,   6.5870536E-03,   6.0053025E-03
     +,   5.4876152E-03,   5.0313333E-03,   4.6328241E-03
     +,   4.2876154E-03,   3.9905631E-03,   3.7360885E-03
     +,   3.5183758E-03,   3.3315422E-03,   3.1698989E-03
     +,   3.0281257E-03,   2.9015024E-03,   2.7860273E-03
     +,   2.6785121E-03,   2.5765635E-03,   2.4785423E-03
     +,   2.3834258E-03,   2.2906859E-03,   2.2001681E-03
     +,   2.1119402E-03,   2.0262084E-03,   1.9432243E-03
     +,   1.8632519E-03,   1.7865063E-03,   1.7131645E-03
     +,   1.6433283E-03,   1.5770572E-03,   1.5143518E-03
     +,   1.4551829E-03,   1.3994839E-03,   1.3471813E-03
     +,   1.2981838E-03,   1.2524009E-03,   1.2097456E-03
     +,   1.1701322E-03,   1.1334772E-03,   1.0996957E-03
     +,   1.0687043E-03,   1.0404112E-03,   1.0147154E-03
     +,   9.9150254E-04,   9.7064627E-04,   9.5200271E-04
     +,   9.3541207E-04,   9.2070090E-04,   9.0768118E-04
     +,   8.9615519E-04,   8.8591472E-04,   8.7675033E-04
     +,   8.6844951E-04,   8.6080463E-04,   8.5361325E-04
     +,   8.4668398E-04,   8.3983975E-04,   8.3291961E-04
     +,   8.2578149E-04,   8.1830483E-04,   8.1039098E-04
     +,   8.0196507E-04,   7.9297583E-04,   7.8339595E-04
     +,   7.7322067E-04,   7.6246646E-04,   7.5116981E-04
     +,   7.3938700E-04,   7.2718866E-04,   7.1465952E-04
     +,   7.0189481E-04,   6.8900076E-04,   6.7608600E-04
     +,   6.6326489E-04,   6.5065245E-04,   6.3836214E-04
     +,   6.2650326E-04,   6.1518181E-04,   6.0449645E-04
     +,   5.9453677E-04,   5.8538438E-04,   5.7711155E-04
     +,   5.6977896E-04,   5.6343799E-04,   5.5812806E-04
     +,   5.5387814E-04,   5.5070769E-04,   5.4862443E-04
     +,   5.4762751E-04,   5.4770667E-04,   5.4884277E-04
     +,   5.5100885E-04,   5.5417040E-04,   5.5828650E-04
     +,   5.6330924E-04,   5.6918617E-04,   5.7585863E-04
     +,   5.8326393E-04,   5.9133465E-04,   6.0000084E-04
     +,   6.0918805E-04,   6.1881897E-04,   6.2881387E-04
     +,   6.3909165E-04,   6.4956705E-04,   6.6015526E-04
     +,   6.7076908E-04,   6.8132114E-04,   6.9172238E-04
     +,   7.0188462E-04,   7.1171997E-04,   7.2114210E-04
     +,   7.3006377E-04,   7.3840236E-04,   7.4607757E-04
     +,   7.5301074E-04,   7.5912912E-04,   7.6436409E-04
     +,   7.6865207E-04,   7.7193609E-04,   7.7416562E-04
     +,   7.7529758E-04,   7.7529706E-04,   7.7413680E-04
     +,   7.7179895E-04,   7.6827483E-04,   7.6356326E-04
     +,   7.5767451E-04,   7.5062655E-04,   7.4244698E-04
     +,   7.3317066E-04,   7.2284276E-04,   7.1151386E-04
     +,   6.9924223E-04,   6.8609294E-04,   6.7213504E-04
     +,   6.5744249E-04,   6.4209261E-04,   6.2616600E-04
     +,   6.0974353E-04,   5.9290632E-04,   5.7573640E-04
     +,   5.5831450E-04,   5.4071815E-04,   5.2302179E-04
     +,   5.0529785E-04,   4.8761434E-04,   4.7003425E-04
     +,   4.5261491E-04,   4.3541082E-04,   4.1846914E-04
     +,   4.0183173E-04,   3.8553638E-04,   3.6961550E-04
     +,   3.5409490E-04,   3.3899603E-04,   3.2433658E-04
     +,   3.1012998E-04,   2.9638427E-04,   2.8310440E-04
     +,   2.7029292E-04,   2.5794911E-04,   2.4606904E-04
     +,   2.3464687E-04,   2.2367574E-04,   2.1314637E-04
     +,   2.0304816E-04,   1.9337035E-04,   1.8410127E-04
     +,   1.7522831E-04,   1.6673829E-04,   1.5861874E-04
     +,   1.5085687E-04,   1.4343957E-04,   1.3635388E-04
     +,   1.2958785E-04,   1.2312863E-04,   1.1696490E-04
     +,   1.1108458E-04,   1.0547679E-04,   1.0013038E-04
     +,   9.5035095E-05,   9.0180481E-05,   8.5557011E-05
     +,   8.1154838E-05,   7.6965072E-05,   7.2978699E-05
     +,   6.9186994E-05,   6.5581917E-05,   6.2155174E-05
     +,   5.8899215E-05,   5.5806304E-05,   5.2869396E-05
     +,   5.0081224E-05,   4.7435205E-05,   4.4924589E-05
     +,   4.2543179E-05,   4.0284722E-05,   3.8143458E-05
     +,   3.6113572E-05,   3.4189743E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt70 = Yx/0.374
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0545035E-04,   4.4146267E-04
     +,   4.7900979E-04,   5.1790499E-04,   5.5793225E-04
     +,   5.9885078E-04,   6.4039842E-04,   6.8229967E-04
     +,   7.2427170E-04,   7.6603401E-04,   8.0731505E-04
     +,   8.4786210E-04,   8.8745181E-04,   9.2589750E-04
     +,   9.6305920E-04,   9.9885068E-04,   1.0332463E-03
     +,   1.0662872E-03,   1.0980830E-03,   1.1288169E-03
     +,   1.1587464E-03,   1.1881974E-03,   1.2175698E-03
     +,   1.2473275E-03,   1.2779956E-03,   1.3101578E-03
     +,   1.3444495E-03,   1.3815546E-03,   1.4222061E-03
     +,   1.4671807E-03,   1.5173043E-03,   1.5734527E-03
     +,   1.6365479E-03,   1.7075583E-03,   1.7874844E-03
     +,   1.8773368E-03,   1.9780952E-03,   2.0906501E-03
     +,   2.2157391E-03,   2.3538482E-03,   2.5051625E-03
     +,   2.6694844E-03,   2.8462373E-03,   3.0345249E-03
     +,   3.2332817E-03,   3.4415096E-03,   3.6586195E-03
     +,   3.8848070E-03,   4.1214162E-03,   4.3712314E-03
     +,   4.6384810E-03,   4.9286038E-03,   5.2475678E-03
     +,   5.6008357E-03,   5.9921071E-03,   6.4222668E-03
     +,   6.8887253E-03,   7.3856744E-03,   7.9053016E-03
     +,   8.4398231E-03,   8.9839399E-03,   9.5372889E-03
     +,   1.0106447E-02,   1.0706579E-02,   1.1362113E-02
     +,   1.2106000E-02,   1.2976570E-02,   1.4010410E-02
     +,   1.5232212E-02,   1.6642923E-02,   1.8211048E-02
     +,   1.9870549E-02,   2.1530870E-02,   2.3102492E-02
     +,   2.4537794E-02,   2.5867179E-02,   2.7194992E-02
     +,   2.8630788E-02,   3.0195052E-02,   3.1795453E-02
     +,   3.3327017E-02,   3.4803152E-02,   3.6349494E-02
     +,   3.8038108E-02,   3.9762363E-02,   4.1330375E-02
     +,   4.2674266E-02,   4.3917391E-02,   4.5234054E-02
     +,   4.6667282E-02,   4.8053350E-02,   4.9097899E-02
     +,   4.9585581E-02,   4.9567539E-02,   4.9290925E-02
     +,   4.8902877E-02,   4.8266921E-02,   4.7097329E-02
     +,   4.5225020E-02,   4.2708181E-02,   3.9745241E-02
     +,   3.6547620E-02,   3.3285361E-02,   3.0093752E-02
     +,   2.7082652E-02,   2.4334654E-02,   2.1894177E-02
     +,   1.9758519E-02,   1.7883820E-02,   1.6208820E-02
     +,   1.4681920E-02,   1.3274484E-02,   1.1978003E-02
     +,   1.0793043E-02,   9.7213909E-03,   8.7625794E-03
     +,   7.9140635E-03,   7.1710069E-03,   6.5262513E-03
     +,   5.9698978E-03,   5.4898672E-03,   5.0729420E-03
     +,   4.7060922E-03,   4.3777511E-03,   4.0787891E-03
     +,   3.8029160E-03,   3.5464622E-03,   3.3078736E-03
     +,   3.0868761E-03,   2.8837705E-03,   2.6987602E-03
     +,   2.5316537E-03,   2.3816775E-03,   2.2475591E-03
     +,   2.1276490E-03,   2.0201113E-03,   1.9231174E-03
     +,   1.8349518E-03,   1.7540994E-03,   1.6792926E-03
     +,   1.6095148E-03,   1.5439742E-03,   1.4820810E-03
     +,   1.4233999E-03,   1.3676389E-03,   1.3145920E-03
     +,   1.2641281E-03,   1.2161679E-03,   1.1706623E-03
     +,   1.1275795E-03,   1.0868930E-03,   1.0485834E-03
     +,   1.0126211E-03,   9.7897195E-04,   9.4758801E-04
     +,   9.1841619E-04,   8.9139363E-04,   8.6644775E-04
     +,   8.4350037E-04,   8.2247087E-04,   8.0327789E-04
     +,   7.8583654E-04,   7.7006727E-04,   7.5589429E-04
     +,   7.4324349E-04,   7.3204807E-04,   7.2224584E-04
     +,   7.1377918E-04,   7.0659519E-04,   7.0064515E-04
     +,   6.9588213E-04,   6.9226197E-04,   6.8974053E-04
     +,   6.8827189E-04,   6.8780960E-04,   6.8830315E-04
     +,   6.8969833E-04,   6.9193583E-04,   6.9495075E-04
     +,   6.9867197E-04,   7.0302252E-04,   7.0791855E-04
     +,   7.1326963E-04,   7.1898074E-04,   7.2495104E-04
     +,   7.3107635E-04,   7.3724729E-04,   7.4335525E-04
     +,   7.4929011E-04,   7.5494166E-04,   7.6020428E-04
     +,   7.6497591E-04,   7.6916005E-04,   7.7266811E-04
     +,   7.7542005E-04,   7.7734725E-04,   7.7839172E-04
     +,   7.7850826E-04,   7.7766553E-04,   7.7584566E-04
     +,   7.7304419E-04,   7.6927303E-04,   7.6455454E-04
     +,   7.5892627E-04,   7.5243739E-04,   7.4514805E-04
     +,   7.3712785E-04,   7.2845421E-04,   7.1921275E-04
     +,   7.0949126E-04,   6.9938117E-04,   6.8897550E-04
     +,   6.7836547E-04,   6.6764001E-04,   6.5688288E-04
     +,   6.4617267E-04,   6.3558138E-04,   6.2517065E-04
     +,   6.1499386E-04,   6.0509529E-04,   5.9550762E-04
     +,   5.8625278E-04,   5.7734305E-04,   5.6878035E-04
     +,   5.6055613E-04,   5.5265316E-04,   5.4504600E-04
     +,   5.3770206E-04,   5.3058227E-04,   5.2364188E-04
     +,   5.1683414E-04,   5.1010842E-04,   5.0341326E-04
     +,   4.9669697E-04,   4.8990926E-04,   4.8300182E-04
     +,   4.7592953E-04,   4.6865144E-04,   4.6113195E-04
     +,   4.5333966E-04,   4.4524961E-04,   4.3684346E-04
     +,   4.2810937E-04,   4.1904114E-04,   4.0963929E-04
     +,   3.9991087E-04,   3.8986880E-04,   3.7953074E-04
     +,   3.6891995E-04,   3.5806451E-04,   3.4699522E-04
     +,   3.3574647E-04,   3.2435576E-04,   3.1286199E-04
     +,   3.0130518E-04,   2.8972549E-04,   2.7816373E-04
     +,   2.6666006E-04,   2.5525276E-04,   2.4397855E-04
     +,   2.3287260E-04,   2.2196774E-04,   2.1129346E-04
     +,   2.0087624E-04,   1.9074060E-04,   1.8090669E-04
     +,   1.7139180E-04,   1.6221037E-04,   1.5337391E-04
     +,   1.4489004E-04,   1.3676385E-04,   1.2899798E-04
     +,   1.2159283E-04,   1.1454568E-04,   1.0785196E-04
     +,   1.0150592E-04,   9.5499192E-05,   8.9823043E-05
     +,   8.4466701E-05,   7.9419173E-05,   7.4668096E-05
     +,   7.0201226E-05,   6.6005268E-05,   6.2067425E-05
     +,   5.8374189E-05,   5.4912663E-05,   5.1669776E-05
     +,   4.8632741E-05,   4.5789417E-05,   4.3127668E-05
     +,   4.0636209E-05,   3.8303911E-05,   3.6120444E-05
     +,   3.4075780E-05,   3.2160657E-05,   3.0366125E-05
     +,   2.8684015E-05,   2.7106456E-05,   2.5626299E-05
     +,   2.4236691E-05,   2.2931425E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt75 = Yx/0.4466
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2564723E-04,   1.3191614E-04
     +,   1.3854261E-04,   1.4555025E-04,   1.5296302E-04
     +,   1.6080533E-04,   1.6910194E-04,   1.7787753E-04
     +,   1.8715655E-04,   1.9696334E-04,   2.0732144E-04
     +,   2.1825403E-04,   2.2978334E-04,   2.4193116E-04
     +,   2.5471882E-04,   2.6816750E-04,   2.8229921E-04
     +,   2.9713710E-04,   3.1270695E-04,   3.2903903E-04
     +,   3.4616955E-04,   3.6414375E-04,   3.8301837E-04
     +,   4.0286666E-04,   4.2377997E-04,   4.4587554E-04
     +,   4.6929889E-04,   4.9422984E-04,   5.2088808E-04
     +,   5.4953556E-04,   5.8048143E-04,   6.1408279E-04
     +,   6.5074244E-04,   6.9090701E-04,   7.3505711E-04
     +,   7.8369759E-04,   8.3733804E-04,   8.9647359E-04
     +,   9.6156285E-04,   1.0329901E-03,   1.1110476E-03
     +,   1.1958951E-03,   1.2875362E-03,   1.3857937E-03
     +,   1.4902971E-03,   1.6004742E-03,   1.7155665E-03
     +,   1.8346561E-03,   1.9567052E-03,   2.0806214E-03
     +,   2.2053423E-03,   2.3299106E-03,   2.4535796E-03
     +,   2.5759181E-03,   2.6968683E-03,   2.8168622E-03
     +,   2.9368498E-03,   3.0583623E-03,   3.1835015E-03
     +,   3.3149165E-03,   3.4556829E-03,   3.6091094E-03
     +,   3.7783729E-03,   3.9660591E-03,   4.1735698E-03
     +,   4.4004531E-03,   4.6439422E-03,   4.8986375E-03
     +,   5.1567960E-03,   5.4090880E-03,   5.6460639E-03
     +,   5.8599268E-03,   6.0466840E-03,   6.2078992E-03
     +,   6.3520344E-03,   6.4949607E-03,   6.6597047E-03
     +,   6.8755792E-03,   7.1767983E-03,   7.6001133E-03
     +,   8.1807375E-03,   8.9454688E-03,   9.9023767E-03
     +,   1.1030067E-02,   1.2271328E-02,   1.3540707E-02
     +,   1.4751003E-02,   1.5857143E-02,   1.6898943E-02
     +,   1.8017029E-02,   1.9416561E-02,   2.1275844E-02
     +,   2.3632938E-02,   2.6316488E-02,   2.8984563E-02
     +,   3.1276107E-02,   3.3004086E-02,   3.4280106E-02
     +,   3.5483636E-02,   3.7052307E-02,   3.9220762E-02
     +,   4.1937456E-02,   4.5025665E-02,   4.8322849E-02
     +,   5.1586941E-02,   5.4433167E-02,   5.6597244E-02
     +,   5.8205314E-02,   5.9655346E-02,   6.1250500E-02
     +,   6.2995784E-02,   6.4681210E-02,   6.5864660E-02
     +,   6.6006765E-02,   6.5150008E-02,   6.3896105E-02
     +,   6.2296320E-02,   5.9587318E-02,   5.5311408E-02
     +,   5.0005563E-02,   4.4560548E-02,   3.9404918E-02
     +,   3.4547266E-02,   3.0023849E-02,   2.5998874E-02
     +,   2.2567755E-02,   1.9664774E-02,   1.7161604E-02
     +,   1.4977077E-02,   1.3092365E-02,   1.1505361E-02
     +,   1.0195816E-02,   9.1224434E-03,   8.2369270E-03
     +,   7.4956510E-03,   6.8642735E-03,   6.3173962E-03
     +,   5.8364859E-03,   5.4078749E-03,   5.0213360E-03
     +,   4.6690390E-03,   4.3448713E-03,   4.0440839E-03
     +,   3.7631900E-03,   3.4999186E-03,   3.2530476E-03
     +,   3.0222295E-03,   2.8077036E-03,   2.6099368E-03
     +,   2.4293130E-03,   2.2659178E-03,   2.1194150E-03
     +,   1.9890028E-03,   1.8734507E-03,   1.7712216E-03
     +,   1.6806003E-03,   1.5998222E-03,   1.5271800E-03
     +,   1.4611237E-03,   1.4003259E-03,   1.3436953E-03
     +,   1.2903865E-03,   1.2397920E-03,   1.1915052E-03
     +,   1.1452831E-03,   1.1010204E-03,   1.0587042E-03
     +,   1.0183908E-03,   9.8017079E-04,   9.4415440E-04
     +,   9.1045670E-04,   8.7918446E-04,   8.5042772E-04
     +,   8.2425732E-04,   8.0072455E-04,   7.7985536E-04
     +,   7.6165202E-04,   7.4609596E-04,   7.3314545E-04
     +,   7.2273461E-04,   7.1477931E-04,   7.0917461E-04
     +,   7.0579688E-04,   7.0450589E-04,   7.0514641E-04
     +,   7.0754904E-04,   7.1153283E-04,   7.1690744E-04
     +,   7.2347507E-04,   7.3103159E-04,   7.3936995E-04
     +,   7.4827968E-04,   7.5755228E-04,   7.6697906E-04
     +,   7.7635521E-04,   7.8548183E-04,   7.9416670E-04
     +,   8.0222578E-04,   8.0948608E-04,   8.1578607E-04
     +,   8.2097930E-04,   8.2493329E-04,   8.2753313E-04
     +,   8.2868309E-04,   8.2830485E-04,   8.2634226E-04
     +,   8.2275877E-04,   8.1753987E-04,   8.1069086E-04
     +,   8.0223894E-04,   7.9222996E-04,   7.8072882E-04
     +,   7.6781778E-04,   7.5359346E-04,   7.3816528E-04
     +,   7.2165387E-04,   7.0418941E-04,   6.8590528E-04
     +,   6.6693849E-04,   6.4742850E-04,   6.2751054E-04
     +,   6.0731667E-04,   5.8697269E-04,   5.6659768E-04
     +,   5.4629956E-04,   5.2617572E-04,   5.0631352E-04
     +,   4.8678840E-04,   4.6766276E-04,   4.4898695E-04
     +,   4.3080145E-04,   4.1313580E-04,   3.9600822E-04
     +,   3.7942838E-04,   3.6339954E-04,   3.4791659E-04
     +,   3.3296959E-04,   3.1854471E-04,   3.0462525E-04
     +,   2.9119148E-04,   2.7822264E-04,   2.6569844E-04
     +,   2.5359908E-04,   2.4190500E-04,   2.3059802E-04
     +,   2.1966259E-04,   2.0908503E-04,   1.9885303E-04
     +,   1.8895620E-04,   1.7938732E-04,   1.7013954E-04
     +,   1.6120798E-04,   1.5258942E-04,   1.4428157E-04
     +,   1.3628243E-04,   1.2859047E-04,   1.2120479E-04
     +,   1.1412457E-04,   1.0734810E-04,   1.0087341E-04
     +,   9.4698276E-05,   8.8819885E-05,   8.3234074E-05
     +,   7.7936129E-05,   7.2920913E-05,   6.8181944E-05
     +,   6.3712068E-05,   5.9503654E-05,   5.5548433E-05
     +,   5.1837298E-05,   4.8360675E-05,   4.5108827E-05
     +,   4.2071759E-05,   3.9239028E-05,   3.6600173E-05
     +,   3.4144890E-05,   3.1862695E-05,   2.9743531E-05
     +,   2.7777220E-05,   2.5954170E-05,   2.4264826E-05
     +,   2.2700209E-05,   2.1251521E-05,   1.9910562E-05
     +,   1.8669372E-05,   1.7520570E-05,   1.6457119E-05
     +,   1.5472400E-05,   1.4560323E-05,   1.3715088E-05
     +,   1.2931419E-05,   1.2204314E-05,   1.1529239E-05
     +,   1.0901926E-05,   1.0318523E-05,   9.7754109E-06
     +,   9.2693344E-06,   8.7972494E-06,   8.3564219E-06
     +,   7.9442952E-06,   7.5585904E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt80 = Yx/0.507843137254902
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0304771E-05,   4.1923096E-05
     +,   4.3631531E-05,   4.5435445E-05,   4.7340316E-05
     +,   4.9351675E-05,   5.1475166E-05,   5.3716449E-05
     +,   5.6081150E-05,   5.8575079E-05,   6.1203835E-05
     +,   6.3973086E-05,   6.6888366E-05,   6.9955138E-05
     +,   7.3178759E-05,   7.6564385E-05,   8.0116988E-05
     +,   8.3841296E-05,   8.7741792E-05,   9.1822527E-05
     +,   9.6087286E-05,   1.0053925E-04,   1.0518111E-04
     +,   1.1001527E-04,   1.1504280E-04,   1.2026462E-04
     +,   1.2568053E-04,   1.3128931E-04,   1.3708892E-04
     +,   1.4307596E-04,   1.4924600E-04,   1.5559318E-04
     +,   1.6211047E-04,   1.6878935E-04,   1.7562018E-04
     +,   1.8259180E-04,   1.8969219E-04,   1.9690806E-04
     +,   2.0422587E-04,   2.1163111E-04,   2.1911008E-04
     +,   2.2664941E-04,   2.3423730E-04,   2.4186418E-04
     +,   2.4952367E-04,   2.5721380E-04,   2.6493819E-04
     +,   2.7270726E-04,   2.8053968E-04,   2.8846390E-04
     +,   2.9651917E-04,   3.0475753E-04,   3.1324450E-04
     +,   3.2206115E-04,   3.3130389E-04,   3.4108708E-04
     +,   3.5154325E-04,   3.6282398E-04,   3.7510236E-04
     +,   3.8857374E-04,   4.0345831E-04,   4.2000462E-04
     +,   4.3849144E-04,   4.5923446E-04,   4.8258965E-04
     +,   5.0895533E-04,   5.3878210E-04,   5.7256606E-04
     +,   6.1085873E-04,   6.5425085E-04,   7.0337427E-04
     +,   7.5887417E-04,   8.2139828E-04,   8.9155202E-04
     +,   9.6987194E-04,   1.0567813E-03,   1.1525297E-03
     +,   1.2571585E-03,   1.3704663E-03,   1.4919874E-03
     +,   1.6209823E-03,   1.7565142E-03,   1.8975070E-03
     +,   2.0429331E-03,   2.1919620E-03,   2.3442358E-03
     +,   2.5000575E-03,   2.6606475E-03,   2.8282176E-03
     +,   3.0060497E-03,   3.1983792E-03,   3.4101717E-03
     +,   3.6468657E-03,   3.9140475E-03,   4.2170626E-03
     +,   4.5604450E-03,   4.9472391E-03,   5.3778687E-03
     +,   5.8491472E-03,   6.3535967E-03,   6.8805474E-03
     +,   7.4193864E-03,   7.9656309E-03,   8.5277408E-03
     +,   9.1316765E-03,   9.8187355E-03,   1.0634568E-02
     +,   1.1612225E-02,   1.2757757E-02,   1.4049425E-02
     +,   1.5454153E-02,   1.6951056E-02,   1.8540444E-02
     +,   2.0230234E-02,   2.2018181E-02,   2.3902848E-02
     +,   2.5927680E-02,   2.8208122E-02,   3.0868435E-02
     +,   3.3908796E-02,   3.7147269E-02,   4.0323548E-02
     +,   4.3323569E-02,   4.6478253E-02,   5.0620630E-02
     +,   5.6296084E-02,   6.2628314E-02,   6.7753315E-02
     +,   7.0840895E-02,   7.3045515E-02,   7.6330751E-02
     +,   8.1140272E-02,   8.5132673E-02,   8.5753478E-02
     +,   8.3502777E-02,   8.0200888E-02,   7.6330200E-02
     +,   7.2276853E-02,   6.8761952E-02,   6.4893864E-02
     +,   5.9134971E-02,   5.1759299E-02,   4.4227324E-02
     +,   3.7549548E-02,   3.2017138E-02,   2.7487967E-02
     +,   2.3670090E-02,   2.0354804E-02,   1.7464373E-02
     +,   1.4988047E-02,   1.2928048E-02,   1.1266027E-02
     +,   9.9477423E-03,   8.8945460E-03,   8.0291145E-03
     +,   7.2934218E-03,   6.6517792E-03,   6.0846927E-03
     +,   5.5814395E-03,   5.1346743E-03,   4.7373078E-03
     +,   4.3814033E-03,   4.0583573E-03,   3.7598789E-03
     +,   3.4791618E-03,   3.2117227E-03,   2.9555717E-03
     +,   2.7108041E-03,   2.4788375E-03,   2.2616773E-03
     +,   2.0613130E-03,   1.8793067E-03,   1.7166197E-03
     +,   1.5735971E-03,   1.4500539E-03,   1.3453382E-03
     +,   1.2584454E-03,   1.1881138E-03,   1.1328829E-03
     +,   1.0911496E-03,   1.0612399E-03,   1.0414505E-03
     +,   1.0300963E-03,   1.0255503E-03,   1.0262800E-03
     +,   1.0308733E-03,   1.0380580E-03,   1.0467150E-03
     +,   1.0558862E-03,   1.0647721E-03,   1.0727309E-03
     +,   1.0792713E-03,   1.0840397E-03,   1.0868085E-03
     +,   1.0874645E-03,   1.0859884E-03,   1.0824411E-03
     +,   1.0769468E-03,   1.0696751E-03,   1.0608220E-03
     +,   1.0506005E-03,   1.0392204E-03,   1.0268792E-03
     +,   1.0137515E-03,   9.9998317E-04,   9.8568399E-04
     +,   9.7092852E-04,   9.5575693E-04,   9.4017835E-04
     +,   9.2417345E-04,   9.0770435E-04,   8.9072151E-04
     +,   8.7317161E-04,   8.5500284E-04,   8.3617546E-04
     +,   8.1666542E-04,   7.9647230E-04,   7.7561598E-04
     +,   7.5414346E-04,   7.3212787E-04,   7.0966379E-04
     +,   6.8686553E-04,   6.6386495E-04,   6.4080389E-04
     +,   6.1782950E-04,   5.9508765E-04,   5.7272147E-04
     +,   5.5086374E-04,   5.2963209E-04,   5.0912669E-04
     +,   4.8942957E-04,   4.7060204E-04,   4.5268226E-04
     +,   4.3568772E-04,   4.1961734E-04,   4.0445052E-04
     +,   3.9015038E-04,   3.7666800E-04,   3.6394355E-04
     +,   3.5190835E-04,   3.4048918E-04,   3.2961104E-04
     +,   3.1919862E-04,   3.0917858E-04,   2.9948130E-04
     +,   2.9004319E-04,   2.8080703E-04,   2.7172288E-04
     +,   2.6274778E-04,   2.5384844E-04,   2.4499811E-04
     +,   2.3617799E-04,   2.2737711E-04,   2.1859116E-04
     +,   2.0982130E-04,   2.0107422E-04,   1.9236139E-04
     +,   1.8369827E-04,   1.7510273E-04,   1.6659457E-04
     +,   1.5819601E-04,   1.4992969E-04,   1.4181795E-04
     +,   1.3388273E-04,   1.2614579E-04,   1.1862676E-04
     +,   1.1134358E-04,   1.0431262E-04,   9.7548065E-05
     +,   9.1061280E-05,   8.4861153E-05,   7.8954552E-05
     +,   7.3345851E-05,   6.8036672E-05,   6.3026389E-05
     +,   5.8312715E-05,   5.3890821E-05,   4.9754686E-05
     +,   4.5896166E-05,   4.2306299E-05,   3.8974533E-05
     +,   3.5889836E-05,   3.3040054E-05,   3.0412939E-05
     +,   2.7995540E-05,   2.5775134E-05,   2.3738725E-05
     +,   2.1873549E-05,   2.0167243E-05,   1.8607609E-05
     +,   1.7183129E-05,   1.5882586E-05,   1.4695553E-05
     +,   1.3612021E-05,   1.2622777E-05,   1.1719111E-05
     +,   1.0893084E-05,   1.0137268E-05,   9.4449597E-06
     +,   8.8099468E-06,   8.2266733E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt85 = Yx/0.529392156862745
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0905150E-05,   5.1752064E-05
     +,   5.2573843E-05,   5.3370437E-05,   5.4142038E-05
     +,   5.4889064E-05,   5.5612159E-05,   5.6312289E-05
     +,   5.6990604E-05,   5.7648565E-05,   5.8287875E-05
     +,   5.8910489E-05,   5.9518672E-05,   6.0114897E-05
     +,   6.0701936E-05,   6.1282815E-05,   6.1860825E-05
     +,   6.2439489E-05,   6.3022620E-05,   6.3614258E-05
     +,   6.4218686E-05,   6.4840431E-05,   6.5484215E-05
     +,   6.6155088E-05,   6.6858163E-05,   6.7598907E-05
     +,   6.8382891E-05,   6.9215908E-05,   7.0103932E-05
     +,   7.1053044E-05,   7.2069495E-05,   7.3159739E-05
     +,   7.4330244E-05,   7.5587603E-05,   7.6938435E-05
     +,   7.8389501E-05,   7.9947487E-05,   8.1619110E-05
     +,   8.3411192E-05,   8.5330277E-05,   8.7383043E-05
     +,   8.9576046E-05,   9.1915746E-05,   9.4408497E-05
     +,   9.7060583E-05,   9.9878191E-05,   1.0286745E-04
     +,   1.0603436E-04,   1.0938503E-04,   1.1292548E-04
     +,   1.1666178E-04,   1.2060013E-04,   1.2474689E-04
     +,   1.2910887E-04,   1.3369256E-04,   1.3850561E-04
     +,   1.4355553E-04,   1.4885046E-04,   1.5439912E-04
     +,   1.6021061E-04,   1.6629467E-04,   1.7266152E-04
     +,   1.7932146E-04,   1.8628550E-04,   1.9356493E-04
     +,   2.0117029E-04,   2.0911259E-04,   2.1740158E-04
     +,   2.2604690E-04,   2.3505585E-04,   2.4443536E-04
     +,   2.5418922E-04,   2.6431982E-04,   2.7482564E-04
     +,   2.8570314E-04,   2.9694533E-04,   3.0854112E-04
     +,   3.2047616E-04,   3.3273303E-04,   3.4529169E-04
     +,   3.5812822E-04,   3.7121828E-04,   3.8453541E-04
     +,   3.9805486E-04,   4.1175270E-04,   4.2561049E-04
     +,   4.3961406E-04,   4.5376018E-04,   4.6805490E-04
     +,   4.8252186E-04,   4.9720227E-04,   5.1215995E-04
     +,   5.2748434E-04,   5.4329756E-04,   5.5975572E-04
     +,   5.7705195E-04,   5.9542368E-04,   6.1515032E-04
     +,   6.3655910E-04,   6.6002127E-04,   6.8595586E-04
     +,   7.1482058E-04,   7.4711553E-04,   7.8337040E-04
     +,   8.2414522E-04,   8.7002380E-04,   9.2160905E-04
     +,   9.7952574E-04,   1.0444309E-03,   1.1170254E-03
     +,   1.1980634E-03,   1.2883876E-03,   1.3889250E-03
     +,   1.5007101E-03,   1.6248388E-03,   1.7624357E-03
     +,   1.9145326E-03,   2.0819867E-03,   2.2653206E-03
     +,   2.4647054E-03,   2.6800158E-03,   2.9110797E-03
     +,   3.1582033E-03,   3.4229110E-03,   3.7087309E-03
     +,   4.0218332E-03,   4.3713222E-03,   4.7686868E-03
     +,   5.2265837E-03,   5.7565710E-03,   6.3666115E-03
     +,   7.0584347E-03,   7.8266878E-03,   8.6604301E-03
     +,   9.5482497E-03,   1.0484695E-02,   1.1474532E-02
     +,   1.2532612E-02,   1.3680917E-02,   1.4946182E-02
     +,   1.6356330E-02,   1.7933978E-02,   1.9700773E-02
     +,   2.1717580E-02,   2.4137612E-02,   2.7166657E-02
     +,   3.0871926E-02,   3.5050012E-02,   3.9458774E-02
     +,   4.4181906E-02,   4.9540807E-02,   5.5605467E-02
     +,   6.1875373E-02,   6.7882001E-02,   7.4341089E-02
     +,   8.1990696E-02,   8.9036174E-02,   9.2570156E-02
     +,   9.2767850E-02,   9.2145152E-02,   9.1771677E-02
     +,   9.1239482E-02,   8.8953219E-02,   8.3114065E-02
     +,   7.4184909E-02,   6.4290091E-02,   5.4896474E-02
     +,   4.6127770E-02,   3.8030382E-02,   3.1030025E-02
     +,   2.5301518E-02,   2.0713164E-02,   1.7108891E-02
     +,   1.4350560E-02,   1.2282301E-02,   1.0763424E-02
     +,   9.6978247E-03,   9.0144202E-03,   8.6376555E-03
     +,   8.4821377E-03,   8.4657241E-03,   8.5231019E-03
     +,   8.6100763E-03,   8.6993212E-03,   8.7726098E-03
     +,   8.8141635E-03,   8.8077020E-03,   8.7376051E-03
     +,   8.5924929E-03,   8.3688553E-03,   8.0726715E-03
     +,   7.7184266E-03,   7.3261103E-03,   6.9174231E-03
     +,   6.5123313E-03,   6.1268727E-03,   5.7720249E-03
     +,   5.4535912E-03,   5.1727244E-03,   4.9269255E-03
     +,   4.7112699E-03,   4.5196190E-03,   4.3457337E-03
     +,   4.1841529E-03,   4.0306756E-03,   3.8824098E-03
     +,   3.7376257E-03,   3.5953554E-03,   3.4550424E-03
     +,   3.3161982E-03,   3.1782512E-03,   3.0405226E-03
     +,   2.9023034E-03,   2.7629503E-03,   2.6220570E-03
     +,   2.4795437E-03,   2.3357018E-03,   2.1911853E-03
     +,   2.0469623E-03,   1.9042424E-03,   1.7643458E-03
     +,   1.6286153E-03,   1.4983176E-03,   1.3745630E-03
     +,   1.2582376E-03,   1.1499778E-03,   1.0501688E-03
     +,   9.5894543E-04,   8.7620993E-04,   8.0167374E-04
     +,   7.3490344E-04,   6.7535735E-04,   6.2241900E-04
     +,   5.7544000E-04,   5.3377269E-04,   4.9678358E-04
     +,   4.6387652E-04,   4.3450404E-04,   4.0817205E-04
     +,   3.8443989E-04,   3.6292250E-04,   3.4328818E-04
     +,   3.2525329E-04,   3.0857656E-04,   2.9305508E-04
     +,   2.7852101E-04,   2.6483508E-04,   2.5188149E-04
     +,   2.3956604E-04,   2.2781285E-04,   2.1655948E-04
     +,   2.0575606E-04,   1.9536357E-04,   1.8535102E-04
     +,   1.7569415E-04,   1.6637419E-04,   1.5737773E-04
     +,   1.4869524E-04,   1.4031939E-04,   1.3224540E-04
     +,   1.2447080E-04,   1.1699422E-04,   1.0981472E-04
     +,   1.0293175E-04,   9.6345502E-05,   9.0055350E-05
     +,   8.4060266E-05,   7.8358906E-05,   7.2949268E-05
     +,   6.7828056E-05,   6.2991094E-05,   5.8433568E-05
     +,   5.4149696E-05,   5.0132505E-05,   4.6374178E-05
     +,   4.2866512E-05,   3.9600087E-05,   3.6565372E-05
     +,   3.3751898E-05,   3.1149219E-05,   2.8746257E-05
     +,   2.6532100E-05,   2.4495484E-05,   2.2625438E-05
     +,   2.0910875E-05,   1.9341167E-05,   1.7905762E-05
     +,   1.6594504E-05,   1.5397731E-05,   1.4306062E-05
     +,   1.3310735E-05,   1.2403336E-05,   1.1576088E-05
     +,   1.0821606E-05,   1.0133124E-05,   9.5042924E-06
     +,   8.9293353E-06,   8.4028834E-06,   7.9201000E-06
     +,   7.4765208E-06,   7.0681567E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt90 = Yx/0.528294117647059
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7389862E-05,   4.9211594E-05
     +,   5.1058134E-05,   5.2926738E-05,   5.4814482E-05
     +,   5.6718243E-05,   5.8634811E-05,   6.0560749E-05
     +,   6.2492560E-05,   6.4426640E-05,   6.6359302E-05
     +,   6.8286805E-05,   7.0205337E-05,   7.2111179E-05
     +,   7.4000585E-05,   7.5869910E-05,   7.7715646E-05
     +,   7.9534446E-05,   8.1323160E-05,   8.3078921E-05
     +,   8.4799191E-05,   8.6481756E-05,   8.8124907E-05
     +,   8.9727371E-05,   9.1288355E-05,   9.2807815E-05
     +,   9.4286152E-05,   9.5724645E-05,   9.7125230E-05
     +,   9.8490607E-05,   9.9824370E-05,   1.0113086E-04
     +,   1.0241540E-04,   1.0368408E-04,   1.0494392E-04
     +,   1.0620277E-04,   1.0746935E-04,   1.0875313E-04
     +,   1.1006433E-04,   1.1141375E-04,   1.1281289E-04
     +,   1.1427353E-04,   1.1580793E-04,   1.1742845E-04
     +,   1.1914749E-04,   1.2097742E-04,   1.2293016E-04
     +,   1.2501716E-04,   1.2724921E-04,   1.2963623E-04
     +,   1.3218695E-04,   1.3490883E-04,   1.3780787E-04
     +,   1.4088841E-04,   1.4415281E-04,   1.4760166E-04
     +,   1.5123322E-04,   1.5504361E-04,   1.5902669E-04
     +,   1.6317391E-04,   1.6747446E-04,   1.7191532E-04
     +,   1.7648084E-04,   1.8115385E-04,   1.8591520E-04
     +,   1.9074354E-04,   1.9561671E-04,   2.0051088E-04
     +,   2.0540193E-04,   2.1026470E-04,   2.1507483E-04
     +,   2.1980731E-04,   2.2443918E-04,   2.2894774E-04
     +,   2.3331282E-04,   2.3751637E-04,   2.4154295E-04
     +,   2.4538024E-04,   2.4902000E-04,   2.5245771E-04
     +,   2.5569336E-04,   2.5873174E-04,   2.6158238E-04
     +,   2.6426016E-04,   2.6678501E-04,   2.6918223E-04
     +,   2.7148207E-04,   2.7371998E-04,   2.7593566E-04
     +,   2.7817322E-04,   2.8048063E-04,   2.8290870E-04
     +,   2.8551032E-04,   2.8834020E-04,   2.9145347E-04
     +,   2.9490446E-04,   2.9874625E-04,   3.0302894E-04
     +,   3.0779897E-04,   3.1309752E-04,   3.1896026E-04
     +,   3.2541479E-04,   3.3248210E-04,   3.4017267E-04
     +,   3.4848889E-04,   3.5742341E-04,   3.6695789E-04
     +,   3.7706434E-04,   3.8770563E-04,   3.9883563E-04
     +,   4.1039920E-04,   4.2233602E-04,   4.3457819E-04
     +,   4.4705646E-04,   4.5969876E-04,   4.7243480E-04
     +,   4.8519688E-04,   4.9792480E-04,   5.1056704E-04
     +,   5.2308454E-04,   5.3545536E-04,   5.4767518E-04
     +,   5.5976334E-04,   5.7176489E-04,   5.8375444E-04
     +,   5.9583678E-04,   6.0815271E-04,   6.2087592E-04
     +,   6.3421810E-04,   6.4842397E-04,   6.6377182E-04
     +,   6.8056752E-04,   6.9914019E-04,   7.1983127E-04
     +,   7.4298988E-04,   7.6895778E-04,   7.9805683E-04
     +,   8.3057774E-04,   8.6676906E-04,   9.0682553E-04
     +,   9.5087511E-04,   9.9897431E-04,   1.0511106E-03
     +,   1.1071967E-03,   1.1670705E-03,   1.2305150E-03
     +,   1.2972589E-03,   1.3669842E-03,   1.4393415E-03
     +,   1.5139630E-03,   1.5904645E-03,   1.6684473E-03
     +,   1.7474872E-03,   1.8271464E-03,   1.9069500E-03
     +,   1.9863660E-03,   2.0648031E-03,   2.1416200E-03
     +,   2.2161321E-03,   2.2876584E-03,   2.3556051E-03
     +,   2.4195891E-03,   2.4795840E-03,   2.5361164E-03
     +,   2.5904384E-03,   2.6446618E-03,   2.7018031E-03
     +,   2.7656483E-03,   2.8404561E-03,   2.9304156E-03
     +,   3.0389384E-03,   3.1679496E-03,   3.3173980E-03
     +,   3.4852794E-03,   3.6685385E-03,   3.8650234E-03
     +,   4.0763370E-03,   4.3108859E-03,   4.5862664E-03
     +,   4.9301973E-03,   5.3807157E-03,   5.9877979E-03
     +,   6.8186601E-03,   7.9643829E-03,   9.5367236E-03
     +,   1.1641243E-02,   1.4335706E-02,   1.7628727E-02
     +,   2.1569164E-02,   2.6346015E-02,   3.2201696E-02
     +,   3.9123088E-02,   4.6632469E-02,   5.4036979E-02
     +,   6.1042856E-02,   6.8270445E-02,   7.6201335E-02
     +,   8.3322927E-02,   8.9064352E-02,   9.5199041E-02
     +,   0.1002438    ,   0.1007139    ,   9.5993944E-02
     +,   8.9198351E-02,   8.4449023E-02,   8.1210300E-02
     +,   7.6004125E-02,   6.8884879E-02,   6.1989691E-02
     +,   5.5846136E-02,   5.0277743E-02,   4.5217685E-02
     +,   4.0383235E-02,   3.5573766E-02,   3.0909056E-02
     +,   2.6668347E-02,   2.3058893E-02,   2.0089932E-02
     +,   1.7618380E-02,   1.5472890E-02,   1.3543999E-02
     +,   1.1806473E-02,   1.0285321E-02,   9.0055410E-03
     +,   7.9636984E-03,   7.1298685E-03,   6.4635403E-03
     +,   5.9261620E-03,   5.4848348E-03,   5.1107239E-03
     +,   4.7775432E-03,   4.4623022E-03,   4.1475561E-03
     +,   3.8233199E-03,   3.4873765E-03,   3.1438398E-03
     +,   2.8007824E-03,   2.4676758E-03,   2.1532329E-03
     +,   1.8640577E-03,   1.6041346E-03,   1.3749455E-03
     +,   1.1759258E-03,   1.0050880E-03,   8.5963466E-04
     +,   7.3645049E-04,   6.3242426E-04,   5.4464932E-04
     +,   4.7053292E-04,   4.0783689E-04,   3.5465584E-04
     +,   3.0939936E-04,   2.7075651E-04,   2.3765223E-04
     +,   2.0920715E-04,   1.8470346E-04,   1.6355471E-04
     +,   1.4527625E-04,   1.2946193E-04,   1.1576912E-04
     +,   1.0390561E-04,   9.3619252E-05,   8.4690437E-05
     +,   7.6928256E-05,   7.0167262E-05,   6.4263120E-05
     +,   5.9091239E-05,   5.4544904E-05,   5.0532777E-05
     +,   4.6977028E-05,   4.3811804E-05,   4.0981817E-05
     +,   3.8440576E-05,   3.6148882E-05,   3.4073801E-05
     +,   3.2187800E-05,   3.0467345E-05,   2.8892677E-05
     +,   2.7446684E-05,   2.6114818E-05,   2.4884275E-05
     +,   2.3744044E-05,   2.2684304E-05,   2.1696509E-05
     +,   2.0772952E-05,   1.9906916E-05,   1.9092322E-05
     +,   1.8323772E-05,   1.7596536E-05,   1.6906322E-05
     +,   1.6249407E-05,   1.5622441E-05,   1.5022547E-05
     +,   1.4447129E-05,   1.3893995E-05,   1.3361177E-05
     +,   1.2847042E-05,   1.2350110E-05,   1.1869196E-05
     +,   1.1403215E-05,   1.0951319E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_hatt95 = Yx/0.502901960784314
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4493253E-05,   2.4846653E-05
     +,   2.5192845E-05,   2.5531808E-05,   2.5863623E-05
     +,   2.6188403E-05,   2.6506345E-05,   2.6817719E-05
     +,   2.7122835E-05,   2.7422133E-05,   2.7716089E-05
     +,   2.8005290E-05,   2.8290380E-05,   2.8572118E-05
     +,   2.8851324E-05,   2.9128943E-05,   2.9405968E-05
     +,   2.9683542E-05,   2.9962843E-05,   3.0245181E-05
     +,   3.0531966E-05,   3.0824671E-05,   3.1124884E-05
     +,   3.1434294E-05,   3.1754633E-05,   3.2087770E-05
     +,   3.2435630E-05,   3.2800213E-05,   3.3183591E-05
     +,   3.3587916E-05,   3.4015382E-05,   3.4468230E-05
     +,   3.4948756E-05,   3.5459263E-05,   3.6002097E-05
     +,   3.6579619E-05,   3.7194146E-05,   3.7848007E-05
     +,   3.8543549E-05,   3.9282972E-05,   4.0068506E-05
     +,   4.0902276E-05,   4.1786323E-05,   4.2722608E-05
     +,   4.3712942E-05,   4.4759025E-05,   4.5862420E-05
     +,   4.7024540E-05,   4.8246620E-05,   4.9529717E-05
     +,   5.0874703E-05,   5.2282263E-05,   5.3752836E-05
     +,   5.5286764E-05,   5.6884004E-05,   5.8544487E-05
     +,   6.0267779E-05,   6.2053339E-05,   6.3900392E-05
     +,   6.5807944E-05,   6.7774854E-05,   6.9799826E-05
     +,   7.1881288E-05,   7.4017698E-05,   7.6207405E-05
     +,   7.8448480E-05,   8.0739199E-05,   8.3077532E-05
     +,   8.5461739E-05,   8.7889865E-05,   9.0360292E-05
     +,   9.2871225E-05,   9.5421376E-05,   9.8009332E-05
     +,   1.0063413E-04,   1.0329522E-04,   1.0599216E-04
     +,   1.0872487E-04,   1.1149397E-04,   1.1430056E-04
     +,   1.1714595E-04,   1.2003247E-04,   1.2296259E-04
     +,   1.2593991E-04,   1.2896830E-04,   1.3205272E-04
     +,   1.3519837E-04,   1.3841173E-04,   1.4169952E-04
     +,   1.4506954E-04,   1.4853021E-04,   1.5209052E-04
     +,   1.5576002E-04,   1.5954921E-04,   1.6346910E-04
     +,   1.6753071E-04,   1.7174627E-04,   1.7612756E-04
     +,   1.8068733E-04,   1.8543782E-04,   1.9039212E-04
     +,   1.9556246E-04,   2.0096156E-04,   2.0660146E-04
     +,   2.1249399E-04,   2.1865068E-04,   2.2508191E-04
     +,   2.3179736E-04,   2.3880589E-04,   2.4611567E-04
     +,   2.5373278E-04,   2.6166291E-04,   2.6990953E-04
     +,   2.7847578E-04,   2.8736235E-04,   2.9656992E-04
     +,   3.0609700E-04,   3.1594277E-04,   3.2610516E-04
     +,   3.3658370E-04,   3.4737971E-04,   3.5849659E-04
     +,   3.6994214E-04,   3.8173073E-04,   3.9388504E-04
     +,   4.0643627E-04,   4.1943006E-04,   4.3292486E-04
     +,   4.4699790E-04,   4.6174327E-04,   4.7727668E-04
     +,   4.9373211E-04,   5.1126507E-04,   5.3004600E-04
     +,   5.5025861E-04,   5.7209411E-04,   5.9573929E-04
     +,   6.2136777E-04,   6.4912933E-04,   6.7913282E-04
     +,   7.1143016E-04,   7.4600289E-04,   7.8274880E-04
     +,   8.2146993E-04,   8.6186093E-04,   9.0351119E-04
     +,   9.4590615E-04,   9.8843465E-04,   1.0304066E-03
     +,   1.0710820E-03,   1.1096942E-03,   1.1454885E-03
     +,   1.1777559E-03,   1.2058793E-03,   1.2293655E-03
     +,   1.2478771E-03,   1.2612635E-03,   1.2695792E-03
     +,   1.2730932E-03,   1.2722857E-03,   1.2678456E-03
     +,   1.2606402E-03,   1.2516982E-03,   1.2421735E-03
     +,   1.2333062E-03,   1.2263870E-03,   1.2227186E-03
     +,   1.2235780E-03,   1.2301786E-03,   1.2436362E-03
     +,   1.2649283E-03,   1.2948500E-03,   1.3339816E-03
     +,   1.3826494E-03,   1.4409074E-03,   1.5085847E-03
     +,   1.5853909E-03,   1.6711518E-03,   1.7661935E-03
     +,   1.8718857E-03,   1.9912813E-03,   2.1297282E-03
     +,   2.2952326E-03,   2.4983436E-03,   2.7512028E-03
     +,   3.0657849E-03,   3.4517273E-03,   3.9147362E-03
     +,   4.4568535E-03,   5.0796014E-03,   5.7899263E-03
     +,   6.6064587E-03,   7.5620394E-03,   8.6985193E-03
     +,   1.0052010E-02,   1.1633428E-02,   1.3418051E-02
     +,   1.5361958E-02,   1.7448520E-02,   1.9737035E-02
     +,   2.2372220E-02,   2.5533313E-02,   2.9315947E-02
     +,   3.3585180E-02,   3.7984777E-02,   4.2181119E-02
     +,   4.5980982E-02,   4.9226154E-02,   5.2030765E-02
     +,   5.4886129E-02,   5.7698656E-02,   5.9472281E-02
     +,   5.9834335E-02,   6.0015503E-02,   6.1472073E-02
     +,   6.3519441E-02,   6.3906975E-02,   6.2096175E-02
     +,   5.9367504E-02,   5.6276392E-02,   5.2340835E-02
     +,   4.7564875E-02,   4.2808998E-02,   3.8873598E-02
     +,   3.6008772E-02,   3.3957098E-02,   3.2092594E-02
     +,   2.9829863E-02,   2.7060917E-02,   2.4125123E-02
     +,   2.1419313E-02,   1.9123727E-02,   1.7221119E-02
     +,   1.5627697E-02,   1.4264444E-02,   1.3066864E-02
     +,   1.1986646E-02,   1.0996908E-02,   1.0089041E-02
     +,   9.2606172E-03,   8.5055325E-03,   7.8128856E-03
     +,   7.1713706E-03,   6.5734689E-03,   6.0161809E-03
     +,   5.4990398E-03,   5.0214808E-03,   4.5812279E-03
     +,   4.1742045E-03,   3.7954061E-03,   3.4399009E-03
     +,   3.1037736E-03,   2.7846065E-03,   2.4814915E-03
     +,   2.1947753E-03,   1.9256340E-03,   1.6756412E-03
     +,   1.4463117E-03,   1.2387768E-03,   1.0536008E-03
     +,   8.9071185E-04,   7.4940326E-04,   6.2841340E-04
     +,   5.2606943E-04,   4.4043889E-04,   3.6945462E-04
     +,   3.1105243E-04,   2.6327168E-04,   2.2431936E-04
     +,   1.9260934E-04,   1.6678007E-04,   1.4569233E-04
     +,   1.2840910E-04,   1.1417047E-04,   1.0236795E-04
     +,   9.2518203E-05,   8.4235988E-05,   7.7216209E-05
     +,   7.1214505E-05,   6.6035907E-05,   6.1522856E-05
     +,   5.7548772E-05,   5.4010878E-05,   5.0826693E-05
     +,   4.7929578E-05,   4.5266697E-05,   4.2796066E-05
     +,   4.0484847E-05,   3.8307917E-05,   3.6245929E-05
     +,   3.4284680E-05,   3.2413525E-05,   3.0624975E-05
     +,   2.8913550E-05,   2.7275590E-05,   2.5708376E-05
     +,   2.4210120E-05,   2.2779319E-05,   2.1414897E-05
     +,   2.0115673E-05,   1.8880626E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt100 = Yx/0.42252
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8061206E-05,   1.8418066E-05
     +,   1.8771721E-05,   1.9122099E-05,   1.9469164E-05
     +,   1.9812913E-05,   2.0153391E-05,   2.0490672E-05
     +,   2.0824862E-05,   2.1156127E-05,   2.1484644E-05
     +,   2.1810640E-05,   2.2134371E-05,   2.2456123E-05
     +,   2.2776214E-05,   2.3094997E-05,   2.3412844E-05
     +,   2.3730152E-05,   2.4047336E-05,   2.4364825E-05
     +,   2.4683079E-05,   2.5002548E-05,   2.5323694E-05
     +,   2.5646999E-05,   2.5972911E-05,   2.6301919E-05
     +,   2.6634465E-05,   2.6970998E-05,   2.7311949E-05
     +,   2.7657730E-05,   2.8008737E-05,   2.8365337E-05
     +,   2.8727891E-05,   2.9096702E-05,   2.9472067E-05
     +,   2.9854255E-05,   3.0243478E-05,   3.0639960E-05
     +,   3.1043895E-05,   3.1455420E-05,   3.1874679E-05
     +,   3.2301788E-05,   3.2736869E-05,   3.3180022E-05
     +,   3.3631361E-05,   3.4091001E-05,   3.4559103E-05
     +,   3.5035835E-05,   3.5521443E-05,   3.6016205E-05
     +,   3.6520494E-05,   3.7034777E-05,   3.7559628E-05
     +,   3.8095772E-05,   3.8644030E-05,   3.9205486E-05
     +,   3.9781338E-05,   4.0373056E-05,   4.0982319E-05
     +,   4.1611096E-05,   4.2261596E-05,   4.2936415E-05
     +,   4.3638378E-05,   4.4370729E-05,   4.5137080E-05
     +,   4.5941346E-05,   4.6787889E-05,   4.7681431E-05
     +,   4.8627149E-05,   4.9630460E-05,   5.0697359E-05
     +,   5.1834002E-05,   5.3047057E-05,   5.4343334E-05
     +,   5.5730048E-05,   5.7214620E-05,   5.8804606E-05
     +,   6.0507609E-05,   6.2331404E-05,   6.4283791E-05
     +,   6.6372268E-05,   6.8604415E-05,   7.0987269E-05
     +,   7.3527852E-05,   7.6232434E-05,   7.9107158E-05
     +,   8.2157167E-05,   8.5387437E-05,   8.8801804E-05
     +,   9.2403643E-05,   9.6195625E-05,   1.0017942E-04
     +,   1.0435571E-04,   1.0872489E-04,   1.1328638E-04
     +,   1.1803850E-04,   1.2297960E-04,   1.2810671E-04
     +,   1.3341689E-04,   1.3890627E-04,   1.4457123E-04
     +,   1.5040708E-04,   1.5640983E-04,   1.6257454E-04
     +,   1.6889676E-04,   1.7537222E-04,   1.8199594E-04
     +,   1.8876309E-04,   1.9566921E-04,   2.0270956E-04
     +,   2.0987848E-04,   2.1717085E-04,   2.2457987E-04
     +,   2.3209877E-04,   2.3971879E-04,   2.4743070E-04
     +,   2.5522252E-04,   2.6308151E-04,   2.7099150E-04
     +,   2.7893475E-04,   2.8689101E-04,   2.9483667E-04
     +,   3.0274526E-04,   3.1058834E-04,   3.1833476E-04
     +,   3.2595024E-04,   3.3339969E-04,   3.4064561E-04
     +,   3.4765023E-04,   3.5437546E-04,   3.6078409E-04
     +,   3.6683990E-04,   3.7251032E-04,   3.7776516E-04
     +,   3.8257986E-04,   3.8693560E-04,   3.9081959E-04
     +,   3.9422704E-04,   3.9716240E-04,   3.9963907E-04
     +,   4.0168042E-04,   4.0332024E-04,   4.0460378E-04
     +,   4.0558670E-04,   4.0633543E-04,   4.0692763E-04
     +,   4.0745019E-04,   4.0800052E-04,   4.0868370E-04
     +,   4.0961342E-04,   4.1090982E-04,   4.1269895E-04
     +,   4.1511093E-04,   4.1827981E-04,   4.2234187E-04
     +,   4.2743419E-04,   4.3369381E-04,   4.4125610E-04
     +,   4.5025430E-04,   4.6081515E-04,   4.7306053E-04
     +,   4.8710275E-04,   5.0304073E-04,   5.2095816E-04
     +,   5.4091972E-04,   5.6296674E-04,   5.8710965E-04
     +,   6.1332464E-04,   6.4155331E-04,   6.7169557E-04
     +,   7.0360705E-04,   7.3710171E-04,   7.7195774E-04
     +,   8.0792385E-04,   8.4472663E-04,   8.8209490E-04
     +,   9.1977575E-04,   9.5755851E-04,   9.9530420E-04
     +,   1.0329779E-03,   1.0706777E-03,   1.1086629E-03
     +,   1.1473848E-03,   1.1875150E-03,   1.2299743E-03
     +,   1.2759550E-03,   1.3269531E-03,   1.3848066E-03
     +,   1.4517243E-03,   1.5302948E-03,   1.6234904E-03
     +,   1.7345879E-03,   1.8670005E-03,   2.0240033E-03
     +,   2.2083479E-03,   2.4217449E-03,   2.6643022E-03
     +,   2.9340235E-03,   3.2265058E-03,   3.5349047E-03
     +,   3.8504363E-03,   4.1635334E-03,   4.4658212E-03
     +,   4.7527044E-03,   5.0263740E-03,   5.2984948E-03
     +,   5.5914721E-03,   5.9371986E-03,   6.3724765E-03
     +,   6.9313217E-03,   7.6361247E-03,   8.4923189E-03
     +,   9.4920844E-03,   1.0628535E-02,   1.1912153E-02
     +,   1.3373712E-02,   1.5042741E-02,   1.6912205E-02
     +,   1.8925777E-02,   2.1031087E-02,   2.3287730E-02
     +,   2.5898581E-02,   2.9061137E-02,   3.2837380E-02
     +,   3.7268337E-02,   4.2397659E-02,   4.7851529E-02
     +,   5.2578133E-02,   5.5671625E-02,   5.7778142E-02
     +,   6.0517110E-02,   6.3869901E-02,   6.6167757E-02
     +,   6.6407844E-02,   6.5031558E-02,   6.3624501E-02
     +,   6.2689520E-02,   6.0798395E-02,   5.7597212E-02
     +,   5.4086607E-02,   5.0826833E-02,   4.7893737E-02
     +,   4.4934142E-02,   4.1488387E-02,   3.7691023E-02
     +,   3.3972129E-02,   3.0502819E-02,   2.7235456E-02
     +,   2.4086501E-02,   2.0996658E-02,   1.7977623E-02
     +,   1.5128138E-02,   1.2574244E-02,   1.0392824E-02
     +,   8.5821850E-03,   7.0851292E-03,   5.8297934E-03
     +,   4.7582053E-03,   3.8351601E-03,   3.0444132E-03
     +,   2.3798258E-03,   1.8366509E-03,   1.4061520E-03
     +,   1.0744602E-03,   8.2442071E-04,   6.3833577E-04
     +,   5.0027465E-04,   3.9724389E-04,   3.1937676E-04
     +,   2.5956304E-04,   2.1285811E-04,   1.7587970E-04
     +,   1.4630260E-04,   1.2248674E-04,   1.0323089E-04
     +,   8.7618122E-05,   7.4920499E-05,   6.4552238E-05
     +,   5.6036843E-05,   4.8991446E-05,   4.3110376E-05
     +,   3.8154642E-05,   3.3938744E-05,   3.0321240E-05
     +,   2.7193877E-05,   2.4474375E-05,   2.2098946E-05
     +,   2.0017464E-05,   1.8189778E-05,   1.6582508E-05
     +,   1.5167653E-05,   1.3920901E-05,   1.2821199E-05
     +,   1.1849881E-05,   1.0990615E-05,   1.0228883E-05
     +,   9.5520245E-06,   8.9488585E-06,   8.4097182E-06
     +,   7.9261408E-06,   7.4908749E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt105 = Yx/0.407714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1833569E-05,   1.2324474E-05
     +,   1.2823257E-05,   1.3329377E-05,   1.3842258E-05
     +,   1.4361303E-05,   1.4885902E-05,   1.5415424E-05
     +,   1.5949216E-05,   1.6486660E-05,   1.7027085E-05
     +,   1.7569837E-05,   1.8114271E-05,   1.8659737E-05
     +,   1.9205610E-05,   1.9751269E-05,   2.0296115E-05
     +,   2.0839580E-05,   2.1381109E-05,   2.1920196E-05
     +,   2.2456348E-05,   2.2989123E-05,   2.3518125E-05
     +,   2.4043013E-05,   2.4563447E-05,   2.5079195E-05
     +,   2.5590056E-05,   2.6095877E-05,   2.6596568E-05
     +,   2.7092097E-05,   2.7582531E-05,   2.8067931E-05
     +,   2.8548486E-05,   2.9024412E-05,   2.9496023E-05
     +,   2.9963679E-05,   3.0427809E-05,   3.0888918E-05
     +,   3.1347612E-05,   3.1804491E-05,   3.2260294E-05
     +,   3.2715816E-05,   3.3171906E-05,   3.3629491E-05
     +,   3.4089589E-05,   3.4553257E-05,   3.5021647E-05
     +,   3.5495977E-05,   3.5977551E-05,   3.6467725E-05
     +,   3.6967962E-05,   3.7479753E-05,   3.8004699E-05
     +,   3.8544476E-05,   3.9100792E-05,   3.9675495E-05
     +,   4.0270443E-05,   4.0887597E-05,   4.1528961E-05
     +,   4.2196632E-05,   4.2892731E-05,   4.3619475E-05
     +,   4.4379070E-05,   4.5173812E-05,   4.6006022E-05
     +,   4.6878005E-05,   4.7792149E-05,   4.8750742E-05
     +,   4.9756174E-05,   5.0810686E-05,   5.1916591E-05
     +,   5.3076044E-05,   5.4291238E-05,   5.5564116E-05
     +,   5.6896697E-05,   5.8290781E-05,   5.9748050E-05
     +,   6.1269944E-05,   6.2857871E-05,   6.4513057E-05
     +,   6.6236389E-05,   6.8028749E-05,   6.9890622E-05
     +,   7.1822491E-05,   7.3824391E-05,   7.5896416E-05
     +,   7.8038167E-05,   8.0249360E-05,   8.2529215E-05
     +,   8.4876971E-05,   8.7291723E-05,   8.9772329E-05
     +,   9.2317401E-05,   9.4925679E-05,   9.7595766E-05
     +,   1.0032597E-04,   1.0311486E-04,   1.0596059E-04
     +,   1.0886161E-04,   1.1181604E-04,   1.1482227E-04
     +,   1.1787828E-04,   1.2098239E-04,   1.2413252E-04
     +,   1.2732673E-04,   1.3056296E-04,   1.3383882E-04
     +,   1.3715184E-04,   1.4049934E-04,   1.4387848E-04
     +,   1.4728573E-04,   1.5071756E-04,   1.5416964E-04
     +,   1.5763751E-04,   1.6111571E-04,   1.6459853E-04
     +,   1.6807925E-04,   1.7155080E-04,   1.7500496E-04
     +,   1.7843302E-04,   1.8182545E-04,   1.8517190E-04
     +,   1.8846091E-04,   1.9168077E-04,   1.9481900E-04
     +,   1.9786223E-04,   2.0079683E-04,   2.0360849E-04
     +,   2.0628287E-04,   2.0880529E-04,   2.1116123E-04
     +,   2.1333608E-04,   2.1531605E-04,   2.1708746E-04
     +,   2.1863780E-04,   2.1995533E-04,   2.2102972E-04
     +,   2.2185179E-04,   2.2241448E-04,   2.2271216E-04
     +,   2.2274157E-04,   2.2250165E-04,   2.2199372E-04
     +,   2.2122178E-04,   2.2019254E-04,   2.1891564E-04
     +,   2.1740352E-04,   2.1567178E-04,   2.1373919E-04
     +,   2.1162741E-04,   2.0936140E-04,   2.0696913E-04
     +,   2.0448177E-04,   2.0193348E-04,   1.9936086E-04
     +,   1.9680396E-04,   1.9430516E-04,   1.9190916E-04
     +,   1.8966284E-04,   1.8761522E-04,   1.8581665E-04
     +,   1.8431881E-04,   1.8317421E-04,   1.8243594E-04
     +,   1.8215700E-04,   1.8239042E-04,   1.8318859E-04
     +,   1.8460353E-04,   1.8668722E-04,   1.8949232E-04
     +,   1.9307285E-04,   1.9748682E-04,   2.0279903E-04
     +,   2.0908537E-04,   2.1643811E-04,   2.2497460E-04
     +,   2.3484729E-04,   2.4625627E-04,   2.5946472E-04
     +,   2.7482008E-04,   2.9277330E-04,   3.1390126E-04
     +,   3.3892738E-04,   3.6873980E-04,   4.0439764E-04
     +,   4.4711813E-04,   4.9824646E-04,   5.5920042E-04
     +,   6.3137774E-04,   7.1602454E-04,   8.1410247E-04
     +,   9.2612213E-04,   1.0519774E-03,   1.1908335E-03
     +,   1.3410691E-03,   1.5002950E-03,   1.6654766E-03
     +,   1.8331910E-03,   2.0000059E-03,   2.1629324E-03
     +,   2.3199189E-03,   2.4703725E-03,   2.6155575E-03
     +,   2.7587945E-03,   2.9053323E-03,   3.0619497E-03
     +,   3.2362931E-03,   3.4362725E-03,   3.6700258E-03
     +,   3.9468091E-03,   4.2787879E-03,   4.6829311E-03
     +,   5.1814024E-03,   5.7986598E-03,   6.5545756E-03
     +,   7.4552344E-03,   8.4855612E-03,   9.6087195E-03
     +,   1.0775765E-02,   1.1944439E-02,   1.3096234E-02
     +,   1.4231828E-02,   1.5340860E-02,   1.6383151E-02
     +,   1.7334582E-02,   1.8278692E-02,   1.9426839E-02
     +,   2.0994784E-02,   2.3049133E-02,   2.5488036E-02
     +,   2.8166497E-02,   3.1064926E-02,   3.4305356E-02
     +,   3.7943419E-02,   4.2043258E-02,   4.6836235E-02
     +,   5.2133609E-02,   5.7562876E-02,   6.3385293E-02
     +,   6.8889290E-02,   7.1595520E-02,   7.0983216E-02
     +,   6.9689006E-02,   6.9354415E-02,   6.9416426E-02
     +,   6.8163611E-02,   6.4359017E-02,   5.9319820E-02
     +,   5.4756202E-02,   5.0266065E-02,   4.5136046E-02
     +,   3.9768014E-02,   3.4644298E-02,   2.9739171E-02
     +,   2.4918549E-02,   2.0255910E-02,   1.6008496E-02
     +,   1.2420312E-02,   9.5726624E-03,   7.3863203E-03
     +,   5.7119718E-03,   4.4123488E-03,   3.3938084E-03
     +,   2.5981788E-03,   1.9842936E-03,   1.5169140E-03
     +,   1.1645941E-03,   9.0062979E-04,   7.0352817E-04
     +,   5.5649813E-04,   4.4657616E-04,   3.6382183E-04
     +,   3.0070986E-04,   2.5167500E-04,   2.1272336E-04
     +,   1.8107533E-04,   1.5483487E-04,   1.3272988E-04
     +,   1.1389754E-04,   9.7742530E-05,   8.3833147E-05
     +,   7.1843766E-05,   6.1513630E-05,   5.2628198E-05
     +,   4.5003442E-05,   3.8480692E-05,   3.2919888E-05
     +,   2.8197303E-05,   2.4203635E-05,   2.0841198E-05
     +,   1.8023626E-05,   1.5673870E-05,   1.3723957E-05
     +,   1.2113577E-05,   1.0789868E-05,   9.7063621E-06
     +,   8.8227598E-06,   8.1040989E-06,   7.5204812E-06
     +,   7.0463916E-06,   6.6603743E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt107 = Yx/0.397571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1688449E-05,   2.2448121E-05
     +,   2.3214776E-05,   2.3987264E-05,   2.4764411E-05
     +,   2.5544969E-05,   2.6327663E-05,   2.7111164E-05
     +,   2.7894104E-05,   2.8675115E-05,   2.9452776E-05
     +,   3.0225634E-05,   3.0992243E-05,   3.1751144E-05
     +,   3.2500877E-05,   3.3239961E-05,   3.3966957E-05
     +,   3.4680430E-05,   3.5378958E-05,   3.6061159E-05
     +,   3.6725687E-05,   3.7371232E-05,   3.7996531E-05
     +,   3.8600421E-05,   3.9181705E-05,   3.9739345E-05
     +,   4.0272334E-05,   4.0779749E-05,   4.1260737E-05
     +,   4.1714567E-05,   4.2140571E-05,   4.2538166E-05
     +,   4.2906900E-05,   4.3246408E-05,   4.3556418E-05
     +,   4.3836772E-05,   4.4087425E-05,   4.4308428E-05
     +,   4.4499964E-05,   4.4662302E-05,   4.4795830E-05
     +,   4.4901029E-05,   4.4978526E-05,   4.5029024E-05
     +,   4.5053344E-05,   4.5052409E-05,   4.5027249E-05
     +,   4.4978999E-05,   4.4908902E-05,   4.4818284E-05
     +,   4.4708595E-05,   4.4581375E-05,   4.4438246E-05
     +,   4.4280969E-05,   4.4111395E-05,   4.3931454E-05
     +,   4.3743203E-05,   4.3548807E-05,   4.3350530E-05
     +,   4.3150776E-05,   4.2952022E-05,   4.2756903E-05
     +,   4.2568186E-05,   4.2388765E-05,   4.2221647E-05
     +,   4.2070005E-05,   4.1937172E-05,   4.1826621E-05
     +,   4.1741980E-05,   4.1687075E-05,   4.1665862E-05
     +,   4.1682473E-05,   4.1741208E-05,   4.1846557E-05
     +,   4.2003154E-05,   4.2215786E-05,   4.2489388E-05
     +,   4.2829026E-05,   4.3239903E-05,   4.3727323E-05
     +,   4.4296612E-05,   4.4953253E-05,   4.5702618E-05
     +,   4.6550191E-05,   4.7501315E-05,   4.8561305E-05
     +,   4.9735299E-05,   5.1028324E-05,   5.2445070E-05
     +,   5.3990101E-05,   5.5667682E-05,   5.7481593E-05
     +,   5.9435246E-05,   6.1531719E-05,   6.3773659E-05
     +,   6.6162967E-05,   6.8701447E-05,   7.1389957E-05
     +,   7.4229225E-05,   7.7219083E-05,   8.0359248E-05
     +,   8.3648600E-05,   8.7085959E-05,   9.0669317E-05
     +,   9.4396688E-05,   9.8265780E-05,   1.0227381E-04
     +,   1.0641794E-04,   1.1069534E-04,   1.1510328E-04
     +,   1.1963848E-04,   1.2429852E-04,   1.2908028E-04
     +,   1.3398143E-04,   1.3899920E-04,   1.4413142E-04
     +,   1.4937545E-04,   1.5472926E-04,   1.6018997E-04
     +,   1.6575510E-04,   1.7142184E-04,   1.7718648E-04
     +,   1.8304473E-04,   1.8899176E-04,   1.9502200E-04
     +,   2.0112793E-04,   2.0730175E-04,   2.1353331E-04
     +,   2.1981192E-04,   2.2612445E-04,   2.3245717E-04
     +,   2.3879383E-04,   2.4511776E-04,   2.5141001E-04
     +,   2.5765123E-04,   2.6382128E-04,   2.6989912E-04
     +,   2.7586339E-04,   2.8169333E-04,   2.8736866E-04
     +,   2.9287001E-04,   2.9817905E-04,   3.0327970E-04
     +,   3.0815805E-04,   3.1280203E-04,   3.1720300E-04
     +,   3.2135489E-04,   3.2525478E-04,   3.2890262E-04
     +,   3.3230209E-04,   3.3545992E-04,   3.3838529E-04
     +,   3.4109104E-04,   3.4359237E-04,   3.4590758E-04
     +,   3.4805702E-04,   3.5006355E-04,   3.5195288E-04
     +,   3.5375284E-04,   3.5549374E-04,   3.5720924E-04
     +,   3.5893574E-04,   3.6071378E-04,   3.6258774E-04
     +,   3.6460761E-04,   3.6682855E-04,   3.6931303E-04
     +,   3.7213086E-04,   3.7536115E-04,   3.7909226E-04
     +,   3.8342428E-04,   3.8846862E-04,   3.9435062E-04
     +,   4.0121030E-04,   4.0920218E-04,   4.1849946E-04
     +,   4.2929372E-04,   4.4179670E-04,   4.5624335E-04
     +,   4.7289673E-04,   4.9205049E-04,   5.1403308E-04
     +,   5.3921394E-04,   5.6801183E-04,   6.0089887E-04
     +,   6.3840271E-04,   6.8111200E-04,   7.2967715E-04
     +,   7.8480627E-04,   8.4724691E-04,   9.1778167E-04
     +,   9.9719921E-04,   1.0862482E-03,   1.1855949E-03
     +,   1.2957625E-03,   1.4170430E-03,   1.5494020E-03
     +,   1.6924050E-03,   1.8451901E-03,   2.0065014E-03
     +,   2.1748396E-03,   2.3487881E-03,   2.5274800E-03
     +,   2.7111217E-03,   2.9014279E-03,   3.1018620E-03
     +,   3.3173582E-03,   3.5535286E-03,   3.8154225E-03
     +,   4.1062539E-03,   4.4265310E-03,   4.7740838E-03
     +,   5.1452108E-03,   5.5363062E-03,   5.9449822E-03
     +,   6.3698236E-03,   6.8087052E-03,   7.2568003E-03
     +,   7.7060917E-03,   8.1472648E-03,   8.5735032E-03
     +,   8.9831259E-03,   9.3796859E-03,   9.7702090E-03
     +,   1.0165185E-02,   1.0583511E-02,   1.1061709E-02
     +,   1.1661723E-02,   1.2469805E-02,   1.3583353E-02
     +,   1.5087973E-02,   1.7026592E-02,   1.9360056E-02
     +,   2.1925880E-02,   2.4413314E-02,   2.6388962E-02
     +,   2.7460327E-02,   2.7648635E-02,   2.7705507E-02
     +,   2.8827688E-02,   3.1787354E-02,   3.6358394E-02
     +,   4.1622717E-02,   4.6730097E-02,   5.1339068E-02
     +,   5.5367887E-02,   5.8687665E-02,   6.1379306E-02
     +,   6.3558884E-02,   6.5006189E-02,   6.6013284E-02
     +,   6.7360684E-02,   6.8252213E-02,   6.6065945E-02
     +,   5.9873559E-02,   5.1941123E-02,   4.4480063E-02
     +,   3.7640303E-02,   3.0970326E-02,   2.4647892E-02
     +,   1.9133061E-02,   1.4646065E-02,   1.1142521E-02
     +,   8.4711714E-03,   6.4598159E-03,   4.9441401E-03
     +,   3.7881061E-03,   2.8949582E-03,   2.2028156E-03
     +,   1.6714515E-03,   1.2701432E-03,   9.7148004E-04
     +,   7.5054204E-04,   5.8634853E-04,   4.6289645E-04
     +,   3.6888011E-04,   2.9653747E-04,   2.4045628E-04
     +,   1.9666819E-04,   1.6216452E-04,   1.3463698E-04
     +,   1.1235183E-04,   9.4036477E-05,   7.8784018E-05
     +,   6.5952969E-05,   5.5090095E-05,   4.5865450E-05
     +,   3.8030084E-05,   3.1387975E-05,   2.5776493E-05
     +,   2.1057531E-05,   1.7109762E-05,   1.3826351E-05
     +,   1.1111826E-05,   8.8816896E-06,   7.0608544E-06
     +,   5.5835676E-06,   4.3923073E-06,   3.4375496E-06
     +,   2.6767871E-06,   2.0741043E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt110 = Yx/0.371428571428571
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8775811E-06,   4.0107907E-06
     +,   4.1487169E-06,   4.2915758E-06,   4.4395902E-06
     +,   4.5929992E-06,   4.7520489E-06,   4.9169980E-06
     +,   5.0881144E-06,   5.2656892E-06,   5.4500128E-06
     +,   5.6413965E-06,   5.8401588E-06,   6.0466359E-06
     +,   6.2611771E-06,   6.4841429E-06,   6.7159108E-06
     +,   6.9568669E-06,   7.2074204E-06,   7.4679856E-06
     +,   7.7389941E-06,   8.0208938E-06,   8.3141413E-06
     +,   8.6192258E-06,   8.9366140E-06,   9.2668251E-06
     +,   9.6103759E-06,   9.9677909E-06,   1.0339621E-05
     +,   1.0726422E-05,   1.1128767E-05,   1.1547239E-05
     +,   1.1982440E-05,   1.2434980E-05,   1.2905479E-05
     +,   1.3394578E-05,   1.3902918E-05,   1.4431153E-05
     +,   1.4979978E-05,   1.5550040E-05,   1.6142048E-05
     +,   1.6756701E-05,   1.7394708E-05,   1.8056775E-05
     +,   1.8743645E-05,   1.9456038E-05,   2.0194706E-05
     +,   2.0960386E-05,   2.1753833E-05,   2.2575801E-05
     +,   2.3427059E-05,   2.4308367E-05,   2.5220470E-05
     +,   2.6164194E-05,   2.7140233E-05,   2.8149412E-05
     +,   2.9192466E-05,   3.0270165E-05,   3.1383261E-05
     +,   3.2532505E-05,   3.3718647E-05,   3.4942423E-05
     +,   3.6204532E-05,   3.7505695E-05,   3.8846705E-05
     +,   4.0228151E-05,   4.1650790E-05,   4.3115266E-05
     +,   4.4622313E-05,   4.6172547E-05,   4.7766742E-05
     +,   4.9405498E-05,   5.1089668E-05,   5.2819902E-05
     +,   5.4597072E-05,   5.6422159E-05,   5.8296057E-05
     +,   6.0219842E-05,   6.2194857E-05,   6.4222622E-05
     +,   6.6304696E-05,   6.8443180E-05,   7.0640308E-05
     +,   7.2898911E-05,   7.5222008E-05,   7.7613462E-05
     +,   8.0077392E-05,   8.2618993E-05,   8.5243730E-05
     +,   8.7958288E-05,   9.0770118E-05,   9.3687566E-05
     +,   9.6719843E-05,   9.9877543E-05,   1.0317218E-04
     +,   1.0661608E-04,   1.1022310E-04,   1.1400755E-04
     +,   1.1798514E-04,   1.2217187E-04,   1.2658478E-04
     +,   1.3124087E-04,   1.3615779E-04,   1.4135240E-04
     +,   1.4684156E-04,   1.5264111E-04,   1.5876551E-04
     +,   1.6522701E-04,   1.7203623E-04,   1.7920097E-04
     +,   1.8672508E-04,   1.9460949E-04,   2.0284990E-04
     +,   2.1143847E-04,   2.2036105E-04,   2.2959930E-04
     +,   2.3912815E-04,   2.4891796E-04,   2.5893189E-04
     +,   2.6912877E-04,   2.7946176E-04,   2.8987825E-04
     +,   3.0032135E-04,   3.1073060E-04,   3.2104267E-04
     +,   3.3119050E-04,   3.4110746E-04,   3.5072493E-04
     +,   3.5997634E-04,   3.6879620E-04,   3.7712263E-04
     +,   3.8489708E-04,   3.9206693E-04,   3.9858493E-04
     +,   4.0441137E-04,   4.0951415E-04,   4.1386893E-04
     +,   4.1746045E-04,   4.2028274E-04,   4.2233858E-04
     +,   4.2363990E-04,   4.2420751E-04,   4.2407087E-04
     +,   4.2326722E-04,   4.2184125E-04,   4.1984476E-04
     +,   4.1733499E-04,   4.1437481E-04,   4.1103159E-04
     +,   4.0737624E-04,   4.0348253E-04,   3.9942708E-04
     +,   3.9528820E-04,   3.9114532E-04,   3.8707891E-04
     +,   3.8317085E-04,   3.7950382E-04,   3.7616090E-04
     +,   3.7322674E-04,   3.7078757E-04,   3.6893133E-04
     +,   3.6774806E-04,   3.6733138E-04,   3.6777771E-04
     +,   3.6918835E-04,   3.7166831E-04,   3.7532885E-04
     +,   3.8028610E-04,   3.8666301E-04,   3.9458944E-04
     +,   4.0420165E-04,   4.1564321E-04,   4.2906610E-04
     +,   4.4463004E-04,   4.6250102E-04,   4.8285353E-04
     +,   5.0586904E-04,   5.3173251E-04,   5.6063337E-04
     +,   5.9276412E-04,   6.2831934E-04,   6.6749036E-04
     +,   7.1046891E-04,   7.5745117E-04,   8.0864289E-04
     +,   8.6426403E-04,   9.2456711E-04,   9.8985864E-04
     +,   1.0605181E-03,   1.1370101E-03,   1.2199119E-03
     +,   1.3099127E-03,   1.4077765E-03,   1.5142984E-03
     +,   1.6302238E-03,   1.7561232E-03,   1.8922552E-03
     +,   2.0384535E-03,   2.1941015E-03,   2.3581712E-03
     +,   2.5294141E-03,   2.7067040E-03,   2.8894653E-03
     +,   3.0780588E-03,   3.2739872E-03,   3.4798852E-03
     +,   3.6990920E-03,   3.9350069E-03,   4.1904380E-03
     +,   4.4672643E-03,   4.7665294E-03,   5.0889030E-03
     +,   5.4351315E-03,   5.8058538E-03,   6.2004416E-03
     +,   6.6153109E-03,   7.0429938E-03,   7.4733370E-03
     +,   7.8973025E-03,   8.3127785E-03,   8.7303594E-03
     +,   9.1758696E-03,   9.6866237E-03,   1.0299566E-02
     +,   1.1033603E-02,   1.1874516E-02,   1.2775451E-02
     +,   1.3680566E-02,   1.4561695E-02,   1.5440652E-02
     +,   1.6373547E-02,   1.7407030E-02,   1.8549638E-02
     +,   1.9790111E-02,   2.1133970E-02,   2.2594118E-02
     +,   2.4120992E-02,   2.5547713E-02,   2.6633345E-02
     +,   2.7207593E-02,   2.7324414E-02,   2.7288856E-02
     +,   2.7502116E-02,   2.8239978E-02,   2.9500345E-02
     +,   3.0966641E-02,   3.2140460E-02,   3.2613430E-02
     +,   3.2271363E-02,   3.1294819E-02,   3.0007267E-02
     +,   2.8693521E-02,   2.7504506E-02,   2.6457231E-02
     +,   2.5451304E-02,   2.4304032E-02,   2.2849789E-02
     +,   2.1045282E-02,   1.8974008E-02,   1.6756771E-02
     +,   1.4482591E-02,   1.2220565E-02,   1.0056851E-02
     +,   8.0907056E-03,   6.3968413E-03,   4.9993452E-03
     +,   3.8779920E-03,   2.9912384E-03,   2.2955474E-03
     +,   1.7536733E-03,   1.3353430E-03,   1.0155377E-03
     +,   7.7315810E-04,   5.9049041E-04,   4.5303124E-04
     +,   3.4928991E-04,   2.7045139E-04,   2.0999630E-04
     +,   1.6321619E-04,   1.2676959E-04,   9.8268312E-05
     +,   7.5974567E-05,   5.8575009E-05,   4.5047826E-05
     +,   3.4575281E-05,   2.6499358E-05,   2.0289328E-05
     +,   1.5522055E-05,   1.1864625E-05,   9.0576741E-06
     +,   6.9020821E-06,   5.2455762E-06,   3.9725896E-06
     +,   2.9950702E-06,   2.2459569E-06,   1.6736805E-06
     +,   1.2384714E-06,   9.0934310E-07,   6.6212289E-07
     +,   4.7783374E-07,   3.4162628E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt115 = Yx/0.258255319148936
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7623310E-05,   1.7969887E-05
     +,   1.8310746E-05,   1.8645414E-05,   1.8973427E-05
     +,   1.9294344E-05,   1.9607742E-05,   1.9913214E-05
     +,   2.0210367E-05,   2.0498852E-05,   2.0778321E-05
     +,   2.1048474E-05,   2.1309019E-05,   2.1559696E-05
     +,   2.1800286E-05,   2.2030594E-05,   2.2250451E-05
     +,   2.2459730E-05,   2.2658338E-05,   2.2846205E-05
     +,   2.3023307E-05,   2.3189654E-05,   2.3345283E-05
     +,   2.3490285E-05,   2.3624765E-05,   2.3748891E-05
     +,   2.3862847E-05,   2.3966855E-05,   2.4061193E-05
     +,   2.4146158E-05,   2.4222092E-05,   2.4289371E-05
     +,   2.4348412E-05,   2.4399667E-05,   2.4443629E-05
     +,   2.4480820E-05,   2.4511803E-05,   2.4537185E-05
     +,   2.4557605E-05,   2.4573734E-05,   2.4586287E-05
     +,   2.4596018E-05,   2.4603722E-05,   2.4610221E-05
     +,   2.4616389E-05,   2.4623127E-05,   2.4631398E-05
     +,   2.4642182E-05,   2.4656512E-05,   2.4675470E-05
     +,   2.4700170E-05,   2.4731782E-05,   2.4771509E-05
     +,   2.4820609E-05,   2.4880384E-05,   2.4952196E-05
     +,   2.5037436E-05,   2.5137570E-05,   2.5254078E-05
     +,   2.5388530E-05,   2.5542531E-05,   2.5717736E-05
     +,   2.5915850E-05,   2.6138636E-05,   2.6387917E-05
     +,   2.6665552E-05,   2.6973476E-05,   2.7313637E-05
     +,   2.7688091E-05,   2.8098879E-05,   2.8548176E-05
     +,   2.9038129E-05,   2.9571002E-05,   3.0149064E-05
     +,   3.0774700E-05,   3.1450338E-05,   3.2178457E-05
     +,   3.2961580E-05,   3.3802378E-05,   3.4703600E-05
     +,   3.5668032E-05,   3.6698650E-05,   3.7798454E-05
     +,   3.8970713E-05,   4.0218700E-05,   4.1546002E-05
     +,   4.2956246E-05,   4.4453456E-05,   4.6041652E-05
     +,   4.7725294E-05,   4.9509126E-05,   5.1397990E-05
     +,   5.3397089E-05,   5.5512031E-05,   5.7748752E-05
     +,   6.0113296E-05,   6.2612300E-05,   6.5252367E-05
     +,   6.8040732E-05,   7.0984468E-05,   7.4091244E-05
     +,   7.7368422E-05,   8.0823840E-05,   8.4464882E-05
     +,   8.8299035E-05,   9.2333714E-05,   9.6575524E-05
     +,   1.0103056E-04,   1.0570459E-04,   1.1060251E-04
     +,   1.1572770E-04,   1.2108303E-04,   1.2666939E-04
     +,   1.3248678E-04,   1.3853281E-04,   1.4480401E-04
     +,   1.5129418E-04,   1.5799583E-04,   1.6489836E-04
     +,   1.7198965E-04,   1.7925531E-04,   1.8667805E-04
     +,   1.9423843E-04,   2.0191511E-04,   2.0968473E-04
     +,   2.1752097E-04,   2.2539677E-04,   2.3328250E-04
     +,   2.4114759E-04,   2.4895967E-04,   2.5668615E-04
     +,   2.6429273E-04,   2.7174581E-04,   2.7901030E-04
     +,   2.8605244E-04,   2.9283843E-04,   2.9933508E-04
     +,   3.0551010E-04,   3.1133284E-04,   3.1677415E-04
     +,   3.2180655E-04,   3.2640420E-04,   3.3054428E-04
     +,   3.3420604E-04,   3.3737122E-04,   3.4002485E-04
     +,   3.4215470E-04,   3.4375198E-04,   3.4481141E-04
     +,   3.4533124E-04,   3.4531383E-04,   3.4476563E-04
     +,   3.4369770E-04,   3.4212545E-04,   3.4006950E-04
     +,   3.3755603E-04,   3.3461684E-04,   3.3128963E-04
     +,   3.2761873E-04,   3.2365581E-04,   3.1945933E-04
     +,   3.1509582E-04,   3.1064040E-04,   3.0617710E-04
     +,   3.0179863E-04,   2.9760797E-04,   2.9371842E-04
     +,   2.9025390E-04,   2.8734925E-04,   2.8515104E-04
     +,   2.8381779E-04,   2.8351982E-04,   2.8443953E-04
     +,   2.8677098E-04,   2.9071880E-04,   2.9649775E-04
     +,   3.0432994E-04,   3.1444200E-04,   3.2706128E-04
     +,   3.4241166E-04,   3.6070790E-04,   3.8214779E-04
     +,   4.0690586E-04,   4.3512951E-04,   4.6693269E-04
     +,   5.0239044E-04,   5.4154056E-04,   5.8439159E-04
     +,   6.3092983E-04,   6.8113056E-04,   7.3498779E-04
     +,   7.9253799E-04,   8.5388758E-04,   9.1924530E-04
     +,   9.8895817E-04,   1.0635263E-03,   1.1436014E-03
     +,   1.2299687E-03,   1.3235068E-03,   1.4250925E-03
     +,   1.5354742E-03,   1.6551213E-03,   1.7840686E-03
     +,   1.9217391E-03,   2.0668104E-03,   2.2172015E-03
     +,   2.3701550E-03,   2.5224891E-03,   2.6710681E-03
     +,   2.8134445E-03,   2.9485726E-03,   3.0774358E-03
     +,   3.2034100E-03,   3.3321234E-03,   3.4706274E-03
     +,   3.6260455E-03,   3.8039221E-03,   4.0068827E-03
     +,   4.2341254E-03,   4.4822032E-03,   4.7471682E-03
     +,   5.0274180E-03,   5.3261989E-03,   5.6526628E-03
     +,   6.0204617E-03,   6.4440304E-03,   6.9338116E-03
     +,   7.4921730E-03,   8.1112897E-03,   8.7724784E-03
     +,   9.4465185E-03,   1.0096529E-02,   1.0687085E-02
     +,   1.1200063E-02,   1.1649272E-02,   1.2079135E-02
     +,   1.2540919E-02,   1.3063127E-02,   1.3643070E-02
     +,   1.4267557E-02,   1.4938921E-02,   1.5678080E-02
     +,   1.6503019E-02,   1.7403334E-02,   1.8329298E-02
     +,   1.9203067E-02,   1.9945910E-02,   2.0500168E-02
     +,   2.0834018E-02,   2.0946758E-02,   2.0882489E-02
     +,   2.0713955E-02,   2.0479219E-02,   2.0138526E-02
     +,   1.9618707E-02,   1.8896395E-02,   1.8015884E-02
     +,   1.7029088E-02,   1.5942588E-02,   1.4732284E-02
     +,   1.3396489E-02,   1.1984927E-02,   1.0579389E-02
     +,   9.2526162E-03,   8.0420319E-03,   6.9510853E-03
     +,   5.9670764E-03,   5.0774375E-03,   4.2760642E-03
     +,   3.5619659E-03,   2.9354973E-03,   2.3954795E-03
     +,   1.9380144E-03,   1.5566279E-03,   1.2430392E-03
     +,   9.8810170E-04,   7.8257907E-04,   6.1788165E-04
     +,   4.8641427E-04,   3.8178029E-04,   2.9871540E-04
     +,   2.3298203E-04,   1.8117225E-04,   1.4055624E-04
     +,   1.0892079E-04,   8.4465508E-05,   6.5708744E-05
     +,   5.1430656E-05,   4.0630573E-05,   3.2492451E-05
     +,   2.6362321E-05,   2.1723539E-05,   1.8177458E-05
     +,   1.5422196E-05,   1.3235110E-05,   1.1455310E-05
     +,   9.9697672E-06,   8.7006165E-06,   7.5957250E-06
     +,   6.6206226E-06,   5.7529701E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt120 = Yx/0.173727272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7862695E-04,   4.1771712E-04
     +,   4.6107973E-04,   5.0935033E-04,   5.6330272E-04
     +,   6.2388193E-04,   6.9223752E-04,   7.6976587E-04
     +,   8.5814367E-04,   9.5936935E-04,   1.0757707E-03
     +,   1.2100074E-03,   1.3650398E-03,   1.5440634E-03
     +,   1.7504183E-03,   1.9874910E-03,   2.2586086E-03
     +,   2.5669683E-03,   2.9155989E-03,   3.3073786E-03
     +,   3.7451135E-03,   4.2317468E-03,   4.7707139E-03
     +,   5.3665782E-03,   6.0257777E-03,   6.7575984E-03
     +,   7.5747697E-03,   8.4934207E-03,   9.5319571E-03
     +,   1.0708834E-02,   1.2039481E-02,   1.3533019E-02
     +,   1.5189316E-02,   1.6996181E-02,   1.8926607E-02
     +,   2.0935969E-02,   2.2960540E-02,   2.4920367E-02
     +,   2.6728578E-02,   2.8305328E-02,   2.9590683E-02
     +,   3.0548321E-02,   3.1157920E-02,   3.1403955E-02
     +,   3.1271137E-02,   3.0753005E-02,   2.9867087E-02
     +,   2.8663456E-02,   2.7219228E-02,   2.5621960E-02
     +,   2.3953389E-02,   2.2281589E-02,   2.0661781E-02
     +,   1.9138893E-02,   1.7747017E-02,   1.6504580E-02
     +,   1.5411113E-02,   1.4448423E-02,   1.3587615E-02
     +,   1.2799096E-02,   1.2061502E-02,   1.1365991E-02
     +,   1.0715593E-02,   1.0119913E-02,   9.5886076E-03
     +,   9.1257952E-03,   8.7273335E-03,   8.3815129E-03
     +,   8.0720996E-03,   7.7824038E-03,   7.4987416E-03
     +,   7.2125387E-03,   6.9207880E-03,   6.6252565E-03
     +,   6.3309572E-03,   6.0443776E-03,   5.7720314E-03
     +,   5.5193393E-03,   5.2900035E-03,   5.0858399E-03
     +,   4.9068951E-03,   4.7517344E-03,   4.6178130E-03
     +,   4.5018671E-03,   4.4002472E-03,   4.3092081E-03
     +,   4.2251572E-03,   4.1448162E-03,   4.0653907E-03
     +,   3.9846567E-03,   3.9010227E-03,   3.8135615E-03
     +,   3.7219648E-03,   3.6264772E-03,   3.5278094E-03
     +,   3.4270161E-03,   3.3253473E-03,   3.2241750E-03
     +,   3.1248392E-03,   3.0285979E-03,   2.9365579E-03
     +,   2.8496596E-03,   2.7686548E-03,   2.6941334E-03
     +,   2.6265327E-03,   2.5661713E-03,   2.5132652E-03
     +,   2.4679445E-03,   2.4302513E-03,   2.4001447E-03
     +,   2.3774831E-03,   2.3620026E-03,   2.3533183E-03
     +,   2.3508894E-03,   2.3540349E-03,   2.3619260E-03
     +,   2.3736183E-03,   2.3880631E-03,   2.4041559E-03
     +,   2.4207777E-03,   2.4368365E-03,   2.4513162E-03
     +,   2.4633124E-03,   2.4720673E-03,   2.4769951E-03
     +,   2.4776864E-03,   2.4739197E-03,   2.4656474E-03
     +,   2.4529712E-03,   2.4361382E-03,   2.4154808E-03
     +,   2.3914198E-03,   2.3644080E-03,   2.3349095E-03
     +,   2.3033763E-03,   2.2702289E-03,   2.2358389E-03
     +,   2.2005131E-03,   2.1645050E-03,   2.1279929E-03
     +,   2.0911079E-03,   2.0539197E-03,   2.0164568E-03
     +,   1.9787150E-03,   1.9406636E-03,   1.9022571E-03
     +,   1.8634436E-03,   1.8241720E-03,   1.7844000E-03
     +,   1.7440933E-03,   1.7032325E-03,   1.6618198E-03
     +,   1.6198745E-03,   1.5774363E-03,   1.5345591E-03
     +,   1.4913253E-03,   1.4478314E-03,   1.4041938E-03
     +,   1.3605410E-03,   1.3170240E-03,   1.2738009E-03
     +,   1.2310393E-03,   1.1889216E-03,   1.1476306E-03
     +,   1.1073502E-03,   1.0682630E-03,   1.0305468E-03
     +,   9.9437346E-04,   9.5989782E-04,   9.2726119E-04
     +,   8.9658867E-04,   8.6798635E-04,   8.4153510E-04
     +,   8.1729563E-04,   7.9530553E-04,   7.7557721E-04
     +,   7.5810187E-04,   7.4284844E-04,   7.2976697E-04
     +,   7.1878562E-04,   7.0981763E-04,   7.0276210E-04
     +,   6.9750467E-04,   6.9392024E-04,   6.9187710E-04
     +,   6.9123588E-04,   6.9185469E-04,   6.9358788E-04
     +,   6.9629104E-04,   6.9981924E-04,   7.0403039E-04
     +,   7.0878683E-04,   7.1395328E-04,   7.1940146E-04
     +,   7.2500767E-04,   7.3065609E-04,   7.3623599E-04
     +,   7.4164447E-04,   7.4678648E-04,   7.5157388E-04
     +,   7.5592526E-04,   7.5976818E-04,   7.6303602E-04
     +,   7.6567131E-04,   7.6762214E-04,   7.6884456E-04
     +,   7.6930091E-04,   7.6896168E-04,   7.6780195E-04
     +,   7.6580379E-04,   7.6295639E-04,   7.5925264E-04
     +,   7.5469341E-04,   7.4928324E-04,   7.4303179E-04
     +,   7.3595351E-04,   7.2806806E-04,   7.1939890E-04
     +,   7.0997147E-04,   6.9981767E-04,   6.8897038E-04
     +,   6.7746587E-04,   6.6534319E-04,   6.5264420E-04
     +,   6.3941133E-04,   6.2568852E-04,   6.1152241E-04
     +,   5.9695943E-04,   5.8204698E-04,   5.6683202E-04
     +,   5.5136241E-04,   5.3568627E-04,   5.1984988E-04
     +,   5.0389883E-04,   4.8787918E-04,   4.7183412E-04
     +,   4.5580574E-04,   4.3983545E-04,   4.2396216E-04
     +,   4.0822316E-04,   3.9265287E-04,   3.7728422E-04
     +,   3.6214860E-04,   3.4727380E-04,   3.3268487E-04
     +,   3.1840589E-04,   3.0445837E-04,   2.9086019E-04
     +,   2.7762714E-04,   2.6477367E-04,   2.5231083E-04
     +,   2.4024720E-04,   2.2859014E-04,   2.1734495E-04
     +,   2.0651390E-04,   1.9609764E-04,   1.8609581E-04
     +,   1.7650604E-04,   1.6732413E-04,   1.5854434E-04
     +,   1.5016044E-04,   1.4216485E-04,   1.3454862E-04
     +,   1.2730184E-04,   1.2041470E-04,   1.1387598E-04
     +,   1.0767398E-04,   1.0179721E-04,   9.6233663E-05
     +,   9.0970767E-05,   8.5995962E-05,   8.1297054E-05
     +,   7.6861681E-05,   7.2677503E-05,   6.8732254E-05
     +,   6.5014297E-05,   6.1511790E-05,   5.8213671E-05
     +,   5.5108740E-05,   5.2186606E-05,   4.9436858E-05
     +,   4.6849851E-05,   4.4415974E-05,   4.2126394E-05
     +,   3.9972365E-05,   3.7945880E-05,   3.6039040E-05
     +,   3.4244476E-05,   3.2555323E-05,   3.0964879E-05
     +,   2.9467046E-05,   2.8055878E-05,   2.6725989E-05
     +,   2.5472105E-05,   2.4289491E-05,   2.3173523E-05
     +,   2.2120037E-05,   2.1124995E-05,   2.0184756E-05
     +,   1.9295801E-05,   1.8454972E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt60 = Yx/0.281489361702128
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1328017E-04,   1.2346728E-04
     +,   1.3456644E-04,   1.4663688E-04,   1.5973889E-04
     +,   1.7393379E-04,   1.8928405E-04,   2.0585352E-04
     +,   2.2370787E-04,   2.4291605E-04,   2.6355003E-04
     +,   2.8568695E-04,   3.0941036E-04,   3.3481303E-04
     +,   3.6199973E-04,   3.9109107E-04,   4.2222950E-04
     +,   4.5558557E-04,   4.9136655E-04,   5.2982668E-04
     +,   5.7127705E-04,   6.1609549E-04,   6.6473370E-04
     +,   7.1772444E-04,   7.7566830E-04,   8.3923555E-04
     +,   9.0914348E-04,   9.8614872E-04,   1.0710596E-03
     +,   1.1647835E-03,   1.2684531E-03,   1.3836464E-03
     +,   1.5127182E-03,   1.6592336E-03,   1.8284280E-03
     +,   2.0275747E-03,   2.2660848E-03,   2.5551496E-03
     +,   2.9068452E-03,   3.3326331E-03,   3.8417906E-03
     +,   4.4399463E-03,   5.1286779E-03,   5.9065162E-03
     +,   6.7717079E-03,   7.7262530E-03,   8.7799877E-03
     +,   9.9528721E-03,   1.1273528E-02,   1.2773339E-02
     +,   1.4477168E-02,   1.6392199E-02,   1.8497048E-02
     +,   2.0734828E-02,   2.3015996E-02,   2.5239041E-02
     +,   2.7322661E-02,   2.9231383E-02,   3.0972440E-02
     +,   3.2561906E-02,   3.3988420E-02,   3.5207376E-02
     +,   3.6170825E-02,   3.6860839E-02,   3.7286159E-02
     +,   3.7436690E-02,   3.7243508E-02,   3.6598738E-02
     +,   3.5437141E-02,   3.3810936E-02,   3.1888276E-02
     +,   2.9877182E-02,   2.7938664E-02,   2.6151057E-02
     +,   2.4525590E-02,   2.3037659E-02,   2.1648448E-02
     +,   2.0318033E-02,   1.9020027E-02,   1.7754877E-02
     +,   1.6551573E-02,   1.5453595E-02,   1.4498278E-02
     +,   1.3700089E-02,   1.3046921E-02,   1.2506969E-02
     +,   1.2041342E-02,   1.1614527E-02,   1.1200047E-02
     +,   1.0781107E-02,   1.0348802E-02,   9.9001331E-03
     +,   9.4364760E-03,   8.9626573E-03,   8.4859263E-03
     +,   8.0148419E-03,   7.5579090E-03,   7.1225446E-03
     +,   6.7143189E-03,   6.3367882E-03,   5.9915311E-03
     +,   5.6785648E-03,   5.3968034E-03,   5.1445290E-03
     +,   4.9197786E-03,   4.7205673E-03,   4.5450656E-03
     +,   4.3916269E-03,   4.2587072E-03,   4.1448572E-03
     +,   4.0486264E-03,   3.9684577E-03,   3.9026807E-03
     +,   3.8494298E-03,   3.8066674E-03,   3.7721966E-03
     +,   3.7437233E-03,   3.7189547E-03,   3.6956829E-03
     +,   3.6719337E-03,   3.6460271E-03,   3.6166827E-03
     +,   3.5830447E-03,   3.5447010E-03,   3.5016299E-03
     +,   3.4541690E-03,   3.4029232E-03,   3.3486919E-03
     +,   3.2923704E-03,   3.2348935E-03,   3.1771548E-03
     +,   3.1199581E-03,   3.0639782E-03,   3.0097412E-03
     +,   2.9575939E-03,   2.9077155E-03,   2.8601217E-03
     +,   2.8146622E-03,   2.7710539E-03,   2.7288967E-03
     +,   2.6877173E-03,   2.6469829E-03,   2.6061439E-03
     +,   2.5646645E-03,   2.5220567E-03,   2.4778906E-03
     +,   2.4318241E-03,   2.3836177E-03,   2.3331274E-03
     +,   2.2803131E-03,   2.2252297E-03,   2.1680165E-03
     +,   2.1088864E-03,   2.0481036E-03,   1.9859772E-03
     +,   1.9228433E-03,   1.8590539E-03,   1.7949622E-03
     +,   1.7309146E-03,   1.6672539E-03,   1.6043005E-03
     +,   1.5423616E-03,   1.4817244E-03,   1.4226607E-03
     +,   1.3654188E-03,   1.3102319E-03,   1.2573202E-03
     +,   1.2068863E-03,   1.1591160E-03,   1.1141804E-03
     +,   1.0722381E-03,   1.0334332E-03,   9.9789014E-04
     +,   9.6571777E-04,   9.3700842E-04,   9.1183296E-04
     +,   8.9024135E-04,   8.7226118E-04,   8.5789373E-04
     +,   8.4711646E-04,   8.3987787E-04,   8.3609752E-04
     +,   8.3566358E-04,   8.3843514E-04,   8.4423908E-04
     +,   8.5287035E-04,   8.6409249E-04,   8.7764102E-04
     +,   8.9322368E-04,   9.1051939E-04,   9.2918804E-04
     +,   9.4886951E-04,   9.6918881E-04,   9.8975934E-04
     +,   1.0101928E-03,   1.0301024E-03,   1.0491062E-03
     +,   1.0668373E-03,   1.0829472E-03,   1.0971149E-03
     +,   1.1090485E-03,   1.1184919E-03,   1.1252305E-03
     +,   1.1290928E-03,   1.1299533E-03,   1.1277357E-03
     +,   1.1224109E-03,   1.1139987E-03,   1.1025638E-03
     +,   1.0882159E-03,   1.0711036E-03,   1.0514110E-03
     +,   1.0293551E-03,   1.0051745E-03,   9.7912771E-04
     +,   9.5148833E-04,   9.2253630E-04,   8.9255226E-04
     +,   8.6181116E-04,   8.3058368E-04,   7.9912355E-04
     +,   7.6766638E-04,   7.3643134E-04,   7.0561399E-04
     +,   6.7538553E-04,   6.4589130E-04,   6.1725447E-04
     +,   5.8957358E-04,   5.6292221E-04,   5.3735188E-04
     +,   5.1289576E-04,   4.8956834E-04,   4.6736660E-04
     +,   4.4627383E-04,   4.2626352E-04,   4.0729798E-04
     +,   3.8933198E-04,   3.7231628E-04,   3.5619785E-04
     +,   3.4092073E-04,   3.2642807E-04,   3.1266492E-04
     +,   2.9957734E-04,   2.8711298E-04,   2.7522244E-04
     +,   2.6386030E-04,   2.5298461E-04,   2.4255614E-04
     +,   2.3253987E-04,   2.2290496E-04,   2.1362345E-04
     +,   2.0467056E-04,   1.9602530E-04,   1.8766956E-04
     +,   1.7958705E-04,   1.7176442E-04,   1.6419026E-04
     +,   1.5685544E-04,   1.4975178E-04,   1.4287238E-04
     +,   1.3621198E-04,   1.2976633E-04,   1.2353131E-04
     +,   1.1750356E-04,   1.1168070E-04,   1.0605997E-04
     +,   1.0063900E-04,   9.5415773E-05,   9.0388290E-05
     +,   8.5554238E-05,   8.0911144E-05,   7.6456745E-05
     +,   7.2188574E-05,   6.8103684E-05,   6.4198903E-05
     +,   6.0471288E-05,   5.6917026E-05,   5.3532742E-05
     +,   5.0314204E-05,   4.7257508E-05,   4.4358112E-05
     +,   4.1611682E-05,   3.9013317E-05,   3.6558380E-05
     +,   3.4241759E-05,   3.2058542E-05,   3.0003537E-05
     +,   2.8071519E-05,   2.6257399E-05,   2.4555866E-05
     +,   2.2961838E-05,   2.1470065E-05,   2.0075555E-05
     +,   1.8773202E-05,   1.7558175E-05,   1.6425573E-05
     +,   1.5370792E-05,   1.4389201E-05,   1.3476455E-05
     +,   1.2628244E-05,   1.1840527E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt65 = Yx/0.336875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.7872992E-05,   6.0836355E-05
     +,   6.3932610E-05,   6.7168534E-05,   7.0551745E-05
     +,   7.4090683E-05,   7.7794881E-05,   8.1675018E-05
     +,   8.5743013E-05,   9.0012538E-05,   9.4498704E-05
     +,   9.9218611E-05,   1.0419163E-04,   1.0943943E-04
     +,   1.1498664E-04,   1.2086099E-04,   1.2709378E-04
     +,   1.3372052E-04,   1.4078115E-04,   1.4832089E-04
     +,   1.5639084E-04,   1.6504845E-04,   1.7435824E-04
     +,   1.8439307E-04,   1.9523334E-04,   2.0696950E-04
     +,   2.1970105E-04,   2.3353779E-04,   2.4859965E-04
     +,   2.6501779E-04,   2.8293417E-04,   3.0250271E-04
     +,   3.2389036E-04,   3.4727834E-04,   3.7286634E-04
     +,   4.0087677E-04,   4.3156210E-04,   4.6521588E-04
     +,   5.0218927E-04,   5.4290512E-04,   5.8788905E-04
     +,   6.3779263E-04,   6.9342990E-04,   7.5581024E-04
     +,   8.2617754E-04,   9.0603722E-04,   9.9717942E-04
     +,   1.1016822E-03,   1.2218895E-03,   1.3603622E-03
     +,   1.5197886E-03,   1.7028690E-03,   1.9121637E-03
     +,   2.1499742E-03,   2.4181749E-03,   2.7182077E-03
     +,   3.0511161E-03,   3.4178286E-03,   3.8197115E-03
     +,   4.2594937E-03,   4.7425721E-03,   5.2785845E-03
     +,   5.8826641E-03,   6.5757013E-03,   7.3823114E-03
     +,   8.3263004E-03,   9.4255926E-03,   1.0689349E-02
     +,   1.2120705E-02,   1.3721891E-02,   1.5495302E-02
     +,   1.7433988E-02,   1.9509742E-02,   2.1673575E-02
     +,   2.3879413E-02,   2.6113510E-02,   2.8400620E-02
     +,   3.0772852E-02,   3.3223636E-02,   3.5685316E-02
     +,   3.8042407E-02,   4.0165734E-02,   4.1957203E-02
     +,   4.3399651E-02,   4.4549953E-02,   4.5419868E-02
     +,   4.5840248E-02,   4.5503657E-02,   4.4214830E-02
     +,   4.2125054E-02,   3.9717823E-02,   3.7541281E-02
     +,   3.5884246E-02,   3.4629371E-02,   3.3390347E-02
     +,   3.1823888E-02,   2.9867107E-02,   2.7731126E-02
     +,   2.5702849E-02,   2.3951337E-02,   2.2473339E-02
     +,   2.1163989E-02,   1.9915175E-02,   1.8672112E-02
     +,   1.7437087E-02,   1.6243611E-02,   1.5125959E-02
     +,   1.4100270E-02,   1.3161504E-02,   1.2293177E-02
     +,   1.1480774E-02,   1.0720781E-02,   1.0021751E-02
     +,   9.3983589E-03,   8.8632191E-03,   8.4204627E-03
     +,   8.0641387E-03,   7.7805081E-03,   7.5524608E-03
     +,   7.3636426E-03,   7.2008078E-03,   7.0543615E-03
     +,   6.9173751E-03,   6.7844409E-03,   6.6508367E-03
     +,   6.5123620E-03,   6.3656666E-03,   6.2087388E-03
     +,   6.0412535E-03,   5.8646514E-03,   5.6817690E-03
     +,   5.4963194E-03,   5.3121857E-03,   5.1328614E-03
     +,   4.9609067E-03,   4.7976826E-03,   4.6432903E-03
     +,   4.4966759E-03,   4.3559051E-03,   4.2185457E-03
     +,   4.0821061E-03,   3.9443937E-03,   3.8038271E-03
     +,   3.6596132E-03,   3.5118316E-03,   3.3613252E-03
     +,   3.2095711E-03,   3.0584498E-03,   2.9099963E-03
     +,   2.7661643E-03,   2.6286449E-03,   2.4987378E-03
     +,   2.3772847E-03,   2.2646559E-03,   2.1607983E-03
     +,   2.0653338E-03,   1.9776381E-03,   1.8969346E-03
     +,   1.8224026E-03,   1.7532457E-03,   1.6887335E-03
     +,   1.6282380E-03,   1.5712564E-03,   1.5174011E-03
     +,   1.4663876E-03,   1.4180266E-03,   1.3722026E-03
     +,   1.3288590E-03,   1.2879774E-03,   1.2495655E-03
     +,   1.2136525E-03,   1.1802723E-03,   1.1494608E-03
     +,   1.1212438E-03,   1.0956450E-03,   1.0726687E-03
     +,   1.0523066E-03,   1.0345319E-03,   1.0192994E-03
     +,   1.0065419E-03,   9.9617103E-04,   9.8808052E-04
     +,   9.8214217E-04,   9.7820989E-04,   9.7611884E-04
     +,   9.7568694E-04,   9.7671966E-04,   9.7900885E-04
     +,   9.8233612E-04,   9.8647457E-04,   9.9119346E-04
     +,   9.9625753E-04,   1.0014343E-03,   1.0064922E-03
     +,   1.0112068E-03,   1.0153650E-03,   1.0187638E-03
     +,   1.0212181E-03,   1.0225595E-03,   1.0226417E-03
     +,   1.0213424E-03,   1.0185641E-03,   1.0142351E-03
     +,   1.0083135E-03,   1.0007829E-03,   9.9165598E-04
     +,   9.8097289E-04,   9.6879707E-04,   9.5521699E-04
     +,   9.4034075E-04,   9.2429348E-04,   9.0721628E-04
     +,   8.8926003E-04,   8.7058271E-04,   8.5134455E-04
     +,   8.3170674E-04,   8.1182673E-04,   7.9185318E-04
     +,   7.7192386E-04,   7.5216708E-04,   7.3269376E-04
     +,   7.1359839E-04,   6.9496001E-04,   6.7683938E-04
     +,   6.5927883E-04,   6.4230320E-04,   6.2592170E-04
     +,   6.1012874E-04,   5.9490453E-04,   5.8021670E-04
     +,   5.6602445E-04,   5.5227918E-04,   5.3892506E-04
     +,   5.2590319E-04,   5.1315408E-04,   5.0061772E-04
     +,   4.8823489E-04,   4.7595121E-04,   4.6371730E-04
     +,   4.5148778E-04,   4.3922479E-04,   4.2689737E-04
     +,   4.1448337E-04,   4.0196633E-04,   3.8933798E-04
     +,   3.7659795E-04,   3.6375312E-04,   3.5081568E-04
     +,   3.3780388E-04,   3.2474214E-04,   3.1165770E-04
     +,   2.9858173E-04,   2.8554886E-04,   2.7259480E-04
     +,   2.5975620E-04,   2.4706978E-04,   2.3457244E-04
     +,   2.2230014E-04,   2.1028622E-04,   1.9856203E-04
     +,   1.8715694E-04,   1.7609756E-04,   1.6540651E-04
     +,   1.5510290E-04,   1.4520391E-04,   1.3572184E-04
     +,   1.2666571E-04,   1.1804189E-04,   1.0985344E-04
     +,   1.0209989E-04,   9.4777948E-05,   8.7882254E-05
     +,   8.1405131E-05,   7.5336386E-05,   6.9663998E-05
     +,   6.4375134E-05,   5.9454836E-05,   5.4887900E-05
     +,   5.0657749E-05,   4.6747788E-05,   4.3140612E-05
     +,   3.9819155E-05,   3.6765960E-05,   3.3964137E-05
     +,   3.1396754E-05,   2.9047671E-05,   2.6901002E-05
     +,   2.4941488E-05,   2.3154724E-05,   2.1526750E-05
     +,   2.0044577E-05,   1.8695746E-05,   1.7468750E-05
     +,   1.6352664E-05,   1.5337464E-05,   1.4413709E-05
     +,   1.3572794E-05,   1.2806683E-05,   1.2108080E-05
     +,   1.1470222E-05,   1.0887010E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt70 = Yx/0.384571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.0737304E-05,   6.3112711E-05
     +,   6.5526336E-05,   6.7975518E-05,   7.0457594E-05
     +,   7.2969939E-05,   7.5510005E-05,   7.8075427E-05
     +,   8.0663973E-05,   8.3273895E-05,   8.5903681E-05
     +,   8.8552348E-05,   9.1219496E-05,   9.3905423E-05
     +,   9.6611227E-05,   9.9338955E-05,   1.0209163E-04
     +,   1.0487348E-04,   1.0768990E-04,   1.1054772E-04
     +,   1.1345516E-04,   1.1642194E-04,   1.1945936E-04
     +,   1.2258043E-04,   1.2579953E-04,   1.2913297E-04
     +,   1.3259856E-04,   1.3621582E-04,   1.4000577E-04
     +,   1.4399117E-04,   1.4819644E-04,   1.5264784E-04
     +,   1.5737361E-04,   1.6240421E-04,   1.6777329E-04
     +,   1.7351746E-04,   1.7967813E-04,   1.8630212E-04
     +,   1.9344380E-04,   2.0116605E-04,   2.0954388E-04
     +,   2.1866622E-04,   2.2863966E-04,   2.3959193E-04
     +,   2.5167660E-04,   2.6507681E-04,   2.8001060E-04
     +,   2.9673538E-04,   3.1555261E-04,   3.3681124E-04
     +,   3.6091084E-04,   3.8830246E-04,   4.1948727E-04
     +,   4.5501502E-04,   4.9547118E-04,   5.4147531E-04
     +,   5.9365976E-04,   6.5265771E-04,   7.1908312E-04
     +,   7.9351477E-04,   8.7647792E-04,   9.6843549E-04
     +,   1.0697740E-03,   1.1808241E-03,   1.3018713E-03
     +,   1.4331703E-03,   1.5750208E-03,   1.7277776E-03
     +,   1.8919475E-03,   2.0682029E-03,   2.2574747E-03
     +,   2.4609801E-03,   2.6803704E-03,   2.9178581E-03
     +,   3.1765669E-03,   3.4609302E-03,   3.7771766E-03
     +,   4.1337926E-03,   4.5415927E-03,   5.0132014E-03
     +,   5.5617364E-03,   6.1991527E-03,   6.9342870E-03
     +,   7.7717644E-03,   8.7110503E-03,   9.7462814E-03
     +,   1.0865688E-02,   1.2052750E-02,   1.3290199E-02
     +,   1.4569471E-02,   1.5902994E-02,   1.7334962E-02
     +,   1.8944599E-02,   2.0833556E-02,   2.3086395E-02
     +,   2.5706002E-02,   2.8568564E-02,   3.1471476E-02
     +,   3.4276452E-02,   3.6994088E-02,   3.9677374E-02
     +,   4.2259991E-02,   4.4611834E-02,   4.6728402E-02
     +,   4.8689291E-02,   5.0398350E-02,   5.1550936E-02
     +,   5.1932219E-02,   5.1613927E-02,   5.0805923E-02
     +,   4.9594175E-02,   4.7848701E-02,   4.5375232E-02
     +,   4.2190608E-02,   3.8643200E-02,   3.5210658E-02
     +,   3.2192398E-02,   2.9621236E-02,   2.7406631E-02
     +,   2.5479674E-02,   2.3818918E-02,   2.2411468E-02
     +,   2.1232080E-02,   2.0250935E-02,   1.9438656E-02
     +,   1.8755186E-02,   1.8139604E-02,   1.7518250E-02
     +,   1.6825516E-02,   1.6023086E-02,   1.5106495E-02
     +,   1.4100541E-02,   1.3048014E-02,   1.1997805E-02
     +,   1.0994828E-02,   1.0073823E-02,   9.2566581E-03
     +,   8.5521648E-03,   7.9579763E-03,   7.4634822E-03
     +,   7.0533971E-03,   6.7107701E-03,   6.4192116E-03
     +,   6.1640739E-03,   5.9328526E-03,   5.7151481E-03
     +,   5.5027963E-03,   5.2899630E-03,   5.0732638E-03
     +,   4.8516346E-03,   4.6260408E-03,   4.3988507E-03
     +,   4.1732080E-03,   3.9523104E-03,   3.7389416E-03
     +,   3.5351750E-03,   3.3422292E-03,   3.1605198E-03
     +,   2.9898125E-03,   2.8294616E-03,   2.6785701E-03
     +,   2.5362039E-03,   2.4015247E-03,   2.2738862E-03
     +,   2.1528576E-03,   2.0382390E-03,   1.9300383E-03
     +,   1.8284289E-03,   1.7336872E-03,   1.6461466E-03
     +,   1.5661585E-03,   1.4940406E-03,   1.4300377E-03
     +,   1.3743059E-03,   1.3268907E-03,   1.2877118E-03
     +,   1.2565603E-03,   1.2331038E-03,   1.2168903E-03
     +,   1.2073581E-03,   1.2038555E-03,   1.2056553E-03
     +,   1.2119790E-03,   1.2220177E-03,   1.2349528E-03
     +,   1.2499784E-03,   1.2663229E-03,   1.2832680E-03
     +,   1.3001644E-03,   1.3164476E-03,   1.3316433E-03
     +,   1.3453827E-03,   1.3573971E-03,   1.3675215E-03
     +,   1.3756893E-03,   1.3819241E-03,   1.3863232E-03
     +,   1.3890500E-03,   1.3903136E-03,   1.3903492E-03
     +,   1.3894035E-03,   1.3877155E-03,   1.3854996E-03
     +,   1.3829326E-03,   1.3801432E-03,   1.3772037E-03
     +,   1.3741245E-03,   1.3708569E-03,   1.3672940E-03
     +,   1.3632792E-03,   1.3586137E-03,   1.3530690E-03
     +,   1.3464043E-03,   1.3383736E-03,   1.3287448E-03
     +,   1.3173093E-03,   1.3038984E-03,   1.2883862E-03
     +,   1.2707008E-03,   1.2508291E-03,   1.2288134E-03
     +,   1.2047532E-03,   1.1788001E-03,   1.1511538E-03
     +,   1.1220471E-03,   1.0917409E-03,   1.0605166E-03
     +,   1.0286612E-03,   9.9645683E-04,   9.6417463E-04
     +,   9.3206612E-04,   9.0035686E-04,   8.6923852E-04
     +,   8.3886844E-04,   8.0937159E-04,   7.8083348E-04
     +,   7.5330510E-04,   7.2680920E-04,   7.0133962E-04
     +,   6.7686517E-04,   6.5333460E-04,   6.3068548E-04
     +,   6.0884451E-04,   5.8773154E-04,   5.6726491E-04
     +,   5.4736627E-04,   5.2796100E-04,   5.0898100E-04
     +,   4.9036497E-04,   4.7206381E-04,   4.5403640E-04
     +,   4.3625140E-04,   4.1868814E-04,   4.0133565E-04
     +,   3.8419027E-04,   3.6725518E-04,   3.5054193E-04
     +,   3.3406715E-04,   3.1785070E-04,   3.0191569E-04
     +,   2.8628853E-04,   2.7099668E-04,   2.5606732E-04
     +,   2.4152685E-04,   2.2740201E-04,   2.1371670E-04
     +,   2.0049227E-04,   1.8774862E-04,   1.7550257E-04
     +,   1.6376715E-04,   1.5255196E-04,   1.4186437E-04
     +,   1.3170809E-04,   1.2208319E-04,   1.1298653E-04
     +,   1.0441311E-04,   9.6353979E-05,   8.8798690E-05
     +,   8.1733757E-05,   7.5144591E-05,   6.9013993E-05
     +,   6.3324282E-05,   5.8055834E-05,   5.3188909E-05
     +,   4.8702488E-05,   4.4575801E-05,   4.0787494E-05
     +,   3.7316331E-05,   3.4141663E-05,   3.1242795E-05
     +,   2.8599994E-05,   2.6193797E-05,   2.4005867E-05
     +,   2.2018376E-05,   2.0214669E-05,   1.8578781E-05
     +,   1.7095910E-05,   1.5752054E-05,   1.4534313E-05
     +,   1.3430606E-05,   1.2429914E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt75 = Yx/0.4158
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.4411750E-05,   7.7220277E-05
     +,   8.0138096E-05,   8.3171450E-05,   8.6326734E-05
     +,   8.9610556E-05,   9.3029521E-05,   9.6590324E-05
     +,   1.0029940E-04,   1.0416331E-04,   1.0818815E-04
     +,   1.1237963E-04,   1.1674304E-04,   1.2128308E-04
     +,   1.2600371E-04,   1.3090803E-04,   1.3599829E-04
     +,   1.4127577E-04,   1.4674047E-04,   1.5239138E-04
     +,   1.5822626E-04,   1.6424141E-04,   1.7043200E-04
     +,   1.7679224E-04,   1.8331439E-04,   1.8999031E-04
     +,   1.9681052E-04,   2.0376472E-04,   2.1084188E-04
     +,   2.1803053E-04,   2.2531895E-04,   2.3269554E-04
     +,   2.4014885E-04,   2.4766833E-04,   2.5524443E-04
     +,   2.6286894E-04,   2.7053527E-04,   2.7823911E-04
     +,   2.8597884E-04,   2.9375509E-04,   3.0157247E-04
     +,   3.0943853E-04,   3.1736502E-04,   3.2536787E-04
     +,   3.3346750E-04,   3.4168913E-04,   3.5006349E-04
     +,   3.5862660E-04,   3.6742102E-04,   3.7649577E-04
     +,   3.8590742E-04,   3.9572016E-04,   4.0600734E-04
     +,   4.1685303E-04,   4.2835082E-04,   4.4060816E-04
     +,   4.5374446E-04,   4.6789387E-04,   4.8320554E-04
     +,   4.9984345E-04,   5.1798648E-04,   5.3782790E-04
     +,   5.5957108E-04,   5.8342976E-04,   6.0962193E-04
     +,   6.3836179E-04,   6.6985871E-04,   7.0430274E-04
     +,   7.4186461E-04,   7.8267982E-04,   8.2685112E-04
     +,   8.7443471E-04,   9.2545094E-04,   9.7987475E-04
     +,   1.0376595E-03,   1.0987432E-03,   1.1630742E-03
     +,   1.2306398E-03,   1.3015100E-03,   1.3758696E-03
     +,   1.4540579E-03,   1.5366207E-03,   1.6243213E-03
     +,   1.7181790E-03,   1.8194462E-03,   1.9296127E-03
     +,   2.0503458E-03,   2.1834648E-03,   2.3308662E-03
     +,   2.4945056E-03,   2.6763524E-03,   2.8783525E-03
     +,   3.1023924E-03,   3.3502528E-03,   3.6235177E-03
     +,   3.9234716E-03,   4.2512412E-03,   4.6080253E-03
     +,   4.9958806E-03,   5.4185647E-03,   5.8825100E-03
     +,   6.3968832E-03,   6.9725262E-03,   7.6192832E-03
     +,   8.3430773E-03,   9.1442736E-03,   1.0019816E-02
     +,   1.0970430E-02,   1.2011089E-02,   1.3178405E-02
     +,   1.4526588E-02,   1.6107948E-02,   1.7944787E-02
     +,   2.0016547E-02,   2.2277942E-02,   2.4698373E-02
     +,   2.7282149E-02,   3.0053768E-02,   3.3033539E-02
     +,   3.6226105E-02,   3.9593372E-02,   4.3024320E-02
     +,   4.6391182E-02,   4.9635656E-02,   5.2642759E-02
     +,   5.5003211E-02,   5.6182481E-02,   5.6100570E-02
     +,   5.5363078E-02,   5.4755796E-02,   5.4561853E-02
     +,   5.4375347E-02,   5.3483061E-02,   5.1428534E-02
     +,   4.8319727E-02,   4.4686843E-02,   4.1076187E-02
     +,   3.7747130E-02,   3.4683004E-02,   3.1823125E-02
     +,   2.9241957E-02,   2.7090130E-02,   2.5405040E-02
     +,   2.4035944E-02,   2.2754600E-02,   2.1402460E-02
     +,   1.9939994E-02,   1.8405288E-02,   1.6860349E-02
     +,   1.5366139E-02,   1.3977115E-02,   1.2735917E-02
     +,   1.1664775E-02,   1.0760742E-02,   9.9996701E-03
     +,   9.3461191E-03,   8.7639149E-03,   8.2233958E-03
     +,   7.7042775E-03,   7.1953512E-03,   6.6924179E-03
     +,   6.1960351E-03,   5.7096235E-03,   5.2378322E-03
     +,   4.7854921E-03,   4.3569850E-03,   3.9559267E-03
     +,   3.5850485E-03,   3.2461875E-03,   2.9404289E-03
     +,   2.6682306E-03,   2.4294732E-03,   2.2235364E-03
     +,   2.0493513E-03,   1.9054513E-03,   1.7899870E-03
     +,   1.7008140E-03,   1.6355756E-03,   1.5917917E-03
     +,   1.5669605E-03,   1.5586452E-03,   1.5645624E-03
     +,   1.5826160E-03,   1.6109342E-03,   1.6478651E-03
     +,   1.6919537E-03,   1.7419123E-03,   1.7965802E-03
     +,   1.8548719E-03,   1.9157317E-03,   1.9781035E-03
     +,   2.0408975E-03,   2.1029687E-03,   2.1631212E-03
     +,   2.2201114E-03,   2.2726818E-03,   2.3195830E-03
     +,   2.3596245E-03,   2.3917351E-03,   2.4150035E-03
     +,   2.4287298E-03,   2.4324795E-03,   2.4261086E-03
     +,   2.4097839E-03,   2.3839853E-03,   2.3494882E-03
     +,   2.3073379E-03,   2.2587993E-03,   2.2053006E-03
     +,   2.1483656E-03,   2.0895503E-03,   2.0303668E-03
     +,   1.9722357E-03,   1.9164121E-03,   1.8639519E-03
     +,   1.8156836E-03,   1.7721830E-03,   1.7337640E-03
     +,   1.7004900E-03,   1.6721890E-03,   1.6484752E-03
     +,   1.6287819E-03,   1.6123996E-03,   1.5985153E-03
     +,   1.5862505E-03,   1.5747015E-03,   1.5629821E-03
     +,   1.5502524E-03,   1.5357494E-03,   1.5188145E-03
     +,   1.4989073E-03,   1.4756244E-03,   1.4486978E-03
     +,   1.4180011E-03,   1.3835427E-03,   1.3454510E-03
     +,   1.3039677E-03,   1.2594274E-03,   1.2122394E-03
     +,   1.1628629E-03,   1.1117921E-03,   1.0595392E-03
     +,   1.0066124E-03,   9.5349923E-04,   9.0065668E-04
     +,   8.4850483E-04,   7.9741480E-04,   7.4770272E-04
     +,   6.9963204E-04,   6.5341609E-04,   6.0921261E-04
     +,   5.6713109E-04,   5.2724167E-04,   4.8957457E-04
     +,   4.5412645E-04,   4.2086554E-04,   3.8974133E-04
     +,   3.6068496E-04,   3.3361343E-04,   3.0843506E-04
     +,   2.8505363E-04,   2.6337002E-04,   2.4328240E-04
     +,   2.2469056E-04,   2.0749764E-04,   1.9160831E-04
     +,   1.7693125E-04,   1.6338045E-04,   1.5087424E-04
     +,   1.3933485E-04,   1.2868928E-04,   1.1887022E-04
     +,   1.0981447E-04,   1.0146293E-04,   9.3760784E-05
     +,   8.6657936E-05,   8.0107238E-05,   7.4065967E-05
     +,   6.8494017E-05,   6.3355117E-05,   5.8615180E-05
     +,   5.4243501E-05,   5.0211278E-05,   4.6492452E-05
     +,   4.3062588E-05,   3.9899634E-05,   3.6982972E-05
     +,   3.4293538E-05,   3.1814037E-05,   2.9528153E-05
     +,   2.7421149E-05,   2.5479054E-05,   2.3689228E-05
     +,   2.2039745E-05,   2.0519774E-05,   1.9119072E-05
     +,   1.7828344E-05,   1.6638818E-05,   1.5542519E-05
     +,   1.4531929E-05,   1.3600225E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt80 = Yx/0.44324
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9137491E-05,   2.9822342E-05
     +,   3.0513782E-05,   3.1211704E-05,   3.1916064E-05
     +,   3.2626835E-05,   3.3344048E-05,   3.4067769E-05
     +,   3.4798108E-05,   3.5535293E-05,   3.6279573E-05
     +,   3.7031266E-05,   3.7790815E-05,   3.8558755E-05
     +,   3.9335722E-05,   4.0122461E-05,   4.0919891E-05
     +,   4.1729050E-05,   4.2551153E-05,   4.3387616E-05
     +,   4.4240063E-05,   4.5110326E-05,   4.6000496E-05
     +,   4.6912992E-05,   4.7850437E-05,   4.8815928E-05
     +,   4.9812803E-05,   5.0844887E-05,   5.1916428E-05
     +,   5.3032127E-05,   5.4197219E-05,   5.5417502E-05
     +,   5.6699366E-05,   5.8049885E-05,   5.9476741E-05
     +,   6.0988419E-05,   6.2594103E-05,   6.4303866E-05
     +,   6.6128596E-05,   6.8079920E-05,   7.0170579E-05
     +,   7.2414106E-05,   7.4824973E-05,   7.7418576E-05
     +,   8.0211241E-05,   8.3220257E-05,   8.6463690E-05
     +,   8.9960500E-05,   9.3730407E-05,   9.7793796E-05
     +,   1.0217174E-04,   1.0688571E-04,   1.1195760E-04
     +,   1.1740982E-04,   1.2326433E-04,   1.2954361E-04
     +,   1.3626958E-04,   1.4346380E-04,   1.5114724E-04
     +,   1.5933996E-04,   1.6806090E-04,   1.7732810E-04
     +,   1.8715704E-04,   1.9756240E-04,   2.0855687E-04
     +,   2.2014960E-04,   2.3234867E-04,   2.4515780E-04
     +,   2.5857906E-04,   2.7260976E-04,   2.8724544E-04
     +,   3.0247605E-04,   3.1829040E-04,   3.3467170E-04
     +,   3.5160195E-04,   3.6906113E-04,   3.8702696E-04
     +,   4.0547780E-04,   4.2439543E-04,   4.4376706E-04
     +,   4.6358648E-04,   4.8386183E-04,   5.0461554E-04
     +,   5.2589457E-04,   5.4776971E-04,   5.7034637E-04
     +,   5.9376651E-04,   6.1821658E-04,   6.4392999E-04
     +,   6.7119498E-04,   7.0035917E-04,   7.3183316E-04
     +,   7.6610036E-04,   8.0372940E-04,   8.4538996E-04
     +,   8.9186663E-04,   9.4409741E-04,   1.0031909E-03
     +,   1.0704715E-03,   1.1474856E-03,   1.2360298E-03
     +,   1.3381033E-03,   1.4558746E-03,   1.5915348E-03
     +,   1.7471703E-03,   1.9245438E-03,   2.1248756E-03
     +,   2.3486733E-03,   2.5956577E-03,   2.8647992E-03
     +,   3.1545050E-03,   3.4630594E-03,   3.7889883E-03
     +,   4.1315416E-03,   4.4907755E-03,   4.8674885E-03
     +,   5.2627022E-03,   5.6772628E-03,   6.1117117E-03
     +,   6.5672761E-03,   7.0479806E-03,   7.5637349E-03
     +,   8.1333397E-03,   8.7853232E-03,   9.5545407E-03
     +,   1.0473629E-02,   1.1562433E-02,   1.2821877E-02
     +,   1.4241878E-02,   1.5823470E-02,   1.7602397E-02
     +,   1.9647192E-02,   2.2019224E-02,   2.4712414E-02
     +,   2.7625389E-02,   3.0605728E-02,   3.3545192E-02
     +,   3.6431614E-02,   3.9277051E-02,   4.1990869E-02
     +,   4.4370912E-02,   4.6267495E-02,   4.7744490E-02
     +,   4.9027167E-02,   5.0269678E-02,   5.1443342E-02
     +,   5.2522697E-02,   5.3655092E-02,   5.4971892E-02
     +,   5.6295324E-02,   5.7171810E-02,   5.7228420E-02
     +,   5.6444522E-02,   5.4984756E-02,   5.2858524E-02
     +,   4.9935583E-02,   4.6244569E-02,   4.2098179E-02
     +,   3.7944365E-02,   3.4142226E-02,   3.0824026E-02
     +,   2.7917285E-02,   2.5289625E-02,   2.2868330E-02
     +,   2.0637874E-02,   1.8575503E-02,   1.6627003E-02
     +,   1.4740705E-02,   1.2907285E-02,   1.1163270E-02
     +,   9.5643234E-03,   8.1569524E-03,   6.9661397E-03
     +,   5.9972373E-03,   5.2419552E-03,   4.6826648E-03
     +,   4.2954125E-03,   4.0528071E-03,   3.9272578E-03
     +,   3.8938539E-03,   3.9319457E-03,   4.0251482E-03
     +,   4.1602915E-03,   4.3260134E-03,   4.5114625E-03
     +,   4.7055567E-03,   4.8967339E-03,   5.0732950E-03
     +,   5.2240794E-03,   5.3393054E-03,   5.4114754E-03
     +,   5.4361126E-03,   5.4122307E-03,   5.3424668E-03
     +,   5.2328026E-03,   5.0919340E-03,   4.9303845E-03
     +,   4.7594444E-03,   4.5900671E-03,   4.4319374E-03
     +,   4.2927419E-03,   4.1777114E-03,   4.0894840E-03
     +,   4.0282286E-03,   3.9920202E-03,   3.9772652E-03
     +,   3.9792438E-03,   3.9925659E-03,   4.0115919E-03
     +,   4.0307431E-03,   4.0447456E-03,   4.0487861E-03
     +,   4.0386659E-03,   4.0109209E-03,   3.9629554E-03
     +,   3.8931742E-03,   3.8010876E-03,   3.6873720E-03
     +,   3.5538559E-03,   3.4034464E-03,   3.2399078E-03
     +,   3.0675980E-03,   2.8911661E-03,   2.7152044E-03
     +,   2.5439030E-03,   2.3808195E-03,   2.2286992E-03
     +,   2.0893707E-03,   1.9637418E-03,   1.8518884E-03
     +,   1.7531771E-03,   1.6664375E-03,   1.5901206E-03
     +,   1.5224789E-03,   1.4617202E-03,   1.4061086E-03
     +,   1.3540677E-03,   1.3042365E-03,   1.2554997E-03
     +,   1.2069972E-03,   1.1581198E-03,   1.1084927E-03
     +,   1.0579502E-03,   1.0064974E-03,   9.5428317E-04
     +,   9.0156839E-04,   8.4869307E-04,   7.9604040E-04
     +,   7.4401515E-04,   6.9302396E-04,   6.4344850E-04
     +,   5.9563271E-04,   5.4987700E-04,   5.0642446E-04
     +,   4.6545846E-04,   4.2710203E-04,   3.9142394E-04
     +,   3.5843981E-04,   3.2811551E-04,   3.0037703E-04
     +,   2.7511973E-04,   2.5221254E-04,   2.3150483E-04
     +,   2.1283451E-04,   1.9603541E-04,   1.8093888E-04
     +,   1.6737969E-04,   1.5520018E-04,   1.4425155E-04
     +,   1.3439493E-04,   1.2550298E-04,   1.1746115E-04
     +,   1.1016666E-04,   1.0352772E-04,   9.7463708E-05
     +,   9.1904549E-05,   8.6788750E-05,   8.2063700E-05
     +,   7.7683537E-05,   7.3609415E-05,   6.9807509E-05
     +,   6.6249340E-05,   6.2909996E-05,   5.9768576E-05
     +,   5.6806697E-05,   5.4008866E-05,   5.1361356E-05
     +,   4.8852260E-05,   4.6471410E-05,   4.4209530E-05
     +,   4.2058724E-05,   4.0011684E-05,   3.8062182E-05
     +,   3.6204317E-05,   3.4433055E-05,   3.2743570E-05
     +,   3.1131694E-05,   2.9593410E-05,   2.8125211E-05
     +,   2.6723674E-05,   2.5385814E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt85 = Yx/0.46172
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0308364E-05,   2.1066173E-05
     +,   2.1855101E-05,   2.2676339E-05,   2.3531082E-05
     +,   2.4420571E-05,   2.5346073E-05,   2.6308857E-05
     +,   2.7310232E-05,   2.8351536E-05,   2.9434124E-05
     +,   3.0559342E-05,   3.1728574E-05,   3.2943226E-05
     +,   3.4204699E-05,   3.5514411E-05,   3.6873771E-05
     +,   3.8284241E-05,   3.9747232E-05,   4.1264186E-05
     +,   4.2836542E-05,   4.4465723E-05,   4.6153138E-05
     +,   4.7900281E-05,   4.9708444E-05,   5.1579125E-05
     +,   5.3513690E-05,   5.5513494E-05,   5.7579935E-05
     +,   5.9714352E-05,   6.1918094E-05,   6.4192493E-05
     +,   6.6538887E-05,   6.8958623E-05,   7.1453018E-05
     +,   7.4023395E-05,   7.6671116E-05,   7.9397563E-05
     +,   8.2204235E-05,   8.5092375E-05,   8.8063680E-05
     +,   9.1119655E-05,   9.4261930E-05,   9.7492324E-05
     +,   1.0081269E-04,   1.0422499E-04,   1.0773149E-04
     +,   1.1133451E-04,   1.1503671E-04,   1.1884089E-04
     +,   1.2275022E-04,   1.2676814E-04,   1.3089849E-04
     +,   1.3514559E-04,   1.3951393E-04,   1.4400885E-04
     +,   1.4863603E-04,   1.5340185E-04,   1.5831324E-04
     +,   1.6337790E-04,   1.6860433E-04,   1.7400185E-04
     +,   1.7958038E-04,   1.8535125E-04,   1.9132666E-04
     +,   1.9751933E-04,   2.0394390E-04,   2.1061512E-04
     +,   2.1754987E-04,   2.2476535E-04,   2.3228065E-04
     +,   2.4011511E-04,   2.4829037E-04,   2.5682803E-04
     +,   2.6575150E-04,   2.7508551E-04,   2.8485508E-04
     +,   2.9508618E-04,   3.0580678E-04,   3.1704555E-04
     +,   3.2883149E-04,   3.4119652E-04,   3.5417211E-04
     +,   3.6779398E-04,   3.8209785E-04,   3.9712468E-04
     +,   4.1291708E-04,   4.2952457E-04,   4.4700003E-04
     +,   4.6540462E-04,   4.8480733E-04,   5.0528522E-04
     +,   5.2692374E-04,   5.4981979E-04,   5.7408004E-04
     +,   5.9981714E-04,   6.2715309E-04,   6.5620954E-04
     +,   6.8711117E-04,   7.1997242E-04,   7.5489876E-04
     +,   7.9197087E-04,   8.3124673E-04,   8.7274471E-04
     +,   9.1644516E-04,   9.6228358E-04,   1.0101467E-03
     +,   1.0598751E-03,   1.1112815E-03,   1.1641528E-03
     +,   1.2182737E-03,   1.2734592E-03,   1.3295780E-03
     +,   1.3866002E-03,   1.4446278E-03,   1.5039422E-03
     +,   1.5650290E-03,   1.6286217E-03,   1.6956950E-03
     +,   1.7674896E-03,   1.8454854E-03,   1.9313825E-03
     +,   2.0270648E-03,   2.1345872E-03,   2.2561492E-03
     +,   2.3940592E-03,   2.5507577E-03,   2.7287214E-03
     +,   2.9303678E-03,   3.1577947E-03,   3.4124821E-03
     +,   3.6948218E-03,   4.0038563E-03,   4.3370910E-03
     +,   4.6908706E-03,   5.0611440E-03,   5.4446571E-03
     +,   5.8404463E-03,   6.2513072E-03,   6.6850511E-03
     +,   7.1552349E-03,   7.6812296E-03,   8.2868487E-03
     +,   8.9971181E-03,   9.8335240E-03,   1.0809574E-02
     +,   1.1929250E-02,   1.3191083E-02,   1.4597928E-02
     +,   1.6166903E-02,   1.7932083E-02,   1.9936824E-02
     +,   2.2221744E-02,   2.4811264E-02,   2.7687531E-02
     +,   3.0743793E-02,   3.3756338E-02,   3.6449600E-02
     +,   3.8657766E-02,   4.0445752E-02,   4.2046692E-02
     +,   4.3660272E-02,   4.5296025E-02,   4.6758633E-02
     +,   4.7729921E-02,   4.7892846E-02,   4.7072869E-02
     +,   4.5331791E-02,   4.2906035E-02,   4.0016577E-02
     +,   3.6759179E-02,   3.3209637E-02,   2.9590048E-02
     +,   2.6257236E-02,   2.3527648E-02,   2.1545200E-02
     +,   2.0295784E-02,   1.9691600E-02,   1.9628150E-02
     +,   1.9996837E-02,   2.0675149E-02,   2.1517448E-02
     +,   2.2357667E-02,   2.3032388E-02,   2.3418058E-02
     +,   2.3466419E-02,   2.3216533E-02,   2.2770906E-02
     +,   2.2243651E-02,   2.1708228E-02,   2.1174720E-02
     +,   2.0605959E-02,   1.9956853E-02,   1.9208934E-02
     +,   1.8382967E-02,   1.7528791E-02,   1.6702319E-02
     +,   1.5942896E-02,   1.5260899E-02,   1.4639348E-02
     +,   1.4046477E-02,   1.3451472E-02,   1.2836462E-02
     +,   1.2201202E-02,   1.1561099E-02,   1.0939987E-02
     +,   1.0361632E-02,   9.8418025E-03,   9.3835602E-03
     +,   8.9770406E-03,   8.6035868E-03,   8.2423352E-03
     +,   7.8766607E-03,   7.4982648E-03,   7.1080043E-03
     +,   6.7137778E-03,   6.3268449E-03,   5.9580412E-03
     +,   5.6152511E-03,   5.3022648E-03,   5.0189700E-03
     +,   4.7624367E-03,   4.5281928E-03,   4.3113786E-03
     +,   4.1075414E-03,   3.9130514E-03,   3.7252679E-03
     +,   3.5424447E-03,   3.3635560E-03,   3.1881337E-03
     +,   3.0160928E-03,   2.8475912E-03,   2.6829250E-03
     +,   2.5224756E-03,   2.3666881E-03,   2.2160199E-03
     +,   2.0709292E-03,   1.9318742E-03,   1.7992745E-03
     +,   1.6734782E-03,   1.5547553E-03,   1.4432819E-03
     +,   1.3391178E-03,   1.2421961E-03,   1.1523340E-03
     +,   1.0692478E-03,   9.9256169E-04,   9.2182599E-04
     +,   8.5654738E-04,   7.9621648E-04,   7.4032054E-04
     +,   6.8837166E-04,   6.3992268E-04,   5.9457793E-04
     +,   5.5199658E-04,   5.1189750E-04,   4.7406164E-04
     +,   4.3832234E-04,   4.0455637E-04,   3.7267894E-04
     +,   3.4263491E-04,   3.1438810E-04,   2.8791133E-04
     +,   2.6318119E-04,   2.4017484E-04,   2.1886021E-04
     +,   1.9919695E-04,   1.8113524E-04,   1.6461450E-04
     +,   1.4956314E-04,   1.3590090E-04,   1.2354190E-04
     +,   1.1239520E-04,   1.0236663E-04,   9.3361581E-05
     +,   8.5287626E-05,   7.8054174E-05,   7.1575858E-05
     +,   6.5771572E-05,   6.0566927E-05,   5.5893066E-05
     +,   5.1688181E-05,   4.7896290E-05,   4.4468037E-05
     +,   4.1359413E-05,   3.8532253E-05,   3.5952951E-05
     +,   3.3592394E-05,   3.1425607E-05,   2.9430805E-05
     +,   2.7589424E-05,   2.5885261E-05,   2.4304598E-05
     +,   2.2835347E-05,   2.1467225E-05,   2.0191133E-05
     +,   1.8999259E-05,   1.7884597E-05,   1.6841101E-05
     +,   1.5863241E-05,   1.4946218E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt90 = Yx/0.44072
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5033234E-05,   3.5797359E-05
     +,   3.6579004E-05,   3.7379541E-05,   3.8200465E-05
     +,   3.9043356E-05,   3.9909875E-05,   4.0801777E-05
     +,   4.1720894E-05,   4.2669184E-05,   4.3648630E-05
     +,   4.4661301E-05,   4.5709334E-05,   4.6794896E-05
     +,   4.7920224E-05,   4.9087565E-05,   5.0299186E-05
     +,   5.1557381E-05,   5.2864405E-05,   5.4222506E-05
     +,   5.5633867E-05,   5.7100624E-05,   5.8624813E-05
     +,   6.0208476E-05,   6.1853352E-05,   6.3561216E-05
     +,   6.5333581E-05,   6.7171859E-05,   6.9077192E-05
     +,   7.1050556E-05,   7.3092684E-05,   7.5204065E-05
     +,   7.7384910E-05,   7.9635160E-05,   8.1954488E-05
     +,   8.4342209E-05,   8.6797387E-05,   8.9318710E-05
     +,   9.1904694E-05,   9.4553274E-05,   9.7262367E-05
     +,   1.0002939E-04,   1.0285151E-04,   1.0572559E-04
     +,   1.0864827E-04,   1.1161590E-04,   1.1462461E-04
     +,   1.1767033E-04,   1.2074885E-04,   1.2385575E-04
     +,   1.2698655E-04,   1.3013673E-04,   1.3330164E-04
     +,   1.3647680E-04,   1.3965761E-04,   1.4283968E-04
     +,   1.4601884E-04,   1.4919091E-04,   1.5235211E-04
     +,   1.5549899E-04,   1.5862823E-04,   1.6173713E-04
     +,   1.6482320E-04,   1.6788456E-04,   1.7092003E-04
     +,   1.7392843E-04,   1.7690993E-04,   1.7986463E-04
     +,   1.8279387E-04,   1.8569917E-04,   1.8858348E-04
     +,   1.9144976E-04,   1.9430245E-04,   1.9714641E-04
     +,   1.9998758E-04,   2.0283296E-04,   2.0569016E-04
     +,   2.0856781E-04,   2.1147597E-04,   2.1442540E-04
     +,   2.1742789E-04,   2.2049685E-04,   2.2364628E-04
     +,   2.2689191E-04,   2.3025044E-04,   2.3374023E-04
     +,   2.3738071E-04,   2.4119321E-04,   2.4520041E-04
     +,   2.4942667E-04,   2.5389876E-04,   2.5864434E-04
     +,   2.6369371E-04,   2.6907970E-04,   2.7483693E-04
     +,   2.8100266E-04,   2.8761727E-04,   2.9472300E-04
     +,   3.0236595E-04,   3.1059430E-04,   3.1946017E-04
     +,   3.2901770E-04,   3.3932482E-04,   3.5044109E-04
     +,   3.6242933E-04,   3.7535487E-04,   3.8928320E-04
     +,   4.0428108E-04,   4.2041586E-04,   4.3775470E-04
     +,   4.5636072E-04,   4.7629647E-04,   4.9761735E-04
     +,   5.2037602E-04,   5.4461375E-04,   5.7036674E-04
     +,   5.9765566E-04,   6.2649255E-04,   6.5687258E-04
     +,   6.8877748E-04,   7.2217471E-04,   7.5701508E-04
     +,   7.9323765E-04,   8.3077460E-04,   8.6955761E-04
     +,   9.0952264E-04,   9.5063122E-04,   9.9287287E-04
     +,   1.0362952E-03,   1.0810163E-03,   1.1272483E-03
     +,   1.1753110E-03,   1.2256585E-03,   1.2788748E-03
     +,   1.3356929E-03,   1.3969777E-03,   1.4637109E-03
     +,   1.5369648E-03,   1.6178745E-03,   1.7075882E-03
     +,   1.8072206E-03,   1.9178014E-03,   2.0402372E-03
     +,   2.1752629E-03,   2.3233714E-03,   2.4848233E-03
     +,   2.6595988E-03,   2.8474131E-03,   3.0477655E-03
     +,   3.2600642E-03,   3.4837998E-03,   3.7187596E-03
     +,   3.9653587E-03,   4.2249365E-03,   4.4999942E-03
     +,   4.7941767E-03,   5.1119253E-03,   5.4575824E-03
     +,   5.8338805E-03,   6.2398962E-03,   6.6691078E-03
     +,   7.1080034E-03,   7.5360262E-03,   7.9277148E-03
     +,   8.2566161E-03,   8.5004382E-03,   8.6459424E-03
     +,   8.6921332E-03,   8.6508431E-03,   8.5447486E-03
     +,   8.4039988E-03,   8.2628159E-03,   8.1568444E-03
     +,   8.1215966E-03,   8.1913946E-03,   8.3990796E-03
     +,   8.7777330E-03,   9.3651591E-03,   1.0209532E-02
     +,   1.1371995E-02,   1.2923605E-02,   1.4939348E-02
     +,   1.7497361E-02,   2.0684492E-02,   2.4593996E-02
     +,   2.9282348E-02,   3.4652244E-02,   4.0302262E-02
     +,   4.5565795E-02,   4.9968716E-02,   5.3751480E-02
     +,   5.7523910E-02,   6.1057214E-02,   6.2976778E-02
     +,   6.2274374E-02,   5.9517961E-02,   5.6085877E-02
     +,   5.2996632E-02,   5.0656218E-02,   4.8963238E-02
     +,   4.7526617E-02,   4.5920111E-02,   4.3775752E-02
     +,   4.0976111E-02,   3.7849948E-02,   3.4915294E-02
     +,   3.2401279E-02,   3.0168435E-02,   2.8047780E-02
     +,   2.6089432E-02,   2.4460407E-02,   2.3211585E-02
     +,   2.2195777E-02,   2.1173170E-02,   1.9967295E-02
     +,   1.8545147E-02,   1.6994908E-02,   1.5450388E-02
     +,   1.4024233E-02,   1.2778909E-02,   1.1728104E-02
     +,   1.0852254E-02,   1.0114700E-02,   9.4744600E-03
     +,   8.8946586E-03,   8.3473753E-03,   7.8152092E-03
     +,   7.2906874E-03,   6.7743319E-03,   6.2721842E-03
     +,   5.7932278E-03,   5.3469832E-03,   4.9414597E-03
     +,   4.5818826E-03,   4.2700022E-03,   4.0040342E-03
     +,   3.7792269E-03,   3.5887968E-03,   3.4249269E-03
     +,   3.2796909E-03,   3.1458181E-03,   3.0171496E-03
     +,   2.8888788E-03,   2.7576005E-03,   2.6212633E-03
     +,   2.4790333E-03,   2.3311025E-03,   2.1784676E-03
     +,   2.0227146E-03,   1.8658072E-03,   1.7098542E-03
     +,   1.5569449E-03,   1.4090107E-03,   1.2677143E-03
     +,   1.1343758E-03,   1.0099574E-03,   8.9507370E-04
     +,   7.9000869E-04,   6.9475296E-04,   6.0906197E-04
     +,   5.3251511E-04,   4.6455790E-04,   4.0454726E-04
     +,   3.5179546E-04,   3.0560861E-04,   2.6529870E-04
     +,   2.3021054E-04,   1.9973364E-04,   1.7330740E-04
     +,   1.5042257E-04,   1.3062381E-04,   1.1350880E-04
     +,   9.8722950E-05,   8.5954649E-05,   7.4932228E-05
     +,   6.5420129E-05,   5.7212441E-05,   5.0131421E-05
     +,   4.4021868E-05,   3.8749949E-05,   3.4198954E-05
     +,   3.0268357E-05,   2.6870644E-05,   2.3930612E-05
     +,   2.1382999E-05,   1.9171970E-05,   1.7249295E-05
     +,   1.5573662E-05,   1.4109873E-05,   1.2827679E-05
     +,   1.1701443E-05,   1.0709196E-05,   9.8323490E-06
     +,   9.0549693E-06,   8.3635869E-06,   7.7466257E-06
     +,   7.1942782E-06,   6.6980811E-06,   6.2508443E-06
     +,   5.8463306E-06,   5.4792154E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_htt95 = Yx/0.43694
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4054609E-06,   4.6135465E-06
     +,   4.8292050E-06,   5.0526619E-06,   5.2841583E-06
     +,   5.5239502E-06,   5.7723128E-06,   6.0295365E-06
     +,   6.2959334E-06,   6.5718491E-06,   6.8576401E-06
     +,   7.1536988E-06,   7.4604427E-06,   7.7783243E-06
     +,   8.1078288E-06,   8.4494750E-06,   8.8038223E-06
     +,   9.1714674E-06,   9.5530495E-06,   9.9492490E-06
     +,   1.0360789E-05,   1.0788438E-05,   1.1233000E-05
     +,   1.1695356E-05,   1.2176371E-05,   1.2677014E-05
     +,   1.3198258E-05,   1.3741121E-05,   1.4306663E-05
     +,   1.4895964E-05,   1.5510137E-05,   1.6150316E-05
     +,   1.6817645E-05,   1.7513277E-05,   1.8238363E-05
     +,   1.8994042E-05,   1.9781437E-05,   2.0601623E-05
     +,   2.1455700E-05,   2.2344604E-05,   2.3269316E-05
     +,   2.4230680E-05,   2.5229485E-05,   2.6266394E-05
     +,   2.7341979E-05,   2.8456700E-05,   2.9610870E-05
     +,   3.0804691E-05,   3.2038202E-05,   3.3311306E-05
     +,   3.4623754E-05,   3.5975158E-05,   3.7364956E-05
     +,   3.8792539E-05,   4.0257008E-05,   4.1757496E-05
     +,   4.3292970E-05,   4.4862303E-05,   4.6464334E-05
     +,   4.8097852E-05,   4.9761638E-05,   5.1454550E-05
     +,   5.3175358E-05,   5.4923079E-05,   5.6696877E-05
     +,   5.8495909E-05,   6.0319770E-05,   6.2168067E-05
     +,   6.4040920E-05,   6.5938519E-05,   6.7861649E-05
     +,   6.9811183E-05,   7.1788651E-05,   7.3795687E-05
     +,   7.5834534E-05,   7.7907760E-05,   8.0018232E-05
     +,   8.2169063E-05,   8.4363841E-05,   8.6606378E-05
     +,   8.8900415E-05,   9.1250178E-05,   9.3659510E-05
     +,   9.6132593E-05,   9.8673147E-05,   1.0128490E-04
     +,   1.0397101E-04,   1.0673451E-04,   1.0957768E-04
     +,   1.1250240E-04,   1.1551003E-04,   1.1860102E-04
     +,   1.2177527E-04,   1.2503212E-04,   1.2837035E-04
     +,   1.3178785E-04,   1.3528251E-04,   1.3885142E-04
     +,   1.4249198E-04,   1.4620107E-04,   1.4997623E-04
     +,   1.5381504E-04,   1.5771590E-04,   1.6167789E-04
     +,   1.6570138E-04,   1.6978793E-04,   1.7394037E-04
     +,   1.7816301E-04,   1.8246211E-04,   1.8684553E-04
     +,   1.9132253E-04,   1.9590415E-04,   2.0060244E-04
     +,   2.0543116E-04,   2.1040421E-04,   2.1553649E-04
     +,   2.2084259E-04,   2.2633713E-04,   2.3203339E-04
     +,   2.3794423E-04,   2.4408064E-04,   2.5045188E-04
     +,   2.5706473E-04,   2.6392489E-04,   2.7103565E-04
     +,   2.7839805E-04,   2.8601280E-04,   2.9387866E-04
     +,   3.0199523E-04,   3.1036197E-04,   3.1898095E-04
     +,   3.2785561E-04,   3.3699462E-04,   3.4640994E-04
     +,   3.5612064E-04,   3.6615189E-04,   3.7653607E-04
     +,   3.8731308E-04,   3.9853135E-04,   4.1024663E-04
     +,   4.2252082E-04,   4.3542116E-04,   4.4901879E-04
     +,   4.6338656E-04,   4.7859343E-04,   4.9470429E-04
     +,   5.1177497E-04,   5.2984612E-04,   5.4893974E-04
     +,   5.6905672E-04,   5.9017033E-04,   6.1222247E-04
     +,   6.3512009E-04,   6.5873587E-04,   6.8290677E-04
     +,   7.0743146E-04,   7.3207577E-04,   7.5657869E-04
     +,   7.8065583E-04,   8.0400583E-04,   8.2632579E-04
     +,   8.4731897E-04,   8.6670375E-04,   8.8423124E-04
     +,   8.9969480E-04,   9.1294217E-04,   9.2388119E-04
     +,   9.3248958E-04,   9.3881815E-04,   9.4298960E-04
     +,   9.4519724E-04,   9.4570243E-04,   9.4483304E-04
     +,   9.4298914E-04,   9.4065518E-04,   9.3842857E-04
     +,   9.3706441E-04,   9.3753397E-04,   9.4110006E-04
     +,   9.4939524E-04,   9.6448581E-04,   9.8890858E-04
     +,   1.0256560E-03,   1.0780934E-03,   1.1498017E-03
     +,   1.2443388E-03,   1.3649735E-03,   1.5144194E-03
     +,   1.6945903E-03,   1.9063749E-03,   2.1495116E-03
     +,   2.4224499E-03,   2.7224084E-03,   3.0459589E-03
     +,   3.3905022E-03,   3.7567350E-03,   4.1515338E-03
     +,   4.5899265E-03,   5.0945021E-03,   5.6915083E-03
     +,   6.4044846E-03,   7.2472091E-03,   8.2174549E-03
     +,   9.2936773E-03,   1.0438306E-02,   1.1611193E-02
     +,   1.2786614E-02,   1.3958639E-02,   1.5127013E-02
     +,   1.6279906E-02,   1.7393945E-02,   1.8440820E-02
     +,   1.9373994E-02,   2.0112410E-02,   2.0572213E-02
     +,   2.0733733E-02,   2.0643586E-02,   2.0317934E-02
     +,   1.9673720E-02,   1.8619463E-02,   1.7226616E-02
     +,   1.5771592E-02,   1.4574159E-02,   1.3779701E-02
     +,   1.3278958E-02,   1.2814029E-02,   1.2160183E-02
     +,   1.1240506E-02,   1.0118946E-02,   8.9228712E-03
     +,   7.7729025E-03,   6.7535946E-03,   5.9117144E-03
     +,   5.2605676E-03,   4.7837300E-03,   4.4416562E-03
     +,   4.1836854E-03,   3.9616683E-03,   3.7402387E-03
     +,   3.5009549E-03,   3.2407111E-03,   2.9667625E-03
     +,   2.6908992E-03,   2.4246874E-03,   2.1766187E-03
     +,   1.9511604E-03,   1.7491486E-03,   1.5689412E-03
     +,   1.4077241E-03,   1.2625557E-03,   1.1309526E-03
     +,   1.0111089E-03,   9.0183411E-04,   8.0233830E-04
     +,   7.1200961E-04,   6.3026953E-04,   5.5649958E-04
     +,   4.9002992E-04,   4.3016844E-04,   3.7625415E-04
     +,   3.2769790E-04,   2.8399858E-04,   2.4474305E-04
     +,   2.0959594E-04,   1.7828125E-04,   1.5055313E-04
     +,   1.2618025E-04,   1.0493326E-04,   8.6575157E-05
     +,   7.0858638E-05,   5.7529833E-05,   4.6333491E-05
     +,   3.7017606E-05,   2.9338644E-05,   2.3067319E-05
     +,   1.7992643E-05,   1.3922941E-05,   1.0688403E-05
     +,   8.1400822E-06,   6.1500477E-06,   4.6093746E-06
     +,   3.4269915E-06,   2.5273564E-06,   1.8488153E-06
     +,   1.3414275E-06,   9.6533813E-07,   6.8898322E-07
     +,   4.8767942E-07,   3.4233605E-07,   2.3830923E-07
     +,   1.6451216E-07,   1.1261701E-07,   7.6447158E-08
     +,   5.1457814E-08,   3.4346215E-08,   2.2731417E-08
     +,   1.4917630E-08,   9.7069179E-09,   6.2629244E-09
     +,   4.0065316E-09,   2.5413343E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz100 = Yx/0.143093023255814
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0284486E-05,   3.0674299E-05
     +,   3.1038628E-05,   3.1376727E-05,   3.1687930E-05
     +,   3.1971696E-05,   3.2227570E-05,   3.2455217E-05
     +,   3.2654410E-05,   3.2825050E-05,   3.2967124E-05
     +,   3.3080760E-05,   3.3166201E-05,   3.3223780E-05
     +,   3.3253978E-05,   3.3257355E-05,   3.3234595E-05
     +,   3.3186479E-05,   3.3113891E-05,   3.3017815E-05
     +,   3.2899305E-05,   3.2759504E-05,   3.2599663E-05
     +,   3.2421049E-05,   3.2225031E-05,   3.2013024E-05
     +,   3.1786491E-05,   3.1546926E-05,   3.1295869E-05
     +,   3.1034881E-05,   3.0765543E-05,   3.0489435E-05
     +,   3.0208155E-05,   2.9923289E-05,   2.9636411E-05
     +,   2.9349096E-05,   2.9062874E-05,   2.8779275E-05
     +,   2.8499766E-05,   2.8225826E-05,   2.7958857E-05
     +,   2.7700256E-05,   2.7451368E-05,   2.7213506E-05
     +,   2.6987960E-05,   2.6775970E-05,   2.6578780E-05
     +,   2.6397583E-05,   2.6233583E-05,   2.6087973E-05
     +,   2.5961952E-05,   2.5856742E-05,   2.5773585E-05
     +,   2.5713771E-05,   2.5678662E-05,   2.5669679E-05
     +,   2.5688345E-05,   2.5736297E-05,   2.5815298E-05
     +,   2.5927267E-05,   2.6074280E-05,   2.6258625E-05
     +,   2.6482767E-05,   2.6749429E-05,   2.7061571E-05
     +,   2.7422389E-05,   2.7835382E-05,   2.8304283E-05
     +,   2.8833167E-05,   2.9426328E-05,   3.0088409E-05
     +,   3.0824249E-05,   3.1639014E-05,   3.2538010E-05
     +,   3.3526791E-05,   3.4611108E-05,   3.5796722E-05
     +,   3.7089423E-05,   3.8495069E-05,   4.0019411E-05
     +,   4.1667870E-05,   4.3445776E-05,   4.5357858E-05
     +,   4.7408554E-05,   4.9601465E-05,   5.1939704E-05
     +,   5.4425258E-05,   5.7059427E-05,   5.9842074E-05
     +,   6.2772138E-05,   6.5847271E-05,   6.9063455E-05
     +,   7.2415234E-05,   7.5895798E-05,   7.9496735E-05
     +,   8.3207698E-05,   8.7017172E-05,   9.0911577E-05
     +,   9.4876275E-05,   9.8894758E-05,   1.0294958E-04
     +,   1.0702170E-04,   1.1109155E-04,   1.1513819E-04
     +,   1.1914052E-04,   1.2307710E-04,   1.2692614E-04
     +,   1.3066609E-04,   1.3427607E-04,   1.3773600E-04
     +,   1.4102663E-04,   1.4413036E-04,   1.4703095E-04
     +,   1.4971435E-04,   1.5216826E-04,   1.5438310E-04
     +,   1.5635147E-04,   1.5806887E-04,   1.5953327E-04
     +,   1.6074561E-04,   1.6170958E-04,   1.6243158E-04
     +,   1.6292061E-04,   1.6318838E-04,   1.6324889E-04
     +,   1.6311828E-04,   1.6281470E-04,   1.6235794E-04
     +,   1.6176917E-04,   1.6107065E-04,   1.6028540E-04
     +,   1.5943679E-04,   1.5854828E-04,   1.5764320E-04
     +,   1.5674415E-04,   1.5587299E-04,   1.5505032E-04
     +,   1.5429535E-04,   1.5362570E-04,   1.5305703E-04
     +,   1.5260302E-04,   1.5227524E-04,   1.5208298E-04
     +,   1.5203314E-04,   1.5213041E-04,   1.5237714E-04
     +,   1.5277330E-04,   1.5331694E-04,   1.5400386E-04
     +,   1.5482816E-04,   1.5578223E-04,   1.5685709E-04
     +,   1.5804256E-04,   1.5932776E-04,   1.6070137E-04
     +,   1.6215201E-04,   1.6366868E-04,   1.6524158E-04
     +,   1.6686248E-04,   1.6852553E-04,   1.7022841E-04
     +,   1.7197293E-04,   1.7376660E-04,   1.7562399E-04
     +,   1.7756845E-04,   1.7963434E-04,   1.8186844E-04
     +,   1.8433320E-04,   1.8710888E-04,   1.9029630E-04
     +,   1.9401906E-04,   1.9842594E-04,   2.0369257E-04
     +,   2.1002231E-04,   2.1764528E-04,   2.2681683E-04
     +,   2.3781450E-04,   2.5093046E-04,   2.6646370E-04
     +,   2.8471134E-04,   3.0595466E-04,   3.3044323E-04
     +,   3.5838044E-04,   3.8990905E-04,   4.2509538E-04
     +,   4.6391296E-04,   5.0623436E-04,   5.5182824E-04
     +,   6.0035830E-04,   6.5138424E-04,   7.0438581E-04
     +,   7.5878174E-04,   8.1395591E-04,   8.6930202E-04
     +,   9.2427252E-04,   9.7843225E-04,   1.0315115E-03
     +,   1.0834718E-03,   1.1345610E-03,   1.1853486E-03
     +,   1.2367286E-03,   1.2898961E-03,   1.3462816E-03
     +,   1.4074523E-03,   1.4750343E-03,   1.5507258E-03
     +,   1.6364307E-03,   1.7345618E-03,   1.8484545E-03
     +,   1.9827385E-03,   2.1433826E-03,   2.3371992E-03
     +,   2.5707821E-03,   2.8491549E-03,   3.1747639E-03
     +,   3.5475476E-03,   3.9662812E-03,   4.4301907E-03
     +,   4.9390765E-03,   5.4915296E-03,   6.0845744E-03
     +,   6.7191012E-03,   7.4108350E-03,   8.1951600E-03
     +,   9.1104014E-03,   1.0162394E-02,   1.1303277E-02
     +,   1.2462739E-02,   1.3624201E-02,   1.4877242E-02
     +,   1.6371692E-02,   1.8176494E-02,   2.0141812E-02
     +,   2.1884274E-02,   2.2939663E-02,   2.3014545E-02
     +,   2.2179965E-02,   2.0852042E-02,   1.9533213E-02
     +,   1.8500149E-02,   1.7700879E-02,   1.6926838E-02
     +,   1.6056141E-02,   1.5128868E-02,   1.4232362E-02
     +,   1.3366270E-02,   1.2431276E-02,   1.1326091E-02
     +,   1.0038652E-02,   8.6543253E-03,   7.2969627E-03
     +,   6.0654292E-03,   5.0061145E-03,   4.1202041E-03
     +,   3.3850053E-03,   2.7724598E-03,   2.2589003E-03
     +,   1.8275521E-03,   1.4671107E-03,   1.1692635E-03
     +,   9.2668482E-04,   7.3204323E-04,   5.7790102E-04
     +,   4.5705715E-04,   3.6292782E-04,   2.8977307E-04
     +,   2.3281168E-04,   1.8820568E-04,   1.5296825E-04
     +,   1.2483762E-04,   1.0214200E-04,   8.3664148E-05
     +,   6.8518973E-05,   5.6054923E-05,   4.5781238E-05
     +,   3.7316793E-05,   3.0353902E-05,   2.4639472E-05
     +,   1.9960575E-05,   1.6138274E-05,   1.3021395E-05
     +,   1.0483754E-05,   8.4201110E-06,   6.7438932E-06
     +,   5.3838735E-06,   4.2820589E-06,   3.3910819E-06
     +,   2.6723728E-06,   2.0945222E-06,   1.6317466E-06
     +,   1.2629308E-06,   9.7061775E-07,   7.4041918E-07
     +,   5.6039403E-07,   4.2068621E-07,   3.1314121E-07
     +,   2.3106973E-07,   1.6899372E-07,   1.2247864E-07
     +,   8.7951733E-08,   6.2572795E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz105 = Yx/0.131166666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3463887E-05,   1.4292503E-05
     +,   1.5158468E-05,   1.6062320E-05,   1.7004511E-05
     +,   1.7985400E-05,   1.9005251E-05,   2.0064223E-05
     +,   2.1162370E-05,   2.2299668E-05,   2.3475954E-05
     +,   2.4690948E-05,   2.5944271E-05,   2.7235423E-05
     +,   2.8563789E-05,   2.9928649E-05,   3.1329168E-05
     +,   3.2764401E-05,   3.4233315E-05,   3.5734760E-05
     +,   3.7267506E-05,   3.8830251E-05,   4.0421564E-05
     +,   4.2040083E-05,   4.3684169E-05,   4.5352353E-05
     +,   4.7042991E-05,   4.8754460E-05,   5.0485109E-05
     +,   5.2233270E-05,   5.3997290E-05,   5.5775516E-05
     +,   5.7566318E-05,   5.9368089E-05,   6.1179264E-05
     +,   6.2998333E-05,   6.4823776E-05,   6.6654175E-05
     +,   6.8488233E-05,   7.0324495E-05,   7.2161791E-05
     +,   7.3998883E-05,   7.5834585E-05,   7.7667806E-05
     +,   7.9497462E-05,   8.1322498E-05,   8.3141924E-05
     +,   8.4954721E-05,   8.6759886E-05,   8.8556466E-05
     +,   9.0343456E-05,   9.2119844E-05,   9.3884511E-05
     +,   9.5636547E-05,   9.7374694E-05,   9.9097910E-05
     +,   1.0080494E-04,   1.0249454E-04,   1.0416546E-04
     +,   1.0581635E-04,   1.0744589E-04,   1.0905275E-04
     +,   1.1063547E-04,   1.1219276E-04,   1.1372341E-04
     +,   1.1522606E-04,   1.1669965E-04,   1.1814309E-04
     +,   1.1955559E-04,   1.2093648E-04,   1.2228529E-04
     +,   1.2360186E-04,   1.2488638E-04,   1.2613923E-04
     +,   1.2736133E-04,   1.2855389E-04,   1.2971865E-04
     +,   1.3085765E-04,   1.3197355E-04,   1.3306948E-04
     +,   1.3414891E-04,   1.3521608E-04,   1.3627535E-04
     +,   1.3733182E-04,   1.3839087E-04,   1.3945829E-04
     +,   1.4054023E-04,   1.4164316E-04,   1.4277364E-04
     +,   1.4393852E-04,   1.4514459E-04,   1.4639867E-04
     +,   1.4770743E-04,   1.4907736E-04,   1.5051471E-04
     +,   1.5202515E-04,   1.5361399E-04,   1.5528587E-04
     +,   1.5704479E-04,   1.5889393E-04,   1.6083574E-04
     +,   1.6287163E-04,   1.6500225E-04,   1.6722691E-04
     +,   1.6954429E-04,   1.7195188E-04,   1.7444610E-04
     +,   1.7702229E-04,   1.7967491E-04,   1.8239761E-04
     +,   1.8518283E-04,   1.8802240E-04,   1.9090717E-04
     +,   1.9382754E-04,   1.9677315E-04,   1.9973329E-04
     +,   2.0269645E-04,   2.0565138E-04,   2.0858592E-04
     +,   2.1148819E-04,   2.1434616E-04,   2.1714774E-04
     +,   2.1988072E-04,   2.2253320E-04,   2.2509365E-04
     +,   2.2755028E-04,   2.2989196E-04,   2.3210754E-04
     +,   2.3418655E-04,   2.3611862E-04,   2.3789384E-04
     +,   2.3950274E-04,   2.4093637E-04,   2.4218608E-04
     +,   2.4324395E-04,   2.4410269E-04,   2.4475553E-04
     +,   2.4519645E-04,   2.4542038E-04,   2.4542291E-04
     +,   2.4520091E-04,   2.4475230E-04,   2.4407606E-04
     +,   2.4317285E-04,   2.4204463E-04,   2.4069510E-04
     +,   2.3912975E-04,   2.3735593E-04,   2.3538322E-04
     +,   2.3322321E-04,   2.3088984E-04,   2.2839956E-04
     +,   2.2577138E-04,   2.2302668E-04,   2.2018969E-04
     +,   2.1728728E-04,   2.1434917E-04,   2.1140763E-04
     +,   2.0849753E-04,   2.0565670E-04,   2.0292526E-04
     +,   2.0034569E-04,   1.9796296E-04,   1.9582409E-04
     +,   1.9397777E-04,   1.9247434E-04,   1.9136549E-04
     +,   1.9070385E-04,   1.9054237E-04,   1.9093421E-04
     +,   1.9193198E-04,   1.9358724E-04,   1.9594999E-04
     +,   1.9906803E-04,   2.0298592E-04,   2.0774464E-04
     +,   2.1338099E-04,   2.1992621E-04,   2.2740549E-04
     +,   2.3583813E-04,   2.4523685E-04,   2.5560625E-04
     +,   2.6694391E-04,   2.7924121E-04,   2.9248328E-04
     +,   3.0664940E-04,   3.2171520E-04,   3.3765586E-04
     +,   3.5444825E-04,   3.7207277E-04,   3.9052125E-04
     +,   4.0980070E-04,   4.2993898E-04,   4.5099269E-04
     +,   4.7305838E-04,   4.9627910E-04,   5.2085437E-04
     +,   5.4704852E-04,   5.7520246E-04,   6.0573802E-04
     +,   6.3915987E-04,   6.7605864E-04,   7.1711332E-04
     +,   7.6308689E-04,   8.1481616E-04,   8.7321311E-04
     +,   9.3924941E-04,   1.0139247E-03,   1.0982309E-03
     +,   1.1930898E-03,   1.2992606E-03,   1.4172164E-03
     +,   1.5470253E-03,   1.6882422E-03,   1.8398272E-03
     +,   2.0001365E-03,   2.1670852E-03,   2.3385368E-03
     +,   2.5130247E-03,   2.6908615E-03,   2.8756659E-03
     +,   3.0759049E-03,   3.3059395E-03,   3.5857819E-03
     +,   3.9386861E-03,   4.3860930E-03,   4.9406150E-03
     +,   5.5993572E-03,   6.3413060E-03,   7.1320161E-03
     +,   7.9358043E-03,   8.7308595E-03,   9.5192101E-03
     +,   1.0325852E-02,   1.1188161E-02,   1.2141374E-02
     +,   1.3204386E-02,   1.4366829E-02,   1.5580516E-02
     +,   1.6762910E-02,   1.7820148E-02,   1.8685495E-02
     +,   1.9350363E-02,   1.9859144E-02,   2.0259446E-02
     +,   2.0537585E-02,   2.0593580E-02,   2.0285513E-02
     +,   1.9515822E-02,   1.8293777E-02,   1.6729521E-02
     +,   1.4974793E-02,   1.3162033E-02,   1.1378775E-02
     +,   9.6760169E-03,   8.0868639E-03,   6.6372612E-03
     +,   5.3471532E-03,   4.2284383E-03,   3.2840655E-03
     +,   2.5084796E-03,   1.8887041E-03,   1.4060962E-03
     +,   1.0387996E-03,   7.6436775E-04,   5.6191412E-04
     +,   4.1356348E-04,   3.0499516E-04,   2.2530467E-04
     +,   1.6650118E-04,   1.2287502E-04,   9.0384528E-05
     +,   6.6150220E-05,   4.8088375E-05,   3.4665976E-05
     +,   2.4739875E-05,   1.7447799E-05,   1.2137978E-05
     +,   8.3141458E-06,   5.5979831E-06,   3.6993963E-06
     +,   2.3965579E-06,   1.5204230E-06,   9.4395574E-07
     +,   5.7320193E-07,   3.4032666E-07,   1.9752810E-07
     +,   1.1206828E-07,   6.2164013E-08,   3.3725506E-08
     +,   1.7910962E-08,   9.3255634E-09,   4.7737263E-09
     +,   2.4142763E-09,   1.2165946E-09,   6.1923944E-10
     +,   3.2484682E-10,   1.8002072E-10,   1.0772665E-10
     +,   7.0208929E-11,   4.9386290E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz107 = Yx/0.122585365853659
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9853574E-05,   2.0482021E-05
     +,   2.1124761E-05,   2.1782012E-05,   2.2454025E-05
     +,   2.3141063E-05,   2.3843386E-05,   2.4561306E-05
     +,   2.5295141E-05,   2.6045247E-05,   2.6811995E-05
     +,   2.7595777E-05,   2.8397011E-05,   2.9216160E-05
     +,   3.0053707E-05,   3.0910156E-05,   3.1786018E-05
     +,   3.2681859E-05,   3.3598270E-05,   3.4535842E-05
     +,   3.5495203E-05,   3.6476988E-05,   3.7481834E-05
     +,   3.8510472E-05,   3.9563489E-05,   4.0641607E-05
     +,   4.1745498E-05,   4.2875832E-05,   4.4033251E-05
     +,   4.5218410E-05,   4.6431909E-05,   4.7674359E-05
     +,   4.8946291E-05,   5.0248247E-05,   5.1580704E-05
     +,   5.2944077E-05,   5.4338765E-05,   5.5765035E-05
     +,   5.7223238E-05,   5.8713467E-05,   6.0235947E-05
     +,   6.1790699E-05,   6.3377745E-05,   6.4997010E-05
     +,   6.6648427E-05,   6.8331778E-05,   7.0046866E-05
     +,   7.1793394E-05,   7.3571100E-05,   7.5379612E-05
     +,   7.7218639E-05,   7.9087768E-05,   8.0986669E-05
     +,   8.2914979E-05,   8.4872445E-05,   8.6858752E-05
     +,   8.8873741E-05,   9.0917201E-05,   9.2989096E-05
     +,   9.5089476E-05,   9.7218428E-05,   9.9376201E-05
     +,   1.0156308E-04,   1.0377950E-04,   1.0602613E-04
     +,   1.0830357E-04,   1.1061264E-04,   1.1295404E-04
     +,   1.1532892E-04,   1.1773801E-04,   1.2018255E-04
     +,   1.2266340E-04,   1.2518169E-04,   1.2773815E-04
     +,   1.3033366E-04,   1.3296901E-04,   1.3564454E-04
     +,   1.3836035E-04,   1.4111650E-04,   1.4391262E-04
     +,   1.4674773E-04,   1.4962065E-04,   1.5252957E-04
     +,   1.5547227E-04,   1.5844569E-04,   1.6144653E-04
     +,   1.6447049E-04,   1.6751296E-04,   1.7056830E-04
     +,   1.7363041E-04,   1.7669256E-04,   1.7974719E-04
     +,   1.8278605E-04,   1.8580060E-04,   1.8878155E-04
     +,   1.9171908E-04,   1.9460310E-04,   1.9742292E-04
     +,   2.0016798E-04,   2.0282711E-04,   2.0538953E-04
     +,   2.0784400E-04,   2.1018001E-04,   2.1238679E-04
     +,   2.1445416E-04,   2.1637272E-04,   2.1813318E-04
     +,   2.1972717E-04,   2.2114722E-04,   2.2238668E-04
     +,   2.2343983E-04,   2.2430204E-04,   2.2496970E-04
     +,   2.2544053E-04,   2.2571333E-04,   2.2578795E-04
     +,   2.2566566E-04,   2.2534879E-04,   2.2484089E-04
     +,   2.2414653E-04,   2.2327142E-04,   2.2222225E-04
     +,   2.2100663E-04,   2.1963302E-04,   2.1811048E-04
     +,   2.1644903E-04,   2.1465887E-04,   2.1275091E-04
     +,   2.1073622E-04,   2.0862631E-04,   2.0643247E-04
     +,   2.0416644E-04,   2.0183956E-04,   1.9946319E-04
     +,   1.9704852E-04,   1.9460618E-04,   1.9214684E-04
     +,   1.8968068E-04,   1.8721732E-04,   1.8476590E-04
     +,   1.8233543E-04,   1.7993429E-04,   1.7757034E-04
     +,   1.7525110E-04,   1.7298372E-04,   1.7077508E-04
     +,   1.6863141E-04,   1.6655900E-04,   1.6456397E-04
     +,   1.6265200E-04,   1.6082883E-04,   1.5910012E-04
     +,   1.5747178E-04,   1.5594940E-04,   1.5453897E-04
     +,   1.5324673E-04,   1.5207902E-04,   1.5104271E-04
     +,   1.5014478E-04,   1.4939299E-04,   1.4879527E-04
     +,   1.4836038E-04,   1.4809756E-04,   1.4801683E-04
     +,   1.4812905E-04,   1.4844589E-04,   1.4898011E-04
     +,   1.4974548E-04,   1.5075725E-04,   1.5203202E-04
     +,   1.5358807E-04,   1.5544552E-04,   1.5762648E-04
     +,   1.6015560E-04,   1.6305962E-04,   1.6636812E-04
     +,   1.7011356E-04,   1.7433125E-04,   1.7905909E-04
     +,   1.8433839E-04,   1.9021325E-04,   1.9673028E-04
     +,   2.0393834E-04,   2.1188916E-04,   2.2063676E-04
     +,   2.3023700E-04,   2.4074766E-04,   2.5222998E-04
     +,   2.6474870E-04,   2.7837127E-04,   2.9317223E-04
     +,   3.0923358E-04,   3.2664533E-04,   3.4550886E-04
     +,   3.6594120E-04,   3.8807545E-04,   4.1206286E-04
     +,   4.3807525E-04,   4.6630963E-04,   4.9698824E-04
     +,   5.3035660E-04,   5.6668581E-04,   6.0627185E-04
     +,   6.4942759E-04,   6.9647020E-04,   7.4770983E-04
     +,   8.0342172E-04,   8.6380722E-04,   9.2895207E-04
     +,   9.9878013E-04,   1.0730010E-03,   1.1510690E-03
     +,   1.2321780E-03,   1.3153071E-03,   1.3993214E-03
     +,   1.4831565E-03,   1.5660947E-03,   1.6481170E-03
     +,   1.7302734E-03,   1.8150151E-03,   1.9064195E-03
     +,   2.0101534E-03,   2.1330991E-03,   2.2825969E-03
     +,   2.4653170E-03,   2.6859052E-03,   2.9455849E-03
     +,   3.2411332E-03,   3.5645128E-03,   3.9033210E-03
     +,   4.2421306E-03,   4.5645847E-03,   4.8559504E-03
     +,   5.1058899E-03,   5.3113722E-03,   5.4797614E-03
     +,   5.6310929E-03,   5.7979939E-03,   6.0210107E-03
     +,   6.3385856E-03,   6.7740758E-03,   7.3264032E-03
     +,   7.9716817E-03,   8.6785704E-03,   9.4309114E-03
     +,   1.0244194E-02,   1.1163134E-02,   1.2237743E-02
     +,   1.3488783E-02,   1.4880572E-02,   1.6315883E-02
     +,   1.7653164E-02,   1.8736273E-02,   1.9422989E-02
     +,   1.9604621E-02,   1.9217789E-02,   1.8254651E-02
     +,   1.6771063E-02,   1.4886784E-02,   1.2769681E-02
     +,   1.0604446E-02,   8.5550277E-03,   6.7361537E-03
     +,   5.2034552E-03,   3.9617354E-03,   2.9827340E-03
     +,   2.2238754E-03,   1.6415116E-03,   1.1975305E-03
     +,   8.6125353E-04,   6.0886482E-04,   4.2195324E-04
     +,   2.8601798E-04,   1.8935380E-04,   1.2236768E-04
     +,   7.7217832E-05,   4.7621732E-05,   2.8736094E-05
     +,   1.6981001E-05,   9.8302971E-06,   5.5721193E-06
     +,   3.0888382E-06,   1.6713381E-06,   8.8084789E-07
     +,   4.5118813E-07,   2.2423229E-07,   1.0802381E-07
     +,   5.0474807E-08,   2.2954053E-08,   1.0247726E-08
     +,   4.5754782E-09,   2.1139130E-09,   1.0625120E-09
     +,   6.0870381E-10,   4.0130249E-10,   2.9456690E-10
     +,   2.3017917E-10,   1.8533346E-10,   1.5107839E-10
     +,   1.2367497E-10,   1.0132546E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz110 = Yx/0.106024390243902
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4919412E-05,   4.5705710E-05
     +,   4.6501082E-05,   4.7306454E-05,   4.8122842E-05
     +,   4.8951359E-05,   4.9793172E-05,   5.0649578E-05
     +,   5.1521911E-05,   5.2411637E-05,   5.3320291E-05
     +,   5.4249482E-05,   5.5200919E-05,   5.6176374E-05
     +,   5.7177724E-05,   5.8206930E-05,   5.9265967E-05
     +,   6.0356986E-05,   6.1482104E-05,   6.2643550E-05
     +,   6.3843596E-05,   6.5084576E-05,   6.6368790E-05
     +,   6.7698755E-05,   6.9076777E-05,   7.0505332E-05
     +,   7.1986855E-05,   7.3523755E-05,   7.5118449E-05
     +,   7.6773307E-05,   7.8490652E-05,   8.0272745E-05
     +,   8.2121784E-05,   8.4039857E-05,   8.6028980E-05
     +,   8.8091059E-05,   9.0227804E-05,   9.2440787E-05
     +,   9.4731578E-05,   9.7101285E-05,   9.9551085E-05
     +,   1.0208182E-04,   1.0469418E-04,   1.0738857E-04
     +,   1.1016524E-04,   1.1302406E-04,   1.1596482E-04
     +,   1.1898702E-04,   1.2208983E-04,   1.2527230E-04
     +,   1.2853321E-04,   1.3187111E-04,   1.3528434E-04
     +,   1.3877120E-04,   1.4232958E-04,   1.4595762E-04
     +,   1.4965313E-04,   1.5341410E-04,   1.5723839E-04
     +,   1.6112407E-04,   1.6506948E-04,   1.6907312E-04
     +,   1.7313371E-04,   1.7725077E-04,   1.8142421E-04
     +,   1.8565428E-04,   1.8994250E-04,   1.9429071E-04
     +,   1.9870205E-04,   2.0318042E-04,   2.0773105E-04
     +,   2.1235997E-04,   2.1707488E-04,   2.2188411E-04
     +,   2.2679777E-04,   2.3182703E-04,   2.3698414E-04
     +,   2.4228191E-04,   2.4773492E-04,   2.5335810E-04
     +,   2.5916644E-04,   2.6517603E-04,   2.7140175E-04
     +,   2.7785948E-04,   2.8456296E-04,   2.9152588E-04
     +,   2.9875906E-04,   3.0627253E-04,   3.1407247E-04
     +,   3.2216305E-04,   3.3054454E-04,   3.3921350E-04
     +,   3.4816159E-04,   3.5737685E-04,   3.6684229E-04
     +,   3.7653538E-04,   3.8642934E-04,   3.9649146E-04
     +,   4.0668537E-04,   4.1696898E-04,   4.2729662E-04
     +,   4.3761844E-04,   4.4788231E-04,   4.5803210E-04
     +,   4.6801136E-04,   4.7776298E-04,   4.8722874E-04
     +,   4.9635174E-04,   5.0507800E-04,   5.1335571E-04
     +,   5.2113680E-04,   5.2837859E-04,   5.3504290E-04
     +,   5.4109847E-04,   5.4651999E-04,   5.5128994E-04
     +,   5.5539719E-04,   5.5883877E-04,   5.6161865E-04
     +,   5.6374789E-04,   5.6524429E-04,   5.6613219E-04
     +,   5.6644098E-04,   5.6620524E-04,   5.6546420E-04
     +,   5.6425889E-04,   5.6263385E-04,   5.6063459E-04
     +,   5.5830705E-04,   5.5569725E-04,   5.5284897E-04
     +,   5.4980564E-04,   5.4660643E-04,   5.4328906E-04
     +,   5.3988653E-04,   5.3642842E-04,   5.3294038E-04
     +,   5.2944425E-04,   5.2595703E-04,   5.2249240E-04
     +,   5.1906001E-04,   5.1566656E-04,   5.1231531E-04
     +,   5.0900661E-04,   5.0573976E-04,   5.0251093E-04
     +,   4.9931585E-04,   4.9615005E-04,   4.9300812E-04
     +,   4.8988528E-04,   4.8677780E-04,   4.8368287E-04
     +,   4.8059961E-04,   4.7752907E-04,   4.7447468E-04
     +,   4.7144268E-04,   4.6844262E-04,   4.6548632E-04
     +,   4.6258984E-04,   4.5977259E-04,   4.5705753E-04
     +,   4.5447107E-04,   4.5204375E-04,   4.4980875E-04
     +,   4.4780358E-04,   4.4606786E-04,   4.4464431E-04
     +,   4.4357794E-04,   4.4291522E-04,   4.4270325E-04
     +,   4.4299004E-04,   4.4382227E-04,   4.4524507E-04
     +,   4.4730119E-04,   4.5002913E-04,   4.5346300E-04
     +,   4.5763107E-04,   4.6255437E-04,   4.6824658E-04
     +,   4.7471403E-04,   4.8195329E-04,   4.8995361E-04
     +,   4.9869518E-04,   5.0815206E-04,   5.1829213E-04
     +,   5.2907923E-04,   5.4047519E-04,   5.5244355E-04
     +,   5.6495401E-04,   5.7798234E-04,   5.9151993E-04
     +,   6.0557516E-04,   6.2017905E-04,   6.3539005E-04
     +,   6.5130077E-04,   6.6804053E-04,   6.8577938E-04
     +,   7.0473028E-04,   7.2515261E-04,   7.4734970E-04
     +,   7.7166234E-04,   7.9846440E-04,   8.2815188E-04
     +,   8.6112553E-04,   8.9776691E-04,   9.3842053E-04
     +,   9.8336220E-04,   1.0327675E-03,   1.0866849E-03
     +,   1.1450181E-03,   1.2075107E-03,   1.2737389E-03
     +,   1.3431371E-03,   1.4150378E-03,   1.4887271E-03
     +,   1.5635183E-03,   1.6388441E-03,   1.7143500E-03
     +,   1.7899806E-03,   1.8660243E-03,   1.9431603E-03
     +,   2.0224289E-03,   2.1051727E-03,   2.1929424E-03
     +,   2.2873774E-03,   2.3900764E-03,   2.5024852E-03
     +,   2.6258177E-03,   2.7610431E-03,   2.9088983E-03
     +,   3.0699102E-03,   3.2444934E-03,   3.4329705E-03
     +,   3.6356193E-03,   3.8526016E-03,   4.0839263E-03
     +,   4.3293536E-03,   4.5882505E-03,   4.8595266E-03
     +,   5.1415800E-03,   5.4322383E-03,   5.7287170E-03
     +,   6.0275863E-03,   6.3247345E-03,   6.6152113E-03
     +,   6.8931379E-03,   7.1516437E-03,   7.3829368E-03
     +,   7.5784796E-03,   7.7293841E-03,   7.8270184E-03
     +,   7.8636501E-03,   7.8330999E-03,   7.7313581E-03
     +,   7.5569432E-03,   7.3111076E-03,   6.9978437E-03
     +,   6.6236951E-03,   6.1973929E-03,   5.7294657E-03
     +,   5.2317940E-03,   4.7169700E-03,   4.1976883E-03
     +,   3.6861070E-03,   3.1933100E-03,   2.7286771E-03
     +,   2.2995663E-03,   1.9111247E-03,   1.5662566E-03
     +,   1.2657506E-03,   1.0086126E-03,   7.9244439E-04
     +,   6.1382534E-04,   4.6869769E-04,   3.5272274E-04
     +,   2.6156628E-04,   1.9108308E-04,   1.3748197E-04
     +,   9.7391094E-05,   6.7909255E-05,   4.6595716E-05
     +,   3.1453554E-05,   2.0882879E-05,   1.3634358E-05
     +,   8.7522449E-06,   5.5233249E-06,   3.4263269E-06
     +,   2.0891239E-06,   1.2519793E-06,   7.3738676E-07
     +,   4.2683394E-07,   2.4280510E-07,   1.3573472E-07
     +,   7.4562323E-08,   4.0246853E-08,   2.1343890E-08
     +,   1.1120325E-08,   5.6910139E-09,   2.8605325E-09
     +,   1.4118818E-09,   6.8420519E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz115 = Yx/0.0773589743589744
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8297525E-05,   2.9067432E-05
     +,   2.9869429E-05,   3.0705363E-05,   3.1577172E-05
     +,   3.2486823E-05,   3.3436329E-05,   3.4427743E-05
     +,   3.5463148E-05,   3.6544709E-05,   3.7674527E-05
     +,   3.8854803E-05,   4.0087696E-05,   4.1375395E-05
     +,   4.2720079E-05,   4.4123939E-05,   4.5589160E-05
     +,   4.7117901E-05,   4.8712333E-05,   5.0374583E-05
     +,   5.2106829E-05,   5.3911172E-05,   5.5789726E-05
     +,   5.7744710E-05,   5.9778162E-05,   6.1892344E-05
     +,   6.4089400E-05,   6.6371584E-05,   6.8741196E-05
     +,   7.1200615E-05,   7.3752322E-05,   7.6398872E-05
     +,   7.9142934E-05,   8.1987346E-05,   8.4935135E-05
     +,   8.7989385E-05,   9.1153481E-05,   9.4430776E-05
     +,   9.7825199E-05,   1.0134029E-04,   1.0498031E-04
     +,   1.0874937E-04,   1.1265171E-04,   1.1669177E-04
     +,   1.2087388E-04,   1.2520260E-04,   1.2968232E-04
     +,   1.3431713E-04,   1.3911122E-04,   1.4406833E-04
     +,   1.4919178E-04,   1.5448449E-04,   1.5994874E-04
     +,   1.6558624E-04,   1.7139767E-04,   1.7738318E-04
     +,   1.8354159E-04,   1.8987073E-04,   1.9636733E-04
     +,   2.0302692E-04,   2.0984357E-04,   2.1681045E-04
     +,   2.2391877E-04,   2.3115917E-04,   2.3852094E-04
     +,   2.4599186E-04,   2.5355953E-04,   2.6120953E-04
     +,   2.6892839E-04,   2.7670083E-04,   2.8451267E-04
     +,   2.9234905E-04,   3.0019641E-04,   3.0804137E-04
     +,   3.1587249E-04,   3.2367994E-04,   3.3145543E-04
     +,   3.3919339E-04,   3.4689117E-04,   3.5454909E-04
     +,   3.6217028E-04,   3.6976268E-04,   3.7733617E-04
     +,   3.8490604E-04,   3.9248972E-04,   4.0010992E-04
     +,   4.0779103E-04,   4.1556184E-04,   4.2345215E-04
     +,   4.3149540E-04,   4.3972593E-04,   4.4817780E-04
     +,   4.5688567E-04,   4.6588303E-04,   4.7520173E-04
     +,   4.8486970E-04,   4.9491221E-04,   5.0534838E-04
     +,   5.1619351E-04,   5.2745419E-04,   5.3913204E-04
     +,   5.5121927E-04,   5.6370138E-04,   5.7655369E-04
     +,   5.8974448E-04,   6.0323323E-04,   6.1697012E-04
     +,   6.3089718E-04,   6.4494996E-04,   6.5905676E-04
     +,   6.7313859E-04,   6.8711297E-04,   7.0089113E-04
     +,   7.1438256E-04,   7.2749320E-04,   7.4012874E-04
     +,   7.5219426E-04,   7.6359679E-04,   7.7424420E-04
     +,   7.8404904E-04,   7.9292787E-04,   8.0080243E-04
     +,   8.0760021E-04,   8.1325730E-04,   8.1771781E-04
     +,   8.2093308E-04,   8.2286622E-04,   8.2348945E-04
     +,   8.2278560E-04,   8.2074961E-04,   8.1738661E-04
     +,   8.1271451E-04,   8.0676179E-04,   7.9956913E-04
     +,   7.9118850E-04,   7.8168185E-04,   7.7112205E-04
     +,   7.5959187E-04,   7.4718037E-04,   7.3398545E-04
     +,   7.2011090E-04,   7.0566597E-04,   6.9076160E-04
     +,   6.7551178E-04,   6.6003110E-04,   6.4443215E-04
     +,   6.2882464E-04,   6.1331579E-04,   5.9800758E-04
     +,   5.8299431E-04,   5.6836236E-04,   5.5419182E-04
     +,   5.4055313E-04,   5.2750658E-04,   5.1510241E-04
     +,   5.0338265E-04,   4.9237814E-04,   4.8211013E-04
     +,   4.7259100E-04,   4.6382443E-04,   4.5580600E-04
     +,   4.4852315E-04,   4.4195828E-04,   4.3608740E-04
     +,   4.3088151E-04,   4.2630814E-04,   4.2233244E-04
     +,   4.1891733E-04,   4.1602534E-04,   4.1361831E-04
     +,   4.1165968E-04,   4.1011482E-04,   4.0895102E-04
     +,   4.0813905E-04,   4.0765342E-04,   4.0747263E-04
     +,   4.0757970E-04,   4.0796262E-04,   4.0861368E-04
     +,   4.0953048E-04,   4.1071457E-04,   4.1217200E-04
     +,   4.1391313E-04,   4.1595165E-04,   4.1830514E-04
     +,   4.2099360E-04,   4.2404054E-04,   4.2747243E-04
     +,   4.3132005E-04,   4.3561784E-04,   4.4040618E-04
     +,   4.4573238E-04,   4.5165341E-04,   4.5823719E-04
     +,   4.6556655E-04,   4.7374226E-04,   4.8288453E-04
     +,   4.9313752E-04,   5.0467148E-04,   5.1768404E-04
     +,   5.3240027E-04,   5.4907060E-04,   5.6797022E-04
     +,   5.8939087E-04,   6.1362993E-04,   6.4098329E-04
     +,   6.7172956E-04,   7.0610753E-04,   7.4430252E-04
     +,   7.8642712E-04,   8.3250011E-04,   8.8242668E-04
     +,   9.3598786E-04,   9.9284016E-04,   1.0525123E-03
     +,   1.1144143E-03,   1.1778647E-03,   1.2421234E-03
     +,   1.3064343E-03,   1.3700613E-03,   1.4323584E-03
     +,   1.4928094E-03,   1.5510713E-03,   1.6070136E-03
     +,   1.6607484E-03,   1.7126281E-03,   1.7632365E-03
     +,   1.8133649E-03,   1.8639779E-03,   1.9161518E-03
     +,   1.9710232E-03,   2.0297219E-03,   2.0933261E-03
     +,   2.1628025E-03,   2.2389479E-03,   2.3223714E-03
     +,   2.4134568E-03,   2.5123251E-03,   2.6188246E-03
     +,   2.7325116E-03,   2.8526359E-03,   2.9781132E-03
     +,   3.1075238E-03,   3.2391089E-03,   3.3707710E-03
     +,   3.5000867E-03,   3.6243442E-03,   3.7405919E-03
     +,   3.8457164E-03,   3.9365115E-03,   4.0098149E-03
     +,   4.0626158E-03,   4.0921839E-03,   4.0962240E-03
     +,   4.0729903E-03,   4.0214034E-03,   3.9411564E-03
     +,   3.8327645E-03,   3.6975800E-03,   3.5377650E-03
     +,   3.3562360E-03,   3.1565393E-03,   2.9426930E-03
     +,   2.7190065E-03,   2.4899235E-03,   2.2597832E-03
     +,   2.0326653E-03,   1.8122521E-03,   1.6016916E-03
     +,   1.4035087E-03,   1.2195846E-03,   1.0511695E-03
     +,   8.9890475E-04,   7.6288031E-04,   6.4272905E-04
     +,   5.3773070E-04,   4.4687963E-04,   3.6900464E-04
     +,   3.0282492E-04,   2.4703972E-04,   2.0036449E-04
     +,   1.6158594E-04,   1.2957626E-04,   1.0331909E-04
     +,   8.1907077E-05,   6.4548738E-05,   5.0557381E-05
     +,   3.9345632E-05,   3.0416077E-05,   2.3348410E-05
     +,   1.7791763E-05,   1.3453351E-05,   1.0091341E-05
     +,   7.5061798E-06,   5.5348696E-06,   4.0445561E-06
     +,   2.9281418E-06,   2.0996406E-06,   1.4908404E-06
     +,   1.0479553E-06,   7.2912286E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz120 = Yx/0.0561944444444444
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.3565818E-05,   6.0514722E-05
     +,   6.8453322E-05,   7.7520170E-05,   8.7865003E-05
     +,   9.9647288E-05,   1.1303432E-04,   1.2819875E-04
     +,   1.4531618E-04,   1.6456313E-04,   1.8611348E-04
     +,   2.1013757E-04,   2.3680076E-04,   2.6626303E-04
     +,   2.9868021E-04,   3.3420481E-04,   3.7298969E-04
     +,   4.1519068E-04,   4.6096847E-04,   5.1049306E-04
     +,   5.6394283E-04,   6.2150427E-04,   6.8336737E-04
     +,   7.4972340E-04,   8.2074350E-04,   8.9658168E-04
     +,   9.7734458E-04,   1.0630833E-03,   1.1537734E-03
     +,   1.2492954E-03,   1.3494225E-03,   1.4538051E-03
     +,   1.5619649E-03,   1.6732833E-03,   1.7870046E-03
     +,   1.9022333E-03,   2.0179411E-03,   2.1329741E-03
     +,   2.2460676E-03,   2.3558494E-03,   2.4608823E-03
     +,   2.5596712E-03,   2.6507040E-03,   2.7324928E-03
     +,   2.8036193E-03,   2.8627953E-03,   2.9089081E-03
     +,   2.9410955E-03,   2.9587809E-03,   2.9617359E-03
     +,   2.9500960E-03,   2.9243832E-03,   2.8854834E-03
     +,   2.8346279E-03,   2.7733315E-03,   2.7033202E-03
     +,   2.6264396E-03,   2.5445786E-03,   2.4595533E-03
     +,   2.3730390E-03,   2.2864952E-03,   2.2011120E-03
     +,   2.1177831E-03,   2.0370972E-03,   1.9593614E-03
     +,   1.8846383E-03,   1.8127826E-03,   1.7435193E-03
     +,   1.6764840E-03,   1.6112999E-03,   1.5476118E-03
     +,   1.4851389E-03,   1.4236908E-03,   1.3631914E-03
     +,   1.3036696E-03,   1.2452541E-03,   1.1881638E-03
     +,   1.1326732E-03,   1.0790941E-03,   1.0277451E-03
     +,   9.7893761E-04,   9.3294436E-04,   8.8999729E-04
     +,   8.5026363E-04,   8.1385579E-04,   7.8081538E-04
     +,   7.5113174E-04,   7.2473491E-04,   7.0151559E-04
     +,   6.8132672E-04,   6.6399766E-04,   6.4934639E-04
     +,   6.3718477E-04,   6.2732951E-04,   6.1960833E-04
     +,   6.1386474E-04,   6.0996157E-04,   6.0778274E-04
     +,   6.0723233E-04,   6.0823339E-04,   6.1072555E-04
     +,   6.1466085E-04,   6.2000053E-04,   6.2670920E-04
     +,   6.3475250E-04,   6.4409157E-04,   6.5467955E-04
     +,   6.6645909E-04,   6.7936082E-04,   6.9330062E-04
     +,   7.0817943E-04,   7.2388590E-04,   7.4029167E-04
     +,   7.5726060E-04,   7.7464455E-04,   7.9229026E-04
     +,   8.1003871E-04,   8.2773273E-04,   8.4521505E-04
     +,   8.6233555E-04,   8.7895250E-04,   8.9493417E-04
     +,   9.1016281E-04,   9.2453568E-04,   9.3796832E-04
     +,   9.5039082E-04,   9.6175371E-04,   9.7202533E-04
     +,   9.8118931E-04,   9.8924711E-04,   9.9621504E-04
     +,   1.0021211E-03,   1.0070042E-03,   1.0109114E-03
     +,   1.0138951E-03,   1.0160108E-03,   1.0173139E-03
     +,   1.0178572E-03,   1.0176899E-03,   1.0168545E-03
     +,   1.0153861E-03,   1.0133098E-03,   1.0106429E-03
     +,   1.0073917E-03,   1.0035555E-03,   9.9912449E-04
     +,   9.9408149E-04,   9.8840566E-04,   9.8207360E-04
     +,   9.7506033E-04,   9.6734235E-04,   9.5890136E-04
     +,   9.4972359E-04,   9.3980372E-04,   9.2914456E-04
     +,   9.1775990E-04,   9.0567389E-04,   8.9292147E-04
     +,   8.7954570E-04,   8.6560176E-04,   8.5114996E-04
     +,   8.3625753E-04,   8.2099577E-04,   8.0543885E-04
     +,   7.8965892E-04,   7.7372737E-04,   7.5771153E-04
     +,   7.4167445E-04,   7.2567083E-04,   7.0974929E-04
     +,   6.9395045E-04,   6.7830813E-04,   6.6284725E-04
     +,   6.4758648E-04,   6.3253951E-04,   6.1771349E-04
     +,   6.0311210E-04,   5.8873685E-04,   5.7458808E-04
     +,   5.6066440E-04,   5.4696487E-04,   5.3349085E-04
     +,   5.2024476E-04,   5.0723040E-04,   4.9445435E-04
     +,   4.8192590E-04,   4.6965666E-04,   4.5765887E-04
     +,   4.4594664E-04,   4.3453622E-04,   4.2344318E-04
     +,   4.1268341E-04,   4.0227204E-04,   3.9222388E-04
     +,   3.8255093E-04,   3.7326332E-04,   3.6436925E-04
     +,   3.5587448E-04,   3.4778059E-04,   3.4008644E-04
     +,   3.3278807E-04,   3.2587847E-04,   3.1934644E-04
     +,   3.1317840E-04,   3.0735836E-04,   3.0186708E-04
     +,   2.9668331E-04,   2.9178403E-04,   2.8714479E-04
     +,   2.8273958E-04,   2.7854159E-04,   2.7452395E-04
     +,   2.7065960E-04,   2.6692168E-04,   2.6328390E-04
     +,   2.5972127E-04,   2.5620987E-04,   2.5272707E-04
     +,   2.4925216E-04,   2.4576631E-04,   2.4225253E-04
     +,   2.3869585E-04,   2.3508372E-04,   2.3140569E-04
     +,   2.2765342E-04,   2.2382045E-04,   2.1990300E-04
     +,   2.1589889E-04,   2.1180771E-04,   2.0763086E-04
     +,   2.0337157E-04,   1.9903462E-04,   1.9462575E-04
     +,   1.9015164E-04,   1.8562078E-04,   1.8104172E-04
     +,   1.7642368E-04,   1.7177686E-04,   1.6711155E-04
     +,   1.6243810E-04,   1.5776680E-04,   1.5310822E-04
     +,   1.4847273E-04,   1.4387009E-04,   1.3930963E-04
     +,   1.3480060E-04,   1.3035172E-04,   1.2597069E-04
     +,   1.2166471E-04,   1.1744073E-04,   1.1330449E-04
     +,   1.0926115E-04,   1.0531535E-04,   1.0147112E-04
     +,   9.7731448E-05,   9.4098694E-05,   9.0574860E-05
     +,   8.7161272E-05,   8.3858504E-05,   8.0666534E-05
     +,   7.7585129E-05,   7.4613541E-05,   7.1750386E-05
     +,   6.8993984E-05,   6.6342531E-05,   6.3793712E-05
     +,   6.1344952E-05,   5.8993635E-05,   5.6736983E-05
     +,   5.4571905E-05,   5.2495241E-05,   5.0503910E-05
     +,   4.8594753E-05,   4.6764497E-05,   4.5009874E-05
     +,   4.3327822E-05,   4.1715099E-05,   4.0168758E-05
     +,   3.8685703E-05,   3.7263144E-05,   3.5898185E-05
     +,   3.4588207E-05,   3.3330562E-05,   3.2122840E-05
     +,   3.0962616E-05,   2.9847724E-05,   2.8775996E-05
     +,   2.7745387E-05,   2.6754054E-05,   2.5800144E-05
     +,   2.4882014E-05,   2.3998024E-05,   2.3146720E-05
     +,   2.2326645E-05,   2.1536518E-05,   2.0775044E-05
     +,   2.0041103E-05,   1.9333542E-05,   1.8651363E-05
     +,   1.7993543E-05,   1.7359202E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz60 = Yx/0.0521111111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0747904E-05,   9.3677547E-05
     +,   9.6636570E-05,   9.9626937E-05,   1.0265120E-04
     +,   1.0571239E-04,   1.0881434E-04,   1.1196167E-04
     +,   1.1515997E-04,   1.1841638E-04,   1.2173964E-04
     +,   1.2514071E-04,   1.2863353E-04,   1.3223555E-04
     +,   1.3596874E-04,   1.3986045E-04,   1.4394465E-04
     +,   1.4826302E-04,   1.5286621E-04,   1.5781542E-04
     +,   1.6318359E-04,   1.6905715E-04,   1.7553737E-04
     +,   1.8274249E-04,   1.9080818E-04,   1.9989103E-04
     +,   2.1016866E-04,   2.2184184E-04,   2.3513610E-04
     +,   2.5030266E-04,   2.6761930E-04,   2.8739139E-04
     +,   3.0995149E-04,   3.3565983E-04,   3.6490397E-04
     +,   3.9809741E-04,   4.3568097E-04,   4.7811907E-04
     +,   5.2590383E-04,   5.7954399E-04,   6.3957111E-04
     +,   7.0652645E-04,   7.8095507E-04,   8.6339796E-04
     +,   9.5438550E-04,   1.0544366E-03,   1.1640765E-03
     +,   1.2838668E-03,   1.4144665E-03,   1.5567133E-03
     +,   1.7117137E-03,   1.8809132E-03,   2.0661277E-03
     +,   2.2694736E-03,   2.4931354E-03,   2.7390546E-03
     +,   3.0083789E-03,   3.3008936E-03,   3.6144250E-03
     +,   3.9443979E-03,   4.2836256E-03,   4.6224934E-03
     +,   4.9495003E-03,   5.2522551E-03,   5.5186339E-03
     +,   5.7380274E-03,   5.9025474E-03,   6.0077454E-03
     +,   6.0529844E-03,   6.0411519E-03,   5.9779854E-03
     +,   5.8709597E-03,   5.7280585E-03,   5.5567445E-03
     +,   5.3631775E-03,   5.1519345E-03,   4.9262517E-03
     +,   4.6885526E-03,   4.4411370E-03,   4.1868496E-03
     +,   3.9294758E-03,   3.6737279E-03,   3.4249856E-03
     +,   3.1887009E-03,   2.9698389E-03,   2.7722537E-03
     +,   2.5983937E-03,   2.4491064E-03,   2.3237742E-03
     +,   2.2205370E-03,   2.1366412E-03,   2.0688206E-03
     +,   2.0136202E-03,   1.9676758E-03,   1.9279305E-03
     +,   1.8917947E-03,   1.8572356E-03,   1.8228292E-03
     +,   1.7877746E-03,   1.7518570E-03,   1.7153731E-03
     +,   1.6790332E-03,   1.6438296E-03,   1.6108978E-03
     +,   1.5813754E-03,   1.5562763E-03,   1.5364030E-03
     +,   1.5222701E-03,   1.5140781E-03,   1.5117261E-03
     +,   1.5148286E-03,   1.5227785E-03,   1.5348103E-03
     +,   1.5500610E-03,   1.5676371E-03,   1.5866697E-03
     +,   1.6063561E-03,   1.6259942E-03,   1.6449902E-03
     +,   1.6628760E-03,   1.6792953E-03,   1.6939930E-03
     +,   1.7068008E-03,   1.7176172E-03,   1.7263815E-03
     +,   1.7330600E-03,   1.7376289E-03,   1.7400607E-03
     +,   1.7403173E-03,   1.7383522E-03,   1.7341097E-03
     +,   1.7275341E-03,   1.7185869E-03,   1.7072528E-03
     +,   1.6935620E-03,   1.6775933E-03,   1.6594923E-03
     +,   1.6394727E-03,   1.6178081E-03,   1.5948330E-03
     +,   1.5709177E-03,   1.5464578E-03,   1.5218408E-03
     +,   1.4974254E-03,   1.4735162E-03,   1.4503404E-03
     +,   1.4280292E-03,   1.4066158E-03,   1.3860277E-03
     +,   1.3660931E-03,   1.3465553E-03,   1.3270974E-03
     +,   1.3073629E-03,   1.2869816E-03,   1.2655976E-03
     +,   1.2428981E-03,   1.2186310E-03,   1.1926199E-03
     +,   1.1647759E-03,   1.1351032E-03,   1.1036947E-03
     +,   1.0707225E-03,   1.0364322E-03,   1.0011238E-03
     +,   9.6513453E-04,   9.2882133E-04,   8.9254725E-04
     +,   8.5666601E-04,   8.2150288E-04,   7.8734790E-04
     +,   7.5445132E-04,   7.2301540E-04,   6.9318927E-04
     +,   6.6507392E-04,   6.3872413E-04,   6.1414973E-04
     +,   5.9132185E-04,   5.7018112E-04,   5.5064290E-04
     +,   5.3260120E-04,   5.1593821E-04,   5.0053047E-04
     +,   4.8625137E-04,   4.7297738E-04,   4.6059041E-04
     +,   4.4898238E-04,   4.3805561E-04,   4.2772415E-04
     +,   4.1791363E-04,   4.0856304E-04,   3.9962176E-04
     +,   3.9104925E-04,   3.8281453E-04,   3.7489404E-04
     +,   3.6726979E-04,   3.5992815E-04,   3.5285889E-04
     +,   3.4605365E-04,   3.3950424E-04,   3.3320283E-04
     +,   3.2714009E-04,   3.2130608E-04,   3.1568896E-04
     +,   3.1027480E-04,   3.0504871E-04,   2.9999329E-04
     +,   2.9509026E-04,   2.9032043E-04,   2.8566390E-04
     +,   2.8110002E-04,   2.7660833E-04,   2.7216904E-04
     +,   2.6776304E-04,   2.6337197E-04,   2.5897883E-04
     +,   2.5456838E-04,   2.5012734E-04,   2.4564358E-04
     +,   2.4110739E-04,   2.3651130E-04,   2.3184966E-04
     +,   2.2711857E-04,   2.2231668E-04,   2.1744460E-04
     +,   2.1250428E-04,   2.0749954E-04,   2.0243603E-04
     +,   1.9732081E-04,   1.9216194E-04,   1.8696849E-04
     +,   1.8175077E-04,   1.7651977E-04,   1.7128681E-04
     +,   1.6606339E-04,   1.6086164E-04,   1.5569347E-04
     +,   1.5057022E-04,   1.4550370E-04,   1.4050491E-04
     +,   1.3558406E-04,   1.3075079E-04,   1.2601425E-04
     +,   1.2138268E-04,   1.1686321E-04,   1.1246202E-04
     +,   1.0818471E-04,   1.0403581E-04,   1.0001866E-04
     +,   9.6135751E-05,   9.2388982E-05,   8.8779030E-05
     +,   8.5305801E-05,   8.1968676E-05,   7.8766308E-05
     +,   7.5696516E-05,   7.2756593E-05,   6.9943533E-05
     +,   6.7253903E-05,   6.4683714E-05,   6.2228704E-05
     +,   5.9884624E-05,   5.7646950E-05,   5.5510965E-05
     +,   5.3471882E-05,   5.1525141E-05,   4.9665989E-05
     +,   4.7889727E-05,   4.6191948E-05,   4.4568300E-05
     +,   4.3014501E-05,   4.1526444E-05,   4.0100316E-05
     +,   3.8732476E-05,   3.7419384E-05,   3.6157729E-05
     +,   3.4944525E-05,   3.3776818E-05,   3.2652009E-05
     +,   3.1567532E-05,   3.0521172E-05,   2.9510747E-05
     +,   2.8534358E-05,   2.7590157E-05,   2.6676562E-05
     +,   2.5792007E-05,   2.4935178E-05,   2.4104786E-05
     +,   2.3299657E-05,   2.2518787E-05,   2.1761176E-05
     +,   2.1025991E-05,   2.0312382E-05,   1.9619652E-05
     +,   1.8947083E-05,   1.8294082E-05,   1.7660026E-05
     +,   1.7044425E-05,   1.6446726E-05,   1.5866493E-05
     +,   1.5303249E-05,   1.4756600E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz65 = Yx/0.0775384615384615
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2084865E-05,   2.2591688E-05
     +,   2.3117273E-05,   2.3663839E-05,   2.4233907E-05
     +,   2.4830319E-05,   2.5456267E-05,   2.6115342E-05
     +,   2.6811571E-05,   2.7549448E-05,   2.8333958E-05
     +,   2.9170616E-05,   3.0065510E-05,   3.1025302E-05
     +,   3.2057287E-05,   3.3169363E-05,   3.4370092E-05
     +,   3.5668683E-05,   3.7074984E-05,   3.8599494E-05
     +,   4.0253373E-05,   4.2048407E-05,   4.3996981E-05
     +,   4.6112273E-05,   4.8407823E-05,   5.0898110E-05
     +,   5.3598138E-05,   5.6523666E-05,   5.9691254E-05
     +,   6.3118328E-05,   6.6823297E-05,   7.0825750E-05
     +,   7.5146621E-05,   7.9808546E-05,   8.4836196E-05
     +,   9.0256974E-05,   9.6101750E-05,   1.0240587E-04
     +,   1.0921134E-04,   1.1656753E-04,   1.2453560E-04
     +,   1.3319074E-04,   1.4262693E-04,   1.5296217E-04
     +,   1.6434431E-04,   1.7695798E-04,   1.9103081E-04
     +,   2.0684040E-04,   2.2471941E-04,   2.4505879E-04
     +,   2.6830775E-04,   2.9497032E-04,   3.2559579E-04
     +,   3.6076902E-04,   4.0108885E-04,   4.4715966E-04
     +,   4.9957156E-04,   5.5889756E-04,   6.2569912E-04
     +,   7.0054352E-04,   7.8403362E-04,   8.7684311E-04
     +,   9.7973621E-04,   1.0935874E-03,   1.2193485E-03
     +,   1.3579759E-03,   1.5103727E-03,   1.6772815E-03
     +,   1.8592889E-03,   2.0568522E-03,   2.2705386E-03
     +,   2.5012754E-03,   2.7507581E-03,   3.0216498E-03
     +,   3.3176772E-03,   3.6432184E-03,   4.0023685E-03
     +,   4.3975618E-03,   4.8278789E-03,   5.2873874E-03
     +,   5.7641240E-03,   6.2404391E-03,   6.6946978E-03
     +,   7.1046483E-03,   7.4512446E-03,   7.7222656E-03
     +,   7.9139676E-03,   8.0305664E-03,   8.0813374E-03
     +,   8.0766799E-03,   8.0246478E-03,   7.9292776E-03
     +,   7.7913436E-03,   7.6108393E-03,   7.3900293E-03
     +,   7.1354690E-03,   6.8580145E-03,   6.5709543E-03
     +,   6.2869340E-03,   6.0153049E-03,   5.7607349E-03
     +,   5.5236956E-03,   5.3021535E-03,   5.0937221E-03
     +,   4.8971069E-03,   4.7125756E-03,   4.5414055E-03
     +,   4.3849349E-03,   4.2436663E-03,   4.1168570E-03
     +,   4.0026051E-03,   3.8982243E-03,   3.8007265E-03
     +,   3.7071956E-03,   3.6150445E-03,   3.5221390E-03
     +,   3.4268920E-03,   3.3283038E-03,   3.2260106E-03
     +,   3.1202824E-03,   3.0119498E-03,   2.9023115E-03
     +,   2.7929954E-03,   2.6857951E-03,   2.5825622E-03
     +,   2.4850869E-03,   2.3949901E-03,   2.3136467E-03
     +,   2.2420844E-03,   2.1809153E-03,   2.1302791E-03
     +,   2.0898464E-03,   2.0588273E-03,   2.0360553E-03
     +,   2.0200801E-03,   2.0092968E-03,   2.0020716E-03
     +,   1.9968553E-03,   1.9922897E-03,   1.9872703E-03
     +,   1.9809874E-03,   1.9729242E-03,   1.9628326E-03
     +,   1.9506789E-03,   1.9365733E-03,   1.9206954E-03
     +,   1.9032133E-03,   1.8842282E-03,   1.8637298E-03
     +,   1.8415683E-03,   1.8174612E-03,   1.7910193E-03
     +,   1.7617880E-03,   1.7292899E-03,   1.6930908E-03
     +,   1.6528482E-03,   1.6083523E-03,   1.5595526E-03
     +,   1.5065788E-03,   1.4497380E-03,   1.3895000E-03
     +,   1.3264690E-03,   1.2613604E-03,   1.1949566E-03
     +,   1.1280661E-03,   1.0614891E-03,   9.9599524E-04
     +,   9.3228539E-04,   8.7097293E-04,   8.1257534E-04
     +,   7.5750944E-04,   7.0608960E-04,   6.5852841E-04
     +,   6.1494752E-04,   5.7539542E-04,   5.3984689E-04
     +,   5.0822139E-04,   4.8039565E-04,   4.5621055E-04
     +,   4.3547837E-04,   4.1799212E-04,   4.0353145E-04
     +,   3.9186652E-04,   3.8275987E-04,   3.7597041E-04
     +,   3.7125745E-04,   3.6838005E-04,   3.6710000E-04
     +,   3.6718370E-04,   3.6840359E-04,   3.7053975E-04
     +,   3.7338192E-04,   3.7672976E-04,   3.8039518E-04
     +,   3.8420293E-04,   3.8799227E-04,   3.9161634E-04
     +,   3.9494390E-04,   3.9785961E-04,   4.0026335E-04
     +,   4.0207090E-04,   4.0321366E-04,   4.0363835E-04
     +,   4.0330563E-04,   4.0219066E-04,   4.0028174E-04
     +,   3.9757875E-04,   3.9409366E-04,   3.8984828E-04
     +,   3.8487324E-04,   3.7920714E-04,   3.7289530E-04
     +,   3.6598917E-04,   3.5854350E-04,   3.5061664E-04
     +,   3.4226914E-04,   3.3356293E-04,   3.2455949E-04
     +,   3.1531925E-04,   3.0590227E-04,   2.9636527E-04
     +,   2.8676237E-04,   2.7714463E-04,   2.6755984E-04
     +,   2.5805083E-04,   2.4865655E-04,   2.3941224E-04
     +,   2.3034874E-04,   2.2149224E-04,   2.1286467E-04
     +,   2.0448468E-04,   1.9636714E-04,   1.8852288E-04
     +,   1.8095943E-04,   1.7368213E-04,   1.6669302E-04
     +,   1.5999166E-04,   1.5357597E-04,   1.4744209E-04
     +,   1.4158413E-04,   1.3599498E-04,   1.3066686E-04
     +,   1.2559099E-04,   1.2075780E-04,   1.1615707E-04
     +,   1.1177870E-04,   1.0761231E-04,   1.0364722E-04
     +,   9.9872836E-05,   9.6278935E-05,   9.2855254E-05
     +,   8.9591740E-05,   8.6478867E-05,   8.3507453E-05
     +,   8.0668418E-05,   7.7953235E-05,   7.5353782E-05
     +,   7.2862480E-05,   7.0471935E-05,   6.8175228E-05
     +,   6.5965985E-05,   6.3838255E-05,   6.1786348E-05
     +,   5.9804996E-05,   5.7889487E-05,   5.6035322E-05
     +,   5.4238382E-05,   5.2494994E-05,   5.0801831E-05
     +,   4.9155766E-05,   4.7553993E-05,   4.5994111E-05
     +,   4.4473956E-05,   4.2991564E-05,   4.1545161E-05
     +,   4.0133375E-05,   3.8754821E-05,   3.7408488E-05
     +,   3.6093377E-05,   3.4808774E-05,   3.3553955E-05
     +,   3.2328469E-05,   3.1131796E-05,   2.9963678E-05
     +,   2.8823761E-05,   2.7711894E-05,   2.6627882E-05
     +,   2.5571540E-05,   2.4542831E-05,   2.3541603E-05
     +,   2.2567812E-05,   2.1621314E-05,   2.0702066E-05
     +,   1.9809893E-05,   1.8944724E-05,   1.8106344E-05
     +,   1.7294631E-05,   1.6509324E-05,   1.5750236E-05
     +,   1.5017051E-05,   1.4309515E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz70 = Yx/0.095375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7681681E-05,   1.8229965E-05
     +,   1.8807923E-05,   1.9418216E-05,   2.0063680E-05
     +,   2.0747326E-05,   2.1472355E-05,   2.2242137E-05
     +,   2.3060185E-05,   2.3930224E-05,   2.4856075E-05
     +,   2.5841709E-05,   2.6891204E-05,   2.8008746E-05
     +,   2.9198587E-05,   3.0465026E-05,   3.1812404E-05
     +,   3.3245044E-05,   3.4767265E-05,   3.6383321E-05
     +,   3.8097383E-05,   3.9913517E-05,   4.1835643E-05
     +,   4.3867647E-05,   4.6013003E-05,   4.8275277E-05
     +,   5.0657673E-05,   5.3163276E-05,   5.5794953E-05
     +,   5.8555412E-05,   6.1447201E-05,   6.4472719E-05
     +,   6.7634275E-05,   7.0934118E-05,   7.4374439E-05
     +,   7.7957404E-05,   8.1685270E-05,   8.5560183E-05
     +,   8.9584741E-05,   9.3761140E-05,   9.8091994E-05
     +,   1.0257989E-04,   1.0722737E-04,   1.1203708E-04
     +,   1.1701149E-04,   1.2215301E-04,   1.2746397E-04
     +,   1.3294644E-04,   1.3860254E-04,   1.4443444E-04
     +,   1.5044463E-04,   1.5663652E-04,   1.6301475E-04
     +,   1.6958677E-04,   1.7636284E-04,   1.8335924E-04
     +,   1.9059867E-04,   1.9811363E-04,   2.0594856E-04
     +,   2.1416349E-04,   2.2283700E-04,   2.3207068E-04
     +,   2.4199134E-04,   2.5275641E-04,   2.6455618E-04
     +,   2.7761492E-04,   2.9219504E-04,   3.0859304E-04
     +,   3.2714248E-04,   3.4820638E-04,   3.7217865E-04
     +,   3.9947493E-04,   4.3053814E-04,   4.6583291E-04
     +,   5.0586241E-04,   5.5118243E-04,   6.0242607E-04
     +,   6.6034333E-04,   7.2584988E-04,   8.0006936E-04
     +,   8.8436372E-04,   9.8036521E-04,   1.0899338E-03
     +,   1.2151211E-03,   1.3580298E-03,   1.5207258E-03
     +,   1.7050887E-03,   1.9128359E-03,   2.1455889E-03
     +,   2.4051734E-03,   2.6939125E-03,   3.0147911E-03
     +,   3.3712091E-03,   3.7661020E-03,   4.2003780E-03
     +,   4.6710824E-03,   5.1704301E-03,   5.6863362E-03
     +,   6.2055667E-03,   6.7185331E-03,   7.2244029E-03
     +,   7.7333553E-03,   8.2644643E-03,   8.8384766E-03
     +,   9.4681168E-03,   1.0148961E-02,   1.0854382E-02
     +,   1.1536700E-02,   1.2134979E-02,   1.2588053E-02
     +,   1.2849745E-02,   1.2901571E-02,   1.2757841E-02
     +,   1.2460990E-02,   1.2068791E-02,   1.1638507E-02
     +,   1.1213317E-02,   1.0814439E-02,   1.0440089E-02
     +,   1.0070462E-02,   9.6777221E-03,   9.2381602E-03
     +,   8.7427935E-03,   8.2025900E-03,   7.6464163E-03
     +,   7.1129003E-03,   6.6395234E-03,   6.2533389E-03
     +,   5.9655854E-03,   5.7711531E-03,   5.6517534E-03
     +,   5.5812811E-03,   5.5315117E-03,   5.4769176E-03
     +,   5.3978586E-03,   5.2819857E-03,   5.1242406E-03
     +,   4.9257902E-03,   4.6924446E-03,   4.4329548E-03
     +,   4.1574617E-03,   3.8761711E-03,   3.5983270E-03
     +,   3.3315509E-03,   3.0814917E-03,   2.8516501E-03
     +,   2.6435223E-03,   2.4569123E-03,   2.2903264E-03
     +,   2.1414268E-03,   2.0075263E-03,   1.8859728E-03
     +,   1.7744412E-03,   1.6710975E-03,   1.5746549E-03
     +,   1.4843445E-03,   1.3997970E-03,   1.3209154E-03
     +,   1.2477426E-03,   1.1803675E-03,   1.1188277E-03
     +,   1.0630754E-03,   1.0129645E-03,   9.6825010E-04
     +,   9.2860404E-04,   8.9363882E-04,   8.6293410E-04
     +,   8.3605316E-04,   8.1255665E-04,   7.9201901E-04
     +,   7.7403447E-04,   7.5822428E-04,   7.4423628E-04
     +,   7.3175062E-04,   7.2048174E-04,   7.1017462E-04
     +,   7.0060976E-04,   6.9160166E-04,   6.8299955E-04
     +,   6.7468500E-04,   6.6657242E-04,   6.5860787E-04
     +,   6.5076584E-04,   6.4304681E-04,   6.3547411E-04
     +,   6.2809070E-04,   6.2095461E-04,   6.1413454E-04
     +,   6.0770550E-04,   6.0174539E-04,   5.9632870E-04
     +,   5.9152377E-04,   5.8738951E-04,   5.8397115E-04
     +,   5.8129826E-04,   5.7938328E-04,   5.7821913E-04
     +,   5.7778013E-04,   5.7802146E-04,   5.7888066E-04
     +,   5.8027840E-04,   5.8212102E-04,   5.8430346E-04
     +,   5.8671221E-04,   5.8922672E-04,   5.9172552E-04
     +,   5.9408712E-04,   5.9619418E-04,   5.9793593E-04
     +,   5.9921097E-04,   5.9992966E-04,   6.0001569E-04
     +,   5.9940701E-04,   5.9805665E-04,   5.9593387E-04
     +,   5.9302297E-04,   5.8932294E-04,   5.8484613E-04
     +,   5.7961734E-04,   5.7367212E-04,   5.6705449E-04
     +,   5.5981515E-04,   5.5200956E-04,   5.4369681E-04
     +,   5.3493539E-04,   5.2578334E-04,   5.1629712E-04
     +,   5.0652894E-04,   4.9652613E-04,   4.8633054E-04
     +,   4.7597833E-04,   4.6550026E-04,   4.5491982E-04
     +,   4.4425522E-04,   4.3352027E-04,   4.2272350E-04
     +,   4.1186914E-04,   4.0096001E-04,   3.8999651E-04
     +,   3.7897733E-04,   3.6790094E-04,   3.5676733E-04
     +,   3.4557746E-04,   3.3433377E-04,   3.2304093E-04
     +,   3.1170709E-04,   3.0034318E-04,   2.8896256E-04
     +,   2.7758125E-04,   2.6621914E-04,   2.5489763E-04
     +,   2.4363997E-04,   2.3247185E-04,   2.2142015E-04
     +,   2.1051170E-04,   1.9977348E-04,   1.8923292E-04
     +,   1.7891655E-04,   1.6884894E-04,   1.5905316E-04
     +,   1.4955091E-04,   1.4036147E-04,   1.3150118E-04
     +,   1.2298366E-04,   1.1482069E-04,   1.0702029E-04
     +,   9.9587945E-05,   9.2526789E-05,   8.5837404E-05
     +,   7.9517435E-05,   7.3562267E-05,   6.7965724E-05
     +,   6.2719715E-05,   5.7814123E-05,   5.3237520E-05
     +,   4.8977803E-05,   4.5021323E-05,   4.1354349E-05
     +,   3.7962061E-05,   3.4829867E-05,   3.1942589E-05
     +,   2.9285498E-05,   2.6843651E-05,   2.4602748E-05
     +,   2.2548580E-05,   2.0667678E-05,   1.8946939E-05
     +,   1.7373870E-05,   1.5936774E-05,   1.4624408E-05
     +,   1.3426397E-05,   1.2332877E-05,   1.1334816E-05
     +,   1.0423689E-05,   9.5917503E-06,   8.8317629E-06
     +,   8.1371791E-06,   7.5019143E-06,   6.9205062E-06
     +,   6.3879043E-06,   5.8995934E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz75 = Yx/0.121560975609756
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7668036E-05,   3.8436887E-05
     +,   3.9162038E-05,   3.9840495E-05,   4.0469458E-05
     +,   4.1046293E-05,   4.1568619E-05,   4.2034295E-05
     +,   4.2441436E-05,   4.2788462E-05,   4.3074087E-05
     +,   4.3297347E-05,   4.3457621E-05,   4.3554610E-05
     +,   4.3588403E-05,   4.3559456E-05,   4.3468579E-05
     +,   4.3316977E-05,   4.3106222E-05,   4.2838299E-05
     +,   4.2515541E-05,   4.2140677E-05,   4.1716808E-05
     +,   4.1247378E-05,   4.0736235E-05,   4.0187530E-05
     +,   3.9605766E-05,   3.8995771E-05,   3.8362698E-05
     +,   3.7711969E-05,   3.7049322E-05,   3.6380756E-05
     +,   3.5712528E-05,   3.5051158E-05,   3.4403409E-05
     +,   3.3776294E-05,   3.3177046E-05,   3.2613178E-05
     +,   3.2092401E-05,   3.1622749E-05,   3.1212494E-05
     +,   3.0870211E-05,   3.0604831E-05,   3.0425634E-05
     +,   3.0342300E-05,   3.0364950E-05,   3.0504198E-05
     +,   3.0771171E-05,   3.1177573E-05,   3.1735719E-05
     +,   3.2458553E-05,   3.3359680E-05,   3.4453340E-05
     +,   3.5754489E-05,   3.7278554E-05,   3.9041661E-05
     +,   4.1060288E-05,   4.3351269E-05,   4.5931574E-05
     +,   4.8818198E-05,   5.2027808E-05,   5.5576696E-05
     +,   5.9480088E-05,   6.3752414E-05,   6.8406807E-05
     +,   7.3454328E-05,   7.8904806E-05,   8.4765379E-05
     +,   9.1041846E-05,   9.7737240E-05,   1.0485381E-04
     +,   1.1239150E-04,   1.2035069E-04,   1.2873125E-04
     +,   1.3753543E-04,   1.4676881E-04,   1.5644133E-04
     +,   1.6656988E-04,   1.7718096E-04,   1.8831226E-04
     +,   2.0001311E-04,   2.1234858E-04,   2.2539687E-04
     +,   2.3925281E-04,   2.5402350E-04,   2.6982982E-04
     +,   2.8680079E-04,   3.0507540E-04,   3.2479642E-04
     +,   3.4611596E-04,   3.6919673E-04,   3.9421974E-04
     +,   4.2139817E-04,   4.5099866E-04,   4.8336244E-04
     +,   5.1892793E-04,   5.5826484E-04,   6.0209242E-04
     +,   6.5132120E-04,   7.0708594E-04,   7.7082473E-04
     +,   8.4436906E-04,   9.3010295E-04,   1.0311122E-03
     +,   1.1513386E-03,   1.2956029E-03,   1.4693930E-03
     +,   1.6783967E-03,   1.9278998E-03,   2.2224078E-03
     +,   2.5661036E-03,   2.9647022E-03,   3.4280047E-03
     +,   3.9717308E-03,   4.6156081E-03,   5.3766621E-03
     +,   6.2588179E-03,   7.2446498E-03,   8.2942536E-03
     +,   9.3553243E-03,   1.0381873E-02,   1.1355778E-02
     +,   1.2298971E-02,   1.3261884E-02,   1.4284289E-02
     +,   1.5350186E-02,   1.6372899E-02,   1.7227126E-02
     +,   1.7808849E-02,   1.8083876E-02,   1.8101692E-02
     +,   1.7970625E-02,   1.7805578E-02,   1.7676612E-02
     +,   1.7588589E-02,   1.7498741E-02,   1.7345596E-02
     +,   1.7063124E-02,   1.6586801E-02,   1.5874323E-02
     +,   1.4939162E-02,   1.3864969E-02,   1.2779150E-02
     +,   1.1800686E-02,   1.0996634E-02,   1.0367624E-02
     +,   9.8624406E-03,   9.4079887E-03,   8.9406706E-03
     +,   8.4270760E-03,   7.8680366E-03,   7.2882567E-03
     +,   6.7196847E-03,   6.1876597E-03,   5.7043452E-03
     +,   5.2693812E-03,   4.8746490E-03,   4.5099328E-03
     +,   4.1670674E-03,   3.8417361E-03,   3.5331221E-03
     +,   3.2426454E-03,   2.9725286E-03,   2.7246899E-03
     +,   2.5001627E-03,   2.2989321E-03,   2.1200201E-03
     +,   1.9617071E-03,   1.8218241E-03,   1.6980834E-03
     +,   1.5883626E-03,   1.4909008E-03,   1.4043933E-03
     +,   1.3280076E-03,   1.2613130E-03,   1.2041363E-03
     +,   1.1564236E-03,   1.1181069E-03,   1.0889992E-03
     +,   1.0687276E-03,   1.0567185E-03,   1.0522027E-03
     +,   1.0542463E-03,   1.0617918E-03,   1.0736960E-03
     +,   1.0887753E-03,   1.1058354E-03,   1.1237059E-03
     +,   1.1412663E-03,   1.1574677E-03,   1.1713625E-03
     +,   1.1821216E-03,   1.1890546E-03,   1.1916241E-03
     +,   1.1894584E-03,   1.1823536E-03,   1.1702735E-03
     +,   1.1533395E-03,   1.1318171E-03,   1.1060934E-03
     +,   1.0766588E-03,   1.0440768E-03,   1.0089545E-03
     +,   9.7191852E-04,   9.3359419E-04,   8.9457561E-04
     +,   8.5541321E-04,   8.1660011E-04,   7.7856280E-04
     +,   7.4165309E-04,   7.0614874E-04,   6.7225995E-04
     +,   6.4012868E-04,   6.0983596E-04,   5.8141071E-04
     +,   5.5483973E-04,   5.3007482E-04,   5.0703838E-04
     +,   4.8563362E-04,   4.6575314E-04,   4.4727998E-04
     +,   4.3009469E-04,   4.1408086E-04,   3.9912591E-04
     +,   3.8512304E-04,   3.7197355E-04,   3.5958854E-04
     +,   3.4788772E-04,   3.3679948E-04,   3.2626066E-04
     +,   3.1621690E-04,   3.0662070E-04,   2.9743044E-04
     +,   2.8860974E-04,   2.8012780E-04,   2.7195638E-04
     +,   2.6407032E-04,   2.5644712E-04,   2.4906616E-04
     +,   2.4190742E-04,   2.3495193E-04,   2.2818192E-04
     +,   2.2158021E-04,   2.1512971E-04,   2.0881389E-04
     +,   2.0261745E-04,   1.9652555E-04,   1.9052401E-04
     +,   1.8459983E-04,   1.7874167E-04,   1.7293895E-04
     +,   1.6718281E-04,   1.6146617E-04,   1.5578384E-04
     +,   1.5013199E-04,   1.4450854E-04,   1.3891360E-04
     +,   1.3334895E-04,   1.2781764E-04,   1.2232426E-04
     +,   1.1687506E-04,   1.1147756E-04,   1.0613979E-04
     +,   1.0087067E-04,   9.5680203E-05,   9.0578200E-05
     +,   8.5574713E-05,   8.0680045E-05,   7.5904252E-05
     +,   7.1256691E-05,   6.6746143E-05,   6.2380990E-05
     +,   5.8168800E-05,   5.4115881E-05,   5.0227587E-05
     +,   4.6508616E-05,   4.2962049E-05,   3.9590366E-05
     +,   3.6394482E-05,   3.3374694E-05,   3.0529860E-05
     +,   2.7858250E-05,   2.5356863E-05,   2.3022205E-05
     +,   2.0849719E-05,   1.8834484E-05,   1.6970776E-05
     +,   1.5252441E-05,   1.3673075E-05,   1.2225773E-05
     +,   1.0903613E-05,   9.6993581E-06,   8.6058835E-06
     +,   7.6159304E-06,   6.7224482E-06,   5.9184013E-06
     +,   5.1970474E-06,   4.5517631E-06,   3.9762795E-06
     +,   3.4645279E-06,   3.0108233E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz80 = Yx/0.152860465116279
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.5061984E-06,   8.9168179E-06
     +,   9.3411691E-06,   9.7794018E-06,   1.0231659E-05
     +,   1.0698077E-05,   1.1178783E-05,   1.1673897E-05
     +,   1.2183530E-05,   1.2707813E-05,   1.3246846E-05
     +,   1.3800740E-05,   1.4369601E-05,   1.4953545E-05
     +,   1.5552676E-05,   1.6167121E-05,   1.6797007E-05
     +,   1.7442466E-05,   1.8103647E-05,   1.8780711E-05
     +,   1.9473840E-05,   2.0183234E-05,   2.0909099E-05
     +,   2.1651722E-05,   2.2411341E-05,   2.3188302E-05
     +,   2.3982946E-05,   2.4795681E-05,   2.5626960E-05
     +,   2.6477281E-05,   2.7347223E-05,   2.8237449E-05
     +,   2.9148672E-05,   3.0081745E-05,   3.1037587E-05
     +,   3.2017277E-05,   3.3022010E-05,   3.4053126E-05
     +,   3.5112229E-05,   3.6200981E-05,   3.7321417E-05
     +,   3.8475737E-05,   3.9666458E-05,   4.0896404E-05
     +,   4.2168751E-05,   4.3487060E-05,   4.4855286E-05
     +,   4.6277877E-05,   4.7759706E-05,   4.9306203E-05
     +,   5.0923289E-05,   5.2617463E-05,   5.4395732E-05
     +,   5.6265791E-05,   5.8235681E-05,   6.0314142E-05
     +,   6.2510313E-05,   6.4833745E-05,   6.7294372E-05
     +,   6.9902329E-05,   7.2667899E-05,   7.5601391E-05
     +,   7.8712736E-05,   8.2011720E-05,   8.5507621E-05
     +,   8.9208559E-05,   9.3122100E-05,   9.7254073E-05
     +,   1.0160932E-04,   1.0619037E-04,   1.1099834E-04
     +,   1.1603165E-04,   1.2128685E-04,   1.2675743E-04
     +,   1.3243461E-04,   1.3830711E-04,   1.4436053E-04
     +,   1.5057795E-04,   1.5694054E-04,   1.6342755E-04
     +,   1.7001595E-04,   1.7668298E-04,   1.8340492E-04
     +,   1.9016014E-04,   1.9692892E-04,   2.0369653E-04
     +,   2.1045412E-04,   2.1720288E-04,   2.2395502E-04
     +,   2.3073926E-04,   2.3760380E-04,   2.4462043E-04
     +,   2.5188943E-04,   2.5954520E-04,   2.6776030E-04
     +,   2.7675019E-04,   2.8677838E-04,   2.9815847E-04
     +,   3.1125921E-04,   3.2650252E-04,   3.4436714E-04
     +,   3.6538162E-04,   3.9012486E-04,   4.1921317E-04
     +,   4.5329382E-04,   4.9303070E-04,   5.3908204E-04
     +,   5.9208041E-04,   6.5261265E-04,   7.2119175E-04
     +,   7.9822534E-04,   8.8401354E-04,   9.7871851E-04
     +,   1.0823968E-03,   1.1949961E-03,   1.3164261E-03
     +,   1.4465845E-03,   1.5854499E-03,   1.7331026E-03
     +,   1.8897847E-03,   2.0559174E-03,   2.2320920E-03
     +,   2.4190831E-03,   2.6178469E-03,   2.8294479E-03
     +,   3.0549662E-03,   3.2955820E-03,   3.5529530E-03
     +,   3.8304022E-03,   4.1345768E-03,   4.4770511E-03
     +,   4.8740087E-03,   5.3430656E-03,   5.8972347E-03
     +,   6.5393513E-03,   7.2609698E-03,   8.0482652E-03
     +,   8.8931089E-03,   9.8034460E-03,   1.0807932E-02
     +,   1.1950874E-02,   1.3270696E-02,   1.4757407E-02
     +,   1.6314805E-02,   1.7784508E-02,   1.9045202E-02
     +,   2.0091962E-02,   2.1003900E-02,   2.1859335E-02
     +,   2.2715375E-02,   2.3610454E-02,   2.4488121E-02
     +,   2.5132323E-02,   2.5278540E-02,   2.4828354E-02
     +,   2.3921318E-02,   2.2788055E-02,   2.1573273E-02
     +,   2.0315174E-02,   1.9024668E-02,   1.7707316E-02
     +,   1.6329395E-02,   1.4834503E-02,   1.3214873E-02
     +,   1.1542889E-02,   9.9261813E-03,   8.4464494E-03
     +,   7.1405191E-03,   6.0180626E-03,   5.0798855E-03
     +,   4.3204264E-03,   3.7236009E-03,   3.2634297E-03
     +,   2.9104818E-03,   2.6386315E-03,   2.4280730E-03
     +,   2.2649248E-03,   2.1393108E-03,   2.0438286E-03
     +,   1.9728902E-03,   1.9226148E-03,   1.8907442E-03
     +,   1.8763175E-03,   1.8791370E-03,   1.8991759E-03
     +,   1.9360407E-03,   1.9885856E-03,   2.0546929E-03
     +,   2.1311885E-03,   2.2138909E-03,   2.2978038E-03
     +,   2.3774023E-03,   2.4470191E-03,   2.5012973E-03
     +,   2.5356640E-03,   2.5467230E-03,   2.5325674E-03
     +,   2.4929231E-03,   2.4291323E-03,   2.3439494E-03
     +,   2.2412380E-03,   2.1255524E-03,   2.0017021E-03
     +,   1.8743548E-03,   1.7477245E-03,   1.6253130E-03
     +,   1.5098026E-03,   1.4030279E-03,   1.3060212E-03
     +,   1.2191095E-03,   1.1420543E-03,   1.0742006E-03
     +,   1.0146094E-03,   9.6217752E-04,   9.1574754E-04
     +,   8.7419088E-04,   8.3646120E-04,   8.0163364E-04
     +,   7.6892896E-04,   7.3772267E-04,   7.0753798E-04
     +,   6.7803572E-04,   6.4900098E-04,   6.2032160E-04
     +,   5.9196778E-04,   5.6397257E-04,   5.3641829E-04
     +,   5.0941575E-04,   4.8309044E-04,   4.5757231E-04
     +,   4.3298758E-04,   4.0944957E-04,   3.8705242E-04
     +,   3.6586827E-04,   3.4594777E-04,   3.2731530E-04
     +,   3.0997174E-04,   2.9389729E-04,   2.7905224E-04
     +,   2.6537958E-04,   2.5280876E-04,   2.4126060E-04
     +,   2.3064890E-04,   2.2088345E-04,   2.1187296E-04
     +,   2.0352902E-04,   1.9576617E-04,   1.8850385E-04
     +,   1.8166772E-04,   1.7519107E-04,   1.6901387E-04
     +,   1.6308359E-04,   1.5735543E-04,   1.5179158E-04
     +,   1.4636054E-04,   1.4103693E-04,   1.3580124E-04
     +,   1.3063890E-04,   1.2553952E-04,   1.2049632E-04
     +,   1.1550629E-04,   1.1056905E-04,   1.0568628E-04
     +,   1.0086153E-04,   9.6100201E-05,   9.1408372E-05
     +,   8.6792927E-05,   8.2261577E-05,   7.7822260E-05
     +,   7.3482704E-05,   6.9250455E-05,   6.5133019E-05
     +,   6.1137485E-05,   5.7270059E-05,   5.3536343E-05
     +,   4.9941522E-05,   4.6489517E-05,   4.3183882E-05
     +,   4.0026898E-05,   3.7020342E-05,   3.4164827E-05
     +,   3.1460440E-05,   2.8906152E-05,   2.6500504E-05
     +,   2.4241002E-05,   2.2124803E-05,   2.0148265E-05
     +,   1.8307228E-05,   1.6597251E-05,   1.5013279E-05
     +,   1.3550149E-05,   1.2202243E-05,   1.0963950E-05
     +,   9.8293567E-06,   8.7926437E-06,   7.8478388E-06
     +,   6.9891357E-06,   6.2106969E-06,   5.5069149E-06
     +,   4.8722395E-06,   4.3013997E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz85 = Yx/0.177704545454545
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.2061561E-06,   8.3475479E-06
     +,   8.4905942E-06,   8.6354712E-06,   8.7823728E-06
     +,   8.9315199E-06,   9.0831509E-06,   9.2375258E-06
     +,   9.3949320E-06,   9.5556870E-06,   9.7201228E-06
     +,   9.8886085E-06,   1.0061539E-05,   1.0239337E-05
     +,   1.0422456E-05,   1.0611377E-05,   1.0806614E-05
     +,   1.1008718E-05,   1.1218263E-05,   1.1435865E-05
     +,   1.1662168E-05,   1.1897844E-05,   1.2143607E-05
     +,   1.2400209E-05,   1.2668412E-05,   1.2949041E-05
     +,   1.3242929E-05,   1.3550956E-05,   1.3874029E-05
     +,   1.4213087E-05,   1.4569101E-05,   1.4943073E-05
     +,   1.5336038E-05,   1.5749063E-05,   1.6183245E-05
     +,   1.6639719E-05,   1.7119641E-05,   1.7624207E-05
     +,   1.8154680E-05,   1.8712302E-05,   1.9298421E-05
     +,   1.9914394E-05,   2.0561643E-05,   2.1241654E-05
     +,   2.1955961E-05,   2.2706185E-05,   2.3494043E-05
     +,   2.4321313E-05,   2.5189922E-05,   2.6101890E-05
     +,   2.7059388E-05,   2.8064751E-05,   2.9120472E-05
     +,   3.0229330E-05,   3.1394207E-05,   3.2618398E-05
     +,   3.3905406E-05,   3.5259141E-05,   3.6683898E-05
     +,   3.8184440E-05,   3.9766066E-05,   4.1434701E-05
     +,   4.3196869E-05,   4.5060016E-05,   4.7032478E-05
     +,   4.9123471E-05,   5.1343570E-05,   5.3704378E-05
     +,   5.6219214E-05,   5.8902675E-05,   6.1771338E-05
     +,   6.4843298E-05,   6.8138950E-05,   7.1680290E-05
     +,   7.5491640E-05,   7.9599376E-05,   8.4031519E-05
     +,   8.8817818E-05,   9.3989751E-05,   9.9579898E-05
     +,   1.0562084E-04,   1.1214589E-04,   1.1918676E-04
     +,   1.2677428E-04,   1.3493566E-04,   1.4369542E-04
     +,   1.5307229E-04,   1.6307992E-04,   1.7372392E-04
     +,   1.8500251E-04,   1.9690544E-04,   2.0941184E-04
     +,   2.2249098E-04,   2.3610299E-04,   2.5019850E-04
     +,   2.6471808E-04,   2.7959640E-04,   2.9476054E-04
     +,   3.1013574E-04,   3.2564401E-04,   3.4121092E-04
     +,   3.5676447E-04,   3.7224250E-04,   3.8759140E-04
     +,   4.0277315E-04,   4.1776604E-04,   4.3256607E-04
     +,   4.4719040E-04,   4.6167884E-04,   4.7609507E-04
     +,   4.9052364E-04,   5.0507404E-04,   5.1987590E-04
     +,   5.3508003E-04,   5.5085216E-04,   5.6737353E-04
     +,   5.8483228E-04,   6.0342270E-04,   6.2333571E-04
     +,   6.4475805E-04,   6.6786748E-04,   6.9283234E-04
     +,   7.1981474E-04,   7.4898446E-04,   7.8053359E-04
     +,   8.1469450E-04,   8.5177372E-04,   8.9217210E-04
     +,   9.3641790E-04,   9.8517723E-04,   1.0392767E-03
     +,   1.0997033E-03,   1.1676316E-03,   1.2444333E-03
     +,   1.3317382E-03,   1.4314827E-03,   1.5459610E-03
     +,   1.6778632E-03,   1.8302858E-03,   2.0067119E-03
     +,   2.2109984E-03,   2.4474578E-03,   2.7209590E-03
     +,   3.0368364E-03,   3.4002436E-03,   3.8147459E-03
     +,   4.2800605E-03,   4.7898060E-03,   5.3309589E-03
     +,   5.8865366E-03,   6.4415564E-03,   6.9900965E-03
     +,   7.5395349E-03,   8.1090573E-03,   8.7237693E-03
     +,   9.4087189E-03,   1.0184729E-02,   1.1062696E-02
     +,   1.2033314E-02,   1.3058175E-02,   1.4074166E-02
     +,   1.5014590E-02,   1.5835403E-02,   1.6528668E-02
     +,   1.7111938E-02,   1.7593740E-02,   1.7933790E-02
     +,   1.8031225E-02,   1.7765751E-02,   1.7071461E-02
     +,   1.5986931E-02,   1.4645391E-02,   1.3222138E-02
     +,   1.1883275E-02,   1.0756866E-02,   9.9196546E-03
     +,   9.3913060E-03,   9.1387341E-03,   9.0947710E-03
     +,   9.1857295E-03,   9.3539441E-03,   9.5657622E-03
     +,   9.8043373E-03,   1.0054694E-02,   1.0290696E-02
     +,   1.0471815E-02,   1.0551943E-02,   1.0495039E-02
     +,   1.0288975E-02,   9.9500380E-03,   9.5163286E-03
     +,   9.0341521E-03,   8.5443305E-03,   8.0738077E-03
     +,   7.6344633E-03,   7.2273593E-03,   6.8486314E-03
     +,   6.4940490E-03,   6.1610388E-03,   5.8485209E-03
     +,   5.5555743E-03,   5.2800626E-03,   5.0181653E-03
     +,   4.7649136E-03,   4.5155799E-03,   4.2670509E-03
     +,   4.0187603E-03,   3.7726588E-03,   3.5323903E-03
     +,   3.3020484E-03,   3.0850330E-03,   2.8833293E-03
     +,   2.6973116E-03,   2.5260372E-03,   2.3678194E-03
     +,   2.2208518E-03,   2.0836585E-03,   1.9553257E-03
     +,   1.8355179E-03,   1.7243230E-03,   1.6219835E-03
     +,   1.5286644E-03,   1.4442785E-03,   1.3683909E-03
     +,   1.3002231E-03,   1.2387340E-03,   1.1827474E-03
     +,   1.1310761E-03,   1.0826373E-03,   1.0365380E-03
     +,   9.9212758E-04,   9.4899582E-04,   9.0695487E-04
     +,   8.6599297E-04,   8.2622562E-04,   7.8783231E-04
     +,   7.5100781E-04,   7.1592542E-04,   6.8270543E-04
     +,   6.5139955E-04,   6.2198477E-04,   5.9437327E-04
     +,   5.6842022E-04,   5.4393575E-04,   5.2070600E-04
     +,   4.9850851E-04,   4.7712636E-04,   4.5635825E-04
     +,   4.3602948E-04,   4.1599938E-04,   3.9616149E-04
     +,   3.7644489E-04,   3.5681514E-04,   3.3726942E-04
     +,   3.1783112E-04,   2.9854657E-04,   2.7948071E-04
     +,   2.6071089E-04,   2.4232040E-04,   2.2439509E-04
     +,   2.0702033E-04,   1.9027662E-04,   1.7423506E-04
     +,   1.5895687E-04,   1.4449307E-04,   1.3088058E-04
     +,   1.1814375E-04,   1.0629508E-04,   9.5334923E-05
     +,   8.5251908E-05,   7.6024895E-05,   6.7624926E-05
     +,   6.0015958E-05,   5.3155884E-05,   4.6998630E-05
     +,   4.1496049E-05,   3.6597776E-05,   3.2253796E-05
     +,   2.8414119E-05,   2.5030697E-05,   2.2057071E-05
     +,   1.9449702E-05,   1.7167573E-05,   1.5173056E-05
     +,   1.3431425E-05,   1.1911399E-05,   1.0584668E-05
     +,   9.4259567E-06,   8.4129606E-06,   7.5259068E-06
     +,   6.7475994E-06,   6.0629754E-06,   5.4590787E-06
     +,   4.9246801E-06,   4.4502153E-06,   4.0274576E-06
     +,   3.6494575E-06,   3.3102688E-06,   3.0048984E-06
     +,   2.7290898E-06,   2.4792737E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz90 = Yx/0.169272727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_ashz_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4808605E-05,   1.5258292E-05
     +,   1.5715761E-05,   1.6181644E-05,   1.6656651E-05
     +,   1.7141610E-05,   1.7637447E-05,   1.8145181E-05
     +,   1.8665933E-05,   1.9200954E-05,   1.9751569E-05
     +,   2.0319199E-05,   2.0905367E-05,   2.1511672E-05
     +,   2.2139810E-05,   2.2791522E-05,   2.3468621E-05
     +,   2.4172963E-05,   2.4906425E-05,   2.5670908E-05
     +,   2.6468311E-05,   2.7300513E-05,   2.8169343E-05
     +,   2.9076613E-05,   3.0023964E-05,   3.1013034E-05
     +,   3.2045278E-05,   3.3121996E-05,   3.4244349E-05
     +,   3.5413268E-05,   3.6629495E-05,   3.7893511E-05
     +,   3.9205544E-05,   4.0565548E-05,   4.1973191E-05
     +,   4.3427804E-05,   4.4928423E-05,   4.6473702E-05
     +,   4.8062095E-05,   4.9691469E-05,   5.1359628E-05
     +,   5.3063832E-05,   5.4801098E-05,   5.6568104E-05
     +,   5.8361216E-05,   6.0176524E-05,   6.2009858E-05
     +,   6.3856765E-05,   6.5712658E-05,   6.7572699E-05
     +,   6.9431946E-05,   7.1285373E-05,   7.3127827E-05
     +,   7.4954267E-05,   7.6759497E-05,   7.8538556E-05
     +,   8.0286554E-05,   8.1998733E-05,   8.3670595E-05
     +,   8.5297885E-05,   8.6876636E-05,   8.8403336E-05
     +,   8.9874666E-05,   9.1287911E-05,   9.2640817E-05
     +,   9.3931470E-05,   9.5158692E-05,   9.6321623E-05
     +,   9.7420176E-05,   9.8454642E-05,   9.9426070E-05
     +,   1.0033589E-04,   1.0118635E-04,   1.0198000E-04
     +,   1.0272013E-04,   1.0341047E-04,   1.0405527E-04
     +,   1.0465919E-04,   1.0522737E-04,   1.0576540E-04
     +,   1.0627904E-04,   1.0677454E-04,   1.0725826E-04
     +,   1.0773686E-04,   1.0821714E-04,   1.0870608E-04
     +,   1.0921063E-04,   1.0973791E-04,   1.1029506E-04
     +,   1.1088936E-04,   1.1152799E-04,   1.1221829E-04
     +,   1.1296770E-04,   1.1378375E-04,   1.1467439E-04
     +,   1.1564766E-04,   1.1671224E-04,   1.1787717E-04
     +,   1.1915238E-04,   1.2054843E-04,   1.2207720E-04
     +,   1.2375141E-04,   1.2558549E-04,   1.2759522E-04
     +,   1.2979827E-04,   1.3221425E-04,   1.3486482E-04
     +,   1.3777382E-04,   1.4096782E-04,   1.4447585E-04
     +,   1.4832945E-04,   1.5256343E-04,   1.5721506E-04
     +,   1.6232522E-04,   1.6793740E-04,   1.7409892E-04
     +,   1.8085986E-04,   1.8827451E-04,   1.9640013E-04
     +,   2.0529843E-04,   2.1503569E-04,   2.2568225E-04
     +,   2.3731367E-04,   2.5001258E-04,   2.6386892E-04
     +,   2.7897957E-04,   2.9545338E-04,   3.1340800E-04
     +,   3.3297576E-04,   3.5429932E-04,   3.7753661E-04
     +,   4.0285394E-04,   4.3042868E-04,   4.6043773E-04
     +,   4.9305568E-04,   5.2844232E-04,   5.6672894E-04
     +,   6.0800550E-04,   6.5231061E-04,   6.9961662E-04
     +,   7.4981846E-04,   8.0273522E-04,   8.5811934E-04
     +,   9.1567717E-04,   9.7509625E-04,   1.0361050E-03
     +,   1.0985322E-03,   1.1623716E-03,   1.2278556E-03
     +,   1.2955173E-03,   1.3662089E-03,   1.4410766E-03
     +,   1.5214809E-03,   1.6088426E-03,   1.7044134E-03
     +,   1.8089782E-03,   1.9225533E-03,   2.0440985E-03
     +,   2.1712980E-03,   2.3004804E-03,   2.4267505E-03
     +,   2.5443183E-03,   2.6470271E-03,   2.7290715E-03
     +,   2.7857581E-03,   2.8142019E-03,   2.8138468E-03
     +,   2.7867120E-03,   2.7373398E-03,   2.6724879E-03
     +,   2.6007676E-03,   2.5323327E-03,   2.4787714E-03
     +,   2.4532143E-03,   2.4704214E-03,   2.5466792E-03
     +,   2.6994753E-03,   2.9473330E-03,   3.3104278E-03
     +,   3.8121562E-03,   4.4800281E-03,   5.3426046E-03
     +,   6.4199553E-03,   7.7098175E-03,   9.1774762E-03
     +,   1.0757568E-02,   1.2367018E-02,   1.3920817E-02
     +,   1.5347079E-02,   1.6611114E-02,   1.7748091E-02
     +,   1.8866409E-02,   2.0069120E-02,   2.1317104E-02
     +,   2.2375276E-02,   2.2958646E-02,   2.2970615E-02
     +,   2.2573723E-02,   2.2010021E-02,   2.1386400E-02
     +,   2.0652303E-02,   1.9736117E-02,   1.8651562E-02
     +,   1.7483953E-02,   1.6315499E-02,   1.5172533E-02
     +,   1.4029979E-02,   1.2858445E-02,   1.1672126E-02
     +,   1.0535700E-02,   9.5241135E-03,   8.6728027E-03
     +,   7.9613132E-03,   7.3378412E-03,   6.7567769E-03
     +,   6.1995154E-03,   5.6714690E-03,   5.1873131E-03
     +,   4.7584246E-03,   4.3880730E-03,   4.0723397E-03
     +,   3.8032981E-03,   3.5716717E-03,   3.3684417E-03
     +,   3.1856205E-03,   3.0166248E-03,   2.8564353E-03
     +,   2.7015808E-03,   2.5500176E-03,   2.4008784E-03
     +,   2.2541571E-03,   2.1103660E-03,   1.9702439E-03
     +,   1.8345686E-03,   1.7040636E-03,   1.5793192E-03
     +,   1.4607835E-03,   1.3487682E-03,   1.2434453E-03
     +,   1.1448469E-03,   1.0528925E-03,   9.6740981E-04
     +,   8.8815455E-04,   8.1482413E-04,   7.4708665E-04
     +,   6.8459677E-04,   6.2700390E-04,   5.7395664E-04
     +,   5.2511354E-04,   4.8015136E-04,   4.3875849E-04
     +,   4.0064342E-04,   3.6553884E-04,   3.3319878E-04
     +,   3.0339754E-04,   2.7593184E-04,   2.5062120E-04
     +,   2.2730335E-04,   2.0583156E-04,   1.8607386E-04
     +,   1.6791192E-04,   1.5123749E-04,   1.3594970E-04
     +,   1.2195500E-04,   1.0916699E-04,   9.7503216E-05
     +,   8.6885790E-05,   7.7241551E-05,   6.8501133E-05
     +,   6.0598068E-05,   5.3469405E-05,   4.7055921E-05
     +,   4.1301402E-05,   3.6152262E-05,   3.1557836E-05
     +,   2.7470714E-05,   2.3845634E-05,   2.0640508E-05
     +,   1.7815368E-05,   1.5333237E-05,   1.3159282E-05
     +,   1.1261469E-05,   9.6099102E-06,   8.1773351E-06
     +,   6.9385628E-06,   5.8708183E-06,   4.9533292E-06
     +,   4.1673661E-06,   3.4961836E-06,   2.9247276E-06
     +,   2.4396852E-06,   2.0292023E-06,   1.6828870E-06
     +,   1.3915685E-06,   1.1472696E-06,   9.4300879E-07
     +,   7.7275899E-07,   6.3128550E-07,   5.1409950E-07
     +,   4.1733281E-07,   3.3768902E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_ashz_ttz95 = Yx/0.163068181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4674978E-05,   1.5419275E-05
     +,   1.6183931E-05,   1.6968346E-05,   1.7771859E-05
     +,   1.8593715E-05,   1.9433097E-05,   2.0289115E-05
     +,   2.1160793E-05,   2.2047139E-05,   2.2947053E-05
     +,   2.3859398E-05,   2.4782985E-05,   2.5716581E-05
     +,   2.6658918E-05,   2.7608688E-05,   2.8564569E-05
     +,   2.9525225E-05,   3.0489293E-05,   3.1455427E-05
     +,   3.2422278E-05,   3.3388511E-05,   3.4352797E-05
     +,   3.5313908E-05,   3.6270529E-05,   3.7221511E-05
     +,   3.8165676E-05,   3.9101928E-05,   4.0029237E-05
     +,   4.0946627E-05,   4.1853193E-05,   4.2748110E-05
     +,   4.3630611E-05,   4.4500022E-05,   4.5355737E-05
     +,   4.6197212E-05,   4.7024001E-05,   4.7835685E-05
     +,   4.8631995E-05,   4.9412603E-05,   5.0177332E-05
     +,   5.0926024E-05,   5.1658542E-05,   5.2374813E-05
     +,   5.3074778E-05,   5.3758376E-05,   5.4425593E-05
     +,   5.5076373E-05,   5.5710672E-05,   5.6328419E-05
     +,   5.6929533E-05,   5.7513869E-05,   5.8081248E-05
     +,   5.8631478E-05,   5.9164242E-05,   5.9679242E-05
     +,   6.0176073E-05,   6.0654304E-05,   6.1113409E-05
     +,   6.1552855E-05,   6.1972023E-05,   6.2370280E-05
     +,   6.2746942E-05,   6.3101339E-05,   6.3432773E-05
     +,   6.3740583E-05,   6.4024141E-05,   6.4282860E-05
     +,   6.4516258E-05,   6.4723943E-05,   6.4905675E-05
     +,   6.5061380E-05,   6.5191169E-05,   6.5295382E-05
     +,   6.5374610E-05,   6.5429762E-05,   6.5462038E-05
     +,   6.5473010E-05,   6.5464614E-05,   6.5439184E-05
     +,   6.5399508E-05,   6.5348788E-05,   6.5290726E-05
     +,   6.5229469E-05,   6.5169639E-05,   6.5116357E-05
     +,   6.5075183E-05,   6.5052154E-05,   6.5053697E-05
     +,   6.5086700E-05,   6.5158340E-05,   6.5276108E-05
     +,   6.5447763E-05,   6.5681226E-05,   6.5984510E-05
     +,   6.6365654E-05,   6.6832596E-05,   6.7393063E-05
     +,   6.8054571E-05,   6.8824134E-05,   6.9708309E-05
     +,   7.0712929E-05,   7.1843206E-05,   7.3103249E-05
     +,   7.4496376E-05,   7.6024713E-05,   7.7689139E-05
     +,   7.9489204E-05,   8.1423146E-05,   8.3487808E-05
     +,   8.5678286E-05,   8.7988425E-05,   9.0410242E-05
     +,   9.2934490E-05,   9.5550124E-05,   9.8244927E-05
     +,   1.0100501E-04,   1.0381551E-04,   1.0666008E-04
     +,   1.0952161E-04,   1.1238218E-04,   1.1522295E-04
     +,   1.1802471E-04,   1.2076808E-04,   1.2343371E-04
     +,   1.2600217E-04,   1.2845481E-04,   1.3077322E-04
     +,   1.3294027E-04,   1.3493960E-04,   1.3675640E-04
     +,   1.3837709E-04,   1.3978999E-04,   1.4098494E-04
     +,   1.4195390E-04,   1.4269080E-04,   1.4319160E-04
     +,   1.4345442E-04,   1.4347957E-04,   1.4326947E-04
     +,   1.4282879E-04,   1.4216427E-04,   1.4128465E-04
     +,   1.4020070E-04,   1.3892518E-04,   1.3747257E-04
     +,   1.3585902E-04,   1.3410236E-04,   1.3222182E-04
     +,   1.3023785E-04,   1.2817186E-04,   1.2604619E-04
     +,   1.2388374E-04,   1.2170745E-04,   1.1953992E-04
     +,   1.1740340E-04,   1.1531889E-04,   1.1330547E-04
     +,   1.1138000E-04,   1.0955654E-04,   1.0784546E-04
     +,   1.0625309E-04,   1.0478129E-04,   1.0342697E-04
     +,   1.0218204E-04,   1.0103335E-04,   9.9963407E-05
     +,   9.8951183E-05,   9.7973199E-05,   9.7005868E-05
     +,   9.6027885E-05,   9.5023759E-05,   9.3987255E-05
     +,   9.2925889E-05,   9.1865222E-05,   9.0852169E-05
     +,   8.9958136E-05,   8.9280307E-05,   8.8941888E-05
     +,   8.9092166E-05,   8.9908252E-05,   9.1601578E-05
     +,   9.4433497E-05,   9.8743687E-05,   1.0499328E-04
     +,   1.1382225E-04,   1.2611592E-04,   1.4307545E-04
     +,   1.6628004E-04,   1.9773931E-04,   2.3995533E-04
     +,   2.9600746E-04,   3.6969772E-04,   4.6578693E-04
     +,   5.9031183E-04,   7.5086922E-04,   9.5667393E-04
     +,   1.2181494E-03,   1.5457693E-03,   1.9479414E-03
     +,   2.4280357E-03,   2.9810776E-03,   3.5908855E-03
     +,   4.2285654E-03,   4.8532579E-03,   5.4158806E-03
     +,   5.8651627E-03,   6.1552874E-03,   6.2535317E-03
     +,   6.1460803E-03,   5.8405930E-03,   5.3650909E-03
     +,   4.7632600E-03,   4.0873308E-03,   3.3903045E-03
     +,   2.7190424E-03,   2.1093483E-03,   1.5836937E-03
     +,   1.1515754E-03,   8.1173121E-04,   5.5526453E-04
     +,   3.6906209E-04,   2.3868632E-04,   1.5043022E-04
     +,   9.2523478E-05,   5.5608878E-05,   3.2694643E-05
     +,   1.8817231E-05,   1.0604580E-05,   5.8511637E-06
     +,   3.1599632E-06,   1.6700787E-06,   8.6411467E-07
     +,   4.3847169E-07,   2.1915633E-07,   1.0884163E-07
     +,   5.4542088E-08,   2.8229890E-08,   1.5524416E-08
     +,   9.2804617E-09,   6.0608105E-09,   4.2607118E-09
     +,   3.1484921E-09,   2.3940274E-09,   1.8462365E-09
     +,   1.4321129E-09,   1.1125934E-09,   8.6390395E-10
     +,   6.6981831E-10,   5.1838045E-10,   4.0037981E-10
     +,   3.0860547E-10,   2.3738056E-10,   1.8222369E-10
     +,   1.3959985E-10,   1.0673031E-10,   8.1437232E-11
     +,   6.2015150E-11,   4.7131663E-11,   3.5749147E-11
     +,   2.7062103E-11,   2.0445822E-11,   1.5416638E-11
     +,   1.1601403E-11,   8.7130953E-12,   6.5308293E-12
     +,   4.8852576E-12,   3.6469543E-12,   2.7170282E-12
     +,   2.0200785E-12,   1.4987917E-12,   1.1097111E-12
     +,   8.1991965E-13,   6.0452104E-13,   4.4475261E-13
     +,   3.2650681E-13,   2.3917508E-13,   1.7481952E-13
     +,   1.2749579E-13,   9.2775885E-14,   6.7358045E-14
     +,   4.8793380E-14,   3.5264031E-14,   2.5427453E-14
     +,   1.8291888E-14,   1.3128070E-14,   9.3997880E-15
     +,   6.7142671E-15,   4.7846160E-15,   3.4013078E-15
     +,   2.4121275E-15,   1.7064584E-15,   1.2043023E-15
     +,   8.4782429E-16,   5.9540614E-16,   4.1710165E-16
     +,   2.9147391E-16,   2.0317541E-16,   1.4127489E-16
     +,   9.7986300E-17,   6.7792699E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt100 = Yx/0.0245
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3012940E-05,   7.6766846E-05
     +,   8.0684811E-05,   8.4768064E-05,   8.9017194E-05
     +,   9.3431736E-05,   9.8010270E-05,   1.0275031E-04
     +,   1.0764803E-04,   1.1269868E-04,   1.1789589E-04
     +,   1.2323208E-04,   1.2869816E-04,   1.3428373E-04
     +,   1.3997688E-04,   1.4576424E-04,   1.5163107E-04
     +,   1.5756127E-04,   1.6353745E-04,   1.6954100E-04
     +,   1.7555215E-04,   1.8155031E-04,   1.8751372E-04
     +,   1.9342052E-04,   1.9924765E-04,   2.0497236E-04
     +,   2.1057148E-04,   2.1602202E-04,   2.2130145E-04
     +,   2.2638770E-04,   2.3125946E-04,   2.3589667E-04
     +,   2.4028035E-04,   2.4439319E-04,   2.4821924E-04
     +,   2.5174493E-04,   2.5495823E-04,   2.5784975E-04
     +,   2.6041234E-04,   2.6264103E-04,   2.6453385E-04
     +,   2.6609135E-04,   2.6731630E-04,   2.6821467E-04
     +,   2.6879457E-04,   2.6906704E-04,   2.6904538E-04
     +,   2.6874529E-04,   2.6818452E-04,   2.6738306E-04
     +,   2.6636262E-04,   2.6514655E-04,   2.6375960E-04
     +,   2.6222761E-04,   2.6057742E-04,   2.5883640E-04
     +,   2.5703234E-04,   2.5519312E-04,   2.5334652E-04
     +,   2.5151987E-04,   2.4973977E-04,   2.4803219E-04
     +,   2.4642190E-04,   2.4493251E-04,   2.4358621E-04
     +,   2.4240368E-04,   2.4140408E-04,   2.4060502E-04
     +,   2.4002236E-04,   2.3967010E-04,   2.3956098E-04
     +,   2.3970570E-04,   2.4011383E-04,   2.4079318E-04
     +,   2.4175028E-04,   2.4299054E-04,   2.4451810E-04
     +,   2.4633596E-04,   2.4844625E-04,   2.5085054E-04
     +,   2.5354896E-04,   2.5654165E-04,   2.5982753E-04
     +,   2.6340538E-04,   2.6727279E-04,   2.7142759E-04
     +,   2.7586601E-04,   2.8058438E-04,   2.8557793E-04
     +,   2.9084118E-04,   2.9636800E-04,   3.0215085E-04
     +,   3.0818078E-04,   3.1444815E-04,   3.2094138E-04
     +,   3.2764702E-04,   3.3454996E-04,   3.4163205E-04
     +,   3.4887419E-04,   3.5625312E-04,   3.6374450E-04
     +,   3.7132006E-04,   3.7895041E-04,   3.8660309E-04
     +,   3.9424465E-04,   4.0184104E-04,   4.0935757E-04
     +,   4.1676071E-04,   4.2401999E-04,   4.3110843E-04
     +,   4.3800380E-04,   4.4469128E-04,   4.5116333E-04
     +,   4.5742243E-04,   4.6348030E-04,   4.6936009E-04
     +,   4.7509486E-04,   4.8072787E-04,   4.8631127E-04
     +,   4.9190404E-04,   4.9757032E-04,   5.0337549E-04
     +,   5.0938415E-04,   5.1565591E-04,   5.2224239E-04
     +,   5.2918331E-04,   5.3650473E-04,   5.4421544E-04
     +,   5.5230764E-04,   5.6075380E-04,   5.6951056E-04
     +,   5.7851733E-04,   5.8770197E-04,   5.9698214E-04
     +,   6.0627109E-04,   6.1548315E-04,   6.2453607E-04
     +,   6.3335762E-04,   6.4188975E-04,   6.5009011E-04
     +,   6.5793446E-04,   6.6541648E-04,   6.7254587E-04
     +,   6.7934627E-04,   6.8584882E-04,   6.9208728E-04
     +,   6.9809158E-04,   7.0387940E-04,   7.0944993E-04
     +,   7.1477838E-04,   7.1981089E-04,   7.2446046E-04
     +,   7.2860910E-04,   7.3210796E-04,   7.3478254E-04
     +,   7.3644205E-04,   7.3688623E-04,   7.3591998E-04
     +,   7.3336420E-04,   7.2907109E-04,   7.2293560E-04
     +,   7.1490795E-04,   7.0500269E-04,   6.9330679E-04
     +,   6.7998120E-04,   6.6526164E-04,   6.4945407E-04
     +,   6.3292799E-04,   6.1610190E-04,   5.9943029E-04
     +,   5.8338797E-04,   5.6845089E-04,   5.5507565E-04
     +,   5.4368324E-04,   5.3464173E-04,   5.2824995E-04
     +,   5.2472641E-04,   5.2419992E-04,   5.2670477E-04
     +,   5.3217745E-04,   5.4046157E-04,   5.5131083E-04
     +,   5.6439865E-04,   5.7933095E-04,   5.9565896E-04
     +,   6.1289250E-04,   6.3051732E-04,   6.4801215E-04
     +,   6.6486286E-04,   6.8057620E-04,   6.9469551E-04
     +,   7.0681027E-04,   7.1656477E-04,   7.2366680E-04
     +,   7.2789146E-04,   7.2908337E-04,   7.2715653E-04
     +,   7.2209252E-04,   7.1393617E-04,   7.0279028E-04
     +,   6.8880979E-04,   6.7219365E-04,   6.5317593E-04
     +,   6.3201709E-04,   6.0900033E-04,   5.8441708E-04
     +,   5.5856293E-04,   5.3173327E-04,   5.0421502E-04
     +,   4.7628043E-04,   4.4818508E-04,   4.2016624E-04
     +,   3.9244001E-04,   3.6519757E-04,   3.3860642E-04
     +,   3.1281257E-04,   2.8793901E-04,   2.6408496E-04
     +,   2.4132912E-04,   2.1973280E-04,   1.9933749E-04
     +,   1.8016815E-04,   1.6223654E-04,   1.4554098E-04
     +,   1.3006703E-04,   1.1579027E-04,   1.0267848E-04
     +,   9.0691727E-05,   7.9783262E-05,   6.9901347E-05
     +,   6.0991119E-05,   5.2994743E-05,   4.5852037E-05
     +,   3.9501956E-05,   3.3883982E-05,   2.8937591E-05
     +,   2.4603640E-05,   2.0825119E-05,   1.7547305E-05
     +,   1.4717978E-05,   1.2288010E-05,   1.0211676E-05
     +,   8.4466219E-06,   6.9538178E-06,   5.6977387E-06
     +,   4.6463474E-06,   3.7708860E-06,   3.0456840E-06
     +,   2.4480714E-06,   1.9582089E-06,   1.5587610E-06
     +,   1.2347388E-06,   9.7329178E-07,   7.6345162E-07
     +,   5.9591224E-07,   4.6284646E-07,   3.5772160E-07
     +,   2.7511061E-07,   2.1053111E-07,   1.6031183E-07
     +,   1.2146639E-07,   9.1577753E-08,   6.8700658E-08
     +,   5.1281784E-08,   3.8089297E-08,   2.8149785E-08
     +,   2.0700146E-08,   1.5146123E-08,   1.1027122E-08
     +,   7.9882199E-09,   5.7578351E-09,   4.1294665E-09
     +,   2.9468443E-09,   2.0923954E-09,   1.4782483E-09
     +,   1.0391480E-09,   7.2681272E-10,   5.0581539E-10
     +,   3.5024683E-10,   2.4131205E-10,   1.6542234E-10
     +,   1.1283142E-10,   7.6572762E-11,   5.1705449E-11
     +,   3.4737959E-11,   2.3221413E-11,   1.5444807E-11
     +,   1.0220661E-11,   6.7295895E-12,   4.4085902E-12
     +,   2.8735814E-12,   1.8635831E-12,   1.2025083E-12
     +,   7.7202578E-13,   4.9316904E-13,   3.1345334E-13
     +,   1.9823703E-13,   1.2474746E-13,   7.8117024E-14
     +,   4.8679061E-14,   3.0190890E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt105 = Yx/0.0221666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2999655E-05,   1.4533516E-05
     +,   1.6209458E-05,   1.8035375E-05,   2.0018921E-05
     +,   2.2167429E-05,   2.4487788E-05,   2.6986358E-05
     +,   2.9668794E-05,   3.2540131E-05,   3.5604386E-05
     +,   3.8864673E-05,   4.2323019E-05,   4.5980280E-05
     +,   4.9836090E-05,   5.3888765E-05,   5.8135272E-05
     +,   6.2571198E-05,   6.7190718E-05,   7.1986608E-05
     +,   7.6950309E-05,   8.2071943E-05,   8.7340319E-05
     +,   9.2743474E-05,   9.8267810E-05,   1.0389947E-04
     +,   1.0962355E-04,   1.1542465E-04,   1.2128700E-04
     +,   1.2719464E-04,   1.3313163E-04,   1.3908207E-04
     +,   1.4503054E-04,   1.5096185E-04,   1.5686166E-04
     +,   1.6271605E-04,   1.6851195E-04,   1.7423701E-04
     +,   1.7987993E-04,   1.8542951E-04,   1.9087586E-04
     +,   1.9620913E-04,   2.0142013E-04,   2.0649967E-04
     +,   2.1143872E-04,   2.1622793E-04,   2.2085768E-04
     +,   2.2531759E-04,   2.2959660E-04,   2.3368250E-04
     +,   2.3756223E-04,   2.4122128E-04,   2.4464415E-04
     +,   2.4781423E-04,   2.5071352E-04,   2.5332364E-04
     +,   2.5562543E-04,   2.5759957E-04,   2.5922700E-04
     +,   2.6048944E-04,   2.6137009E-04,   2.6185409E-04
     +,   2.6192909E-04,   2.6158654E-04,   2.6082175E-04
     +,   2.5963498E-04,   2.5803183E-04,   2.5602433E-04
     +,   2.5363074E-04,   2.5087685E-04,   2.4779531E-04
     +,   2.4442683E-04,   2.4081911E-04,   2.3702758E-04
     +,   2.3311444E-04,   2.2914819E-04,   2.2520313E-04
     +,   2.2135845E-04,   2.1769649E-04,   2.1430220E-04
     +,   2.1126161E-04,   2.0865999E-04,   2.0658072E-04
     +,   2.0510322E-04,   2.0430188E-04,   2.0424406E-04
     +,   2.0498862E-04,   2.0658500E-04,   2.0907134E-04
     +,   2.1247394E-04,   2.1680650E-04,   2.2206899E-04
     +,   2.2824743E-04,   2.3531439E-04,   2.4322902E-04
     +,   2.5193638E-04,   2.6136998E-04,   2.7145099E-04
     +,   2.8209106E-04,   2.9319184E-04,   3.0464903E-04
     +,   3.1635116E-04,   3.2818501E-04,   3.4003396E-04
     +,   3.5178350E-04,   3.6332183E-04,   3.7454153E-04
     +,   3.8534240E-04,   3.9563447E-04,   4.0533900E-04
     +,   4.1438924E-04,   4.2273395E-04,   4.3033678E-04
     +,   4.3717810E-04,   4.4325381E-04,   4.4857667E-04
     +,   4.5317406E-04,   4.5708779E-04,   4.6037129E-04
     +,   4.6308781E-04,   4.6530829E-04,   4.6710769E-04
     +,   4.6856230E-04,   4.6974744E-04,   4.7073406E-04
     +,   4.7158657E-04,   4.7236119E-04,   4.7310448E-04
     +,   4.7385271E-04,   4.7463155E-04,   4.7545790E-04
     +,   4.7633977E-04,   4.7728012E-04,   4.7827789E-04
     +,   4.7933168E-04,   4.8044199E-04,   4.8161444E-04
     +,   4.8286151E-04,   4.8420494E-04,   4.8567666E-04
     +,   4.8731823E-04,   4.8918137E-04,   4.9132539E-04
     +,   4.9381499E-04,   4.9671641E-04,   5.0009479E-04
     +,   5.0400838E-04,   5.0850562E-04,   5.1361963E-04
     +,   5.1936629E-04,   5.2574021E-04,   5.3271279E-04
     +,   5.4023194E-04,   5.4822298E-04,   5.5659009E-04
     +,   5.6521874E-04,   5.7398109E-04,   5.8274111E-04
     +,   5.9136056E-04,   5.9970497E-04,   6.0765201E-04
     +,   6.1509665E-04,   6.2195858E-04,   6.2818604E-04
     +,   6.3376199E-04,   6.3870545E-04,   6.4307154E-04
     +,   6.4695190E-04,   6.5046956E-04,   6.5377424E-04
     +,   6.5703387E-04,   6.6042528E-04,   6.6412345E-04
     +,   6.6828978E-04,   6.7305932E-04,   6.7853130E-04
     +,   6.8475713E-04,   6.9173402E-04,   6.9939863E-04
     +,   7.0762623E-04,   7.1623217E-04,   7.2497473E-04
     +,   7.3356612E-04,   7.4168260E-04,   7.4897765E-04
     +,   7.5509807E-04,   7.5969781E-04,   7.6245592E-04
     +,   7.6308905E-04,   7.6136360E-04,   7.5710600E-04
     +,   7.5020932E-04,   7.4063521E-04,   7.2841509E-04
     +,   7.1364496E-04,   6.9647981E-04,   6.7712582E-04
     +,   6.5582962E-04,   6.3286576E-04,   6.0852594E-04
     +,   5.8310962E-04,   5.5691320E-04,   5.3021836E-04
     +,   5.0328701E-04,   4.7635884E-04,   4.4964277E-04
     +,   4.2331786E-04,   3.9753437E-04,   3.7241442E-04
     +,   3.4805181E-04,   3.2451723E-04,   3.0186289E-04
     +,   2.8012469E-04,   2.5932366E-04,   2.3947110E-04
     +,   2.2057195E-04,   2.0262563E-04,   1.8562641E-04
     +,   1.6956581E-04,   1.5443459E-04,   1.4021988E-04
     +,   1.2690708E-04,   1.1448012E-04,   1.0292067E-04
     +,   9.2206908E-05,   8.2314444E-05,   7.3216652E-05
     +,   6.4884101E-05,   5.7284120E-05,   5.0381692E-05
     +,   4.4140259E-05,   3.8521568E-05,   3.3485827E-05
     +,   2.8992632E-05,   2.5001882E-05,   2.1473323E-05
     +,   1.8367502E-05,   1.5646334E-05,   1.3273142E-05
     +,   1.1212845E-05,   9.4323595E-06,   7.9008305E-06
     +,   6.5895965E-06,   5.4721559E-06,   4.5242919E-06
     +,   3.7240854E-06,   3.0517558E-06,   2.4895419E-06
     +,   2.0216551E-06,   1.6341789E-06,   1.3148496E-06
     +,   1.0529660E-06,   8.3926744E-07,   6.6576359E-07
     +,   5.2559761E-07,   4.1293396E-07,   3.2284208E-07
     +,   2.5117149E-07,   1.9444822E-07,   1.4978696E-07
     +,   1.1480788E-07,   8.7556622E-08,   6.6437181E-08
     +,   5.0156174E-08,   3.7672656E-08,   2.8151709E-08
     +,   2.0928949E-08,   1.5479271E-08,   1.1389683E-08
     +,   8.3371994E-09,   6.0710783E-09,   4.3979220E-09
     +,   3.1693146E-09,   2.2720090E-09,   1.6202182E-09
     +,   1.1493723E-09,   8.1107265E-10,   5.6934707E-10
     +,   3.9755735E-10,   2.7614405E-10,   1.9079756E-10
     +,   1.3113523E-10,   8.9652619E-11,   6.0969570E-11
     +,   4.1243647E-11,   2.7752689E-11,   1.8575913E-11
     +,   1.2367622E-11,   8.1907319E-12,   5.3956965E-12
     +,   3.5356735E-12,   2.3045324E-12,   1.4941431E-12
     +,   9.6357807E-13,   6.1812789E-13,   3.9441467E-13
     +,   2.5033637E-13,   1.5804378E-13,   9.9248822E-14
     +,   6.1994721E-14,   3.8519250E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt107 = Yx/0.019
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9053059E-05,   2.9916446E-05
     +,   3.0794225E-05,   3.1688647E-05,   3.2602333E-05
     +,   3.3538261E-05,   3.4499779E-05,   3.5490611E-05
     +,   3.6514801E-05,   3.7576796E-05,   3.8681297E-05
     +,   3.9833285E-05,   4.1037994E-05,   4.2300842E-05
     +,   4.3627380E-05,   4.5023222E-05,   4.6493988E-05
     +,   4.8045229E-05,   4.9682345E-05,   5.1410469E-05
     +,   5.3234420E-05,   5.5158620E-05,   5.7186906E-05
     +,   5.9322694E-05,   6.1568433E-05,   6.3926098E-05
     +,   6.6396657E-05,   6.8980218E-05,   7.1675990E-05
     +,   7.4482101E-05,   7.7395744E-05,   8.0413105E-05
     +,   8.3529361E-05,   8.6738779E-05,   9.0034751E-05
     +,   9.3409930E-05,   9.6856282E-05,   1.0036530E-04
     +,   1.0392845E-04,   1.0753665E-04,   1.1118150E-04
     +,   1.1485485E-04,   1.1854938E-04,   1.2225888E-04
     +,   1.2597849E-04,   1.2970528E-04,   1.3343834E-04
     +,   1.3717916E-04,   1.4093195E-04,   1.4470391E-04
     +,   1.4850528E-04,   1.5234966E-04,   1.5625378E-04
     +,   1.6023783E-04,   1.6432469E-04,   1.6854034E-04
     +,   1.7291290E-04,   1.7747229E-04,   1.8224961E-04
     +,   1.8727627E-04,   1.9258310E-04,   1.9819947E-04
     +,   2.0415170E-04,   2.1046289E-04,   2.1715110E-04
     +,   2.2422789E-04,   2.3169840E-04,   2.3955863E-04
     +,   2.4779653E-04,   2.5638938E-04,   2.6530493E-04
     +,   2.7449918E-04,   2.8391872E-04,   2.9349816E-04
     +,   3.0316319E-04,   3.1283000E-04,   3.2240612E-04
     +,   3.3179231E-04,   3.4088452E-04,   3.4957554E-04
     +,   3.5775584E-04,   3.6531797E-04,   3.7215668E-04
     +,   3.7817319E-04,   3.8327568E-04,   3.8738330E-04
     +,   3.9042643E-04,   3.9235025E-04,   3.9311510E-04
     +,   3.9269848E-04,   3.9109541E-04,   3.8831923E-04
     +,   3.8440165E-04,   3.7939247E-04,   3.7335797E-04
     +,   3.6638111E-04,   3.5855846E-04,   3.4999943E-04
     +,   3.4082276E-04,   3.3115555E-04,   3.2112893E-04
     +,   3.1087693E-04,   3.0053232E-04,   2.9022546E-04
     +,   2.8008039E-04,   2.7021309E-04,   2.6073045E-04
     +,   2.5172759E-04,   2.4328660E-04,   2.3547596E-04
     +,   2.2835095E-04,   2.2195208E-04,   2.1630710E-04
     +,   2.1143029E-04,   2.0732480E-04,   2.0398299E-04
     +,   2.0138858E-04,   1.9951776E-04,   1.9834137E-04
     +,   1.9782613E-04,   1.9793643E-04,   1.9863580E-04
     +,   1.9988784E-04,   2.0165753E-04,   2.0391181E-04
     +,   2.0661981E-04,   2.0975353E-04,   2.1328694E-04
     +,   2.1719647E-04,   2.2145973E-04,   2.2605530E-04
     +,   2.3096113E-04,   2.3615493E-04,   2.4161178E-04
     +,   2.4730456E-04,   2.5320280E-04,   2.5927217E-04
     +,   2.6547408E-04,   2.7176653E-04,   2.7810401E-04
     +,   2.8443761E-04,   2.9071630E-04,   2.9688887E-04
     +,   3.0290429E-04,   3.0871303E-04,   3.1426994E-04
     +,   3.1953477E-04,   3.2447372E-04,   3.2906124E-04
     +,   3.3328129E-04,   3.3712795E-04,   3.4060562E-04
     +,   3.4372995E-04,   3.4652732E-04,   3.4903406E-04
     +,   3.5129566E-04,   3.5336526E-04,   3.5530227E-04
     +,   3.5717044E-04,   3.5903530E-04,   3.6096250E-04
     +,   3.6301542E-04,   3.6525284E-04,   3.6772664E-04
     +,   3.7048041E-04,   3.7354743E-04,   3.7694880E-04
     +,   3.8069283E-04,   3.8477412E-04,   3.8917328E-04
     +,   3.9385605E-04,   3.9877422E-04,   4.0386670E-04
     +,   4.0905960E-04,   4.1426797E-04,   4.1939763E-04
     +,   4.2434721E-04,   4.2900970E-04,   4.3327524E-04
     +,   4.3703403E-04,   4.4017858E-04,   4.4260579E-04
     +,   4.4422047E-04,   4.4493683E-04,   4.4468159E-04
     +,   4.4339479E-04,   4.4103226E-04,   4.3756576E-04
     +,   4.3298461E-04,   4.2729537E-04,   4.2052136E-04
     +,   4.1270186E-04,   4.0389178E-04,   3.9415952E-04
     +,   3.8358432E-04,   3.7225490E-04,   3.6026773E-04
     +,   3.4772395E-04,   3.3472691E-04,   3.2137948E-04
     +,   3.0778395E-04,   2.9403885E-04,   2.8023648E-04
     +,   2.6646262E-04,   2.5279721E-04,   2.3931036E-04
     +,   2.2606402E-04,   2.1311245E-04,   2.0050148E-04
     +,   1.8826817E-04,   1.7644222E-04,   1.6504717E-04
     +,   1.5410046E-04,   1.4361333E-04,   1.3359236E-04
     +,   1.2404083E-04,   1.1495843E-04,   1.0634153E-04
     +,   9.8184086E-05,   9.0479007E-05,   8.3216779E-05
     +,   7.6386612E-05,   6.9977126E-05,   6.3975967E-05
     +,   5.8369624E-05,   5.3143991E-05,   4.8284772E-05
     +,   4.3777163E-05,   3.9605678E-05,   3.5754576E-05
     +,   3.2208172E-05,   2.8950593E-05,   2.5965734E-05
     +,   2.3237555E-05,   2.0750436E-05,   1.8488698E-05
     +,   1.6437027E-05,   1.4580627E-05,   1.2905140E-05
     +,   1.1396633E-05,   1.0041766E-05,   8.8279194E-06
     +,   7.7431014E-06,   6.7759261E-06,   5.9157096E-06
     +,   5.1525139E-06,   4.4770718E-06,   3.8807434E-06
     +,   3.3555480E-06,   2.8941879E-06,   2.4899159E-06
     +,   2.1365643E-06,   1.8285351E-06,   1.5607335E-06
     +,   1.3285252E-06,   1.1277255E-06,   9.5457722E-07
     +,   8.0570271E-07,   6.7806610E-07,   5.6895800E-07
     +,   4.7597325E-07,   3.9697423E-07,   3.3006492E-07
     +,   2.7357285E-07,   2.2603309E-07,   1.8615644E-07
     +,   1.5281738E-07,   1.2503885E-07,   1.0197267E-07
     +,   8.2884632E-08,   6.7143027E-08,   5.4207131E-08
     +,   4.3614733E-08,   3.4971876E-08,   2.7944841E-08
     +,   2.2252561E-08,   1.7657928E-08,   1.3963059E-08
     +,   1.1002464E-08,   8.6391081E-09,   6.7593544E-09
     +,   5.2698890E-09,   4.0939860E-09,   3.1691498E-09
     +,   2.4444460E-09,   1.8787278E-09,   1.4387510E-09
     +,   1.0978433E-09,   8.3470436E-10,   6.3234440E-10
     +,   4.7731835E-10,   3.5899411E-10,   2.6902819E-10
     +,   2.0087704E-10,   1.4944870E-10,   1.1078287E-10
     +,   8.1824041E-11,   6.0215319E-11,   4.4152838E-11
     +,   3.2257207E-11,   2.3481167E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt110 = Yx/0.0129230769230769
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.3414154E-05,   8.5781372E-05
     +,   8.8187364E-05,   9.0634487E-05,   9.3125142E-05
     +,   9.5661635E-05,   9.8246310E-05,   1.0088133E-04
     +,   1.0356872E-04,   1.0631043E-04,   1.0910814E-04
     +,   1.1196331E-04,   1.1487718E-04,   1.1785074E-04
     +,   1.2088475E-04,   1.2397970E-04,   1.2713589E-04
     +,   1.3035329E-04,   1.3363179E-04,   1.3697102E-04
     +,   1.4037055E-04,   1.4382978E-04,   1.4734794E-04
     +,   1.5092448E-04,   1.5455838E-04,   1.5824907E-04
     +,   1.6199576E-04,   1.6579762E-04,   1.6965394E-04
     +,   1.7356395E-04,   1.7752680E-04,   1.8154162E-04
     +,   1.8560728E-04,   1.8972252E-04,   1.9388575E-04
     +,   1.9809483E-04,   2.0234731E-04,   2.0663987E-04
     +,   2.1096878E-04,   2.1532890E-04,   2.1971464E-04
     +,   2.2411895E-04,   2.2853365E-04,   2.3294937E-04
     +,   2.3735520E-04,   2.4173899E-04,   2.4608703E-04
     +,   2.5038427E-04,   2.5461419E-04,   2.5875916E-04
     +,   2.6280005E-04,   2.6671687E-04,   2.7048856E-04
     +,   2.7409368E-04,   2.7750985E-04,   2.8071471E-04
     +,   2.8368598E-04,   2.8640160E-04,   2.8884021E-04
     +,   2.9098132E-04,   2.9280563E-04,   2.9429575E-04
     +,   2.9543572E-04,   2.9621218E-04,   2.9661384E-04
     +,   2.9663224E-04,   2.9626195E-04,   2.9550045E-04
     +,   2.9434860E-04,   2.9281067E-04,   2.9089412E-04
     +,   2.8861038E-04,   2.8597386E-04,   2.8300265E-04
     +,   2.7971814E-04,   2.7614465E-04,   2.7230973E-04
     +,   2.6824360E-04,   2.6397876E-04,   2.5954988E-04
     +,   2.5499359E-04,   2.5034745E-04,   2.4565068E-04
     +,   2.4094226E-04,   2.3626201E-04,   2.3164878E-04
     +,   2.2714112E-04,   2.2277588E-04,   2.1858861E-04
     +,   2.1461249E-04,   2.1087800E-04,   2.0741313E-04
     +,   2.0424245E-04,   2.0138685E-04,   1.9886327E-04
     +,   1.9668494E-04,   1.9486051E-04,   1.9339453E-04
     +,   1.9228681E-04,   1.9153305E-04,   1.9112416E-04
     +,   1.9104705E-04,   1.9128418E-04,   1.9181418E-04
     +,   1.9261197E-04,   1.9364888E-04,   1.9489329E-04
     +,   1.9631078E-04,   1.9786475E-04,   1.9951671E-04
     +,   2.0122693E-04,   2.0295482E-04,   2.0465946E-04
     +,   2.0630045E-04,   2.0783792E-04,   2.0923365E-04
     +,   2.1045109E-04,   2.1145646E-04,   2.1221874E-04
     +,   2.1271053E-04,   2.1290829E-04,   2.1279266E-04
     +,   2.1234924E-04,   2.1156851E-04,   2.1044601E-04
     +,   2.0898302E-04,   2.0718596E-04,   2.0506713E-04
     +,   2.0264402E-04,   1.9993987E-04,   1.9698258E-04
     +,   1.9380564E-04,   1.9044644E-04,   1.8694701E-04
     +,   1.8335275E-04,   1.7971219E-04,   1.7607657E-04
     +,   1.7249903E-04,   1.6903366E-04,   1.6573530E-04
     +,   1.6265847E-04,   1.5985723E-04,   1.5738353E-04
     +,   1.5528733E-04,   1.5361577E-04,   1.5241250E-04
     +,   1.5171705E-04,   1.5156467E-04,   1.5198553E-04
     +,   1.5300480E-04,   1.5464201E-04,   1.5691119E-04
     +,   1.5982054E-04,   1.6337259E-04,   1.6756442E-04
     +,   1.7238744E-04,   1.7782742E-04,   1.8386566E-04
     +,   1.9047865E-04,   1.9763788E-04,   2.0531140E-04
     +,   2.1346343E-04,   2.2205456E-04,   2.3104224E-04
     +,   2.4038162E-04,   2.5002557E-04,   2.5992433E-04
     +,   2.7002595E-04,   2.8027777E-04,   2.9062509E-04
     +,   3.0101152E-04,   3.1137909E-04,   3.2166968E-04
     +,   3.3182377E-04,   3.4177999E-04,   3.5147750E-04
     +,   3.6085446E-04,   3.6984851E-04,   3.7839718E-04
     +,   3.8643880E-04,   3.9391278E-04,   4.0075911E-04
     +,   4.0691992E-04,   4.1234022E-04,   4.1696813E-04
     +,   4.2075524E-04,   4.2365803E-04,   4.2563834E-04
     +,   4.2666413E-04,   4.2670974E-04,   4.2575682E-04
     +,   4.2379479E-04,   4.2082128E-04,   4.1684232E-04
     +,   4.1187255E-04,   4.0593476E-04,   3.9906066E-04
     +,   3.9129023E-04,   3.8267087E-04,   3.7325668E-04
     +,   3.6310905E-04,   3.5229520E-04,   3.4088633E-04
     +,   3.2895739E-04,   3.1658751E-04,   3.0385624E-04
     +,   2.9084386E-04,   2.7763139E-04,   2.6429852E-04
     +,   2.5092179E-04,   2.3757477E-04,   2.2432808E-04
     +,   2.1124796E-04,   1.9839458E-04,   1.8582284E-04
     +,   1.7358264E-04,   1.6171778E-04,   1.5026523E-04
     +,   1.3925583E-04,   1.2871563E-04,   1.1866356E-04
     +,   1.0911318E-04,   1.0007339E-04,   9.1548100E-05
     +,   8.3536164E-05,   7.6032498E-05,   6.9028822E-05
     +,   6.2513704E-05,   5.6472545E-05,   5.0888546E-05
     +,   4.5743443E-05,   4.1017483E-05,   3.6689511E-05
     +,   3.2737717E-05,   2.9140270E-05,   2.5874784E-05
     +,   2.2919055E-05,   2.0251391E-05,   1.7850569E-05
     +,   1.5695859E-05,   1.3767333E-05,   1.2046065E-05
     +,   1.0514043E-05,   9.1541433E-06,   7.9502815E-06
     +,   6.8874915E-06,   5.9518256E-06,   5.1302886E-06
     +,   4.4109047E-06,   3.7827303E-06,   3.2356854E-06
     +,   2.7605829E-06,   2.3491134E-06,   1.9937497E-06
     +,   1.6876838E-06,   1.4248042E-06,   1.1996584E-06
     +,   1.0073794E-06,   8.4362938E-07,   7.0456775E-07
     +,   5.8681530E-07,   4.8739668E-07,   4.0369764E-07
     +,   3.3343588E-07,   2.7463051E-07,   2.2555683E-07
     +,   1.8472420E-07,   1.5085094E-07,   1.2283586E-07
     +,   9.9734514E-08,   8.0741977E-08,   6.5175406E-08
     +,   5.2456027E-08,   4.2094474E-08,   3.3679385E-08
     +,   2.6866614E-08,   2.1367773E-08,   1.6943558E-08
     +,   1.3394818E-08,   1.0557409E-08,   8.2957312E-09
     +,   6.4987580E-09,   5.0754361E-09,   3.9517114E-09
     +,   3.0672900E-09,   2.3734783E-09,   1.8309133E-09
     +,   1.4079768E-09,   1.0793724E-09,   8.2486612E-10
     +,   6.2840028E-10,   4.7721938E-10,   3.6127085E-10
     +,   2.7262759E-10,   2.0508449E-10,   1.5378399E-10
     +,   1.1495004E-10,   8.5647774E-11,   6.3611630E-11
     +,   4.7093347E-11,   3.4752850E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt115 = Yx/0.0126538461538462
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.2365372E-05,   7.4880511E-05
     +,   7.7470773E-05,   8.0133810E-05,   8.2866631E-05
     +,   8.5665561E-05,   8.8526212E-05,   9.1443457E-05
     +,   9.4411458E-05,   9.7423661E-05,   1.0047282E-04
     +,   1.0355087E-04,   1.0664915E-04,   1.0975840E-04
     +,   1.1286872E-04,   1.1596969E-04,   1.1905050E-04
     +,   1.2209993E-04,   1.2510648E-04,   1.2805853E-04
     +,   1.3094438E-04,   1.3375234E-04,   1.3647100E-04
     +,   1.3908923E-04,   1.4159622E-04,   1.4398195E-04
     +,   1.4623691E-04,   1.4835254E-04,   1.5032114E-04
     +,   1.5213608E-04,   1.5379199E-04,   1.5528467E-04
     +,   1.5661132E-04,   1.5777047E-04,   1.5876218E-04
     +,   1.5958799E-04,   1.6025094E-04,   1.6075555E-04
     +,   1.6110788E-04,   1.6131533E-04,   1.6138676E-04
     +,   1.6133228E-04,   1.6116317E-04,   1.6089182E-04
     +,   1.6053153E-04,   1.6009643E-04,   1.5960124E-04
     +,   1.5906119E-04,   1.5849185E-04,   1.5790893E-04
     +,   1.5732813E-04,   1.5676495E-04,   1.5623459E-04
     +,   1.5575170E-04,   1.5533040E-04,   1.5498413E-04
     +,   1.5472539E-04,   1.5456587E-04,   1.5451625E-04
     +,   1.5458628E-04,   1.5478466E-04,   1.5511907E-04
     +,   1.5559615E-04,   1.5622171E-04,   1.5700053E-04
     +,   1.5793659E-04,   1.5903309E-04,   1.6029249E-04
     +,   1.6171671E-04,   1.6330699E-04,   1.6506425E-04
     +,   1.6698874E-04,   1.6908062E-04,   1.7133939E-04
     +,   1.7376442E-04,   1.7635479E-04,   1.7910900E-04
     +,   1.8202513E-04,   1.8510096E-04,   1.8833367E-04
     +,   1.9171946E-04,   1.9525431E-04,   1.9893267E-04
     +,   2.0274850E-04,   2.0669411E-04,   2.1076108E-04
     +,   2.1493898E-04,   2.1921644E-04,   2.2357996E-04
     +,   2.2801488E-04,   2.3250487E-04,   2.3703162E-04
     +,   2.4157512E-04,   2.4611416E-04,   2.5062618E-04
     +,   2.5508669E-04,   2.5947086E-04,   2.6375221E-04
     +,   2.6790419E-04,   2.7189936E-04,   2.7571074E-04
     +,   2.7931086E-04,   2.8267343E-04,   2.8577249E-04
     +,   2.8858354E-04,   2.9108371E-04,   2.9325139E-04
     +,   2.9506726E-04,   2.9651463E-04,   2.9757892E-04
     +,   2.9824843E-04,   2.9851450E-04,   2.9837113E-04
     +,   2.9781577E-04,   2.9684886E-04,   2.9547387E-04
     +,   2.9369767E-04,   2.9152961E-04,   2.8898256E-04
     +,   2.8607182E-04,   2.8281528E-04,   2.7923344E-04
     +,   2.7534887E-04,   2.7118629E-04,   2.6677173E-04
     +,   2.6213337E-04,   2.5729995E-04,   2.5230178E-04
     +,   2.4716911E-04,   2.4193361E-04,   2.3662616E-04
     +,   2.3127846E-04,   2.2592109E-04,   2.2058490E-04
     +,   2.1529940E-04,   2.1009323E-04,   2.0499430E-04
     +,   2.0002911E-04,   1.9522257E-04,   1.9059813E-04
     +,   1.8617781E-04,   1.8198199E-04,   1.7802915E-04
     +,   1.7433593E-04,   1.7091769E-04,   1.6778766E-04
     +,   1.6495748E-04,   1.6243738E-04,   1.6023593E-04
     +,   1.5836021E-04,   1.5681582E-04,   1.5560733E-04
     +,   1.5473797E-04,   1.5420985E-04,   1.5402393E-04
     +,   1.5418038E-04,   1.5467833E-04,   1.5551591E-04
     +,   1.5669041E-04,   1.5819800E-04,   1.6003395E-04
     +,   1.6219246E-04,   1.6466649E-04,   1.6744759E-04
     +,   1.7052604E-04,   1.7389064E-04,   1.7752829E-04
     +,   1.8142395E-04,   1.8556086E-04,   1.8992029E-04
     +,   1.9448090E-04,   1.9921928E-04,   2.0410978E-04
     +,   2.0912467E-04,   2.1423344E-04,   2.1940387E-04
     +,   2.2460190E-04,   2.2979101E-04,   2.3493345E-04
     +,   2.3999030E-04,   2.4492174E-04,   2.4968697E-04
     +,   2.5424510E-04,   2.5855578E-04,   2.6257918E-04
     +,   2.6627668E-04,   2.6961093E-04,   2.7254727E-04
     +,   2.7505326E-04,   2.7709932E-04,   2.7865931E-04
     +,   2.7971095E-04,   2.8023569E-04,   2.8021939E-04
     +,   2.7965219E-04,   2.7852904E-04,   2.7684911E-04
     +,   2.7461667E-04,   2.7184025E-04,   2.6853260E-04
     +,   2.6471110E-04,   2.6039709E-04,   2.5561528E-04
     +,   2.5039364E-04,   2.4476371E-04,   2.3875896E-04
     +,   2.3241506E-04,   2.2576955E-04,   2.1886133E-04
     +,   2.1172957E-04,   2.0441379E-04,   1.9695371E-04
     +,   1.8938862E-04,   1.8175643E-04,   1.7409360E-04
     +,   1.6643573E-04,   1.5881637E-04,   1.5126662E-04
     +,   1.4381518E-04,   1.3648906E-04,   1.2931206E-04
     +,   1.2230528E-04,   1.1548772E-04,   1.0887567E-04
     +,   1.0248242E-04,   9.6318698E-05,   9.0393274E-05
     +,   8.4712541E-05,   7.9280391E-05,   7.4098643E-05
     +,   6.9167691E-05,   6.4486194E-05,   6.0050996E-05
     +,   5.5857650E-05,   5.1900955E-05,   4.8174352E-05
     +,   4.4670469E-05,   4.1381554E-05,   3.8299298E-05
     +,   3.5414825E-05,   3.2719028E-05,   3.0202869E-05
     +,   2.7857244E-05,   2.5672944E-05,   2.3640923E-05
     +,   2.1752432E-05,   1.9998997E-05,   1.8372271E-05
     +,   1.6864256E-05,   1.5467445E-05,   1.4174536E-05
     +,   1.2978601E-05,   1.1873165E-05,   1.0852113E-05
     +,   9.9096142E-06,   9.0402027E-06,   8.2388087E-06
     +,   7.5006801E-06,   6.8213144E-06,   6.1965216E-06
     +,   5.6224239E-06,   5.0953954E-06,   4.6120199E-06
     +,   4.1691105E-06,   3.7637337E-06,   3.3931110E-06
     +,   3.0546487E-06,   2.7459500E-06,   2.4647698E-06
     +,   2.2089930E-06,   1.9766446E-06,   1.7658967E-06
     +,   1.5750380E-06,   1.4024582E-06,   1.2466554E-06
     +,   1.1062439E-06,   9.7991324E-07,   8.6645935E-07
     +,   7.6474709E-07,   6.7373594E-07,   5.9244803E-07
     +,   5.1998859E-07,   4.5552042E-07,   3.9827944E-07
     +,   3.4755413E-07,   3.0269723E-07,   2.6310971E-07
     +,   2.2824416E-07,   1.9760360E-07,   1.7073133E-07
     +,   1.4721553E-07,   1.2667979E-07,   1.0878631E-07
     +,   9.3227946E-08,   7.9730334E-08,   6.8045388E-08
     +,   5.7952587E-08,   4.9253668E-08,   4.1773234E-08
     +,   3.5354422E-08,   2.9859212E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt120 = Yx/0.0110833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5344250E-04,   2.7885934E-04
     +,   3.0690277E-04,   3.3768386E-04,   3.7127771E-04
     +,   4.0771905E-04,   4.4700000E-04,   4.8906839E-04
     +,   5.3382997E-04,   5.8116310E-04,   6.3094305E-04
     +,   6.8311067E-04,   7.3778862E-04,   7.9547398E-04
     +,   8.5731043E-04,   9.2544704E-04,   1.0034780E-03
     +,   1.0969833E-03,   1.2142083E-03,   1.3668969E-03
     +,   1.5711493E-03,   1.8479303E-03,   2.2225697E-03
     +,   2.7225872E-03,   3.3734895E-03,   4.1948995E-03
     +,   5.2026706E-03,   6.4235986E-03,   7.9146978E-03
     +,   9.7675445E-03,   1.2106825E-02,   1.5096790E-02
     +,   1.8843610E-02,   2.3186423E-02,   2.7751403E-02
     +,   3.2180924E-02,   3.6382087E-02,   4.1061915E-02
     +,   4.6585713E-02,   5.2009784E-02,   5.6916174E-02
     +,   5.9118181E-02,   5.5981647E-02,   5.1316172E-02
     +,   4.9497180E-02,   4.8246272E-02,   4.5373667E-02
     +,   4.1420065E-02,   3.7320957E-02,   3.3405397E-02
     +,   2.9217746E-02,   2.4917604E-02,   2.1314962E-02
     +,   1.8620387E-02,   1.6413936E-02,   1.4344097E-02
     +,   1.2398032E-02,   1.0669084E-02,   9.1651781E-03
     +,   7.8562750E-03,   6.7468248E-03,   5.8576958E-03
     +,   5.1838919E-03,   4.6859146E-03,   4.3082987E-03
     +,   4.0006870E-03,   3.7289613E-03,   3.4758330E-03
     +,   3.2352295E-03,   3.0060394E-03,   2.7880215E-03
     +,   2.5805484E-03,   2.3828854E-03,   2.1949885E-03
     +,   2.0179076E-03,   1.8536800E-03,   1.7047843E-03
     +,   1.5733807E-03,   1.4606755E-03,   1.3665607E-03
     +,   1.2895993E-03,   1.2272522E-03,   1.1763143E-03
     +,   1.1333600E-03,   1.0951657E-03,   1.0589976E-03
     +,   1.0227973E-03,   9.8522846E-04,   9.4564643E-04
     +,   9.0398494E-04,   8.6061482E-04,   8.1619236E-04
     +,   7.7150750E-04,   7.2735565E-04,   6.8444479E-04
     +,   6.4333848E-04,   6.0441787E-04,   5.6788931E-04
     +,   5.3379446E-04,   5.0205237E-04,   4.7248820E-04
     +,   4.4488051E-04,   4.1898759E-04,   3.9458135E-04
     +,   3.7146086E-04,   3.4946523E-04,   3.2847942E-04
     +,   3.0843046E-04,   2.8928093E-04,   2.7102217E-04
     +,   2.5366686E-04,   2.3723701E-04,   2.2175918E-04
     +,   2.0725516E-04,   1.9374017E-04,   1.8121647E-04
     +,   1.6967495E-04,   1.5909171E-04,   1.4943174E-04
     +,   1.4064804E-04,   1.3268505E-04,   1.2548125E-04
     +,   1.1897104E-04,   1.1308667E-04,   1.0776098E-04
     +,   1.0292955E-04,   9.8530785E-05,   9.4508505E-05
     +,   9.0811278E-05,   8.7393804E-05,   8.4216168E-05
     +,   8.1244412E-05,   7.8449499E-05,   7.5807577E-05
     +,   7.3298797E-05,   7.0907059E-05,   6.8619636E-05
     +,   6.6426357E-05,   6.4319051E-05,   6.2291307E-05
     +,   6.0338145E-05,   5.8455531E-05,   5.6640070E-05
     +,   5.4888926E-05,   5.3199747E-05,   5.1570292E-05
     +,   4.9998471E-05,   4.8482427E-05,   4.7020330E-05
     +,   4.5610341E-05,   4.4250653E-05,   4.2939599E-05
     +,   4.1675539E-05,   4.0456798E-05,   3.9281796E-05
     +,   3.8149043E-05,   3.7057140E-05,   3.6004665E-05
     +,   3.4990273E-05,   3.4012770E-05,   3.3070919E-05
     +,   3.2163534E-05,   3.1289550E-05,   3.0447920E-05
     +,   2.9637580E-05,   2.8857488E-05,   2.8106684E-05
     +,   2.7384212E-05,   2.6689086E-05,   2.6020316E-05
     +,   2.5376978E-05,   2.4758136E-05,   2.4162822E-05
     +,   2.3590064E-05,   2.3038961E-05,   2.2508546E-05
     +,   2.1997870E-05,   2.1506010E-05,   2.1032063E-05
     +,   2.0575093E-05,   2.0134190E-05,   1.9708474E-05
     +,   1.9297089E-05,   1.8899160E-05,   1.8513840E-05
     +,   1.8140325E-05,   1.7777833E-05,   1.7425578E-05
     +,   1.7082804E-05,   1.6748811E-05,   1.6422890E-05
     +,   1.6104361E-05,   1.5792597E-05,   1.5486987E-05
     +,   1.5186940E-05,   1.4891893E-05,   1.4601322E-05
     +,   1.4314747E-05,   1.4031696E-05,   1.3751715E-05
     +,   1.3474420E-05,   1.3199450E-05,   1.2926451E-05
     +,   1.2655118E-05,   1.2385192E-05,   1.2116420E-05
     +,   1.1848595E-05,   1.1581550E-05,   1.1315154E-05
     +,   1.1049285E-05,   1.0783863E-05,   1.0518846E-05
     +,   1.0254235E-05,   9.9900271E-06,   9.7262600E-06
     +,   9.4630132E-06,   9.2003856E-06,   8.9384894E-06
     +,   8.6774553E-06,   8.4174599E-06,   8.1586759E-06
     +,   7.9012862E-06,   7.6455117E-06,   7.3915780E-06
     +,   7.1397094E-06,   6.8901354E-06,   6.6431062E-06
     +,   6.3988768E-06,   6.1576861E-06,   5.9197714E-06
     +,   5.6853842E-06,   5.4547691E-06,   5.2281493E-06
     +,   5.0057379E-06,   4.7877638E-06,   4.5744168E-06
     +,   4.3658788E-06,   4.1623298E-06,   3.9639335E-06
     +,   3.7708253E-06,   3.5831249E-06,   3.4009472E-06
     +,   3.2243895E-06,   3.0535191E-06,   2.8883862E-06
     +,   2.7290362E-06,   2.5754948E-06,   2.4277608E-06
     +,   2.2858180E-06,   2.1496483E-06,   2.0192017E-06
     +,   1.8944190E-06,   1.7752313E-06,   1.6615591E-06
     +,   1.5533016E-06,   1.4503485E-06,   1.3525857E-06
     +,   1.2598910E-06,   1.1721260E-06,   1.0891472E-06
     +,   1.0108103E-06,   9.3696514E-07,   8.6745268E-07
     +,   8.0211169E-07,   7.4078412E-07,   6.8330456E-07
     +,   6.2950755E-07,   5.7923114E-07,   5.3231372E-07
     +,   4.8859204E-07,   4.4790531E-07,   4.1009798E-07
     +,   3.7501769E-07,   3.4251261E-07,   3.1243547E-07
     +,   2.8464606E-07,   2.5900496E-07,   2.3538104E-07
     +,   2.1364473E-07,   1.9367450E-07,   1.7535142E-07
     +,   1.5856430E-07,   1.4320470E-07,   1.2917192E-07
     +,   1.1636816E-07,   1.0470283E-07,   9.4089110E-08
     +,   8.4445205E-08,   7.5695191E-08,   6.7766642E-08
     +,   6.0592811E-08,   5.4110345E-08,   4.8261015E-08
     +,   4.2989903E-08,   3.8246668E-08,   3.3983955E-08
     +,   3.0158599E-08,   2.6730158E-08,   2.3661849E-08
     +,   2.0919369E-08,   1.8471626E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt60 = Yx/0.257021739130435
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.4720429E-05,   7.1340226E-05
     +,   7.8413650E-05,   8.5940570E-05,   9.3915391E-05
     +,   1.0232653E-04,   1.1115611E-04,   1.2037998E-04
     +,   1.2996786E-04,   1.3988485E-04,   1.5009196E-04
     +,   1.6054919E-04,   1.7121842E-04,   1.8206766E-04
     +,   1.9307696E-04,   2.0424432E-04,   2.1559373E-04
     +,   2.2718385E-04,   2.3911704E-04,   2.5155005E-04
     +,   2.6470397E-04,   2.7887657E-04,   2.9445504E-04
     +,   3.1193384E-04,   3.3193058E-04,   3.5521679E-04
     +,   3.8274433E-04,   4.1568308E-04,   4.5545379E-04
     +,   5.0374854E-04,   5.6251558E-04,   6.3387671E-04
     +,   7.1993994E-04,   8.2248455E-04,   9.4253087E-04
     +,   1.0798904E-03,   1.2328750E-03,   1.3983985E-03
     +,   1.5726490E-03,   1.7521960E-03,   1.9352974E-03
     +,   2.1229291E-03,   2.3202363E-03,   2.5409225E-03
     +,   2.8185954E-03,   3.2248655E-03,   3.8790905E-03
     +,   4.9178419E-03,   6.4069489E-03,   8.2509378E-03
     +,   1.0222005E-02,   1.2138456E-02,   1.3982476E-02
     +,   1.5794201E-02,   1.7666046E-02,   2.0017160E-02
     +,   2.3496136E-02,   2.8547328E-02,   3.5110500E-02
     +,   4.2234365E-02,   4.8720252E-02,   5.3610671E-02
     +,   5.5189028E-02,   5.4293994E-02,   5.2502390E-02
     +,   5.0896473E-02,   4.8035026E-02,   4.2347994E-02
     +,   3.8334742E-02,   3.5691876E-02,   3.1010162E-02
     +,   2.5129808E-02,   2.0615192E-02,   1.8043788E-02
     +,   1.6156148E-02,   1.4045781E-02,   1.1830179E-02
     +,   9.8859491E-03,   8.3514825E-03,   7.1751173E-03
     +,   6.2760930E-03,   5.6057349E-03,   5.1250085E-03
     +,   4.7755800E-03,   4.4840015E-03,   4.1859783E-03
     +,   3.8464782E-03,   3.4639339E-03,   3.0609269E-03
     +,   2.6686634E-03,   2.3134747E-03,   2.0097077E-03
     +,   1.7593474E-03,   1.5559086E-03,   1.3893717E-03
     +,   1.2499334E-03,   1.1298554E-03,   1.0238793E-03
     +,   9.2876510E-04,   8.4267097E-04,   7.6457643E-04
     +,   6.9392833E-04,   6.3039770E-04,   5.7376322E-04
     +,   5.2380853E-04,   4.8027025E-04,   4.4280186E-04
     +,   4.1095639E-04,   3.8419155E-04,   3.6189717E-04
     +,   3.4343026E-04,   3.2814415E-04,   3.1542420E-04
     +,   3.0470500E-04,   2.9548712E-04,   2.8733982E-04
     +,   2.7990196E-04,   2.7287583E-04,   2.6602237E-04
     +,   2.5915302E-04,   2.5212366E-04,   2.4482960E-04
     +,   2.3720060E-04,   2.2919604E-04,   2.2080194E-04
     +,   2.1202861E-04,   2.0290530E-04,   1.9347956E-04
     +,   1.8381125E-04,   1.7397181E-04,   1.6403814E-04
     +,   1.5409187E-04,   1.4421382E-04,   1.3448340E-04
     +,   1.2497400E-04,   1.1575189E-04,   1.0687524E-04
     +,   9.8392331E-05,   9.0340480E-05,   8.2746541E-05
     +,   7.5627700E-05,   6.8991540E-05,   6.2836581E-05
     +,   5.7153960E-05,   5.1929117E-05,   4.7141966E-05
     +,   4.2768799E-05,   3.8783724E-05,   3.5159359E-05
     +,   3.1867563E-05,   2.8880539E-05,   2.6171563E-05
     +,   2.3715211E-05,   2.1487545E-05,   1.9466510E-05
     +,   1.7632092E-05,   1.5966183E-05,   1.4452387E-05
     +,   1.3076073E-05,   1.1824331E-05,   1.0685537E-05
     +,   9.6493477E-06,   8.7066092E-06,   7.8491157E-06
     +,   7.0694396E-06,   6.3608873E-06,   5.7174293E-06
     +,   5.1335692E-06,   4.6042428E-06,   4.1248081E-06
     +,   3.6910251E-06,   3.2989794E-06,   2.9450373E-06
     +,   2.6258463E-06,   2.3383425E-06,   2.0796717E-06
     +,   1.8472066E-06,   1.6385470E-06,   1.4514839E-06
     +,   1.2839795E-06,   1.1341696E-06,   1.0003581E-06
     +,   8.8099586E-07,   7.7466132E-07,   6.8006000E-07
     +,   5.9602075E-07,   5.2147777E-07,   4.5545738E-07
     +,   3.9707712E-07,   3.4554213E-07,   3.0012674E-07
     +,   2.6017463E-07,   2.2509482E-07,   1.9435281E-07
     +,   1.6746446E-07,   1.4399353E-07,   1.2354899E-07
     +,   1.0577911E-07,   9.0367024E-08,   7.7029178E-08
     +,   6.5512936E-08,   5.5592682E-08,   4.7066880E-08
     +,   3.9756632E-08,   3.3504048E-08,   2.8168847E-08
     +,   2.3627427E-08,   1.9771331E-08,   1.6505368E-08
     +,   1.3746024E-08,   1.1420497E-08,   9.4655963E-09
     +,   7.8264533E-09,   6.4555215E-09,   5.3117946E-09
     +,   4.3600923E-09,   3.5702179E-09,   2.9163165E-09
     +,   2.3763529E-09,   1.9316482E-09,   1.5663243E-09
     +,   1.2669771E-09,   1.0223274E-09,   8.2290280E-10
     +,   6.6075612E-10,   5.2925297E-10,   4.2288095E-10
     +,   3.3706071E-10,   2.6799737E-10,   2.1255951E-10
     +,   1.6817522E-10,   1.3273284E-10,   1.0450221E-10
     +,   8.2072897E-11,   6.4299635E-11,   5.0251293E-11
     +,   3.9175409E-11,   3.0465623E-11,   2.3634147E-11
     +,   1.8289467E-11,   1.4118481E-11,   1.0871908E-11
     +,   8.3513491E-12,   6.3993910E-12,   4.8915494E-12
     +,   3.7297869E-12,   2.8369809E-12,   2.1525748E-12
     +,   1.6292455E-12,   1.2301246E-12,   9.2649098E-13
     +,   6.9608089E-13,   5.2168464E-13,   3.9002303E-13
     +,   2.9087277E-13,   2.1639216E-13,   1.6058708E-13
     +,   1.1888109E-13,   8.7790269E-14,   6.4670281E-14
     +,   4.7521899E-14,   3.4835070E-14,   2.5472420E-14
     +,   1.8580118E-14,   1.3519528E-14,   9.8130969E-15
     +,   7.1051707E-15,   5.1318457E-15,   3.6974932E-15
     +,   2.6574860E-15,   1.9052822E-15,   1.3626337E-15
     +,   9.7214903E-16,   6.9185699E-16,   4.9116280E-16
     +,   3.4783247E-16,   2.4571949E-16,   1.7315851E-16
     +,   1.2172304E-16,   8.5356662E-17,   5.9707220E-17
     +,   4.1663039E-17,   2.9000181E-17,   2.0136518E-17
     +,   1.3947440E-17,   9.6369445E-18,   6.6422318E-18
     +,   4.5668154E-18,   3.1321928E-18,   2.1429274E-18
     +,   1.4625206E-18,   9.9568547E-19,   6.7620433E-19
     +,   4.5809640E-19,   3.0958005E-19,   2.0869510E-19
     +,   1.4034206E-19,   9.4142886E-20,   6.2997526E-20
     +,   4.2051778E-20,   2.8001411E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt65 = Yx/0.230391304347826
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3430952E-05,   3.4641438E-05
     +,   3.5858619E-05,   3.7083926E-05,   3.8319533E-05
     +,   3.9568476E-05,   4.0834700E-05,   4.2123193E-05
     +,   4.3440017E-05,   4.4792523E-05,   4.6189340E-05
     +,   4.7640580E-05,   4.9157923E-05,   5.0754803E-05
     +,   5.2446583E-05,   5.4250697E-05,   5.6186811E-05
     +,   5.8277074E-05,   6.0546190E-05,   6.3021580E-05
     +,   6.5733388E-05,   6.8714522E-05,   7.2000417E-05
     +,   7.5628966E-05,   7.9639445E-05,   8.4072693E-05
     +,   8.8969362E-05,   9.4369294E-05,   1.0030974E-04
     +,   1.0682402E-04,   1.1393954E-04,   1.2167604E-04
     +,   1.3004376E-04,   1.3904182E-04,   1.4865701E-04
     +,   1.5886323E-04,   1.6962194E-04,   1.8088332E-04
     +,   1.9259029E-04,   2.0468084E-04,   2.1709710E-04
     +,   2.2979132E-04,   2.4273616E-04,   2.5593580E-04
     +,   2.6943727E-04,   2.8334348E-04,   2.9782718E-04
     +,   3.1314738E-04,   3.2967277E-04,   3.4791534E-04
     +,   3.6858543E-04,   3.9267677E-04,   4.2159506E-04
     +,   4.5733980E-04,   5.0272542E-04,   5.6163548E-04
     +,   6.3921016E-04,   7.4187195E-04,   8.7703101E-04
     +,   1.0523642E-03,   1.2747055E-03,   1.5488107E-03
     +,   1.8763896E-03,   2.2559084E-03,   2.6831401E-03
     +,   3.1522666E-03,   3.6579045E-03,   4.1998597E-03
     +,   4.7949604E-03,   5.4956251E-03,   6.4019789E-03
     +,   7.6333606E-03,   9.2412988E-03,   1.1186434E-02
     +,   1.3581838E-02,   1.6834931E-02,   2.1117918E-02
     +,   2.6004227E-02,   3.0560039E-02,   3.3752464E-02
     +,   3.6314752E-02,   4.0864330E-02,   4.6999693E-02
     +,   5.0436795E-02,   5.0826561E-02,   4.9803317E-02
     +,   4.5932706E-02,   3.9144628E-02,   3.3787094E-02
     +,   3.1749584E-02,   2.9846052E-02,   2.6083183E-02
     +,   2.1528918E-02,   1.7794190E-02,   1.5275639E-02
     +,   1.3317598E-02,   1.1255329E-02,   9.0908911E-03
     +,   7.2365794E-03,   5.9448350E-03,   5.1479302E-03
     +,   4.6380209E-03,   4.2385706E-03,   3.8570496E-03
     +,   3.4692029E-03,   3.0869974E-03,   2.7315980E-03
     +,   2.4177409E-03,   2.1490878E-03,   1.9206956E-03
     +,   1.7239753E-03,   1.5508189E-03,   1.3957786E-03
     +,   1.2562408E-03,   1.1315922E-03,   1.0220218E-03
     +,   9.2760666E-04,   8.4776664E-04,   7.8118342E-04
     +,   7.2595378E-04,   6.7989691E-04,   6.4085500E-04
     +,   6.0691277E-04,   5.7652261E-04,   5.4853974E-04
     +,   5.2219228E-04,   4.9700483E-04,   4.7272362E-04
     +,   4.4923366E-04,   4.2650470E-04,   4.0454260E-04
     +,   3.8337006E-04,   3.6300847E-04,   3.4347919E-04
     +,   3.2479927E-04,   3.0698424E-04,   2.9005005E-04
     +,   2.7401073E-04,   2.5887476E-04,   2.4464395E-04
     +,   2.3131065E-04,   2.1885493E-04,   2.0724229E-04
     +,   1.9642522E-04,   1.8634560E-04,   1.7693535E-04
     +,   1.6812117E-04,   1.5982869E-04,   1.5198569E-04
     +,   1.4452489E-04,   1.3738724E-04,   1.3052407E-04
     +,   1.2389748E-04,   1.1748025E-04,   1.1125552E-04
     +,   1.0521618E-04,   9.9362784E-05,   9.3701550E-05
     +,   8.8242821E-05,   8.2999897E-05,   7.7986268E-05
     +,   7.3214869E-05,   6.8697249E-05,   6.4442349E-05
     +,   6.0455768E-05,   5.6739744E-05,   5.3293261E-05
     +,   5.0112019E-05,   4.7188383E-05,   4.4512100E-05
     +,   4.2070802E-05,   3.9850347E-05,   3.7835154E-05
     +,   3.6008816E-05,   3.4354704E-05,   3.2855995E-05
     +,   3.1496198E-05,   3.0259516E-05,   2.9130908E-05
     +,   2.8096243E-05,   2.7142469E-05,   2.6257752E-05
     +,   2.5431395E-05,   2.4653815E-05,   2.3916587E-05
     +,   2.3212402E-05,   2.2534967E-05,   2.1878894E-05
     +,   2.1239666E-05,   2.0613617E-05,   1.9997720E-05
     +,   1.9389581E-05,   1.8787407E-05,   1.8189885E-05
     +,   1.7596074E-05,   1.7005414E-05,   1.6417684E-05
     +,   1.5832920E-05,   1.5251346E-05,   1.4673352E-05
     +,   1.4099520E-05,   1.3530536E-05,   1.2967135E-05
     +,   1.2410109E-05,   1.1860348E-05,   1.1318697E-05
     +,   1.0786008E-05,   1.0263154E-05,   9.7509810E-06
     +,   9.2502578E-06,   8.7617127E-06,   8.2860479E-06
     +,   7.8239027E-06,   7.3758192E-06,   6.9422704E-06
     +,   6.5236845E-06,   6.1204137E-06,   5.7327084E-06
     +,   5.3607450E-06,   5.0046606E-06,   4.6644905E-06
     +,   4.3401951E-06,   4.0316982E-06,   3.7388527E-06
     +,   3.4614416E-06,   3.1991895E-06,   2.9517944E-06
     +,   2.7189064E-06,   2.5001223E-06,   2.2950060E-06
     +,   2.1031058E-06,   1.9239451E-06,   1.7570154E-06
     +,   1.6017938E-06,   1.4577631E-06,   1.3243828E-06
     +,   1.2011126E-06,   1.0874199E-06,   9.8277530E-07
     +,   8.8664910E-07,   7.9852293E-07,   7.1789492E-07
     +,   6.4427729E-07,   5.7719194E-07,   5.1617940E-07
     +,   4.6080197E-07,   4.1064035E-07,   3.6529201E-07
     +,   3.2437487E-07,   2.8753107E-07,   2.5441946E-07
     +,   2.2471978E-07,   1.9813366E-07,   1.7438214E-07
     +,   1.5320398E-07,   1.3435677E-07,   1.1761739E-07
     +,   1.0277963E-07,   8.9652666E-08,   7.8061589E-08
     +,   6.7846997E-08,   5.8863268E-08,   5.0977160E-08
     +,   4.4067853E-08,   3.8026499E-08,   3.2754148E-08
     +,   2.8161708E-08,   2.4169378E-08,   2.0705606E-08
     +,   1.7706119E-08,   1.5113619E-08,   1.2877316E-08
     +,   1.0952057E-08,   9.2977173E-09,   7.8788842E-09
     +,   6.6644565E-09,   5.6269274E-09,   4.7422968E-09
     +,   3.9894346E-09,   3.3499954E-09,   2.8078961E-09
     +,   2.3492392E-09,   1.9618991E-09,   1.6354385E-09
     +,   1.3608007E-09,   1.1302176E-09,   9.3698804E-10
     +,   7.7536666E-10,   6.4045225E-10,   5.2803995E-10
     +,   4.3456239E-10,   3.5697489E-10,   2.9270350E-10
     +,   2.3956184E-10,   1.9570909E-10,   1.5958922E-10
     +,   1.2989713E-10,   1.0553417E-10,   8.5583547E-11
     +,   6.9276258E-11,   5.5973393E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt70 = Yx/0.200977777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7118738E-05,   1.7493410E-05
     +,   1.7933622E-05,   1.8448307E-05,   1.9046749E-05
     +,   1.9738472E-05,   2.0533156E-05,   2.1440503E-05
     +,   2.2470060E-05,   2.3631143E-05,   2.4932513E-05
     +,   2.6382255E-05,   2.7987513E-05,   2.9754276E-05
     +,   3.1687086E-05,   3.3788816E-05,   3.6060428E-05
     +,   3.8500697E-05,   4.1106043E-05,   4.3870292E-05
     +,   4.6784564E-05,   4.9837181E-05,   5.3013500E-05
     +,   5.6296289E-05,   5.9665159E-05,   6.3097505E-05
     +,   6.6568180E-05,   7.0050075E-05,   7.3514551E-05
     +,   7.6931930E-05,   8.0272184E-05,   8.3505627E-05
     +,   8.6603803E-05,   8.9540459E-05,   9.2292525E-05
     +,   9.4841351E-05,   9.7173957E-05,   9.9284283E-05
     +,   1.0117464E-04,   1.0285687E-04,   1.0435390E-04
     +,   1.0570064E-04,   1.0694505E-04,   1.0814860E-04
     +,   1.0938630E-04,   1.1074624E-04,   1.1232818E-04
     +,   1.1424132E-04,   1.1660120E-04,   1.1952542E-04
     +,   1.2312873E-04,   1.2751701E-04,   1.3278106E-04
     +,   1.3899068E-04,   1.4618773E-04,   1.5438306E-04
     +,   1.6355253E-04,   1.7363754E-04,   1.8454829E-04
     +,   1.9617091E-04,   2.0837929E-04,   2.2105098E-04
     +,   2.3408599E-04,   2.4743198E-04,   2.6110897E-04
     +,   2.7523615E-04,   2.9006531E-04,   3.0601164E-04
     +,   3.2369787E-04,   3.4399852E-04,   3.6809829E-04
     +,   3.9753655E-04,   4.3423491E-04,   4.8044027E-04
     +,   5.3856458E-04,   6.1085465E-04,   6.9889775E-04
     +,   8.0307556E-04,   9.2218386E-04,   1.0535379E-03
     +,   1.1939076E-03,   1.3414461E-03,   1.4981399E-03
     +,   1.6720771E-03,   1.8784753E-03,   2.1394345E-03
     +,   2.4826536E-03,   2.9388829E-03,   3.5344423E-03
     +,   4.2763995E-03,   5.1399991E-03,   6.0859313E-03
     +,   7.1123838E-03,   8.2696220E-03,   9.5997825E-03
     +,   1.1215750E-02,   1.3531924E-02,   1.6962158E-02
     +,   2.1397792E-02,   2.6384000E-02,   3.1248353E-02
     +,   3.5060056E-02,   3.6112178E-02,   3.4262665E-02
     +,   3.2176089E-02,   3.0780250E-02,   2.9984750E-02
     +,   2.9294755E-02,   2.7093239E-02,   2.3697136E-02
     +,   2.0760503E-02,   1.8281041E-02,   1.5261376E-02
     +,   1.1756497E-02,   8.6390087E-03,   6.3631916E-03
     +,   4.8006307E-03,   3.7101256E-03,   2.9474103E-03
     +,   2.4216108E-03,   2.0542589E-03,   1.7835459E-03
     +,   1.5705233E-03,   1.3938321E-03,   1.2415452E-03
     +,   1.1062399E-03,   9.8322122E-04,   8.7006739E-04
     +,   7.6614600E-04,   6.7194604E-04,   5.8829034E-04
     +,   5.1576662E-04,   4.5441004E-04,   4.0369283E-04
     +,   3.6264388E-04,   3.3004617E-04,   3.0460642E-04
     +,   2.8506826E-04,   2.7027683E-04,   2.5920552E-04
     +,   2.5095837E-04,   2.4475952E-04,   2.3994138E-04
     +,   2.3593384E-04,   2.3225635E-04,   2.2851097E-04
     +,   2.2437912E-04,   2.1961876E-04,   2.1406116E-04
     +,   2.0760704E-04,   2.0022139E-04,   1.9192767E-04
     +,   1.8279935E-04,   1.7295020E-04,   1.6252462E-04
     +,   1.5168870E-04,   1.4061929E-04,   1.2949425E-04
     +,   1.1848504E-04,   1.0775074E-04,   9.7430806E-05
     +,   8.7642242E-05,   7.8478071E-05,   7.0005874E-05
     +,   6.2267776E-05,   5.5282759E-05,   4.9049540E-05
     +,   4.3548949E-05,   3.8747025E-05,   3.4598910E-05
     +,   3.1052365E-05,   2.8050488E-05,   2.5534266E-05
     +,   2.3445100E-05,   2.1726757E-05,   2.0326263E-05
     +,   1.9195093E-05,   1.8289693E-05,   1.7571605E-05
     +,   1.7007380E-05,   1.6568394E-05,   1.6230504E-05
     +,   1.5973525E-05,   1.5780743E-05,   1.5638443E-05
     +,   1.5535428E-05,   1.5462574E-05,   1.5412430E-05
     +,   1.5378897E-05,   1.5356933E-05,   1.5342333E-05
     +,   1.5331527E-05,   1.5321433E-05,   1.5309362E-05
     +,   1.5292922E-05,   1.5269959E-05,   1.5238526E-05
     +,   1.5196857E-05,   1.5143344E-05,   1.5076540E-05
     +,   1.4995154E-05,   1.4898063E-05,   1.4784300E-05
     +,   1.4653070E-05,   1.4503762E-05,   1.4335938E-05
     +,   1.4149335E-05,   1.3943889E-05,   1.3719719E-05
     +,   1.3477116E-05,   1.3216531E-05,   1.2938604E-05
     +,   1.2644136E-05,   1.2334054E-05,   1.2009416E-05
     +,   1.1671418E-05,   1.1321365E-05,   1.0960625E-05
     +,   1.0590638E-05,   1.0212933E-05,   9.8290393E-06
     +,   9.4405059E-06,   9.0489084E-06,   8.6558166E-06
     +,   8.2627394E-06,   7.8711500E-06,   7.4824875E-06
     +,   7.0981291E-06,   6.7193464E-06,   6.3473276E-06
     +,   5.9831918E-06,   5.6279614E-06,   5.2825271E-06
     +,   4.9476789E-06,   4.6241285E-06,   4.3124514E-06
     +,   4.0131144E-06,   3.7264992E-06,   3.4528896E-06
     +,   3.1924469E-06,   2.9452488E-06,   2.7112990E-06
     +,   2.4905225E-06,   2.2827526E-06,   2.0877599E-06
     +,   1.9052683E-06,   1.7349471E-06,   1.5764097E-06
     +,   1.4292320E-06,   1.2929727E-06,   1.1671519E-06
     +,   1.0512709E-06,   9.4482732E-07,   8.4730931E-07
     +,   7.5819605E-07,   6.7696959E-07,   6.0312345E-07
     +,   5.3615963E-07,   4.7558831E-07,   4.2093546E-07
     +,   3.7174775E-07,   3.2759087E-07,   2.8804720E-07
     +,   2.5272146E-07,   2.2124365E-07,   1.9326248E-07
     +,   1.6844993E-07,   1.4650139E-07,   1.2713438E-07
     +,   1.1008602E-07,   9.5114558E-08,   8.1999268E-08
     +,   7.0537915E-08,   6.0545673E-08,   5.1854844E-08
     +,   4.4314440E-08,   3.7787380E-08,   3.2151274E-08
     +,   2.7295743E-08,   2.3122864E-08,   1.9544908E-08
     +,   1.6484490E-08,   1.3872757E-08,   1.1649300E-08
     +,   9.7607211E-09,   8.1604501E-09,   6.8075998E-09
     +,   5.6665499E-09,   4.7064530E-09,   3.9004378E-09
     +,   3.2253991E-09,   2.6613265E-09,   2.1911051E-09
     +,   1.8000009E-09,   1.4754776E-09,   1.2068060E-09
     +,   9.8490105E-10,   8.0203305E-10,   6.5169181E-10
     +,   5.2836824E-10,   4.2744666E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt75 = Yx/0.1375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2320047E-05,   3.3317508E-05
     +,   3.4327502E-05,   3.5347202E-05,   3.6373563E-05
     +,   3.7403388E-05,   3.8433318E-05,   3.9459897E-05
     +,   4.0479561E-05,   4.1488762E-05,   4.2483891E-05
     +,   4.3461398E-05,   4.4417808E-05,   4.5349778E-05
     +,   4.6254136E-05,   4.7127942E-05,   4.7968486E-05
     +,   4.8773392E-05,   4.9540620E-05,   5.0268514E-05
     +,   5.0955830E-05,   5.1601783E-05,   5.2206029E-05
     +,   5.2768777E-05,   5.3290638E-05,   5.3772801E-05
     +,   5.4216904E-05,   5.4625092E-05,   5.4999935E-05
     +,   5.5344459E-05,   5.5662065E-05,   5.5956505E-05
     +,   5.6231824E-05,   5.6492325E-05,   5.6742505E-05
     +,   5.6987017E-05,   5.7230689E-05,   5.7478410E-05
     +,   5.7735248E-05,   5.8006430E-05,   5.8297497E-05
     +,   5.8614391E-05,   5.8963717E-05,   5.9353006E-05
     +,   5.9791128E-05,   6.0288734E-05,   6.0858798E-05
     +,   6.1517327E-05,   6.2284023E-05,   6.3183114E-05
     +,   6.4244115E-05,   6.5502689E-05,   6.7001274E-05
     +,   6.8789850E-05,   7.0926006E-05,   7.3475465E-05
     +,   7.6511555E-05,   8.0114580E-05,   8.4370775E-05
     +,   8.9370478E-05,   9.5206029E-05,   1.0196896E-04
     +,   1.0974615E-04,   1.1861717E-04,   1.2864960E-04
     +,   1.3989367E-04,   1.5238023E-04,   1.6611362E-04
     +,   1.8107099E-04,   1.9719571E-04,   2.1439900E-04
     +,   2.3255535E-04,   2.5150794E-04,   2.7106839E-04
     +,   2.9102739E-04,   3.1116427E-04,   3.3126018E-04
     +,   3.5111909E-04,   3.7059202E-04,   3.8960253E-04
     +,   4.0817275E-04,   4.2645415E-04,   4.4474585E-04
     +,   4.6351261E-04,   4.8338424E-04,   5.0514744E-04
     +,   5.2971288E-04,   5.5807305E-04,   5.9123017E-04
     +,   6.3011626E-04,   6.7548681E-04,   7.2779693E-04
     +,   7.8707456E-04,   8.5280876E-04,   9.2386646E-04
     +,   9.9848583E-04,   1.0744050E-03,   1.1490892E-03
     +,   1.2201036E-03,   1.2854766E-03,   1.3440185E-03
     +,   1.3953808E-03,   1.4398631E-03,   1.4779698E-03
     +,   1.5100457E-03,   1.5364292E-03,   1.5586695E-03
     +,   1.5819841E-03,   1.6182723E-03,   1.6880182E-03
     +,   1.8192068E-03,   2.0427543E-03,   2.3857926E-03
     +,   2.8653073E-03,   3.4842773E-03,   4.2353920E-03
     +,   5.1173768E-03,   6.1553996E-03,   7.3909713E-03
     +,   8.8221123E-03,   1.0344992E-02,   1.1779655E-02
     +,   1.2958901E-02,   1.3760136E-02,   1.4057487E-02
     +,   1.3721738E-02,   1.2726561E-02,   1.1235723E-02
     +,   9.5506199E-03,   7.9658469E-03,   6.6551566E-03
     +,   5.6468602E-03,   4.8685912E-03,   4.2193937E-03
     +,   3.6271231E-03,   3.0675770E-03,   2.5496397E-03
     +,   2.0901356E-03,   1.6980038E-03,   1.3717033E-03
     +,   1.1035700E-03,   8.8469184E-04,   7.0759881E-04
     +,   5.6674320E-04,   4.5775063E-04,   3.7646675E-04
     +,   3.1849922E-04,   2.7927774E-04,   2.5439705E-04
     +,   2.3996562E-04,   2.3279502E-04,   2.3041375E-04
     +,   2.3097424E-04,   2.3312807E-04,   2.3590872E-04
     +,   2.3863805E-04,   2.4085514E-04,   2.4226306E-04
     +,   2.4268709E-04,   2.4204225E-04,   2.4030838E-04
     +,   2.3751125E-04,   2.3370929E-04,   2.2898310E-04
     +,   2.2342792E-04,   2.1714835E-04,   2.1025470E-04
     +,   2.0285891E-04,   1.9507157E-04,   1.8699958E-04
     +,   1.7874496E-04,   1.7040265E-04,   1.6205857E-04
     +,   1.5378937E-04,   1.4566266E-04,   1.3773511E-04
     +,   1.3005335E-04,   1.2265485E-04,   1.1556782E-04
     +,   1.0881148E-04,   1.0239752E-04,   9.6331285E-05
     +,   9.0612368E-05,   8.5235180E-05,   8.0190322E-05
     +,   7.5465781E-05,   7.1047361E-05,   6.6919063E-05
     +,   6.3064173E-05,   5.9465958E-05,   5.6107398E-05
     +,   5.2971893E-05,   5.0043705E-05,   4.7307803E-05
     +,   4.4749890E-05,   4.2356583E-05,   4.0115607E-05
     +,   3.8015543E-05,   3.6045712E-05,   3.4196222E-05
     +,   3.2458116E-05,   3.0823056E-05,   2.9283243E-05
     +,   2.7831478E-05,   2.6461219E-05,   2.5166288E-05
     +,   2.3940975E-05,   2.2780076E-05,   2.1678794E-05
     +,   2.0632633E-05,   1.9637480E-05,   1.8689636E-05
     +,   1.7785729E-05,   1.6922639E-05,   1.6097560E-05
     +,   1.5308016E-05,   1.4551797E-05,   1.3826892E-05
     +,   1.3131510E-05,   1.2464145E-05,   1.1823405E-05
     +,   1.1208071E-05,   1.0617104E-05,   1.0049604E-05
     +,   9.5047280E-06,   8.9817413E-06,   8.4800131E-06
     +,   7.9989713E-06,   7.5380667E-06,   7.0967812E-06
     +,   6.6746602E-06,   6.2712652E-06,   5.8861351E-06
     +,   5.5188225E-06,   5.1689140E-06,   4.8359566E-06
     +,   4.5194934E-06,   4.2190832E-06,   3.9342722E-06
     +,   3.6645822E-06,   3.4095262E-06,   3.1686282E-06
     +,   2.9414030E-06,   2.7273477E-06,   2.5259549E-06
     +,   2.3367306E-06,   2.1591793E-06,   1.9927941E-06
     +,   1.8370731E-06,   1.6915344E-06,   1.5556875E-06
     +,   1.4290507E-06,   1.3111594E-06,   1.2015579E-06
     +,   1.0997956E-06,   1.0054338E-06,   9.1805344E-07
     +,   8.3724848E-07,   7.6262097E-07,   6.9378905E-07
     +,   6.3038948E-07,   5.7207399E-07,   5.1850537E-07
     +,   4.6936222E-07,   4.2434269E-07,   3.8315585E-07
     +,   3.4552562E-07,   3.1119302E-07,   2.7991294E-07
     +,   2.5145266E-07,   2.2559279E-07,   2.0212936E-07
     +,   1.8087047E-07,   1.6163526E-07,   1.4425511E-07
     +,   1.2857417E-07,   1.1444541E-07,   1.0173405E-07
     +,   9.0313456E-08,   8.0067736E-08,   7.0888731E-08
     +,   6.2677614E-08,   5.5342419E-08,   4.8799613E-08
     +,   4.2971621E-08,   3.7788205E-08,   3.3184612E-08
     +,   2.9101807E-08,   2.5486385E-08,   2.2289306E-08
     +,   1.9466471E-08,   1.6977573E-08,   1.4786457E-08
     +,   1.2860209E-08,   1.1169416E-08,   9.6873718E-09
     +,   8.3903027E-09,   7.2567317E-09,   6.2675745E-09
     +,   5.4056448E-09,   4.6557447E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt80 = Yx/0.0582702702702703
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1333141E-05,   1.1841263E-05
     +,   1.2365603E-05,   1.2906493E-05,   1.3464251E-05
     +,   1.4039170E-05,   1.4631522E-05,   1.5241548E-05
     +,   1.5869431E-05,   1.6515345E-05,   1.7179373E-05
     +,   1.7861541E-05,   1.8561808E-05,   1.9280049E-05
     +,   2.0016045E-05,   2.0769487E-05,   2.1539958E-05
     +,   2.2326929E-05,   2.3129762E-05,   2.3947699E-05
     +,   2.4779858E-05,   2.5625242E-05,   2.6482712E-05
     +,   2.7351076E-05,   2.8228929E-05,   2.9114870E-05
     +,   3.0007337E-05,   3.0904717E-05,   3.1805321E-05
     +,   3.2707427E-05,   3.3609274E-05,   3.4509121E-05
     +,   3.5405232E-05,   3.6295922E-05,   3.7179590E-05
     +,   3.8054764E-05,   3.8920090E-05,   3.9774393E-05
     +,   4.0616775E-05,   4.1446470E-05,   4.2263124E-05
     +,   4.3066641E-05,   4.3857301E-05,   4.4635806E-05
     +,   4.5403282E-05,   4.6161356E-05,   4.6912181E-05
     +,   4.7658501E-05,   4.8403694E-05,   4.9151822E-05
     +,   4.9907743E-05,   5.0677139E-05,   5.1466614E-05
     +,   5.2283893E-05,   5.3137785E-05,   5.4038504E-05
     +,   5.4997694E-05,   5.6028686E-05,   5.7146637E-05
     +,   5.8368736E-05,   5.9714377E-05,   6.1205385E-05
     +,   6.2865889E-05,   6.4722764E-05,   6.6805384E-05
     +,   6.9145397E-05,   7.1776776E-05,   7.4735086E-05
     +,   7.8057463E-05,   8.1781174E-05,   8.5943677E-05
     +,   9.0580666E-05,   9.5725969E-05,   1.0140931E-04
     +,   1.0765609E-04,   1.1448579E-04,   1.2191055E-04
     +,   1.2993428E-04,   1.3855273E-04,   1.4775243E-04
     +,   1.5750942E-04,   1.6779143E-04,   1.7855567E-04
     +,   1.8975193E-04,   2.0132051E-04,   2.1319569E-04
     +,   2.2530381E-04,   2.3756675E-04,   2.4989966E-04
     +,   2.6221419E-04,   2.7441760E-04,   2.8641257E-04
     +,   2.9809802E-04,   3.0937081E-04,   3.2012578E-04
     +,   3.3025592E-04,   3.3965698E-04,   3.4822826E-04
     +,   3.5587786E-04,   3.6252619E-04,   3.6811255E-04
     +,   3.7259969E-04,   3.7598042E-04,   3.7828236E-04
     +,   3.7957198E-04,   3.7995612E-04,   3.7958112E-04
     +,   3.7862768E-04,   3.7730220E-04,   3.7582271E-04
     +,   3.7440160E-04,   3.7322417E-04,   3.7242562E-04
     +,   3.7207076E-04,   3.7213773E-04,   3.7251503E-04
     +,   3.7301789E-04,   3.7343361E-04,   3.7360645E-04
     +,   3.7356783E-04,   3.7371225E-04,   3.7500481E-04
     +,   3.7918045E-04,   3.8888038E-04,   4.0764690E-04
     +,   4.3970707E-04,   4.8952486E-04,   5.6112878E-04
     +,   6.5735477E-04,   7.7912398E-04,   9.2507771E-04
     +,   1.0917947E-03,   1.2750766E-03,   1.4723798E-03
     +,   1.6862628E-03,   1.9275021E-03,   2.2158080E-03
     +,   2.5759127E-03,   3.0283686E-03,   3.5772186E-03
     +,   4.1997386E-03,   4.8440732E-03,   5.4377727E-03
     +,   5.9052939E-03,   6.1881952E-03,   6.2602418E-03
     +,   6.1311862E-03,   5.8387923E-03,   5.4337508E-03
     +,   4.9649025E-03,   4.4707325E-03,   3.9782114E-03
     +,   3.5058982E-03,   3.0673693E-03,   2.6727612E-03
     +,   2.3285171E-03,   2.0366546E-03,   1.7947077E-03
     +,   1.5966932E-03,   1.4346214E-03,   1.2999935E-03
     +,   1.1849926E-03,   1.0831653E-03,   9.8964944E-04
     +,   9.0113096E-04,   8.1568549E-04,   7.3258986E-04
     +,   6.5209501E-04,   5.7515077E-04,   5.0308346E-04
     +,   4.3724969E-04,   3.7872390E-04,   3.2809624E-04
     +,   2.8540971E-04,   2.5021625E-04,   2.2169908E-04
     +,   1.9883768E-04,   1.8055679E-04,   1.6583755E-04
     +,   1.5378668E-04,   1.4366909E-04,   1.3491057E-04
     +,   1.2708145E-04,   1.1987340E-04,   1.1307470E-04
     +,   1.0654840E-04,   1.0021255E-04,   9.4024974E-05
     +,   8.7971697E-05,   8.2058585E-05,   7.6302997E-05
     +,   7.0728900E-05,   6.5362918E-05,   6.0230817E-05
     +,   5.5354787E-05,   5.0752387E-05,   4.6435962E-05
     +,   4.2412074E-05,   3.8681439E-05,   3.5239751E-05
     +,   3.2078580E-05,   2.9185943E-05,   2.6547017E-05
     +,   2.4145165E-05,   2.1962916E-05,   1.9982170E-05
     +,   1.8184983E-05,   1.6554119E-05,   1.5073249E-05
     +,   1.3727063E-05,   1.2501561E-05,   1.1384168E-05
     +,   1.0363640E-05,   9.4299712E-06,   8.5744014E-06
     +,   7.7893483E-06,   7.0682408E-06,   6.4053456E-06
     +,   5.7957122E-06,   5.2350997E-06,   4.7197564E-06
     +,   4.2463812E-06,   3.8120720E-06,   3.4142104E-06
     +,   3.0503795E-06,   2.7183496E-06,   2.4160538E-06
     +,   2.1415340E-06,   1.8929057E-06,   1.6683658E-06
     +,   1.4661949E-06,   1.2847357E-06,   1.1223798E-06
     +,   9.7758573E-07,   8.4889047E-07,   7.3488462E-07
     +,   6.3423124E-07,   5.4567357E-07,   4.6802822E-07
     +,   4.0018324E-07,   3.4110442E-07,   2.8983933E-07
     +,   2.4550971E-07,   2.0730857E-07,   1.7450165E-07
     +,   1.4642544E-07,   1.2248128E-07,   1.0213068E-07
     +,   8.4893145E-08,   7.0343503E-08,   5.8104142E-08
     +,   4.7843081E-08,   3.9270123E-08,   3.2132121E-08
     +,   2.6208843E-08,   2.1310036E-08,   1.7272354E-08
     +,   1.3955732E-08,   1.1240466E-08,   9.0249328E-09
     +,   7.2232735E-09,   5.7631300E-09,   4.5836677E-09
     +,   3.6340904E-09,   2.8721845E-09,   2.2628663E-09
     +,   1.7771880E-09,   1.3913568E-09,   1.0858697E-09
     +,   8.4478791E-10,   6.5515582E-10,   5.0649168E-10
     +,   3.9033227E-10,   2.9986583E-10,   2.2963964E-10
     +,   1.7530762E-10,   1.3340798E-10,   1.0120390E-10
     +,   7.6531406E-11,   5.7692132E-11,   4.3353092E-11
     +,   3.2475661E-11,   2.4250629E-11,   1.8051897E-11
     +,   1.3395190E-11,   9.9085523E-12,   7.3063734E-12
     +,   5.3705660E-12,   3.9352614E-12,   2.8744375E-12
     +,   2.0929914E-12,   1.5191750E-12,   1.0992180E-12
     +,   7.9284176E-13,   5.7006456E-13,   4.0858958E-13
     +,   2.9193510E-13,   2.0792669E-13,   1.4762867E-13
     +,   1.0448572E-13,   7.3718910E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt85 = Yx/0.0319375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6606462E-05,   1.7240156E-05
     +,   1.7884026E-05,   1.8537703E-05,   1.9200808E-05
     +,   1.9872959E-05,   2.0553785E-05,   2.1242919E-05
     +,   2.1939981E-05,   2.2644628E-05,   2.3356501E-05
     +,   2.4075262E-05,   2.4800569E-05,   2.5532087E-05
     +,   2.6269512E-05,   2.7012517E-05,   2.7760807E-05
     +,   2.8514056E-05,   2.9271978E-05,   3.0034264E-05
     +,   3.0800595E-05,   3.1570671E-05,   3.2344135E-05
     +,   3.3120705E-05,   3.3899960E-05,   3.4681580E-05
     +,   3.5465157E-05,   3.6250265E-05,   3.7036483E-05
     +,   3.7823334E-05,   3.8610331E-05,   3.9396957E-05
     +,   4.0182673E-05,   4.0966916E-05,   4.1749125E-05
     +,   4.2528714E-05,   4.3305099E-05,   4.4077689E-05
     +,   4.4845972E-05,   4.5609377E-05,   4.6367448E-05
     +,   4.7119789E-05,   4.7866059E-05,   4.8606023E-05
     +,   4.9339618E-05,   5.0066876E-05,   5.0788047E-05
     +,   5.1503557E-05,   5.2214073E-05,   5.2920539E-05
     +,   5.3624135E-05,   5.4326396E-05,   5.5029144E-05
     +,   5.5734599E-05,   5.6445304E-05,   5.7164190E-05
     +,   5.7894598E-05,   5.8640228E-05,   5.9405134E-05
     +,   6.0193750E-05,   6.1010844E-05,   6.1861465E-05
     +,   6.2750842E-05,   6.3684500E-05,   6.4668027E-05
     +,   6.5706939E-05,   6.6806846E-05,   6.7973000E-05
     +,   6.9210539E-05,   7.0523995E-05,   7.1917515E-05
     +,   7.3394411E-05,   7.4957308E-05,   7.6607714E-05
     +,   7.8346151E-05,   8.0171973E-05,   8.2083025E-05
     +,   8.4075757E-05,   8.6145192E-05,   8.8284767E-05
     +,   9.0486144E-05,   9.2739589E-05,   9.5033480E-05
     +,   9.7354939E-05,   9.9689321E-05,   1.0202089E-04
     +,   1.0433244E-04,   1.0660598E-04,   1.0882245E-04
     +,   1.1096234E-04,   1.1300587E-04,   1.1493297E-04
     +,   1.1672384E-04,   1.1835922E-04,   1.1982075E-04
     +,   1.2109085E-04,   1.2215351E-04,   1.2299416E-04
     +,   1.2360017E-04,   1.2396078E-04,   1.2406756E-04
     +,   1.2391429E-04,   1.2349722E-04,   1.2281505E-04
     +,   1.2186893E-04,   1.2066244E-04,   1.1920157E-04
     +,   1.1749461E-04,   1.1555188E-04,   1.1338558E-04
     +,   1.1100990E-04,   1.0844024E-04,   1.0569359E-04
     +,   1.0278761E-04,   9.9741141E-05,   9.6573109E-05
     +,   9.3303133E-05,   8.9950488E-05,   8.6534703E-05
     +,   8.3074658E-05,   7.9588805E-05,   7.6095406E-05
     +,   7.2612318E-05,   6.9157068E-05,   6.5747503E-05
     +,   6.2402833E-05,   5.9143917E-05,   5.5995442E-05
     +,   5.2986790E-05,   5.0154897E-05,   4.7545473E-05
     +,   4.5215806E-05,   4.3235690E-05,   4.1689298E-05
     +,   4.0675666E-05,   4.0310279E-05,   4.0728271E-05
     +,   4.2091295E-05,   4.4600914E-05,   4.8520047E-05
     +,   5.4201741E-05,   6.2122417E-05,   7.2912131E-05
     +,   8.7369473E-05,   1.0644943E-04,   1.3122645E-04
     +,   1.6283365E-04,   2.0240521E-04,   2.5106678E-04
     +,   3.1001633E-04,   3.8071294E-04,   4.6516288E-04
     +,   5.6625035E-04,   6.8798958E-04,   8.3553779E-04
     +,   1.0148573E-03,   1.2320328E-03,   1.4923785E-03
     +,   1.7995441E-03,   2.1548311E-03,   2.5568632E-03
     +,   3.0011039E-03,   3.4787608E-03,   3.9748964E-03
     +,   4.4661351E-03,   4.9193758E-03,   5.2934447E-03
     +,   5.5450229E-03,   5.6380173E-03,   5.5534625E-03
     +,   5.2960441E-03,   4.8942105E-03,   4.3934365E-03
     +,   3.8453736E-03,   3.2970791E-03,   2.7835323E-03
     +,   2.3252913E-03,   1.9302557E-03,   1.5975501E-03
     +,   1.3215992E-03,   1.0952268E-03,   9.1137557E-04
     +,   7.6372735E-04,   6.4669579E-04,   5.5521610E-04
     +,   4.8454042E-04,   4.3015758E-04,   3.8786701E-04
     +,   3.5395002E-04,   3.2534634E-04,   2.9975999E-04
     +,   2.7567564E-04,   2.5227299E-04,   2.2927149E-04
     +,   2.0674986E-04,   1.8497983E-04,   1.6429514E-04
     +,   1.4500007E-04,   1.2731906E-04,   1.1137987E-04
     +,   9.7217708E-05,   8.4788153E-05,   7.3986637E-05
     +,   6.4669388E-05,   5.6672423E-05,   4.9824426E-05
     +,   4.3958880E-05,   3.8921869E-05,   3.4575947E-05
     +,   3.0801992E-05,   2.7499715E-05,   2.4586740E-05
     +,   2.1996475E-05,   1.9675899E-05,   1.7583521E-05
     +,   1.5687361E-05,   1.3962918E-05,   1.2391348E-05
     +,   1.0958232E-05,   9.6524991E-06,   8.4651811E-06
     +,   7.3888323E-06,   6.4169885E-06,   5.5436667E-06
     +,   4.7630210E-06,   4.0692339E-06,   3.4564555E-06
     +,   2.9187236E-06,   2.4499634E-06,   2.0440878E-06
     +,   1.6950913E-06,   1.3970943E-06,   1.1444117E-06
     +,   9.3164488E-07,   7.5375209E-07,   6.0605072E-07
     +,   4.8426631E-07,   3.8455221E-07,   3.0347525E-07
     +,   2.3800388E-07,   1.8549513E-07,   1.4367184E-07
     +,   1.1058729E-07,   8.4591939E-08,   6.4304089E-08
     +,   4.8577824E-08,   3.6469640E-08,   2.7209113E-08
     +,   2.0173578E-08,   1.4864327E-08,   1.0884222E-08
     +,   7.9201694E-09,   5.7274430E-09,   4.1160635E-09
     +,   2.9396297E-09,   2.0863531E-09,   1.4715421E-09
     +,   1.0314595E-09,   7.1849021E-10,   4.9736432E-10
     +,   3.4215084E-10,   2.3391369E-10,   1.5892160E-10
     +,   1.0729878E-10,   7.1994841E-11,   4.8006311E-11
     +,   3.1811071E-11,   2.0948260E-11,   1.3709243E-11
     +,   8.9159626E-12,   5.7624508E-12,   3.7011362E-12
     +,   2.3624306E-12,   1.4985541E-12,   9.4464530E-13
     +,   5.9178270E-13,   3.6841550E-13,   2.2793437E-13
     +,   1.4014090E-13,   8.5628058E-14,   5.1993572E-14
     +,   3.1374808E-14,   1.8814589E-14,   1.1212538E-14
     +,   6.6404431E-15,   3.9082875E-15,   2.2859448E-15
     +,   1.3286982E-15,   7.6751344E-16,   4.4058231E-16
     +,   2.5134223E-16,   1.4249011E-16,   8.0279348E-17
     +,   4.4947317E-17,   2.5009344E-17,   1.3828740E-17
     +,   7.5990899E-18,   4.1497583E-18,   2.2520716E-18
     +,   1.2145772E-18,   6.5097879E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt90 = Yx/0.0248387096774194
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3705878E-05,   2.4423422E-05
     +,   2.5131609E-05,   2.5828655E-05,   2.6512804E-05
     +,   2.7182352E-05,   2.7835642E-05,   2.8471080E-05
     +,   2.9087159E-05,   2.9682469E-05,   3.0255695E-05
     +,   3.0805619E-05,   3.1331176E-05,   3.1831401E-05
     +,   3.2305499E-05,   3.2752800E-05,   3.3172790E-05
     +,   3.3565138E-05,   3.3929646E-05,   3.4266304E-05
     +,   3.4575271E-05,   3.4856868E-05,   3.5111596E-05
     +,   3.5340123E-05,   3.5543264E-05,   3.5722023E-05
     +,   3.5877554E-05,   3.6011148E-05,   3.6124238E-05
     +,   3.6218404E-05,   3.6295329E-05,   3.6356829E-05
     +,   3.6404788E-05,   3.6441208E-05,   3.6468129E-05
     +,   3.6487683E-05,   3.6502002E-05,   3.6513295E-05
     +,   3.6523747E-05,   3.6535548E-05,   3.6550853E-05
     +,   3.6571815E-05,   3.6600493E-05,   3.6638903E-05
     +,   3.6688987E-05,   3.6752550E-05,   3.6831327E-05
     +,   3.6926907E-05,   3.7040740E-05,   3.7174137E-05
     +,   3.7328253E-05,   3.7504058E-05,   3.7702357E-05
     +,   3.7923786E-05,   3.8168761E-05,   3.8437534E-05
     +,   3.8730148E-05,   3.9046456E-05,   3.9386108E-05
     +,   3.9748567E-05,   4.0133102E-05,   4.0538813E-05
     +,   4.0964576E-05,   4.1409145E-05,   4.1871095E-05
     +,   4.2348824E-05,   4.2840638E-05,   4.3344651E-05
     +,   4.3858934E-05,   4.4381391E-05,   4.4909913E-05
     +,   4.5442244E-05,   4.5976158E-05,   4.6509325E-05
     +,   4.7039455E-05,   4.7564256E-05,   4.8081427E-05
     +,   4.8588718E-05,   4.9083948E-05,   4.9565024E-05
     +,   5.0029896E-05,   5.0476694E-05,   5.0903596E-05
     +,   5.1308976E-05,   5.1691302E-05,   5.2049265E-05
     +,   5.2381667E-05,   5.2687530E-05,   5.2966014E-05
     +,   5.3216521E-05,   5.3438627E-05,   5.3632069E-05
     +,   5.3796801E-05,   5.3932959E-05,   5.4040862E-05
     +,   5.4120992E-05,   5.4174023E-05,   5.4200751E-05
     +,   5.4202119E-05,   5.4179229E-05,   5.4133256E-05
     +,   5.4065487E-05,   5.3977310E-05,   5.3870139E-05
     +,   5.3745422E-05,   5.3604679E-05,   5.3449396E-05
     +,   5.3281037E-05,   5.3101034E-05,   5.2910771E-05
     +,   5.2711555E-05,   5.2504602E-05,   5.2291012E-05
     +,   5.2071769E-05,   5.1847750E-05,   5.1619627E-05
     +,   5.1387968E-05,   5.1153154E-05,   5.0915420E-05
     +,   5.0674804E-05,   5.0431187E-05,   5.0184284E-05
     +,   4.9933653E-05,   4.9678667E-05,   4.9418562E-05
     +,   4.9152444E-05,   4.8879287E-05,   4.8597929E-05
     +,   4.8307142E-05,   4.8005590E-05,   4.7691883E-05
     +,   4.7364603E-05,   4.7022266E-05,   4.6663441E-05
     +,   4.6286659E-05,   4.5890501E-05,   4.5473633E-05
     +,   4.5034783E-05,   4.4572771E-05,   4.4086526E-05
     +,   4.3575143E-05,   4.3037908E-05,   4.2474323E-05
     +,   4.1884185E-05,   4.1267805E-05,   4.0626161E-05
     +,   3.9961342E-05,   3.9277256E-05,   3.8580700E-05
     +,   3.7882870E-05,   3.7201760E-05,   3.6565372E-05
     +,   3.6015812E-05,   3.5614124E-05,   3.5445693E-05
     +,   3.5625213E-05,   3.6299894E-05,   3.7649730E-05
     +,   3.9882674E-05,   4.3223292E-05,   4.7895104E-05
     +,   5.4096952E-05,   6.1976374E-05,   7.1606861E-05
     +,   8.2976156E-05,   9.5991876E-05,   1.1051204E-04
     +,   1.2640751E-04,   1.4365782E-04,   1.6247816E-04
     +,   1.8348018E-04,   2.0787241E-04,   2.3770978E-04
     +,   2.7620606E-04,   3.2812727E-04,   4.0029228E-04
     +,   5.0213496E-04,   6.4621697E-04,   8.4846158E-04
     +,   1.1277092E-03,   1.5040312E-03,   1.9953093E-03
     +,   2.6119801E-03,   3.3504975E-03,   4.1867825E-03
     +,   5.0719557E-03,   5.9331502E-03,   6.6813561E-03
     +,   7.2263074E-03,   7.4959747E-03,   7.4551832E-03
     +,   7.1162512E-03,   6.5370318E-03,   5.8058710E-03
     +,   5.0185793E-03,   4.2561432E-03,   3.5707168E-03
     +,   2.9830784E-03,   2.4897878E-03,   2.0748281E-03
     +,   1.7201911E-03,   1.4122033E-03,   1.1432794E-03
     +,   9.1061922E-04,   7.1372208E-04,   5.5212615E-04
     +,   4.2412838E-04,   3.2642734E-04,   2.5442179E-04
     +,   2.0285166E-04,   1.6649919E-04,   1.4074097E-04
     +,   1.2186771E-04,   1.0717740E-04,   9.4892392E-05
     +,   8.3973588E-05,   7.3903240E-05,   6.4487220E-05
     +,   5.5702989E-05,   4.7597270E-05,   4.0224440E-05
     +,   3.3619104E-05,   2.7788099E-05,   2.2711956E-05
     +,   1.8350913E-05,   1.4652095E-05,   1.1555274E-05
     +,   8.9966315E-06,   6.9115040E-06,   5.2365672E-06
     +,   3.9113565E-06,   2.8792590E-06,   2.0883895E-06
     +,   1.4923792E-06,   1.0508064E-06,   7.2919636E-07
     +,   4.9893407E-07,   3.3686268E-07,   2.2468471E-07
     +,   1.4829125E-07,   9.7069034E-08,   6.3220874E-08
     +,   4.1143846E-08,   2.6899949E-08,   1.7782211E-08
     +,   1.1968192E-08,   8.2546814E-09,   5.8622023E-09
     +,   4.2948911E-09,   3.2423511E-09,   2.5126790E-09
     +,   1.9885005E-09,   1.5983751E-09,   1.2986949E-09
     +,   1.0625114E-09,   8.7279201E-10,   7.1840062E-10
     +,   5.9171668E-10,   4.8726345E-10,   4.0093115E-10
     +,   3.2952061E-10,   2.7046645E-10,   2.2166902E-10
     +,   1.8139382E-10,   1.4820198E-10,   1.2088903E-10
     +,   9.8449339E-11,   8.0044714E-11,   6.4975310E-11
     +,   5.2657025E-11,   4.2604361E-11,   3.4414784E-11
     +,   2.7754462E-11,   2.2346810E-11,   1.7963468E-11
     +,   1.4416654E-11,   1.1551340E-11,   9.2406135E-12
     +,   7.3801477E-12,   5.8847957E-12,   4.6848450E-12
     +,   3.7235970E-12,   2.9548072E-12,   2.3409996E-12
     +,   1.8517165E-12,   1.4623619E-12,   1.1530305E-12
     +,   9.0767351E-13,   7.1339278E-13,   5.5979993E-13
     +,   4.3858073E-13,   3.4306238E-13,   2.6792303E-13
     +,   2.0890842E-13,   1.6263657E-13,   1.2641276E-13
     +,   9.8102780E-14,   7.6012384E-14,   5.8804002E-14
     +,   4.5419753E-14,   3.5027076E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_hatt95 = Yx/0.0268709677419355
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5444853E-06,   3.7489367E-06
     +,   3.9606543E-06,   4.1795524E-06,   4.4055150E-06
     +,   4.6383930E-06,   4.8780062E-06,   5.1241418E-06
     +,   5.3765493E-06,   5.6349554E-06,   5.8990395E-06
     +,   6.1684505E-06,   6.4428036E-06,   6.7216774E-06
     +,   7.0046171E-06,   7.2911357E-06,   7.5807111E-06
     +,   7.8727899E-06,   8.1667904E-06,   8.4620997E-06
     +,   8.7580793E-06,   9.0540643E-06,   9.3493636E-06
     +,   9.6432841E-06,   9.9350809E-06,   1.0224032E-05
     +,   1.0509374E-05,   1.0790349E-05,   1.1066192E-05
     +,   1.1336134E-05,   1.1599403E-05,   1.1855241E-05
     +,   1.2102892E-05,   1.2341613E-05,   1.2570682E-05
     +,   1.2789391E-05,   1.2997059E-05,   1.3193021E-05
     +,   1.3376674E-05,   1.3547408E-05,   1.3704682E-05
     +,   1.3847981E-05,   1.3976846E-05,   1.4090855E-05
     +,   1.4189646E-05,   1.4272911E-05,   1.4340398E-05
     +,   1.4391921E-05,   1.4427359E-05,   1.4446668E-05
     +,   1.4449872E-05,   1.4437083E-05,   1.4408500E-05
     +,   1.4364418E-05,   1.4305246E-05,   1.4231495E-05
     +,   1.4143813E-05,   1.4042997E-05,   1.3930001E-05
     +,   1.3805967E-05,   1.3672236E-05,   1.3530390E-05
     +,   1.3382282E-05,   1.3230060E-05,   1.3076211E-05
     +,   1.2923622E-05,   1.2775602E-05,   1.2635954E-05
     +,   1.2509020E-05,   1.2399741E-05,   1.2313708E-05
     +,   1.2257236E-05,   1.2237395E-05,   1.2262082E-05
     +,   1.2340050E-05,   1.2480952E-05,   1.2695346E-05
     +,   1.2994688E-05,   1.3391355E-05,   1.3898581E-05
     +,   1.4530319E-05,   1.5301293E-05,   1.6226648E-05
     +,   1.7322011E-05,   1.8603028E-05,   2.0085385E-05
     +,   2.1784181E-05,   2.3713999E-05,   2.5888092E-05
     +,   2.8318404E-05,   3.1015003E-05,   3.3985467E-05
     +,   3.7234586E-05,   4.0764164E-05,   4.4572473E-05
     +,   4.8653455E-05,   5.2997308E-05,   5.7589197E-05
     +,   6.2410196E-05,   6.7436013E-05,   7.2638242E-05
     +,   7.7983299E-05,   8.3433872E-05,   8.8948029E-05
     +,   9.4480871E-05,   9.9984660E-05,   1.0540916E-04
     +,   1.1070272E-04,   1.1581367E-04,   1.2069072E-04
     +,   1.2528355E-04,   1.2954493E-04,   1.3343040E-04
     +,   1.3690030E-04,   1.3991966E-04,   1.4245987E-04
     +,   1.4449847E-04,   1.4602035E-04,   1.4701756E-04
     +,   1.4748993E-04,   1.4744484E-04,   1.4689710E-04
     +,   1.4586886E-04,   1.4438893E-04,   1.4249224E-04
     +,   1.4021933E-04,   1.3761519E-04,   1.3472891E-04
     +,   1.3161203E-04,   1.2831851E-04,   1.2490268E-04
     +,   1.2141949E-04,   1.1792249E-04,   1.1446402E-04
     +,   1.1109364E-04,   1.0785777E-04,   1.0479942E-04
     +,   1.0195738E-04,   9.9365716E-05,   9.7053693E-05
     +,   9.5045660E-05,   9.3360759E-05,   9.2012720E-05
     +,   9.1009984E-05,   9.0355737E-05,   9.0047768E-05
     +,   9.0078567E-05,   9.0435315E-05,   9.1099937E-05
     +,   9.2049122E-05,   9.3254443E-05,   9.4682255E-05
     +,   9.6294068E-05,   9.8046745E-05,   9.9892866E-05
     +,   1.0178112E-04,   1.0365711E-04,   1.0546455E-04
     +,   1.0714639E-04,   1.0864644E-04,   1.0991224E-04
     +,   1.1089805E-04,   1.1156937E-04,   1.1190896E-04
     +,   1.1192440E-04,   1.1165768E-04,   1.1119587E-04
     +,   1.1068236E-04,   1.1032611E-04,   1.1040700E-04
     +,   1.1127402E-04,   1.1333474E-04,   1.1703790E-04
     +,   1.2285433E-04,   1.3126839E-04,   1.4279908E-04
     +,   1.5806641E-04,   1.7791292E-04,   2.0357699E-04
     +,   2.3688104E-04,   2.8037187E-04,   3.3733129E-04
     +,   4.1160404E-04,   5.0723238E-04,   6.2795676E-04
     +,   7.7673455E-04,   9.5547346E-04,   1.1650912E-03
     +,   1.4057928E-03,   1.6772716E-03,   1.9784763E-03
     +,   2.3064429E-03,   2.6542326E-03,   3.0086474E-03
     +,   3.3488700E-03,   3.6472790E-03,   3.8732809E-03
     +,   3.9997874E-03,   4.0104110E-03,   3.9047261E-03
     +,   3.6993367E-03,   3.4239118E-03,   3.1134018E-03
     +,   2.7993969E-03,   2.5036486E-03,   2.2356040E-03
     +,   1.9942182E-03,   1.7724202E-03,   1.5620477E-03
     +,   1.3574988E-03,   1.1573143E-03,   9.6383964E-04
     +,   7.8170298E-04,   6.1601680E-04,   4.7094189E-04
     +,   3.4886767E-04,   2.5018942E-04,   1.7355193E-04
     +,   1.1635979E-04,   7.5349737E-05,   4.7092934E-05
     +,   2.8387683E-05,   1.6494778E-05,   9.2337377E-06
     +,   4.9775440E-06,   2.5828206E-06,   1.2898263E-06
     +,   6.1993057E-07,   2.8687754E-07,   1.2796012E-07
     +,   5.5158203E-08,   2.3104814E-08,   9.5113268E-09
     +,   3.9333505E-09,   1.6976103E-09,   8.0498141E-10
     +,   4.3687190E-10,   2.7125213E-10,   1.8555728E-10
     +,   1.3398728E-10,   9.9210459E-11,   7.4198488E-11
     +,   5.5666020E-11,   4.1771475E-11,   3.1314631E-11
     +,   2.3441627E-11,   1.7518990E-11,   1.3069375E-11
     +,   9.7315628E-12,   7.2321506E-12,   5.3638426E-12
     +,   3.9698635E-12,   2.9318594E-12,   2.1605146E-12
     +,   1.5885147E-12,   1.1652415E-12,   8.5274295E-13
     +,   6.2255870E-13,   4.5340088E-13,   3.2938439E-13
     +,   2.3868871E-13,   1.7252767E-13,   1.2438557E-13
     +,   8.9443339E-14,   6.4149430E-14,   4.5887143E-14
     +,   3.2736367E-14,   2.3292059E-14,   1.6528137E-14
     +,   1.1696812E-14,   8.2552322E-15,   5.8104508E-15
     +,   4.0786225E-15,   2.8551598E-15,   1.9932170E-15
     +,   1.3877000E-15,   9.6347859E-16,   6.6711976E-16
     +,   4.6064966E-16,   3.1721694E-16,   2.1784626E-16
     +,   1.4919904E-16,   1.0190509E-16,   6.9415316E-17
     +,   4.7156180E-17,   3.1949352E-17,   2.1588762E-17
     +,   1.4549248E-17,   9.7795554E-18,   6.5564159E-18
     +,   4.3843782E-18,   2.9244935E-18,   1.9459099E-18
     +,   1.2916286E-18,   8.5533293E-19,   5.6511180E-19
     +,   3.7255258E-19,   2.4508816E-19,   1.6091802E-19
     +,   1.0545901E-19,   6.8998088E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt100 = Yx/0.019
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.9495182E-09,   7.1158035E-09
     +,   8.4938021E-09,   1.0118516E-08,   1.2030058E-08
     +,   1.4274309E-08,   1.6903572E-08,   1.9977376E-08
     +,   2.3563169E-08,   2.7737428E-08,   3.2586303E-08
     +,   3.8206771E-08,   4.4707662E-08,   5.2210734E-08
     +,   6.0851868E-08,   7.0782257E-08,   8.2169613E-08
     +,   9.5199411E-08,   1.1007633E-07,   1.2702512E-07
     +,   1.4629239E-07,   1.6814738E-07,   1.9288298E-07
     +,   2.2081879E-07,   2.5229724E-07,   2.8769094E-07
     +,   3.2739811E-07,   3.7184560E-07,   4.2148818E-07
     +,   4.7680891E-07,   5.3831906E-07,   6.0655668E-07
     +,   6.8208624E-07,   7.6549736E-07,   8.5740146E-07
     +,   9.5843188E-07,   1.0692382E-06,   1.1904833E-06
     +,   1.3228481E-06,   1.4670048E-06,   1.6236409E-06
     +,   1.7934323E-06,   1.9770434E-06,   2.1751223E-06
     +,   2.3882926E-06,   2.6171444E-06,   2.8622278E-06
     +,   3.1240429E-06,   3.4030329E-06,   3.6995734E-06
     +,   4.0139635E-06,   4.3464179E-06,   4.6970517E-06
     +,   5.0659000E-06,   5.4528455E-06,   5.8576934E-06
     +,   6.2800964E-06,   6.7195833E-06,   7.1755417E-06
     +,   7.6472170E-06,   8.1337048E-06,   8.6339633E-06
     +,   9.1467627E-06,   9.6707690E-06,   1.0204499E-05
     +,   1.0746275E-05,   1.1294350E-05,   1.1846776E-05
     +,   1.2401553E-05,   1.2956501E-05,   1.3509406E-05
     +,   1.4057906E-05,   1.4599630E-05,   1.5132092E-05
     +,   1.5652817E-05,   1.6159314E-05,   1.6649063E-05
     +,   1.7119564E-05,   1.7568404E-05,   1.7993227E-05
     +,   1.8391722E-05,   1.8761741E-05,   1.9101222E-05
     +,   1.9408291E-05,   1.9681211E-05,   1.9918463E-05
     +,   2.0118719E-05,   2.0280895E-05,   2.0404121E-05
     +,   2.0487822E-05,   2.0531677E-05,   2.0535666E-05
     +,   2.0500082E-05,   2.0425541E-05,   2.0313000E-05
     +,   2.0163801E-05,   1.9979656E-05,   1.9762714E-05
     +,   1.9515554E-05,   1.9241261E-05,   1.8943423E-05
     +,   1.8626230E-05,   1.8294464E-05,   1.7953642E-05
     +,   1.7609991E-05,   1.7270580E-05,   1.6943395E-05
     +,   1.6637410E-05,   1.6362646E-05,   1.6130265E-05
     +,   1.5952672E-05,   1.5843514E-05,   1.5817785E-05
     +,   1.5891794E-05,   1.6083184E-05,   1.6410882E-05
     +,   1.6894963E-05,   1.7556586E-05,   1.8417633E-05
     +,   1.9500580E-05,   2.0828098E-05,   2.2422499E-05
     +,   2.4305273E-05,   2.6496609E-05,   2.9014680E-05
     +,   3.1874602E-05,   3.5088247E-05,   3.8662685E-05
     +,   4.2600233E-05,   4.6896683E-05,   5.1541632E-05
     +,   5.6516714E-05,   6.1796287E-05,   6.7345813E-05
     +,   7.3122850E-05,   7.9076701E-05,   8.5148349E-05
     +,   9.1271402E-05,   9.7373420E-05,   1.0337671E-04
     +,   1.0919933E-04,   1.1475722E-04,   1.1996632E-04
     +,   1.2474423E-04,   1.2901172E-04,   1.3269589E-04
     +,   1.3573140E-04,   1.3806239E-04,   1.3964412E-04
     +,   1.4044464E-04,   1.4044529E-04,   1.3964158E-04
     +,   1.3804328E-04,   1.3567423E-04,   1.3257157E-04
     +,   1.2878496E-04,   1.2437516E-04,   1.1941192E-04
     +,   1.1397235E-04,   1.0813938E-04,   1.0199864E-04
     +,   9.5636788E-05,   8.9139925E-05,   8.2591410E-05
     +,   7.6069809E-05,   6.9648217E-05,   6.3394014E-05
     +,   5.7368386E-05,   5.1626845E-05,   4.6221390E-05
     +,   4.1203883E-05,   3.6629659E-05,   3.2562457E-05
     +,   2.9080531E-05,   2.6282547E-05,   2.4291456E-05
     +,   2.3257342E-05,   2.3357106E-05,   2.4791576E-05
     +,   2.7782789E-05,   3.2575514E-05,   3.9448802E-05
     +,   4.8746377E-05,   6.0932445E-05,   7.6671880E-05
     +,   9.6923679E-05,   1.2302394E-04,   1.5671684E-04
     +,   2.0008281E-04,   2.5533375E-04,   3.2451254E-04
     +,   4.0916089E-04,   5.1010883E-04,   6.2754448E-04
     +,   7.6142012E-04,   9.1204495E-04,   1.0805578E-03
     +,   1.2688861E-03,   1.4788776E-03,   1.7106029E-03
     +,   1.9603153E-03,   2.2188846E-03,   2.4715043E-03
     +,   2.6990513E-03,   2.8809840E-03,   2.9991085E-03
     +,   3.0410024E-03,   3.0022310E-03,   2.8867444E-03
     +,   2.7054460E-03,   2.4735888E-03,   2.2079588E-03
     +,   1.9246299E-03,   1.6377181E-03,   1.3590641E-03
     +,   1.0983243E-03,   8.6299784E-04,   6.5826555E-04
     +,   4.8679198E-04,   3.4869483E-04,   2.4179980E-04
     +,   1.6226889E-04,   1.0536808E-04,   6.6190558E-05
     +,   4.0210267E-05,   2.3608503E-05,   1.3385136E-05
     +,   7.3201886E-06,   3.8564162E-06,   1.9541912E-06
     +,   9.5110892E-07,   4.4396356E-07,   1.9847643E-07
     +,   8.4870805E-08,   3.4676724E-08,   1.3524528E-08
     +,   5.0308975E-09,   1.7837332E-09,   6.0249605E-10
     +,   1.9378250E-10,   5.9326571E-11,   1.7285324E-11
     +,   4.7928428E-12,   1.2650598E-12,   3.1826210E-13
     +,   7.6665027E-14,   1.7950968E-14,   4.2854095E-15
     +,   1.1827659E-15,   4.5380701E-16,   2.4792609E-16
     +,   1.6382162E-16,   1.1545117E-16,   8.2768261E-17
     +,   5.9549500E-17,   4.2842864E-17,   3.0791699E-17
     +,   2.2100133E-17,   1.5837235E-17,   1.1329981E-17
     +,   8.0912789E-18,   5.7679060E-18,   4.1040086E-18
     +,   2.9145372E-18,   2.0658499E-18,   1.4614497E-18
     +,   1.0318486E-18,   7.2709853E-19,   5.1135153E-19
     +,   3.5891119E-19,   2.5141371E-19,   1.7576413E-19
     +,   1.2263517E-19,   8.5395748E-20,   5.9345821E-20
     +,   4.1160892E-20,   2.8491367E-20,   1.9682593E-20
     +,   1.3570058E-20,   9.3373723E-21,   6.4120408E-21
     +,   4.3945198E-21,   3.0057776E-21,   2.0518508E-21
     +,   1.3978590E-21,   9.5043567E-22,   6.4493956E-22
     +,   4.3676424E-22,   2.9520051E-22,   1.9912106E-22
     +,   1.3404765E-22,   9.0059908E-23,   6.0387296E-23
     +,   4.0410249E-23,   2.6988437E-23,   1.7988532E-23
     +,   1.1966227E-23,   7.9441480E-24,   5.2635565E-24
     +,   3.4804981E-24,   2.2969261E-24
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt105 = Yx/0.0131923076923077
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   2.1848967E-38
     +,   6.7269792E-38,   2.0540022E-37,   6.2197087E-37
     +,   1.8678170E-36,   5.5626744E-36,   1.6429511E-35
     +,   4.8123513E-35,   1.3979074E-34,   4.0270581E-34
     +,   1.1505152E-33,   3.2597575E-33,   9.1592514E-33
     +,   2.5523559E-32,   7.0533581E-32,   1.9330838E-31
     +,   5.2540455E-31,   1.4162133E-30,   3.7857497E-30
     +,   1.0036102E-29,   2.6385791E-29,   6.8796571E-29
     +,   1.7789012E-28,   4.5617023E-28,   1.1600911E-27
     +,   2.9258179E-27,   7.3180300E-27,   1.8152001E-26
     +,   4.4653601E-26,   1.0893486E-25,   2.6355567E-25
     +,   6.3236974E-25,   1.5047291E-24,   3.5508897E-24
     +,   8.3100343E-24,   1.9286871E-23,   4.4392620E-23
     +,   1.0133236E-22,   2.2939235E-22,   5.1498920E-22
     +,   1.1465878E-21,   2.5316670E-21,   5.5435876E-21
     +,   1.2038579E-20,   2.5926348E-20,   5.5373558E-20
     +,   1.1728755E-19,   2.4637298E-19,   5.1324448E-19
     +,   1.0603432E-18,   2.1724939E-18,   4.4143316E-18
     +,   8.8951289E-18,   1.7775817E-17,   3.5229596E-17
     +,   6.9241416E-17,   1.3496569E-16,   2.6089253E-16
     +,   5.0015061E-16,   9.5086775E-16,   1.7928276E-15
     +,   3.3522614E-15,   6.2163756E-15,   1.1431876E-14
     +,   2.0849165E-14,   3.7710069E-14,   6.7642208E-14
     +,   1.2032590E-13,   2.1227132E-13,   3.7138291E-13
     +,   6.4436851E-13,   1.1087792E-12,   1.8920753E-12
     +,   3.2020660E-12,   5.3740836E-12,   8.9449151E-12
     +,   1.4764927E-11,   2.4170416E-11,   3.9239261E-11
     +,   6.3175409E-11,   1.0087258E-10,   1.5973099E-10
     +,   2.5083624E-10,   3.9064577E-10,   6.0335797E-10
     +,   9.2417285E-10,   1.4038850E-09,   2.1149427E-09
     +,   3.1598559E-09,   4.6819637E-09,   6.8800943E-09
     +,   1.0026674E-08,   1.4492050E-08,   2.0773353E-08
     +,   2.9532282E-08,   4.1640067E-08,   5.8230693E-08
     +,   8.0764814E-08,   1.1110585E-07,   1.5160477E-07
     +,   2.0518971E-07,   2.7548032E-07,   3.6688559E-07
     +,   4.8473879E-07,   6.3539227E-07,   8.2636973E-07
     +,   1.0664396E-06,   1.3657748E-06,   1.7359889E-06
     +,   2.1902933E-06,   2.7435585E-06,   3.4123557E-06
     +,   4.2150482E-06,   5.1719539E-06,   6.3054158E-06
     +,   7.6398210E-06,   9.2020437E-06,   1.1021316E-05
     +,   1.3129882E-05,   1.5562780E-05,   1.8358656E-05
     +,   2.1559272E-05,   2.5210304E-05,   2.9360268E-05
     +,   3.4060817E-05,   3.9365452E-05,   4.5327641E-05
     +,   5.1998901E-05,   5.9426467E-05,   6.7649518E-05
     +,   7.6694574E-05,   8.6571381E-05,   9.7269127E-05
     +,   1.0875153E-04,   1.2095177E-04,   1.3377205E-04
     +,   1.4708111E-04,   1.6071394E-04,   1.7447502E-04
     +,   1.8814403E-04,   2.0148174E-04,   2.1423773E-04
     +,   2.2616121E-04,   2.3701249E-04,   2.4657240E-04
     +,   2.5465171E-04,   2.6109995E-04,   2.6581189E-04
     +,   2.6873016E-04,   2.6984606E-04,   2.6919783E-04
     +,   2.6686603E-04,   2.6296728E-04,   2.5764690E-04
     +,   2.5107004E-04,   2.4341367E-04,   2.3485968E-04
     +,   2.2558792E-04,   2.1577024E-04,   2.0556721E-04
     +,   1.9512638E-04,   1.8458042E-04,   1.7404601E-04
     +,   1.6362504E-04,   1.5340671E-04,   1.4346719E-04
     +,   1.3387277E-04,   1.2468417E-04,   1.1596031E-04
     +,   1.0776450E-04,   1.0017372E-04,   9.3289527E-05
     +,   8.7248569E-05,   8.2232531E-05,   7.8475961E-05
     +,   7.6270197E-05,   7.5963821E-05,   7.7965153E-05
     +,   8.2751649E-05,   9.0886504E-05,   1.0304066E-04
     +,   1.2000603E-04,   1.4269065E-04,   1.7211057E-04
     +,   2.0942213E-04,   2.5603961E-04,   3.1384194E-04
     +,   3.8538038E-04,   4.7393446E-04,   5.8335386E-04
     +,   7.1791222E-04,   8.8258740E-04,   1.0838336E-03
     +,   1.3299442E-03,   1.6292819E-03,   1.9852258E-03
     +,   2.3887167E-03,   2.8123467E-03,   3.2107781E-03
     +,   3.5294259E-03,   3.7184481E-03,   3.7460472E-03
     +,   3.6057788E-03,   3.3161654E-03,   2.9145714E-03
     +,   2.4483935E-03,   1.9659158E-03,   1.5085415E-03
     +,   1.1057919E-03,   7.7364937E-04,   5.1581766E-04
     +,   3.2697120E-04,   1.9645205E-04,   1.1147890E-04
     +,   5.9522154E-05,   2.9794473E-05,   1.3937472E-05
     +,   6.0774701E-06,   2.4660833E-06,   9.3083065E-07
     +,   3.2753039E-07,   1.0826297E-07,   3.4313885E-08
     +,   1.0949356E-08,   3.8558947E-09,   1.6562783E-09
     +,   8.7782431E-10,   5.2969817E-10,   3.3672590E-10
     +,   2.1686866E-10,   1.3947077E-10,   8.9155044E-11
     +,   5.6574898E-11,   3.5625440E-11,   2.2259413E-11
     +,   1.3800108E-11,   8.4893108E-12,   5.1817409E-12
     +,   3.1382360E-12,   1.8858916E-12,   1.1245032E-12
     +,   6.6528998E-13,   3.9054917E-13,   2.2748876E-13
     +,   1.3147973E-13,   7.5398699E-14,   4.2902412E-14
     +,   2.4222603E-14,   1.3569829E-14,   7.5427996E-15
     +,   4.1601066E-15,   2.2766607E-15,   1.2362489E-15
     +,   6.6606849E-16,   3.5608447E-16,   1.8888684E-16
     +,   9.9415516E-17,   5.1918378E-17,   2.6903580E-17
     +,   1.3832883E-17,   7.0569979E-18,   3.5722291E-18
     +,   1.7942536E-18,   8.9421202E-19,   4.4218268E-19
     +,   2.1696343E-19,   1.0562665E-19,   5.1025331E-20
     +,   2.4456829E-20,   1.1631564E-20,   5.4888321E-21
     +,   2.5700821E-21,   1.1940280E-21,   5.5043659E-22
     +,   2.5176994E-22,   1.1426785E-22,   5.1458602E-23
     +,   2.2992916E-23,   1.0194252E-23,   4.4845496E-24
     +,   1.9575333E-24,   8.4780637E-25,   3.6434635E-25
     +,   1.5535647E-25,   6.5731404E-26,   2.7594142E-26
     +,   1.1494439E-26,   4.7507172E-27,   1.9483002E-27
     +,   7.9278354E-28,   3.2009485E-28
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt107 = Yx/0.0134615384615385
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4456734E-06,   1.5850301E-06
     +,   1.7354391E-06,   1.8975203E-06,   2.0718994E-06
     +,   2.2592121E-06,   2.4600945E-06,   2.6751820E-06
     +,   2.9051039E-06,   3.1504910E-06,   3.4119537E-06
     +,   3.6900874E-06,   3.9854676E-06,   4.2986439E-06
     +,   4.6301361E-06,   4.9804262E-06,   5.3499571E-06
     +,   5.7391203E-06,   6.1482610E-06,   6.5776626E-06
     +,   7.0275460E-06,   7.4980617E-06,   7.9892770E-06
     +,   8.5012152E-06,   9.0337535E-06,   9.5867390E-06
     +,   1.0159892E-05,   1.0752840E-05,   1.1365109E-05
     +,   1.1996122E-05,   1.2645193E-05,   1.3311525E-05
     +,   1.3994208E-05,   1.4692222E-05,   1.5404439E-05
     +,   1.6129608E-05,   1.6866385E-05,   1.7613291E-05
     +,   1.8368799E-05,   1.9131196E-05,   1.9898764E-05
     +,   2.0669646E-05,   2.1441911E-05,   2.2213557E-05
     +,   2.2982522E-05,   2.3746687E-05,   2.4503877E-05
     +,   2.5251902E-05,   2.5988533E-05,   2.6711545E-05
     +,   2.7418704E-05,   2.8107812E-05,   2.8776663E-05
     +,   2.9423163E-05,   3.0045192E-05,   3.0640778E-05
     +,   3.1208001E-05,   3.1745050E-05,   3.2250235E-05
     +,   3.2722000E-05,   3.3158925E-05,   3.3559772E-05
     +,   3.3923436E-05,   3.4249028E-05,   3.4535857E-05
     +,   3.4783410E-05,   3.4991412E-05,   3.5159796E-05
     +,   3.5288733E-05,   3.5378624E-05,   3.5430112E-05
     +,   3.5444074E-05,   3.5421646E-05,   3.5364195E-05
     +,   3.5273319E-05,   3.5150864E-05,   3.4998902E-05
     +,   3.4819735E-05,   3.4615867E-05,   3.4389992E-05
     +,   3.4145029E-05,   3.3884022E-05,   3.3610217E-05
     +,   3.3326953E-05,   3.3037726E-05,   3.2746084E-05
     +,   3.2455690E-05,   3.2170199E-05,   3.1893334E-05
     +,   3.1628784E-05,   3.1380179E-05,   3.1151110E-05
     +,   3.0945062E-05,   3.0765379E-05,   3.0615236E-05
     +,   3.0497631E-05,   3.0415336E-05,   3.0370857E-05
     +,   3.0366431E-05,   3.0403971E-05,   3.0485080E-05
     +,   3.0610965E-05,   3.0782499E-05,   3.1000120E-05
     +,   3.1263877E-05,   3.1573411E-05,   3.1927910E-05
     +,   3.2326141E-05,   3.2766471E-05,   3.3246844E-05
     +,   3.3764783E-05,   3.4317472E-05,   3.4901703E-05
     +,   3.5513993E-05,   3.6150534E-05,   3.6807352E-05
     +,   3.7480218E-05,   3.8164879E-05,   3.8856939E-05
     +,   3.9552091E-05,   4.0246141E-05,   4.0935032E-05
     +,   4.1614989E-05,   4.2282649E-05,   4.2935124E-05
     +,   4.3570017E-05,   4.4185679E-05,   4.4781140E-05
     +,   4.5356348E-05,   4.5912122E-05,   4.6450376E-05
     +,   4.6974001E-05,   4.7487123E-05,   4.7994970E-05
     +,   4.8503996E-05,   4.9021866E-05,   4.9557380E-05
     +,   5.0120459E-05,   5.0722105E-05,   5.1374271E-05
     +,   5.2089690E-05,   5.2881722E-05,   5.3764292E-05
     +,   5.4751559E-05,   5.5857610E-05,   5.7096440E-05
     +,   5.8481553E-05,   6.0025581E-05,   6.1740117E-05
     +,   6.3635533E-05,   6.5720640E-05,   6.8002257E-05
     +,   7.0485068E-05,   7.3171635E-05,   7.6062010E-05
     +,   7.9153331E-05,   8.2439852E-05,   8.5913009E-05
     +,   8.9561028E-05,   9.3368508E-05,   9.7316864E-05
     +,   1.0138397E-04,   1.0554372E-04,   1.0976631E-04
     +,   1.1401844E-04,   1.1826339E-04,   1.2246100E-04
     +,   1.2656875E-04,   1.3054298E-04,   1.3434005E-04
     +,   1.3791813E-04,   1.4123971E-04,   1.4427486E-04
     +,   1.4700386E-04,   1.4942062E-04,   1.5153628E-04
     +,   1.5338174E-04,   1.5500958E-04,   1.5649531E-04
     +,   1.5793680E-04,   1.5945226E-04,   1.6117685E-04
     +,   1.6325810E-04,   1.6585116E-04,   1.6911438E-04
     +,   1.7320625E-04,   1.7828579E-04,   1.8451724E-04
     +,   1.9207936E-04,   2.0117927E-04,   2.1207452E-04
     +,   2.2509678E-04,   2.4067846E-04,   2.5938096E-04
     +,   2.8192121E-04,   3.0919007E-04,   3.4225819E-04
     +,   3.8236848E-04,   4.3090645E-04,   4.8933644E-04
     +,   5.5909436E-04,   6.4144225E-04,   7.3728053E-04
     +,   8.4691186E-04,   9.6977217E-04,   1.1042067E-03
     +,   1.2472660E-03,   1.3946000E-03,   1.5405230E-03
     +,   1.6782633E-03,   1.8003786E-03,   1.8993531E-03
     +,   1.9683137E-03,   2.0017673E-03,   1.9962308E-03
     +,   1.9506973E-03,   1.8668296E-03,   1.7488350E-03
     +,   1.6030632E-03,   1.4373788E-03,   1.2603552E-03
     +,   1.0804812E-03,   9.0545393E-04,   7.4161333E-04
     +,   5.9359975E-04,   4.6426436E-04,   3.5477796E-04
     +,   2.6487347E-04,   1.9318704E-04,   1.3763983E-04
     +,   9.5789372E-05,   6.5114946E-05,   4.3232278E-05
     +,   2.8033204E-05,   1.7752793E-05,   1.0979040E-05
     +,   6.6303987E-06,   3.9100400E-06,   2.2515503E-06
     +,   1.2659646E-06,   6.9500322E-07,   3.7255592E-07
     +,   1.9501637E-07,   9.9696123E-08,   4.9788433E-08
     +,   2.4303647E-08,   1.1608314E-08,   5.4356577E-09
     +,   2.5041809E-09,   1.1425619E-09,   5.2232013E-10
     +,   2.4389502E-10,   1.1962326E-10,   6.3586143E-11
     +,   3.7395260E-11,   2.4269886E-11,   1.6995908E-11
     +,   1.2493021E-11,   9.4315788E-12,   7.2138320E-12
     +,   5.5481951E-12,   4.2744033E-12,   3.2924427E-12
     +,   2.5333088E-12,   1.9462904E-12,   1.4927420E-12
     +,   1.1427995E-12,   8.7326061E-13,   6.6602892E-13
     +,   5.0699581E-13,   3.8518109E-13,   2.9206059E-13
     +,   2.2101795E-13,   1.6692459E-13,   1.2581810E-13
     +,   9.4646113E-14,   7.1053887E-14,   5.3236048E-14
     +,   3.9805754E-14,   2.9704036E-14,   2.2121043E-14
     +,   1.6440857E-14,   1.2194461E-14,   9.0266768E-15
     +,   6.6682711E-15,   4.9161453E-15,   3.6170971E-15
     +,   2.6559133E-15,   1.9462316E-15,   1.4232934E-15
     +,   1.0387788E-15,   7.5660546E-16,   5.4997796E-16
     +,   3.9897012E-16,   2.8884467E-16,   2.0869289E-16
     +,   1.5048071E-16,   1.0828662E-16,   7.7767557E-17
     +,   5.5736899E-17,   3.9867419E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt110 = Yx/0.0112
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6989991E-06,   3.9505576E-06
     +,   4.2152737E-06,   4.4935696E-06,   4.7858643E-06
     +,   5.0925805E-06,   5.4141383E-06,   5.7509574E-06
     +,   6.1034470E-06,   6.4720343E-06,   6.8571253E-06
     +,   7.2591301E-06,   7.6784509E-06,   8.1154913E-06
     +,   8.5706424E-06,   9.0442973E-06,   9.5368359E-06
     +,   1.0048631E-05,   1.0580050E-05,   1.1131441E-05
     +,   1.1703147E-05,   1.2295493E-05,   1.2908777E-05
     +,   1.3543315E-05,   1.4199337E-05,   1.4877110E-05
     +,   1.5576834E-05,   1.6298696E-05,   1.7042830E-05
     +,   1.7809341E-05,   1.8598284E-05,   1.9409670E-05
     +,   2.0243437E-05,   2.1099489E-05,   2.1977639E-05
     +,   2.2877663E-05,   2.3799228E-05,   2.4741928E-05
     +,   2.5705340E-05,   2.6688824E-05,   2.7691784E-05
     +,   2.8713463E-05,   2.9753028E-05,   3.0809562E-05
     +,   3.1882049E-05,   3.2969394E-05,   3.4070432E-05
     +,   3.5183897E-05,   3.6308506E-05,   3.7442864E-05
     +,   3.8585582E-05,   3.9735220E-05,   4.0890318E-05
     +,   4.2049505E-05,   4.3211297E-05,   4.4374407E-05
     +,   4.5537545E-05,   4.6699530E-05,   4.7859325E-05
     +,   4.9016031E-05,   5.0168961E-05,   5.1317613E-05
     +,   5.2461681E-05,   5.3601183E-05,   5.4736418E-05
     +,   5.5867888E-05,   5.6996545E-05,   5.8123525E-05
     +,   5.9250440E-05,   6.0379094E-05,   6.1511782E-05
     +,   6.2650957E-05,   6.3799547E-05,   6.4960615E-05
     +,   6.6137589E-05,   6.7334142E-05,   6.8554065E-05
     +,   6.9801230E-05,   7.1079739E-05,   7.2393676E-05
     +,   7.3746989E-05,   7.5143638E-05,   7.6587290E-05
     +,   7.8081473E-05,   7.9629208E-05,   8.1233331E-05
     +,   8.2895960E-05,   8.4618841E-05,   8.6402928E-05
     +,   8.8248569E-05,   9.0155467E-05,   9.2122333E-05
     +,   9.4147072E-05,   9.6226897E-05,   9.8358119E-05
     +,   1.0053605E-04,   1.0275543E-04,   1.0501000E-04
     +,   1.0729300E-04,   1.0959688E-04,   1.1191376E-04
     +,   1.1423520E-04,   1.1655276E-04,   1.1885769E-04
     +,   1.2114155E-04,   1.2339630E-04,   1.2561427E-04
     +,   1.2778852E-04,   1.2991336E-04,   1.3198421E-04
     +,   1.3399782E-04,   1.3595274E-04,   1.3784925E-04
     +,   1.3968974E-04,   1.4147855E-04,   1.4322239E-04
     +,   1.4493006E-04,   1.4661264E-04,   1.4828330E-04
     +,   1.4995720E-04,   1.5165129E-04,   1.5338382E-04
     +,   1.5517420E-04,   1.5704245E-04,   1.5900885E-04
     +,   1.6109287E-04,   1.6331337E-04,   1.6568694E-04
     +,   1.6822819E-04,   1.7094822E-04,   1.7385476E-04
     +,   1.7695049E-04,   1.8023363E-04,   1.8369639E-04
     +,   1.8732536E-04,   1.9110086E-04,   1.9499670E-04
     +,   1.9898037E-04,   2.0301358E-04,   2.0705232E-04
     +,   2.1104734E-04,   2.1494512E-04,   2.1868902E-04
     +,   2.2222030E-04,   2.2547880E-04,   2.2840517E-04
     +,   2.3094185E-04,   2.3303418E-04,   2.3463223E-04
     +,   2.3569212E-04,   2.3617691E-04,   2.3605804E-04
     +,   2.3531583E-04,   2.3394033E-04,   2.3193167E-04
     +,   2.2930029E-04,   2.2606665E-04,   2.2226134E-04
     +,   2.1792362E-04,   2.1310212E-04,   2.0785267E-04
     +,   2.0223805E-04,   1.9632721E-04,   1.9019442E-04
     +,   1.8391784E-04,   1.7757929E-04,   1.7126418E-04
     +,   1.6506105E-04,   1.5906083E-04,   1.5335729E-04
     +,   1.4804777E-04,   1.4323273E-04,   1.3901581E-04
     +,   1.3550431E-04,   1.3280916E-04,   1.3104395E-04
     +,   1.3032474E-04,   1.3076850E-04,   1.3249170E-04
     +,   1.3560812E-04,   1.4022677E-04,   1.4644858E-04
     +,   1.5436353E-04,   1.6404843E-04,   1.7556328E-04
     +,   1.8894798E-04,   2.0421961E-04,   2.2137193E-04
     +,   2.4037235E-04,   2.6115874E-04,   2.8364192E-04
     +,   3.0770319E-04,   3.3319267E-04,   3.5992981E-04
     +,   3.8770610E-04,   4.1628291E-04,   4.4539044E-04
     +,   4.7472981E-04,   5.0397677E-04,   5.3278118E-04
     +,   5.6076830E-04,   5.8754458E-04,   6.1270443E-04
     +,   6.3583610E-04,   6.5652677E-04,   6.7437725E-04
     +,   6.8901113E-04,   7.0008467E-04,   7.0730102E-04
     +,   7.1042264E-04,   7.0928078E-04,   7.0378464E-04
     +,   6.9392921E-04,   6.7979831E-04,   6.6156563E-04
     +,   6.3949259E-04,   6.1392202E-04,   5.8526674E-04
     +,   5.5399787E-04,   5.2063394E-04,   4.8571837E-04
     +,   4.4980514E-04,   4.1344468E-04,   3.7716565E-04
     +,   3.4145825E-04,   3.0676409E-04,   2.7346952E-04
     +,   2.4189650E-04,   2.1229689E-04,   1.8485435E-04
     +,   1.5968776E-04,   1.3685330E-04,   1.1634923E-04
     +,   9.8125027E-05,   8.2091123E-05,   6.8123714E-05
     +,   5.6075369E-05,   4.5783610E-05,   3.7077058E-05
     +,   2.9781460E-05,   2.3725783E-05,   1.8746659E-05
     +,   1.4691026E-05,   1.1418129E-05,   8.8012021E-06
     +,   6.7280703E-06,   5.1008024E-06,   3.8351027E-06
     +,   2.8595396E-06,   2.1144610E-06,   1.5505252E-06
     +,   1.1275209E-06,   8.1308758E-07,   5.8145764E-07
     +,   4.1234296E-07,   2.8996845E-07,   2.0220703E-07
     +,   1.3982913E-07,   9.5884239E-08,   6.5198421E-08
     +,   4.3961279E-08,   2.9393465E-08,   1.9488171E-08
     +,   1.2812201E-08,   8.3525560E-09,   5.3994622E-09
     +,   3.4610670E-09,   2.1998992E-09,   1.3865473E-09
     +,   8.6656043E-10,   5.3701676E-10,   3.2999503E-10
     +,   2.0107797E-10,   1.2149325E-10,   7.2788463E-11
     +,   4.3242458E-11,   2.5473033E-11,   1.4879483E-11
     +,   8.6182277E-12,   4.9497715E-12,   2.8188658E-12
     +,   1.5918493E-12,   8.9135676E-13,   4.9492452E-13
     +,   2.7248882E-13,   1.4876368E-13,   8.0533419E-14
     +,   4.3229184E-14,   2.3009987E-14,   1.2144440E-14
     +,   6.3559154E-15,   3.2983704E-15,   1.6973065E-15
     +,   8.6604847E-16,   4.3819045E-16,   2.1983897E-16
     +,   1.0936717E-16,   5.3949964E-17,   2.6389955E-17
     +,   1.2800017E-17,   6.1565047E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt115 = Yx/0.009625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.0083172E-07,   7.8594786E-07
     +,   8.7986467E-07,   9.8328894E-07,   1.0969601E-06
     +,   1.2216486E-06,   1.3581539E-06,   1.5073032E-06
     +,   1.6699448E-06,   1.8469572E-06,   2.0392288E-06
     +,   2.2476668E-06,   2.4731855E-06,   2.7167096E-06
     +,   2.9791599E-06,   3.2614557E-06,   3.5645069E-06
     +,   3.8892067E-06,   4.2364245E-06,   4.6070072E-06
     +,   5.0017629E-06,   5.4214615E-06,   5.8668188E-06
     +,   6.3385278E-06,   6.8371719E-06,   7.3633209E-06
     +,   7.9174506E-06,   8.4999638E-06,   9.1111906E-06
     +,   9.7513766E-06,   1.0420684E-05,   1.1119186E-05
     +,   1.1846865E-05,   1.2603615E-05,   1.3389235E-05
     +,   1.4203438E-05,   1.5045837E-05,   1.5915946E-05
     +,   1.6813246E-05,   1.7737028E-05,   1.8686602E-05
     +,   1.9661135E-05,   2.0659725E-05,   2.1681399E-05
     +,   2.2725104E-05,   2.3789717E-05,   2.4874042E-05
     +,   2.5976813E-05,   2.7096708E-05,   2.8232329E-05
     +,   2.9382212E-05,   3.0544845E-05,   3.1718624E-05
     +,   3.2901971E-05,   3.4093111E-05,   3.5290359E-05
     +,   3.6491871E-05,   3.7695794E-05,   3.8900231E-05
     +,   4.0103219E-05,   4.1302785E-05,   4.2496926E-05
     +,   4.3683547E-05,   4.4860641E-05,   4.6026180E-05
     +,   4.7178062E-05,   4.8314345E-05,   4.9432983E-05
     +,   5.0532133E-05,   5.1609888E-05,   5.2664571E-05
     +,   5.3694472E-05,   5.4698150E-05,   5.5674165E-05
     +,   5.6621353E-05,   5.7538684E-05,   5.8425281E-05
     +,   5.9280406E-05,   6.0103619E-05,   6.0894632E-05
     +,   6.1653271E-05,   6.2379644E-05,   6.3073909E-05
     +,   6.3736494E-05,   6.4367858E-05,   6.4968655E-05
     +,   6.5539563E-05,   6.6081404E-05,   6.6594977E-05
     +,   6.7081193E-05,   6.7540968E-05,   6.7975234E-05
     +,   6.8384899E-05,   6.8770962E-05,   6.9134447E-05
     +,   6.9476388E-05,   6.9797999E-05,   7.0100563E-05
     +,   7.0385577E-05,   7.0654809E-05,   7.0910348E-05
     +,   7.1154645E-05,   7.1390670E-05,   7.1621922E-05
     +,   7.1852548E-05,   7.2087387E-05,   7.2332092E-05
     +,   7.2593066E-05,   7.2877599E-05,   7.3193907E-05
     +,   7.3550967E-05,   7.3958690E-05,   7.4427677E-05
     +,   7.4969263E-05,   7.5595264E-05,   7.6317992E-05
     +,   7.7149831E-05,   7.8103280E-05,   7.9190460E-05
     +,   8.0423066E-05,   8.1811966E-05,   8.3366896E-05
     +,   8.5096064E-05,   8.7006141E-05,   8.9101784E-05
     +,   9.1385162E-05,   9.3856157E-05,   9.6511598E-05
     +,   9.9345736E-05,   1.0234932E-04,   1.0551044E-04
     +,   1.0881354E-04,   1.1224040E-04,   1.1576938E-04
     +,   1.1937634E-04,   1.2303457E-04,   1.2671483E-04
     +,   1.3038605E-04,   1.3401579E-04,   1.3757074E-04
     +,   1.4101667E-04,   1.4431946E-04,   1.4744577E-04
     +,   1.5036321E-04,   1.5304089E-04,   1.5545021E-04
     +,   1.5756523E-04,   1.5936294E-04,   1.6082388E-04
     +,   1.6193249E-04,   1.6267721E-04,   1.6305083E-04
     +,   1.6305060E-04,   1.6267823E-04,   1.6193994E-04
     +,   1.6084629E-04,   1.5941224E-04,   1.5765658E-04
     +,   1.5560183E-04,   1.5327403E-04,   1.5070205E-04
     +,   1.4791728E-04,   1.4495329E-04,   1.4184540E-04
     +,   1.3862975E-04,   1.3534300E-04,   1.3202218E-04
     +,   1.2870386E-04,   1.2542345E-04,   1.2221500E-04
     +,   1.1911099E-04,   1.1614156E-04,   1.1333413E-04
     +,   1.1071320E-04,   1.0830028E-04,   1.0611327E-04
     +,   1.0416639E-04,   1.0247033E-04,   1.0103189E-04
     +,   9.9854020E-05,   9.8935801E-05,   9.8272860E-05
     +,   9.7857104E-05,   9.7677126E-05,   9.7718425E-05
     +,   9.7963675E-05,   9.8392971E-05,   9.8984303E-05
     +,   9.9713870E-05,   1.0055630E-04,   1.0148533E-04
     +,   1.0247398E-04,   1.0349500E-04,   1.0452127E-04
     +,   1.0552616E-04,   1.0648392E-04,   1.0736984E-04
     +,   1.0816068E-04,   1.0883484E-04,   1.0937272E-04
     +,   1.0975669E-04,   1.0997130E-04,   1.1000351E-04
     +,   1.0984261E-04,   1.0948028E-04,   1.0891066E-04
     +,   1.0813018E-04,   1.0713768E-04,   1.0593418E-04
     +,   1.0452281E-04,   1.0290862E-04,   1.0109863E-04
     +,   9.9101577E-05,   9.6927564E-05,   9.4588038E-05
     +,   9.2095754E-05,   8.9464484E-05,   8.6708635E-05
     +,   8.3843195E-05,   8.0883940E-05,   7.7846555E-05
     +,   7.4746902E-05,   7.1600938E-05,   6.8424459E-05
     +,   6.5232693E-05,   6.2040388E-05,   5.8861922E-05
     +,   5.5710956E-05,   5.2600175E-05,   4.9541384E-05
     +,   4.6545647E-05,   4.3623033E-05,   4.0782375E-05
     +,   3.8031470E-05,   3.5377303E-05,   3.2825516E-05
     +,   3.0380703E-05,   2.8046583E-05,   2.5825853E-05
     +,   2.3720104E-05,   2.1730024E-05,   1.9855590E-05
     +,   1.8095963E-05,   1.6449476E-05,   1.4913823E-05
     +,   1.3486221E-05,   1.2163379E-05,   1.0941492E-05
     +,   9.8164091E-06,   8.7838089E-06,   7.8390449E-06
     +,   6.9773309E-06,   6.1938508E-06,   5.4837419E-06
     +,   4.8421061E-06,   4.2641136E-06,   3.7450745E-06
     +,   3.2804212E-06,   2.8657128E-06,   2.4966985E-06
     +,   2.1693536E-06,   1.8798623E-06,   1.6246129E-06
     +,   1.4002269E-06,   1.2035789E-06,   1.0317515E-06
     +,   8.8205746E-07,   7.5203923E-07,   6.3945095E-07
     +,   5.4224301E-07,   4.5856081E-07,   3.8673880E-07
     +,   3.2528018E-07,   2.7284315E-07,   2.2823407E-07
     +,   1.9039872E-07,   1.5840075E-07,   1.3142090E-07
     +,   1.0873750E-07,   8.9723493E-08,   7.3830890E-08
     +,   6.0587062E-08,   4.9582070E-08,   4.0464769E-08
     +,   3.2932903E-08,   2.6729364E-08,   2.1634580E-08
     +,   1.7462451E-08,   1.4056083E-08,   1.1282830E-08
     +,   9.0317434E-09,   7.2096955E-09,   5.7393130E-09
     +,   4.5560951E-09,   3.6067898E-09,   2.8473182E-09
     +,   2.2415294E-09,   1.7596953E-09,   1.3775924E-09
     +,   1.0754421E-09,   8.3722301E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt120 = Yx/0.00411764705882353
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.8854625E-05,   5.0855338E-05
     +,   5.2895433E-05,   5.4973803E-05,   5.7090212E-05
     +,   5.9245529E-05,   6.1441926E-05,   6.3683066E-05
     +,   6.5974295E-05,   6.8322901E-05,   7.0738053E-05
     +,   7.3231146E-05,   7.5815660E-05,   7.8507408E-05
     +,   8.1324462E-05,   8.4287145E-05,   8.7418055E-05
     +,   9.0742040E-05,   9.4286210E-05,   9.8079960E-05
     +,   1.0215504E-04,   1.0654563E-04,   1.1128847E-04
     +,   1.1642338E-04,   1.2199263E-04,   1.2804221E-04
     +,   1.3462106E-04,   1.4178151E-04,   1.4957896E-04
     +,   1.5807133E-04,   1.6731839E-04,   1.7738037E-04
     +,   1.8831631E-04,   2.0018166E-04,   2.1302573E-04
     +,   2.2688821E-04,   2.4179560E-04,   2.5775706E-04
     +,   2.7476196E-04,   2.9277289E-04,   3.1172676E-04
     +,   3.3152910E-04,   3.5205434E-04,   3.7314597E-04
     +,   3.9461817E-04,   4.1625975E-04,   4.3784006E-04
     +,   4.5911581E-04,   4.7984044E-04,   4.9977377E-04
     +,   5.1869272E-04,   5.3640112E-04,   5.5274036E-04
     +,   5.6759699E-04,   5.8090687E-04,   5.9266109E-04
     +,   6.0290314E-04,   6.1172619E-04,   6.1926630E-04
     +,   6.2569237E-04,   6.3119386E-04,   6.3596800E-04
     +,   6.4020517E-04,   6.4407679E-04,   6.4772449E-04
     +,   6.5125077E-04,   6.5471692E-04,   6.5814168E-04
     +,   6.6150707E-04,   6.6476641E-04,   6.6785701E-04
     +,   6.7071570E-04,   6.7329424E-04,   6.7557459E-04
     +,   6.7758333E-04,   6.7940040E-04,   6.8116502E-04
     +,   6.8307435E-04,   6.8537710E-04,   6.8836153E-04
     +,   6.9233659E-04,   6.9761096E-04,   7.0446800E-04
     +,   7.1314326E-04,   7.2379713E-04,   7.3649950E-04
     +,   7.5120910E-04,   7.6776883E-04,   7.8589877E-04
     +,   8.0520735E-04,   8.2520186E-04,   8.4531022E-04
     +,   8.6490822E-04,   8.8335713E-04,   9.0003631E-04
     +,   9.1438048E-04,   9.2591770E-04,   9.3429646E-04
     +,   9.3931123E-04,   9.4091246E-04,   9.3920960E-04
     +,   9.3446008E-04,   9.2704827E-04,   9.1745419E-04
     +,   9.0621621E-04,   8.9388847E-04,   8.8100368E-04
     +,   8.6803443E-04,   8.5536414E-04,   8.4326643E-04
     +,   8.3189819E-04,   8.2129560E-04,   8.1138831E-04
     +,   8.0201362E-04,   7.9294114E-04,   7.8389602E-04
     +,   7.7458535E-04,   7.6471915E-04,   7.5403170E-04
     +,   7.4229587E-04,   7.2933332E-04,   7.1502209E-04
     +,   6.9929811E-04,   6.8215362E-04,   6.6363462E-04
     +,   6.4383651E-04,   6.2289421E-04,   6.0097885E-04
     +,   5.7828496E-04,   5.5502623E-04,   5.3142291E-04
     +,   5.0769805E-04,   4.8406550E-04,   4.6072801E-04
     +,   4.3786797E-04,   4.1564537E-04,   3.9419759E-04
     +,   3.7363687E-04,   3.5404987E-04,   3.3550145E-04
     +,   3.1803816E-04,   3.0169007E-04,   2.8647311E-04
     +,   2.7239305E-04,   2.5944959E-04,   2.4763495E-04
     +,   2.3693692E-04,   2.2733978E-04,   2.1882342E-04
     +,   2.1136239E-04,   2.0492599E-04,   1.9947771E-04
     +,   1.9497401E-04,   1.9136375E-04,   1.8858830E-04
     +,   1.8658176E-04,   1.8527142E-04,   1.8457827E-04
     +,   1.8441853E-04,   1.8470491E-04,   1.8534774E-04
     +,   1.8625712E-04,   1.8734385E-04,   1.8852120E-04
     +,   1.8970638E-04,   1.9082152E-04,   1.9179474E-04
     +,   1.9256103E-04,   1.9306291E-04,   1.9325087E-04
     +,   1.9308347E-04,   1.9252779E-04,   1.9155885E-04
     +,   1.9015992E-04,   1.8832194E-04,   1.8604314E-04
     +,   1.8332862E-04,   1.8018983E-04,   1.7664405E-04
     +,   1.7271345E-04,   1.6842458E-04,   1.6380800E-04
     +,   1.5889746E-04,   1.5372882E-04,   1.4833965E-04
     +,   1.4276899E-04,   1.3705637E-04,   1.3124100E-04
     +,   1.2536137E-04,   1.1945545E-04,   1.1355902E-04
     +,   1.0770597E-04,   1.0192825E-04,   9.6255229E-05
     +,   9.0713089E-05,   8.5325082E-05,   8.0111735E-05
     +,   7.5090451E-05,   7.0275273E-05,   6.5677137E-05
     +,   6.1304381E-05,   5.7162510E-05,   5.3254134E-05
     +,   4.9579405E-05,   4.6136680E-05,   4.2921925E-05
     +,   3.9929415E-05,   3.7152116E-05,   3.4581713E-05
     +,   3.2208714E-05,   3.0022871E-05,   2.8013505E-05
     +,   2.6169557E-05,   2.4479656E-05,   2.2932434E-05
     +,   2.1516771E-05,   2.0221778E-05,   1.9036834E-05
     +,   1.7951796E-05,   1.6957134E-05,   1.6043788E-05
     +,   1.5203316E-05,   1.4427955E-05,   1.3710582E-05
     +,   1.3044646E-05,   1.2424237E-05,   1.1844081E-05
     +,   1.1299492E-05,   1.0786277E-05,   1.0300765E-05
     +,   9.8397886E-06,   9.4006127E-06,   8.9808709E-06
     +,   8.5785514E-06,   8.1920043E-06,   7.8198163E-06
     +,   7.4608311E-06,   7.1141194E-06,   6.7789392E-06
     +,   6.4546803E-06,   6.1408641E-06,   5.8371397E-06
     +,   5.5432424E-06,   5.2589512E-06,   4.9841060E-06
     +,   4.7185972E-06,   4.4623462E-06,   4.2152701E-06
     +,   3.9772999E-06,   3.7483896E-06,   3.5284677E-06
     +,   3.3174563E-06,   3.1152802E-06,   2.9218506E-06
     +,   2.7370518E-06,   2.5607542E-06,   2.3928219E-06
     +,   2.2331058E-06,   2.0814286E-06,   1.9376014E-06
     +,   1.8014299E-06,   1.6727090E-06,   1.5512136E-06
     +,   1.4367091E-06,   1.3289650E-06,   1.2277344E-06
     +,   1.1327642E-06,   1.0438058E-06,   9.6060751E-07
     +,   8.8291051E-07,   8.1045812E-07,   7.4299976E-07
     +,   6.8028675E-07,   6.2207010E-07,   5.6810575E-07
     +,   5.1816011E-07,   4.7199921E-07,   4.2940141E-07
     +,   3.9014682E-07,   3.5402795E-07,   3.2084051E-07
     +,   2.9039279E-07,   2.6249722E-07,   2.3697808E-07
     +,   2.1366533E-07,   1.9239981E-07,   1.7302904E-07
     +,   1.5540864E-07,   1.3940442E-07,   1.2488773E-07
     +,   1.1173986E-07,   9.9847696E-08,   8.9107338E-08
     +,   7.9420111E-08,   7.0695670E-08,   6.2848770E-08
     +,   5.5801522E-08,   4.9480825E-08,   4.3820066E-08
     +,   3.8757094E-08,   3.4235327E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt60 = Yx/0.0197931034482759
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5407091E-05,   3.9476035E-05
     +,   4.3853073E-05,   4.8539296E-05,   5.3532774E-05
     +,   5.8828322E-05,   6.4417574E-05,   7.0288945E-05
     +,   7.6427801E-05,   8.2817161E-05,   8.9437672E-05
     +,   9.6268595E-05,   1.0328861E-04,   1.1047679E-04
     +,   1.1781376E-04,   1.2528304E-04,   1.3287236E-04
     +,   1.4057518E-04,   1.4839214E-04,   1.5633240E-04
     +,   1.6441489E-04,   1.7266933E-04,   1.8113687E-04
     +,   1.8987116E-04,   1.9893632E-04,   2.0840841E-04
     +,   2.1837228E-04,   2.2892034E-04,   2.4014946E-04
     +,   2.5215757E-04,   2.6503942E-04,   2.7888187E-04
     +,   2.9375922E-04,   3.0972771E-04,   3.2682018E-04
     +,   3.4504171E-04,   3.6436514E-04,   3.8472688E-04
     +,   4.0602687E-04,   4.2812325E-04,   4.5083763E-04
     +,   4.7395297E-04,   4.9721869E-04,   5.2035530E-04
     +,   5.4306054E-04,   5.6501676E-04,   5.8589969E-04
     +,   6.0538761E-04,   6.2317087E-04,   6.3896232E-04
     +,   6.5250701E-04,   6.6359196E-04,   6.7205454E-04
     +,   6.7779038E-04,   6.8075949E-04,   6.8099017E-04
     +,   6.7858165E-04,   6.7370251E-04,   6.6658901E-04
     +,   6.5753731E-04,   6.4689515E-04,   6.3505064E-04
     +,   6.2241877E-04,   6.0942594E-04,   5.9649436E-04
     +,   5.8402959E-04,   5.7240366E-04,   5.6194724E-04
     +,   5.5294001E-04,   5.4560817E-04,   5.4012338E-04
     +,   5.3660781E-04,   5.3513970E-04,   5.3576333E-04
     +,   5.3849828E-04,   5.4334913E-04,   5.5031222E-04
     +,   5.5937935E-04,   5.7053816E-04,   5.8376719E-04
     +,   5.9902528E-04,   6.1624101E-04,   6.3529360E-04
     +,   6.5600273E-04,   6.7810842E-04,   7.0126745E-04
     +,   7.2504545E-04,   7.4892613E-04,   7.7232148E-04
     +,   7.9459872E-04,   8.1511115E-04,   8.3323423E-04
     +,   8.4841042E-04,   8.6019095E-04,   8.6827209E-04
     +,   8.7252614E-04,   8.7302079E-04,   8.7002356E-04
     +,   8.6399273E-04,   8.5555349E-04,   8.4545754E-04
     +,   8.3453907E-04,   8.2365790E-04,   8.1364723E-04
     +,   8.0525770E-04,   7.9911726E-04,   7.9569739E-04
     +,   7.9529471E-04,   7.9802237E-04,   8.0382184E-04
     +,   8.1247668E-04,   8.2364364E-04,   8.3687506E-04
     +,   8.5165590E-04,   8.6742541E-04,   8.8360853E-04
     +,   8.9962815E-04,   9.1493066E-04,   9.2899310E-04
     +,   9.4134110E-04,   9.5156010E-04,   9.5930538E-04
     +,   9.6431829E-04,   9.6643117E-04,   9.6557511E-04
     +,   9.6177828E-04,   9.5515739E-04,   9.4590243E-04
     +,   9.3425380E-04,   9.2047709E-04,   9.0483215E-04
     +,   8.8755181E-04,   8.6881581E-04,   8.4874587E-04
     +,   8.2739873E-04,   8.0477598E-04,   7.8084430E-04
     +,   7.5555482E-04,   7.2886900E-04,   7.0078339E-04
     +,   6.7135174E-04,   6.4069801E-04,   6.0901762E-04
     +,   5.7657599E-04,   5.4370094E-04,   5.1075761E-04
     +,   4.7813103E-04,   4.4620488E-04,   4.1533718E-04
     +,   3.8584025E-04,   3.5796815E-04,   3.3190992E-04
     +,   3.0778334E-04,   2.8563567E-04,   2.6545100E-04
     +,   2.4716038E-04,   2.3065149E-04,   2.1577939E-04
     +,   2.0237964E-04,   1.9028033E-04,   1.7930895E-04
     +,   1.6930135E-04,   1.6010797E-04,   1.5159677E-04
     +,   1.4365470E-04,   1.3618902E-04,   1.2912675E-04
     +,   1.2241286E-04,   1.1600753E-04,   1.0988418E-04
     +,   1.0402716E-04,   9.8428827E-05,   9.3086812E-05
     +,   8.8002271E-05,   8.3178616E-05,   7.8619036E-05
     +,   7.4325988E-05,   7.0300550E-05,   6.6541739E-05
     +,   6.3045969E-05,   5.9807233E-05,   5.6817560E-05
     +,   5.4066830E-05,   5.1543033E-05,   4.9232800E-05
     +,   4.7121957E-05,   4.5195644E-05,   4.3438649E-05
     +,   4.1835789E-05,   4.0372361E-05,   3.9034065E-05
     +,   3.7807316E-05,   3.6679419E-05,   3.5638630E-05
     +,   3.4674060E-05,   3.3775821E-05,   3.2935019E-05
     +,   3.2143696E-05,   3.1394680E-05,   3.0681640E-05
     +,   2.9999017E-05,   2.9341925E-05,   2.8706056E-05
     +,   2.8087659E-05,   2.7483520E-05,   2.6890824E-05
     +,   2.6307147E-05,   2.5730465E-05,   2.5159074E-05
     +,   2.4591509E-05,   2.4026591E-05,   2.3463392E-05
     +,   2.2901220E-05,   2.2339535E-05,   2.1777978E-05
     +,   2.1216389E-05,   2.0654754E-05,   2.0093154E-05
     +,   1.9531786E-05,   1.8971008E-05,   1.8411212E-05
     +,   1.7852861E-05,   1.7296519E-05,   1.6742802E-05
     +,   1.6192327E-05,   1.5645737E-05,   1.5103726E-05
     +,   1.4567000E-05,   1.4036228E-05,   1.3512062E-05
     +,   1.2995177E-05,   1.2486226E-05,   1.1985799E-05
     +,   1.1494448E-05,   1.1012742E-05,   1.0541157E-05
     +,   1.0080133E-05,   9.6300882E-06,   9.1914007E-06
     +,   8.7643675E-06,   8.3492450E-06,   7.9462689E-06
     +,   7.5556281E-06,   7.1774402E-06,   6.8117824E-06
     +,   6.4587157E-06,   6.1182582E-06,   5.7903694E-06
     +,   5.4749726E-06,   5.1719926E-06,   4.8812876E-06
     +,   4.6026912E-06,   4.3360305E-06,   4.0811060E-06
     +,   3.8376784E-06,   3.6054951E-06,   3.3842978E-06
     +,   3.1738125E-06,   2.9737421E-06,   2.7837773E-06
     +,   2.6036118E-06,   2.4329354E-06,   2.2714178E-06
     +,   2.1187277E-06,   1.9745476E-06,   1.8385426E-06
     +,   1.7103800E-06,   1.5897397E-06,   1.4763013E-06
     +,   1.3697418E-06,   1.2697444E-06,   1.1760040E-06
     +,   1.0882214E-06,   1.0060990E-06,   9.2934653E-07
     +,   8.5769005E-07,   7.9085373E-07,   7.2857972E-07
     +,   6.7061092E-07,   6.1670653E-07,   5.6662788E-07
     +,   5.2015287E-07,   4.7706186E-07,   4.3715042E-07
     +,   4.0021771E-07,   3.6607744E-07,   3.3454842E-07
     +,   3.0545851E-07,   2.7864715E-07,   2.5395852E-07
     +,   2.3124821E-07,   2.1037695E-07,   1.9121586E-07
     +,   1.7364087E-07,   1.5753758E-07,   1.4279630E-07
     +,   1.2931596E-07,   1.1700011E-07,   1.0575989E-07
     +,   9.5510764E-08,   8.6175298E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt65 = Yx/0.0217
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.4842941E-06,   9.2927021E-06
     +,   1.0157168E-05,   1.1079598E-05,   1.2061842E-05
     +,   1.3105717E-05,   1.4213026E-05,   1.5385576E-05
     +,   1.6625179E-05,   1.7933768E-05,   1.9313324E-05
     +,   2.0765970E-05,   2.2294014E-05,   2.3899991E-05
     +,   2.5586685E-05,   2.7357224E-05,   2.9215056E-05
     +,   3.1164040E-05,   3.3208438E-05,   3.5352950E-05
     +,   3.7602716E-05,   3.9963328E-05,   4.2440744E-05
     +,   4.5041430E-05,   4.7771915E-05,   5.0639246E-05
     +,   5.3650427E-05,   5.6812547E-05,   6.0132523E-05
     +,   6.3617059E-05,   6.7272362E-05,   7.1104034E-05
     +,   7.5116826E-05,   7.9314472E-05,   8.3699517E-05
     +,   8.8273046E-05,   9.3034563E-05,   9.7981734E-05
     +,   1.0311066E-04,   1.0841480E-04,   1.1388615E-04
     +,   1.1951414E-04,   1.2528623E-04,   1.3118767E-04
     +,   1.3720176E-04,   1.4330991E-04,   1.4949187E-04
     +,   1.5572594E-04,   1.6198937E-04,   1.6825869E-04
     +,   1.7451012E-04,   1.8072003E-04,   1.8686533E-04
     +,   1.9292474E-04,   1.9887782E-04,   2.0470748E-04
     +,   2.1039897E-04,   2.1594133E-04,   2.2132749E-04
     +,   2.2655487E-04,   2.3162583E-04,   2.3654765E-04
     +,   2.4133248E-04,   2.4599786E-04,   2.5056579E-04
     +,   2.5506213E-04,   2.5951656E-04,   2.6396045E-04
     +,   2.6842704E-04,   2.7294832E-04,   2.7755531E-04
     +,   2.8227468E-04,   2.8712867E-04,   2.9213226E-04
     +,   2.9729298E-04,   3.0260961E-04,   3.0807147E-04
     +,   3.1365847E-04,   3.1934297E-04,   3.2509043E-04
     +,   3.3086154E-04,   3.3661630E-04,   3.4231582E-04
     +,   3.4792846E-04,   3.5343153E-04,   3.5881752E-04
     +,   3.6409553E-04,   3.6929591E-04,   3.7447005E-04
     +,   3.7969177E-04,   3.8505613E-04,   3.9067460E-04
     +,   3.9667188E-04,   4.0317871E-04,   4.1032463E-04
     +,   4.1822836E-04,   4.2699088E-04,   4.3668441E-04
     +,   4.4734799E-04,   4.5897841E-04,   4.7153002E-04
     +,   4.8491065E-04,   4.9898698E-04,   5.1358645E-04
     +,   5.2850781E-04,   5.4353045E-04,   5.5842480E-04
     +,   5.7296624E-04,   5.8694836E-04,   6.0019188E-04
     +,   6.1255408E-04,   6.2393589E-04,   6.3428184E-04
     +,   6.4358203E-04,   6.5186433E-04,   6.5919029E-04
     +,   6.6564174E-04,   6.7131320E-04,   6.7629956E-04
     +,   6.8068714E-04,   6.8454561E-04,   6.8792299E-04
     +,   6.9084333E-04,   6.9330801E-04,   6.9529796E-04
     +,   6.9677882E-04,   6.9770694E-04,   6.9803611E-04
     +,   6.9772120E-04,   6.9672428E-04,   6.9501542E-04
     +,   6.9257600E-04,   6.8939594E-04,   6.8547379E-04
     +,   6.8081444E-04,   6.7542715E-04,   6.6932512E-04
     +,   6.6252536E-04,   6.5504812E-04,   6.4692064E-04
     +,   6.3817733E-04,   6.2886567E-04,   6.1904418E-04
     +,   6.0878589E-04,   5.9817935E-04,   5.8732386E-04
     +,   5.7632779E-04,   5.6530529E-04,   5.5436802E-04
     +,   5.4361986E-04,   5.3315086E-04,   5.2303291E-04
     +,   5.1331468E-04,   5.0401944E-04,   4.9514481E-04
     +,   4.8666543E-04,   4.7853557E-04,   4.7069322E-04
     +,   4.6306709E-04,   4.5558179E-04,   4.4816377E-04
     +,   4.4074614E-04,   4.3327315E-04,   4.2570321E-04
     +,   4.1800880E-04,   4.1017751E-04,   4.0221139E-04
     +,   3.9412422E-04,   3.8593853E-04,   3.7768297E-04
     +,   3.6939053E-04,   3.6109428E-04,   3.5282536E-04
     +,   3.4461138E-04,   3.3647649E-04,   3.2843792E-04
     +,   3.2050791E-04,   3.1269339E-04,   3.0499639E-04
     +,   2.9741370E-04,   2.8993882E-04,   2.8256228E-04
     +,   2.7527250E-04,   2.6805600E-04,   2.6089812E-04
     +,   2.5378438E-04,   2.4670051E-04,   2.3963230E-04
     +,   2.3256670E-04,   2.2549275E-04,   2.1840088E-04
     +,   2.1128342E-04,   2.0413594E-04,   1.9695669E-04
     +,   1.8974635E-04,   1.8250868E-04,   1.7525078E-04
     +,   1.6798287E-04,   1.6071735E-04,   1.5346905E-04
     +,   1.4625561E-04,   1.3909629E-04,   1.3201121E-04
     +,   1.2502140E-04,   1.1814888E-04,   1.1141490E-04
     +,   1.0484013E-04,   9.8444667E-05,   9.2247210E-05
     +,   8.6264343E-05,   8.0510712E-05,   7.4999196E-05
     +,   6.9740308E-05,   6.4741871E-05,   6.0009297E-05
     +,   5.5546017E-05,   5.1353116E-05,   4.7429268E-05
     +,   4.3771175E-05,   4.0374060E-05,   3.7231202E-05
     +,   3.4334480E-05,   3.1674754E-05,   2.9241897E-05
     +,   2.7024820E-05,   2.5011881E-05,   2.3191191E-05
     +,   2.1550601E-05,   2.0077798E-05,   1.8760547E-05
     +,   1.7586915E-05,   1.6545233E-05,   1.5624159E-05
     +,   1.4812810E-05,   1.4100905E-05,   1.3478636E-05
     +,   1.2936775E-05,   1.2466737E-05,   1.2060535E-05
     +,   1.1710757E-05,   1.1410581E-05,   1.1153791E-05
     +,   1.0934717E-05,   1.0748202E-05,   1.0589600E-05
     +,   1.0454743E-05,   1.0339902E-05,   1.0241751E-05
     +,   1.0157341E-05,   1.0084080E-05,   1.0019679E-05
     +,   9.9621411E-06,   9.9097279E-06,   9.8609371E-06
     +,   9.8144692E-06,   9.7692118E-06,   9.7242219E-06
     +,   9.6786989E-06,   9.6319727E-06,   9.5834830E-06
     +,   9.5327714E-06,   9.4794714E-06,   9.4232837E-06
     +,   9.3639719E-06,   9.3013696E-06,   9.2353466E-06
     +,   9.1658212E-06,   9.0927460E-06,   9.0161102E-06
     +,   8.9359219E-06,   8.8522129E-06,   8.7650396E-06
     +,   8.6744794E-06,   8.5806105E-06,   8.4835319E-06
     +,   8.3833556E-06,   8.2801935E-06,   8.1741764E-06
     +,   8.0654290E-06,   7.9540951E-06,   7.8403054E-06
     +,   7.7242139E-06,   7.6059600E-06,   7.4857003E-06
     +,   7.3635779E-06,   7.2397511E-06,   7.1143709E-06
     +,   6.9875850E-06,   6.8595541E-06,   6.7304209E-06
     +,   6.6003458E-06,   6.4694700E-06,   6.3379498E-06
     +,   6.2059230E-06,   6.0735429E-06,   5.9409399E-06
     +,   5.8082637E-06,   5.6756412E-06,   5.5432129E-06
     +,   5.4111015E-06,   5.2794394E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt70 = Yx/0.01625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3312808E-05,   2.4425497E-05
     +,   2.5626594E-05,   2.6922931E-05,   2.8321700E-05
     +,   2.9830420E-05,   3.1456930E-05,   3.3209366E-05
     +,   3.5096062E-05,   3.7125661E-05,   3.9306855E-05
     +,   4.1648476E-05,   4.4159377E-05,   4.6848385E-05
     +,   4.9724251E-05,   5.2795556E-05,   5.6070643E-05
     +,   5.9557595E-05,   6.3264131E-05,   6.7197550E-05
     +,   7.1364753E-05,   7.5772048E-05,   8.0425154E-05
     +,   8.5329426E-05,   9.0489004E-05,   9.5907788E-05
     +,   1.0158847E-04,   1.0753291E-04,   1.1374168E-04
     +,   1.2021424E-04,   1.2694833E-04,   1.3394015E-04
     +,   1.4118373E-04,   1.4867085E-04,   1.5639060E-04
     +,   1.6432910E-04,   1.7246912E-04,   1.8078955E-04
     +,   1.8926580E-04,   1.9786807E-04,   2.0656284E-04
     +,   2.1531164E-04,   2.2407121E-04,   2.3279389E-04
     +,   2.4142771E-04,   2.4991707E-04,   2.5820298E-04
     +,   2.6622450E-04,   2.7391917E-04,   2.8122510E-04
     +,   2.8808156E-04,   2.9443105E-04,   3.0022083E-04
     +,   3.0540515E-04,   3.0994584E-04,   3.1381528E-04
     +,   3.1699685E-04,   3.1948683E-04,   3.2129491E-04
     +,   3.2244477E-04,   3.2297449E-04,   3.2293543E-04
     +,   3.2239215E-04,   3.2142003E-04,   3.2010372E-04
     +,   3.1853450E-04,   3.1680753E-04,   3.1501861E-04
     +,   3.1326056E-04,   3.1162027E-04,   3.1017515E-04
     +,   3.0899013E-04,   3.0811541E-04,   3.0758430E-04
     +,   3.0741241E-04,   3.0759699E-04,   3.0811786E-04
     +,   3.0893902E-04,   3.1001112E-04,   3.1127554E-04
     +,   3.1266813E-04,   3.1412495E-04,   3.1558765E-04
     +,   3.1700925E-04,   3.1836008E-04,   3.1963299E-04
     +,   3.2084881E-04,   3.2205967E-04,   3.2335139E-04
     +,   3.2484482E-04,   3.2669498E-04,   3.2908758E-04
     +,   3.3223425E-04,   3.3636560E-04,   3.4172193E-04
     +,   3.4854189E-04,   3.5705068E-04,   3.6744625E-04
     +,   3.7988723E-04,   3.9447748E-04,   4.1125753E-04
     +,   4.3019126E-04,   4.5116368E-04,   4.7397174E-04
     +,   4.9833121E-04,   5.2387838E-04,   5.5017899E-04
     +,   5.7674287E-04,   6.0304324E-04,   6.2853558E-04
     +,   6.5267680E-04,   6.7495374E-04,   6.9489778E-04
     +,   7.1211223E-04,   7.2628079E-04,   7.3718571E-04
     +,   7.4471027E-04,   7.4884231E-04,   7.4966962E-04
     +,   7.4737030E-04,   7.4220070E-04,   7.3447899E-04
     +,   7.2456856E-04,   7.1285805E-04,   6.9974631E-04
     +,   6.8562885E-04,   6.7088369E-04,   6.5586611E-04
     +,   6.4090337E-04,   6.2629534E-04,   6.1231403E-04
     +,   5.9921067E-04,   5.8721629E-04,   5.7654857E-04
     +,   5.6741061E-04,   5.5999163E-04,   5.5446324E-04
     +,   5.5097201E-04,   5.4962980E-04,   5.5050256E-04
     +,   5.5360014E-04,   5.5886357E-04,   5.6615833E-04
     +,   5.7526818E-04,   5.8589521E-04,   5.9766485E-04
     +,   6.1013625E-04,   6.2281452E-04,   6.3517195E-04
     +,   6.4666785E-04,   6.5677200E-04,   6.6498469E-04
     +,   6.7085883E-04,   6.7401730E-04,   6.7416515E-04
     +,   6.7109882E-04,   6.6470960E-04,   6.5498333E-04
     +,   6.4199412E-04,   6.2589918E-04,   6.0692389E-04
     +,   5.8535056E-04,   5.6150736E-04,   5.3575338E-04
     +,   5.0846388E-04,   4.8002024E-04,   4.5080163E-04
     +,   4.2117498E-04,   3.9148485E-04,   3.6205072E-04
     +,   3.3316368E-04,   3.0508239E-04,   2.7802875E-04
     +,   2.5218909E-04,   2.2771663E-04,   2.0472714E-04
     +,   1.8330246E-04,   1.6349414E-04,   1.4532381E-04
     +,   1.2878470E-04,   1.1384619E-04,   1.0045780E-04
     +,   8.8551213E-05,   7.8043093E-05,   6.8839399E-05
     +,   6.0839131E-05,   5.3936459E-05,   4.8023299E-05
     +,   4.2992360E-05,   3.8739621E-05,   3.5165107E-05
     +,   3.2174910E-05,   2.9682298E-05,   2.7608148E-05
     +,   2.5881211E-05,   2.4438405E-05,   2.3224715E-05
     +,   2.2192718E-05,   2.1302099E-05,   2.0519128E-05
     +,   1.9816076E-05,   1.9170478E-05,   1.8564446E-05
     +,   1.7984066E-05,   1.7418854E-05,   1.6861086E-05
     +,   1.6305356E-05,   1.5748181E-05,   1.5187576E-05
     +,   1.4622701E-05,   1.4053614E-05,   1.3481088E-05
     +,   1.2906382E-05,   1.2331055E-05,   1.1756880E-05
     +,   1.1185777E-05,   1.0619709E-05,   1.0060585E-05
     +,   9.5102369E-06,   8.9704572E-06,   8.4428548E-06
     +,   7.9288920E-06,   7.4299096E-06,   6.9470825E-06
     +,   6.4813821E-06,   6.0336120E-06,   5.6044441E-06
     +,   5.1943825E-06,   4.8037482E-06,   4.4327212E-06
     +,   4.0813625E-06,   3.7496097E-06,   3.4372542E-06
     +,   3.1439870E-06,   2.8694308E-06,   2.6130965E-06
     +,   2.3744255E-06,   2.1528135E-06,   1.9476017E-06
     +,   1.7580804E-06,   1.5835087E-06,   1.4231375E-06
     +,   1.2762021E-06,   1.1419228E-06,   1.0195231E-06
     +,   9.0824335E-07,   8.0733463E-07,   7.1606024E-07
     +,   6.3370720E-07,   5.5959543E-07,   4.9306527E-07
     +,   4.3348825E-07,   3.8027255E-07,   3.3285824E-07
     +,   2.9071546E-07,   2.5334936E-07,   2.2030085E-07
     +,   1.9114330E-07,   1.6548046E-07,   1.4294764E-07
     +,   1.2321171E-07,   1.0596780E-07,   9.0936915E-08
     +,   7.7866254E-08,   6.6528109E-08,   5.6715994E-08
     +,   4.8244576E-08,   4.0948311E-08,   3.4679328E-08
     +,   2.9305564E-08,   2.4709939E-08,   2.0789210E-08
     +,   1.7452246E-08,   1.4618725E-08,   1.2218270E-08
     +,   1.0189595E-08,   8.4790379E-09,   7.0401733E-09
     +,   5.8325997E-09,   4.8215716E-09,   3.9770094E-09
     +,   3.2731995E-09,   2.6880043E-09,   2.2025954E-09
     +,   1.8008669E-09,   1.4691827E-09,   1.1959566E-09
     +,   9.7139474E-10,   7.8727108E-10,   6.3664141E-10
     +,   5.1370336E-10,   4.1359149E-10,   3.3226069E-10
     +,   2.6633457E-10,   2.1302213E-10,   1.7000538E-10
     +,   1.3537824E-10,   1.0756630E-10,   8.5280838E-11
     +,   6.7463403E-11,   5.3251674E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt75 = Yx/0.016
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0536287E-05,   2.0801412E-05
     +,   2.1077642E-05,   2.1366013E-05,   2.1667638E-05
     +,   2.1983653E-05,   2.2315266E-05,   2.2663744E-05
     +,   2.3030418E-05,   2.3416720E-05,   2.3824165E-05
     +,   2.4254390E-05,   2.4709154E-05,   2.5190386E-05
     +,   2.5700208E-05,   2.6240947E-05,   2.6815198E-05
     +,   2.7425855E-05,   2.8076151E-05,   2.8769728E-05
     +,   2.9510677E-05,   3.0303587E-05,   3.1153628E-05
     +,   3.2066640E-05,   3.3049080E-05,   3.4108260E-05
     +,   3.5252251E-05,   3.6490012E-05,   3.7831422E-05
     +,   3.9287323E-05,   4.0869487E-05,   4.2590662E-05
     +,   4.4464548E-05,   4.6505709E-05,   4.8729482E-05
     +,   5.1151885E-05,   5.3789452E-05,   5.6658926E-05
     +,   5.9777332E-05,   6.3161053E-05,   6.6826222E-05
     +,   7.0787828E-05,   7.5059463E-05,   7.9652789E-05
     +,   8.4577165E-05,   8.9839043E-05,   9.5441501E-05
     +,   1.0138367E-04,   1.0766036E-04,   1.1426155E-04
     +,   1.2117205E-04,   1.2837119E-04,   1.3583250E-04
     +,   1.4352423E-04,   1.5140817E-04,   1.5944129E-04
     +,   1.6757510E-04,   1.7575642E-04,   1.8392822E-04
     +,   1.9203030E-04,   2.0000026E-04,   2.0777489E-04
     +,   2.1529052E-04,   2.2248576E-04,   2.2930210E-04
     +,   2.3568459E-04,   2.4158497E-04,   2.4696119E-04
     +,   2.5178035E-04,   2.5601822E-04,   2.5966170E-04
     +,   2.6270837E-04,   2.6516771E-04,   2.6706117E-04
     +,   2.6842183E-04,   2.6929475E-04,   2.6973549E-04
     +,   2.6980977E-04,   2.6959216E-04,   2.6916416E-04
     +,   2.6861334E-04,   2.6803045E-04,   2.6750818E-04
     +,   2.6713853E-04,   2.6701094E-04,   2.6720978E-04
     +,   2.6781263E-04,   2.6888808E-04,   2.7049388E-04
     +,   2.7267548E-04,   2.7546508E-04,   2.7888000E-04
     +,   2.8292221E-04,   2.8757867E-04,   2.9282100E-04
     +,   2.9860559E-04,   3.0487558E-04,   3.1156093E-04
     +,   3.1858153E-04,   3.2584782E-04,   3.3326456E-04
     +,   3.4073187E-04,   3.4815015E-04,   3.5542113E-04
     +,   3.6245235E-04,   3.6915948E-04,   3.7546980E-04
     +,   3.8132447E-04,   3.8668164E-04,   3.9151887E-04
     +,   3.9583372E-04,   3.9964644E-04,   4.0299943E-04
     +,   4.0595917E-04,   4.0861388E-04,   4.1107446E-04
     +,   4.1347175E-04,   4.1595535E-04,   4.1869038E-04
     +,   4.2185522E-04,   4.2563735E-04,   4.3022839E-04
     +,   4.3582052E-04,   4.4260031E-04,   4.5074272E-04
     +,   4.6040342E-04,   4.7171363E-04,   4.8477025E-04
     +,   4.9963052E-04,   5.1630265E-04,   5.3474243E-04
     +,   5.5484445E-04,   5.7644374E-04,   5.9930974E-04
     +,   6.2315405E-04,   6.4763339E-04,   6.7235745E-04
     +,   6.9690344E-04,   7.2083221E-04,   7.4370485E-04
     +,   7.6509971E-04,   7.8463380E-04,   8.0198207E-04
     +,   8.1689010E-04,   8.2918588E-04,   8.3878817E-04
     +,   8.4570621E-04,   8.5003598E-04,   8.5194915E-04
     +,   8.5167872E-04,   8.4950036E-04,   8.4571063E-04
     +,   8.4060687E-04,   8.3446561E-04,   8.2752621E-04
     +,   8.1997778E-04,   8.1195147E-04,   8.0351759E-04
     +,   7.9468801E-04,   7.8542711E-04,   7.7565928E-04
     +,   7.6528516E-04,   7.5419754E-04,   7.4229413E-04
     +,   7.2949013E-04,   7.1572908E-04,   7.0098834E-04
     +,   6.8528415E-04,   6.6866621E-04,   6.5121771E-04
     +,   6.3304760E-04,   6.1428419E-04,   5.9506373E-04
     +,   5.7552429E-04,   5.5580004E-04,   5.3601188E-04
     +,   5.1626423E-04,   4.9664569E-04,   4.7722581E-04
     +,   4.5805523E-04,   4.3916961E-04,   4.2059334E-04
     +,   4.0234195E-04,   3.8442406E-04,   3.6684619E-04
     +,   3.4961622E-04,   3.3274389E-04,   3.1624132E-04
     +,   3.0012379E-04,   2.8441192E-04,   2.6912661E-04
     +,   2.5429029E-04,   2.3992590E-04,   2.2605478E-04
     +,   2.1269417E-04,   1.9985755E-04,   1.8755412E-04
     +,   1.7578801E-04,   1.6455735E-04,   1.5385538E-04
     +,   1.4367170E-04,   1.3399239E-04,   1.2480008E-04
     +,   1.1607583E-04,   1.0780071E-04,   9.9954887E-05
     +,   9.2519222E-05,   8.5476262E-05,   7.8809928E-05
     +,   7.2505376E-05,   6.6549452E-05,   6.0930979E-05
     +,   5.5640026E-05,   5.0667393E-05,   4.6004607E-05
     +,   4.1643965E-05,   3.7577836E-05,   3.3798126E-05
     +,   3.0296429E-05,   2.7064112E-05,   2.4091571E-05
     +,   2.1368500E-05,   1.8884122E-05,   1.6626951E-05
     +,   1.4584798E-05,   1.2745048E-05,   1.1094894E-05
     +,   9.6213325E-06,   8.3112272E-06,   7.1515738E-06
     +,   6.1296996E-06,   5.2332730E-06,   4.4503718E-06
     +,   3.7696493E-06,   3.1804432E-06,   2.6726993E-06
     +,   2.2370864E-06,   1.8650255E-06,   1.5486611E-06
     +,   1.2808323E-06,   1.0550845E-06,   8.6564847E-07
     +,   7.0738514E-07,   5.7573817E-07,   4.6670664E-07
     +,   3.7680161E-07,   3.0299290E-07,   2.4265955E-07
     +,   1.9355392E-07,   1.5376226E-07,   1.2165646E-07
     +,   9.5863122E-08,   7.5231561E-08,   5.8800449E-08
     +,   4.5770676E-08,   3.5482401E-08,   2.7394201E-08
     +,   2.1063189E-08,   1.6128846E-08,   1.2299532E-08
     +,   9.3407273E-09,   7.0644779E-09,   5.3208353E-09
     +,   3.9909134E-09,   2.9810017E-09,   2.2173936E-09
     +,   1.6425002E-09,   1.2115796E-09,   8.8998581E-10
     +,   6.5101502E-10,   4.7420767E-10,   3.4396663E-10
     +,   2.4844843E-10,   1.7869822E-10,   1.2798552E-10
     +,   9.1277721E-11,   6.4821509E-11,   4.5838461E-11
     +,   3.2276484E-11,   2.2630488E-11,   1.5799433E-11
     +,   1.0983361E-11,   7.6026321E-12,   5.2400471E-12
     +,   3.5961364E-12,   2.4574052E-12,   1.6720485E-12
     +,   1.1327873E-12,   7.6415989E-13,   5.1327009E-13
     +,   3.4327787E-13,   2.2859999E-13,   1.5158332E-13
     +,   1.0008456E-13,   6.5802784E-14,   4.3080909E-14
     +,   2.8087917E-14,   1.8237378E-14,   1.1794072E-14
     +,   7.5973485E-15,   4.8757169E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt80 = Yx/0.0165
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0717778E-05,   2.1285901E-05
     +,   2.1872025E-05,   2.2476139E-05,   2.3098224E-05
     +,   2.3738257E-05,   2.4396208E-05,   2.5072035E-05
     +,   2.5765714E-05,   2.6477239E-05,   2.7206608E-05
     +,   2.7953831E-05,   2.8718936E-05,   2.9502005E-05
     +,   3.0303117E-05,   3.1122388E-05,   3.1959982E-05
     +,   3.2816068E-05,   3.3690871E-05,   3.4584624E-05
     +,   3.5497585E-05,   3.6430036E-05,   3.7382266E-05
     +,   3.8354610E-05,   3.9347306E-05,   4.0360686E-05
     +,   4.1394993E-05,   4.2450451E-05,   4.3527245E-05
     +,   4.4625485E-05,   4.5745204E-05,   4.6886384E-05
     +,   4.8048856E-05,   4.9232392E-05,   5.0436618E-05
     +,   5.1661038E-05,   5.2905034E-05,   5.4167827E-05
     +,   5.5448600E-05,   5.6746238E-05,   5.8059679E-05
     +,   5.9387676E-05,   6.0728893E-05,   6.2081970E-05
     +,   6.3445470E-05,   6.4817970E-05,   6.6198088E-05
     +,   6.7584522E-05,   6.8976107E-05,   7.0371789E-05
     +,   7.1770788E-05,   7.3172567E-05,   7.4576914E-05
     +,   7.5984033E-05,   7.7394419E-05,   7.8809164E-05
     +,   8.0229751E-05,   8.1658225E-05,   8.3097148E-05
     +,   8.4549582E-05,   8.6019216E-05,   8.7510176E-05
     +,   8.9027053E-05,   9.0574969E-05,   9.2159455E-05
     +,   9.3786191E-05,   9.5461291E-05,   9.7190808E-05
     +,   9.8981080E-05,   1.0083815E-04,   1.0276808E-04
     +,   1.0477645E-04,   1.0686865E-04,   1.0904930E-04
     +,   1.1132268E-04,   1.1369232E-04,   1.1616085E-04
     +,   1.1873016E-04,   1.2140133E-04,   1.2417466E-04
     +,   1.2704935E-04,   1.3002405E-04,   1.3309639E-04
     +,   1.3626361E-04,   1.3952203E-04,   1.4286779E-04
     +,   1.4629638E-04,   1.4980337E-04,   1.5338373E-04
     +,   1.5703295E-04,   1.6074642E-04,   1.6451959E-04
     +,   1.6834808E-04,   1.7222804E-04,   1.7615591E-04
     +,   1.8012777E-04,   1.8414036E-04,   1.8818986E-04
     +,   1.9227252E-04,   1.9638370E-04,   2.0051822E-04
     +,   2.0466944E-04,   2.0882966E-04,   2.1298896E-04
     +,   2.1713573E-04,   2.2125606E-04,   2.2533334E-04
     +,   2.2934843E-04,   2.3328002E-04,   2.3710451E-04
     +,   2.4079601E-04,   2.4432785E-04,   2.4767223E-04
     +,   2.5080217E-04,   2.5369169E-04,   2.5631790E-04
     +,   2.5866143E-04,   2.6070885E-04,   2.6245325E-04
     +,   2.6389575E-04,   2.6504690E-04,   2.6592688E-04
     +,   2.6656658E-04,   2.6700701E-04,   2.6729942E-04
     +,   2.6750407E-04,   2.6768862E-04,   2.6792692E-04
     +,   2.6829666E-04,   2.6887751E-04,   2.6974943E-04
     +,   2.7099112E-04,   2.7267967E-04,   2.7489031E-04
     +,   2.7769839E-04,   2.8118139E-04,   2.8542217E-04
     +,   2.9051316E-04,   2.9656143E-04,   3.0369320E-04
     +,   3.1205703E-04,   3.2182696E-04,   3.3320356E-04
     +,   3.4641277E-04,   3.6169900E-04,   3.7932105E-04
     +,   3.9954035E-04,   4.2260642E-04,   4.4874239E-04
     +,   4.7812995E-04,   5.1088992E-04,   5.4706191E-04
     +,   5.8658962E-04,   6.2930735E-04,   6.7492609E-04
     +,   7.2302303E-04,   7.7304017E-04,   8.2429167E-04
     +,   8.7597308E-04,   9.2717382E-04,   9.7691850E-04
     +,   1.0241969E-03,   1.0680046E-03,   1.1073997E-03
     +,   1.1415518E-03,   1.1697907E-03,   1.1916474E-03
     +,   1.2068856E-03,   1.2155187E-03,   1.2178048E-03
     +,   1.2142250E-03,   1.2054436E-03,   1.1922541E-03
     +,   1.1755095E-03,   1.1560615E-03,   1.1346879E-03
     +,   1.1120402E-03,   1.0886037E-03,   1.0646767E-03
     +,   1.0403643E-03,   1.0155998E-03,   9.9017902E-04
     +,   9.6380332E-04,   9.3612907E-04,   9.0682023E-04
     +,   8.7559491E-04,   8.4225944E-04,   8.0673315E-04
     +,   7.6905725E-04,   7.2940183E-04,   6.8804336E-04
     +,   6.4535014E-04,   6.0175924E-04,   5.5774715E-04
     +,   5.1380019E-04,   4.7039357E-04,   4.2797421E-04
     +,   3.8694325E-04,   3.4764284E-04,   3.1035382E-04
     +,   2.7529604E-04,   2.4262705E-04,   2.1244341E-04
     +,   1.8478860E-04,   1.5966110E-04,   1.3701519E-04
     +,   1.1677067E-04,   9.8820325E-05,   8.3034072E-05
     +,   6.9264119E-05,   5.7351688E-05,   4.7132355E-05
     +,   3.8439455E-05,   3.1107571E-05,   2.4976531E-05
     +,   1.9894282E-05,   1.5718446E-05,   1.2317593E-05
     +,   9.5725354E-06,   7.3769161E-06,   5.6366616E-06
     +,   4.2699307E-06,   3.2065141E-06,   2.3868333E-06
     +,   1.7609343E-06,   1.2875175E-06,   9.3286388E-07
     +,   6.6974133E-07,   4.7640887E-07,   3.3573576E-07
     +,   2.3438685E-07,   1.6209181E-07,   1.1103182E-07
     +,   7.5328430E-08,   5.0615192E-08,   3.3680912E-08
     +,   2.2194172E-08,   1.4482094E-08,   9.3572385E-09
     +,   5.9863901E-09,   3.7919339E-09,   2.3780866E-09
     +,   1.4765950E-09,   9.0770785E-10,   5.5242005E-10
     +,   3.3284239E-10,   1.9854894E-10,   1.1726431E-10
     +,   6.8574167E-11,   3.9712393E-11,   2.2780108E-11
     +,   1.2948246E-11,   7.2975688E-12,   4.0824956E-12
     +,   2.2708959E-12,   1.2595218E-12,   6.9970055E-13
     +,   3.9205184E-13,   2.2382419E-13,   1.3196613E-13
     +,   8.1596649E-14,   5.3613506E-14,   3.7661440E-14
     +,   2.8179443E-14,   2.2206009E-14,   1.8172208E-14
     +,   1.5248816E-14,   1.2996357E-14,   1.1178340E-14
     +,   9.6640716E-15,   8.3775099E-15,   7.2717406E-15
     +,   6.3151376E-15,   5.4847874E-15,   4.7627227E-15
     +,   4.1344114E-15,   3.5876047E-15,   3.1118341E-15
     +,   2.6979338E-15,   2.3380185E-15,   2.0251899E-15
     +,   1.7534204E-15,   1.5174075E-15,   1.3125472E-15
     +,   1.1348167E-15,   9.8070724E-16,   8.4712369E-16
     +,   7.3139527E-16,   6.3118915E-16,   5.4445340E-16
     +,   4.6941708E-16,   4.0453544E-16,   3.4846208E-16
     +,   3.0001859E-16,   2.5818909E-16,   2.2208862E-16
     +,   1.9094873E-16,   1.6409712E-16,   1.4095610E-16
     +,   1.2102187E-16,   1.0385940E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt85 = Yx/0.016
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.3952662E-06,   6.6715788E-06
     +,   6.9517964E-06,   7.2354642E-06,   7.5221005E-06
     +,   7.8112071E-06,   8.1022690E-06,   8.3947552E-06
     +,   8.6881191E-06,   8.9818213E-06,   9.2753035E-06
     +,   9.5680107E-06,   9.8593937E-06,   1.0148911E-05
     +,   1.0436034E-05,   1.0720249E-05,   1.1001065E-05
     +,   1.1278018E-05,   1.1550671E-05,   1.1818625E-05
     +,   1.2081521E-05,   1.2339040E-05,   1.2590907E-05
     +,   1.2836922E-05,   1.3076904E-05,   1.3310761E-05
     +,   1.3538448E-05,   1.3759992E-05,   1.3975481E-05
     +,   1.4185085E-05,   1.4389036E-05,   1.4587647E-05
     +,   1.4781311E-05,   1.4970487E-05,   1.5155731E-05
     +,   1.5337673E-05,   1.5517024E-05,   1.5694584E-05
     +,   1.5871252E-05,   1.6047992E-05,   1.6225891E-05
     +,   1.6406102E-05,   1.6589902E-05,   1.6778653E-05
     +,   1.6973834E-05,   1.7177037E-05,   1.7389964E-05
     +,   1.7614448E-05,   1.7852450E-05,   1.8106068E-05
     +,   1.8377543E-05,   1.8669265E-05,   1.8983779E-05
     +,   1.9323810E-05,   1.9692208E-05,   2.0092037E-05
     +,   2.0526502E-05,   2.0998985E-05,   2.1513028E-05
     +,   2.2072325E-05,   2.2680719E-05,   2.3342176E-05
     +,   2.4060724E-05,   2.4840519E-05,   2.5685753E-05
     +,   2.6600526E-05,   2.7589007E-05,   2.8655120E-05
     +,   2.9802748E-05,   3.1035390E-05,   3.2356365E-05
     +,   3.3768429E-05,   3.5274028E-05,   3.6874826E-05
     +,   3.8571954E-05,   4.0365805E-05,   4.2255771E-05
     +,   4.4240300E-05,   4.6316931E-05,   4.8482092E-05
     +,   5.0730840E-05,   5.3057287E-05,   5.5454006E-05
     +,   5.7912588E-05,   6.0423052E-05,   6.2974505E-05
     +,   6.5554559E-05,   6.8150024E-05,   7.0746457E-05
     +,   7.3328760E-05,   7.5881224E-05,   7.8387522E-05
     +,   8.0831072E-05,   8.3195526E-05,   8.5464875E-05
     +,   8.7623528E-05,   8.9657202E-05,   9.1552662E-05
     +,   9.3298710E-05,   9.4885960E-05,   9.6307813E-05
     +,   9.7560282E-05,   9.8642857E-05,   9.9558478E-05
     +,   1.0031415E-04,   1.0092109E-04,   1.0139504E-04
     +,   1.0175640E-04,   1.0203052E-04,   1.0224764E-04
     +,   1.0244284E-04,   1.0265601E-04,   1.0293148E-04
     +,   1.0331767E-04,   1.0386644E-04,   1.0463248E-04
     +,   1.0567213E-04,   1.0704255E-04,   1.0879998E-04
     +,   1.1099856E-04,   1.1368825E-04,   1.1691287E-04
     +,   1.2070787E-04,   1.2509838E-04,   1.3009667E-04
     +,   1.3569936E-04,   1.4188641E-04,   1.4861795E-04
     +,   1.5583458E-04,   1.6345525E-04,   1.7137981E-04
     +,   1.7948885E-04,   1.8764933E-04,   1.9571780E-04
     +,   2.0354951E-04,   2.1100735E-04,   2.1797279E-04
     +,   2.2436146E-04,   2.3014094E-04,   2.3535073E-04
     +,   2.4012639E-04,   2.4472713E-04,   2.4956386E-04
     +,   2.5522569E-04,   2.6249798E-04,   2.7236744E-04
     +,   2.8600244E-04,   3.0470107E-04,   3.2980385E-04
     +,   3.6257258E-04,   4.0404047E-04,   4.5485143E-04
     +,   5.1512488E-04,   5.8438414E-04,   6.6157919E-04
     +,   7.4525381E-04,   8.3389826E-04,   9.2648162E-04
     +,   1.0230851E-03,   1.1255027E-03,   1.2376212E-03
     +,   1.3652553E-03,   1.5152510E-03,   1.6938567E-03
     +,   1.9045888E-03,   2.1460864E-03,   2.4105988E-03
     +,   2.6837138E-03,   2.9455984E-03,   3.1736710E-03
     +,   3.3464192E-03,   3.4477937E-03,   3.4711533E-03
     +,   3.4215879E-03,   3.3155568E-03,   3.1773606E-03
     +,   3.0332024E-03,   2.9047129E-03,   2.8040470E-03
     +,   2.7321631E-03,   2.6804993E-03,   2.6350343E-03
     +,   2.5810520E-03,   2.5070999E-03,   2.4071687E-03
     +,   2.2809603E-03,   2.1326800E-03,   1.9691272E-03
     +,   1.7978760E-03,   1.6259524E-03,   1.4590740E-03
     +,   1.3014184E-03,   1.1556771E-03,   1.0232292E-03
     +,   9.0439169E-04,   7.9871813E-04,   7.0529396E-04
     +,   6.2298018E-04,   5.5059441E-04,   4.8702263E-04
     +,   4.3126196E-04,   3.8241746E-04,   3.3968478E-04
     +,   3.0234404E-04,   2.6975718E-04,   2.4135914E-04
     +,   2.1665625E-04,   1.9521797E-04,   1.7665951E-04
     +,   1.6062602E-04,   1.4678203E-04,   1.3480616E-04
     +,   1.2439000E-04,   1.1524273E-04,   1.0709951E-04
     +,   9.9729172E-05,   9.2938993E-05,   8.6576969E-05
     +,   8.0531383E-05,   7.4728079E-05,   6.9123613E-05
     +,   6.3699714E-05,   5.8456659E-05,   5.3406777E-05
     +,   4.8568581E-05,   4.3962715E-05,   3.9609011E-05
     +,   3.5523812E-05,   3.1718475E-05,   2.8199056E-05
     +,   2.4966590E-05,   2.2017157E-05,   1.9342415E-05
     +,   1.6930620E-05,   1.4767663E-05,   1.2837393E-05
     +,   1.1122619E-05,   9.6058193E-06,   8.2695033E-06
     +,   7.0965466E-06,   6.0705893E-06,   5.1762963E-06
     +,   4.3993718E-06,   3.7265945E-06,   3.1458897E-06
     +,   2.6463329E-06,   2.2180486E-06,   1.8521331E-06
     +,   1.5406202E-06,   1.2764274E-06,   1.0532285E-06
     +,   8.6541490E-07,   7.0804123E-07,   5.7674765E-07
     +,   4.6769512E-07,   3.7752821E-07,   3.0332970E-07
     +,   2.4256690E-07,   1.9304922E-07,   1.5289611E-07
     +,   1.2050289E-07,   9.4504969E-08,   7.3747508E-08
     +,   5.7260703E-08,   4.4236018E-08,   3.4000912E-08
     +,   2.6000782E-08,   1.9781453E-08,   1.4972787E-08
     +,   1.1274810E-08,   8.4463441E-09,   6.2947758E-09
     +,   4.6670756E-09,   3.4423395E-09,   2.5258109E-09
     +,   1.8437059E-09,   1.3388010E-09,   9.6712227E-10
     +,   6.9498657E-10,   4.9683258E-10,   3.5332312E-10
     +,   2.4996002E-10,   1.7591209E-10,   1.2315628E-10
     +,   8.5771543E-11,   5.9424410E-11,   4.0955943E-11
     +,   2.8079724E-11,   1.9151545E-11,   1.2993872E-11
     +,   8.7701825E-12,   5.8884560E-12,   3.9330535E-12
     +,   2.6132495E-12,   1.7272965E-12,   1.1357321E-12
     +,   7.4288140E-13,   4.8337793E-13,   3.1288782E-13
     +,   2.0147141E-13,   1.2905435E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt90 = Yx/0.0250645161290323
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.8729306E-06,   6.1380383E-06
     +,   6.4083447E-06,   6.6835687E-06,   6.9634166E-06
     +,   7.2475859E-06,   7.5357721E-06,   7.8276653E-06
     +,   8.1229582E-06,   8.4213634E-06,   8.7225899E-06
     +,   9.0263729E-06,   9.3324670E-06,   9.6406602E-06
     +,   9.9507697E-06,   1.0262658E-05,   1.0576234E-05
     +,   1.0891459E-05,   1.1208360E-05,   1.1527022E-05
     +,   1.1847612E-05,   1.2170372E-05,   1.2495628E-05
     +,   1.2823811E-05,   1.3155414E-05,   1.3491075E-05
     +,   1.3831503E-05,   1.4177529E-05,   1.4530085E-05
     +,   1.4890218E-05,   1.5259084E-05,   1.5637946E-05
     +,   1.6028172E-05,   1.6431230E-05,   1.6848684E-05
     +,   1.7282180E-05,   1.7733446E-05,   1.8204257E-05
     +,   1.8696484E-05,   1.9211971E-05,   1.9752633E-05
     +,   2.0320354E-05,   2.0917010E-05,   2.1544422E-05
     +,   2.2204345E-05,   2.2898439E-05,   2.3628239E-05
     +,   2.4395138E-05,   2.5200330E-05,   2.6044818E-05
     +,   2.6929365E-05,   2.7854452E-05,   2.8820272E-05
     +,   2.9826742E-05,   3.0873329E-05,   3.1959251E-05
     +,   3.3083255E-05,   3.4243716E-05,   3.5438588E-05
     +,   3.6665399E-05,   3.7921232E-05,   3.9202780E-05
     +,   4.0506216E-05,   4.1827407E-05,   4.3161825E-05
     +,   4.4504432E-05,   4.5850022E-05,   4.7192894E-05
     +,   4.8527254E-05,   4.9846894E-05,   5.1145609E-05
     +,   5.2416879E-05,   5.3654265E-05,   5.4851182E-05
     +,   5.6001187E-05,   5.7097935E-05,   5.8135207E-05
     +,   5.9106980E-05,   6.0007638E-05,   6.0831866E-05
     +,   6.1574712E-05,   6.2231768E-05,   6.2799059E-05
     +,   6.3273212E-05,   6.3651423E-05,   6.3931511E-05
     +,   6.4111911E-05,   6.4191765E-05,   6.4170817E-05
     +,   6.4049527E-05,   6.3828971E-05,   6.3510903E-05
     +,   6.3097737E-05,   6.2592408E-05,   6.1998493E-05
     +,   6.1320148E-05,   6.0561957E-05,   5.9729125E-05
     +,   5.8827198E-05,   5.7862297E-05,   5.6840854E-05
     +,   5.5769844E-05,   5.4656550E-05,   5.3508844E-05
     +,   5.2334966E-05,   5.1143692E-05,   4.9944454E-05
     +,   4.8747377E-05,   4.7563251E-05,   4.6403773E-05
     +,   4.5281722E-05,   4.4210869E-05,   4.3206346E-05
     +,   4.2284508E-05,   4.1463260E-05,   4.0761886E-05
     +,   4.0201303E-05,   3.9803796E-05,   3.9593113E-05
     +,   3.9594175E-05,   3.9832907E-05,   4.0335879E-05
     +,   4.1129912E-05,   4.2241660E-05,   4.3697088E-05
     +,   4.5520763E-05,   4.7735590E-05,   5.0361759E-05
     +,   5.3416781E-05,   5.6914272E-05,   6.0864266E-05
     +,   6.5271910E-05,   7.0138209E-05,   7.5458658E-05
     +,   8.1224207E-05,   8.7420922E-05,   9.4029747E-05
     +,   1.0102746E-04,   1.0838794E-04,   1.1608325E-04
     +,   1.2408513E-04,   1.3236808E-04,   1.4091383E-04
     +,   1.4971518E-04,   1.5878021E-04,   1.6813952E-04
     +,   1.7785076E-04,   1.8800206E-04,   1.9871486E-04
     +,   2.1014392E-04,   2.2247285E-04,   2.3590504E-04
     +,   2.5065421E-04,   2.6693448E-04,   2.8495098E-04
     +,   3.0489621E-04,   3.2695718E-04,   3.5133149E-04
     +,   3.7824432E-04,   4.0795520E-04,   4.4074588E-04
     +,   4.7685660E-04,   5.1635958E-04,   5.5898144E-04
     +,   6.0389942E-04,   6.4957171E-04,   6.9369969E-04
     +,   7.3343632E-04,   7.6591782E-04,   7.8912394E-04
     +,   8.0300728E-04,   8.1069896E-04,   8.1951340E-04
     +,   8.4143336E-04,   8.9275715E-04,   9.9264027E-04
     +,   1.1603591E-03,   1.4113096E-03,   1.7522092E-03
     +,   2.1765430E-03,   2.6617874E-03,   3.1701361E-03
     +,   3.6538662E-03,   4.0646452E-03,   4.3641436E-03
     +,   4.5322971E-03,   4.5700613E-03,   4.4955607E-03
     +,   4.3356139E-03,   4.1165240E-03,   3.8577297E-03
     +,   3.5702547E-03,   3.2592905E-03,   2.9285585E-03
     +,   2.5840283E-03,   2.2355181E-03,   1.8958927E-03
     +,   1.5786247E-03,   1.2949690E-03,   1.0519128E-03
     +,   8.5141772E-04,   6.9096184E-04,   5.6499679E-04
     +,   4.6670067E-04,   3.8946312E-04,   3.2778902E-04
     +,   2.7764399E-04,   2.3634257E-04,   2.0219570E-04
     +,   1.7411268E-04,   1.5127905E-04,   1.3295398E-04
     +,   1.1838059E-04,   1.0678291E-04,   9.7409116E-05
     +,   8.9584231E-05,   8.2750310E-05,   7.6486831E-05
     +,   7.0510549E-05,   6.4659842E-05,   5.8868416E-05
     +,   5.3138247E-05,   4.7514255E-05,   4.2062518E-05
     +,   3.6853919E-05,   3.1953576E-05,   2.7414540E-05
     +,   2.3274184E-05,   1.9553212E-05,   1.6256952E-05
     +,   1.3377504E-05,   1.0895987E-05,   8.7851558E-06
     +,   7.0122719E-06,   5.5416367E-06,   4.3363084E-06
     +,   3.3599667E-06,   2.5782047E-06,   1.9592960E-06
     +,   1.4747040E-06,   1.0993874E-06,   8.1182225E-07
     +,   5.9382216E-07,   4.3027549E-07,   3.0884249E-07
     +,   2.1960415E-07,   1.5469210E-07,   1.0794935E-07
     +,   7.4626854E-08,   5.1110348E-08,   3.4678759E-08
     +,   2.3311200E-08,   1.5525160E-08,   1.0244995E-08
     +,   6.6992976E-09,   4.3415782E-09,   2.7891311E-09
     +,   1.7767986E-09,   1.1229183E-09,   7.0449258E-10
     +,   4.3916676E-10,   2.7237887E-10,   1.6837309E-10
     +,   1.0398382E-10,   6.4364257E-11,   4.0092055E-11
     +,   2.5253058E-11,   1.6172529E-11,   1.0587928E-11
     +,   7.1184100E-12,   4.9282397E-12,   3.5149060E-12
     +,   2.5774706E-12,   1.9359605E-12,   1.4825387E-12
     +,   1.1521324E-12,   9.0484591E-13,   7.1574729E-13
     +,   5.6875311E-13,   4.5315699E-13,   3.6152987E-13
     +,   2.8854379E-13,   2.3023667E-13,   1.8359358E-13
     +,   1.4626329E-13,   1.1639603E-13,   9.2515303E-14
     +,   7.3439085E-14,   5.8219122E-14,   4.6090637E-14
     +,   3.6438822E-14,   2.8768149E-14,   2.2680815E-14
     +,   1.7856498E-14,   1.4038816E-14,   1.1021838E-14
     +,   8.6411845E-15,   6.7652009E-15,   5.2891405E-15
     +,   4.1293030E-15,   3.2193221E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_htt95 = Yx/0.0228666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7118980E-05,   1.7273824E-05
     +,   1.7428360E-05,   1.7582706E-05,   1.7737002E-05
     +,   1.7891371E-05,   1.8045943E-05,   1.8200861E-05
     +,   1.8356253E-05,   1.8512264E-05,   1.8669029E-05
     +,   1.8826689E-05,   1.8985374E-05,   1.9145229E-05
     +,   1.9306386E-05,   1.9468982E-05,   1.9633146E-05
     +,   1.9799016E-05,   1.9966714E-05,   2.0136364E-05
     +,   2.0308087E-05,   2.0482008E-05,   2.0658230E-05
     +,   2.0836869E-05,   2.1018021E-05,   2.1201791E-05
     +,   2.1388269E-05,   2.1577533E-05,   2.1769671E-05
     +,   2.1964746E-05,   2.2162829E-05,   2.2363969E-05
     +,   2.2568216E-05,   2.2775612E-05,   2.2986178E-05
     +,   2.3199937E-05,   2.3416902E-05,   2.3637058E-05
     +,   2.3860415E-05,   2.4086930E-05,   2.4316581E-05
     +,   2.4549312E-05,   2.4785068E-05,   2.5023775E-05
     +,   2.5265344E-05,   2.5509680E-05,   2.5756672E-05
     +,   2.6006184E-05,   2.6258082E-05,   2.6512207E-05
     +,   2.6768383E-05,   2.7026428E-05,   2.7286133E-05
     +,   2.7547292E-05,   2.7809660E-05,   2.8072989E-05
     +,   2.8337021E-05,   2.8601471E-05,   2.8866039E-05
     +,   2.9130413E-05,   2.9394272E-05,   2.9657271E-05
     +,   2.9919045E-05,   3.0179232E-05,   3.0437455E-05
     +,   3.0693300E-05,   3.0946379E-05,   3.1196254E-05
     +,   3.1442512E-05,   3.1684704E-05,   3.1922398E-05
     +,   3.2155134E-05,   3.2382475E-05,   3.2603952E-05
     +,   3.2819120E-05,   3.3027543E-05,   3.3228775E-05
     +,   3.3422370E-05,   3.3607928E-05,   3.3785051E-05
     +,   3.3953347E-05,   3.4112476E-05,   3.4262099E-05
     +,   3.4401943E-05,   3.4531753E-05,   3.4651326E-05
     +,   3.4760516E-05,   3.4859222E-05,   3.4947407E-05
     +,   3.5025121E-05,   3.5092471E-05,   3.5149649E-05
     +,   3.5196928E-05,   3.5234683E-05,   3.5263380E-05
     +,   3.5283585E-05,   3.5295958E-05,   3.5301284E-05
     +,   3.5300443E-05,   3.5294415E-05,   3.5284302E-05
     +,   3.5271296E-05,   3.5256686E-05,   3.5241865E-05
     +,   3.5228291E-05,   3.5217494E-05,   3.5211062E-05
     +,   3.5210629E-05,   3.5217850E-05,   3.5234363E-05
     +,   3.5261804E-05,   3.5301764E-05,   3.5355748E-05
     +,   3.5425161E-05,   3.5511290E-05,   3.5615249E-05
     +,   3.5737958E-05,   3.5880141E-05,   3.6042235E-05
     +,   3.6224428E-05,   3.6426598E-05,   3.6648278E-05
     +,   3.6888665E-05,   3.7146598E-05,   3.7420537E-05
     +,   3.7708542E-05,   3.8008329E-05,   3.8317190E-05
     +,   3.8632090E-05,   3.8949598E-05,   3.9266026E-05
     +,   3.9577320E-05,   3.9879233E-05,   4.0167248E-05
     +,   4.0436724E-05,   4.0682909E-05,   4.0900977E-05
     +,   4.1086121E-05,   4.1233619E-05,   4.1338888E-05
     +,   4.1397550E-05,   4.1405532E-05,   4.1359111E-05
     +,   4.1255007E-05,   4.1090490E-05,   4.0863455E-05
     +,   4.0572562E-05,   4.0217390E-05,   3.9798695E-05
     +,   3.9318609E-05,   3.8781087E-05,   3.8192371E-05
     +,   3.7561793E-05,   3.6902522E-05,   3.6232836E-05
     +,   3.5577676E-05,   3.4970501E-05,   3.4455530E-05
     +,   3.4090594E-05,   3.3950302E-05,   3.4129716E-05
     +,   3.4748267E-05,   3.5954072E-05,   3.7927977E-05
     +,   4.0887931E-05,   4.5092500E-05,   5.0843224E-05
     +,   5.8486003E-05,   6.8411413E-05,   8.1052109E-05
     +,   9.6876669E-05,   1.1638177E-04,   1.4008248E-04
     +,   1.6849703E-04,   2.0212526E-04,   2.4143321E-04
     +,   2.8682727E-04,   3.3862467E-04,   3.9702817E-04
     +,   4.6210233E-04,   5.3374388E-04,   6.1164971E-04
     +,   6.9529872E-04,   7.8393793E-04,   8.7656517E-04
     +,   9.7191613E-04,   1.0684748E-03,   1.1644945E-03
     +,   1.2580205E-03,   1.3469253E-03,   1.4289883E-03
     +,   1.5019611E-03,   1.5636558E-03,   1.6120534E-03
     +,   1.6454103E-03,   1.6623616E-03,   1.6620113E-03
     +,   1.6440112E-03,   1.6086054E-03,   1.5566404E-03
     +,   1.4895437E-03,   1.4092604E-03,   1.3181505E-03
     +,   1.2188664E-03,   1.1142244E-03,   1.0070391E-03
     +,   8.9999224E-04,   7.9551683E-04,   6.9569331E-04
     +,   6.0217729E-04,   5.1617483E-04,   4.3844909E-04
     +,   3.6934167E-04,   3.0882176E-04,   2.5655745E-04
     +,   2.1199365E-04,   1.7442141E-04,   1.4304552E-04
     +,   1.1704717E-04,   9.5632597E-05,   7.8062083E-05
     +,   6.3674372E-05,   5.1897518E-05,   4.2249088E-05
     +,   3.4330707E-05,   2.7819980E-05,   2.2459450E-05
     +,   1.8044329E-05,   1.4411408E-05,   1.1429892E-05
     +,   8.9936593E-06,   7.0149381E-06,   5.4197735E-06
     +,   4.1450871E-06,   3.1366428E-06,   2.3474245E-06
     +,   1.7368779E-06,   1.2702808E-06,   9.1816554E-07
     +,   6.5584038E-07,   4.6294795E-07,   3.2298178E-07
     +,   2.2276268E-07,   1.5194611E-07,   1.0255867E-07
     +,   6.8560830E-08,   4.5452104E-08,   2.9934732E-08
     +,   1.9634188E-08,   1.2868976E-08,   8.4661904E-09
     +,   5.6214362E-09,   3.7915839E-09,   2.6152911E-09
     +,   1.8556521E-09,   1.3596173E-09,   1.0296194E-09
     +,   8.0418383E-10,   6.4497391E-10,   5.2828653E-10
     +,   4.3953299E-10,   3.6972303E-10,   3.1326808E-10
     +,   2.6663813E-10,   2.2754322E-10,   1.9443365E-10
     +,   1.6621411E-10,   1.4207359E-10,   1.2138276E-10
     +,   1.0363353E-10,   8.8406255E-11,   7.5347791E-11
     +,   6.4157242E-11,   5.4574786E-11,   4.6376725E-11
     +,   3.9370462E-11,   3.3388407E-11,   2.8286512E-11
     +,   2.3939507E-11,   2.0239886E-11,   1.7094342E-11
     +,   1.4422908E-11,   1.2156378E-11,   1.0235558E-11
     +,   8.6093268E-12,   7.2340718E-12,   6.0722503E-12
     +,   5.0917534E-12,   4.2652075E-12,   3.5691409E-12
     +,   2.9836123E-12,   2.4915597E-12,   2.0785305E-12
     +,   1.7321720E-12,   1.4420549E-12,   1.1992842E-12
     +,   9.9636304E-13,   8.2692143E-13,   6.8559139E-13
     +,   5.6782904E-13,   4.6981304E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz100 = Yx/0.0110833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0621070E-14,   1.5902110E-14
     +,   2.3719304E-14,   3.5245935E-14,   5.2176928E-14
     +,   7.6949853E-14,   1.1305709E-13,   1.6548176E-13
     +,   2.4130096E-13,   3.5053541E-13,   5.0730069E-13
     +,   7.3140815E-13,   1.0505453E-12,   1.5032530E-12
     +,   2.1429323E-12,   3.0433110E-12,   4.3057116E-12
     +,   6.0688251E-12,   8.5216756E-12,   1.1920831E-11
     +,   1.6613008E-11,   2.3064899E-11,   3.1901610E-11
     +,   4.3958150E-11,   6.0342474E-11,   8.2521885E-11
     +,   1.1242849E-10,   1.5259638E-10,   2.0633512E-10
     +,   2.7794753E-10,   3.7300341E-10,   4.9868265E-10
     +,   6.6419620E-10,   8.8131119E-10,   1.1649928E-09
     +,   1.5341857E-09,   2.0127657E-09,   2.6306775E-09
     +,   3.4253615E-09,   4.4432693E-09,   5.7419789E-09
     +,   7.3923281E-09,   9.4811616E-09,   1.2114430E-08
     +,   1.5420730E-08,   1.9555467E-08,   2.4705402E-08
     +,   3.1094011E-08,   3.8987203E-08,   4.8699928E-08
     +,   6.0603185E-08,   7.5131773E-08,   9.2792042E-08
     +,   1.1417264E-07,   1.3994942E-07,   1.7090017E-07
     +,   2.0790964E-07,   2.5198091E-07,   3.0424366E-07
     +,   3.6596217E-07,   4.3854246E-07,   5.2353937E-07
     +,   6.2265190E-07,   7.3773799E-07,   8.7080758E-07
     +,   1.0240019E-06,   1.1996163E-06,   1.4000476E-06
     +,   1.6278190E-06,   1.8855067E-06,   2.1757701E-06
     +,   2.5012478E-06,   2.8645945E-06,   3.2683504E-06
     +,   3.7149671E-06,   4.2067231E-06,   4.7456283E-06
     +,   5.3333815E-06,   5.9713484E-06,   6.6604657E-06
     +,   7.4010968E-06,   8.1931321E-06,   9.0357289E-06
     +,   9.9274685E-06,   1.0866095E-05,   1.1848696E-05
     +,   1.2871443E-05,   1.3929832E-05,   1.5018422E-05
     +,   1.6131085E-05,   1.7260949E-05,   1.8400373E-05
     +,   1.9541074E-05,   2.0674317E-05,   2.1790916E-05
     +,   2.2881261E-05,   2.3935689E-05,   2.4944344E-05
     +,   2.5897607E-05,   2.6785983E-05,   2.7600487E-05
     +,   2.8332594E-05,   2.8974584E-05,   2.9519466E-05
     +,   2.9961304E-05,   3.0295210E-05,   3.0517434E-05
     +,   3.0625473E-05,   3.0618117E-05,   3.0495443E-05
     +,   3.0258845E-05,   2.9910969E-05,   2.9455716E-05
     +,   2.8898101E-05,   2.8244254E-05,   2.7501188E-05
     +,   2.6676817E-05,   2.5779646E-05,   2.4818828E-05
     +,   2.3803810E-05,   2.2744258E-05,   2.1650003E-05
     +,   2.0530792E-05,   1.9396095E-05,   1.8255047E-05
     +,   1.7116434E-05,   1.5988344E-05,   1.4878379E-05
     +,   1.3793277E-05,   1.2739173E-05,   1.1721272E-05
     +,   1.0744104E-05,   9.8112705E-06,   8.9257037E-06
     +,   8.0894806E-06,   7.3039573E-06,   6.5698664E-06
     +,   5.8873143E-06,   5.2557994E-06,   4.6743316E-06
     +,   4.1415319E-06,   3.6556546E-06,   3.2146245E-06
     +,   2.8161398E-06,   2.4577680E-06,   2.1369212E-06
     +,   1.8509514E-06,   1.5972105E-06,   1.3730689E-06
     +,   1.1759354E-06,   1.0033051E-06,   8.5279288E-07
     +,   7.2213294E-07,   6.0918865E-07,   5.1197009E-07
     +,   4.2864539E-07,   3.5753237E-07,   2.9709358E-07
     +,   2.4594024E-07,   2.0282872E-07,   1.6664428E-07
     +,   1.3639925E-07,   1.1122497E-07,   9.0362590E-08
     +,   7.3157089E-08,   5.9062987E-08,   4.7668699E-08
     +,   3.8766714E-08,   3.2529972E-08,   2.9911686E-08
     +,   3.3483811E-08,   4.9094623E-08,   8.8955041E-08
     +,   1.7702502E-07,   3.5776074E-07,   7.0931077E-07
     +,   1.3616086E-06,   2.5183281E-06,   4.4792428E-06
     +,   7.6561919E-06,   1.2571826E-05,   1.9828305E-05
     +,   3.0036421E-05,   4.3704658E-05,   6.1102357E-05
     +,   8.2136990E-05,   1.0631447E-04,   1.3286131E-04
     +,   1.6106613E-04,   1.9083601E-04,   2.2334991E-04
     +,   2.6152289E-04,   3.0994945E-04,   3.7410256E-04
     +,   4.5890233E-04,   5.6719355E-04,   6.9892698E-04
     +,   8.5166463E-04,   1.0223431E-03,   1.2093880E-03
     +,   1.4137806E-03,   1.6377416E-03,   1.8805700E-03
     +,   2.1329019E-03,   2.3726898E-03,   2.5669178E-03
     +,   2.6804875E-03,   2.6891965E-03,   2.5897706E-03
     +,   2.4006881E-03,   2.1533710E-03,   1.8795655E-03
     +,   1.6022943E-03,   1.3341425E-03,   1.0811560E-03
     +,   8.4774743E-04,   6.3910463E-04,   4.6062580E-04
     +,   3.1598992E-04,   2.0566725E-04,   1.2671694E-04
     +,   7.3785166E-05,   4.0555387E-05,   2.1021622E-05
     +,   1.0267424E-05,   4.7217745E-06,   2.0431658E-06
     +,   8.3131494E-07,   3.1780905E-07,   1.1406831E-07
     +,   3.8409539E-08,   1.2124547E-08,   3.5850278E-09
     +,   9.9214836E-10,   2.5683228E-10,   6.2146233E-11
     +,   1.4047495E-11,   2.9648456E-12,   5.8405890E-13
     +,   1.0734471E-13,   1.8399922E-14,   2.9408719E-15
     +,   4.3824738E-16,   6.0888189E-17,   7.8932568E-18
     +,   9.5957738E-19,   1.1241109E-19,   1.4512013E-20
     +,   3.0535136E-21,   1.2515920E-21,   6.8254618E-22
     +,   3.9353214E-22,   2.2813494E-22,   1.3192649E-22
     +,   7.6015520E-23,   4.3635282E-23,   2.4953559E-23
     +,   1.4216589E-23,   8.0690357E-24,   4.5624622E-24
     +,   2.5700223E-24,   1.4422680E-24,   8.0633378E-25
     +,   4.4909378E-25,   2.4918716E-25,   1.3774552E-25
     +,   7.5854424E-26,   4.1614610E-26,   2.2744632E-26
     +,   1.2384358E-26,   6.7177107E-27,   3.6301734E-27
     +,   1.9543615E-27,   1.0481956E-27,   5.6005783E-28
     +,   2.9812153E-28,   1.5808973E-28,   8.3519348E-29
     +,   4.3956071E-29,   2.3047404E-29,   1.2038623E-29
     +,   6.2647402E-30,   3.2477122E-30,   1.6773556E-30
     +,   8.6302369E-31,   4.4237788E-31,   2.2590225E-31
     +,   1.1492144E-31,   5.8244240E-32,   2.9407278E-32
     +,   1.4791986E-32,   7.4123000E-33,   3.7003776E-33
     +,   1.8403086E-33,   9.1181848E-34,   4.5006584E-34
     +,   2.2131636E-34,   1.0841789E-34,   5.2912887E-35
     +,   2.5725978E-35,   1.2460976E-35
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz105 = Yx/0.009625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.8111070E-07,   1.0822928E-06
     +,   1.1919979E-06,   1.3107212E-06,   1.4389619E-06
     +,   1.5772208E-06,   1.7259958E-06,   1.8857803E-06
     +,   2.0570556E-06,   2.2402969E-06,   2.4359549E-06
     +,   2.6444604E-06,   2.8662173E-06,   3.1015954E-06
     +,   3.3509305E-06,   3.6145120E-06,   3.8925855E-06
     +,   4.1853391E-06,   4.4929061E-06,   4.8153529E-06
     +,   5.1526786E-06,   5.5048072E-06,   5.8715768E-06
     +,   6.2527711E-06,   6.6480370E-06,   7.0569813E-06
     +,   7.4790873E-06,   7.9137490E-06,   8.3602672E-06
     +,   8.8178385E-06,   9.2855635E-06,   9.7624416E-06
     +,   1.0247380E-05,   1.0739184E-05,   1.1236571E-05
     +,   1.1738175E-05,   1.2242535E-05,   1.2748115E-05
     +,   1.3253340E-05,   1.3756508E-05,   1.4255929E-05
     +,   1.4749827E-05,   1.5236404E-05,   1.5713831E-05
     +,   1.6180275E-05,   1.6633887E-05,   1.7072840E-05
     +,   1.7495320E-05,   1.7899549E-05,   1.8283801E-05
     +,   1.8646399E-05,   1.8985740E-05,   1.9300303E-05
     +,   1.9588675E-05,   1.9849516E-05,   2.0081632E-05
     +,   2.0283935E-05,   2.0455473E-05,   2.0595435E-05
     +,   2.0703153E-05,   2.0778116E-05,   2.0819964E-05
     +,   2.0828493E-05,   2.0803669E-05,   2.0745601E-05
     +,   2.0654577E-05,   2.0531024E-05,   2.0375544E-05
     +,   2.0188858E-05,   1.9971863E-05,   1.9725559E-05
     +,   1.9451112E-05,   1.9149762E-05,   1.8822908E-05
     +,   1.8472012E-05,   1.8098623E-05,   1.7704388E-05
     +,   1.7291028E-05,   1.6860280E-05,   1.6413927E-05
     +,   1.5953821E-05,   1.5481772E-05,   1.4999653E-05
     +,   1.4509264E-05,   1.4012451E-05,   1.3510970E-05
     +,   1.3006593E-05,   1.2500983E-05,   1.1995807E-05
     +,   1.1492614E-05,   1.0992888E-05,   1.0498054E-05
     +,   1.0009458E-05,   9.5283258E-06,   9.0557805E-06
     +,   8.5929069E-06,   8.1406242E-06,   7.6998122E-06
     +,   7.2711969E-06,   6.8554609E-06,   6.4531332E-06
     +,   6.0647039E-06,   5.6905178E-06,   5.3308822E-06
     +,   4.9859791E-06,   4.6559144E-06,   4.3407381E-06
     +,   4.0404279E-06,   3.7548737E-06,   3.4839047E-06
     +,   3.2273228E-06,   2.9848434E-06,   2.7561703E-06
     +,   2.5409342E-06,   2.3387624E-06,   2.1492242E-06
     +,   1.9718896E-06,   1.8062854E-06,   1.6519451E-06
     +,   1.5083739E-06,   1.3750707E-06,   1.2515419E-06
     +,   1.1372897E-06,   1.0318126E-06,   9.3461659E-07
     +,   8.4522355E-07,   7.6315439E-07,   6.8795299E-07
     +,   6.1916705E-07,   5.5636832E-07,   4.9913677E-07
     +,   4.4707718E-07,   3.9980480E-07,   3.5695967E-07
     +,   3.1819582E-07,   2.8318632E-07,   2.5162518E-07
     +,   2.2322443E-07,   1.9771224E-07,   1.7483474E-07
     +,   1.5435688E-07,   1.3605991E-07,   1.1973981E-07
     +,   1.0520805E-07,   9.2292346E-08,   8.0832585E-08
     +,   7.0682106E-08,   6.1707290E-08,   5.3786032E-08
     +,   4.6806587E-08,   4.0667370E-08,   3.5276837E-08
     +,   3.0551970E-08,   2.6417592E-08,   2.2805988E-08
     +,   1.9656614E-08,   1.6915113E-08,   1.4532662E-08
     +,   1.2465720E-08,   1.0675690E-08,   9.1280734E-09
     +,   7.7922744E-09,   6.6413435E-09,   5.6514637E-09
     +,   4.8016968E-09,   4.0739363E-09,   3.4531082E-09
     +,   2.9280043E-09,   2.4937317E-09,   2.1578936E-09
     +,   1.9545030E-09,   1.9741868E-09,   2.4272053E-09
     +,   3.7696042E-09,   6.9454202E-09,   1.3834336E-08
     +,   2.8044024E-08,   5.6251164E-08,   1.1037073E-07
     +,   2.1090383E-07,   3.9183001E-07,   7.0732972E-07
     +,   1.2404538E-06,   2.1135113E-06,   3.4992727E-06
     +,   5.6314352E-06,   8.8126362E-06,   1.3418440E-05
     +,   1.9896104E-05,   2.8758890E-05,   4.0584044E-05
     +,   5.6019449E-05,   7.5810683E-05,   1.0086059E-04
     +,   1.3232416E-04,   1.7172228E-04,   2.2104243E-04
     +,   2.8278027E-04,   3.5985731E-04,   4.5534607E-04
     +,   5.7197240E-04,   7.1143865E-04,   8.7365706E-04
     +,   1.0560249E-03,   1.2529340E-03,   1.4557556E-03
     +,   1.6533008E-03,   1.8328063E-03,   1.9813443E-03
     +,   2.0873917E-03,   2.1422724E-03,   2.1412536E-03
     +,   2.0841169E-03,   1.9750991E-03,   1.8222787E-03
     +,   1.6365452E-03,   1.4303076E-03,   1.2161398E-03
     +,   1.0055867E-03,   8.0824923E-04,   6.3115626E-04
     +,   4.7857719E-04,   3.5216537E-04,   2.5134892E-04
     +,   1.7389824E-04,   1.1656318E-04,   7.5659053E-05
     +,   4.7533231E-05,   2.8892151E-05,   1.6983780E-05
     +,   9.6520553E-06,   5.3016938E-06,   2.8138270E-06
     +,   1.4426462E-06,   7.1439058E-07,   3.4162008E-07
     +,   1.5772824E-07,   7.0305830E-08,   3.0252174E-08
     +,   1.2564805E-08,   5.0366711E-09,   1.9485149E-09
     +,   7.2749101E-10,   2.6210784E-10,   9.1123047E-11
     +,   3.0568145E-11,   9.8947352E-12,   3.0903231E-12
     +,   9.3119154E-13,   2.7072902E-13,   7.5940671E-14
     +,   2.0552562E-14,   5.3682530E-15,   1.3543990E-15
     +,   3.3093178E-16,   7.8979410E-17,   1.8922470E-17
     +,   4.9221846E-18,   1.6258424E-18,   7.6673563E-19
     +,   4.7247704E-19,   3.2661343E-19,   2.3391716E-19
     +,   1.6898055E-19,   1.2220111E-19,   8.8288399E-20
     +,   6.3694148E-20,   4.5879159E-20,   3.2994561E-20
     +,   2.3690584E-20,   1.6982774E-20,   1.2154694E-20
     +,   8.6854085E-21,   6.1963934E-21,   4.4135385E-21
     +,   3.1386585E-21,   2.2284458E-21,   1.5796741E-21
     +,   1.1179795E-21,   7.8996173E-22,   5.5728941E-22
     +,   3.9252111E-22,   2.7602246E-22,   1.9379165E-22
     +,   1.3583964E-22,   9.5065684E-23,   6.6424291E-23
     +,   4.6337150E-23,   3.2272988E-23,   2.2441483E-23
     +,   1.5580085E-23,   1.0799134E-23,   7.4733819E-24
     +,   5.1634855E-24,   3.5618829E-24,   2.4531012E-24
     +,   1.6867816E-24,   1.1579852E-24,   7.9369697E-25
     +,   5.4313236E-25,   3.7107990E-25
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz107 = Yx/0.00821739130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   1.4207504E-38,   9.6073079E-38
     +,   6.3439203E-37,   4.0908387E-36,   2.5759598E-35
     +,   1.5838287E-34,   9.5093177E-34,   5.5754839E-33
     +,   3.1920255E-32,   1.7846187E-31,   9.7424934E-31
     +,   5.1938385E-30,   2.7036725E-29,   1.3744005E-28
     +,   6.8221282E-28,   3.3068926E-27,   1.5652037E-26
     +,   7.2342274E-26,   3.2651542E-25,   1.4390882E-24
     +,   6.1932472E-24,   2.6026945E-23,   1.0681155E-22
     +,   4.2801826E-22,   1.6749429E-21,   6.4000975E-21
     +,   2.3881607E-20,   8.7014728E-20,   3.0960690E-19
     +,   1.0756741E-18,   3.6495515E-18,   1.2090723E-17
     +,   3.9114436E-17,   1.2356834E-16,   3.8119635E-16
     +,   1.1482726E-15,   3.3776205E-15,   9.7020721E-15
     +,   2.7213718E-14,   7.4536114E-14,   1.9935069E-13
     +,   5.2065795E-13,   1.3278361E-12,   3.3068043E-12
     +,   8.0418406E-12,   1.9097321E-11,   4.4284149E-11
     +,   1.0027556E-10,   2.2172969E-10,   4.7876625E-10
     +,   1.0094445E-09,   2.0783215E-09,   4.1785331E-09
     +,   8.2036156E-09,   1.5727084E-08,   2.9441640E-08
     +,   5.3821438E-08,   9.6075048E-08,   1.6747018E-07
     +,   2.8506406E-07,   4.7382511E-07,   7.6905513E-07
     +,   1.2189014E-06,   1.8865043E-06,   2.8511492E-06
     +,   4.2077741E-06,   6.0641096E-06,   8.5345273E-06
     +,   1.1730210E-05,   1.5746391E-05,   2.0648145E-05
     +,   2.6456566E-05,   3.3139229E-05,   4.0612431E-05
     +,   4.8756840E-05,   5.7451809E-05,   6.6629043E-05
     +,   7.6337288E-05,   8.6799992E-05,   9.8441567E-05
     +,   1.1185430E-04,   1.2768341E-04,   1.4642825E-04
     +,   1.6819617E-04,   1.9248479E-04,   2.1809030E-04
     +,   2.4321945E-04,   2.6583328E-04,   2.8416453E-04
     +,   2.9724423E-04,   3.0528239E-04,   3.0980466E-04
     +,   3.1355058E-04,   3.2017825E-04,   3.3371526E-04
     +,   3.5761067E-04,   3.9353626E-04,   4.4084998E-04
     +,   4.9805176E-04,   5.6616572E-04,   6.5092870E-04
     +,   7.5982435E-04,   8.9489721E-04,   1.0479284E-03
     +,   1.2008987E-03,   1.3269230E-03,   1.3936067E-03
     +,   1.3851359E-03,   1.3414052E-03,   1.3646963E-03
     +,   1.5472546E-03,   1.8648945E-03,   2.1542662E-03
     +,   2.2225503E-03,   1.9920054E-03,   1.5432821E-03
     +,   1.0369750E-03,   6.0700480E-04,   3.1013225E-04
     +,   1.3805777E-04,   5.3292886E-05,   1.7729219E-05
     +,   5.0518297E-06,   1.2265991E-06,   2.5281673E-07
     +,   4.4119588E-08,   6.5072108E-09,   8.1015294E-10
     +,   8.5082934E-11,   7.5339639E-12,   5.6222138E-13
     +,   3.5347295E-14,   1.8735259E-15,   8.4160294E-17
     +,   3.3478409E-18,   1.6005649E-19,   1.9340938E-20
     +,   4.5102645E-21,   1.1585494E-21,   2.9388464E-22
     +,   7.2860228E-23,   1.7640028E-23,   4.1702288E-24
     +,   9.6269627E-25,   2.1702631E-25,   4.7775392E-26
     +,   1.0269440E-26,   2.1556728E-27,   4.4186317E-28
     +,   8.8438559E-29,   1.7284932E-29,   3.2990130E-30
     +,   6.1485934E-31,   1.1189521E-31,   1.9884636E-32
     +,   3.4507948E-33,   5.8478038E-34,   9.6762861E-35
     +,   1.5635078E-35,   2.4670808E-36,   3.8013873E-37
     +,   5.7193050E-38,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz110 = Yx/0.00731818181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1102028E-09,   1.3865307E-09
     +,   1.7274990E-09,   2.1471811E-09,   2.6624596E-09
     +,   3.2935328E-09,   4.0644932E-09,   5.0040190E-09
     +,   6.1460832E-09,   7.5309492E-09,   9.2060333E-09
     +,   1.1227129E-08,   1.3659647E-08,   1.6580092E-08
     +,   2.0077646E-08,   2.4255971E-08,   2.9235244E-08
     +,   3.5154304E-08,   4.2173188E-08,   5.0475631E-08
     +,   6.0272313E-08,   7.1803541E-08,   8.5342933E-08
     +,   1.0120189E-07,   1.1973090E-07,   1.4132762E-07
     +,   1.6643784E-07,   1.9556178E-07,   2.2925855E-07
     +,   2.6815076E-07,   3.1293018E-07,   3.6436273E-07
     +,   4.2329268E-07,   4.9064937E-07,   5.6745051E-07
     +,   6.5480845E-07,   7.5393336E-07,   8.6613653E-07
     +,   9.9284239E-07,   1.1355702E-06,   1.2959655E-06
     +,   1.4757777E-06,   1.6768706E-06,   1.9012211E-06
     +,   2.1509136E-06,   2.4281410E-06,   2.7351966E-06
     +,   3.0744682E-06,   3.4484281E-06,   3.8596258E-06
     +,   4.3106734E-06,   4.8042275E-06,   5.3429712E-06
     +,   5.9296353E-06,   6.5668737E-06,   7.2573762E-06
     +,   8.0037371E-06,   8.8084689E-06,   9.6739741E-06
     +,   1.0602505E-05,   1.1596135E-05,   1.2656737E-05
     +,   1.3785861E-05,   1.4984861E-05,   1.6254773E-05
     +,   1.7596149E-05,   1.9009309E-05,   2.0493962E-05
     +,   2.2049548E-05,   2.3674793E-05,   2.5368116E-05
     +,   2.7127167E-05,   2.8949231E-05,   3.0830772E-05
     +,   3.2767835E-05,   3.4755831E-05,   3.6789439E-05
     +,   3.8862730E-05,   4.0969284E-05,   4.3102107E-05
     +,   4.5253448E-05,   4.7415291E-05,   4.9578866E-05
     +,   5.1735242E-05,   5.3874828E-05,   5.5987959E-05
     +,   5.8064506E-05,   6.0094353E-05,   6.2067062E-05
     +,   6.3972388E-05,   6.5800101E-05,   6.7540073E-05
     +,   6.9182366E-05,   7.0717557E-05,   7.2136623E-05
     +,   7.3430914E-05,   7.4592586E-05,   7.5614327E-05
     +,   7.6489712E-05,   7.7213066E-05,   7.7779681E-05
     +,   7.8185738E-05,   7.8428464E-05,   7.8506069E-05
     +,   7.8417848E-05,   7.8164107E-05,   7.7746263E-05
     +,   7.7166755E-05,   7.6429038E-05,   7.5537529E-05
     +,   7.4497671E-05,   7.3315678E-05,   7.1998722E-05
     +,   7.0554554E-05,   6.8991809E-05,   6.7319488E-05
     +,   6.5547305E-05,   6.3685155E-05,   6.1743478E-05
     +,   5.9732753E-05,   5.7663558E-05,   5.5546632E-05
     +,   5.3392650E-05,   5.1211984E-05,   4.9014783E-05
     +,   4.6811070E-05,   4.4610228E-05,   4.2421452E-05
     +,   4.0253166E-05,   3.8113503E-05,   3.6009747E-05
     +,   3.3948825E-05,   3.1936750E-05,   2.9979145E-05
     +,   2.8080762E-05,   2.6245702E-05,   2.4477533E-05
     +,   2.2779157E-05,   2.1152766E-05,   1.9599951E-05
     +,   1.8121855E-05,   1.6719099E-05,   1.5391732E-05
     +,   1.4139403E-05,   1.2961538E-05,   1.1857156E-05
     +,   1.0825112E-05,   9.8642595E-06,   8.9734949E-06
     +,   8.1518892E-06,   7.3989554E-06,   6.7149408E-06
     +,   6.1010910E-06,   5.5600058E-06,   5.0961730E-06
     +,   4.7165827E-06,   4.4313892E-06,   4.2547385E-06
     +,   4.2057991E-06,   4.3098844E-06,   4.5997199E-06
     +,   5.1168900E-06,   5.9132935E-06,   7.0526771E-06
     +,   8.6122309E-06,   1.0683930E-05,   1.3375377E-05
     +,   1.6810409E-05,   2.1129143E-05,   2.6486783E-05
     +,   3.3050812E-05,   4.0997307E-05,   5.0506096E-05
     +,   6.1753250E-05,   7.4900701E-05,   9.0087866E-05
     +,   1.0741901E-04,   1.2694953E-04,   1.4867437E-04
     +,   1.7251867E-04,   1.9832789E-04,   2.2586058E-04
     +,   2.5478934E-04,   2.8470752E-04,   3.1513887E-04
     +,   3.4555211E-04,   3.7538615E-04,   4.0407968E-04
     +,   4.3109959E-04,   4.5596983E-04,   4.7830667E-04
     +,   4.9784069E-04,   5.1443506E-04,   5.2809610E-04
     +,   5.3897308E-04,   5.4734590E-04,   5.5360101E-04
     +,   5.5820151E-04,   5.6164846E-04,   5.6443748E-04
     +,   5.6701718E-04,   5.6974927E-04,   5.7287794E-04
     +,   5.7650625E-04,   5.8058591E-04,   5.8492029E-04
     +,   5.8917812E-04,   5.9291819E-04,   5.9562473E-04
     +,   5.9674622E-04,   5.9573649E-04,   5.9209636E-04
     +,   5.8540900E-04,   5.7536963E-04,   5.6180474E-04
     +,   5.4468506E-04,   5.2412611E-04,   5.0037785E-04
     +,   4.7380981E-04,   4.4489146E-04,   4.1416063E-04
     +,   3.8219744E-04,   3.4959769E-04,   3.1694412E-04
     +,   2.8478072E-04,   2.5359535E-04,   2.2380770E-04
     +,   1.9575775E-04,   1.6970008E-04,   1.4580652E-04
     +,   1.2417200E-04,   1.0482028E-04,   8.7712498E-05
     +,   7.2759816E-05,   5.9836024E-05,   4.8785678E-05
     +,   3.9436207E-05,   3.1607367E-05,   2.5118014E-05
     +,   1.9791940E-05,   1.5462992E-05,   1.1978384E-05
     +,   9.2001310E-06,   7.0058159E-06,   5.2888781E-06
     +,   3.9580586E-06,   2.9361822E-06,   2.1588437E-06
     +,   1.5730679E-06,   1.1358545E-06,   8.1262812E-07
     +,   5.7596617E-07,   4.0437993E-07,   2.8120331E-07
     +,   1.9365622E-07,   1.3205781E-07,   8.9160515E-08
     +,   5.9595429E-08,   3.9430525E-08,   2.5821453E-08
     +,   1.6734804E-08,   1.0732950E-08,   6.8113568E-09
     +,   4.2768442E-09,   2.6568663E-09,   1.6328185E-09
     +,   9.9264552E-10,   5.9692817E-10,   3.5506445E-10
     +,   2.0889249E-10,   1.2154688E-10,   6.9945896E-11
     +,   3.9808136E-11,   2.2405385E-11,   1.2470517E-11
     +,   6.8639682E-12,   3.7359352E-12,   2.0107856E-12
     +,   1.0701627E-12,   5.6320264E-13,   2.9308053E-13
     +,   1.5081008E-13,   7.6731061E-14,   3.8603520E-14
     +,   1.9203197E-14,   9.4456193E-15,   4.5939205E-15
     +,   2.2091250E-15,   1.0504164E-15,   4.9383778E-16
     +,   2.2956626E-16,   1.0551429E-16,   4.7952858E-17
     +,   2.1547398E-17,   9.5735551E-18,   4.2056141E-18
     +,   1.8267630E-18,   7.8453278E-19,   3.3315092E-19
     +,   1.3987698E-19,   5.8069908E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz115 = Yx/0.00666666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3500402E-07,   1.5911320E-07
     +,   1.8711771E-07,   2.1957017E-07,   2.5708852E-07
     +,   3.0036134E-07,   3.5015375E-07,   4.0731274E-07
     +,   4.7277223E-07,   5.4756305E-07,   6.3281243E-07
     +,   7.2975342E-07,   8.3972884E-07,   9.6419649E-07
     +,   1.1047333E-06,   1.2630386E-06,   1.4409374E-06
     +,   1.6403820E-06,   1.8634524E-06,   2.1123578E-06
     +,   2.3894327E-06,   2.6971350E-06,   3.0380368E-06
     +,   3.4148438E-06,   3.8303260E-06,   4.2873889E-06
     +,   4.7889957E-06,   5.3381859E-06,   5.9380473E-06
     +,   6.5917029E-06,   7.3022884E-06,   8.0729324E-06
     +,   8.9067280E-06,   9.8067076E-06,   1.0775821E-05
     +,   1.1816896E-05,   1.2932618E-05,   1.4125471E-05
     +,   1.5397813E-05,   1.6751606E-05,   1.8188695E-05
     +,   1.9710526E-05,   2.1318225E-05,   2.3012553E-05
     +,   2.4793870E-05,   2.6662108E-05,   2.8616756E-05
     +,   3.0656833E-05,   3.2780852E-05,   3.4986842E-05
     +,   3.7272319E-05,   3.9634266E-05,   4.2069121E-05
     +,   4.4572946E-05,   4.7141039E-05,   4.9768481E-05
     +,   5.2449715E-05,   5.5178785E-05,   5.7949317E-05
     +,   6.0754581E-05,   6.3587497E-05,   6.6440742E-05
     +,   6.9306581E-05,   7.2177354E-05,   7.5045260E-05
     +,   7.7902194E-05,   8.0740385E-05,   8.3551844E-05
     +,   8.6329055E-05,   8.9064335E-05,   9.1750713E-05
     +,   9.4381132E-05,   9.6949349E-05,   9.9449207E-05
     +,   1.0187535E-04,   1.0422293E-04,   1.0648758E-04
     +,   1.0866554E-04,   1.1075384E-04,   1.1275017E-04
     +,   1.1465268E-04,   1.1646040E-04,   1.1817273E-04
     +,   1.1978992E-04,   1.2131251E-04,   1.2274178E-04
     +,   1.2407928E-04,   1.2532697E-04,   1.2648711E-04
     +,   1.2756216E-04,   1.2855479E-04,   1.2946753E-04
     +,   1.3030301E-04,   1.3106367E-04,   1.3175173E-04
     +,   1.3236917E-04,   1.3291756E-04,   1.3339800E-04
     +,   1.3381118E-04,   1.3415728E-04,   1.3443590E-04
     +,   1.3464608E-04,   1.3478630E-04,   1.3485455E-04
     +,   1.3484826E-04,   1.3476434E-04,   1.3459940E-04
     +,   1.3434960E-04,   1.3401086E-04,   1.3357891E-04
     +,   1.3304943E-04,   1.3241803E-04,   1.3168051E-04
     +,   1.3083285E-04,   1.2987135E-04,   1.2879274E-04
     +,   1.2759432E-04,   1.2627388E-04,   1.2483008E-04
     +,   1.2326223E-04,   1.2157044E-04,   1.1975578E-04
     +,   1.1782032E-04,   1.1576699E-04,   1.1359958E-04
     +,   1.1132319E-04,   1.0894354E-04,   1.0646763E-04
     +,   1.0390311E-04,   1.0125890E-04,   9.8544362E-05
     +,   9.5770149E-05,   9.2947310E-05,   9.0087990E-05
     +,   8.7204760E-05,   8.4310814E-05,   8.1420119E-05
     +,   7.8547164E-05,   7.5706717E-05,   7.2913928E-05
     +,   7.0184476E-05,   6.7534289E-05,   6.4979315E-05
     +,   6.2535633E-05,   6.0219540E-05,   5.8047015E-05
     +,   5.6033903E-05,   5.4195854E-05,   5.2548072E-05
     +,   5.1105053E-05,   4.9880648E-05,   4.8887909E-05
     +,   4.8138874E-05,   4.7644349E-05,   4.7413909E-05
     +,   4.7455764E-05,   4.7776590E-05,   4.8381531E-05
     +,   4.9274211E-05,   5.0456674E-05,   5.1929594E-05
     +,   5.3692493E-05,   5.5743767E-05,   5.8081161E-05
     +,   6.0702339E-05,   6.3605308E-05,   6.6788736E-05
     +,   7.0252863E-05,   7.4000403E-05,   7.8037134E-05
     +,   8.2372448E-05,   8.7020257E-05,   9.2000111E-05
     +,   9.7337521E-05,   1.0306388E-04,   1.0921781E-04
     +,   1.1584489E-04,   1.2299669E-04,   1.3073084E-04
     +,   1.3911063E-04,   1.4820309E-04,   1.5807677E-04
     +,   1.6879999E-04,   1.8043903E-04,   1.9305458E-04
     +,   2.0669744E-04,   2.2140570E-04,   2.3720210E-04
     +,   2.5408945E-04,   2.7204526E-04,   2.9102163E-04
     +,   3.1094125E-04,   3.3169327E-04,   3.5313354E-04
     +,   3.7508568E-04,   3.9734022E-04,   4.1965544E-04
     +,   4.4176172E-04,   4.6336753E-04,   4.8416390E-04
     +,   5.0382916E-04,   5.2203884E-04,   5.3847447E-04
     +,   5.5283168E-04,   5.6482648E-04,   5.7420757E-04
     +,   5.8076187E-04,   5.8432185E-04,   5.8477098E-04
     +,   5.8204849E-04,   5.7615119E-04,   5.6713430E-04
     +,   5.5511098E-04,   5.4024794E-04,   5.2276091E-04
     +,   5.0291052E-04,   4.8099351E-04,   4.5733331E-04
     +,   4.3227238E-04,   4.0616508E-04,   3.7936462E-04
     +,   3.5221677E-04,   3.2505335E-04,   2.9818431E-04
     +,   2.7188976E-04,   2.4641753E-04,   2.2198170E-04
     +,   1.9875891E-04,   1.7688627E-04,   1.5646398E-04
     +,   1.3755780E-04,   1.2020029E-04,   1.0439275E-04
     +,   9.0110363E-05,   7.7307224E-05,   6.5917644E-05
     +,   5.5861732E-05,   4.7049802E-05,   3.9385097E-05
     +,   3.2766620E-05,   2.7092656E-05,   2.2263392E-05
     +,   1.8182396E-05,   1.4757923E-05,   1.1904401E-05
     +,   9.5432861E-06,   7.6031984E-06,   6.0199964E-06
     +,   4.7368640E-06,   3.7041077E-06,   2.8785066E-06
     +,   2.2229740E-06,   1.7060223E-06,   1.3011223E-06
     +,   9.8611338E-07,   7.4268178E-07,   5.5583450E-07
     +,   4.1338527E-07,   3.0550819E-07,   2.2435719E-07
     +,   1.6372178E-07,   1.1871959E-07,   8.5541814E-08
     +,   6.1244251E-08,   4.3570051E-08,   3.0799026E-08
     +,   2.1632285E-08,   1.5096793E-08,   1.0468497E-08
     +,   7.2125879E-09,   4.9373696E-09,   3.3581322E-09
     +,   2.2693367E-09,   1.5236629E-09,   1.0163812E-09
     +,   6.7361278E-10,   4.4353940E-10,   2.9015529E-10
     +,   1.8857692E-10,   1.2176254E-10,   7.8106965E-11
     +,   4.9776554E-11,   3.1513847E-11,   1.9821134E-11
     +,   1.2384790E-11,   7.6876110E-12,   4.7405118E-12
     +,   2.9038918E-12,   1.7671178E-12,   1.0682275E-12
     +,   6.4148220E-13,   3.8265750E-13,   2.2675260E-13
     +,   1.3347231E-13,   7.8043949E-14,   4.5329124E-14
     +,   2.6152811E-14,   1.4987919E-14,   8.5321959E-15
     +,   4.8245510E-15,   2.7098386E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz120 = Yx/0.00763636363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0946282E-05,   1.2057447E-05
     +,   1.3255276E-05,   1.4544182E-05,   1.5928652E-05
     +,   1.7413236E-05,   1.9002546E-05,   2.0701233E-05
     +,   2.2513956E-05,   2.4445470E-05,   2.6500442E-05
     +,   2.8683547E-05,   3.0999418E-05,   3.3452572E-05
     +,   3.6047459E-05,   3.8788345E-05,   4.1679297E-05
     +,   4.4724111E-05,   4.7926278E-05,   5.1288873E-05
     +,   5.4814431E-05,   5.8504902E-05,   6.2361381E-05
     +,   6.6384280E-05,   7.0572423E-05,   7.4923773E-05
     +,   7.9434438E-05,   8.4098763E-05,   8.8909030E-05
     +,   9.3855284E-05,   9.8925171E-05,   1.0410383E-04
     +,   1.0937406E-04,   1.1471657E-04,   1.2011046E-04
     +,   1.2553394E-04,   1.3096549E-04,   1.3638502E-04
     +,   1.4177601E-04,   1.4712641E-04,   1.5243198E-04
     +,   1.5769737E-04,   1.6293861E-04,   1.6818506E-04
     +,   1.7348069E-04,   1.7888550E-04,   1.8447581E-04
     +,   1.9034468E-04,   1.9660163E-04,   2.0337199E-04
     +,   2.1079635E-04,   2.1902993E-04,   2.2824199E-04
     +,   2.3861600E-04,   2.5034713E-04,   2.6364310E-04
     +,   2.7871883E-04,   2.9579160E-04,   3.1507152E-04
     +,   3.3674794E-04,   3.6097082E-04,   3.8782854E-04
     +,   4.1731997E-04,   4.4933104E-04,   4.8360828E-04
     +,   5.1973551E-04,   5.5713212E-04,   5.9504656E-04
     +,   6.3258316E-04,   6.6872704E-04,   7.0240273E-04
     +,   7.3252409E-04,   7.5807131E-04,   7.7815168E-04
     +,   7.9206837E-04,   7.9936779E-04,   7.9987559E-04
     +,   7.9371268E-04,   7.8128872E-04,   7.6327845E-04
     +,   7.4058236E-04,   7.1426958E-04,   6.8552454E-04
     +,   6.5557664E-04,   6.2564731E-04,   5.9688633E-04
     +,   5.7033199E-04,   5.4686476E-04,   5.2718504E-04
     +,   5.1179063E-04,   5.0097081E-04,   4.9481011E-04
     +,   4.9319799E-04,   4.9584999E-04,   5.0233543E-04
     +,   5.1210797E-04,   5.2454410E-04,   5.3897494E-04
     +,   5.5472401E-04,   5.7113229E-04,   5.8758602E-04
     +,   6.0352788E-04,   6.1847002E-04,   6.3199073E-04
     +,   6.4373488E-04,   6.5340556E-04,   6.6075486E-04
     +,   6.6557911E-04,   6.6771463E-04,   6.6703762E-04
     +,   6.6346716E-04,   6.5697083E-04,   6.4757327E-04
     +,   6.3535944E-04,   6.2048022E-04,   6.0314935E-04
     +,   5.8364077E-04,   5.6227297E-04,   5.3940120E-04
     +,   5.1539519E-04,   4.9062283E-04,   4.6543730E-04
     +,   4.4016069E-04,   4.1507347E-04,   3.9041048E-04
     +,   3.6636260E-04,   3.4307374E-04,   3.2065276E-04
     +,   2.9917466E-04,   2.7869386E-04,   2.5924653E-04
     +,   2.4086141E-04,   2.2355975E-04,   2.0736264E-04
     +,   1.9228808E-04,   1.7835242E-04,   1.6556984E-04
     +,   1.5394903E-04,   1.4349056E-04,   1.3418555E-04
     +,   1.2601462E-04,   1.1894591E-04,   1.1293466E-04
     +,   1.0792389E-04,   1.0384594E-04,   1.0062304E-04
     +,   9.8169774E-05,   9.6395437E-05,   9.5206058E-05
     +,   9.4506824E-05,   9.4204144E-05,   9.4207819E-05
     +,   9.4432544E-05,   9.4799296E-05,   9.5236283E-05
     +,   9.5679658E-05,   9.6073964E-05,   9.6372052E-05
     +,   9.6535194E-05,   9.6532567E-05,   9.6340911E-05
     +,   9.5943935E-05,   9.5331648E-05,   9.4499883E-05
     +,   9.3449285E-05,   9.2184957E-05,   9.0715686E-05
     +,   8.9053363E-05,   8.7212269E-05,   8.5208529E-05
     +,   8.3059858E-05,   8.0784965E-05,   7.8402867E-05
     +,   7.5932767E-05,   7.3393894E-05,   7.0804803E-05
     +,   6.8183232E-05,   6.5546221E-05,   6.2909632E-05
     +,   6.0287937E-05,   5.7694229E-05,   5.5140372E-05
     +,   5.2636766E-05,   5.0192200E-05,   4.7814014E-05
     +,   4.5508350E-05,   4.3279982E-05,   4.1132331E-05
     +,   3.9067651E-05,   3.7087349E-05,   3.5191719E-05
     +,   3.3380202E-05,   3.1651685E-05,   3.0004419E-05
     +,   2.8436061E-05,   2.6943899E-05,   2.5525002E-05
     +,   2.4176254E-05,   2.2894292E-05,   2.1675736E-05
     +,   2.0517266E-05,   1.9415624E-05,   1.8367575E-05
     +,   1.7370015E-05,   1.6420101E-05,   1.5515070E-05
     +,   1.4652346E-05,   1.3829603E-05,   1.3044703E-05
     +,   1.2295648E-05,   1.1580624E-05,   1.0898033E-05
     +,   1.0246436E-05,   9.6244930E-06,   9.0309977E-06
     +,   8.4648973E-06,   7.9252359E-06,   7.4111049E-06
     +,   6.9216690E-06,   6.4561973E-06,   6.0139596E-06
     +,   5.5942564E-06,   5.1964466E-06,   4.8198999E-06
     +,   4.4639692E-06,   4.1280155E-06,   3.8114224E-06
     +,   3.5135661E-06,   3.2337985E-06,   2.9714656E-06
     +,   2.7259243E-06,   2.4965241E-06,   2.2825905E-06
     +,   2.0834482E-06,   1.8984390E-06,   1.7268848E-06
     +,   1.5681100E-06,   1.4214553E-06,   1.2862664E-06
     +,   1.1618901E-06,   1.0476850E-06,   9.4303255E-07
     +,   8.4732966E-07,   7.5998287E-07,   6.8042033E-07
     +,   6.0809708E-07,   5.4248864E-07,   4.8308965E-07
     +,   4.2941892E-07,   3.8102482E-07,   3.3747477E-07
     +,   2.9836167E-07,   2.6330503E-07,   2.3194821E-07
     +,   2.0395585E-07,   1.7901614E-07,   1.5684144E-07
     +,   1.3716502E-07,   1.1973958E-07,   1.0433776E-07
     +,   9.0752067E-08,   7.8792482E-08,   6.8284756E-08
     +,   5.9070604E-08,   5.1007216E-08,   4.3964533E-08
     +,   3.7825224E-08,   3.2484103E-08,   2.7846637E-08
     +,   2.3827836E-08,   2.0351861E-08,   1.7351375E-08
     +,   1.4766452E-08,   1.2543769E-08,   1.0636228E-08
     +,   9.0024264E-09,   7.6057010E-09,   6.4140320E-09
     +,   5.3992100E-09,   4.5367212E-09,   3.8050549E-09
     +,   3.1856080E-09,   2.6621387E-09,   2.2206581E-09
     +,   1.8490133E-09,   1.5367760E-09,   1.2749446E-09
     +,   1.0557936E-09,   8.7272878E-10,   7.2009010E-10
     +,   5.9307093E-10,   4.8756588E-10,   4.0010414E-10
     +,   3.2773262E-10,   2.6796554E-10,   2.1869810E-10
     +,   1.7816557E-10,   1.4488033E-10,   1.1760021E-10
     +,   9.5282608E-11,   7.7060504E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz60 = Yx/0.0126
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0867929E-05,   1.1475236E-05
     +,   1.2096372E-05,   1.2731311E-05,   1.3380403E-05
     +,   1.4044480E-05,   1.4724967E-05,   1.5423997E-05
     +,   1.6144548E-05,   1.6890619E-05,   1.7667307E-05
     +,   1.8480987E-05,   1.9339461E-05,   2.0252077E-05
     +,   2.1229858E-05,   2.2285592E-05,   2.3433919E-05
     +,   2.4691364E-05,   2.6076343E-05,   2.7609107E-05
     +,   2.9311665E-05,   3.1207619E-05,   3.3321900E-05
     +,   3.5680740E-05,   3.8310885E-05,   4.1239768E-05
     +,   4.4494722E-05,   4.8102676E-05,   5.2089705E-05
     +,   5.6480538E-05,   6.1298131E-05,   6.6563189E-05
     +,   7.2293726E-05,   7.8504687E-05,   8.5207423E-05
     +,   9.2409340E-05,   1.0011338E-04,   1.0831733E-04
     +,   1.1701398E-04,   1.2618878E-04,   1.3582119E-04
     +,   1.4588219E-04,   1.5633414E-04,   1.6712965E-04
     +,   1.7821099E-04,   1.8950917E-04,   2.0094369E-04
     +,   2.1242225E-04,   2.2384113E-04,   2.3508588E-04
     +,   2.4603272E-04,   2.5655015E-04,   2.6650162E-04
     +,   2.7574901E-04,   2.8415487E-04,   2.9158854E-04
     +,   2.9792954E-04,   3.0307338E-04,   3.0693709E-04
     +,   3.0946554E-04,   3.1063726E-04,   3.1047114E-04
     +,   3.0903259E-04,   3.0643877E-04,   3.0286412E-04
     +,   2.9854453E-04,   2.9377959E-04,   2.8893468E-04
     +,   2.8443907E-04,   2.8078514E-04,   2.7852162E-04
     +,   2.7824703E-04,   2.8059728E-04,   2.8623044E-04
     +,   2.9580449E-04,   3.0994930E-04,   3.2922745E-04
     +,   3.5408800E-04,   3.8481512E-04,   4.2146930E-04
     +,   4.6382713E-04,   5.1134586E-04,   5.6312990E-04
     +,   6.1795197E-04,   6.7428866E-04,   7.3042454E-04
     +,   7.8456360E-04,   8.3499309E-04,   8.8022504E-04
     +,   9.1914623E-04,   9.5112046E-04,   9.7604486E-04
     +,   9.9436194E-04,   1.0070133E-03,   1.0153451E-03
     +,   1.0209710E-03,   1.0256035E-03,   1.0308558E-03
     +,   1.0380383E-03,   1.0479651E-03,   1.0608057E-03
     +,   1.0760099E-03,   1.0923337E-03,   1.1079729E-03
     +,   1.1207953E-03,   1.1286269E-03,   1.1295537E-03
     +,   1.1221685E-03,   1.1057360E-03,   1.0802337E-03
     +,   1.0462966E-03,   1.0050685E-03,   9.5802546E-04
     +,   9.0678816E-04,   8.5298560E-04,   7.9814566E-04
     +,   7.4366032E-04,   6.9075415E-04,   6.4049737E-04
     +,   5.9378694E-04,   5.5133516E-04,   5.1364524E-04
     +,   4.8097278E-04,   4.5330328E-04,   4.3035042E-04
     +,   4.1158232E-04,   3.9626687E-04,   3.8355001E-04
     +,   3.7253523E-04,   3.6237028E-04,   3.5231549E-04
     +,   3.4179757E-04,   3.3043342E-04,   3.1803604E-04
     +,   3.0459388E-04,   2.9023908E-04,   2.7520760E-04
     +,   2.5979479E-04,   2.4431487E-04,   2.2906782E-04
     +,   2.1431629E-04,   2.0026857E-04,   1.8707069E-04
     +,   1.7480778E-04,   1.6351053E-04,   1.5316189E-04
     +,   1.4370923E-04,   1.3507652E-04,   1.2717368E-04
     +,   1.1990558E-04,   1.1317981E-04,   1.0691219E-04
     +,   1.0102974E-04,   9.5471798E-05,   9.0190864E-05
     +,   8.5152031E-05,   8.0331221E-05,   7.5713098E-05
     +,   7.1289425E-05,   6.7057532E-05,   6.3017789E-05
     +,   5.9172424E-05,   5.5524724E-05,   5.2077619E-05
     +,   4.8832877E-05,   4.5790894E-05,   4.2950585E-05
     +,   4.0309027E-05,   3.7861340E-05,   3.5601013E-05
     +,   3.3520144E-05,   3.1609525E-05,   2.9858782E-05
     +,   2.8256773E-05,   2.6792004E-05,   2.5452528E-05
     +,   2.4226409E-05,   2.3101959E-05,   2.2067867E-05
     +,   2.1113283E-05,   2.0228019E-05,   1.9402712E-05
     +,   1.8628816E-05,   1.7898599E-05,   1.7205228E-05
     +,   1.6542772E-05,   1.5906156E-05,   1.5291074E-05
     +,   1.4693976E-05,   1.4112063E-05,   1.3543110E-05
     +,   1.2985455E-05,   1.2437960E-05,   1.1899906E-05
     +,   1.1370894E-05,   1.0850819E-05,   1.0339849E-05
     +,   9.8383225E-06,   9.3466879E-06,   8.8654824E-06
     +,   8.3953300E-06,   7.9368829E-06,   7.4907566E-06
     +,   7.0575429E-06,   6.6378384E-06,   6.2321392E-06
     +,   5.8408791E-06,   5.4644438E-06,   5.1031407E-06
     +,   4.7571712E-06,   4.4266599E-06,   4.1116732E-06
     +,   3.8121989E-06,   3.5281312E-06,   3.2592966E-06
     +,   3.0054766E-06,   2.7663914E-06,   2.5416930E-06
     +,   2.3309879E-06,   2.1338640E-06,   1.9498514E-06
     +,   1.7784558E-06,   1.6191707E-06,   1.4714697E-06
     +,   1.3348042E-06,   1.2086209E-06,   1.0923711E-06
     +,   9.8550618E-07,   8.8747464E-07,   7.9773503E-07
     +,   7.1576221E-07,   6.4104415E-07,   5.7307903E-07
     +,   5.1138375E-07,   4.5550027E-07,   4.0498384E-07
     +,   3.5941179E-07,   3.1838658E-07,   2.8153087E-07
     +,   2.4848768E-07,   2.1892198E-07,   1.9252249E-07
     +,   1.6899845E-07,   1.4807833E-07,   1.2951071E-07
     +,   1.1306481E-07,   9.8527764E-08,   8.5703199E-08
     +,   7.4411638E-08,   6.4490308E-08,   5.5789897E-08
     +,   4.8174986E-08,   4.1523652E-08,   3.5725524E-08
     +,   3.0681004E-08,   2.6300592E-08,   2.2504491E-08
     +,   1.9221272E-08,   1.6387125E-08,   1.3945319E-08
     +,   1.1845723E-08,   1.0043952E-08,   8.5007068E-09
     +,   7.1814239E-09,   6.0558607E-09,   5.0974016E-09
     +,   4.2827888E-09,   3.5917957E-09,   3.0068186E-09
     +,   2.5125215E-09,   2.0956414E-09,   1.7447466E-09
     +,   1.4499634E-09,   1.2027889E-09,   9.9592479E-10
     +,   8.2314033E-10,   6.7908790E-10,   5.5922766E-10
     +,   4.5967968E-10,   3.7716635E-10,   3.0889760E-10
     +,   2.5252636E-10,   2.0606454E-10,   1.6784575E-10
     +,   1.3646531E-10,   1.1075006E-10,   8.9716783E-11
     +,   7.2544998E-11,   5.8553343E-11,   4.7173748E-11
     +,   3.7936702E-11,   3.0452519E-11,   2.4400428E-11
     +,   1.9515315E-11,   1.5579900E-11,   1.2415329E-11
     +,   9.8755726E-12,   7.8409883E-12,   6.2142600E-12
     +,   4.9160055E-12,   3.8819187E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz65 = Yx/0.014
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7875067E-05,   1.8552761E-05
     +,   1.9246863E-05,   1.9957464E-05,   2.0684607E-05
     +,   2.1428281E-05,   2.2188420E-05,   2.2964879E-05
     +,   2.3757431E-05,   2.4565799E-05,   2.5389569E-05
     +,   2.6228245E-05,   2.7081216E-05,   2.7947764E-05
     +,   2.8827062E-05,   2.9718154E-05,   3.0619976E-05
     +,   3.1531355E-05,   3.2451015E-05,   3.3377572E-05
     +,   3.4309563E-05,   3.5245466E-05,   3.6183686E-05
     +,   3.7122652E-05,   3.8060691E-05,   3.8996255E-05
     +,   3.9927774E-05,   4.0853785E-05,   4.1772917E-05
     +,   4.2683943E-05,   4.3585806E-05,   4.4477620E-05
     +,   4.5358738E-05,   4.6228775E-05,   4.7087575E-05
     +,   4.7935275E-05,   4.8772352E-05,   4.9599552E-05
     +,   5.0418046E-05,   5.1229257E-05,   5.2035120E-05
     +,   5.2837931E-05,   5.3640484E-05,   5.4446129E-05
     +,   5.5258857E-05,   5.6083380E-05,   5.6925310E-05
     +,   5.7791276E-05,   5.8689158E-05,   5.9628266E-05
     +,   6.0619619E-05,   6.1676146E-05,   6.2812956E-05
     +,   6.4047628E-05,   6.5400163E-05,   6.6893466E-05
     +,   6.8552967E-05,   7.0406735E-05,   7.2485011E-05
     +,   7.4819865E-05,   7.7444405E-05,   8.0392048E-05
     +,   8.3695268E-05,   8.7385044E-05,   9.1489674E-05
     +,   9.6033706E-05,   1.0103844E-04,   1.0652102E-04
     +,   1.1249658E-04,   1.1897845E-04,   1.2598191E-04
     +,   1.3352551E-04,   1.4163603E-04,   1.5034935E-04
     +,   1.5971481E-04,   1.6979543E-04,   1.8066666E-04
     +,   1.9241413E-04,   2.0513004E-04,   2.1890561E-04
     +,   2.3382230E-04,   2.4994725E-04,   2.6732270E-04
     +,   2.8596685E-04,   3.0586930E-04,   3.2700101E-04
     +,   3.4931939E-04,   3.7278901E-04,   3.9739281E-04
     +,   4.2315639E-04,   4.5015928E-04,   4.7854058E-04
     +,   5.0849636E-04,   5.4026162E-04,   5.7407661E-04
     +,   6.1013672E-04,   6.4855011E-04,   6.8927795E-04
     +,   7.3210825E-04,   7.7662984E-04,   8.2225079E-04
     +,   8.6822454E-04,   9.1371284E-04,   9.5783768E-04
     +,   9.9974975E-04,   1.0386652E-03,   1.0738869E-03
     +,   1.1048071E-03,   1.1309005E-03,   1.1517041E-03
     +,   1.1668177E-03,   1.1759187E-03,   1.1787955E-03
     +,   1.1753974E-03,   1.1658854E-03,   1.1506737E-03
     +,   1.1304420E-03,   1.1061213E-03,   1.0788491E-03
     +,   1.0498966E-03,   1.0205905E-03,   9.9224260E-04
     +,   9.6608384E-04,   9.4321824E-04,   9.2459098E-04
     +,   9.1095903E-04,   9.0284931E-04,   9.0051448E-04
     +,   9.0387702E-04,   9.1247907E-04,   9.2546054E-04
     +,   9.4157207E-04,   9.5924560E-04,   9.7670977E-04
     +,   9.9214620E-04,   1.0038541E-03,   1.0103976E-03
     +,   1.0107165E-03,   1.0041754E-03,   9.9055714E-04
     +,   9.7000622E-04,   9.4294624E-04,   9.0998237E-04
     +,   8.7182492E-04,   8.2923518E-04,   7.8299054E-04
     +,   7.3388004E-04,   6.8271346E-04,   6.3032599E-04
     +,   5.7757139E-04,   5.2531174E-04,   4.7439220E-04
     +,   4.2560155E-04,   3.7962844E-04,   3.3703208E-04
     +,   2.9821924E-04,   2.6343137E-04,   2.3274557E-04
     +,   2.0609397E-04,   1.8328990E-04,   1.6405249E-04
     +,   1.4803918E-04,   1.3487469E-04,   1.2417235E-04
     +,   1.1555222E-04,   1.0865498E-04,   1.0315070E-04
     +,   9.8742916E-05,   9.5170835E-05,   9.2209804E-05
     +,   8.9670473E-05,   8.7396736E-05,   8.5263273E-05
     +,   8.3172905E-05,   8.1053870E-05,   7.8856261E-05
     +,   7.6549040E-05,   7.4116972E-05,   7.1557573E-05
     +,   6.8877998E-05,   6.6092682E-05,   6.3221261E-05
     +,   6.0286457E-05,   5.7312245E-05,   5.4322827E-05
     +,   5.1341718E-05,   4.8390913E-05,   4.5490098E-05
     +,   4.2656557E-05,   3.9905270E-05,   3.7248315E-05
     +,   3.4695207E-05,   3.2253211E-05,   2.9927303E-05
     +,   2.7720311E-05,   2.5633282E-05,   2.3665882E-05
     +,   2.1816473E-05,   2.0082283E-05,   1.8459721E-05
     +,   1.6944705E-05,   1.5532711E-05,   1.4218835E-05
     +,   1.2998050E-05,   1.1865407E-05,   1.0815872E-05
     +,   9.8445398E-06,   8.9467230E-06,   8.1179096E-06
     +,   7.3537399E-06,   6.6500697E-06,   6.0030279E-06
     +,   5.4089383E-06,   4.8642919E-06,   4.3657783E-06
     +,   3.9103006E-06,   3.4949253E-06,   3.1168486E-06
     +,   2.7734181E-06,   2.4621522E-06,   2.1806659E-06
     +,   1.9266970E-06,   1.6981224E-06,   1.4929253E-06
     +,   1.3091845E-06,   1.1450879E-06,   9.9893850E-07
     +,   8.6913730E-07,   7.5417739E-07,   6.5265004E-07
     +,   5.6324888E-07,   4.8475931E-07,   4.1605196E-07
     +,   3.5608576E-07,   3.0390962E-07,   2.5864804E-07
     +,   2.1950346E-07,   1.8575375E-07,   1.5674595E-07
     +,   1.3189005E-07,   1.1065674E-07,   9.2575100E-08
     +,   7.7225479E-08,   6.4235095E-08,   5.3275155E-08
     +,   4.4057391E-08,   3.6329190E-08,   2.9869724E-08
     +,   2.4487363E-08,   2.0016678E-08,   1.6314662E-08
     +,   1.3258564E-08,   1.0743591E-08,   8.6803933E-09
     +,   6.9929929E-09,   5.6171525E-09,   4.4988644E-09
     +,   3.5927321E-09,   2.8607461E-09,   2.2712394E-09
     +,   1.7979529E-09,   1.4191508E-09,   1.1168911E-09
     +,   8.7643798E-10,   6.8575134E-10,   5.3498772E-10
     +,   4.1614903E-10,   3.2276373E-10,   2.4960645E-10
     +,   1.9246794E-10,   1.4797488E-10,   1.1343562E-10
     +,   8.6705310E-11,   6.6080502E-11,   5.0214350E-11
     +,   3.8046788E-11,   2.8743188E-11,   2.1651474E-11
     +,   1.6261716E-11,   1.2178137E-11,   9.0933311E-12
     +,   6.7701743E-12,   5.0257853E-12,   3.7200056E-12
     +,   2.7454278E-12,   2.0202783E-12,   1.4823273E-12
     +,   1.0844359E-12,   7.9104204E-13,   5.7533568E-13
     +,   4.1723404E-13,   3.0169172E-13,   2.1751230E-13
     +,   1.5636135E-13,   1.1207577E-13,   8.0097855E-14
     +,   5.7077640E-14,   4.0554240E-14,   2.8730511E-14
     +,   2.0294405E-14,   1.4293776E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz70 = Yx/0.01625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7319182E-06,   1.8988042E-06
     +,   2.0779635E-06,   2.2698671E-06,   2.4749563E-06
     +,   2.6936402E-06,   2.9262828E-06,   3.1732025E-06
     +,   3.4346583E-06,   3.7108596E-06,   4.0019386E-06
     +,   4.3079531E-06,   4.6288837E-06,   4.9646237E-06
     +,   5.3149761E-06,   5.6796425E-06,   6.0582238E-06
     +,   6.4502201E-06,   6.8550175E-06,   7.2718904E-06
     +,   7.7000022E-06,   8.1384051E-06,   8.5860247E-06
     +,   9.0417116E-06,   9.5041514E-06,   9.9719791E-06
     +,   1.0443705E-05,   1.0917749E-05,   1.1392452E-05
     +,   1.1866072E-05,   1.2336819E-05,   1.2802842E-05
     +,   1.3262260E-05,   1.3713166E-05,   1.4153663E-05
     +,   1.4581869E-05,   1.4995951E-05,   1.5394144E-05
     +,   1.5774804E-05,   1.6136395E-05,   1.6477605E-05
     +,   1.6797318E-05,   1.7094722E-05,   1.7369342E-05
     +,   1.7621134E-05,   1.7850547E-05,   1.8058636E-05
     +,   1.8247147E-05,   1.8418647E-05,   1.8576622E-05
     +,   1.8725643E-05,   1.8871453E-05,   1.9021127E-05
     +,   1.9183190E-05,   1.9367693E-05,   1.9586345E-05
     +,   1.9852505E-05,   2.0181207E-05,   2.0589116E-05
     +,   2.1094385E-05,   2.1716474E-05,   2.2475915E-05
     +,   2.3393886E-05,   2.4491934E-05,   2.5791502E-05
     +,   2.7313285E-05,   2.9077069E-05,   3.1100895E-05
     +,   3.3401157E-05,   3.5991787E-05,   3.8884769E-05
     +,   4.2089512E-05,   4.5613790E-05,   4.9463415E-05
     +,   5.3643504E-05,   5.8158999E-05,   6.3015104E-05
     +,   6.8218527E-05,   7.3778872E-05,   7.9709382E-05
     +,   8.6027656E-05,   9.2758433E-05,   9.9933561E-05
     +,   1.0759568E-04,   1.1579831E-04,   1.2460956E-04
     +,   1.3411093E-04,   1.4439877E-04,   1.5557835E-04
     +,   1.6775873E-04,   1.8103962E-04,   1.9549319E-04
     +,   2.1114267E-04,   2.2793912E-04,   2.4573773E-04
     +,   2.6427940E-04,   2.8319267E-04,   3.0200576E-04
     +,   3.2019601E-04,   3.3725737E-04,   3.5280501E-04
     +,   3.6668929E-04,   3.7912297E-04,   3.9078298E-04
     +,   4.0287827E-04,   4.1714768E-04,   4.3577224E-04
     +,   4.6119647E-04,   4.9586355E-04,   5.4188899E-04
     +,   6.0070725E-04,   6.7276938E-04,   7.5729756E-04
     +,   8.5219915E-04,   9.5408817E-04,   1.0585028E-03
     +,   1.1602051E-03,   1.2536600E-03,   1.3335658E-03
     +,   1.3955238E-03,   1.4367180E-03,   1.4565439E-03
     +,   1.4570282E-03,   1.4428345E-03,   1.4207085E-03
     +,   1.3983666E-03,   1.3829613E-03,   1.3794964E-03
     +,   1.3896062E-03,   1.4110847E-03,   1.4383740E-03
     +,   1.4639061E-03,   1.4800004E-03,   1.4807731E-03
     +,   1.4635778E-03,   1.4295481E-03,   1.3831322E-03
     +,   1.3307581E-03,   1.2790231E-03,   1.2329818E-03
     +,   1.1949980E-03,   1.1644617E-03,   1.1383796E-03
     +,   1.1125692E-03,   1.0830160E-03,   1.0469598E-03
     +,   1.0034394E-03,   9.5323951E-04,   8.9836295E-04
     +,   8.4129756E-04,   7.8434352E-04,   7.2918006E-04
     +,   6.7672005E-04,   6.2721613E-04,   5.8051315E-04
     +,   5.3631945E-04,   4.9440248E-04,   4.5467736E-04
     +,   4.1720475E-04,   3.8212587E-04,   3.4956951E-04
     +,   3.1958957E-04,   2.9213383E-04,   2.6704668E-04
     +,   2.4409831E-04,   2.2302955E-04,   2.0359339E-04
     +,   1.8558373E-04,   1.6884985E-04,   1.5329932E-04
     +,   1.3889023E-04,   1.2561500E-04,   1.1348244E-04
     +,   1.0250347E-04,   9.2679540E-05,   8.3992454E-05
     +,   7.6402095E-05,   6.9846676E-05,   6.4245200E-05
     +,   5.9501759E-05,   5.5511817E-05,   5.2167939E-05
     +,   4.9364629E-05,   4.7002392E-05,   4.4991084E-05
     +,   4.3251941E-05,   4.1718286E-05,   4.0335450E-05
     +,   3.9060254E-05,   3.7859962E-05,   3.6710615E-05
     +,   3.5595640E-05,   3.4504465E-05,   3.3431017E-05
     +,   3.2372467E-05,   3.1328247E-05,   3.0299292E-05
     +,   2.9287325E-05,   2.8294306E-05,   2.7322145E-05
     +,   2.6372552E-05,   2.5446843E-05,   2.4545801E-05
     +,   2.3669741E-05,   2.2818631E-05,   2.1991962E-05
     +,   2.1188896E-05,   2.0408424E-05,   1.9649342E-05
     +,   1.8910314E-05,   1.8189969E-05,   1.7487015E-05
     +,   1.6800230E-05,   1.6128466E-05,   1.5470723E-05
     +,   1.4826209E-05,   1.4194305E-05,   1.3574533E-05
     +,   1.2966591E-05,   1.2370402E-05,   1.1785984E-05
     +,   1.1213488E-05,   1.0653219E-05,   1.0105573E-05
     +,   9.5709793E-06,   9.0499198E-06,   8.5429338E-06
     +,   8.0505706E-06,   7.5733305E-06,   7.1116920E-06
     +,   6.6661214E-06,   6.2370295E-06,   5.8247347E-06
     +,   5.4294906E-06,   5.0515109E-06,   4.6908917E-06
     +,   4.3476548E-06,   4.0217637E-06,   3.7131042E-06
     +,   3.4214661E-06,   3.1465743E-06,   2.8881041E-06
     +,   2.6456730E-06,   2.4188287E-06,   2.2070733E-06
     +,   2.0098846E-06,   1.8267066E-06,   1.6569422E-06
     +,   1.4999782E-06,   1.3552011E-06,   1.2219735E-06
     +,   1.0996571E-06,   9.8762325E-07,   8.8524871E-07
     +,   7.9191295E-07,   7.0701054E-07,   6.2995906E-07
     +,   5.6019348E-07,   4.9716607E-07,   4.4035275E-07
     +,   3.8925796E-07,   3.4341045E-07,   3.0236191E-07
     +,   2.6569060E-07,   2.3300458E-07,   2.0393432E-07
     +,   1.7813595E-07,   1.5529245E-07,   1.3511018E-07
     +,   1.1731766E-07,   1.0166561E-07,   8.7926956E-08
     +,   7.5894334E-08,   6.5378373E-08,   5.6207480E-08
     +,   4.8227356E-08,   4.1297909E-08,   3.5294100E-08
     +,   3.0103116E-08,   2.5624791E-08,   2.1769274E-08
     +,   1.8457275E-08,   1.5618028E-08,   1.3189379E-08
     +,   1.1116230E-08,   9.3504049E-09,   7.8494793E-09
     +,   6.5763599E-09,   5.4988334E-09,   4.5887107E-09
     +,   3.8216434E-09,   3.1764675E-09,   2.6349893E-09
     +,   2.1814621E-09,   1.8024228E-09,   1.4862792E-09
     +,   1.2231632E-09,   1.0046211E-09,   8.2349549E-10
     +,   6.7368000E-10,   5.5003091E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz75 = Yx/0.016
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.2269822E-06,   7.7480863E-06
     +,   8.2953420E-06,   8.8691277E-06,   9.4697516E-06
     +,   1.0097452E-05,   1.0752395E-05,   1.1434665E-05
     +,   1.2144262E-05,   1.2881133E-05,   1.3645112E-05
     +,   1.4435959E-05,   1.5253353E-05,   1.6096888E-05
     +,   1.6966078E-05,   1.7860366E-05,   1.8779108E-05
     +,   1.9721594E-05,   2.0687052E-05,   2.1674636E-05
     +,   2.2683456E-05,   2.3712553E-05,   2.4760924E-05
     +,   2.5827578E-05,   2.6911381E-05,   2.8011276E-05
     +,   2.9126128E-05,   3.0254781E-05,   3.1396077E-05
     +,   3.2548833E-05,   3.3711844E-05,   3.4883906E-05
     +,   3.6063782E-05,   3.7250218E-05,   3.8441933E-05
     +,   3.9637605E-05,   4.0835897E-05,   4.2035357E-05
     +,   4.3234591E-05,   4.4431956E-05,   4.5625871E-05
     +,   4.6814577E-05,   4.7996233E-05,   4.9168837E-05
     +,   5.0330280E-05,   5.1478273E-05,   5.2610427E-05
     +,   5.3724139E-05,   5.4816694E-05,   5.5885212E-05
     +,   5.6926685E-05,   5.7937974E-05,   5.8915870E-05
     +,   5.9857150E-05,   6.0758481E-05,   6.1616673E-05
     +,   6.2428604E-05,   6.3191321E-05,   6.3902131E-05
     +,   6.4558684E-05,   6.5159104E-05,   6.5702028E-05
     +,   6.6186731E-05,   6.6613306E-05,   6.6982713E-05
     +,   6.7296882E-05,   6.7558889E-05,   6.7772991E-05
     +,   6.7944799E-05,   6.8081295E-05,   6.8190900E-05
     +,   6.8283618E-05,   6.8370900E-05,   6.8465764E-05
     +,   6.8582704E-05,   6.8737609E-05,   6.8947687E-05
     +,   6.9231239E-05,   6.9607515E-05,   7.0096430E-05
     +,   7.0718284E-05,   7.1493443E-05,   7.2441835E-05
     +,   7.3582756E-05,   7.4934134E-05,   7.6512384E-05
     +,   7.8331548E-05,   8.0403217E-05,   8.2735598E-05
     +,   8.5333544E-05,   8.8197972E-05,   9.1325281E-05
     +,   9.4707291E-05,   9.8331264E-05,   1.0217963E-04
     +,   1.0622952E-04,   1.1045386E-04,   1.1482031E-04
     +,   1.1929277E-04,   1.2383038E-04,   1.2838919E-04
     +,   1.3292109E-04,   1.3737568E-04,   1.4169932E-04
     +,   1.4583659E-04,   1.4973037E-04,   1.5332203E-04
     +,   1.5655237E-04,   1.5936258E-04,   1.6169484E-04
     +,   1.6349337E-04,   1.6470626E-04,   1.6528733E-04
     +,   1.6519861E-04,   1.6441345E-04,   1.6292106E-04
     +,   1.6073177E-04,   1.5788403E-04,   1.5445387E-04
     +,   1.5056583E-04,   1.4640753E-04,   1.4224745E-04
     +,   1.3845520E-04,   1.3552488E-04,   1.3410090E-04
     +,   1.3500405E-04,   1.3925403E-04,   1.4808455E-04
     +,   1.6294625E-04,   1.8548389E-04,   2.1749081E-04
     +,   2.6081572E-04,   3.1724409E-04,   3.8832065E-04
     +,   4.7516762E-04,   5.7827530E-04,   6.9730054E-04
     +,   8.3091186E-04,   9.7669987E-04,   1.1311400E-03
     +,   1.2896330E-03,   1.4466527E-03,   1.5959927E-03
     +,   1.7311022E-03,   1.8455473E-03,   1.9336427E-03
     +,   1.9911285E-03,   2.0158677E-03,   2.0084181E-03
     +,   1.9722856E-03,   1.9137183E-03,   1.8409909E-03
     +,   1.7632204E-03,   1.6889112E-03,   1.6245377E-03
     +,   1.5734861E-03,   1.5355814E-03,   1.5073345E-03
     +,   1.4828356E-03,   1.4550755E-03,   1.4173816E-03
     +,   1.3646777E-03,   1.2943186E-03,   1.2063892E-03
     +,   1.1034728E-03,   9.9002849E-04,   8.7155163E-04
     +,   7.5368618E-04,   6.4146426E-04,   5.3879083E-04
     +,   4.4819838E-04,   3.7083169E-04,   3.0663141E-04
     +,   2.5464047E-04,   2.1334436E-04,   1.8097302E-04
     +,   1.5575519E-04,   1.3608696E-04,   1.2061908E-04
     +,   1.0828353E-04,   9.8277829E-05,   9.0024128E-05
     +,   8.3118081E-05,   7.7280369E-05,   7.2316558E-05
     +,   6.8085996E-05,   6.4479704E-05,   6.1406136E-05
     +,   5.8783397E-05,   5.6535762E-05,   5.4591808E-05
     +,   5.2885080E-05,   5.1355204E-05,   4.9948881E-05
     +,   4.8620674E-05,   4.7333619E-05,   4.6059326E-05
     +,   4.4777466E-05,   4.3474924E-05,   4.2144839E-05
     +,   4.0785580E-05,   3.9399525E-05,   3.7991820E-05
     +,   3.6569509E-05,   3.5140831E-05,   3.3714241E-05
     +,   3.2298027E-05,   3.0900006E-05,   2.9527173E-05
     +,   2.8185425E-05,   2.6879597E-05,   2.5613535E-05
     +,   2.4390029E-05,   2.3210821E-05,   2.2076787E-05
     +,   2.0988129E-05,   1.9944404E-05,   1.8944598E-05
     +,   1.7987313E-05,   1.7070961E-05,   1.6193684E-05
     +,   1.5353544E-05,   1.4548639E-05,   1.3777111E-05
     +,   1.3037146E-05,   1.2327061E-05,   1.1645369E-05
     +,   1.0990747E-05,   1.0361990E-05,   9.7580614E-06
     +,   9.1781139E-06,   8.6214368E-06,   8.0873988E-06
     +,   7.5754792E-06,   7.0852784E-06,   6.6164130E-06
     +,   6.1685428E-06,   5.7413813E-06,   5.3346484E-06
     +,   4.9480350E-06,   4.5812149E-06,   4.2338679E-06
     +,   3.9056376E-06,   3.5961114E-06,   3.3048418E-06
     +,   3.0313620E-06,   2.7751685E-06,   2.5357028E-06
     +,   2.3123753E-06,   2.1045932E-06,   1.9117131E-06
     +,   1.7330769E-06,   1.5680223E-06,   1.4158773E-06
     +,   1.2759525E-06,   1.1475620E-06,   1.0300324E-06
     +,   9.2269732E-07,   8.2489561E-07,   7.3598284E-07
     +,   6.5533982E-07,   5.8236702E-07,   5.1648357E-07
     +,   4.5713409E-07,   4.0379533E-07,   3.5596531E-07
     +,   3.1317080E-07,   2.7496836E-07,   2.4094334E-07
     +,   2.1070512E-07,   1.8389163E-07,   1.6016843E-07
     +,   1.3922651E-07,   1.2078007E-07,   1.0456699E-07
     +,   9.0349204E-08,   7.7907629E-08,   6.7044930E-08
     +,   5.7580809E-08,   4.9353737E-08,   4.2217078E-08
     +,   3.6040149E-08,   3.0705127E-08,   2.6107507E-08
     +,   2.2153690E-08,   1.8761039E-08,   1.5856084E-08
     +,   1.3373985E-08,   1.1257858E-08,   9.4575103E-09
     +,   7.9291800E-09,   6.6344570E-09,   5.5400404E-09
     +,   4.6168549E-09,   3.8398174E-09,   3.1871294E-09
     +,   2.6400973E-09,   2.1825561E-09,   1.8007023E-09
     +,   1.4826661E-09,   1.2183627E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz80 = Yx/0.015037037037037
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5862829E-07,   8.5676601E-07
     +,   9.6554209E-07,   1.0858190E-06,   1.2184930E-06
     +,   1.3644882E-06,   1.5247541E-06,   1.7002604E-06
     +,   1.8919867E-06,   2.1009307E-06,   2.3280832E-06
     +,   2.5744284E-06,   2.8409361E-06,   3.1285547E-06
     +,   3.4381965E-06,   3.7707307E-06,   4.1269755E-06
     +,   4.5076840E-06,   4.9135338E-06,   5.3451222E-06
     +,   5.8029450E-06,   6.2874010E-06,   6.7987598E-06
     +,   7.3372044E-06,   7.9027232E-06,   8.4952326E-06
     +,   9.1144620E-06,   9.7600077E-06,   1.0431299E-05
     +,   1.1127620E-05,   1.1848091E-05,   1.2591682E-05
     +,   1.3357203E-05,   1.4143316E-05,   1.4948537E-05
     +,   1.5771247E-05,   1.6609702E-05,   1.7462016E-05
     +,   1.8326271E-05,   1.9200335E-05,   2.0082118E-05
     +,   2.0969410E-05,   2.1859954E-05,   2.2751487E-05
     +,   2.3641718E-05,   2.4528370E-05,   2.5409199E-05
     +,   2.6281998E-05,   2.7144622E-05,   2.7995002E-05
     +,   2.8831166E-05,   2.9651255E-05,   3.0453511E-05
     +,   3.1236377E-05,   3.1998326E-05,   3.2738102E-05
     +,   3.3454548E-05,   3.4146677E-05,   3.4813693E-05
     +,   3.5454952E-05,   3.6069992E-05,   3.6658515E-05
     +,   3.7220372E-05,   3.7755588E-05,   3.8264348E-05
     +,   3.8746934E-05,   3.9203809E-05,   3.9635488E-05
     +,   4.0042669E-05,   4.0426068E-05,   4.0786545E-05
     +,   4.1124986E-05,   4.1442396E-05,   4.1739797E-05
     +,   4.2018277E-05,   4.2279011E-05,   4.2523207E-05
     +,   4.2752163E-05,   4.2967269E-05,   4.3170061E-05
     +,   4.3362168E-05,   4.3545453E-05,   4.3721964E-05
     +,   4.3894062E-05,   4.4064382E-05,   4.4236003E-05
     +,   4.4412409E-05,   4.4597600E-05,   4.4796139E-05
     +,   4.5013203E-05,   4.5254645E-05,   4.5526973E-05
     +,   4.5837402E-05,   4.6193847E-05,   4.6604870E-05
     +,   4.7079560E-05,   4.7627505E-05,   4.8258527E-05
     +,   4.8982609E-05,   4.9809474E-05,   5.0748473E-05
     +,   5.1808041E-05,   5.2995489E-05,   5.4316366E-05
     +,   5.5774250E-05,   5.7370158E-05,   5.9102029E-05
     +,   6.0964336E-05,   6.2947882E-05,   6.5039385E-05
     +,   6.7221066E-05,   6.9471091E-05,   7.1763105E-05
     +,   7.4067138E-05,   7.6349643E-05,   7.8574893E-05
     +,   8.0705708E-05,   8.2705650E-05,   8.4540785E-05
     +,   8.6182808E-05,   8.7612418E-05,   8.8823348E-05
     +,   8.9827350E-05,   9.0659494E-05,   9.1383627E-05
     +,   9.2097558E-05,   9.2937589E-05,   9.4081101E-05
     +,   9.5747557E-05,   9.8196659E-05,   1.0172572E-04
     +,   1.0666584E-04,   1.1338259E-04,   1.2228041E-04
     +,   1.3381889E-04,   1.4853595E-04,   1.6707397E-04
     +,   1.9019759E-04,   2.1878253E-04,   2.5374821E-04
     +,   2.9591669E-04,   3.4580918E-04,   4.0341466E-04
     +,   4.6799774E-04,   5.3803995E-04,   6.1141863E-04
     +,   6.8580441E-04,   7.5922487E-04,   8.3065516E-04
     +,   9.0045755E-04,   9.7055838E-04,   1.0443775E-03
     +,   1.1265986E-03,   1.2228182E-03,   1.3389806E-03
     +,   1.4804242E-03,   1.6504489E-03,   1.8485792E-03
     +,   2.0689797E-03,   2.2996706E-03,   2.5230746E-03
     +,   2.7178312E-03,   2.8616560E-03,   2.9347853E-03
     +,   2.9234346E-03,   2.8226427E-03,   2.6378795E-03
     +,   2.3847083E-03,   2.0862671E-03,   1.7691032E-03
     +,   1.4584556E-03,   1.1742681E-03,   9.2897698E-04
     +,   7.2738319E-04,   5.6811451E-04,   4.4580654E-04
     +,   3.5333569E-04,   2.8350559E-04,   2.3005226E-04
     +,   1.8807244E-04,   1.5405743E-04,   1.2570046E-04
     +,   1.0160710E-04,   8.0998987E-05,   6.3458807E-05
     +,   4.8737555E-05,   3.6628386E-05,   2.6902422E-05
     +,   1.9291256E-05,   1.3495655E-05,   9.2041919E-06
     +,   6.1157016E-06,   3.9564761E-06,   2.4906885E-06
     +,   1.5248578E-06,   9.0742361E-07,   5.2465651E-07
     +,   2.9462507E-07,   1.6064128E-07,   8.5022656E-08
     +,   4.3677645E-08,   2.1779194E-08,   1.0542667E-08
     +,   4.9564948E-09,   2.2654452E-09,   1.0085407E-09
     +,   4.3888859E-10,   1.8798668E-10,   8.0263463E-11
     +,   3.4913263E-11,   1.5985399E-11,   7.9953839E-12
     +,   4.4717628E-12,   2.7799874E-12,   1.8668584E-12
     +,   1.3121844E-12,   9.4363428E-13,   6.8518119E-13
     +,   4.9896795E-13,   3.6326985E-13,   2.6402627E-13
     +,   1.9144904E-13,   1.3846385E-13,   9.9874576E-14
     +,   7.1843078E-14,   5.1536514E-14,   3.6867709E-14
     +,   2.6301505E-14,   1.8711717E-14,   1.3275125E-14
     +,   9.3920826E-15,   6.6265336E-15,   4.6623823E-15
     +,   3.2712999E-15,   2.2889401E-15,   1.5971507E-15
     +,   1.1113411E-15,   7.7116325E-16,   5.3363722E-16
     +,   3.6824985E-16,   2.5341368E-16,   1.7390625E-16
     +,   1.1901497E-16,   8.1224140E-17,   5.5278988E-17
     +,   3.7517465E-17,   2.5392686E-17,   1.7138881E-17
     +,   1.1535800E-17,   7.7431393E-18,   5.1830256E-18
     +,   3.4597454E-18,   2.3030536E-18,   1.5288616E-18
     +,   1.0121162E-18,   6.6817199E-19,   4.3989072E-19
     +,   2.8880755E-19,   1.8909207E-19,   1.2346210E-19
     +,   8.0388675E-20,   5.2199233E-20,   3.3801443E-20
     +,   2.1827490E-20,   1.4056650E-20,   9.0274106E-21
     +,   5.7815397E-21,   3.6925807E-21,   2.3519427E-21
     +,   1.4939325E-21,   9.4631370E-22,   5.9778940E-22
     +,   3.7659631E-22,   2.3659981E-22,   1.4823676E-22
     +,   9.2621781E-23,   5.7713695E-23,   3.5864412E-23
     +,   2.2225799E-23,   1.3736392E-23,   8.4663463E-24
     +,   5.2041111E-24,   3.1901359E-24,   1.9502809E-24
     +,   1.1890595E-24,   7.2300256E-25,   4.3843080E-25
     +,   2.6514537E-25,   1.5991984E-25,   9.6193292E-26
     +,   5.7706944E-26,   3.4525477E-26,   2.0601403E-26
     +,   1.2259862E-26,   7.2765647E-27,   4.3072915E-27
     +,   2.5429528E-27,   1.4973284E-27,   8.7934283E-28
     +,   5.1504957E-28,   3.0089116E-28
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz85 = Yx/0.014
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8192887E-11,   3.9564966E-11
     +,   5.5296077E-11,   7.6964532E-11,   1.0668488E-10
     +,   1.4727607E-10,   2.0247989E-10,   2.7723798E-10
     +,   3.7804737E-10,   5.1341442E-10,   6.9441564E-10
     +,   9.3541264E-10,   1.2549380E-09,   1.6767957E-09
     +,   2.2314104E-09,   2.9574945E-09,   3.9040642E-09
     +,   5.1329034E-09,   6.7214949E-09,   8.7665573E-09
     +,   1.1388267E-08,   1.4735194E-08,   1.8990061E-08
     +,   2.4376948E-08,   3.1168291E-08,   3.9695152E-08
     +,   5.0356565E-08,   6.3631866E-08,   8.0093685E-08
     +,   1.0042291E-07,   1.2542486E-07,   1.5604739E-07
     +,   1.9340047E-07,   2.3877689E-07,   2.9367465E-07
     +,   3.5982058E-07,   4.3919417E-07,   5.3405108E-07
     +,   6.4695490E-07,   7.8078335E-07,   9.3877514E-07
     +,   1.1245298E-06,   1.3420342E-06,   1.5956740E-06
     +,   1.8902416E-06,   2.2309346E-06,   2.6233531E-06
     +,   3.0734807E-06,   3.5876590E-06,   4.1725498E-06
     +,   4.8350803E-06,   5.5823843E-06,   6.4217015E-06
     +,   7.3603519E-06,   8.4054736E-06,   9.5640880E-06
     +,   1.0842803E-05,   1.2247726E-05,   1.3784279E-05
     +,   1.5457017E-05,   1.7269447E-05,   1.9223868E-05
     +,   2.1320999E-05,   2.3560118E-05,   2.5938722E-05
     +,   2.8452117E-05,   3.1093838E-05,   3.3854893E-05
     +,   3.6724370E-05,   3.9688668E-05,   4.2732278E-05
     +,   4.5837045E-05,   4.8983085E-05,   5.2148127E-05
     +,   5.5308439E-05,   5.8438782E-05,   6.1512546E-05
     +,   6.4502274E-05,   6.7380301E-05,   7.0118935E-05
     +,   7.2690680E-05,   7.5069271E-05,   7.7229546E-05
     +,   7.9148391E-05,   8.0804770E-05,   8.2180435E-05
     +,   8.3260005E-05,   8.4031533E-05,   8.4486433E-05
     +,   8.4619955E-05,   8.4431027E-05,   8.3922358E-05
     +,   8.3100465E-05,   8.1975362E-05,   8.0560392E-05
     +,   7.8872145E-05,   7.6929791E-05,   7.4755095E-05
     +,   7.2371578E-05,   6.9804562E-05,   6.7080167E-05
     +,   6.4225496E-05,   6.1267514E-05,   5.8233309E-05
     +,   5.5149114E-05,   5.2040152E-05,   4.8930575E-05
     +,   4.5842982E-05,   4.2797976E-05,   3.9814226E-05
     +,   3.6908605E-05,   3.4095461E-05,   3.1387350E-05
     +,   2.8794315E-05,   2.6324647E-05,   2.3984332E-05
     +,   2.1777807E-05,   1.9707548E-05,   1.7774848E-05
     +,   1.5979602E-05,   1.4320824E-05,   1.2797136E-05
     +,   1.1407058E-05,   1.0149474E-05,   9.0243684E-06
     +,   8.0336349E-06,   7.1816548E-06,   6.4764290E-06
     +,   5.9302447E-06,   5.5606761E-06,   5.3910680E-06
     +,   5.4509028E-06,   5.7755319E-06,   6.4052178E-06
     +,   7.3834208E-06,   8.7541521E-06,   1.0558314E-05
     +,   1.2829590E-05,   1.5590360E-05,   1.8848021E-05
     +,   2.2592891E-05,   2.6799589E-05,   3.1433341E-05
     +,   3.6462126E-05,   4.1876334E-05,   4.7719121E-05
     +,   5.4125358E-05,   6.1370323E-05,   6.9927504E-05
     +,   8.0531077E-05,   9.4233190E-05,   1.1244153E-04
     +,   1.3691642E-04,   1.6970022E-04,   2.1294826E-04
     +,   2.6864669E-04,   3.3824041E-04,   4.2223418E-04
     +,   5.1986903E-04,   6.2903296E-04,   7.4660592E-04
     +,   8.6927810E-04,   9.9478837E-04,   1.1232753E-03
     +,   1.2581260E-03,   1.4056242E-03,   1.5729473E-03
     +,   1.7647279E-03,   1.9792230E-03,   2.2057309E-03
     +,   2.4248031E-03,   2.6118127E-03,   2.7428092E-03
     +,   2.8004458E-03,   2.7777979E-03,   2.6788851E-03
     +,   2.5162597E-03,   2.3072287E-03,   2.0702526E-03
     +,   1.8224760E-03,   1.5784837E-03,   1.3497849E-03
     +,   1.1445322E-03,   9.6734584E-04,   8.1937877E-04
     +,   6.9875026E-04,   6.0138077E-04,   5.2211114E-04
     +,   4.5584067E-04,   3.9839433E-04,   3.4695413E-04
     +,   3.0007630E-04,   2.5738816E-04,   2.1913442E-04
     +,   1.8574219E-04,   1.5751166E-04,   1.3446124E-04
     +,   1.1630129E-04,   1.0249783E-04,   9.2372939E-05
     +,   8.5201980E-05,   8.0287537E-05,   7.7006342E-05
     +,   7.4832511E-05,   7.3342679E-05,   7.2209914E-05
     +,   7.1192677E-05,   7.0121379E-05,   6.8884860E-05
     +,   6.7417801E-05,   6.5689717E-05,   6.3695981E-05
     +,   6.1450199E-05,   5.8978192E-05,   5.6313522E-05
     +,   5.3494274E-05,   5.0560382E-05,   4.7551410E-05
     +,   4.4505414E-05,   4.1458210E-05,   3.8442038E-05
     +,   3.5485431E-05,   3.2613130E-05,   2.9845787E-05
     +,   2.7199845E-05,   2.4687899E-05,   2.2319116E-05
     +,   2.0099345E-05,   1.8031371E-05,   1.6115448E-05
     +,   1.4349801E-05,   1.2730850E-05,   1.1253485E-05
     +,   9.9114986E-06,   8.6979999E-06,   7.6054089E-06
     +,   6.6258222E-06,   5.7512466E-06,   4.9736686E-06
     +,   4.2851439E-06,   3.6779495E-06,   3.1446957E-06
     +,   2.6783280E-06,   2.2721415E-06,   1.9198476E-06
     +,   1.6156097E-06,   1.3540133E-06,   1.1300569E-06
     +,   9.3916896E-07,   7.7720665E-07,   6.4040682E-07
     +,   5.2538752E-07,   4.2913393E-07,   3.4896476E-07
     +,   2.8250608E-07,   2.2767456E-07,   1.8265517E-07
     +,   1.4587201E-07,   1.1596340E-07,   9.1762800E-08
     +,   7.2277601E-08,   5.6666753E-08,   4.4221267E-08
     +,   3.4348123E-08,   2.6554945E-08,   2.0433900E-08
     +,   1.5649945E-08,   1.1929722E-08,   9.0511794E-09
     +,   6.8348878E-09,   5.1369162E-09,   3.8425614E-09
     +,   2.8608131E-09,   2.1198365E-09,   1.5633458E-09
     +,   1.1475050E-09,   8.3828633E-10,   6.0950206E-10
     +,   4.4105747E-10,   3.1765796E-10,   2.2769857E-10
     +,   1.6244459E-10,   1.1534140E-10,   8.1509757E-11
     +,   5.7328194E-11,   4.0130173E-11,   2.7958488E-11
     +,   1.9386054E-11,   1.3378575E-11,   9.1889057E-12
     +,   6.2814736E-12,   4.2735915E-12,   2.8938065E-12
     +,   1.9501969E-12,   1.3080741E-12,   8.7321003E-13
     +,   5.8016293E-13,   3.8363103E-13,   2.5247778E-13
     +,   1.6537283E-13,   1.0780798E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz90 = Yx/0.0134615384615385
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_haonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8484137E-05,   1.8839948E-05
     +,   1.9190287E-05,   1.9534671E-05,   1.9872610E-05
     +,   2.0203639E-05,   2.0527297E-05,   2.0843139E-05
     +,   2.1150738E-05,   2.1449690E-05,   2.1739601E-05
     +,   2.2020113E-05,   2.2290877E-05,   2.2551580E-05
     +,   2.2801934E-05,   2.3041686E-05,   2.3270610E-05
     +,   2.3488521E-05,   2.3695266E-05,   2.3890731E-05
     +,   2.4074840E-05,   2.4247562E-05,   2.4408911E-05
     +,   2.4558954E-05,   2.4697782E-05,   2.4825562E-05
     +,   2.4942497E-05,   2.5048845E-05,   2.5144916E-05
     +,   2.5231067E-05,   2.5307729E-05,   2.5375361E-05
     +,   2.5434507E-05,   2.5485742E-05,   2.5529715E-05
     +,   2.5567111E-05,   2.5598694E-05,   2.5625266E-05
     +,   2.5647683E-05,   2.5666855E-05,   2.5683747E-05
     +,   2.5699355E-05,   2.5714744E-05,   2.5731002E-05
     +,   2.5749254E-05,   2.5770676E-05,   2.5796462E-05
     +,   2.5827829E-05,   2.5866031E-05,   2.5912324E-05
     +,   2.5967978E-05,   2.6034275E-05,   2.6112481E-05
     +,   2.6203865E-05,   2.6309677E-05,   2.6431146E-05
     +,   2.6569471E-05,   2.6725816E-05,   2.6901293E-05
     +,   2.7096972E-05,   2.7313861E-05,   2.7552904E-05
     +,   2.7814949E-05,   2.8100798E-05,   2.8411150E-05
     +,   2.8746585E-05,   2.9107638E-05,   2.9494662E-05
     +,   2.9907975E-05,   3.0347706E-05,   3.0813928E-05
     +,   3.1306532E-05,   3.1825337E-05,   3.2369964E-05
     +,   3.2939959E-05,   3.3534739E-05,   3.4153545E-05
     +,   3.4795488E-05,   3.5459594E-05,   3.6144756E-05
     +,   3.6849702E-05,   3.7573103E-05,   3.8313447E-05
     +,   3.9069211E-05,   3.9838680E-05,   4.0620165E-05
     +,   4.1411782E-05,   4.2211730E-05,   4.3018019E-05
     +,   4.3828732E-05,   4.4641951E-05,   4.5455719E-05
     +,   4.6268087E-05,   4.7077257E-05,   4.7881491E-05
     +,   4.8679103E-05,   4.9468650E-05,   5.0248760E-05
     +,   5.1018385E-05,   5.1776631E-05,   5.2522970E-05
     +,   5.3257096E-05,   5.3979169E-05,   5.4689630E-05
     +,   5.5389402E-05,   5.6079865E-05,   5.6762805E-05
     +,   5.7440498E-05,   5.8115736E-05,   5.8791786E-05
     +,   5.9472328E-05,   6.0161510E-05,   6.0863829E-05
     +,   6.1584149E-05,   6.2327483E-05,   6.3099040E-05
     +,   6.3903979E-05,   6.4747401E-05,   6.5634020E-05
     +,   6.6568165E-05,   6.7553519E-05,   6.8592824E-05
     +,   6.9687834E-05,   7.0839051E-05,   7.2045586E-05
     +,   7.3304785E-05,   7.4612377E-05,   7.5961980E-05
     +,   7.7345394E-05,   7.8752149E-05,   8.0169899E-05
     +,   8.1584047E-05,   8.2978288E-05,   8.4334366E-05
     +,   8.5632659E-05,   8.6852291E-05,   8.7971486E-05
     +,   8.8968016E-05,   8.9819783E-05,   9.0505244E-05
     +,   9.1004047E-05,   9.1297661E-05,   9.1370246E-05
     +,   9.1209266E-05,   9.0806643E-05,   9.0159701E-05
     +,   8.9272478E-05,   8.8157263E-05,   8.6836313E-05
     +,   8.5343891E-05,   8.3728686E-05,   8.2056657E-05
     +,   8.0414007E-05,   7.8910416E-05,   7.7682838E-05
     +,   7.6899181E-05,   7.6762211E-05,   7.7513156E-05
     +,   7.9435675E-05,   8.2859129E-05,   8.8161803E-05
     +,   9.5773546E-05,   1.0617626E-04,   1.1990340E-04
     +,   1.3753772E-04,   1.5970397E-04,   1.8705470E-04
     +,   2.2025249E-04,   2.5994561E-04,   3.0673278E-04
     +,   3.6111614E-04,   4.2345218E-04,   4.9390038E-04
     +,   5.7236105E-04,   6.5840856E-04,   7.5125595E-04
     +,   8.4970909E-04,   9.5214049E-04,   1.0564992E-03
     +,   1.1603560E-03,   1.2609647E-03,   1.3553631E-03
     +,   1.4405155E-03,   1.5134865E-03,   1.5716103E-03
     +,   1.6126719E-03,   1.6350766E-03,   1.6379815E-03
     +,   1.6213720E-03,   1.5860843E-03,   1.5337553E-03
     +,   1.4667070E-03,   1.3877852E-03,   1.3001502E-03
     +,   1.2070466E-03,   1.1115881E-03,   1.0165792E-03
     +,   9.2436030E-04,   8.3671260E-04,   7.5483654E-04
     +,   6.7938055E-04,   6.1050616E-04,   5.4798642E-04
     +,   4.9132976E-04,   4.3990201E-04,   3.9302217E-04
     +,   3.5005197E-04,   3.1045504E-04,   2.7382356E-04
     +,   2.3988080E-04,   2.0846992E-04,   1.7952797E-04
     +,   1.5305035E-04,   1.2905548E-04,   1.0755770E-04
     +,   8.8546214E-05,   7.1969822E-05,   5.7730551E-05
     +,   4.5686887E-05,   3.5661709E-05,   2.7450118E-05
     +,   2.0832504E-05,   1.5586163E-05,   1.1494652E-05
     +,   8.3554278E-06,   5.9857925E-06,   4.2260358E-06
     +,   2.9402624E-06,   2.0158420E-06,   1.3618269E-06
     +,   9.0651019E-07,   5.9456863E-07,   3.8423144E-07
     +,   2.4464035E-07,   1.5346592E-07,   9.4848716E-08
     +,   5.7753009E-08,   3.4645442E-08,   2.0476492E-08
     +,   1.1923493E-08,   6.8406560E-09,   3.8670045E-09
     +,   2.1542259E-09,   1.1828186E-09,   6.4028827E-10
     +,   3.4188533E-10,   1.8020963E-10,   9.3887051E-11
     +,   4.8444120E-11,   2.4838900E-11,   1.2721504E-11
     +,   6.5604831E-12,   3.4464432E-12,   1.8724347E-12
     +,   1.0694756E-12,   6.5062907E-13,   4.2349116E-13
     +,   2.9321226E-13,   2.1321189E-13,   1.6052593E-13
     +,   1.2364502E-13,   9.6602698E-14,   7.6134696E-14
     +,   6.0326879E-14,   4.7967652E-14,   3.8231808E-14
     +,   3.0526549E-14,   2.4409834E-14,   1.9543601E-14
     +,   1.5665264E-14,   1.2569650E-14,   1.0095537E-14
     +,   8.1157564E-15,   6.5296067E-15,   5.2574077E-15
     +,   4.2360046E-15,   3.4151070E-15,   2.7548044E-15
     +,   2.2231959E-15,   1.7949011E-15,   1.4495834E-15
     +,   1.1710135E-15,   9.4615179E-16,   7.6457461E-16
     +,   6.1788211E-16,   4.9934255E-16,   4.0352679E-16
     +,   3.2606118E-16,   2.6342897E-16,   2.1278385E-16
     +,   1.7183543E-16,   1.3872626E-16,   1.1196059E-16
     +,   9.0325906E-17,   7.2843219E-17,   5.8718567E-17
     +,   4.7311082E-17,   3.8100925E-17,   3.0668029E-17
     +,   2.4671557E-17,   1.9836491E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_haonly_ttz95 = Yx/0.01148
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6496678E-04,   1.7197509E-04
     +,   1.7910352E-04,   1.8633700E-04,   1.9365904E-04
     +,   2.0105223E-04,   2.0849748E-04,   2.1597471E-04
     +,   2.2346285E-04,   2.3094006E-04,   2.3838338E-04
     +,   2.4576948E-04,   2.5307451E-04,   2.6027442E-04
     +,   2.6734499E-04,   2.7426216E-04,   2.8100243E-04
     +,   2.8754238E-04,   2.9385995E-04,   2.9993345E-04
     +,   3.0574296E-04,   3.1126960E-04,   3.1649607E-04
     +,   3.2140719E-04,   3.2598944E-04,   3.3023139E-04
     +,   3.3412402E-04,   3.3766057E-04,   3.4083688E-04
     +,   3.4365116E-04,   3.4610447E-04,   3.4820018E-04
     +,   3.4994501E-04,   3.5134726E-04,   3.5241878E-04
     +,   3.5317379E-04,   3.5362894E-04,   3.5380357E-04
     +,   3.5371893E-04,   3.5339899E-04,   3.5286960E-04
     +,   3.5215856E-04,   3.5129589E-04,   3.5031314E-04
     +,   3.4924306E-04,   3.4812046E-04,   3.4698084E-04
     +,   3.4586104E-04,   3.4479838E-04,   3.4383137E-04
     +,   3.4299871E-04,   3.4233954E-04,   3.4189285E-04
     +,   3.4169716E-04,   3.4179122E-04,   3.4221259E-04
     +,   3.4299810E-04,   3.4418327E-04,   3.4580156E-04
     +,   3.4788539E-04,   3.5046425E-04,   3.5356512E-04
     +,   3.5721221E-04,   3.6142615E-04,   3.6622392E-04
     +,   3.7161828E-04,   3.7761783E-04,   3.8422577E-04
     +,   3.9144096E-04,   3.9925592E-04,   4.0765855E-04
     +,   4.1662983E-04,   4.2614609E-04,   4.3617631E-04
     +,   4.4668440E-04,   4.5762866E-04,   4.6896079E-04
     +,   4.8062770E-04,   4.9257150E-04,   5.0472998E-04
     +,   5.1703601E-04,   5.2942074E-04,   5.4181117E-04
     +,   5.5413414E-04,   5.6631351E-04,   5.7827547E-04
     +,   5.8994425E-04,   6.0124829E-04,   6.1211636E-04
     +,   6.2248221E-04,   6.3228264E-04,   6.4145925E-04
     +,   6.4995920E-04,   6.5773574E-04,   6.6474825E-04
     +,   6.7096303E-04,   6.7635294E-04,   6.8089803E-04
     +,   6.8458542E-04,   6.8740913E-04,   6.8937009E-04
     +,   6.9047476E-04,   6.9073681E-04,   6.9017499E-04
     +,   6.8881316E-04,   6.8667927E-04,   6.8380620E-04
     +,   6.8022992E-04,   6.7598897E-04,   6.7112449E-04
     +,   6.6567963E-04,   6.5969868E-04,   6.5322709E-04
     +,   6.4630975E-04,   6.3899375E-04,   6.3132349E-04
     +,   6.2334538E-04,   6.1510300E-04,   6.0664123E-04
     +,   5.9800188E-04,   5.8922748E-04,   5.8035855E-04
     +,   5.7143514E-04,   5.6249514E-04,   5.5357523E-04
     +,   5.4471241E-04,   5.3594029E-04,   5.2729278E-04
     +,   5.1880151E-04,   5.1049754E-04,   5.0240936E-04
     +,   4.9456616E-04,   4.8699320E-04,   4.7971646E-04
     +,   4.7275942E-04,   4.6614450E-04,   4.5989302E-04
     +,   4.5402485E-04,   4.4855892E-04,   4.4351263E-04
     +,   4.3890323E-04,   4.3474717E-04,   4.3105989E-04
     +,   4.2785643E-04,   4.2515254E-04,   4.2296364E-04
     +,   4.2130516E-04,   4.2019360E-04,   4.1964589E-04
     +,   4.1968017E-04,   4.2031545E-04,   4.2157221E-04
     +,   4.2347200E-04,   4.2603811E-04,   4.2929503E-04
     +,   4.3326887E-04,   4.3798730E-04,   4.4347905E-04
     +,   4.4977511E-04,   4.5690665E-04,   4.6490791E-04
     +,   4.7381379E-04,   4.8366093E-04,   4.9448764E-04
     +,   5.0633494E-04,   5.1924656E-04,   5.3326867E-04
     +,   5.4844993E-04,   5.6484388E-04,   5.8250828E-04
     +,   6.0150347E-04,   6.2189420E-04,   6.4374821E-04
     +,   6.6713692E-04,   6.9212890E-04,   7.1879261E-04
     +,   7.4719195E-04,   7.7737786E-04,   8.0938824E-04
     +,   8.4324356E-04,   8.7894069E-04,   9.1644435E-04
     +,   9.5568789E-04,   9.9657243E-04,   1.0389647E-03
     +,   1.0826963E-03,   1.1275728E-03,   1.1733838E-03
     +,   1.2199130E-03,   1.2669477E-03,   1.3143034E-03
     +,   1.3618362E-03,   1.4094606E-03,   1.4571607E-03
     +,   1.5050133E-03,   1.5531963E-03,   1.6019854E-03
     +,   1.6517742E-03,   1.7030791E-03,   1.7565596E-03
     +,   1.8130401E-03,   1.8735543E-03,   1.9394124E-03
     +,   2.0122679E-03,   2.0941789E-03,   2.1876756E-03
     +,   2.2957500E-03,   2.4217835E-03,   2.5693774E-03
     +,   2.7421098E-03,   2.9431777E-03,   3.1750400E-03
     +,   3.4390958E-03,   3.7355134E-03,   4.0631555E-03
     +,   4.4197356E-03,   4.8021809E-03,   5.2072643E-03
     +,   5.6324750E-03,   6.0771364E-03,   6.5438459E-03
     +,   7.0395623E-03,   7.5760111E-03,   8.1687458E-03
     +,   8.8345436E-03,   9.5875608E-03,   1.0435102E-02
     +,   1.1375007E-02,   1.2395353E-02,   1.3476732E-02
     +,   1.4595997E-02,   1.5729539E-02,   1.6854184E-02
     +,   1.7944928E-02,   1.8971024E-02,   1.9892871E-02
     +,   2.0662516E-02,   2.1228969E-02,   2.1547761E-02
     +,   2.1590937E-02,   2.1354089E-02,   2.0857090E-02
     +,   2.0137882E-02,   1.9241536E-02,   1.8209182E-02
     +,   1.7070750E-02,   1.5843986E-02,   1.4539579E-02
     +,   1.3169657E-02,   1.1755166E-02,   1.0328645E-02
     +,   8.9318594E-03,   7.6092025E-03,   6.3996455E-03
     +,   5.3302045E-03,   4.4130725E-03,   3.6463009E-03
     +,   3.0170558E-03,   2.5061537E-03,   2.0924229E-03
     +,   1.7559432E-03,   1.4798358E-03,   1.2508559E-03
     +,   1.0591726E-03,   8.9769397E-04,   7.6125510E-04
     +,   6.4595742E-04,   5.4868509E-04,   4.6679389E-04
     +,   3.9796063E-04,   3.4013137E-04,   2.9151281E-04
     +,   2.5056442E-04,   2.1598941E-04,   1.8671744E-04
     +,   1.6187743E-04,   1.4075717E-04,   1.2277690E-04
     +,   1.0745507E-04,   9.4390125E-05,   8.3239429E-05
     +,   7.3710922E-05,   6.5551816E-05,   5.8545735E-05
     +,   5.2506333E-05,   4.7275949E-05,   4.2721174E-05
     +,   3.8730788E-05,   3.5213270E-05,   3.2093289E-05
     +,   2.9310113E-05,   2.6814412E-05,   2.4566922E-05
     +,   2.2535867E-05,   2.0695992E-05,   1.9026666E-05
     +,   1.7511218E-05,   1.6135622E-05,   1.4888165E-05
     +,   1.3758502E-05,   1.2737572E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt100 = Yx/0.163545454545455
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6200864E-03,   1.7254928E-03
     +,   1.8311231E-03,   1.9362759E-03,   2.0402328E-03
     +,   2.1422575E-03,   2.2416187E-03,   2.3375987E-03
     +,   2.4295088E-03,   2.5167093E-03,   2.5986065E-03
     +,   2.6746839E-03,   2.7445112E-03,   2.8077385E-03
     +,   2.8641312E-03,   2.9135514E-03,   2.9559722E-03
     +,   2.9914782E-03,   3.0202474E-03,   3.0425568E-03
     +,   3.0587583E-03,   3.0692802E-03,   3.0745871E-03
     +,   3.0751815E-03,   3.0715743E-03,   3.0642701E-03
     +,   3.0537548E-03,   3.0404741E-03,   3.0248272E-03
     +,   3.0071579E-03,   2.9877601E-03,   2.9668680E-03
     +,   2.9446678E-03,   2.9213051E-03,   2.8968973E-03
     +,   2.8715462E-03,   2.8453497E-03,   2.8184121E-03
     +,   2.7908597E-03,   2.7628436E-03,   2.7345547E-03
     +,   2.7062097E-03,   2.6780593E-03,   2.6503790E-03
     +,   2.6234628E-03,   2.5976049E-03,   2.5730922E-03
     +,   2.5501885E-03,   2.5291226E-03,   2.5100743E-03
     +,   2.4931682E-03,   2.4784622E-03,   2.4659510E-03
     +,   2.4555598E-03,   2.4471597E-03,   2.4405585E-03
     +,   2.4355331E-03,   2.4318187E-03,   2.4291454E-03
     +,   2.4272371E-03,   2.4258364E-03,   2.4247041E-03
     +,   2.4236420E-03,   2.4224974E-03,   2.4211686E-03
     +,   2.4195970E-03,   2.4177842E-03,   2.4157641E-03
     +,   2.4136140E-03,   2.4114400E-03,   2.4093592E-03
     +,   2.4075019E-03,   2.4059797E-03,   2.4049040E-03
     +,   2.4043459E-03,   2.4043587E-03,   2.4049443E-03
     +,   2.4060798E-03,   2.4076970E-03,   2.4096910E-03
     +,   2.4119297E-03,   2.4142563E-03,   2.4164971E-03
     +,   2.4184717E-03,   2.4199998E-03,   2.4209139E-03
     +,   2.4210603E-03,   2.4203167E-03,   2.4185888E-03
     +,   2.4158133E-03,   2.4119683E-03,   2.4070751E-03
     +,   2.4011827E-03,   2.3943777E-03,   2.3867826E-03
     +,   2.3785417E-03,   2.3698178E-03,   2.3607949E-03
     +,   2.3516573E-03,   2.3425927E-03,   2.3337898E-03
     +,   2.3254175E-03,   2.3176344E-03,   2.3105831E-03
     +,   2.3043766E-03,   2.2991132E-03,   2.2948619E-03
     +,   2.2916659E-03,   2.2895525E-03,   2.2885180E-03
     +,   2.2885543E-03,   2.2896223E-03,   2.2916780E-03
     +,   2.2946680E-03,   2.2985274E-03,   2.3031821E-03
     +,   2.3085580E-03,   2.3145741E-03,   2.3211476E-03
     +,   2.3281805E-03,   2.3355794E-03,   2.3432388E-03
     +,   2.3510484E-03,   2.3588834E-03,   2.3666117E-03
     +,   2.3740921E-03,   2.3811704E-03,   2.3876866E-03
     +,   2.3934690E-03,   2.3983466E-03,   2.4021415E-03
     +,   2.4046761E-03,   2.4057813E-03,   2.4052928E-03
     +,   2.4030553E-03,   2.3989326E-03,   2.3928005E-03
     +,   2.3845569E-03,   2.3741205E-03,   2.3614350E-03
     +,   2.3464621E-03,   2.3291956E-03,   2.3096499E-03
     +,   2.2878635E-03,   2.2639083E-03,   2.2378745E-03
     +,   2.2098813E-03,   2.1800809E-03,   2.1486522E-03
     +,   2.1157984E-03,   2.0817607E-03,   2.0468088E-03
     +,   2.0112507E-03,   1.9754192E-03,   1.9396829E-03
     +,   1.9044508E-03,   1.8701558E-03,   1.8372642E-03
     +,   1.8062680E-03,   1.7776879E-03,   1.7520668E-03
     +,   1.7299597E-03,   1.7119470E-03,   1.6986136E-03
     +,   1.6905559E-03,   1.6883720E-03,   1.6926571E-03
     +,   1.7040042E-03,   1.7229934E-03,   1.7501828E-03
     +,   1.7861041E-03,   1.8312446E-03,   1.8860389E-03
     +,   1.9508576E-03,   2.0259712E-03,   2.1115497E-03
     +,   2.2076345E-03,   2.3141142E-03,   2.4307026E-03
     +,   2.5569522E-03,   2.6922182E-03,   2.8356744E-03
     +,   2.9863156E-03,   3.1430039E-03,   3.3044987E-03
     +,   3.4694846E-03,   3.6366538E-03,   3.8047752E-03
     +,   3.9727665E-03,   4.1397251E-03,   4.3050293E-03
     +,   4.4683600E-03,   4.6296930E-03,   4.7893352E-03
     +,   4.9478565E-03,   5.1060217E-03,   5.2647032E-03
     +,   5.4247770E-03,   5.5869739E-03,   5.7517798E-03
     +,   5.9193070E-03,   6.0892086E-03,   6.2606377E-03
     +,   6.4322073E-03,   6.6020163E-03,   6.7677256E-03
     +,   6.9266278E-03,   7.0757871E-03,   7.2121453E-03
     +,   7.3326910E-03,   7.4345795E-03,   7.5152363E-03
     +,   7.5725010E-03,   7.6046768E-03,   7.6105921E-03
     +,   7.5896899E-03,   7.5419820E-03,   7.4680876E-03
     +,   7.3691760E-03,   7.2469097E-03,   7.1034236E-03
     +,   6.9411499E-03,   6.7627588E-03,   6.5710605E-03
     +,   6.3688243E-03,   6.1587100E-03,   5.9431796E-03
     +,   5.7244003E-03,   5.5042147E-03,   5.2841175E-03
     +,   5.0652814E-03,   4.8485924E-03,   4.6346663E-03
     +,   4.4239471E-03,   4.2167632E-03,   4.0133670E-03
     +,   3.8139762E-03,   3.6188322E-03,   3.4282098E-03
     +,   3.2424028E-03,   3.0617178E-03,   2.8864983E-03
     +,   2.7170731E-03,   2.5537328E-03,   2.3967340E-03
     +,   2.2462781E-03,   2.1025066E-03,   1.9654837E-03
     +,   1.8352071E-03,   1.7116300E-03,   1.5946407E-03
     +,   1.4840864E-03,   1.3797951E-03,   1.2815706E-03
     +,   1.1891992E-03,   1.1024637E-03,   1.0211529E-03
     +,   9.4505493E-04,   8.7395980E-04,   8.0766017E-04
     +,   7.4595562E-04,   6.8864779E-04,   6.3553383E-04
     +,   5.8641075E-04,   5.4107793E-04,   4.9932866E-04
     +,   4.6095476E-04,   4.2574984E-04,   3.9350800E-04
     +,   3.6402346E-04,   3.3709413E-04,   3.1252537E-04
     +,   2.9012928E-04,   2.6972464E-04,   2.5113943E-04
     +,   2.3421433E-04,   2.1879778E-04,   2.0475143E-04
     +,   1.9194592E-04,   1.8026403E-04,   1.6959760E-04
     +,   1.5984941E-04,   1.5092992E-04,   1.4275966E-04
     +,   1.3526564E-04,   1.2838296E-04,   1.2205262E-04
     +,   1.1622132E-04,   1.1084180E-04,   1.0587063E-04
     +,   1.0126927E-04,   9.7002419E-05,   9.3038710E-05
     +,   8.9349225E-05,   8.5908323E-05,   8.2692321E-05
     +,   7.9680183E-05,   7.6852491E-05,   7.4191965E-05
     +,   7.1682654E-05,   6.9310488E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt105 = Yx/0.191863636363636
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6223581E-03,   1.7409552E-03
     +,   1.8609550E-03,   1.9815865E-03,   2.1020435E-03
     +,   2.2215066E-03,   2.3391480E-03,   2.4541509E-03
     +,   2.5657362E-03,   2.6731649E-03,   2.7757511E-03
     +,   2.8728826E-03,   2.9640282E-03,   3.0487380E-03
     +,   3.1266615E-03,   3.1975417E-03,   3.2612067E-03
     +,   3.3175801E-03,   3.3666650E-03,   3.4085424E-03
     +,   3.4433438E-03,   3.4712646E-03,   3.4925418E-03
     +,   3.5074428E-03,   3.5162545E-03,   3.5192922E-03
     +,   3.5168678E-03,   3.5093094E-03,   3.4969512E-03
     +,   3.4801264E-03,   3.4591814E-03,   3.4344664E-03
     +,   3.4063437E-03,   3.3751861E-03,   3.3413789E-03
     +,   3.3053153E-03,   3.2674049E-03,   3.2280569E-03
     +,   3.1876827E-03,   3.1466938E-03,   3.1054837E-03
     +,   3.0644252E-03,   3.0238670E-03,   2.9841221E-03
     +,   2.9454536E-03,   2.9080797E-03,   2.8721683E-03
     +,   2.8378307E-03,   2.8051224E-03,   2.7740533E-03
     +,   2.7445776E-03,   2.7166137E-03,   2.6900475E-03
     +,   2.6647362E-03,   2.6405242E-03,   2.6172537E-03
     +,   2.5947643E-03,   2.5729118E-03,   2.5515715E-03
     +,   2.5306332E-03,   2.5100294E-03,   2.4897123E-03
     +,   2.4696672E-03,   2.4499099E-03,   2.4304802E-03
     +,   2.4114465E-03,   2.3928911E-03,   2.3749124E-03
     +,   2.3576261E-03,   2.3411524E-03,   2.3256140E-03
     +,   2.3111359E-03,   2.2978447E-03,   2.2858607E-03
     +,   2.2753060E-03,   2.2662920E-03,   2.2589278E-03
     +,   2.2533210E-03,   2.2495675E-03,   2.2477566E-03
     +,   2.2479661E-03,   2.2502716E-03,   2.2547264E-03
     +,   2.2613681E-03,   2.2702154E-03,   2.2812621E-03
     +,   2.2944761E-03,   2.3097901E-03,   2.3271022E-03
     +,   2.3462744E-03,   2.3671291E-03,   2.3894450E-03
     +,   2.4129592E-03,   2.4373699E-03,   2.4623421E-03
     +,   2.4875004E-03,   2.5124417E-03,   2.5367402E-03
     +,   2.5599597E-03,   2.5816513E-03,   2.6013774E-03
     +,   2.6187019E-03,   2.6332233E-03,   2.6445689E-03
     +,   2.6524060E-03,   2.6564600E-03,   2.6565103E-03
     +,   2.6524088E-03,   2.6440735E-03,   2.6314980E-03
     +,   2.6147536E-03,   2.5939860E-03,   2.5694042E-03
     +,   2.5412880E-03,   2.5099763E-03,   2.4758510E-03
     +,   2.4393352E-03,   2.4008842E-03,   2.3609623E-03
     +,   2.3200423E-03,   2.2785882E-03,   2.2370485E-03
     +,   2.1958495E-03,   2.1553773E-03,   2.1159817E-03
     +,   2.0779674E-03,   2.0415939E-03,   2.0070667E-03
     +,   1.9745501E-03,   1.9441561E-03,   1.9159587E-03
     +,   1.8899883E-03,   1.8662426E-03,   1.8446918E-03
     +,   1.8252741E-03,   1.8079166E-03,   1.7925255E-03
     +,   1.7790013E-03,   1.7672383E-03,   1.7571265E-03
     +,   1.7485620E-03,   1.7414457E-03,   1.7356866E-03
     +,   1.7312034E-03,   1.7279306E-03,   1.7258130E-03
     +,   1.7248121E-03,   1.7249084E-03,   1.7260924E-03
     +,   1.7283758E-03,   1.7317819E-03,   1.7363527E-03
     +,   1.7421326E-03,   1.7491875E-03,   1.7575816E-03
     +,   1.7673904E-03,   1.7786839E-03,   1.7915384E-03
     +,   1.8060229E-03,   1.8222029E-03,   1.8401340E-03
     +,   1.8598676E-03,   1.8814451E-03,   1.9048961E-03
     +,   1.9302460E-03,   1.9575129E-03,   1.9867145E-03
     +,   2.0178566E-03,   2.0509528E-03,   2.0860205E-03
     +,   2.1230769E-03,   2.1621522E-03,   2.2032864E-03
     +,   2.2465400E-03,   2.2919842E-03,   2.3397114E-03
     +,   2.3898452E-03,   2.4425266E-03,   2.4979238E-03
     +,   2.5562330E-03,   2.6176767E-03,   2.6824954E-03
     +,   2.7509457E-03,   2.8232953E-03,   2.8998111E-03
     +,   2.9807535E-03,   3.0663577E-03,   3.1568306E-03
     +,   3.2523610E-03,   3.3530754E-03,   3.4590776E-03
     +,   3.5704339E-03,   3.6871836E-03,   3.8093599E-03
     +,   3.9369864E-03,   4.0701362E-03,   4.2088903E-03
     +,   4.3533728E-03,   4.5037693E-03,   4.6602981E-03
     +,   4.8231706E-03,   4.9925833E-03,   5.1686601E-03
     +,   5.3513930E-03,   5.5405651E-03,   5.7357089E-03
     +,   5.9360173E-03,   6.1402894E-03,   6.3469023E-03
     +,   6.5537705E-03,   6.7583988E-03,   6.9578411E-03
     +,   7.1487580E-03,   7.3275627E-03,   7.4904738E-03
     +,   7.6336386E-03,   7.7532828E-03,   7.8458814E-03
     +,   7.9083014E-03,   7.9379268E-03,   7.9328576E-03
     +,   7.8919465E-03,   7.8149214E-03,   7.7024046E-03
     +,   7.5559141E-03,   7.3777526E-03,   7.1709799E-03
     +,   6.9392207E-03,   6.6865045E-03,   6.4170798E-03
     +,   6.1352691E-03,   5.8452561E-03,   5.5509629E-03
     +,   5.2559231E-03,   4.9632569E-03,   4.6755583E-03
     +,   4.3949378E-03,   4.1230451E-03,   3.8611232E-03
     +,   3.6100126E-03,   3.3702510E-03,   3.1421497E-03
     +,   2.9258174E-03,   2.7212056E-03,   2.5281513E-03
     +,   2.3464174E-03,   2.1757041E-03,   2.0156433E-03
     +,   1.8658354E-03,   1.7258568E-03,   1.5952507E-03
     +,   1.4735456E-03,   1.3602689E-03,   1.2549475E-03
     +,   1.1571094E-03,   1.0662950E-03,   9.8207057E-04
     +,   9.0402371E-04,   8.3175709E-04,   7.6490000E-04
     +,   7.0311077E-04,   6.4606761E-04,   5.9346465E-04
     +,   5.4501538E-04,   5.0045113E-04,   4.5951339E-04
     +,   4.2195534E-04,   3.8754317E-04,   3.5605233E-04
     +,   3.2726536E-04,   3.0097479E-04,   2.7698441E-04
     +,   2.5510718E-04,   2.3516547E-04,   2.1699198E-04
     +,   2.0043211E-04,   1.8533989E-04,   1.7158204E-04
     +,   1.5903433E-04,   1.4758446E-04,   1.3712849E-04
     +,   1.2757324E-04,   1.1883301E-04,   1.1083138E-04
     +,   1.0349837E-04,   9.6771699E-05,   9.0594578E-05
     +,   8.4915839E-05,   7.9689802E-05,   7.4874668E-05
     +,   7.0433161E-05,   6.6331144E-05,   6.2538173E-05
     +,   5.9026246E-05,   5.5770444E-05,   5.2747753E-05
     +,   4.9937749E-05,   4.7321508E-05,   4.4882283E-05
     +,   4.2604588E-05,   4.0474675E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt107 = Yx/0.192111111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4156746E-03,   1.5114089E-03
     +,   1.6092126E-03,   1.7087988E-03,   1.8098669E-03
     +,   1.9120874E-03,   2.0151199E-03,   2.1185947E-03
     +,   2.2221142E-03,   2.3252626E-03,   2.4275889E-03
     +,   2.5286193E-03,   2.6278503E-03,   2.7247660E-03
     +,   2.8188271E-03,   2.9094920E-03,   2.9962310E-03
     +,   3.0785135E-03,   3.1558585E-03,   3.2278178E-03
     +,   3.2940076E-03,   3.3541175E-03,   3.4079254E-03
     +,   3.4553125E-03,   3.4962439E-03,   3.5308187E-03
     +,   3.5592241E-03,   3.5817646E-03,   3.5988288E-03
     +,   3.6108836E-03,   3.6184650E-03,   3.6221552E-03
     +,   3.6225542E-03,   3.6202641E-03,   3.6158809E-03
     +,   3.6099504E-03,   3.6029709E-03,   3.5953694E-03
     +,   3.5875072E-03,   3.5796559E-03,   3.5719960E-03
     +,   3.5646386E-03,   3.5576066E-03,   3.5508547E-03
     +,   3.5442761E-03,   3.5377091E-03,   3.5309542E-03
     +,   3.5237779E-03,   3.5159239E-03,   3.5071291E-03
     +,   3.4971263E-03,   3.4856459E-03,   3.4724367E-03
     +,   3.4572580E-03,   3.4398919E-03,   3.4201464E-03
     +,   3.3978517E-03,   3.3728823E-03,   3.3451405E-03
     +,   3.3145752E-03,   3.2811821E-03,   3.2450000E-03
     +,   3.2061271E-03,   3.1647116E-03,   3.1209569E-03
     +,   3.0751301E-03,   3.0275367E-03,   2.9785524E-03
     +,   2.9285781E-03,   2.8780650E-03,   2.8274902E-03
     +,   2.7773420E-03,   2.7281172E-03,   2.6803110E-03
     +,   2.6343893E-03,   2.5907939E-03,   2.5499137E-03
     +,   2.5120934E-03,   2.4776040E-03,   2.4466452E-03
     +,   2.4193551E-03,   2.3957791E-03,   2.3758945E-03
     +,   2.3596045E-03,   2.3467417E-03,   2.3370839E-03
     +,   2.3303484E-03,   2.3262200E-03,   2.3243402E-03
     +,   2.3243423E-03,   2.3258417E-03,   2.3284564E-03
     +,   2.3318110E-03,   2.3355554E-03,   2.3393519E-03
     +,   2.3428958E-03,   2.3459203E-03,   2.3481802E-03
     +,   2.3494801E-03,   2.3496493E-03,   2.3485585E-03
     +,   2.3461054E-03,   2.3422230E-03,   2.3368655E-03
     +,   2.3300196E-03,   2.3216850E-03,   2.3118858E-03
     +,   2.3006613E-03,   2.2880635E-03,   2.2741521E-03
     +,   2.2590086E-03,   2.2427035E-03,   2.2253229E-03
     +,   2.2069560E-03,   2.1876902E-03,   2.1676149E-03
     +,   2.1468154E-03,   2.1253757E-03,   2.1033732E-03
     +,   2.0808815E-03,   2.0579617E-03,   2.0346742E-03
     +,   2.0110637E-03,   1.9871667E-03,   1.9630122E-03
     +,   1.9386185E-03,   1.9139920E-03,   1.8891313E-03
     +,   1.8640296E-03,   1.8386733E-03,   1.8130420E-03
     +,   1.7871155E-03,   1.7608699E-03,   1.7342870E-03
     +,   1.7073472E-03,   1.6800393E-03,   1.6523591E-03
     +,   1.6243136E-03,   1.5959207E-03,   1.5672087E-03
     +,   1.5382222E-03,   1.5090234E-03,   1.4796853E-03
     +,   1.4502978E-03,   1.4209683E-03,   1.3918178E-03
     +,   1.3629806E-03,   1.3346055E-03,   1.3068528E-03
     +,   1.2798902E-03,   1.2538950E-03,   1.2290492E-03
     +,   1.2055411E-03,   1.1835562E-03,   1.1632791E-03
     +,   1.1448949E-03,   1.1285830E-03,   1.1145119E-03
     +,   1.1028455E-03,   1.0937356E-03,   1.0873227E-03
     +,   1.0837362E-03,   1.0830924E-03,   1.0854929E-03
     +,   1.0910287E-03,   1.0997741E-03,   1.1117936E-03
     +,   1.1271345E-03,   1.1458358E-03,   1.1679243E-03
     +,   1.1934148E-03,   1.2223127E-03,   1.2546140E-03
     +,   1.2903131E-03,   1.3293929E-03,   1.3718409E-03
     +,   1.4176473E-03,   1.4668093E-03,   1.5193385E-03
     +,   1.5752706E-03,   1.6346790E-03,   1.6976761E-03
     +,   1.7644285E-03,   1.8351766E-03,   1.9102308E-03
     +,   1.9899942E-03,   2.0749569E-03,   2.1657113E-03
     +,   2.2629369E-03,   2.3673854E-03,   2.4798808E-03
     +,   2.6012773E-03,   2.7324199E-03,   2.8741073E-03
     +,   3.0270442E-03,   3.1918008E-03,   3.3687293E-03
     +,   3.5579351E-03,   3.7592449E-03,   3.9721681E-03
     +,   4.1958652E-03,   4.4291657E-03,   4.6705925E-03
     +,   4.9183853E-03,   5.1705102E-03,   5.4247859E-03
     +,   5.6789061E-03,   5.9304503E-03,   6.1770217E-03
     +,   6.4162472E-03,   6.6458248E-03,   6.8635228E-03
     +,   7.0672287E-03,   7.2549535E-03,   7.4248333E-03
     +,   7.5751715E-03,   7.7043860E-03,   7.8111454E-03
     +,   7.8943167E-03,   7.9530254E-03,   7.9867262E-03
     +,   7.9952097E-03,   7.9786088E-03,   7.9374583E-03
     +,   7.8726253E-03,   7.7853184E-03,   7.6770219E-03
     +,   7.5494554E-03,   7.4044489E-03,   7.2439318E-03
     +,   7.0698350E-03,   6.8840226E-03,   6.6882558E-03
     +,   6.4841802E-03,   6.2732990E-03,   6.0569402E-03
     +,   5.8363145E-03,   5.6125368E-03,   5.3865956E-03
     +,   5.1594139E-03,   4.9318545E-03,   4.7047432E-03
     +,   4.4788769E-03,   4.2550093E-03,   4.0338677E-03
     +,   3.8161634E-03,   3.6025897E-03,   3.3937767E-03
     +,   3.1903191E-03,   2.9928021E-03,   2.8017389E-03
     +,   2.6175850E-03,   2.4407674E-03,   2.2716445E-03
     +,   2.1105041E-03,   1.9575644E-03,   1.8129824E-03
     +,   1.6768363E-03,   1.5491274E-03,   1.4297726E-03
     +,   1.3186346E-03,   1.2155039E-03,   1.1201053E-03
     +,   1.0321150E-03,   9.5117511E-04,   8.7688939E-04
     +,   8.0884405E-04,   7.4661721E-04,   6.8978703E-04
     +,   6.3793344E-04,   5.9065118E-04,   5.4755510E-04
     +,   5.0828117E-04,   4.7248640E-04,   4.3985253E-04
     +,   4.1008875E-04,   3.8292413E-04,   3.5811431E-04
     +,   3.3543236E-04,   3.1467481E-04,   2.9565359E-04
     +,   2.7819994E-04,   2.6215799E-04,   2.4738855E-04
     +,   2.3376360E-04,   2.2116874E-04,   2.0949963E-04
     +,   1.9866256E-04,   1.8857430E-04,   1.7915929E-04
     +,   1.7035131E-04,   1.6209045E-04,   1.5432492E-04
     +,   1.4700794E-04,   1.4009912E-04,   1.3356237E-04
     +,   1.2736663E-04,   1.2148399E-04,   1.1589063E-04
     +,   1.1056473E-04,   1.0548799E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt110 = Yx/0.195844444444444
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3454944E-03,   1.4349715E-03
     +,   1.5265729E-03,   1.6200524E-03,   1.7151365E-03
     +,   1.8115336E-03,   1.9089192E-03,   2.0069450E-03
     +,   2.1052347E-03,   2.2033865E-03,   2.3009682E-03
     +,   2.3975237E-03,   2.4925766E-03,   2.5856311E-03
     +,   2.6761813E-03,   2.7637193E-03,   2.8477393E-03
     +,   2.9277536E-03,   3.0033011E-03,   3.0739517E-03
     +,   3.1393287E-03,   3.1991049E-03,   3.2530255E-03
     +,   3.3009101E-03,   3.3426448E-03,   3.3782122E-03
     +,   3.4076616E-03,   3.4311351E-03,   3.4488409E-03
     +,   3.4610638E-03,   3.4681500E-03,   3.4704991E-03
     +,   3.4685463E-03,   3.4627751E-03,   3.4536782E-03
     +,   3.4417692E-03,   3.4275553E-03,   3.4115484E-03
     +,   3.3942384E-03,   3.3761030E-03,   3.3575809E-03
     +,   3.3390855E-03,   3.3209887E-03,   3.3036161E-03
     +,   3.2872551E-03,   3.2721343E-03,   3.2584330E-03
     +,   3.2462741E-03,   3.2357220E-03,   3.2267903E-03
     +,   3.2194320E-03,   3.2135521E-03,   3.2090058E-03
     +,   3.2056060E-03,   3.2031348E-03,   3.2013403E-03
     +,   3.1999594E-03,   3.1987156E-03,   3.1973305E-03
     +,   3.1955480E-03,   3.1931065E-03,   3.1897831E-03
     +,   3.1853870E-03,   3.1797474E-03,   3.1727315E-03
     +,   3.1642523E-03,   3.1542436E-03,   3.1426789E-03
     +,   3.1295600E-03,   3.1149087E-03,   3.0987686E-03
     +,   3.0812030E-03,   3.0622785E-03,   3.0420760E-03
     +,   3.0206675E-03,   2.9981404E-03,   2.9745561E-03
     +,   2.9499924E-03,   2.9245105E-03,   2.8981608E-03
     +,   2.8710037E-03,   2.8430754E-03,   2.8144214E-03
     +,   2.7850773E-03,   2.7550817E-03,   2.7244675E-03
     +,   2.6932757E-03,   2.6615476E-03,   2.6293201E-03
     +,   2.5966461E-03,   2.5635681E-03,   2.5301424E-03
     +,   2.4964206E-03,   2.4624593E-03,   2.4283114E-03
     +,   2.3940355E-03,   2.3596806E-03,   2.3252971E-03
     +,   2.2909301E-03,   2.2566225E-03,   2.2224090E-03
     +,   2.1883252E-03,   2.1543957E-03,   2.1206480E-03
     +,   2.0871020E-03,   2.0537812E-03,   2.0207076E-03
     +,   1.9879020E-03,   1.9553921E-03,   1.9232042E-03
     +,   1.8913734E-03,   1.8599376E-03,   1.8289424E-03
     +,   1.7984335E-03,   1.7684702E-03,   1.7391051E-03
     +,   1.7104032E-03,   1.6824207E-03,   1.6552249E-03
     +,   1.6288720E-03,   1.6034169E-03,   1.5789086E-03
     +,   1.5553886E-03,   1.5328918E-03,   1.5114353E-03
     +,   1.4910317E-03,   1.4716788E-03,   1.4533614E-03
     +,   1.4360520E-03,   1.4197134E-03,   1.4042923E-03
     +,   1.3897298E-03,   1.3759556E-03,   1.3628920E-03
     +,   1.3504574E-03,   1.3385632E-03,   1.3271215E-03
     +,   1.3160462E-03,   1.3052494E-03,   1.2946479E-03
     +,   1.2841674E-03,   1.2737383E-03,   1.2632994E-03
     +,   1.2528027E-03,   1.2422069E-03,   1.2314877E-03
     +,   1.2206299E-03,   1.2096333E-03,   1.1985126E-03
     +,   1.1872927E-03,   1.1760140E-03,   1.1647313E-03
     +,   1.1535117E-03,   1.1424349E-03,   1.1315919E-03
     +,   1.1210871E-03,   1.1110348E-03,   1.1015588E-03
     +,   1.0927919E-03,   1.0848761E-03,   1.0779609E-03
     +,   1.0722001E-03,   1.0677566E-03,   1.0647924E-03
     +,   1.0634750E-03,   1.0639741E-03,   1.0664582E-03
     +,   1.0710938E-03,   1.0780436E-03,   1.0874674E-03
     +,   1.0995180E-03,   1.1143356E-03,   1.1320584E-03
     +,   1.1528055E-03,   1.1766879E-03,   1.2038010E-03
     +,   1.2342305E-03,   1.2680442E-03,   1.3052976E-03
     +,   1.3460387E-03,   1.3903035E-03,   1.4381203E-03
     +,   1.4895116E-03,   1.5445030E-03,   1.6031243E-03
     +,   1.6654048E-03,   1.7313834E-03,   1.8011190E-03
     +,   1.8746788E-03,   1.9521456E-03,   2.0336269E-03
     +,   2.1192450E-03,   2.2091328E-03,   2.3034462E-03
     +,   2.4023633E-03,   2.5060670E-03,   2.6147517E-03
     +,   2.7286152E-03,   2.8478648E-03,   2.9727053E-03
     +,   3.1033272E-03,   3.2398899E-03,   3.3825445E-03
     +,   3.5313859E-03,   3.6864437E-03,   3.8476742E-03
     +,   4.0149377E-03,   4.1879639E-03,   4.3663224E-03
     +,   4.5494470E-03,   4.7365641E-03,   4.9267057E-03
     +,   5.1186830E-03,   5.3111166E-03,   5.5024326E-03
     +,   5.6908592E-03,   5.8745132E-03,   6.0514146E-03
     +,   6.2195659E-03,   6.3770046E-03,   6.5218941E-03
     +,   6.6526160E-03,   6.7677898E-03,   6.8664001E-03
     +,   6.9478285E-03,   7.0118406E-03,   7.0586521E-03
     +,   7.0888516E-03,   7.1033733E-03,   7.1034105E-03
     +,   7.0903166E-03,   7.0654973E-03,   7.0303059E-03
     +,   6.9859060E-03,   6.9332300E-03,   6.8728752E-03
     +,   6.8050758E-03,   6.7297034E-03,   6.6463216E-03
     +,   6.5542287E-03,   6.4525153E-03,   6.3402471E-03
     +,   6.2164883E-03,   6.0804659E-03,   5.9316396E-03
     +,   5.7697850E-03,   5.5950545E-03,   5.4079713E-03
     +,   5.2094371E-03,   5.0007235E-03,   4.7833882E-03
     +,   4.5592175E-03,   4.3301624E-03,   4.0982640E-03
     +,   3.8655454E-03,   3.6339562E-03,   3.4053535E-03
     +,   3.1814135E-03,   2.9635974E-03,   2.7531604E-03
     +,   2.5511412E-03,   2.3583490E-03,   2.1753786E-03
     +,   2.0026250E-03,   1.8403206E-03,   1.6885272E-03
     +,   1.5471710E-03,   1.4160660E-03,   1.2949348E-03
     +,   1.1834097E-03,   1.0810609E-03,   9.8741811E-04
     +,   9.0197357E-04,   8.2419411E-04,   7.5353350E-04
     +,   6.8945356E-04,   6.3141179E-04,   5.7888916E-04
     +,   5.3138001E-04,   4.8841001E-04,   4.4952886E-04
     +,   4.1432303E-04,   3.8240672E-04,   3.5343328E-04
     +,   3.2708456E-04,   3.0307932E-04,   2.8116402E-04
     +,   2.6111444E-04,   2.4273478E-04,   2.2585093E-04
     +,   2.1031269E-04,   1.9598698E-04,   1.8275937E-04
     +,   1.7052829E-04,   1.5920623E-04,   1.4871491E-04
     +,   1.3898658E-04,   1.2995953E-04,   1.2158011E-04
     +,   1.1379856E-04,   1.0657091E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt115 = Yx/0.191545454545455
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4312563E-03,   1.5169246E-03
     +,   1.6032472E-03,   1.6898508E-03,   1.7763554E-03
     +,   1.8623852E-03,   1.9475693E-03,   2.0315454E-03
     +,   2.1139635E-03,   2.1945008E-03,   2.2728466E-03
     +,   2.3487140E-03,   2.4218461E-03,   2.4920043E-03
     +,   2.5589825E-03,   2.6225953E-03,   2.6826777E-03
     +,   2.7390956E-03,   2.7917288E-03,   2.8404761E-03
     +,   2.8852604E-03,   2.9260162E-03,   2.9627001E-03
     +,   2.9952785E-03,   3.0237404E-03,   3.0480963E-03
     +,   3.0683666E-03,   3.0846081E-03,   3.0968827E-03
     +,   3.1052968E-03,   3.1099711E-03,   3.1110588E-03
     +,   3.1087366E-03,   3.1032108E-03,   3.0947139E-03
     +,   3.0834975E-03,   3.0698276E-03,   3.0539974E-03
     +,   3.0362948E-03,   3.0170269E-03,   2.9964868E-03
     +,   2.9749714E-03,   2.9527543E-03,   2.9301143E-03
     +,   2.9072948E-03,   2.8845328E-03,   2.8620290E-03
     +,   2.8399758E-03,   2.8185411E-03,   2.7978690E-03
     +,   2.7780880E-03,   2.7593162E-03,   2.7416423E-03
     +,   2.7251595E-03,   2.7099396E-03,   2.6960515E-03
     +,   2.6835462E-03,   2.6724623E-03,   2.6628375E-03
     +,   2.6546835E-03,   2.6480013E-03,   2.6427677E-03
     +,   2.6389435E-03,   2.6364622E-03,   2.6352312E-03
     +,   2.6351365E-03,   2.6360292E-03,   2.6377488E-03
     +,   2.6400997E-03,   2.6428699E-03,   2.6458423E-03
     +,   2.6487750E-03,   2.6514335E-03,   2.6535795E-03
     +,   2.6549881E-03,   2.6554437E-03,   2.6547469E-03
     +,   2.6527371E-03,   2.6492712E-03,   2.6442367E-03
     +,   2.6375602E-03,   2.6291921E-03,   2.6191294E-03
     +,   2.6073856E-03,   2.5940156E-03,   2.5790844E-03
     +,   2.5626912E-03,   2.5449425E-03,   2.5259606E-03
     +,   2.5058726E-03,   2.4848040E-03,   2.4628821E-03
     +,   2.4402319E-03,   2.4169637E-03,   2.3931775E-03
     +,   2.3689666E-03,   2.3444032E-03,   2.3195525E-03
     +,   2.2944619E-03,   2.2691689E-03,   2.2436988E-03
     +,   2.2180683E-03,   2.1922810E-03,   2.1663413E-03
     +,   2.1402391E-03,   2.1139700E-03,   2.0875202E-03
     +,   2.0608804E-03,   2.0340418E-03,   2.0069925E-03
     +,   1.9797271E-03,   1.9522461E-03,   1.9245478E-03
     +,   1.8966395E-03,   1.8685340E-03,   1.8402453E-03
     +,   1.8117984E-03,   1.7832188E-03,   1.7545390E-03
     +,   1.7257979E-03,   1.6970367E-03,   1.6682992E-03
     +,   1.6396405E-03,   1.6111095E-03,   1.5827643E-03
     +,   1.5546605E-03,   1.5268541E-03,   1.4994034E-03
     +,   1.4723603E-03,   1.4457799E-03,   1.4197114E-03
     +,   1.3941965E-03,   1.3692777E-03,   1.3449882E-03
     +,   1.3213563E-03,   1.2984033E-03,   1.2761450E-03
     +,   1.2545921E-03,   1.2337473E-03,   1.2136075E-03
     +,   1.1941649E-03,   1.1754108E-03,   1.1573281E-03
     +,   1.1399001E-03,   1.1231088E-03,   1.1069343E-03
     +,   1.0913579E-03,   1.0763637E-03,   1.0619375E-03
     +,   1.0480686E-03,   1.0347519E-03,   1.0219840E-03
     +,   1.0097713E-03,   9.9812471E-04,   9.8706060E-04
     +,   9.7660290E-04,   9.6678489E-04,   9.5764064E-04
     +,   9.4921596E-04,   9.4156183E-04,   9.3473401E-04
     +,   9.2879462E-04,   9.2381012E-04,   9.1985246E-04
     +,   9.1699592E-04,   9.1531820E-04,   9.1489911E-04
     +,   9.1581926E-04,   9.1815914E-04,   9.2199864E-04
     +,   9.2741533E-04,   9.3448453E-04,   9.4327418E-04
     +,   9.5384911E-04,   9.6626428E-04,   9.8056812E-04
     +,   9.9679769E-04,   1.0149804E-03,   1.0351281E-03
     +,   1.0572427E-03,   1.0813127E-03,   1.1073095E-03
     +,   1.1351926E-03,   1.1649111E-03,   1.1964019E-03
     +,   1.2295890E-03,   1.2643925E-03,   1.3007281E-03
     +,   1.3385128E-03,   1.3776610E-03,   1.4180994E-03
     +,   1.4597647E-03,   1.5026056E-03,   1.5465878E-03
     +,   1.5917012E-03,   1.6379597E-03,   1.6853950E-03
     +,   1.7340659E-03,   1.7840561E-03,   1.8354713E-03
     +,   1.8884343E-03,   1.9430852E-03,   1.9995798E-03
     +,   2.0580823E-03,   2.1187572E-03,   2.1817682E-03
     +,   2.2472788E-03,   2.3154428E-03,   2.3863902E-03
     +,   2.4602390E-03,   2.5370829E-03,   2.6169883E-03
     +,   2.6999859E-03,   2.7860713E-03,   2.8752110E-03
     +,   2.9673157E-03,   3.0622508E-03,   3.1598494E-03
     +,   3.2598865E-03,   3.3620954E-03,   3.4661682E-03
     +,   3.5717648E-03,   3.6785090E-03,   3.7859904E-03
     +,   3.8938012E-03,   4.0015238E-03,   4.1087442E-03
     +,   4.2150454E-03,   4.3200590E-03,   4.4234190E-03
     +,   4.5247995E-03,   4.6238736E-03,   4.7203656E-03
     +,   4.8140050E-03,   4.9044904E-03,   4.9915398E-03
     +,   5.0748368E-03,   5.1540043E-03,   5.2286186E-03
     +,   5.2981800E-03,   5.3621307E-03,   5.4198266E-03
     +,   5.4705418E-03,   5.5135102E-03,   5.5479147E-03
     +,   5.5729286E-03,   5.5877250E-03,   5.5915350E-03
     +,   5.5836709E-03,   5.5635483E-03,   5.5307182E-03
     +,   5.4849251E-03,   5.4260856E-03,   5.3543220E-03
     +,   5.2699777E-03,   5.1735747E-03,   5.0658449E-03
     +,   4.9476828E-03,   4.8201275E-03,   4.6843085E-03
     +,   4.5414609E-03,   4.3928414E-03,   4.2397077E-03
     +,   4.0832874E-03,   3.9247759E-03,   3.7652543E-03
     +,   3.6057257E-03,   3.4470819E-03,   3.2901070E-03
     +,   3.1354600E-03,   2.9836893E-03,   2.8352519E-03
     +,   2.6905127E-03,   2.5497505E-03,   2.4131734E-03
     +,   2.2809545E-03,   2.1531980E-03,   2.0299973E-03
     +,   1.9113986E-03,   1.7974448E-03,   1.6881496E-03
     +,   1.5835250E-03,   1.4835560E-03,   1.3882301E-03
     +,   1.2975098E-03,   1.2113568E-03,   1.1297090E-03
     +,   1.0524919E-03,   9.7962422E-04,   9.1099966E-04
     +,   8.4650872E-04,   7.8601978E-04,   7.2939682E-04
     +,   6.7648926E-04,   6.2714238E-04,   5.8118894E-04
     +,   5.3846434E-04,   4.9879489E-04,   4.6201082E-04
     +,   4.2793882E-04,   3.9641143E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt120 = Yx/0.175477272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8423398E-04,   4.1311744E-04
     +,   4.4374686E-04,   4.7625331E-04,   5.1077787E-04
     +,   5.4746884E-04,   5.8647961E-04,   6.2796281E-04
     +,   6.7206449E-04,   7.1892131E-04,   7.6864625E-04
     +,   8.2132581E-04,   8.7700685E-04,   9.3568873E-04
     +,   9.9731260E-04,   1.0617528E-03,   1.1288082E-03
     +,   1.1981949E-03,   1.2695427E-03,   1.3423939E-03
     +,   1.4162029E-03,   1.4903422E-03,   1.5641118E-03
     +,   1.6367545E-03,   1.7074622E-03,   1.7754111E-03
     +,   1.8397688E-03,   1.8997252E-03,   1.9545173E-03
     +,   2.0034474E-03,   2.0459120E-03,   2.0814110E-03
     +,   2.1095730E-03,   2.1301615E-03,   2.1430820E-03
     +,   2.1483782E-03,   2.1462382E-03,   2.1369753E-03
     +,   2.1210206E-03,   2.0989084E-03,   2.0712528E-03
     +,   2.0387333E-03,   2.0020704E-03,   1.9620080E-03
     +,   1.9192926E-03,   1.8746549E-03,   1.8287966E-03
     +,   1.7823719E-03,   1.7359779E-03,   1.6901443E-03
     +,   1.6453284E-03,   1.6019025E-03,   1.5601636E-03
     +,   1.5203196E-03,   1.4825024E-03,   1.4467667E-03
     +,   1.4130973E-03,   1.3814220E-03,   1.3516153E-03
     +,   1.3235179E-03,   1.2969440E-03,   1.2716986E-03
     +,   1.2475890E-03,   1.2244363E-03,   1.2020840E-03
     +,   1.1804121E-03,   1.1593354E-03,   1.1388148E-03
     +,   1.1188487E-03,   1.0994797E-03,   1.0807801E-03
     +,   1.0628519E-03,   1.0458130E-03,   1.0297945E-03
     +,   1.0149191E-03,   1.0013039E-03,   9.8904211E-04
     +,   9.7819965E-04,   9.6880889E-04,   9.6086366E-04
     +,   9.5431774E-04,   9.4908685E-04,   9.4504922E-04
     +,   9.4205007E-04,   9.3990873E-04,   9.3842286E-04
     +,   9.3737786E-04,   9.3655393E-04,   9.3573186E-04
     +,   9.3470479E-04,   9.3327870E-04,   9.3128154E-04
     +,   9.2856714E-04,   9.2501653E-04,   9.2054048E-04
     +,   9.1508159E-04,   9.0861076E-04,   9.0112939E-04
     +,   8.9266367E-04,   8.8326319E-04,   8.7299838E-04
     +,   8.6195499E-04,   8.5023232E-04,   8.3793874E-04
     +,   8.2518876E-04,   8.1209769E-04,   7.9878262E-04
     +,   7.8535761E-04,   7.7193038E-04,   7.5860345E-04
     +,   7.4547157E-04,   7.3261972E-04,   7.2012492E-04
     +,   7.0805283E-04,   6.9646077E-04,   6.8539480E-04
     +,   6.7489222E-04,   6.6497963E-04,   6.5567635E-04
     +,   6.4699195E-04,   6.3892751E-04,   6.3147745E-04
     +,   6.2462955E-04,   6.1836385E-04,   6.1265519E-04
     +,   6.0747378E-04,   6.0278416E-04,   5.9854798E-04
     +,   5.9472286E-04,   5.9126446E-04,   5.8812601E-04
     +,   5.8525946E-04,   5.8261619E-04,   5.8014819E-04
     +,   5.7780719E-04,   5.7554670E-04,   5.7332218E-04
     +,   5.7109137E-04,   5.6881469E-04,   5.6645618E-04
     +,   5.6398322E-04,   5.6136801E-04,   5.5858691E-04
     +,   5.5562024E-04,   5.5245403E-04,   5.4907892E-04
     +,   5.4549082E-04,   5.4168992E-04,   5.3768227E-04
     +,   5.3347880E-04,   5.2909460E-04,   5.2455039E-04
     +,   5.1987072E-04,   5.1508477E-04,   5.1022513E-04
     +,   5.0532841E-04,   5.0043478E-04,   4.9558672E-04
     +,   4.9082900E-04,   4.8620949E-04,   4.8177625E-04
     +,   4.7757933E-04,   4.7366813E-04,   4.7009307E-04
     +,   4.6690274E-04,   4.6414442E-04,   4.6186394E-04
     +,   4.6010356E-04,   4.5890265E-04,   4.5829575E-04
     +,   4.5831362E-04,   4.5898074E-04,   4.6031567E-04
     +,   4.6233114E-04,   4.6503195E-04,   4.6841594E-04
     +,   4.7247342E-04,   4.7718571E-04,   4.8252693E-04
     +,   4.8846251E-04,   4.9495016E-04,   5.0193898E-04
     +,   5.0937099E-04,   5.1718130E-04,   5.2529830E-04
     +,   5.3364481E-04,   5.4213771E-04,   5.5069180E-04
     +,   5.5921701E-04,   5.6762295E-04,   5.7581707E-04
     +,   5.8370858E-04,   5.9120805E-04,   5.9822766E-04
     +,   6.0468615E-04,   6.1050546E-04,   6.1561452E-04
     +,   6.1994942E-04,   6.2345411E-04,   6.2608189E-04
     +,   6.2779459E-04,   6.2856445E-04,   6.2837399E-04
     +,   6.2721508E-04,   6.2509050E-04,   6.2201265E-04
     +,   6.1800325E-04,   6.1309320E-04,   6.0732249E-04
     +,   6.0073781E-04,   5.9339282E-04,   5.8534753E-04
     +,   5.7666737E-04,   5.6741998E-04,   5.5767701E-04
     +,   5.4751174E-04,   5.3699873E-04,   5.2621111E-04
     +,   5.1522139E-04,   5.0410099E-04,   4.9291656E-04
     +,   4.8173274E-04,   4.7060917E-04,   4.5960207E-04
     +,   4.4876043E-04,   4.3812921E-04,   4.2774744E-04
     +,   4.1764879E-04,   4.0786024E-04,   3.9840298E-04
     +,   3.8929351E-04,   3.8054259E-04,   3.7215542E-04
     +,   3.6413225E-04,   3.5646991E-04,   3.4915999E-04
     +,   3.4219099E-04,   3.3554816E-04,   3.2921461E-04
     +,   3.2317004E-04,   3.1739296E-04,   3.1186041E-04
     +,   3.0654881E-04,   3.0143326E-04,   2.9648919E-04
     +,   2.9169206E-04,   2.8701784E-04,   2.8244304E-04
     +,   2.7794513E-04,   2.7350316E-04,   2.6909733E-04
     +,   2.6470903E-04,   2.6032195E-04,   2.5592113E-04
     +,   2.5149359E-04,   2.4702767E-04,   2.4251432E-04
     +,   2.3794605E-04,   2.3331681E-04,   2.2862239E-04
     +,   2.2386068E-04,   2.1903098E-04,   2.1413379E-04
     +,   2.0917102E-04,   2.0414640E-04,   1.9906423E-04
     +,   1.9392991E-04,   1.8875011E-04,   1.8353216E-04
     +,   1.7828392E-04,   1.7301369E-04,   1.6773045E-04
     +,   1.6244360E-04,   1.5716242E-04,   1.5189625E-04
     +,   1.4665487E-04,   1.4144742E-04,   1.3628347E-04
     +,   1.3117165E-04,   1.2612097E-04,   1.2113942E-04
     +,   1.1623514E-04,   1.1141518E-04,   1.0668676E-04
     +,   1.0205587E-04,   9.7528515E-05,   9.3109746E-05
     +,   8.8803950E-05,   8.4615371E-05,   8.0547114E-05
     +,   7.6602213E-05,   7.2782575E-05,   6.9090114E-05
     +,   6.5525674E-05,   6.2090039E-05,   5.8783058E-05
     +,   5.5604585E-05,   5.2553583E-05,   4.9629023E-05
     +,   4.6829122E-05,   4.4152141E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt60 = Yx/0.0517222222222222
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3187156E-04,   3.5428006E-04
     +,   3.7716620E-04,   4.0045253E-04,   4.2405905E-04
     +,   4.4790443E-04,   4.7190706E-04,   4.9598666E-04
     +,   5.2006578E-04,   5.4407184E-04,   5.6793872E-04
     +,   5.9160823E-04,   6.1503245E-04,   6.3817523E-04
     +,   6.6101557E-04,   6.8354787E-04,   7.0578384E-04
     +,   7.2775688E-04,   7.4951985E-04,   7.7114935E-04
     +,   7.9274527E-04,   8.1443117E-04,   8.3635398E-04
     +,   8.5868401E-04,   8.8160834E-04,   9.0533582E-04
     +,   9.3008491E-04,   9.5608382E-04,   9.8356034E-04
     +,   1.0127397E-03,   1.0438323E-03,   1.0770281E-03
     +,   1.1124883E-03,   1.1503361E-03,   1.1906491E-03
     +,   1.2334535E-03,   1.2787165E-03,   1.3263413E-03
     +,   1.3761715E-03,   1.4279747E-03,   1.4814606E-03
     +,   1.5362717E-03,   1.5919911E-03,   1.6481507E-03
     +,   1.7042386E-03,   1.7597043E-03,   1.8139738E-03
     +,   1.8664593E-03,   1.9165726E-03,   1.9637344E-03
     +,   2.0073911E-03,   2.0470244E-03,   2.0821672E-03
     +,   2.1124112E-03,   2.1374165E-03,   2.1569242E-03
     +,   2.1707607E-03,   2.1788352E-03,   2.1811530E-03
     +,   2.1778021E-03,   2.1689576E-03,   2.1548711E-03
     +,   2.1358570E-03,   2.1122918E-03,   2.0845893E-03
     +,   2.0531982E-03,   2.0185800E-03,   1.9812058E-03
     +,   1.9415369E-03,   1.9000209E-03,   1.8570775E-03
     +,   1.8131030E-03,   1.7684565E-03,   1.7234697E-03
     +,   1.6784345E-03,   1.6336128E-03,   1.5892405E-03
     +,   1.5455246E-03,   1.5026460E-03,   1.4607620E-03
     +,   1.4200149E-03,   1.3805215E-03,   1.3423861E-03
     +,   1.3056856E-03,   1.2704884E-03,   1.2368357E-03
     +,   1.2047541E-03,   1.1742497E-03,   1.1453144E-03
     +,   1.1179177E-03,   1.0920181E-03,   1.0675587E-03
     +,   1.0444743E-03,   1.0226875E-03,   1.0021174E-03
     +,   9.8267780E-04,   9.6428132E-04,   9.4684085E-04
     +,   9.3026814E-04,   9.1448007E-04,   8.9939369E-04
     +,   8.8493212E-04,   8.7101897E-04,   8.5758319E-04
     +,   8.4455759E-04,   8.3187787E-04,   8.1948499E-04
     +,   8.0732495E-04,   7.9534733E-04,   7.8350928E-04
     +,   7.7177410E-04,   7.6011184E-04,   7.4850180E-04
     +,   7.3692988E-04,   7.2539272E-04,   7.1389327E-04
     +,   7.0244441E-04,   6.9106556E-04,   6.7978509E-04
     +,   6.6863431E-04,   6.5765053E-04,   6.4687454E-04
     +,   6.3634763E-04,   6.2611233E-04,   6.1620772E-04
     +,   6.0667231E-04,   5.9753843E-04,   5.8883487E-04
     +,   5.8058329E-04,   5.7280081E-04,   5.6549511E-04
     +,   5.5866956E-04,   5.5231951E-04,   5.4643460E-04
     +,   5.4099888E-04,   5.3599064E-04,   5.3138466E-04
     +,   5.2715203E-04,   5.2326079E-04,   5.1967712E-04
     +,   5.1636703E-04,   5.1329512E-04,   5.1042740E-04
     +,   5.0773064E-04,   5.0517317E-04,   5.0272554E-04
     +,   5.0036167E-04,   4.9805711E-04,   4.9579202E-04
     +,   4.9354852E-04,   4.9131329E-04,   4.8907584E-04
     +,   4.8683016E-04,   4.8457217E-04,   4.8230225E-04
     +,   4.8002254E-04,   4.7773987E-04,   4.7546165E-04
     +,   4.7319860E-04,   4.7096296E-04,   4.6876838E-04
     +,   4.6662960E-04,   4.6456215E-04,   4.6258213E-04
     +,   4.6070502E-04,   4.5894599E-04,   4.5731969E-04
     +,   4.5584037E-04,   4.5451970E-04,   4.5336911E-04
     +,   4.5239792E-04,   4.5161421E-04,   4.5102395E-04
     +,   4.5063230E-04,   4.5044257E-04,   4.5045681E-04
     +,   4.5067654E-04,   4.5110192E-04,   4.5173304E-04
     +,   4.5256974E-04,   4.5361207E-04,   4.5486062E-04
     +,   4.5631692E-04,   4.5798306E-04,   4.5986287E-04
     +,   4.6196158E-04,   4.6428625E-04,   4.6684491E-04
     +,   4.6964802E-04,   4.7270680E-04,   4.7603421E-04
     +,   4.7964440E-04,   4.8355182E-04,   4.8777135E-04
     +,   4.9231725E-04,   4.9720373E-04,   5.0244300E-04
     +,   5.0804485E-04,   5.1401707E-04,   5.2036386E-04
     +,   5.2708521E-04,   5.3417572E-04,   5.4162589E-04
     +,   5.4942042E-04,   5.5753678E-04,   5.6594668E-04
     +,   5.7461555E-04,   5.8350153E-04,   5.9255556E-04
     +,   6.0172356E-04,   6.1094441E-04,   6.2015152E-04
     +,   6.2927289E-04,   6.3823309E-04,   6.4695359E-04
     +,   6.5535255E-04,   6.6334655E-04,   6.7085313E-04
     +,   6.7779043E-04,   6.8407820E-04,   6.8963954E-04
     +,   6.9440249E-04,   6.9830031E-04,   7.0127193E-04
     +,   7.0326484E-04,   7.0423406E-04,   7.0414308E-04
     +,   7.0296513E-04,   7.0068246E-04,   6.9728744E-04
     +,   6.9278211E-04,   6.8717817E-04,   6.8049645E-04
     +,   6.7276647E-04,   6.6402677E-04,   6.5432297E-04
     +,   6.4370700E-04,   6.3223817E-04,   6.1998022E-04
     +,   6.0700113E-04,   5.9337146E-04,   5.7916529E-04
     +,   5.6445797E-04,   5.4932438E-04,   5.3383940E-04
     +,   5.1807723E-04,   5.0211063E-04,   4.8600879E-04
     +,   4.6983775E-04,   4.5366189E-04,   4.3754012E-04
     +,   4.2152693E-04,   4.0567387E-04,   3.9002788E-04
     +,   3.7463012E-04,   3.5951741E-04,   3.4472294E-04
     +,   3.3027542E-04,   3.1619854E-04,   3.0251176E-04
     +,   2.8923142E-04,   2.7637041E-04,   2.6393728E-04
     +,   2.5193731E-04,   2.4037424E-04,   2.2924785E-04
     +,   2.1855556E-04,   2.0829355E-04,   1.9845588E-04
     +,   1.8903440E-04,   1.8001955E-04,   1.7140122E-04
     +,   1.6316825E-04,   1.5530809E-04,   1.4780767E-04
     +,   1.4065420E-04,   1.3383356E-04,   1.2733246E-04
     +,   1.2113668E-04,   1.1523289E-04,   1.0960716E-04
     +,   1.0424656E-04,   9.9137789E-05,   9.4268609E-05
     +,   8.9626636E-05,   8.5200532E-05,   8.0979022E-05
     +,   7.6951452E-05,   7.3108087E-05,   6.9439171E-05
     +,   6.5936161E-05,   6.2590421E-05,   5.9394362E-05
     +,   5.6340512E-05,   5.3422275E-05,   5.0633138E-05
     +,   4.7967413E-05,   4.5419434E-05,   4.2984309E-05
     +,   4.0657134E-05,   3.8433656E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt65 = Yx/0.0536666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3708923E-04,   2.4842229E-04
     +,   2.5991493E-04,   2.7156045E-04,   2.8335734E-04
     +,   2.9531002E-04,   3.0743034E-04,   3.1973812E-04
     +,   3.3226193E-04,   3.4504075E-04,   3.5812266E-04
     +,   3.7156630E-04,   3.8543998E-04,   3.9982170E-04
     +,   4.1479690E-04,   4.3045834E-04,   4.4690337E-04
     +,   4.6423252E-04,   4.8254573E-04,   5.0194073E-04
     +,   5.2250968E-04,   5.4433703E-04,   5.6749571E-04
     +,   5.9204741E-04,   6.1803643E-04,   6.4549403E-04
     +,   6.7443313E-04,   7.0485100E-04,   7.3673017E-04
     +,   7.7003858E-04,   8.0473238E-04,   8.4075879E-04
     +,   8.7805698E-04,   9.1656164E-04,   9.5620396E-04
     +,   9.9691353E-04,   1.0386177E-03,   1.0812418E-03
     +,   1.1247089E-03,   1.1689331E-03,   1.2138229E-03
     +,   1.2592737E-03,   1.3051693E-03,   1.3513739E-03
     +,   1.3977373E-03,   1.4440918E-03,   1.4902572E-03
     +,   1.5360424E-03,   1.5812548E-03,   1.6257057E-03
     +,   1.6692196E-03,   1.7116447E-03,   1.7528610E-03
     +,   1.7927857E-03,   1.8313788E-03,   1.8686465E-03
     +,   1.9046386E-03,   1.9394404E-03,   1.9731671E-03
     +,   2.0059454E-03,   2.0379121E-03,   2.0691794E-03
     +,   2.0998367E-03,   2.1299261E-03,   2.1594397E-03
     +,   2.1882991E-03,   2.2163666E-03,   2.2434301E-03
     +,   2.2692212E-03,   2.2934119E-03,   2.3156309E-03
     +,   2.3354713E-03,   2.3525043E-03,   2.3662921E-03
     +,   2.3764006E-03,   2.3824133E-03,   2.3839409E-03
     +,   2.3806356E-03,   2.3722078E-03,   2.3584331E-03
     +,   2.3391761E-03,   2.3143904E-03,   2.2841475E-03
     +,   2.2486306E-03,   2.2081519E-03,   2.1631466E-03
     +,   2.1141723E-03,   2.0618890E-03,   2.0070504E-03
     +,   1.9504669E-03,   1.8929809E-03,   1.8354363E-03
     +,   1.7786415E-03,   1.7233319E-03,   1.6701471E-03
     +,   1.6196121E-03,   1.5721139E-03,   1.5279014E-03
     +,   1.4870805E-03,   1.4496330E-03,   1.4154201E-03
     +,   1.3842173E-03,   1.3557238E-03,   1.3295995E-03
     +,   1.3054808E-03,   1.2830053E-03,   1.2618322E-03
     +,   1.2416518E-03,   1.2221965E-03,   1.2032471E-03
     +,   1.1846325E-03,   1.1662263E-03,   1.1479447E-03
     +,   1.1297336E-03,   1.1115700E-03,   1.0934470E-03
     +,   1.0753698E-03,   1.0573488E-03,   1.0393985E-03
     +,   1.0215286E-03,   1.0037450E-03,   9.8605023E-04
     +,   9.6844183E-04,   9.5091155E-04,   9.3345082E-04
     +,   9.1604970E-04,   8.9869916E-04,   8.8139315E-04
     +,   8.6412736E-04,   8.4690534E-04,   8.2973269E-04
     +,   8.1262353E-04,   7.9559401E-04,   7.7866996E-04
     +,   7.6187839E-04,   7.4525166E-04,   7.2882627E-04
     +,   7.1264076E-04,   6.9673633E-04,   6.8115245E-04
     +,   6.6593132E-04,   6.5111433E-04,   6.3673966E-04
     +,   6.2284380E-04,   6.0946221E-04,   5.9662515E-04
     +,   5.8435841E-04,   5.7268603E-04,   5.6162657E-04
     +,   5.5119355E-04,   5.4139632E-04,   5.3224020E-04
     +,   5.2372669E-04,   5.1585253E-04,   5.0861185E-04
     +,   5.0199614E-04,   4.9599481E-04,   4.9059559E-04
     +,   4.8578531E-04,   4.8155125E-04,   4.7788073E-04
     +,   4.7476252E-04,   4.7218706E-04,   4.7014692E-04
     +,   4.6863680E-04,   4.6765467E-04,   4.6720047E-04
     +,   4.6727702E-04,   4.6788980E-04,   4.6904624E-04
     +,   4.7075542E-04,   4.7302720E-04,   4.7587260E-04
     +,   4.7930147E-04,   4.8332333E-04,   4.8794522E-04
     +,   4.9317145E-04,   4.9900322E-04,   5.0543604E-04
     +,   5.1246129E-04,   5.2006415E-04,   5.2822317E-04
     +,   5.3690991E-04,   5.4608891E-04,   5.5571756E-04
     +,   5.6574476E-04,   5.7611306E-04,   5.8675796E-04
     +,   5.9760938E-04,   6.0859002E-04,   6.1961898E-04
     +,   6.3061150E-04,   6.4148067E-04,   6.5213646E-04
     +,   6.6249067E-04,   6.7245611E-04,   6.8194797E-04
     +,   6.9088495E-04,   6.9919223E-04,   7.0680142E-04
     +,   7.1365177E-04,   7.1969128E-04,   7.2487781E-04
     +,   7.2917889E-04,   7.3257391E-04,   7.3505240E-04
     +,   7.3661527E-04,   7.3727377E-04,   7.3705055E-04
     +,   7.3597714E-04,   7.3409401E-04,   7.3145051E-04
     +,   7.2810147E-04,   7.2410901E-04,   7.1953796E-04
     +,   7.1445666E-04,   7.0893503E-04,   7.0304278E-04
     +,   6.9684820E-04,   6.9041690E-04,   6.8381091E-04
     +,   6.7708630E-04,   6.7029445E-04,   6.6347903E-04
     +,   6.5667654E-04,   6.4991583E-04,   6.4321776E-04
     +,   6.3659501E-04,   6.3005235E-04,   6.2358630E-04
     +,   6.1718706E-04,   6.1083818E-04,   6.0451683E-04
     +,   5.9819472E-04,   5.9184147E-04,   5.8542110E-04
     +,   5.7889713E-04,   5.7223137E-04,   5.6538603E-04
     +,   5.5832381E-04,   5.5100874E-04,   5.4340850E-04
     +,   5.3549383E-04,   5.2723888E-04,   5.1862269E-04
     +,   5.0962961E-04,   5.0024915E-04,   4.9047649E-04
     +,   4.8031111E-04,   4.6976027E-04,   4.5883437E-04
     +,   4.4754974E-04,   4.3592803E-04,   4.2399522E-04
     +,   4.1178061E-04,   3.9931657E-04,   3.8663947E-04
     +,   3.7378789E-04,   3.6080138E-04,   3.4772043E-04
     +,   3.3458712E-04,   3.2144354E-04,   3.0833052E-04
     +,   2.9528787E-04,   2.8235535E-04,   2.6956966E-04
     +,   2.5696543E-04,   2.4457584E-04,   2.3243140E-04
     +,   2.2055903E-04,   2.0898289E-04,   1.9772502E-04
     +,   1.8680417E-04,   1.7623593E-04,   1.6603251E-04
     +,   1.5620455E-04,   1.4675871E-04,   1.3770029E-04
     +,   1.2903108E-04,   1.2075163E-04,   1.1285945E-04
     +,   1.0535137E-04,   9.8221339E-05,   9.1462920E-05
     +,   8.5067470E-05,   7.9026097E-05,   7.3328352E-05
     +,   6.7963090E-05,   6.2919047E-05,   5.8183818E-05
     +,   5.3745327E-05,   4.9590657E-05,   4.5707384E-05
     +,   4.2082491E-05,   3.8703562E-05,   3.5557863E-05
     +,   3.2633288E-05,   2.9917577E-05,   2.7399137E-05
     +,   2.5066411E-05,   2.2908493E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt70 = Yx/0.0603513513513514
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2968329E-04,   1.3511394E-04
     +,   1.4064825E-04,   1.4628805E-04,   1.5203665E-04
     +,   1.5789889E-04,   1.6388121E-04,   1.6999202E-04
     +,   1.7624148E-04,   1.8264237E-04,   1.8920934E-04
     +,   1.9595952E-04,   2.0291294E-04,   2.1009218E-04
     +,   2.1752274E-04,   2.2523363E-04,   2.3325680E-04
     +,   2.4162828E-04,   2.5038782E-04,   2.5957922E-04
     +,   2.6925057E-04,   2.7945428E-04,   2.9024709E-04
     +,   3.0169034E-04,   3.1384762E-04,   3.2678686E-04
     +,   3.4057663E-04,   3.5528635E-04,   3.7098333E-04
     +,   3.8773110E-04,   4.0558662E-04,   4.2459724E-04
     +,   4.4479797E-04,   4.6620893E-04,   4.8883184E-04
     +,   5.1264936E-04,   5.3762418E-04,   5.6369690E-04
     +,   5.9079262E-04,   6.1881810E-04,   6.4767321E-04
     +,   6.7725376E-04,   7.0746231E-04,   7.3821837E-04
     +,   7.6947111E-04,   8.0121093E-04,   8.3348370E-04
     +,   8.6640299E-04,   9.0016233E-04,   9.3504443E-04
     +,   9.7142684E-04,   1.0097863E-03,   1.0506932E-03
     +,   1.0948112E-03,   1.1428692E-03,   1.1956561E-03
     +,   1.2539831E-03,   1.3186568E-03,   1.3904416E-03
     +,   1.4700242E-03,   1.5579755E-03,   1.6547175E-03
     +,   1.7604857E-03,   1.8753146E-03,   1.9990113E-03
     +,   2.1311189E-03,   2.2709328E-03,   2.4174508E-03
     +,   2.5693942E-03,   2.7251565E-03,   2.8828422E-03
     +,   3.0402283E-03,   3.1948325E-03,   3.3439274E-03
     +,   3.4846647E-03,   3.6141714E-03,   3.7297138E-03
     +,   3.8288832E-03,   3.9097797E-03,   3.9712051E-03
     +,   4.0127640E-03,   4.0349769E-03,   4.0392550E-03
     +,   4.0277923E-03,   4.0033977E-03,   3.9692307E-03
     +,   3.9285272E-03,   3.8842936E-03,   3.8390618E-03
     +,   3.7947041E-03,   3.7523280E-03,   3.7122897E-03
     +,   3.6742543E-03,   3.6373560E-03,   3.6003618E-03
     +,   3.5618581E-03,   3.5204173E-03,   3.4747189E-03
     +,   3.4236268E-03,   3.3662634E-03,   3.3019886E-03
     +,   3.2304421E-03,   3.1515018E-03,   3.0653030E-03
     +,   2.9722149E-03,   2.8728433E-03,   2.7680334E-03
     +,   2.6588407E-03,   2.5465081E-03,   2.4324162E-03
     +,   2.3180479E-03,   2.2048964E-03,   2.0944197E-03
     +,   1.9879458E-03,   1.8866413E-03,   1.7914250E-03
     +,   1.7029684E-03,   1.6216463E-03,   1.5475646E-03
     +,   1.4805563E-03,   1.4202234E-03,   1.3659834E-03
     +,   1.3171133E-03,   1.2728036E-03,   1.2322130E-03
     +,   1.1945228E-03,   1.1589699E-03,   1.1248862E-03
     +,   1.0917167E-03,   1.0590383E-03,   1.0265541E-03
     +,   9.9409546E-04,   9.6160226E-04,   9.2911482E-04
     +,   8.9674321E-04,   8.6465222E-04,   8.3304197E-04
     +,   8.0212689E-04,   7.7211717E-04,   7.4321026E-04
     +,   7.1557966E-04,   6.8937091E-04,   6.6469342E-04
     +,   6.4162561E-04,   6.2021584E-04,   6.0048304E-04
     +,   5.8242166E-04,   5.6600937E-04,   5.5120810E-04
     +,   5.3796935E-04,   5.2623724E-04,   5.1595381E-04
     +,   5.0705782E-04,   4.9948826E-04,   4.9318350E-04
     +,   4.8808305E-04,   4.8412674E-04,   4.8125282E-04
     +,   4.7939928E-04,   4.7850178E-04,   4.7849395E-04
     +,   4.7930659E-04,   4.8086743E-04,   4.8310135E-04
     +,   4.8593027E-04,   4.8927410E-04,   4.9305049E-04
     +,   4.9717631E-04,   5.0156820E-04,   5.0614268E-04
     +,   5.1081803E-04,   5.1551394E-04,   5.2015332E-04
     +,   5.2466290E-04,   5.2897271E-04,   5.3301727E-04
     +,   5.3673715E-04,   5.4007751E-04,   5.4298918E-04
     +,   5.4542982E-04,   5.4736243E-04,   5.4875656E-04
     +,   5.4958835E-04,   5.4983969E-04,   5.4949883E-04
     +,   5.4856058E-04,   5.4702518E-04,   5.4489903E-04
     +,   5.4219377E-04,   5.3892622E-04,   5.3511810E-04
     +,   5.3079554E-04,   5.2598881E-04,   5.2073202E-04
     +,   5.1506213E-04,   5.0901866E-04,   5.0264364E-04
     +,   4.9598067E-04,   4.8907450E-04,   4.8196974E-04
     +,   4.7471258E-04,   4.6734765E-04,   4.5991931E-04
     +,   4.5247015E-04,   4.4504172E-04,   4.3767289E-04
     +,   4.3040031E-04,   4.2325820E-04,   4.1627805E-04
     +,   4.0948749E-04,   4.0291130E-04,   3.9657103E-04
     +,   3.9048478E-04,   3.8466696E-04,   3.7912876E-04
     +,   3.7387805E-04,   3.6891960E-04,   3.6425490E-04
     +,   3.5988248E-04,   3.5579837E-04,   3.5199604E-04
     +,   3.4846598E-04,   3.4519774E-04,   3.4217813E-04
     +,   3.3939257E-04,   3.3682483E-04,   3.3445813E-04
     +,   3.3227398E-04,   3.3025374E-04,   3.2837765E-04
     +,   3.2662603E-04,   3.2497893E-04,   3.2341635E-04
     +,   3.2191811E-04,   3.2046478E-04,   3.1903721E-04
     +,   3.1761665E-04,   3.1618512E-04,   3.1472518E-04
     +,   3.1322055E-04,   3.1165546E-04,   3.1001534E-04
     +,   3.0828689E-04,   3.0645716E-04,   3.0451521E-04
     +,   3.0245050E-04,   3.0025415E-04,   2.9791842E-04
     +,   2.9543656E-04,   2.9280331E-04,   2.9001446E-04
     +,   2.8706709E-04,   2.8395944E-04,   2.8069099E-04
     +,   2.7726236E-04,   2.7367505E-04,   2.6993177E-04
     +,   2.6603643E-04,   2.6199373E-04,   2.5780883E-04
     +,   2.5348843E-04,   2.4903976E-04,   2.4447049E-04
     +,   2.3978890E-04,   2.3500416E-04,   2.3012569E-04
     +,   2.2516301E-04,   2.2012637E-04,   2.1502623E-04
     +,   2.0987303E-04,   2.0467695E-04,   1.9944881E-04
     +,   1.9419935E-04,   1.8893869E-04,   1.8367685E-04
     +,   1.7842418E-04,   1.7318994E-04,   1.6798396E-04
     +,   1.6281485E-04,   1.5769149E-04,   1.5262171E-04
     +,   1.4761357E-04,   1.4267385E-04,   1.3780966E-04
     +,   1.3302684E-04,   1.2833133E-04,   1.2372814E-04
     +,   1.1922172E-04,   1.1481644E-04,   1.1051551E-04
     +,   1.0632230E-04,   1.0223910E-04,   9.8268247E-05
     +,   9.4411000E-05,   9.0668815E-05,   8.7042114E-05
     +,   8.3531471E-05,   8.0136590E-05,   7.6857221E-05
     +,   7.3692390E-05,   7.0641167E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt75 = Yx/0.0687105263157895
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.6744461E-05,   9.1165348E-05
     +,   9.5792027E-05,   1.0063125E-04,   1.0568964E-04
     +,   1.1097357E-04,   1.1648931E-04,   1.2224277E-04
     +,   1.2823967E-04,   1.3448569E-04,   1.4098611E-04
     +,   1.4774606E-04,   1.5477063E-04,   1.6206490E-04
     +,   1.6963396E-04,   1.7748306E-04,   1.8561777E-04
     +,   1.9404398E-04,   2.0276796E-04,   2.1179653E-04
     +,   2.2113699E-04,   2.3079703E-04,   2.4078462E-04
     +,   2.5110855E-04,   2.6177638E-04,   2.7279663E-04
     +,   2.8417644E-04,   2.9592207E-04,   3.0803823E-04
     +,   3.2052811E-04,   3.3339235E-04,   3.4662965E-04
     +,   3.6023615E-04,   3.7420608E-04,   3.8853206E-04
     +,   4.0320575E-04,   4.1821884E-04,   4.3356515E-04
     +,   4.4924239E-04,   4.6525200E-04,   4.8160442E-04
     +,   4.9831858E-04,   5.1542366E-04,   5.3296215E-04
     +,   5.5098761E-04,   5.6956633E-04,   5.8877555E-04
     +,   6.0869998E-04,   6.2942959E-04,   6.5105438E-04
     +,   6.7365944E-04,   6.9732103E-04,   7.2210107E-04
     +,   7.4804627E-04,   7.7518407E-04,   8.0352981E-04
     +,   8.3308702E-04,   8.6385960E-04,   8.9586334E-04
     +,   9.2913868E-04,   9.6376811E-04,   9.9988782E-04
     +,   1.0376961E-03,   1.0774651E-03,   1.1195325E-03
     +,   1.1642916E-03,   1.2121790E-03,   1.2636423E-03
     +,   1.3191288E-03,   1.3790459E-03,   1.4437602E-03
     +,   1.5135757E-03,   1.5887535E-03,   1.6695037E-03
     +,   1.7560242E-03,   1.8484937E-03,   1.9470690E-03
     +,   2.0518503E-03,   2.1628246E-03,   2.2797831E-03
     +,   2.4021994E-03,   2.5291936E-03,   2.6594799E-03
     +,   2.7914592E-03,   2.9233773E-03,   3.0536265E-03
     +,   3.1810608E-03,   3.3053900E-03,   3.4273744E-03
     +,   3.5489392E-03,   3.6729847E-03,   3.8029496E-03
     +,   3.9422107E-03,   4.0934104E-03,   4.2578760E-03
     +,   4.4352571E-03,   4.6235532E-03,   4.8194299E-03
     +,   5.0188242E-03,   5.2176127E-03,   5.4122549E-03
     +,   5.6000999E-03,   5.7795285E-03,   5.9497035E-03
     +,   6.1102170E-03,   6.2606963E-03,   6.4004157E-03
     +,   6.5281298E-03,   6.6419682E-03,   6.7394525E-03
     +,   6.8175299E-03,   6.8726512E-03,   6.9008647E-03
     +,   6.8980539E-03,   6.8602269E-03,   6.7840349E-03
     +,   6.6672345E-03,   6.5091625E-03,   6.3110925E-03
     +,   6.0762656E-03,   5.8097108E-03,   5.5179116E-03
     +,   5.2082273E-03,   4.8883460E-03,   4.5657451E-03
     +,   4.2473054E-03,   3.9389199E-03,   3.6453700E-03
     +,   3.3701430E-03,   3.1154994E-03,   2.8825011E-03
     +,   2.6712038E-03,   2.4808191E-03,   2.3100022E-03
     +,   2.1570406E-03,   2.0201127E-03,   1.8974547E-03
     +,   1.7874726E-03,   1.6887960E-03,   1.6002884E-03
     +,   1.5210117E-03,   1.4501557E-03,   1.3869738E-03
     +,   1.3307286E-03,   1.2806626E-03,   1.2359766E-03
     +,   1.1958441E-03,   1.1594433E-03,   1.1259869E-03
     +,   1.0947590E-03,   1.0651463E-03,   1.0366618E-03
     +,   1.0089489E-03,   9.8177604E-04,   9.5502671E-04
     +,   9.2867919E-04,   9.0278196E-04,   8.7743002E-04
     +,   8.5274252E-04,   8.2884962E-04,   8.0587191E-04
     +,   7.8391324E-04,   7.6305732E-04,   7.4336381E-04
     +,   7.2486646E-04,   7.0757681E-04,   6.9148897E-04
     +,   6.7658006E-04,   6.6281576E-04,   6.5015251E-04
     +,   6.3854258E-04,   6.2793650E-04,   6.1828311E-04
     +,   6.0953415E-04,   6.0164474E-04,   5.9457298E-04
     +,   5.8828219E-04,   5.8274111E-04,   5.7792244E-04
     +,   5.7380408E-04,   5.7036709E-04,   5.6759652E-04
     +,   5.6548009E-04,   5.6400709E-04,   5.6316820E-04
     +,   5.6295388E-04,   5.6335400E-04,   5.6435721E-04
     +,   5.6594983E-04,   5.6811550E-04,   5.7083386E-04
     +,   5.7408115E-04,   5.7782902E-04,   5.8204355E-04
     +,   5.8668654E-04,   5.9171382E-04,   5.9707521E-04
     +,   6.0271419E-04,   6.0857018E-04,   6.1457464E-04
     +,   6.2065368E-04,   6.2672829E-04,   6.3271384E-04
     +,   6.3852168E-04,   6.4405834E-04,   6.4922788E-04
     +,   6.5393315E-04,   6.5807492E-04,   6.6155603E-04
     +,   6.6428090E-04,   6.6615880E-04,   6.6710380E-04
     +,   6.6703826E-04,   6.6589291E-04,   6.6360994E-04
     +,   6.6014339E-04,   6.5546122E-04,   6.4954523E-04
     +,   6.4239290E-04,   6.3401775E-04,   6.2444829E-04
     +,   6.1372860E-04,   6.0191826E-04,   5.8909075E-04
     +,   5.7533180E-04,   5.6073774E-04,   5.4541533E-04
     +,   5.2947918E-04,   5.1304791E-04,   4.9624342E-04
     +,   4.7918916E-04,   4.6200847E-04,   4.4481960E-04
     +,   4.2773641E-04,   4.1086704E-04,   3.9431063E-04
     +,   3.7815614E-04,   3.6248367E-04,   3.4736234E-04
     +,   3.3284840E-04,   3.1898709E-04,   3.0581246E-04
     +,   2.9334787E-04,   2.8160488E-04,   2.7058503E-04
     +,   2.6028178E-04,   2.5068026E-04,   2.4175741E-04
     +,   2.3348465E-04,   2.2582868E-04,   2.1875168E-04
     +,   2.1221288E-04,   2.0616986E-04,   2.0057919E-04
     +,   1.9539667E-04,   1.9057879E-04,   1.8608334E-04
     +,   1.8186984E-04,   1.7789951E-04,   1.7413621E-04
     +,   1.7054660E-04,   1.6710043E-04,   1.6377006E-04
     +,   1.6053104E-04,   1.5736223E-04,   1.5424509E-04
     +,   1.5116404E-04,   1.4810628E-04,   1.4506177E-04
     +,   1.4202234E-04,   1.3898216E-04,   1.3593747E-04
     +,   1.3288624E-04,   1.2982782E-04,   1.2676274E-04
     +,   1.2369300E-04,   1.2062109E-04,   1.1755079E-04
     +,   1.1448579E-04,   1.1143083E-04,   1.0839043E-04
     +,   1.0536975E-04,   1.0237353E-04,   9.9406934E-05
     +,   9.6474520E-05,   9.3581184E-05,   9.0731177E-05
     +,   8.7928485E-05,   8.5177031E-05,   8.2480081E-05
     +,   7.9840778E-05,   7.7261575E-05,   7.4744916E-05
     +,   7.2292409E-05,   6.9905691E-05,   6.7585657E-05
     +,   6.5333188E-05,   6.3148465E-05,   6.1031686E-05
     +,   5.8982423E-05,   5.7000292E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt80 = Yx/0.093975
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.2173246E-05,   8.4329644E-05
     +,   8.6481174E-05,   8.8626381E-05,   9.0763948E-05
     +,   9.2892886E-05,   9.5012423E-05,   9.7122138E-05
     +,   9.9221848E-05,   1.0131189E-04,   1.0339287E-04
     +,   1.0546573E-04,   1.0753196E-04,   1.0959346E-04
     +,   1.1165247E-04,   1.1371177E-04,   1.1577462E-04
     +,   1.1784461E-04,   1.1992585E-04,   1.2202279E-04
     +,   1.2414031E-04,   1.2628348E-04,   1.2845789E-04
     +,   1.3066918E-04,   1.3292315E-04,   1.3522578E-04
     +,   1.3758311E-04,   1.4000092E-04,   1.4248512E-04
     +,   1.4504130E-04,   1.4767481E-04,   1.5039077E-04
     +,   1.5319399E-04,   1.5608888E-04,   1.5907970E-04
     +,   1.6217037E-04,   1.6536479E-04,   1.6866667E-04
     +,   1.7208034E-04,   1.7561000E-04,   1.7926113E-04
     +,   1.8303978E-04,   1.8695375E-04,   1.9101225E-04
     +,   1.9522689E-04,   1.9961194E-04,   2.0418451E-04
     +,   2.0896536E-04,   2.1397900E-04,   2.1925423E-04
     +,   2.2482447E-04,   2.3072801E-04,   2.3700815E-04
     +,   2.4371409E-04,   2.5089964E-04,   2.5862519E-04
     +,   2.6695654E-04,   2.7596511E-04,   2.8572863E-04
     +,   2.9633031E-04,   3.0785953E-04,   3.2041126E-04
     +,   3.3408587E-04,   3.4898985E-04,   3.6523529E-04
     +,   3.8293755E-04,   4.0221933E-04,   4.2320450E-04
     +,   4.4602316E-04,   4.7080542E-04,   4.9768569E-04
     +,   5.2679580E-04,   5.5826828E-04,   5.9222785E-04
     +,   6.2879384E-04,   6.6807296E-04,   7.1015191E-04
     +,   7.5509201E-04,   8.0292515E-04,   8.5364550E-04
     +,   9.0719754E-04,   9.6348178E-04,   1.0223400E-03
     +,   1.0835730E-03,   1.1469295E-03,   1.2121366E-03
     +,   1.2788967E-03,   1.3469241E-03,   1.4159417E-03
     +,   1.4857152E-03,   1.5560439E-03,   1.6267524E-03
     +,   1.6976726E-03,   1.7686121E-03,   1.8393028E-03
     +,   1.9093514E-03,   1.9782179E-03,   2.0451981E-03
     +,   2.1094831E-03,   2.1702510E-03,   2.2268689E-03
     +,   2.2791473E-03,   2.3276978E-03,   2.3743147E-03
     +,   2.4223544E-03,   2.4770293E-03,   2.5454620E-03
     +,   2.6364459E-03,   2.7597775E-03,   2.9251643E-03
     +,   3.1408053E-03,   3.4119887E-03,   3.7398331E-03
     +,   4.1208076E-03,   4.5468127E-03,   5.0062495E-03
     +,   5.4853871E-03,   5.9702457E-03,   6.4482423E-03
     +,   6.9100070E-03,   7.3508318E-03,   7.7715009E-03
     +,   8.1779612E-03,   8.5792243E-03,   8.9834761E-03
     +,   9.3935914E-03,   9.8041687E-03,   1.0201355E-02
     +,   1.0566423E-02,   1.0880939E-02,   1.1131264E-02
     +,   1.1309356E-02,   1.1409892E-02,   1.1425497E-02
     +,   1.1343892E-02,   1.1149528E-02,   1.0829846E-02
     +,   1.0383393E-02,   9.8254420E-03,   9.1882227E-03
     +,   8.5153067E-03,   7.8522349E-03,   7.2373073E-03
     +,   6.6955471E-03,   6.2369960E-03,   5.8585810E-03
     +,   5.5481941E-03,   5.2890889E-03,   5.0636111E-03
     +,   4.8557878E-03,   4.6529137E-03,   4.4462853E-03
     +,   4.2313193E-03,   4.0071751E-03,   3.7760753E-03
     +,   3.5424102E-03,   3.3116690E-03,   3.0893853E-03
     +,   2.8802920E-03,   2.6877550E-03,   2.5134743E-03
     +,   2.3576042E-03,   2.2190625E-03,   2.0959531E-03
     +,   1.9860046E-03,   1.8869215E-03,   1.7966358E-03
     +,   1.7134323E-03,   1.6359776E-03,   1.5633206E-03
     +,   1.4948492E-03,   1.4302196E-03,   1.3692955E-03
     +,   1.3120833E-03,   1.2586752E-03,   1.2091830E-03
     +,   1.1636961E-03,   1.1222496E-03,   1.0847971E-03
     +,   1.0512015E-03,   1.0212385E-03,   9.9461072E-04
     +,   9.7096409E-04,   9.4990438E-04,   9.3102286E-04
     +,   9.1391167E-04,   8.9818123E-04,   8.8346994E-04
     +,   8.6945150E-04,   8.5584557E-04,   8.4241410E-04
     +,   8.2896411E-04,   8.1534887E-04,   8.0146483E-04
     +,   7.8724651E-04,   7.7266671E-04,   7.5773237E-04
     +,   7.4247929E-04,   7.2696875E-04,   7.1128219E-04
     +,   6.9551932E-04,   6.7979138E-04,   6.6421606E-04
     +,   6.4891344E-04,   6.3400413E-04,   6.1960117E-04
     +,   6.0580857E-04,   5.9271901E-04,   5.8040977E-04
     +,   5.6894048E-04,   5.5835303E-04,   5.4867059E-04
     +,   5.3989771E-04,   5.3201965E-04,   5.2500499E-04
     +,   5.1880663E-04,   5.1336311E-04,   5.0860131E-04
     +,   5.0443801E-04,   5.0078297E-04,   4.9754034E-04
     +,   4.9461081E-04,   4.9189519E-04,   4.8929418E-04
     +,   4.8671110E-04,   4.8405354E-04,   4.8123425E-04
     +,   4.7817244E-04,   4.7479465E-04,   4.7103481E-04
     +,   4.6683627E-04,   4.6215087E-04,   4.5693954E-04
     +,   4.5117209E-04,   4.4482847E-04,   4.3789673E-04
     +,   4.3037409E-04,   4.2226611E-04,   4.1358688E-04
     +,   4.0435721E-04,   3.9460475E-04,   3.8436378E-04
     +,   3.7367418E-04,   3.6258006E-04,   3.5112901E-04
     +,   3.3937290E-04,   3.2736547E-04,   3.1516128E-04
     +,   3.0281587E-04,   2.9038556E-04,   2.7792493E-04
     +,   2.6548703E-04,   2.5312381E-04,   2.4088466E-04
     +,   2.2881519E-04,   2.1695773E-04,   2.0535162E-04
     +,   1.9403241E-04,   1.8303090E-04,   1.7237363E-04
     +,   1.6208392E-04,   1.5218077E-04,   1.4267860E-04
     +,   1.3358796E-04,   1.2491677E-04,   1.1666836E-04
     +,   1.0884308E-04,   1.0143879E-04,   9.4450632E-05
     +,   8.7870969E-05,   8.1690021E-05,   7.5896714E-05
     +,   7.0478396E-05,   6.5420827E-05,   6.0708859E-05
     +,   5.6327030E-05,   5.2258827E-05,   4.8487978E-05
     +,   4.4997618E-05,   4.1771429E-05,   3.8792859E-05
     +,   3.6046087E-05,   3.3515396E-05,   3.1185911E-05
     +,   2.9043078E-05,   2.7073271E-05,   2.5263353E-05
     +,   2.3600916E-05,   2.2074453E-05,   2.0672982E-05
     +,   1.9386418E-05,   1.8205219E-05,   1.7120692E-05
     +,   1.6124653E-05,   1.5209685E-05,   1.4368843E-05
     +,   1.3595853E-05,   1.2884862E-05,   1.2230616E-05
     +,   1.1628210E-05,   1.1073254E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt85 = Yx/0.117634146341463
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9977049E-05,   3.1530941E-05
     +,   3.3146920E-05,   3.4825716E-05,   3.6567984E-05
     +,   3.8374306E-05,   4.0245202E-05,   4.2181149E-05
     +,   4.4182590E-05,   4.6250032E-05,   4.8383914E-05
     +,   5.0584778E-05,   5.2853255E-05,   5.5190070E-05
     +,   5.7596168E-05,   6.0072613E-05,   6.2620828E-05
     +,   6.5242442E-05,   6.7939480E-05,   7.0714319E-05
     +,   7.3569812E-05,   7.6509241E-05,   7.9536381E-05
     +,   8.2655679E-05,   8.5871827E-05,   8.9190435E-05
     +,   9.2617396E-05,   9.6159216E-05,   9.9822872E-05
     +,   1.0361581E-04,   1.0754574E-04,   1.1162065E-04
     +,   1.1584868E-04,   1.2023787E-04,   1.2479613E-04
     +,   1.2953089E-04,   1.3444907E-04,   1.3955653E-04
     +,   1.4485854E-04,   1.5035835E-04,   1.5605820E-04
     +,   1.6195816E-04,   1.6805623E-04,   1.7434808E-04
     +,   1.8082678E-04,   1.8748271E-04,   1.9430320E-04
     +,   2.0127263E-04,   2.0837229E-04,   2.1558034E-04
     +,   2.2287192E-04,   2.3021920E-04,   2.3759175E-04
     +,   2.4495675E-04,   2.5227884E-04,   2.5952162E-04
     +,   2.6664688E-04,   2.7361599E-04,   2.8039000E-04
     +,   2.8693056E-04,   2.9320028E-04,   2.9916369E-04
     +,   3.0478704E-04,   3.1004046E-04,   3.1489728E-04
     +,   3.1933462E-04,   3.2333474E-04,   3.2688433E-04
     +,   3.2997591E-04,   3.3260716E-04,   3.3478203E-04
     +,   3.3650949E-04,   3.3780481E-04,   3.3868855E-04
     +,   3.3918660E-04,   3.3933032E-04,   3.3915543E-04
     +,   3.3870229E-04,   3.3801555E-04,   3.3714337E-04
     +,   3.3613772E-04,   3.3505404E-04,   3.3395097E-04
     +,   3.3289075E-04,   3.3193908E-04,   3.3116550E-04
     +,   3.3064379E-04,   3.3045266E-04,   3.3067583E-04
     +,   3.3140319E-04,   3.3273079E-04,   3.3476192E-04
     +,   3.3760685E-04,   3.4138377E-04,   3.4621856E-04
     +,   3.5224389E-04,   3.5960018E-04,   3.6843325E-04
     +,   3.7889450E-04,   3.9113811E-04,   4.0532101E-04
     +,   4.2159864E-04,   4.4012550E-04,   4.6104880E-04
     +,   4.8450954E-04,   5.1063747E-04,   5.3954741E-04
     +,   5.7133462E-04,   6.0607417E-04,   6.4381433E-04
     +,   6.8456662E-04,   7.2830816E-04,   7.7496457E-04
     +,   8.2441460E-04,   8.7647222E-04,   9.3089679E-04
     +,   9.8737958E-04,   1.0455690E-03,   1.1050715E-03
     +,   1.1654969E-03,   1.2264975E-03,   1.2878214E-03
     +,   1.3493908E-03,   1.4113840E-03,   1.4743203E-03
     +,   1.5391320E-03,   1.6072473E-03,   1.6806243E-03
     +,   1.7617886E-03,   1.8537986E-03,   1.9602068E-03
     +,   2.0849162E-03,   2.2320100E-03,   2.4054535E-03
     +,   2.6087693E-03,   2.8446559E-03,   3.1145930E-03
     +,   3.4185699E-03,   3.7549688E-03,   4.1206768E-03
     +,   4.5114672E-03,   4.9228156E-03,   5.3510228E-03
     +,   5.7941945E-03,   6.2526814E-03,   6.7285406E-03
     +,   7.2236978E-03,   7.7376533E-03,   8.2658380E-03
     +,   8.7996190E-03,   9.3282526E-03,   9.8424694E-03
     +,   1.0338330E-02,   1.0819292E-02,   1.1293652E-02
     +,   1.1766021E-02,   1.2225638E-02,   1.2638041E-02
     +,   1.2948296E-02,   1.3098149E-02,   1.3049939E-02
     +,   1.2803597E-02,   1.2395817E-02,   1.1881532E-02
     +,   1.1309354E-02,   1.0706077E-02,   1.0077275E-02
     +,   9.4202021E-03,   8.7381694E-03,   8.0477595E-03
     +,   7.3766955E-03,   6.7560137E-03,   6.2115844E-03
     +,   5.7585896E-03,   5.3996723E-03,   5.1262127E-03
     +,   4.9219835E-03,   4.7676479E-03,   4.6448195E-03
     +,   4.5385552E-03,   4.4380235E-03,   4.3357005E-03
     +,   4.2260243E-03,   4.1044611E-03,   3.9673047E-03
     +,   3.8121664E-03,   3.6386279E-03,   3.4486561E-03
     +,   3.2464822E-03,   3.0379826E-03,   2.8296818E-03
     +,   2.6278072E-03,   2.4375049E-03,   2.2623865E-03
     +,   2.1043967E-03,   1.9639777E-03,   1.8403962E-03
     +,   1.7321244E-03,   1.6372065E-03,   1.5535846E-03
     +,   1.4793365E-03,   1.4128122E-03,   1.3526876E-03
     +,   1.2979796E-03,   1.2480044E-03,   1.2023072E-03
     +,   1.1605966E-03,   1.1226800E-03,   1.0884069E-03
     +,   1.0576254E-03,   1.0301579E-03,   1.0057872E-03
     +,   9.8425255E-04,   9.6524955E-04,   9.4844273E-04
     +,   9.3347946E-04,   9.1999967E-04,   9.0765092E-04
     +,   8.9609955E-04,   8.8504294E-04,   8.7421399E-04
     +,   8.6338527E-04,   8.5237290E-04,   8.4103370E-04
     +,   8.2926225E-04,   8.1698538E-04,   8.0415979E-04
     +,   7.9076405E-04,   7.7679247E-04,   7.6225190E-04
     +,   7.4715726E-04,   7.3152827E-04,   7.1538636E-04
     +,   6.9875381E-04,   6.8165542E-04,   6.6411571E-04
     +,   6.4616051E-04,   6.2782032E-04,   6.0912856E-04
     +,   5.9012236E-04,   5.7084468E-04,   5.5134500E-04
     +,   5.3167820E-04,   5.1190413E-04,   4.9208623E-04
     +,   4.7229262E-04,   4.5259349E-04,   4.3305810E-04
     +,   4.1375443E-04,   3.9474992E-04,   3.7610569E-04
     +,   3.5787746E-04,   3.4011604E-04,   3.2286500E-04
     +,   3.0615949E-04,   2.9002680E-04,   2.7448829E-04
     +,   2.5955777E-04,   2.4524156E-04,   2.3154049E-04
     +,   2.1845079E-04,   2.0596448E-04,   1.9406930E-04
     +,   1.8275008E-04,   1.7199101E-04,   1.6177354E-04
     +,   1.5207840E-04,   1.4288648E-04,   1.3417863E-04
     +,   1.2593511E-04,   1.1813676E-04,   1.1076534E-04
     +,   1.0380310E-04,   9.7232325E-05,   9.1035923E-05
     +,   8.5197884E-05,   7.9701880E-05,   7.4532814E-05
     +,   6.9675225E-05,   6.5114698E-05,   6.0836552E-05
     +,   5.6827048E-05,   5.3072181E-05,   4.9558865E-05
     +,   4.6273872E-05,   4.3204760E-05,   4.0339222E-05
     +,   3.7665337E-05,   3.5171888E-05,   3.2847809E-05
     +,   3.0682761E-05,   2.8666615E-05,   2.6790000E-05
     +,   2.5043755E-05,   2.3419439E-05,   2.1908876E-05
     +,   2.0504545E-05,   1.9199173E-05,   1.7986111E-05
     +,   1.6858950E-05,   1.5811829E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt90 = Yx/0.123833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8621100E-05,   4.0217619E-05
     +,   4.1883177E-05,   4.3620414E-05,   4.5431887E-05
     +,   4.7320031E-05,   4.9287137E-05,   5.1335290E-05
     +,   5.3466352E-05,   5.5681958E-05,   5.7983380E-05
     +,   6.0371542E-05,   6.2846957E-05,   6.5409680E-05
     +,   6.8059322E-05,   7.0794915E-05,   7.3614916E-05
     +,   7.6517194E-05,   7.9498961E-05,   8.2556777E-05
     +,   8.5686443E-05,   8.8883120E-05,   9.2141105E-05
     +,   9.5454277E-05,   9.8815341E-05,   1.0221666E-04
     +,   1.0564970E-04,   1.0910536E-04,   1.1257381E-04
     +,   1.1604476E-04,   1.1950733E-04,   1.2295018E-04
     +,   1.2636161E-04,   1.2972968E-04,   1.3304211E-04
     +,   1.3628666E-04,   1.3945103E-04,   1.4252297E-04
     +,   1.4549069E-04,   1.4834231E-04,   1.5106687E-04
     +,   1.5365373E-04,   1.5609297E-04,   1.5837551E-04
     +,   1.6049313E-04,   1.6243874E-04,   1.6420618E-04
     +,   1.6579068E-04,   1.6718866E-04,   1.6839791E-04
     +,   1.6941760E-04,   1.7024834E-04,   1.7089235E-04
     +,   1.7135327E-04,   1.7163614E-04,   1.7174787E-04
     +,   1.7169656E-04,   1.7149189E-04,   1.7114506E-04
     +,   1.7066854E-04,   1.7007634E-04,   1.6938349E-04
     +,   1.6860657E-04,   1.6776292E-04,   1.6687132E-04
     +,   1.6595119E-04,   1.6502316E-04,   1.6410841E-04
     +,   1.6322898E-04,   1.6240762E-04,   1.6166759E-04
     +,   1.6103245E-04,   1.6052648E-04,   1.6017411E-04
     +,   1.5999998E-04,   1.6002895E-04,   1.6028598E-04
     +,   1.6079596E-04,   1.6158358E-04,   1.6267349E-04
     +,   1.6408975E-04,   1.6585623E-04,   1.6799565E-04
     +,   1.7053023E-04,   1.7348101E-04,   1.7686783E-04
     +,   1.8070870E-04,   1.8502038E-04,   1.8981668E-04
     +,   1.9510955E-04,   2.0090819E-04,   2.0721823E-04
     +,   2.1404176E-04,   2.2137746E-04,   2.2921979E-04
     +,   2.3755792E-04,   2.4637740E-04,   2.5565733E-04
     +,   2.6537300E-04,   2.7549293E-04,   2.8598154E-04
     +,   2.9679658E-04,   3.0789184E-04,   3.1921477E-04
     +,   3.3070918E-04,   3.4231498E-04,   3.5396731E-04
     +,   3.6559853E-04,   3.7713989E-04,   3.8852129E-04
     +,   3.9967126E-04,   4.1052073E-04,   4.2100096E-04
     +,   4.3104810E-04,   4.4060091E-04,   4.4960537E-04
     +,   4.5801257E-04,   4.6578323E-04,   4.7288500E-04
     +,   4.7929719E-04,   4.8500946E-04,   4.9002242E-04
     +,   4.9434882E-04,   4.9801474E-04,   5.0105836E-04
     +,   5.0353073E-04,   5.0549529E-04,   5.0702778E-04
     +,   5.0821510E-04,   5.0915539E-04,   5.0995621E-04
     +,   5.1073427E-04,   5.1161466E-04,   5.1272911E-04
     +,   5.1421643E-04,   5.1622168E-04,   5.1889592E-04
     +,   5.2239641E-04,   5.2688812E-04,   5.3254404E-04
     +,   5.3954683E-04,   5.4809049E-04,   5.5838173E-04
     +,   5.7064317E-04,   5.8511138E-04,   6.0204073E-04
     +,   6.2170235E-04,   6.4438075E-04,   6.7037373E-04
     +,   6.9998711E-04,   7.3352933E-04,   7.7130046E-04
     +,   8.1358117E-04,   8.6061982E-04,   9.1261463E-04
     +,   9.6968358E-04,   1.0318435E-03,   1.0989858E-03
     +,   1.1708466E-03,   1.2469798E-03,   1.3267631E-03
     +,   1.4094047E-03,   1.4939761E-03,   1.5794918E-03
     +,   1.6650178E-03,   1.7498030E-03,   1.8334195E-03
     +,   1.9159268E-03,   1.9980059E-03,   2.0810564E-03
     +,   2.1672626E-03,   2.2596552E-03,   2.3621577E-03
     +,   2.4796417E-03,   2.6179380E-03,   2.7837125E-03
     +,   2.9839899E-03,   3.2251421E-03,   3.5113397E-03
     +,   3.8428325E-03,   4.2147376E-03,   4.6173665E-03
     +,   5.0389343E-03,   5.4705883E-03,   5.9125856E-03
     +,   6.3795107E-03,   6.9019464E-03,   7.5224671E-03
     +,   8.2849944E-03,   9.2191668E-03,   1.0324066E-02
     +,   1.1557432E-02,   1.2837859E-02,   1.4064281E-02
     +,   1.5149309E-02,   1.6051352E-02,   1.6784731E-02
     +,   1.7395295E-02,   1.7912138E-02,   1.8309910E-02
     +,   1.8513164E-02,   1.8442161E-02,   1.8064175E-02
     +,   1.7410694E-02,   1.6555071E-02,   1.5577236E-02
     +,   1.4545480E-02,   1.3517092E-02,   1.2541250E-02
     +,   1.1653776E-02,   1.0869602E-02,   1.0183255E-02
     +,   9.5777512E-03,   9.0344651E-03,   8.5374508E-03
     +,   8.0728019E-03,   7.6270504E-03,   7.1874321E-03
     +,   6.7438064E-03,   6.2907236E-03,   5.8281561E-03
     +,   5.3611412E-03,   4.8983269E-03,   4.4500278E-03
     +,   4.0262816E-03,   3.6353902E-03,   3.2829668E-03
     +,   2.9715837E-03,   2.7008816E-03,   2.4680977E-03
     +,   2.2687982E-03,   2.0976495E-03,   1.9491620E-03
     +,   1.8182993E-03,   1.7008390E-03,   1.5934902E-03
     +,   1.4938610E-03,   1.4003062E-03,   1.3117399E-03
     +,   1.2274585E-03,   1.1470187E-03,   1.0701570E-03
     +,   9.9673378E-04,   9.2669140E-04,   8.6003251E-04
     +,   7.9680007E-04,   7.3704839E-04,   6.8082055E-04
     +,   6.2813348E-04,   5.7897507E-04,   5.3328794E-04
     +,   4.9097673E-04,   4.5191575E-04,   4.1595186E-04
     +,   3.8291130E-04,   3.5260950E-04,   3.2486022E-04
     +,   2.9947818E-04,   2.7628214E-04,   2.5509880E-04
     +,   2.3576626E-04,   2.1813241E-04,   2.0205459E-04
     +,   1.8740028E-04,   1.7404785E-04,   1.6188316E-04
     +,   1.5080061E-04,   1.4070288E-04,   1.3149992E-04
     +,   1.2310770E-04,   1.1544881E-04,   1.0845230E-04
     +,   1.0205291E-04,   9.6190452E-05,   9.0810077E-05
     +,   8.5862266E-05,   8.1301674E-05,   7.7087920E-05
     +,   7.3184252E-05,   6.9558235E-05,   6.6180604E-05
     +,   6.3025836E-05,   6.0070914E-05,   5.7295951E-05
     +,   5.4683122E-05,   5.2217067E-05,   4.9884122E-05
     +,   4.7672289E-05,   4.5571276E-05,   4.3571781E-05
     +,   4.1665866E-05,   3.9846323E-05,   3.8106999E-05
     +,   3.6442234E-05,   3.4847239E-05,   3.3317498E-05
     +,   3.1849235E-05,   3.0438860E-05,   2.9083327E-05
     +,   2.7779730E-05,   2.6525637E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_hatt95 = Yx/0.145046511627907
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1511372E-05,   1.1854600E-05
     +,   1.2213270E-05,   1.2588665E-05,   1.2982158E-05
     +,   1.3395210E-05,   1.3829350E-05,   1.4286198E-05
     +,   1.4767445E-05,   1.5274867E-05,   1.5810310E-05
     +,   1.6375669E-05,   1.6972914E-05,   1.7604067E-05
     +,   1.8271188E-05,   1.8976381E-05,   1.9721772E-05
     +,   2.0509504E-05,   2.1341719E-05,   2.2220562E-05
     +,   2.3148141E-05,   2.4126535E-05,   2.5157744E-05
     +,   2.6243784E-05,   2.7386463E-05,   2.8587599E-05
     +,   2.9848836E-05,   3.1171701E-05,   3.2557560E-05
     +,   3.4007640E-05,   3.5522975E-05,   3.7104404E-05
     +,   3.8752565E-05,   4.0467879E-05,   4.2250544E-05
     +,   4.4100529E-05,   4.6017536E-05,   4.8001031E-05
     +,   5.0050330E-05,   5.2164298E-05,   5.4341755E-05
     +,   5.6581212E-05,   5.8880913E-05,   6.1238941E-05
     +,   6.3653148E-05,   6.6121211E-05,   6.8640613E-05
     +,   7.1208749E-05,   7.3822805E-05,   7.6479941E-05
     +,   7.9177145E-05,   8.1911487E-05,   8.4679843E-05
     +,   8.7479333E-05,   9.0306770E-05,   9.3159288E-05
     +,   9.6034026E-05,   9.8928162E-05,   1.0183901E-04
     +,   1.0476400E-04,   1.0770075E-04,   1.1064702E-04
     +,   1.1360054E-04,   1.1655944E-04,   1.1952194E-04
     +,   1.2248622E-04,   1.2545087E-04,   1.2841422E-04
     +,   1.3137503E-04,   1.3433180E-04,   1.3728344E-04
     +,   1.4022835E-04,   1.4316548E-04,   1.4609312E-04
     +,   1.4900995E-04,   1.5191437E-04,   1.5480454E-04
     +,   1.5767853E-04,   1.6053418E-04,   1.6336949E-04
     +,   1.6618188E-04,   1.6896898E-04,   1.7172800E-04
     +,   1.7445644E-04,   1.7715164E-04,   1.7981116E-04
     +,   1.8243254E-04,   1.8501408E-04,   1.8755409E-04
     +,   1.9005171E-04,   1.9250701E-04,   1.9492071E-04
     +,   1.9729468E-04,   1.9963241E-04,   2.0193860E-04
     +,   2.0421989E-04,   2.0648472E-04,   2.0874354E-04
     +,   2.1100919E-04,   2.1329691E-04,   2.1562421E-04
     +,   2.1801140E-04,   2.2048150E-04,   2.2305976E-04
     +,   2.2577433E-04,   2.2865574E-04,   2.3173666E-04
     +,   2.3505173E-04,   2.3863750E-04,   2.4253168E-04
     +,   2.4677263E-04,   2.5139929E-04,   2.5644974E-04
     +,   2.6196157E-04,   2.6796953E-04,   2.7450651E-04
     +,   2.8160098E-04,   2.8927726E-04,   2.9755320E-04
     +,   3.0644052E-04,   3.1594335E-04,   3.2605635E-04
     +,   3.3676464E-04,   3.4804340E-04,   3.5985693E-04
     +,   3.7215673E-04,   3.8488454E-04,   3.9796837E-04
     +,   4.1132706E-04,   4.2486735E-04,   4.3848864E-04
     +,   4.5208089E-04,   4.6553038E-04,   4.7871887E-04
     +,   4.9152947E-04,   5.0384837E-04,   5.1556755E-04
     +,   5.2659051E-04,   5.3683500E-04,   5.4623833E-04
     +,   5.5475847E-04,   5.6237984E-04,   5.6911545E-04
     +,   5.7500857E-04,   5.8013550E-04,   5.8460439E-04
     +,   5.8855559E-04,   5.9216027E-04,   5.9561658E-04
     +,   5.9914635E-04,   6.0298987E-04,   6.0740043E-04
     +,   6.1263645E-04,   6.1895733E-04,   6.2661327E-04
     +,   6.3583953E-04,   6.4684922E-04,   6.5982703E-04
     +,   6.7492330E-04,   6.9224747E-04,   7.1186613E-04
     +,   7.3379878E-04,   7.5801485E-04,   7.8443624E-04
     +,   8.1294059E-04,   8.4336841E-04,   8.7553257E-04
     +,   9.0923643E-04,   9.4429927E-04,   9.8058372E-04
     +,   1.0180249E-03,   1.0566677E-03,   1.0967009E-03
     +,   1.1384767E-03,   1.1825156E-03,   1.2295084E-03
     +,   1.2802904E-03,   1.3358177E-03,   1.3971576E-03
     +,   1.4655187E-03,   1.5423304E-03,   1.6293718E-03
     +,   1.7289517E-03,   1.8440717E-03,   1.9784782E-03
     +,   2.1365252E-03,   2.3228182E-03,   2.5416506E-03
     +,   2.7963649E-03,   3.0888401E-03,   3.4194475E-03
     +,   3.7874889E-03,   4.1920040E-03,   4.6326849E-03
     +,   5.1104194E-03,   5.6269704E-03,   6.1839949E-03
     +,   6.7818672E-03,   7.4188858E-03,   8.0909487E-03
     +,   8.7913377E-03,   9.5101073E-03,   1.0232694E-02
     +,   1.0938958E-02,   1.1605158E-02,   1.2210413E-02
     +,   1.2745375E-02,   1.3218021E-02,   1.3652151E-02
     +,   1.4079091E-02,   1.4527529E-02,   1.5015071E-02
     +,   1.5539285E-02,   1.6068112E-02,   1.6538827E-02
     +,   1.6877649E-02,   1.7038198E-02,   1.7031973E-02
     +,   1.6922295E-02,   1.6779626E-02,   1.6630111E-02
     +,   1.6436970E-02,   1.6127642E-02,   1.5644567E-02
     +,   1.4982086E-02,   1.4186172E-02,   1.3323808E-02
     +,   1.2448933E-02,   1.1590413E-02,   1.0762661E-02
     +,   9.9814981E-03,   9.2691965E-03,   8.6479578E-03
     +,   8.1304777E-03,   7.7145011E-03,   7.3826308E-03
     +,   7.1063577E-03,   6.8527739E-03,   6.5926043E-03
     +,   6.3069924E-03,   5.9904712E-03,   5.6493902E-03
     +,   5.2968743E-03,   4.9471855E-03,   4.6114749E-03
     +,   4.2959545E-03,   4.0021166E-03,   3.7281932E-03
     +,   3.4708984E-03,   3.2268730E-03,   2.9934009E-03
     +,   2.7687405E-03,   2.5520714E-03,   2.3432798E-03
     +,   2.1427234E-03,   1.9510523E-03,   1.7690639E-03
     +,   1.5975462E-03,   1.4371612E-03,   1.2883749E-03
     +,   1.1514126E-03,   1.0262482E-03,   9.1261533E-04
     +,   8.1006548E-04,   7.1803184E-04,   6.3585694E-04
     +,   5.6284590E-04,   4.9829646E-04,   4.4150802E-04
     +,   3.9178715E-04,   3.4845562E-04,   3.1085644E-04
     +,   2.7835328E-04,   2.5033441E-04,   2.2622160E-04
     +,   2.0547828E-04,   1.8760946E-04,   1.7217139E-04
     +,   1.5876870E-04,   1.4705898E-04,   1.3674737E-04
     +,   1.2758652E-04,   1.1936993E-04,   1.1192934E-04
     +,   1.0512798E-04,   9.8857432E-05,   9.3031544E-05
     +,   8.7583016E-05,   8.2460218E-05,   7.7622899E-05
     +,   7.3040886E-05,   6.8690715E-05,   6.4555024E-05
     +,   6.0620085E-05,   5.6875753E-05,   5.3313601E-05
     +,   4.9927181E-05,   4.6710640E-05,   4.3659216E-05
     +,   4.0768096E-05,   3.8032998E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt100 = Yx/0.165613636363636
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6706235E-05,   1.7042745E-05
     +,   1.7378901E-05,   1.7714718E-05,   1.8050256E-05
     +,   1.8385608E-05,   1.8720901E-05,   1.9056304E-05
     +,   1.9392031E-05,   1.9728352E-05,   2.0065561E-05
     +,   2.0404023E-05,   2.0744141E-05,   2.1086373E-05
     +,   2.1431242E-05,   2.1779317E-05,   2.2131229E-05
     +,   2.2487684E-05,   2.2849432E-05,   2.3217299E-05
     +,   2.3592178E-05,   2.3975024E-05,   2.4366873E-05
     +,   2.4768846E-05,   2.5182091E-05,   2.5607898E-05
     +,   2.6047586E-05,   2.6502566E-05,   2.6974340E-05
     +,   2.7464477E-05,   2.7974645E-05,   2.8506565E-05
     +,   2.9062072E-05,   2.9643061E-05,   3.0251500E-05
     +,   3.0889460E-05,   3.1559070E-05,   3.2262509E-05
     +,   3.3002085E-05,   3.3780070E-05,   3.4598885E-05
     +,   3.5460929E-05,   3.6368656E-05,   3.7324549E-05
     +,   3.8331105E-05,   3.9390790E-05,   4.0506082E-05
     +,   4.1679403E-05,   4.2913132E-05,   4.4209566E-05
     +,   4.5570894E-05,   4.6999194E-05,   4.8496371E-05
     +,   5.0064267E-05,   5.1704308E-05,   5.3417916E-05
     +,   5.5206154E-05,   5.7069799E-05,   5.9009322E-05
     +,   6.1024875E-05,   6.3116247E-05,   6.5282838E-05
     +,   6.7523564E-05,   6.9836999E-05,   7.2221359E-05
     +,   7.4674143E-05,   7.7192708E-05,   7.9773563E-05
     +,   8.2413142E-05,   8.5107065E-05,   8.7850851E-05
     +,   9.0639216E-05,   9.3466879E-05,   9.6327763E-05
     +,   9.9215809E-05,   1.0212466E-04,   1.0504752E-04
     +,   1.0797745E-04,   1.1090763E-04,   1.1383122E-04
     +,   1.1674113E-04,   1.1963081E-04,   1.2249361E-04
     +,   1.2532354E-04,   1.2811470E-04,   1.3086206E-04
     +,   1.3356081E-04,   1.3620732E-04,   1.3879823E-04
     +,   1.4133152E-04,   1.4380590E-04,   1.4622111E-04
     +,   1.4857780E-04,   1.5087806E-04,   1.5312496E-04
     +,   1.5532256E-04,   1.5747616E-04,   1.5959215E-04
     +,   1.6167802E-04,   1.6374204E-04,   1.6579358E-04
     +,   1.6784250E-04,   1.6989949E-04,   1.7197555E-04
     +,   1.7408191E-04,   1.7623014E-04,   1.7843131E-04
     +,   1.8069618E-04,   1.8303496E-04,   1.8545717E-04
     +,   1.8797076E-04,   1.9058277E-04,   1.9329837E-04
     +,   1.9612121E-04,   1.9905252E-04,   2.0209179E-04
     +,   2.0523601E-04,   2.0847976E-04,   2.1181504E-04
     +,   2.1523159E-04,   2.1871676E-04,   2.2225511E-04
     +,   2.2582925E-04,   2.2941966E-04,   2.3300543E-04
     +,   2.3656347E-04,   2.4007012E-04,   2.4350070E-04
     +,   2.4683049E-04,   2.5003447E-04,   2.5308880E-04
     +,   2.5597037E-04,   2.5865829E-04,   2.6113322E-04
     +,   2.6337919E-04,   2.6538319E-04,   2.6713571E-04
     +,   2.6863161E-04,   2.6987016E-04,   2.7085558E-04
     +,   2.7159700E-04,   2.7210903E-04,   2.7241147E-04
     +,   2.7252993E-04,   2.7249526E-04,   2.7234381E-04
     +,   2.7211700E-04,   2.7186144E-04,   2.7162820E-04
     +,   2.7147270E-04,   2.7145408E-04,   2.7163498E-04
     +,   2.7208056E-04,   2.7285839E-04,   2.7403745E-04
     +,   2.7568813E-04,   2.7788107E-04,   2.8068706E-04
     +,   2.8417684E-04,   2.8842021E-04,   2.9348681E-04
     +,   2.9944614E-04,   3.0636677E-04,   3.1431782E-04
     +,   3.2337036E-04,   3.3359765E-04,   3.4507623E-04
     +,   3.5788736E-04,   3.7212030E-04,   3.8787207E-04
     +,   4.0524945E-04,   4.2436950E-04,   4.4536288E-04
     +,   4.6837091E-04,   4.9354427E-04,   5.2104320E-04
     +,   5.5103231E-04,   5.8367394E-04,   6.1912369E-04
     +,   6.5752480E-04,   6.9900195E-04,   7.4365077E-04
     +,   7.9153618E-04,   8.4269361E-04,   8.9712895E-04
     +,   9.5481850E-04,   1.0157237E-03,   1.0798143E-03
     +,   1.1470894E-03,   1.2176039E-03,   1.2915286E-03
     +,   1.3691965E-03,   1.4511583E-03,   1.5382507E-03
     +,   1.6316546E-03,   1.7329445E-03,   1.8440949E-03
     +,   1.9674953E-03,   2.1059408E-03,   2.2625977E-03
     +,   2.4409548E-03,   2.6447768E-03,   2.8780014E-03
     +,   3.1445061E-03,   3.4477029E-03,   3.7900186E-03
     +,   4.1722036E-03,   4.5924978E-03,   5.0459164E-03
     +,   5.5237762E-03,   6.0138251E-03,   6.5016421E-03
     +,   6.9738771E-03,   7.4229003E-03,   7.8509497E-03
     +,   8.2709733E-03,   8.7015610E-03,   9.1565596E-03
     +,   9.6342042E-03,   1.0114098E-02,   1.0569301E-02
     +,   1.0992579E-02,   1.1422561E-02,   1.1946054E-02
     +,   1.2662949E-02,   1.3631459E-02,   1.4838992E-02
     +,   1.6226871E-02,   1.7740855E-02,   1.9343641E-02
     +,   2.0969624E-02,   2.2483293E-02,   2.3717150E-02
     +,   2.4572147E-02,   2.5073964E-02,   2.5318101E-02
     +,   2.5358547E-02,   2.5149340E-02,   2.4590289E-02
     +,   2.3628529E-02,   2.2321986E-02,   2.0812072E-02
     +,   1.9243682E-02,   1.7709959E-02,   1.6256519E-02
     +,   1.4914796E-02,   1.3713646E-02,   1.2659264E-02
     +,   1.1717861E-02,   1.0830235E-02,   9.9443281E-03
     +,   9.0357671E-03,   8.1061563E-03,   7.1719950E-03
     +,   6.2569100E-03,   5.3880611E-03,   4.5922678E-03
     +,   3.8902096E-03,   3.2916449E-03,   2.7944141E-03
     +,   2.3872897E-03,   2.0545493E-03,   1.7801909E-03
     +,   1.5505706E-03,   1.3553515E-03,   1.1872619E-03
     +,   1.0414139E-03,   9.1452012E-04,   8.0422702E-04
     +,   7.0865493E-04,   6.2613742E-04,   5.5510423E-04
     +,   4.9404457E-04,   4.4152554E-04,   3.9623358E-04
     +,   3.5700737E-04,   3.2284297E-04,   2.9290479E-04
     +,   2.6650378E-04,   2.4308670E-04,   2.2220645E-04
     +,   2.0350759E-04,   1.8670125E-04,   1.7155416E-04
     +,   1.5787162E-04,   1.4549168E-04,   1.3427470E-04
     +,   1.2409966E-04,   1.1486112E-04,   1.0646439E-04
     +,   9.8826007E-05,   9.1870061E-05,   8.5529209E-05
     +,   7.9741869E-05,   7.4453274E-05,   6.9613227E-05
     +,   6.5177002E-05,   6.1103550E-05,   5.7356301E-05
     +,   5.3901615E-05,   5.0709528E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt105 = Yx/0.185818181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5640162E-05,   2.6243739E-05
     +,   2.6858090E-05,   2.7483578E-05,   2.8120570E-05
     +,   2.8769475E-05,   2.9430703E-05,   3.0104698E-05
     +,   3.0791893E-05,   3.1492804E-05,   3.2207881E-05
     +,   3.2937638E-05,   3.3682587E-05,   3.4443230E-05
     +,   3.5220095E-05,   3.6013687E-05,   3.6824535E-05
     +,   3.7653135E-05,   3.8499969E-05,   3.9365532E-05
     +,   4.0250277E-05,   4.1154624E-05,   4.2078962E-05
     +,   4.3023705E-05,   4.3989101E-05,   4.4975484E-05
     +,   4.5983070E-05,   4.7012036E-05,   4.8062488E-05
     +,   4.9134494E-05,   5.0228020E-05,   5.1343024E-05
     +,   5.2479332E-05,   5.3636737E-05,   5.4814922E-05
     +,   5.6013538E-05,   5.7232141E-05,   5.8470181E-05
     +,   5.9727132E-05,   6.1002269E-05,   6.2294937E-05
     +,   6.3604311E-05,   6.4929576E-05,   6.6269859E-05
     +,   6.7624213E-05,   6.8991714E-05,   7.0371389E-05
     +,   7.1762224E-05,   7.3163239E-05,   7.4573465E-05
     +,   7.5991920E-05,   7.7417702E-05,   7.8849909E-05
     +,   8.0287755E-05,   8.1730417E-05,   8.3177256E-05
     +,   8.4627667E-05,   8.6081178E-05,   8.7537359E-05
     +,   8.8995985E-05,   9.0456844E-05,   9.1920010E-05
     +,   9.3385446E-05,   9.4853465E-05,   9.6324424E-05
     +,   9.7798773E-05,   9.9277109E-05,   1.0076012E-04
     +,   1.0224862E-04,   1.0374348E-04,   1.0524563E-04
     +,   1.0675604E-04,   1.0827580E-04,   1.0980584E-04
     +,   1.1134726E-04,   1.1290105E-04,   1.1446811E-04
     +,   1.1604915E-04,   1.1764501E-04,   1.1925625E-04
     +,   1.2088324E-04,   1.2252622E-04,   1.2418526E-04
     +,   1.2586020E-04,   1.2755048E-04,   1.2925555E-04
     +,   1.3097448E-04,   1.3270619E-04,   1.3444912E-04
     +,   1.3620175E-04,   1.3796221E-04,   1.3972848E-04
     +,   1.4149821E-04,   1.4326911E-04,   1.4503869E-04
     +,   1.4680433E-04,   1.4856356E-04,   1.5031360E-04
     +,   1.5205203E-04,   1.5377642E-04,   1.5548459E-04
     +,   1.5717436E-04,   1.5884405E-04,   1.6049204E-04
     +,   1.6211730E-04,   1.6371899E-04,   1.6529678E-04
     +,   1.6685059E-04,   1.6838095E-04,   1.6988885E-04
     +,   1.7137545E-04,   1.7284261E-04,   1.7429233E-04
     +,   1.7572724E-04,   1.7714981E-04,   1.7856322E-04
     +,   1.7997043E-04,   1.8137475E-04,   1.8277932E-04
     +,   1.8418719E-04,   1.8560136E-04,   1.8702428E-04
     +,   1.8845826E-04,   1.8990501E-04,   1.9136572E-04
     +,   1.9284087E-04,   1.9433026E-04,   1.9583292E-04
     +,   1.9734701E-04,   1.9886975E-04,   2.0039766E-04
     +,   2.0192617E-04,   2.0345015E-04,   2.0496313E-04
     +,   2.0645843E-04,   2.0792846E-04,   2.0936503E-04
     +,   2.1075942E-04,   2.1210281E-04,   2.1338633E-04
     +,   2.1460070E-04,   2.1573718E-04,   2.1678732E-04
     +,   2.1774348E-04,   2.1859849E-04,   2.1934668E-04
     +,   2.1998353E-04,   2.2050600E-04,   2.2091290E-04
     +,   2.2120519E-04,   2.2138630E-04,   2.2146170E-04
     +,   2.2144052E-04,   2.2133453E-04,   2.2115927E-04
     +,   2.2093386E-04,   2.2068199E-04,   2.2043134E-04
     +,   2.2021473E-04,   2.2007021E-04,   2.2004130E-04
     +,   2.2017758E-04,   2.2053503E-04,   2.2117606E-04
     +,   2.2217038E-04,   2.2359480E-04,   2.2553370E-04
     +,   2.2807880E-04,   2.3132966E-04,   2.3539312E-04
     +,   2.4038304E-04,   2.4641905E-04,   2.5362702E-04
     +,   2.6213677E-04,   2.7208027E-04,   2.8359110E-04
     +,   2.9680174E-04,   3.1184073E-04,   3.2883100E-04
     +,   3.4788952E-04,   3.6912583E-04,   3.9264039E-04
     +,   4.1852781E-04,   4.4688230E-04,   4.7780215E-04
     +,   5.1139615E-04,   5.4779544E-04,   5.8716611E-04
     +,   6.2971987E-04,   6.7571743E-04,   7.2548271E-04
     +,   7.7939895E-04,   8.3789747E-04,   9.0144976E-04
     +,   9.7055745E-04,   1.0457387E-03,   1.1275285E-03
     +,   1.2165076E-03,   1.3133736E-03,   1.4190280E-03
     +,   1.5346797E-03,   1.6619412E-03,   1.8028604E-03
     +,   1.9597902E-03,   2.1350579E-03,   2.3304813E-03
     +,   2.5467172E-03,   2.7826361E-03,   3.0350499E-03
     +,   3.2989702E-03,   3.5685580E-03,   3.8386912E-03
     +,   4.1068019E-03,   4.3743537E-03,   4.6473206E-03
     +,   4.9351831E-03,   5.2487487E-03,   5.5972035E-03
     +,   5.9855045E-03,   6.4129946E-03,   6.8741227E-03
     +,   7.3609655E-03,   7.8669740E-03,   8.3906958E-03
     +,   8.9383712E-03,   9.5246052E-03,   1.0171389E-02
     +,   1.0905037E-02,   1.1748003E-02,   1.2703291E-02
     +,   1.3737609E-02,   1.4783384E-02,   1.5777191E-02
     +,   1.6717963E-02,   1.7691471E-02,   1.8821789E-02
     +,   2.0178534E-02,   2.1717224E-02,   2.3295263E-02
     +,   2.4736967E-02,   2.5895182E-02,   2.6685670E-02
     +,   2.7097054E-02,   2.7177958E-02,   2.6989855E-02
     +,   2.6543634E-02,   2.5781136E-02,   2.4637889E-02
     +,   2.3128277E-02,   2.1365777E-02,   1.9508239E-02
     +,   1.7688273E-02,   1.5973756E-02,   1.4364802E-02
     +,   1.2818832E-02,   1.1291816E-02,   9.7737685E-03
     +,   8.2985768E-03,   6.9259712E-03,   5.7118796E-03
     +,   4.6867356E-03,   3.8505509E-03,   3.1813132E-03
     +,   2.6477971E-03,   2.2196248E-03,   1.8721458E-03
     +,   1.5873681E-03,   1.3526840E-03,   1.1590092E-03
     +,   9.9927199E-04,   8.6751592E-04,   7.5850368E-04
     +,   6.6763075E-04,   5.9097796E-04,   5.2537373E-04
     +,   4.6838343E-04,   4.1821311E-04,   3.7359935E-04
     +,   3.3365944E-04,   2.9778210E-04,   2.6552140E-04
     +,   2.3653886E-04,   2.1055143E-04,   1.8731400E-04
     +,   1.6659894E-04,   1.4819609E-04,   1.3190485E-04
     +,   1.1753588E-04,   1.0491165E-04,   9.3863193E-05
     +,   8.4233354E-05,   7.5873671E-05,   6.8646928E-05
     +,   6.2424842E-05,   5.7089917E-05,   5.2533731E-05
     +,   4.8658148E-05,   4.5373781E-05,   4.2600728E-05
     +,   4.0267158E-05,   3.8309539E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt107 = Yx/0.187886363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4342695E-05,   2.5479743E-05
     +,   2.6652810E-05,   2.7861008E-05,   2.9103210E-05
     +,   3.0378116E-05,   3.1684223E-05,   3.3019813E-05
     +,   3.4382931E-05,   3.5771514E-05,   3.7183207E-05
     +,   3.8615490E-05,   4.0065635E-05,   4.1530748E-05
     +,   4.3007763E-05,   4.4493430E-05,   4.5984372E-05
     +,   4.7477060E-05,   4.8967875E-05,   5.0453054E-05
     +,   5.1928793E-05,   5.3391188E-05,   5.4836299E-05
     +,   5.6260258E-05,   5.7659046E-05,   5.9028815E-05
     +,   6.0365699E-05,   6.1665938E-05,   6.2925850E-05
     +,   6.4141932E-05,   6.5310756E-05,   6.6429195E-05
     +,   6.7494155E-05,   6.8502937E-05,   6.9452981E-05
     +,   7.0342001E-05,   7.1168019E-05,   7.1929324E-05
     +,   7.2624571E-05,   7.3252668E-05,   7.3812895E-05
     +,   7.4304895E-05,   7.4728589E-05,   7.5084303E-05
     +,   7.5372700E-05,   7.5594791E-05,   7.5751923E-05
     +,   7.5845783E-05,   7.5878430E-05,   7.5852178E-05
     +,   7.5769713E-05,   7.5633987E-05,   7.5448232E-05
     +,   7.5215976E-05,   7.4940966E-05,   7.4627220E-05
     +,   7.4278905E-05,   7.3900439E-05,   7.3496441E-05
     +,   7.3071576E-05,   7.2630784E-05,   7.2179020E-05
     +,   7.1721421E-05,   7.1263152E-05,   7.0809489E-05
     +,   7.0365750E-05,   6.9937290E-05,   6.9529546E-05
     +,   6.9147907E-05,   6.8797846E-05,   6.8484827E-05
     +,   6.8214344E-05,   6.7991830E-05,   6.7822803E-05
     +,   6.7712739E-05,   6.7667104E-05,   6.7691464E-05
     +,   6.7791225E-05,   6.7971981E-05,   6.8239220E-05
     +,   6.8598449E-05,   6.9055233E-05,   6.9615089E-05
     +,   7.0283531E-05,   7.1066068E-05,   7.1968199E-05
     +,   7.2995303E-05,   7.4152762E-05,   7.5445772E-05
     +,   7.6879456E-05,   7.8458776E-05,   8.0188373E-05
     +,   8.2072605E-05,   8.4115556E-05,   8.6320986E-05
     +,   8.8691850E-05,   9.1230941E-05,   9.3940071E-05
     +,   9.6820622E-05,   9.9872836E-05,   1.0309642E-04
     +,   1.0648970E-04,   1.1005035E-04,   1.1377449E-04
     +,   1.1765730E-04,   1.2169270E-04,   1.2587305E-04
     +,   1.3018919E-04,   1.3463099E-04,   1.3918681E-04
     +,   1.4384319E-04,   1.4858584E-04,   1.5339856E-04
     +,   1.5826446E-04,   1.6316480E-04,   1.6808067E-04
     +,   1.7299131E-04,   1.7787598E-04,   1.8271279E-04
     +,   1.8747995E-04,   1.9215554E-04,   1.9671756E-04
     +,   2.0114431E-04,   2.0541521E-04,   2.0951059E-04
     +,   2.1341177E-04,   2.1710215E-04,   2.2056655E-04
     +,   2.2379259E-04,   2.2676999E-04,   2.2949187E-04
     +,   2.3195392E-04,   2.3415586E-04,   2.3610066E-04
     +,   2.3779571E-04,   2.3925236E-04,   2.4048632E-04
     +,   2.4151780E-04,   2.4237185E-04,   2.4307807E-04
     +,   2.4367077E-04,   2.4418894E-04,   2.4467608E-04
     +,   2.4518010E-04,   2.4575245E-04,   2.4644885E-04
     +,   2.4732773E-04,   2.4845017E-04,   2.4987917E-04
     +,   2.5167860E-04,   2.5391279E-04,   2.5664506E-04
     +,   2.5993714E-04,   2.6384796E-04,   2.6843275E-04
     +,   2.7374172E-04,   2.7981933E-04,   2.8670419E-04
     +,   2.9442759E-04,   3.0301337E-04,   3.1247849E-04
     +,   3.2283337E-04,   3.3408171E-04,   3.4622155E-04
     +,   3.5924916E-04,   3.7315895E-04,   3.8794513E-04
     +,   4.0360590E-04,   4.2014613E-04,   4.3758037E-04
     +,   4.5593351E-04,   4.7524457E-04,   4.9556984E-04
     +,   5.1698345E-04,   5.3957332E-04,   5.6344672E-04
     +,   5.8872515E-04,   6.1553990E-04,   6.4403011E-04
     +,   6.7434041E-04,   7.0661743E-04,   7.4100436E-04
     +,   7.7764434E-04,   8.1668835E-04,   8.5829862E-04
     +,   9.0266095E-04,   9.4999891E-04,   1.0005983E-03
     +,   1.0548134E-03,   1.1130759E-03,   1.1758987E-03
     +,   1.2438525E-03,   1.3175238E-03,   1.3974553E-03
     +,   1.4840699E-03,   1.5775778E-03,   1.6778780E-03
     +,   1.7845042E-03,   1.8966075E-03,   2.0130069E-03
     +,   2.1323180E-03,   2.2531841E-03,   2.3745813E-03
     +,   2.4961273E-03,   2.6183364E-03,   2.7427853E-03
     +,   2.8720298E-03,   3.0092844E-03,   3.1578981E-03
     +,   3.3207186E-03,   3.4995377E-03,   3.6948265E-03
     +,   3.9059049E-03,   4.1316249E-03,   4.3712156E-03
     +,   4.6250457E-03,   4.8948731E-03,   5.1834853E-03
     +,   5.4938844E-03,   5.8287494E-03,   6.1910055E-03
     +,   6.5854732E-03,   7.0206458E-03,   7.5084209E-03
     +,   8.0592642E-03,   8.6724469E-03,   9.3252985E-03
     +,   9.9696815E-03,   1.0543983E-02,   1.1001896E-02
     +,   1.1346524E-02,   1.1648241E-02,   1.2026141E-02
     +,   1.2592528E-02,   1.3386486E-02,   1.4338040E-02
     +,   1.5292492E-02,   1.6090317E-02,   1.6661897E-02
     +,   1.7077655E-02,   1.7512154E-02,   1.8141972E-02
     +,   1.9054919E-02,   2.0238090E-02,   2.1629533E-02
     +,   2.3158411E-02,   2.4730137E-02,   2.6189161E-02
     +,   2.7326670E-02,   2.7963765E-02,   2.8051833E-02
     +,   2.7682092E-02,   2.6976978E-02,   2.5974484E-02
     +,   2.4627721E-02,   2.2906065E-02,   2.0876940E-02
     +,   1.8690746E-02,   1.6501883E-02,   1.4407179E-02
     +,   1.2442528E-02,   1.0617997E-02,   8.9478362E-03
     +,   7.4545355E-03,   6.1566392E-03,   5.0583030E-03
     +,   4.1488679E-03,   3.4081123E-03,   2.8116296E-03
     +,   2.3343498E-03,   1.9526321E-03,   1.6456112E-03
     +,   1.3960379E-03,   1.1905591E-03,   1.0194288E-03
     +,   8.7577617E-04,   7.5470388E-04,   6.5258041E-04
     +,   5.6649552E-04,   4.9400318E-04,   4.3297600E-04
     +,   3.8158096E-04,   3.3824620E-04,   3.0165428E-04
     +,   2.7069892E-04,   2.4445905E-04,   2.2215665E-04
     +,   2.0313196E-04,   1.8682508E-04,   1.7275802E-04
     +,   1.6053056E-04,   1.4980904E-04,   1.4032314E-04
     +,   1.3185543E-04,   1.2423581E-04,   1.1733114E-04
     +,   1.1103893E-04,   1.0527848E-04,   9.9986326E-05
     +,   9.5109957E-05,   9.0605645E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt110 = Yx/0.206266666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.9914943E-05,   5.1041297E-05
     +,   5.2185671E-05,   5.3348707E-05,   5.4531083E-05
     +,   5.5733519E-05,   5.6956756E-05,   5.8201578E-05
     +,   5.9468755E-05,   6.0759154E-05,   6.2073588E-05
     +,   6.3412939E-05,   6.4778054E-05,   6.6169792E-05
     +,   6.7589048E-05,   6.9036665E-05,   7.0513503E-05
     +,   7.2020383E-05,   7.3558127E-05,   7.5127471E-05
     +,   7.6729179E-05,   7.8363904E-05,   8.0032223E-05
     +,   8.1734805E-05,   8.3471990E-05,   8.5244261E-05
     +,   8.7051834E-05,   8.8894958E-05,   9.0773676E-05
     +,   9.2687929E-05,   9.4637559E-05,   9.6622207E-05
     +,   9.8641409E-05,   1.0069453E-04,   1.0278077E-04
     +,   1.0489912E-04,   1.0704843E-04,   1.0922731E-04
     +,   1.1143429E-04,   1.1366748E-04,   1.1592506E-04
     +,   1.1820474E-04,   1.2050420E-04,   1.2282078E-04
     +,   1.2515172E-04,   1.2749399E-04,   1.2984428E-04
     +,   1.3219923E-04,   1.3455513E-04,   1.3690819E-04
     +,   1.3925433E-04,   1.4158945E-04,   1.4390904E-04
     +,   1.4620880E-04,   1.4848394E-04,   1.5072983E-04
     +,   1.5294156E-04,   1.5511434E-04,   1.5724315E-04
     +,   1.5932308E-04,   1.6134915E-04,   1.6331655E-04
     +,   1.6522028E-04,   1.6705567E-04,   1.6881819E-04
     +,   1.7050329E-04,   1.7210680E-04,   1.7362460E-04
     +,   1.7505309E-04,   1.7638860E-04,   1.7762823E-04
     +,   1.7876907E-04,   1.7980889E-04,   1.8074573E-04
     +,   1.8157811E-04,   1.8230511E-04,   1.8292645E-04
     +,   1.8344200E-04,   1.8385264E-04,   1.8415965E-04
     +,   1.8436489E-04,   1.8447106E-04,   1.8448124E-04
     +,   1.8439947E-04,   1.8423019E-04,   1.8397873E-04
     +,   1.8365102E-04,   1.8325375E-04,   1.8279422E-04
     +,   1.8228051E-04,   1.8172120E-04,   1.8112583E-04
     +,   1.8050434E-04,   1.7986735E-04,   1.7922615E-04
     +,   1.7859259E-04,   1.7797892E-04,   1.7739816E-04
     +,   1.7686357E-04,   1.7638881E-04,   1.7598801E-04
     +,   1.7567562E-04,   1.7546605E-04,   1.7537418E-04
     +,   1.7541478E-04,   1.7560260E-04,   1.7595242E-04
     +,   1.7647869E-04,   1.7719553E-04,   1.7811693E-04
     +,   1.7925611E-04,   1.8062582E-04,   1.8223801E-04
     +,   1.8410414E-04,   1.8623425E-04,   1.8863799E-04
     +,   1.9132333E-04,   1.9429773E-04,   1.9756680E-04
     +,   2.0113539E-04,   2.0500690E-04,   2.0918337E-04
     +,   2.1366529E-04,   2.1845223E-04,   2.2354226E-04
     +,   2.2893205E-04,   2.3461747E-04,   2.4059271E-04
     +,   2.4685165E-04,   2.5338653E-04,   2.6018955E-04
     +,   2.6725145E-04,   2.7456350E-04,   2.8211545E-04
     +,   2.8989807E-04,   2.9790189E-04,   3.0611712E-04
     +,   3.1453441E-04,   3.2314568E-04,   3.3194368E-04
     +,   3.4092146E-04,   3.5007313E-04,   3.5939494E-04
     +,   3.6888479E-04,   3.7854095E-04,   3.8836498E-04
     +,   3.9836002E-04,   4.0853122E-04,   4.1888570E-04
     +,   4.2943441E-04,   4.4019049E-04,   4.5116985E-04
     +,   4.6239182E-04,   4.7388024E-04,   4.8566310E-04
     +,   4.9777218E-04,   5.1024527E-04,   5.2312698E-04
     +,   5.3646893E-04,   5.5032916E-04,   5.6477607E-04
     +,   5.7988707E-04,   5.9574895E-04,   6.1245862E-04
     +,   6.3012337E-04,   6.4885966E-04,   6.6879077E-04
     +,   6.9004507E-04,   7.1275432E-04,   7.3704869E-04
     +,   7.6305197E-04,   7.9087605E-04,   8.2061969E-04
     +,   8.5236243E-04,   8.8615826E-04,   9.2203787E-04
     +,   9.6000661E-04,   1.0000403E-03,   1.0420963E-03
     +,   1.0861153E-03,   1.1320318E-03,   1.1797781E-03
     +,   1.2293005E-03,   1.2805769E-03,   1.3336281E-03
     +,   1.3885379E-03,   1.4454700E-03,   1.5046942E-03
     +,   1.5665926E-03,   1.6316705E-03,   1.7005559E-03
     +,   1.7739806E-03,   1.8527354E-03,   1.9376144E-03
     +,   2.0293551E-03,   2.1285515E-03,   2.2355739E-03
     +,   2.3505443E-03,   2.4733222E-03,   2.6035656E-03
     +,   2.7408216E-03,   2.8847030E-03,   3.0350802E-03
     +,   3.1922769E-03,   3.3572032E-03,   3.5314925E-03
     +,   3.7174535E-03,   3.9179171E-03,   4.1359398E-03
     +,   4.3744030E-03,   4.6355426E-03,   4.9205394E-03
     +,   5.2293641E-03,   5.5610016E-03,   5.9140516E-03
     +,   6.2875585E-03,   6.6816970E-03,   7.0977267E-03
     +,   7.5365854E-03,   7.9963580E-03,   8.4696896E-03
     +,   8.9429673E-03,   9.3990825E-03,   9.8244203E-03
     +,   1.0217645E-02,   1.0595451E-02,   1.0990666E-02
     +,   1.1441283E-02,   1.1974474E-02,   1.2593418E-02
     +,   1.3273684E-02,   1.3970664E-02,   1.4633197E-02
     +,   1.5217352E-02,   1.5697040E-02,   1.6071668E-02
     +,   1.6369352E-02,   1.6640993E-02,   1.6942874E-02
     +,   1.7313549E-02,   1.7758269E-02,   1.8251227E-02
     +,   1.8752752E-02,   1.9228259E-02,   1.9659143E-02
     +,   2.0044193E-02,   2.0394295E-02,   2.0718558E-02
     +,   2.1002900E-02,   2.1193624E-02,   2.1205962E-02
     +,   2.0960733E-02,   2.0427298E-02,   1.9639917E-02
     +,   1.8675333E-02,   1.7611919E-02,   1.6500995E-02
     +,   1.5364673E-02,   1.4210808E-02,   1.3047128E-02
     +,   1.1885167E-02,   1.0736725E-02,   9.6108904E-03
     +,   8.5151549E-03,   7.4590016E-03,   6.4559393E-03
     +,   5.5227340E-03,   4.6759611E-03,   3.9279968E-03
     +,   3.2842858E-03,   2.7428349E-03,   2.2954878E-03
     +,   1.9301614E-03,   1.6332716E-03,   1.3917289E-03
     +,   1.1941706E-03,   1.0313826E-03,   8.9630752E-04
     +,   7.8363810E-04,   6.8940804E-04,   6.1053742E-04
     +,   5.4454373E-04,   4.8931100E-04,   4.4299869E-04
     +,   4.0397816E-04,   3.7083382E-04,   3.4235232E-04
     +,   3.1752684E-04,   2.9554873E-04,   2.7578557E-04
     +,   2.5776302E-04,   2.4113353E-04,   2.2565480E-04
     +,   2.1116104E-04,   1.9754574E-04,   1.8474033E-04
     +,   1.7270395E-04,   1.6140928E-04,   1.5083802E-04
     +,   1.4097267E-04,   1.3179579E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt115 = Yx/0.212333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.8593577E-05,   8.1131278E-05
     +,   8.3691877E-05,   8.6272805E-05,   8.8871398E-05
     +,   9.1484959E-05,   9.4110750E-05,   9.6745978E-05
     +,   9.9387828E-05,   1.0203355E-04,   1.0468029E-04
     +,   1.0732524E-04,   1.0996559E-04,   1.1259856E-04
     +,   1.1522137E-04,   1.1783136E-04,   1.2042579E-04
     +,   1.2300200E-04,   1.2555749E-04,   1.2808967E-04
     +,   1.3059612E-04,   1.3307440E-04,   1.3552215E-04
     +,   1.3793724E-04,   1.4031731E-04,   1.4266037E-04
     +,   1.4496432E-04,   1.4722724E-04,   1.4944717E-04
     +,   1.5162233E-04,   1.5375100E-04,   1.5583148E-04
     +,   1.5786220E-04,   1.5984164E-04,   1.6176839E-04
     +,   1.6364102E-04,   1.6545826E-04,   1.6721895E-04
     +,   1.6892194E-04,   1.7056607E-04,   1.7215050E-04
     +,   1.7367424E-04,   1.7513661E-04,   1.7653669E-04
     +,   1.7787408E-04,   1.7914813E-04,   1.8035849E-04
     +,   1.8150486E-04,   1.8258703E-04,   1.8360498E-04
     +,   1.8455878E-04,   1.8544869E-04,   1.8627502E-04
     +,   1.8703840E-04,   1.8773942E-04,   1.8837904E-04
     +,   1.8895828E-04,   1.8947831E-04,   1.8994061E-04
     +,   1.9034679E-04,   1.9069861E-04,   1.9099806E-04
     +,   1.9124738E-04,   1.9144894E-04,   1.9160533E-04
     +,   1.9171933E-04,   1.9179381E-04,   1.9183200E-04
     +,   1.9183713E-04,   1.9181255E-04,   1.9176204E-04
     +,   1.9168900E-04,   1.9159738E-04,   1.9149102E-04
     +,   1.9137377E-04,   1.9124958E-04,   1.9112237E-04
     +,   1.9099604E-04,   1.9087447E-04,   1.9076136E-04
     +,   1.9066043E-04,   1.9057505E-04,   1.9050870E-04
     +,   1.9046437E-04,   1.9044505E-04,   1.9045323E-04
     +,   1.9049125E-04,   1.9056117E-04,   1.9066468E-04
     +,   1.9080297E-04,   1.9097701E-04,   1.9118737E-04
     +,   1.9143410E-04,   1.9171704E-04,   1.9203554E-04
     +,   1.9238837E-04,   1.9277423E-04,   1.9319130E-04
     +,   1.9363732E-04,   1.9410993E-04,   1.9460612E-04
     +,   1.9512307E-04,   1.9565738E-04,   1.9620571E-04
     +,   1.9676448E-04,   1.9733005E-04,   1.9789896E-04
     +,   1.9846746E-04,   1.9903226E-04,   1.9959014E-04
     +,   2.0013815E-04,   2.0067366E-04,   2.0119434E-04
     +,   2.0169852E-04,   2.0218489E-04,   2.0265288E-04
     +,   2.0310233E-04,   2.0353409E-04,   2.0394940E-04
     +,   2.0435049E-04,   2.0474035E-04,   2.0512276E-04
     +,   2.0550241E-04,   2.0588476E-04,   2.0627629E-04
     +,   2.0668405E-04,   2.0711623E-04,   2.0758154E-04
     +,   2.0808959E-04,   2.0865088E-04,   2.0927632E-04
     +,   2.0997769E-04,   2.1076734E-04,   2.1165817E-04
     +,   2.1266386E-04,   2.1379846E-04,   2.1507656E-04
     +,   2.1651335E-04,   2.1812468E-04,   2.1992727E-04
     +,   2.2193851E-04,   2.2417649E-04,   2.2666089E-04
     +,   2.2941262E-04,   2.3245420E-04,   2.3581028E-04
     +,   2.3950817E-04,   2.4357790E-04,   2.4805265E-04
     +,   2.5297006E-04,   2.5837266E-04,   2.6430713E-04
     +,   2.7082639E-04,   2.7798978E-04,   2.8586324E-04
     +,   2.9451930E-04,   3.0403759E-04,   3.1450464E-04
     +,   3.2601389E-04,   3.3866297E-04,   3.5255466E-04
     +,   3.6779459E-04,   3.8448750E-04,   4.0273511E-04
     +,   4.2263450E-04,   4.4427294E-04,   4.6772239E-04
     +,   4.9303618E-04,   5.2024575E-04,   5.4935605E-04
     +,   5.8033899E-04,   6.1313109E-04,   6.4763444E-04
     +,   6.8371353E-04,   7.2119286E-04,   7.5986661E-04
     +,   7.9949904E-04,   8.3983107E-04,   8.8059029E-04
     +,   9.2150772E-04,   9.6232543E-04,   1.0028140E-03
     +,   1.0427857E-03,   1.0821172E-03,   1.1207591E-03
     +,   1.1587441E-03,   1.1962046E-03,   1.2333723E-03
     +,   1.2705754E-03,   1.3082302E-03,   1.3468266E-03
     +,   1.3869087E-03,   1.4290401E-03,   1.4737796E-03
     +,   1.5216514E-03,   1.5731151E-03,   1.6285452E-03
     +,   1.6882168E-03,   1.7523180E-03,   1.8209533E-03
     +,   1.8941668E-03,   1.9719733E-03,   2.0543861E-03
     +,   2.1414384E-03,   2.2331662E-03,   2.3296094E-03
     +,   2.4307584E-03,   2.5365187E-03,   2.6466721E-03
     +,   2.7609107E-03,   2.8789362E-03,   3.0006559E-03
     +,   3.1265425E-03,   3.2580637E-03,   3.3981677E-03
     +,   3.5516298E-03,   3.7252021E-03,   3.9273254E-03
     +,   4.1673398E-03,   4.4541368E-03,   4.7946642E-03
     +,   5.1923878E-03,   5.6462819E-03,   6.1506843E-03
     +,   6.6960528E-03,   7.2701643E-03,   7.8593614E-03
     +,   8.4495721E-03,   9.0270806E-03,   9.5797190E-03
     +,   1.0099272E-02,   1.0585398E-02,   1.1049670E-02
     +,   1.1517330E-02,   1.2024093E-02,   1.2607126E-02
     +,   1.3292162E-02,   1.4081025E-02,   1.4945476E-02
     +,   1.5830668E-02,   1.6668689E-02,   1.7399509E-02
     +,   1.7992547E-02,   1.8458638E-02,   1.8844897E-02
     +,   1.9211868E-02,   1.9604305E-02,   2.0030731E-02
     +,   2.0461150E-02,   2.0841844E-02,   2.1116870E-02
     +,   2.1246148E-02,   2.1215620E-02,   2.1038784E-02
     +,   2.0750675E-02,   2.0395439E-02,   2.0011200E-02
     +,   1.9616893E-02,   1.9206343E-02,   1.8749597E-02
     +,   1.8200466E-02,   1.7507883E-02,   1.6630758E-02
     +,   1.5553076E-02,   1.4294267E-02,   1.2908611E-02
     +,   1.1473382E-02,   1.0070204E-02,   8.7671988E-03
     +,   7.6080905E-03,   6.6103009E-03,   5.7696439E-03
     +,   5.0679948E-03,   4.4809650E-03,   3.9837882E-03
     +,   3.5548578E-03,   3.1771248E-03,   2.8383650E-03
     +,   2.5304926E-03,   2.2487401E-03,   1.9906044E-03
     +,   1.7550172E-03,   1.5415548E-03,   1.3499535E-03
     +,   1.1797189E-03,   1.0300142E-03,   8.9958840E-04
     +,   7.8685547E-04,   6.9001276E-04,   6.0713745E-04
     +,   5.3632830E-04,   4.7577490E-04,   4.2384272E-04
     +,   3.7909226E-04,   3.4030507E-04,   3.0646459E-04
     +,   2.7674704E-04,   2.5048605E-04,   2.2715300E-04
     +,   2.0632333E-04,   1.8765968E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt120 = Yx/0.212333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.4996601E-04,   7.3909579E-04
     +,   8.4093557E-04,   9.5686701E-04,   1.0881780E-03
     +,   1.2360185E-03,   1.4013870E-03,   1.5851666E-03
     +,   1.7882362E-03,   2.0116819E-03,   2.2570521E-03
     +,   2.5267096E-03,   2.8241749E-03,   3.1544121E-03
     +,   3.5239728E-03,   3.9409325E-03,   4.4145114E-03
     +,   4.9543087E-03,   5.5691130E-03,   6.2653222E-03
     +,   7.0453607E-03,   7.9066278E-03,   8.8419663E-03
     +,   9.8422160E-03,   1.0900164E-02,   1.2014777E-02
     +,   1.3191724E-02,   1.4438819E-02,   1.5756283E-02
     +,   1.7126987E-02,   1.8513789E-02,   1.9868962E-02
     +,   2.1153850E-02,   2.2357982E-02,   2.3506653E-02
     +,   2.4649797E-02,   2.5835922E-02,   2.7081881E-02
     +,   2.8351825E-02,   2.9555315E-02,   3.0570934E-02
     +,   3.1286620E-02,   3.1638216E-02,   3.1621415E-02
     +,   3.1270906E-02,   3.0624019E-02,   2.9699564E-02
     +,   2.8505808E-02,   2.7065564E-02,   2.5432574E-02
     +,   2.3685960E-02,   2.1909539E-02,   2.0172335E-02
     +,   1.8520230E-02,   1.6976397E-02,   1.5544903E-02
     +,   1.4216559E-02,   1.2976322E-02,   1.1812286E-02
     +,   1.0722599E-02,   9.7168162E-03,   8.8113230E-03
     +,   8.0218781E-03,   7.3568425E-03,   6.8142386E-03
     +,   6.3823839E-03,   6.0429140E-03,   5.7746619E-03
     +,   5.5569015E-03,   5.3717461E-03,   5.2052434E-03
     +,   5.0476636E-03,   4.8930440E-03,   4.7384533E-03
     +,   4.5830049E-03,   4.4270921E-03,   4.2717247E-03
     +,   4.1180914E-03,   3.9673108E-03,   3.8203127E-03
     +,   3.6778091E-03,   3.5402768E-03,   3.4079745E-03
     +,   3.2809556E-03,   3.1591002E-03,   3.0421163E-03
     +,   2.9296202E-03,   2.8211304E-03,   2.7161583E-03
     +,   2.6142355E-03,   2.5149549E-03,   2.4180210E-03
     +,   2.3232705E-03,   2.2306615E-03,   2.1402834E-03
     +,   2.0523462E-03,   1.9671237E-03,   1.8849542E-03
     +,   1.8061772E-03,   1.7311287E-03,   1.6600885E-03
     +,   1.5932844E-03,   1.5308597E-03,   1.4728812E-03
     +,   1.4193279E-03,   1.3701055E-03,   1.3250515E-03
     +,   1.2839454E-03,   1.2465243E-03,   1.2124878E-03
     +,   1.1815231E-03,   1.1533018E-03,   1.1275004E-03
     +,   1.1038013E-03,   1.0819028E-03,   1.0615233E-03
     +,   1.0424055E-03,   1.0243176E-03,   1.0070581E-03
     +,   9.9045294E-04,   9.7435672E-04,   9.5865474E-04
     +,   9.4325852E-04,   9.2810503E-04,   9.1315783E-04
     +,   8.9840102E-04,   8.8383874E-04,   8.6949317E-04
     +,   8.5540098E-04,   8.4161165E-04,   8.2818116E-04
     +,   8.1517763E-04,   8.0266770E-04,   7.9072290E-04
     +,   7.7941315E-04,   7.6880539E-04,   7.5896189E-04
     +,   7.4993947E-04,   7.4178603E-04,   7.3454186E-04
     +,   7.2823605E-04,   7.2288967E-04,   7.1851199E-04
     +,   7.1510149E-04,   7.1264646E-04,   7.1112579E-04
     +,   7.1050768E-04,   7.1075250E-04,   7.1181124E-04
     +,   7.1362796E-04,   7.1614067E-04,   7.1928219E-04
     +,   7.2297954E-04,   7.2715763E-04,   7.3173962E-04
     +,   7.3664641E-04,   7.4179965E-04,   7.4712164E-04
     +,   7.5253734E-04,   7.5797399E-04,   7.6336320E-04
     +,   7.6864182E-04,   7.7375071E-04,   7.7863835E-04
     +,   7.8325934E-04,   7.8757509E-04,   7.9155539E-04
     +,   7.9517654E-04,   7.9842226E-04,   8.0128550E-04
     +,   8.0376444E-04,   8.0586545E-04,   8.0760120E-04
     +,   8.0898881E-04,   8.1005238E-04,   8.1081904E-04
     +,   8.1131910E-04,   8.1158616E-04,   8.1165478E-04
     +,   8.1155915E-04,   8.1133487E-04,   8.1101322E-04
     +,   8.1062497E-04,   8.1019581E-04,   8.0974883E-04
     +,   8.0930098E-04,   8.0886419E-04,   8.0844341E-04
     +,   8.0803840E-04,   8.0764154E-04,   8.0723956E-04
     +,   8.0681097E-04,   8.0633041E-04,   8.0576417E-04
     +,   8.0507604E-04,   8.0422236E-04,   8.0315839E-04
     +,   8.0183428E-04,   8.0019888E-04,   7.9820078E-04
     +,   7.9578720E-04,   7.9290732E-04,   7.8951195E-04
     +,   7.8555464E-04,   7.8099332E-04,   7.7579054E-04
     +,   7.6991384E-04,   7.6333736E-04,   7.5604190E-04
     +,   7.4801565E-04,   7.3925301E-04,   7.2975643E-04
     +,   7.1953679E-04,   7.0860994E-04,   6.9700112E-04
     +,   6.8474049E-04,   6.7186553E-04,   6.5841817E-04
     +,   6.4444577E-04,   6.3000002E-04,   6.1513548E-04
     +,   5.9990870E-04,   5.8437971E-04,   5.6860852E-04
     +,   5.5265438E-04,   5.3657690E-04,   5.2043481E-04
     +,   5.0428463E-04,   4.8818038E-04,   4.7217228E-04
     +,   4.5630880E-04,   4.4063421E-04,   4.2518837E-04
     +,   4.1000705E-04,   3.9512324E-04,   3.8056434E-04
     +,   3.6635352E-04,   3.5251112E-04,   3.3905348E-04
     +,   3.2599215E-04,   3.1333565E-04,   3.0108960E-04
     +,   2.8925721E-04,   2.7783783E-04,   2.6682849E-04
     +,   2.5622483E-04,   2.4602105E-04,   2.3620838E-04
     +,   2.2677731E-04,   2.1771784E-04,   2.0901834E-04
     +,   2.0066662E-04,   1.9265043E-04,   1.8495736E-04
     +,   1.7757413E-04,   1.7048775E-04,   1.6368547E-04
     +,   1.5715495E-04,   1.5088360E-04,   1.4485924E-04
     +,   1.3907047E-04,   1.3350626E-04,   1.2815585E-04
     +,   1.2300878E-04,   1.1805574E-04,   1.1328745E-04
     +,   1.0869512E-04,   1.0427084E-04,   1.0000714E-04
     +,   9.5896787E-05,   9.1933085E-05,   8.8109977E-05
     +,   8.4421976E-05,   8.0863567E-05,   7.7429781E-05
     +,   7.4116353E-05,   7.0918853E-05,   6.7833600E-05
     +,   6.4856809E-05,   6.1985331E-05,   5.9215876E-05
     +,   5.6545727E-05,   5.3971969E-05,   5.1492225E-05
     +,   4.9103895E-05,   4.6804831E-05,   4.4592747E-05
     +,   4.2465432E-05,   4.0420975E-05,   3.8457209E-05
     +,   3.6572295E-05,   3.4764180E-05,   3.3031058E-05
     +,   3.1370888E-05,   2.9781902E-05,   2.8262097E-05
     +,   2.6809659E-05,   2.5422603E-05,   2.4099128E-05
     +,   2.2837228E-05,   2.1635089E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt60 = Yx/0.271957446808511
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3069665E-04,   2.5009559E-04
     +,   2.7113603E-04,   2.9392581E-04,   3.1857309E-04
     +,   3.4518499E-04,   3.7386714E-04,   4.0472450E-04
     +,   4.3786116E-04,   4.7338376E-04,   5.1140075E-04
     +,   5.5202865E-04,   5.9539475E-04,   6.4164511E-04
     +,   6.9095101E-04,   7.4352074E-04,   7.9961255E-04
     +,   8.5955171E-04,   9.2375214E-04,   9.9273922E-04
     +,   1.0671798E-03,   1.1479098E-03,   1.2359620E-03
     +,   1.3326013E-03,   1.4393250E-03,   1.5579109E-03
     +,   1.6903949E-03,   1.8390955E-03,   2.0066083E-03
     +,   2.1957788E-03,   2.4096756E-03,   2.6514826E-03
     +,   2.9243722E-03,   3.2312647E-03,   3.5745956E-03
     +,   3.9560744E-03,   4.3765525E-03,   4.8360424E-03
     +,   5.3339046E-03,   5.8689043E-03,   6.4393431E-03
     +,   7.0427540E-03,   7.6759327E-03,   8.3355159E-03
     +,   9.0198405E-03,   9.7319428E-03,   1.0482533E-02
     +,   1.1290961E-02,   1.2182002E-02,   1.3177952E-02
     +,   1.4287774E-02,   1.5497489E-02,   1.6766839E-02
     +,   1.8035609E-02,   1.9239623E-02,   2.0331454E-02
     +,   2.1296641E-02,   2.2157660E-02,   2.2961311E-02
     +,   2.3752211E-02,   2.4542691E-02,   2.5293114E-02
     +,   2.5913367E-02,   2.6289133E-02,   2.6321700E-02
     +,   2.5962891E-02,   2.5227120E-02,   2.4178166E-02
     +,   2.2900969E-02,   2.1477377E-02,   1.9975213E-02
     +,   1.8450929E-02,   1.6955782E-02,   1.5537987E-02
     +,   1.4237296E-02,   1.3077194E-02,   1.2060416E-02
     +,   1.1171278E-02,   1.0384182E-02,   9.6733198E-03
     +,   9.0198452E-03,   8.4135989E-03,   7.8511555E-03
     +,   7.3318942E-03,   6.8549705E-03,   6.4176889E-03
     +,   6.0157627E-03,   5.6441585E-03,   5.2981875E-03
     +,   4.9740681E-03,   4.6691662E-03,   4.3818951E-03
     +,   4.1115070E-03,   3.8578559E-03,   3.6212190E-03
     +,   3.4021426E-03,   3.2011899E-03,   3.0188144E-03
     +,   2.8551496E-03,   2.7099417E-03,   2.5824590E-03
     +,   2.4715760E-03,   2.3757683E-03,   2.2932759E-03
     +,   2.2221759E-03,   2.1605107E-03,   2.1063879E-03
     +,   2.0580469E-03,   2.0139134E-03,   1.9726369E-03
     +,   1.9331179E-03,   1.8944882E-03,   1.8561279E-03
     +,   1.8176246E-03,   1.7787676E-03,   1.7395065E-03
     +,   1.6999319E-03,   1.6602323E-03,   1.6206749E-03
     +,   1.5815677E-03,   1.5432369E-03,   1.5060063E-03
     +,   1.4701798E-03,   1.4360200E-03,   1.4037424E-03
     +,   1.3735141E-03,   1.3454409E-03,   1.3195755E-03
     +,   1.2959121E-03,   1.2743978E-03,   1.2549304E-03
     +,   1.2373715E-03,   1.2215452E-03,   1.2072561E-03
     +,   1.1942856E-03,   1.1824089E-03,   1.1713968E-03
     +,   1.1610242E-03,   1.1510777E-03,   1.1413607E-03
     +,   1.1316992E-03,   1.1219447E-03,   1.1119774E-03
     +,   1.1017126E-03,   1.0910948E-03,   1.0801016E-03
     +,   1.0687433E-03,   1.0570566E-03,   1.0451075E-03
     +,   1.0329818E-03,   1.0207834E-03,   1.0086314E-03
     +,   9.9665252E-04,   9.8497642E-04,   9.7373407E-04
     +,   9.6305076E-04,   9.5304381E-04,   9.4381644E-04
     +,   9.3545945E-04,   9.2804548E-04,   9.2162791E-04
     +,   9.1624010E-04,   9.1189565E-04,   9.0858771E-04
     +,   9.0628827E-04,   9.0495148E-04,   9.0451218E-04
     +,   9.0489036E-04,   9.0599142E-04,   9.0770790E-04
     +,   9.0992200E-04,   9.1251108E-04,   9.1534574E-04
     +,   9.1829372E-04,   9.2122488E-04,   9.2401053E-04
     +,   9.2652743E-04,   9.2866039E-04,   9.3030179E-04
     +,   9.3135738E-04,   9.3174254E-04,   9.3138893E-04
     +,   9.3024177E-04,   9.2825969E-04,   9.2541805E-04
     +,   9.2170731E-04,   9.1713067E-04,   9.1170595E-04
     +,   9.0546248E-04,   8.9844107E-04,   8.9069194E-04
     +,   8.8227342E-04,   8.7324937E-04,   8.6368906E-04
     +,   8.5366372E-04,   8.4324449E-04,   8.3250355E-04
     +,   8.2151004E-04,   8.1032963E-04,   7.9902320E-04
     +,   7.8764604E-04,   7.7624776E-04,   7.6487020E-04
     +,   7.5354800E-04,   7.4231002E-04,   7.3117582E-04
     +,   7.2015973E-04,   7.0926850E-04,   6.9850456E-04
     +,   6.8786280E-04,   6.7733461E-04,   6.6690805E-04
     +,   6.5656676E-04,   6.4629351E-04,   6.3606806E-04
     +,   6.2587037E-04,   6.1568100E-04,   6.0547999E-04
     +,   5.9524807E-04,   5.8496970E-04,   5.7462946E-04
     +,   5.6421536E-04,   5.5371755E-04,   5.4313021E-04
     +,   5.3244922E-04,   5.2167324E-04,   5.1080500E-04
     +,   4.9985002E-04,   4.8881501E-04,   4.7771010E-04
     +,   4.6654756E-04,   4.5534177E-04,   4.4410804E-04
     +,   4.3286287E-04,   4.2162492E-04,   4.1041197E-04
     +,   3.9924285E-04,   3.8813663E-04,   3.7711221E-04
     +,   3.6618763E-04,   3.5537989E-04,   3.4470606E-04
     +,   3.3418185E-04,   3.2382138E-04,   3.1363766E-04
     +,   3.0364256E-04,   2.9384694E-04,   2.8425927E-04
     +,   2.7488661E-04,   2.6573599E-04,   2.5681147E-04
     +,   2.4811632E-04,   2.3965312E-04,   2.3142294E-04
     +,   2.2342558E-04,   2.1565965E-04,   2.0812341E-04
     +,   2.0081454E-04,   1.9372925E-04,   1.8686340E-04
     +,   1.8021281E-04,   1.7377274E-04,   1.6753780E-04
     +,   1.6150244E-04,   1.5566134E-04,   1.5000874E-04
     +,   1.4453870E-04,   1.3924569E-04,   1.3412428E-04
     +,   1.2916866E-04,   1.2437330E-04,   1.1973307E-04
     +,   1.1524300E-04,   1.1089803E-04,   1.0669326E-04
     +,   1.0262446E-04,   9.8687036E-05,   9.4877141E-05
     +,   9.1190544E-05,   8.7623797E-05,   8.4173065E-05
     +,   8.0835242E-05,   7.7606914E-05,   7.4485171E-05
     +,   7.1466930E-05,   6.8549583E-05,   6.5730383E-05
     +,   6.3006650E-05,   6.0376147E-05,   5.7836303E-05
     +,   5.5384986E-05,   5.3019787E-05,   5.0738719E-05
     +,   4.8539518E-05,   4.6420235E-05,   4.4378718E-05
     +,   4.2413107E-05,   4.0521310E-05,   3.8701502E-05
     +,   3.6951667E-05,   3.5270015E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt65 = Yx/0.234804347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1488872E-04,   1.1957719E-04
     +,   1.2433143E-04,   1.2914839E-04,   1.3402608E-04
     +,   1.3896375E-04,   1.4396261E-04,   1.4902596E-04
     +,   1.5415993E-04,   1.5937435E-04,   1.6468283E-04
     +,   1.7010405E-04,   1.7566235E-04,   1.8138855E-04
     +,   1.8732111E-04,   1.9350645E-04,   2.0000046E-04
     +,   2.0686872E-04,   2.1418744E-04,   2.2204369E-04
     +,   2.3053576E-04,   2.3977309E-04,   2.4987562E-04
     +,   2.6097373E-04,   2.7320528E-04,   2.8671630E-04
     +,   3.0165716E-04,   3.1818065E-04,   3.3644016E-04
     +,   3.5658674E-04,   3.7876848E-04,   4.0312900E-04
     +,   4.2981084E-04,   4.5895754E-04,   4.9072248E-04
     +,   5.2528054E-04,   5.6284235E-04,   6.0367328E-04
     +,   6.4811873E-04,   6.9661823E-04,   7.4973714E-04
     +,   8.0817397E-04,   8.7277644E-04,   9.4454357E-04
     +,   1.0246247E-03,   1.1143205E-03,   1.2150807E-03
     +,   1.3285207E-03,   1.4564291E-03,   1.6007817E-03
     +,   1.7637199E-03,   1.9474619E-03,   2.1541428E-03
     +,   2.3855492E-03,   2.6427459E-03,   2.9257657E-03
     +,   3.2333152E-03,   3.5627589E-03,   3.9103869E-03
     +,   4.2720577E-03,   4.6441890E-03,   5.0249859E-03
     +,   5.4156957E-03,   5.8217868E-03,   6.2534730E-03
     +,   6.7254785E-03,   7.2558266E-03,   7.8633036E-03
     +,   8.5643083E-03,   9.3690576E-03,   1.0278595E-02
     +,   1.1282588E-02,   1.2359767E-02,   1.3479990E-02
     +,   1.4608845E-02,   1.5712367E-02,   1.6760342E-02
     +,   1.7726561E-02,   1.8585743E-02,   1.9309077E-02
     +,   1.9862195E-02,   2.0209236E-02,   2.0322138E-02
     +,   2.0192081E-02,   1.9836338E-02,   1.9296758E-02
     +,   1.8629633E-02,   1.7891442E-02,   1.7126797E-02
     +,   1.6362585E-02,   1.5608568E-02,   1.4862552E-02
     +,   1.4116048E-02,   1.3359467E-02,   1.2586163E-02
     +,   1.1795446E-02,   1.0994030E-02,   1.0195564E-02
     +,   9.4175925E-03,   8.6775590E-03,   7.9886904E-03
     +,   7.3580169E-03,   6.7861369E-03,   6.2690363E-03
     +,   5.8002882E-03,   5.3732642E-03,   4.9826247E-03
     +,   4.6248580E-03,   4.2981608E-03,   4.0019033E-03
     +,   3.7359600E-03,   3.4999736E-03,   3.2930113E-03
     +,   3.1133224E-03,   2.9584502E-03,   2.8253749E-03
     +,   2.7108258E-03,   2.6114972E-03,   2.5242926E-03
     +,   2.4464424E-03,   2.3756237E-03,   2.3099841E-03
     +,   2.2481377E-03,   2.1891177E-03,   2.1323115E-03
     +,   2.0773918E-03,   2.0242124E-03,   1.9727615E-03
     +,   1.9230797E-03,   1.8752426E-03,   1.8293175E-03
     +,   1.7853791E-03,   1.7434838E-03,   1.7036984E-03
     +,   1.6660900E-03,   1.6307338E-03,   1.5977119E-03
     +,   1.5671108E-03,   1.5390137E-03,   1.5134885E-03
     +,   1.4905867E-03,   1.4703317E-03,   1.4527090E-03
     +,   1.4376665E-03,   1.4251075E-03,   1.4148930E-03
     +,   1.4068392E-03,   1.4007216E-03,   1.3962771E-03
     +,   1.3932096E-03,   1.3911978E-03,   1.3899024E-03
     +,   1.3889709E-03,   1.3880536E-03,   1.3868106E-03
     +,   1.3849208E-03,   1.3820949E-03,   1.3780836E-03
     +,   1.3726846E-03,   1.3657527E-03,   1.3571996E-03
     +,   1.3469991E-03,   1.3351890E-03,   1.3218616E-03
     +,   1.3071672E-03,   1.2912982E-03,   1.2744863E-03
     +,   1.2569891E-03,   1.2390800E-03,   1.2210347E-03
     +,   1.2031209E-03,   1.1855911E-03,   1.1686670E-03
     +,   1.1525361E-03,   1.1373471E-03,   1.1232035E-03
     +,   1.1101621E-03,   1.0982371E-03,   1.0873989E-03
     +,   1.0775789E-03,   1.0686759E-03,   1.0605602E-03
     +,   1.0530843E-03,   1.0460847E-03,   1.0393928E-03
     +,   1.0328402E-03,   1.0262660E-03,   1.0195193E-03
     +,   1.0124661E-03,   1.0049919E-03,   9.9700491E-04
     +,   9.8843488E-04,   9.7923784E-04,   9.6939132E-04
     +,   9.5889805E-04,   9.4777840E-04,   9.3607418E-04
     +,   9.2384219E-04,   9.1115234E-04,   8.9808408E-04
     +,   8.8472595E-04,   8.7116973E-04,   8.5750734E-04
     +,   8.4383093E-04,   8.3022902E-04,   8.1678270E-04
     +,   8.0356700E-04,   7.9064840E-04,   7.7808189E-04
     +,   7.6591276E-04,   7.5417472E-04,   7.4288982E-04
     +,   7.3207100E-04,   7.2171778E-04,   7.1182102E-04
     +,   7.0236222E-04,   6.9331506E-04,   6.8464468E-04
     +,   6.7631027E-04,   6.6826690E-04,   6.6046428E-04
     +,   6.5285002E-04,   6.4536964E-04,   6.3796825E-04
     +,   6.3059101E-04,   6.2318397E-04,   6.1569590E-04
     +,   6.0807844E-04,   6.0028548E-04,   5.9227593E-04
     +,   5.8401306E-04,   5.7546597E-04,   5.6660781E-04
     +,   5.5741699E-04,   5.4787955E-04,   5.3798506E-04
     +,   5.2773015E-04,   5.1711651E-04,   5.0615170E-04
     +,   4.9484748E-04,   4.8322114E-04,   4.7129413E-04
     +,   4.5909244E-04,   4.4664505E-04,   4.3398328E-04
     +,   4.2114253E-04,   4.0815948E-04,   3.9507181E-04
     +,   3.8191761E-04,   3.6873712E-04,   3.5556871E-04
     +,   3.4245031E-04,   3.2941953E-04,   3.1651245E-04
     +,   3.0376253E-04,   2.9120111E-04,   2.7885809E-04
     +,   2.6676053E-04,   2.5493206E-04,   2.4339357E-04
     +,   2.3216393E-04,   2.2125900E-04,   2.1069103E-04
     +,   2.0046979E-04,   1.9060328E-04,   1.8109608E-04
     +,   1.7195031E-04,   1.6316673E-04,   1.5474395E-04
     +,   1.4667834E-04,   1.3896459E-04,   1.3159672E-04
     +,   1.2456723E-04,   1.1786735E-04,   1.1148738E-04
     +,   1.0541775E-04,   9.9647346E-05,   9.4165604E-05
     +,   8.8960944E-05,   8.4022351E-05,   7.9338162E-05
     +,   7.4897303E-05,   7.0688402E-05,   6.6700813E-05
     +,   6.2923580E-05,   5.9346574E-05,   5.5959699E-05
     +,   5.2753156E-05,   4.9717943E-05,   4.6844987E-05
     +,   4.4126013E-05,   4.1552819E-05,   3.9117913E-05
     +,   3.6813886E-05,   3.4634017E-05,   3.2571686E-05
     +,   3.0620849E-05,   2.8775592E-05,   2.7030561E-05
     +,   2.5380468E-05,   2.3820532E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt70 = Yx/0.190711111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2275936E-05,   5.5180033E-05
     +,   5.8237838E-05,   6.1455379E-05,   6.4838634E-05
     +,   6.8393514E-05,   7.2125738E-05,   7.6040924E-05
     +,   8.0144411E-05,   8.4441555E-05,   8.8937319E-05
     +,   9.3636540E-05,   9.8543867E-05,   1.0366378E-04
     +,   1.0900071E-04,   1.1455906E-04,   1.2034306E-04
     +,   1.2635725E-04,   1.3260629E-04,   1.3909519E-04
     +,   1.4582946E-04,   1.5281505E-04,   1.6005861E-04
     +,   1.6756807E-04,   1.7535160E-04,   1.8341905E-04
     +,   1.9178145E-04,   2.0045089E-04,   2.0944091E-04
     +,   2.1876671E-04,   2.2844494E-04,   2.3849361E-04
     +,   2.4893260E-04,   2.5978332E-04,   2.7106865E-04
     +,   2.8281333E-04,   2.9504343E-04,   3.0778724E-04
     +,   3.2107488E-04,   3.3493797E-04,   3.4941154E-04
     +,   3.6453264E-04,   3.8034227E-04,   3.9688530E-04
     +,   4.1421238E-04,   4.3238135E-04,   4.5145873E-04
     +,   4.7152300E-04,   4.9266708E-04,   5.1500241E-04
     +,   5.3866243E-04,   5.6380685E-04,   5.9062475E-04
     +,   6.1933993E-04,   6.5020699E-04,   6.8351830E-04
     +,   7.1959529E-04,   7.5878424E-04,   8.0144923E-04
     +,   8.4795913E-04,   8.9867826E-04,   9.5395377E-04
     +,   1.0141009E-03,   1.0794072E-03,   1.1501251E-03
     +,   1.2264730E-03,   1.3086633E-03,   1.3969134E-03
     +,   1.4915061E-03,   1.5928224E-03,   1.7014456E-03
     +,   1.8182223E-03,   1.9443705E-03,   2.0815090E-03
     +,   2.2316787E-03,   2.3972362E-03,   2.5806485E-03
     +,   2.7842592E-03,   3.0101070E-03,   3.2599051E-03
     +,   3.5353359E-03,   3.8388441E-03,   4.1746069E-03
     +,   4.5496654E-03,   4.9744439E-03,   5.4623107E-03
     +,   6.0274731E-03,   6.6814432E-03,   7.4282927E-03
     +,   8.2605453E-03,   9.1569070E-03,   1.0083607E-02
     +,   1.1000012E-02,   1.1867180E-02,   1.2656767E-02
     +,   1.3356820E-02,   1.3972249E-02,   1.4518620E-02
     +,   1.5011596E-02,   1.5455583E-02,   1.5836636E-02
     +,   1.6122781E-02,   1.6272837E-02,   1.6250418E-02
     +,   1.6038002E-02,   1.5644442E-02,   1.5103043E-02
     +,   1.4461196E-02,   1.3766564E-02,   1.3056166E-02
     +,   1.2352126E-02,   1.1663960E-02,   1.0994567E-02
     +,   1.0345994E-02,   9.7225942E-03,   9.1310190E-03
     +,   8.5784588E-03,   8.0702547E-03,   7.6084691E-03
     +,   7.1912473E-03,   6.8135192E-03,   6.4683519E-03
     +,   6.1486322E-03,   5.8486438E-03,   5.5651111E-03
     +,   5.2974960E-03,   5.0474424E-03,   4.8177578E-03
     +,   4.6111331E-03,   4.4291830E-03,   4.2718113E-03
     +,   4.1371570E-03,   4.0218676E-03,   3.9216643E-03
     +,   3.8319260E-03,   3.7482104E-03,   3.6666824E-03
     +,   3.5843754E-03,   3.4993133E-03,   3.4105601E-03
     +,   3.3181729E-03,   3.2230553E-03,   3.1268003E-03
     +,   3.0314468E-03,   2.9392715E-03,   2.8525288E-03
     +,   2.7732421E-03,   2.7030327E-03,   2.6429894E-03
     +,   2.5935951E-03,   2.5547142E-03,   2.5256288E-03
     +,   2.5051229E-03,   2.4915794E-03,   2.4831176E-03
     +,   2.4777274E-03,   2.4733983E-03,   2.4682435E-03
     +,   2.4605987E-03,   2.4490950E-03,   2.4327203E-03
     +,   2.4108284E-03,   2.3831408E-03,   2.3497241E-03
     +,   2.3109284E-03,   2.2673404E-03,   2.2197086E-03
     +,   2.1688768E-03,   2.1157167E-03,   2.0610786E-03
     +,   2.0057485E-03,   1.9504108E-03,   1.8956451E-03
     +,   1.8419070E-03,   1.7895468E-03,   1.7388167E-03
     +,   1.6898814E-03,   1.6428486E-03,   1.5977725E-03
     +,   1.5546760E-03,   1.5135556E-03,   1.4743969E-03
     +,   1.4371733E-03,   1.4018522E-03,   1.3683876E-03
     +,   1.3367347E-03,   1.3068366E-03,   1.2786323E-03
     +,   1.2520528E-03,   1.2270303E-03,   1.2034936E-03
     +,   1.1813765E-03,   1.1606183E-03,   1.1411672E-03
     +,   1.1229833E-03,   1.1060372E-03,   1.0903144E-03
     +,   1.0758108E-03,   1.0625313E-03,   1.0504865E-03
     +,   1.0396893E-03,   1.0301514E-03,   1.0218758E-03
     +,   1.0148545E-03,   1.0090661E-03,   1.0044699E-03
     +,   1.0010051E-03,   9.9858991E-04,   9.9712040E-04
     +,   9.9647569E-04,   9.9651329E-04,   9.9707965E-04
     +,   9.9800946E-04,   9.9912984E-04,   1.0002687E-03
     +,   1.0012556E-03,   1.0019270E-03,   1.0021307E-03
     +,   1.0017294E-03,   1.0006018E-03,   9.9864614E-04
     +,   9.9578022E-04,   9.9193933E-04,   9.8708156E-04
     +,   9.8117965E-04,   9.7422389E-04,   9.6621865E-04
     +,   9.5717935E-04,   9.4713201E-04,   9.3610835E-04
     +,   9.2414569E-04,   9.1128505E-04,   8.9756801E-04
     +,   8.8303589E-04,   8.6773158E-04,   8.5169566E-04
     +,   8.3496666E-04,   8.1758329E-04,   7.9958397E-04
     +,   7.8100571E-04,   7.6188485E-04,   7.4226095E-04
     +,   7.2217401E-04,   7.0166518E-04,   6.8077823E-04
     +,   6.5955956E-04,   6.3805957E-04,   6.1632850E-04
     +,   5.9442007E-04,   5.7239196E-04,   5.5030087E-04
     +,   5.2820507E-04,   5.0616474E-04,   4.8424030E-04
     +,   4.6248952E-04,   4.4096945E-04,   4.1973635E-04
     +,   3.9884448E-04,   3.7834342E-04,   3.5827965E-04
     +,   3.3869749E-04,   3.1963698E-04,   3.0113271E-04
     +,   2.8321514E-04,   2.6591201E-04,   2.4924459E-04
     +,   2.3323021E-04,   2.1788251E-04,   2.0321102E-04
     +,   1.8922018E-04,   1.7591048E-04,   1.6327997E-04
     +,   1.5132288E-04,   1.4002970E-04,   1.2938808E-04
     +,   1.1938408E-04,   1.1000025E-04,   1.0121831E-04
     +,   9.3017159E-05,   8.5375403E-05,   7.8269397E-05
     +,   7.1675735E-05,   6.5569358E-05,   5.9925798E-05
     +,   5.4719549E-05,   4.9925900E-05,   4.5519875E-05
     +,   4.1476902E-05,   3.7773367E-05,   3.4385819E-05
     +,   3.1292013E-05,   2.8470169E-05,   2.5899792E-05
     +,   2.3561044E-05,   2.1435419E-05,   1.9505162E-05
     +,   1.7753840E-05,   1.6165832E-05,   1.4726792E-05
     +,   1.3423170E-05,   1.2242619E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt75 = Yx/0.175318181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.4104374E-05,   5.5975383E-05
     +,   5.7882840E-05,   5.9826110E-05,   6.1804538E-05
     +,   6.3817439E-05,   6.5864209E-05,   6.7944180E-05
     +,   7.0056798E-05,   7.2201583E-05,   7.4378135E-05
     +,   7.6586148E-05,   7.8825557E-05,   8.1096405E-05
     +,   8.3399042E-05,   8.5734013E-05,   8.8102242E-05
     +,   9.0505040E-05,   9.2944007E-05,   9.5421332E-05
     +,   9.7939665E-05,   1.0050221E-04,   1.0311278E-04
     +,   1.0577600E-04,   1.0849696E-04,   1.1128178E-04
     +,   1.1413723E-04,   1.1707094E-04,   1.2009148E-04
     +,   1.2320833E-04,   1.2643177E-04,   1.2977305E-04
     +,   1.3324439E-04,   1.3685871E-04,   1.4062984E-04
     +,   1.4457230E-04,   1.4870137E-04,   1.5303271E-04
     +,   1.5758273E-04,   1.6236767E-04,   1.6740439E-04
     +,   1.7270964E-04,   1.7829976E-04,   1.8419113E-04
     +,   1.9039950E-04,   1.9693983E-04,   2.0382668E-04
     +,   2.1107342E-04,   2.1869256E-04,   2.2669559E-04
     +,   2.3509278E-04,   2.4389343E-04,   2.5310559E-04
     +,   2.6273672E-04,   2.7279215E-04,   2.8327751E-04
     +,   2.9419662E-04,   3.0555256E-04,   3.1734759E-04
     +,   3.2958281E-04,   3.4225825E-04,   3.5537287E-04
     +,   3.6892417E-04,   3.8290903E-04,   3.9732340E-04
     +,   4.1216135E-04,   4.2741859E-04,   4.4309022E-04
     +,   4.5917614E-04,   4.7567947E-04,   4.9261411E-04
     +,   5.1000493E-04,   5.2789686E-04,   5.4635771E-04
     +,   5.6548871E-04,   5.8543036E-04,   6.0637144E-04
     +,   6.2855659E-04,   6.5229752E-04,   6.7797798E-04
     +,   7.0605951E-04,   7.3709089E-04,   7.7170541E-04
     +,   8.1063027E-04,   8.5467839E-04,   9.0475357E-04
     +,   9.6183474E-04,   1.0269780E-03,   1.1012817E-03
     +,   1.1858792E-03,   1.2819052E-03,   1.3904548E-03
     +,   1.5125579E-03,   1.6491702E-03,   1.8011644E-03
     +,   1.9693349E-03,   2.1544828E-03,   2.3574189E-03
     +,   2.5790806E-03,   2.8204999E-03,   3.0828724E-03
     +,   3.3674126E-03,   3.6753539E-03,   4.0077590E-03
     +,   4.3654931E-03,   4.7492087E-03,   5.1593329E-03
     +,   5.5961474E-03,   6.0596857E-03,   6.5492382E-03
     +,   7.0623038E-03,   7.5931773E-03,   8.1312303E-03
     +,   8.6601144E-03,   9.1583906E-03,   9.6025374E-03
     +,   9.9716997E-03,   1.0253203E-02,   1.0446221E-02
     +,   1.0562330E-02,   1.0621993E-02,   1.0648482E-02
     +,   1.0661421E-02,   1.0672827E-02,   1.0686159E-02
     +,   1.0698426E-02,   1.0703129E-02,   1.0692879E-02
     +,   1.0660725E-02,   1.0600709E-02,   1.0508175E-02
     +,   1.0380399E-02,   1.0217434E-02,   1.0022546E-02
     +,   9.8018833E-03,   9.5632654E-03,   9.3144914E-03
     +,   9.0617463E-03,   8.8084731E-03,   8.5553415E-03
     +,   8.3009340E-03,   8.0428729E-03,   7.7788206E-03
     +,   7.5072111E-03,   7.2274152E-03,   6.9396324E-03
     +,   6.6447333E-03,   6.3443664E-03,   6.0410541E-03
     +,   5.7383152E-03,   5.4406747E-03,   5.1533617E-03
     +,   4.8817545E-03,   4.6307030E-03,   4.4039278E-03
     +,   4.2035943E-03,   4.0300819E-03,   3.8819988E-03
     +,   3.7564493E-03,   3.6494385E-03,   3.5563230E-03
     +,   3.4723317E-03,   3.3930489E-03,   3.3147768E-03
     +,   3.2347862E-03,   3.1514131E-03,   3.0640257E-03
     +,   2.9728417E-03,   2.8786715E-03,   2.7826570E-03
     +,   2.6860179E-03,   2.5898623E-03,   2.4950581E-03
     +,   2.4022069E-03,   2.3116751E-03,   2.2236481E-03
     +,   2.1382337E-03,   2.0555551E-03,   1.9758106E-03
     +,   1.8993140E-03,   1.8265151E-03,   1.7579783E-03
     +,   1.6943408E-03,   1.6362583E-03,   1.5843468E-03
     +,   1.5391352E-03,   1.5010190E-03,   1.4702303E-03
     +,   1.4468208E-03,   1.4306734E-03,   1.4215052E-03
     +,   1.4188961E-03,   1.4223168E-03,   1.4311606E-03
     +,   1.4447728E-03,   1.4624789E-03,   1.4836077E-03
     +,   1.5075051E-03,   1.5335525E-03,   1.5611653E-03
     +,   1.5897905E-03,   1.6189124E-03,   1.6480399E-03
     +,   1.6767012E-03,   1.7044365E-03,   1.7307916E-03
     +,   1.7553174E-03,   1.7775667E-03,   1.7970988E-03
     +,   1.8134884E-03,   1.8263328E-03,   1.8352601E-03
     +,   1.8399494E-03,   1.8401355E-03,   1.8356282E-03
     +,   1.8263117E-03,   1.8121626E-03,   1.7932396E-03
     +,   1.7696914E-03,   1.7417480E-03,   1.7097124E-03
     +,   1.6739460E-03,   1.6348631E-03,   1.5929078E-03
     +,   1.5485404E-03,   1.5022253E-03,   1.4544198E-03
     +,   1.4055583E-03,   1.3560462E-03,   1.3062499E-03
     +,   1.2564993E-03,   1.2070813E-03,   1.1582378E-03
     +,   1.1101696E-03,   1.0630430E-03,   1.0169870E-03
     +,   9.7209832E-04,   9.2845107E-04,   8.8609691E-04
     +,   8.4506604E-04,   8.0537435E-04,   7.6702941E-04
     +,   7.3002785E-04,   6.9435762E-04,   6.6000246E-04
     +,   6.2694412E-04,   5.9516128E-04,   5.6462962E-04
     +,   5.3532288E-04,   5.0721754E-04,   4.8028686E-04
     +,   4.5450413E-04,   4.2984408E-04,   4.0628162E-04
     +,   3.8379035E-04,   3.6234368E-04,   3.4191669E-04
     +,   3.2248421E-04,   3.0401966E-04,   2.8649624E-04
     +,   2.6988806E-04,   2.5416823E-04,   2.3930914E-04
     +,   2.2528159E-04,   2.1205794E-04,   1.9960808E-04
     +,   1.8790158E-04,   1.7690813E-04,   1.6659687E-04
     +,   1.5693589E-04,   1.4789318E-04,   1.3943709E-04
     +,   1.3153613E-04,   1.2415847E-04,   1.1727261E-04
     +,   1.1084849E-04,   1.0485583E-04,   9.9266013E-05
     +,   9.4050753E-05,   8.9183603E-05,   8.4638654E-05
     +,   8.0391939E-05,   7.6420358E-05,   7.2702744E-05
     +,   6.9218782E-05,   6.5950167E-05,   6.2879553E-05
     +,   5.9991107E-05,   5.7270521E-05,   5.4704415E-05
     +,   5.2280975E-05,   4.9989158E-05,   4.7819267E-05
     +,   4.5762299E-05,   4.3810429E-05,   4.1956315E-05
     +,   4.0193612E-05,   3.8516420E-05,   3.6919577E-05
     +,   3.5398265E-05,   3.3948298E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt80 = Yx/0.155302325581395
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.1786326E-05,   5.2504754E-05
     +,   5.3205200E-05,   5.3888001E-05,   5.4553671E-05
     +,   5.5203018E-05,   5.5837070E-05,   5.6457138E-05
     +,   5.7064808E-05,   5.7662026E-05,   5.8251015E-05
     +,   5.8834339E-05,   5.9414946E-05,   5.9996160E-05
     +,   6.0581693E-05,   6.1175677E-05,   6.1782652E-05
     +,   6.2407576E-05,   6.3055915E-05,   6.3733532E-05
     +,   6.4446765E-05,   6.5202403E-05,   6.6007691E-05
     +,   6.6870372E-05,   6.7798552E-05,   6.8800822E-05
     +,   6.9886170E-05,   7.1063929E-05,   7.2343792E-05
     +,   7.3735799E-05,   7.5250202E-05,   7.6897435E-05
     +,   7.8688128E-05,   8.0632941E-05,   8.2742561E-05
     +,   8.5027590E-05,   8.7498411E-05,   9.0165093E-05
     +,   9.3037561E-05,   9.6124866E-05,   9.9435798E-05
     +,   1.0297827E-04,   1.0675939E-04,   1.1078535E-04
     +,   1.1506116E-04,   1.1959083E-04,   1.2437692E-04
     +,   1.2942073E-04,   1.3472202E-04,   1.4027898E-04
     +,   1.4608826E-04,   1.5214480E-04,   1.5844175E-04
     +,   1.6497102E-04,   1.7172207E-04,   1.7868337E-04
     +,   1.8584162E-04,   1.9318184E-04,   2.0068805E-04
     +,   2.0834277E-04,   2.1612762E-04,   2.2402374E-04
     +,   2.3201089E-04,   2.4006949E-04,   2.4817995E-04
     +,   2.5632238E-04,   2.6447876E-04,   2.7263147E-04
     +,   2.8076558E-04,   2.8886768E-04,   2.9692822E-04
     +,   3.0494083E-04,   3.1290419E-04,   3.2082185E-04
     +,   3.2870442E-04,   3.3657064E-04,   3.4444718E-04
     +,   3.5237180E-04,   3.6039442E-04,   3.6857885E-04
     +,   3.7700339E-04,   3.8576481E-04,   3.9497647E-04
     +,   4.0477276E-04,   4.1530712E-04,   4.2675406E-04
     +,   4.3930585E-04,   4.5317339E-04,   4.6857976E-04
     +,   4.8575838E-04,   5.0494639E-04,   5.2637572E-04
     +,   5.5026560E-04,   5.7681621E-04,   6.0619798E-04
     +,   6.3853886E-04,   6.7392486E-04,   7.1238494E-04
     +,   7.5389672E-04,   7.9837436E-04,   8.4568228E-04
     +,   8.9562818E-04,   9.4798533E-04,   1.0024926E-03
     +,   1.0588847E-03,   1.1169154E-03,   1.1763877E-03
     +,   1.2372057E-03,   1.2994420E-03,   1.3634098E-03
     +,   1.4297479E-03,   1.4995325E-03,   1.5743554E-03
     +,   1.6564024E-03,   1.7484471E-03,   1.8537970E-03
     +,   1.9760916E-03,   2.1190147E-03,   2.2858400E-03
     +,   2.4789593E-03,   2.6993784E-03,   2.9463023E-03
     +,   3.2169665E-03,   3.5067885E-03,   3.8098451E-03
     +,   4.1196728E-03,   4.4304212E-03,   4.7379080E-03
     +,   5.0407220E-03,   5.3407750E-03,   5.6434153E-03
     +,   5.9566349E-03,   6.2897215E-03,   6.6510998E-03
     +,   7.0461794E-03,   7.4753873E-03,   7.9329768E-03
     +,   8.4070871E-03,   8.8809235E-03,   9.3346797E-03
     +,   9.7477911E-03,   1.0101240E-02,   1.0379501E-02
     +,   1.0572363E-02,   1.0676531E-02,   1.0696687E-02
     +,   1.0645382E-02,   1.0541012E-02,   1.0404253E-02
     +,   1.0253274E-02,   1.0099486E-02,   9.9453265E-03
     +,   9.7847693E-03,   9.6062375E-03,   9.3970504E-03
     +,   9.1473972E-03,   8.8529857E-03,   8.5158395E-03
     +,   8.1434008E-03,   7.7467989E-03,   7.3388037E-03
     +,   6.9319434E-03,   6.5372149E-03,   6.1631640E-03
     +,   5.8154822E-03,   5.4971748E-03,   5.2090432E-03
     +,   4.9503809E-03,   4.7197007E-03,   4.5152898E-03
     +,   4.3354989E-03,   4.1787103E-03,   4.0431544E-03
     +,   3.9266953E-03,   3.8267409E-03,   3.7403107E-03
     +,   3.6643019E-03,   3.5958698E-03,   3.5328015E-03
     +,   3.4737790E-03,   3.4184621E-03,   3.3674138E-03
     +,   3.3218127E-03,   3.2831125E-03,   3.2526462E-03
     +,   3.2313114E-03,   3.2193414E-03,   3.2162147E-03
     +,   3.2206853E-03,   3.2309187E-03,   3.2446983E-03
     +,   3.2596262E-03,   3.2733490E-03,   3.2837251E-03
     +,   3.2889496E-03,   3.2876232E-03,   3.2787742E-03
     +,   3.2618528E-03,   3.2366593E-03,   3.2032954E-03
     +,   3.1620788E-03,   3.1134572E-03,   3.0579371E-03
     +,   2.9960333E-03,   2.9282263E-03,   2.8549458E-03
     +,   2.7765881E-03,   2.6935455E-03,   2.6062536E-03
     +,   2.5152355E-03,   2.4211542E-03,   2.3248456E-03
     +,   2.2273404E-03,   2.1298383E-03,   2.0336853E-03
     +,   1.9403214E-03,   1.8512050E-03,   1.7677246E-03
     +,   1.6911254E-03,   1.6224375E-03,   1.5624025E-03
     +,   1.5114435E-03,   1.4696423E-03,   1.4367480E-03
     +,   1.4121883E-03,   1.3951256E-03,   1.3845050E-03
     +,   1.3791185E-03,   1.3776639E-03,   1.3788153E-03
     +,   1.3812731E-03,   1.3838167E-03,   1.3853387E-03
     +,   1.3848797E-03,   1.3816393E-03,   1.3749931E-03
     +,   1.3644889E-03,   1.3498428E-03,   1.3309331E-03
     +,   1.3077816E-03,   1.2805365E-03,   1.2494612E-03
     +,   1.2149075E-03,   1.1772979E-03,   1.1371049E-03
     +,   1.0948363E-03,   1.0510166E-03,   1.0061632E-03
     +,   9.6077874E-04,   9.1534125E-04,   8.7028480E-04
     +,   8.2599523E-04,   7.8280957E-04,   7.4100640E-04
     +,   7.0080510E-04,   6.6236802E-04,   6.2580575E-04
     +,   5.9117941E-04,   5.5850361E-04,   5.2775489E-04
     +,   4.9888075E-04,   4.7180385E-04,   4.4642732E-04
     +,   4.2264219E-04,   4.0033567E-04,   3.7939104E-04
     +,   3.5969386E-04,   3.4113607E-04,   3.2361763E-04
     +,   3.0704515E-04,   2.9133583E-04,   2.7641724E-04
     +,   2.6222650E-04,   2.4870920E-04,   2.3581846E-04
     +,   2.2351622E-04,   2.1176896E-04,   2.0054955E-04
     +,   1.8983362E-04,   1.7960157E-04,   1.6983488E-04
     +,   1.6051796E-04,   1.5163545E-04,   1.4317394E-04
     +,   1.3511932E-04,   1.2745897E-04,   1.2017950E-04
     +,   1.1326761E-04,   1.0671059E-04,   1.0049484E-04
     +,   9.4607589E-05,   8.9035246E-05,   8.3764971E-05
     +,   7.8783392E-05,   7.4077878E-05,   6.9635484E-05
     +,   6.5443957E-05,   6.1490849E-05,   5.7764559E-05
     +,   5.4253309E-05,   5.0946215E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt85 = Yx/0.146348837209302
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.5105090E-05,   9.8403427E-05
     +,   1.0169033E-04,   1.0495698E-04,   1.0819435E-04
     +,   1.1139350E-04,   1.1454547E-04,   1.1764144E-04
     +,   1.2067273E-04,   1.2363102E-04,   1.2650817E-04
     +,   1.2929646E-04,   1.3198861E-04,   1.3457784E-04
     +,   1.3705794E-04,   1.3942328E-04,   1.4166895E-04
     +,   1.4379070E-04,   1.4578510E-04,   1.4764941E-04
     +,   1.4938178E-04,   1.5098116E-04,   1.5244736E-04
     +,   1.5378115E-04,   1.5498392E-04,   1.5605811E-04
     +,   1.5700702E-04,   1.5783463E-04,   1.5854579E-04
     +,   1.5914606E-04,   1.5964177E-04,   1.6003993E-04
     +,   1.6034806E-04,   1.6057436E-04,   1.6072748E-04
     +,   1.6081645E-04,   1.6085072E-04,   1.6083998E-04
     +,   1.6079424E-04,   1.6072353E-04,   1.6063802E-04
     +,   1.6054777E-04,   1.6046282E-04,   1.6039312E-04
     +,   1.6034812E-04,   1.6033721E-04,   1.6036925E-04
     +,   1.6045272E-04,   1.6059562E-04,   1.6080515E-04
     +,   1.6108814E-04,   1.6145065E-04,   1.6189781E-04
     +,   1.6243436E-04,   1.6306387E-04,   1.6378936E-04
     +,   1.6461282E-04,   1.6553543E-04,   1.6655744E-04
     +,   1.6767828E-04,   1.6889661E-04,   1.7021001E-04
     +,   1.7161536E-04,   1.7310883E-04,   1.7468573E-04
     +,   1.7634069E-04,   1.7806784E-04,   1.7986061E-04
     +,   1.8171221E-04,   1.8361525E-04,   1.8556252E-04
     +,   1.8754639E-04,   1.8955958E-04,   1.9159507E-04
     +,   1.9364634E-04,   1.9570765E-04,   1.9777425E-04
     +,   1.9984244E-04,   2.0191053E-04,   2.0397844E-04
     +,   2.0604829E-04,   2.0812485E-04,   2.1021576E-04
     +,   2.1233206E-04,   2.1448822E-04,   2.1670302E-04
     +,   2.1899921E-04,   2.2140441E-04,   2.2395060E-04
     +,   2.2667534E-04,   2.2962084E-04,   2.3283437E-04
     +,   2.3636801E-04,   2.4027895E-04,   2.4462864E-04
     +,   2.4948228E-04,   2.5490898E-04,   2.6098063E-04
     +,   2.6777180E-04,   2.7535841E-04,   2.8381846E-04
     +,   2.9323026E-04,   3.0367338E-04,   3.1522746E-04
     +,   3.2797319E-04,   3.4199253E-04,   3.5736753E-04
     +,   3.7418195E-04,   3.9252144E-04,   4.1247343E-04
     +,   4.3412379E-04,   4.5756091E-04,   4.8286672E-04
     +,   5.1012094E-04,   5.3939177E-04,   5.7073898E-04
     +,   6.0420349E-04,   6.3981448E-04,   6.7758106E-04
     +,   7.1750197E-04,   7.5956952E-04,   8.0377498E-04
     +,   8.5012376E-04,   8.9865201E-04,   9.4943825E-04
     +,   1.0026142E-03,   1.0583856E-03,   1.1170307E-03
     +,   1.1789181E-03,   1.2444946E-03,   1.3143043E-03
     +,   1.3889722E-03,   1.4692263E-03,   1.5558853E-03
     +,   1.6498890E-03,   1.7523087E-03,   1.8643618E-03
     +,   1.9874435E-03,   2.1231540E-03,   2.2733165E-03
     +,   2.4399671E-03,   2.6253292E-03,   2.8317657E-03
     +,   3.0615923E-03,   3.3168106E-03,   3.5986966E-03
     +,   3.9072614E-03,   4.2405548E-03,   4.5941421E-03
     +,   4.9609318E-03,   5.3315838E-03,   5.6957453E-03
     +,   6.0441457E-03,   6.3710897E-03,   6.6765221E-03
     +,   6.9669485E-03,   7.2545381E-03,   7.5542224E-03
     +,   7.8794379E-03,   8.2375500E-03,   8.6264573E-03
     +,   9.0331724E-03,   9.4350278E-03,   9.8031722E-03
     +,   1.0107662E-02,   1.0322952E-02,   1.0432767E-02
     +,   1.0433293E-02,   1.0333895E-02,   1.0155131E-02
     +,   9.9245394E-03,   9.6713435E-03,   9.4212294E-03
     +,   9.1929268E-03,   8.9968601E-03,   8.8357329E-03
     +,   8.7068127E-03,   8.6049447E-03,   8.5253995E-03
     +,   8.4658721E-03,   8.4267948E-03,   8.4100300E-03
     +,   8.4159896E-03,   8.4407153E-03,   8.4741050E-03
     +,   8.5000675E-03,   8.4989695E-03,   8.4514311E-03
     +,   8.3422959E-03,   8.1634857E-03,   7.9151709E-03
     +,   7.6050689E-03,   7.2463397E-03,   6.8549886E-03
     +,   6.4473283E-03,   6.0383491E-03,   5.6407689E-03
     +,   5.2648867E-03,   4.9186270E-03,   4.6077645E-03
     +,   4.3360428E-03,   4.1051391E-03,   3.9147274E-03
     +,   3.7627181E-03,   3.6455989E-03,   3.5589300E-03
     +,   3.4978725E-03,   3.4576415E-03,   3.4337761E-03
     +,   3.4222801E-03,   3.4196188E-03,   3.4226091E-03
     +,   3.4283039E-03,   3.4338813E-03,   3.4366080E-03
     +,   3.4338578E-03,   3.4231737E-03,   3.4023984E-03
     +,   3.3697728E-03,   3.3240695E-03,   3.2646337E-03
     +,   3.1914343E-03,   3.1050290E-03,   3.0065179E-03
     +,   2.8974339E-03,   2.7796440E-03,   2.6552386E-03
     +,   2.5264136E-03,   2.3953579E-03,   2.2641730E-03
     +,   2.1348065E-03,   2.0089883E-03,   1.8881857E-03
     +,   1.7735800E-03,   1.6660719E-03,   1.5662536E-03
     +,   1.4744382E-03,   1.3906824E-03,   1.3148104E-03
     +,   1.2464462E-03,   1.1850559E-03,   1.1299994E-03
     +,   1.0805604E-03,   1.0359855E-03,   9.9552248E-04
     +,   9.5844956E-04,   9.2409400E-04,   8.9184713E-04
     +,   8.6117524E-04,   8.3162793E-04,   8.0283039E-04
     +,   7.7448657E-04,   7.4637280E-04,   7.1833225E-04
     +,   6.9026294E-04,   6.6211424E-04,   6.3388079E-04
     +,   6.0559198E-04,   5.7730492E-04,   5.4909848E-04
     +,   5.2106899E-04,   4.9332355E-04,   4.6597290E-04
     +,   4.3912759E-04,   4.1289913E-04,   3.8738933E-04
     +,   3.6269100E-04,   3.3888844E-04,   3.1605290E-04
     +,   2.9424098E-04,   2.7349594E-04,   2.5384853E-04
     +,   2.3531645E-04,   2.1790357E-04,   2.0160222E-04
     +,   1.8639602E-04,   1.7225726E-04,   1.5915254E-04
     +,   1.4704012E-04,   1.3587475E-04,   1.2560592E-04
     +,   1.1618191E-04,   1.0754821E-04,   9.9651028E-05
     +,   9.2435788E-05,   8.5850079E-05,   7.9842423E-05
     +,   7.4363707E-05,   6.9367823E-05,   6.4810847E-05
     +,   6.0652419E-05,   5.6854697E-05,   5.3383392E-05
     +,   5.0206745E-05,   4.7296300E-05,   4.4625962E-05
     +,   4.2172564E-05,   3.9914998E-05,   3.7834659E-05
     +,   3.5914672E-05,   3.4140197E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt90 = Yx/0.148302325581395
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1059800E-05,   6.3109481E-05
     +,   6.5184780E-05,   6.7284236E-05,   6.9406349E-05
     +,   7.1549577E-05,   7.3712414E-05,   7.5893317E-05
     +,   7.8090699E-05,   8.0303107E-05,   8.2528983E-05
     +,   8.4766842E-05,   8.7015214E-05,   8.9272653E-05
     +,   9.1537840E-05,   9.3809394E-05,   9.6086049E-05
     +,   9.8366603E-05,   1.0064994E-04,   1.0293497E-04
     +,   1.0522074E-04,   1.0750631E-04,   1.0979093E-04
     +,   1.1207393E-04,   1.1435459E-04,   1.1663252E-04
     +,   1.1890728E-04,   1.2117864E-04,   1.2344644E-04
     +,   1.2571069E-04,   1.2797141E-04,   1.3022889E-04
     +,   1.3248352E-04,   1.3473585E-04,   1.3698648E-04
     +,   1.3923629E-04,   1.4148629E-04,   1.4373759E-04
     +,   1.4599159E-04,   1.4824970E-04,   1.5051373E-04
     +,   1.5278545E-04,   1.5506695E-04,   1.5736045E-04
     +,   1.5966843E-04,   1.6199340E-04,   1.6433820E-04
     +,   1.6670571E-04,   1.6909913E-04,   1.7152162E-04
     +,   1.7397659E-04,   1.7646750E-04,   1.7899784E-04
     +,   1.8157151E-04,   1.8419187E-04,   1.8686277E-04
     +,   1.8958787E-04,   1.9237069E-04,   1.9521470E-04
     +,   1.9812337E-04,   2.0109986E-04,   2.0414716E-04
     +,   2.0726801E-04,   2.1046490E-04,   2.1374026E-04
     +,   2.1709591E-04,   2.2053336E-04,   2.2405385E-04
     +,   2.2765866E-04,   2.3134779E-04,   2.3512197E-04
     +,   2.3898079E-04,   2.4292403E-04,   2.4695083E-04
     +,   2.5106024E-04,   2.5525116E-04,   2.5952206E-04
     +,   2.6387119E-04,   2.6829678E-04,   2.7279713E-04
     +,   2.7736960E-04,   2.8201254E-04,   2.8672334E-04
     +,   2.9149966E-04,   2.9633858E-04,   3.0123780E-04
     +,   3.0619398E-04,   3.1120426E-04,   3.1626489E-04
     +,   3.2137221E-04,   3.2652231E-04,   3.3171053E-04
     +,   3.3693129E-04,   3.4217976E-04,   3.4744962E-04
     +,   3.5273421E-04,   3.5802697E-04,   3.6331988E-04
     +,   3.6860566E-04,   3.7387625E-04,   3.7912390E-04
     +,   3.8434062E-04,   3.8951979E-04,   3.9465504E-04
     +,   3.9974137E-04,   4.0477604E-04,   4.0975816E-04
     +,   4.1468989E-04,   4.1957706E-04,   4.2443004E-04
     +,   4.2926366E-04,   4.3409917E-04,   4.3896382E-04
     +,   4.4389308E-04,   4.4893014E-04,   4.5412764E-04
     +,   4.5954727E-04,   4.6526166E-04,   4.7135359E-04
     +,   4.7791708E-04,   4.8505774E-04,   4.9289101E-04
     +,   5.0154334E-04,   5.1115156E-04,   5.2186166E-04
     +,   5.3382741E-04,   5.4721074E-04,   5.6217995E-04
     +,   5.7890988E-04,   5.9757911E-04,   6.1837398E-04
     +,   6.4148300E-04,   6.6710083E-04,   6.9542311E-04
     +,   7.2664797E-04,   7.6097180E-04,   7.9857960E-04
     +,   8.3963905E-04,   8.8429096E-04,   9.3263574E-04
     +,   9.8471472E-04,   1.0404966E-03,   1.0998741E-03
     +,   1.1626520E-03,   1.2285453E-03,   1.2972044E-03
     +,   1.3682409E-03,   1.4412600E-03,   1.5159175E-03
     +,   1.5919860E-03,   1.6694064E-03,   1.7483362E-03
     +,   1.8291757E-03,   1.9125897E-03,   1.9994651E-03
     +,   2.0908415E-03,   2.1878339E-03,   2.2915266E-03
     +,   2.4028630E-03,   2.5225254E-03,   2.6509073E-03
     +,   2.7880571E-03,   2.9336826E-03,   3.0871828E-03
     +,   3.2477337E-03,   3.4143019E-03,   3.5856783E-03
     +,   3.7604705E-03,   3.9370852E-03,   4.1136360E-03
     +,   4.2879344E-03,   4.4575771E-03,   4.6202457E-03
     +,   4.7742105E-03,   4.9191052E-03,   5.0569354E-03
     +,   5.1931138E-03,   5.3374083E-03,   5.5045541E-03
     +,   5.7142181E-03,   5.9900638E-03,   6.3576493E-03
     +,   6.8413946E-03,   7.4606598E-03,   8.2253432E-03
     +,   9.1310954E-03,   1.0155128E-02,   1.1253948E-02
     +,   1.2364571E-02,   1.3410707E-02,   1.4314448E-02
     +,   1.5010200E-02,   1.5458315E-02,   1.5653526E-02
     +,   1.5624627E-02,   1.5423538E-02,   1.5106387E-02
     +,   1.4714478E-02,   1.4265187E-02,   1.3757980E-02
     +,   1.3191848E-02,   1.2581442E-02,   1.1961158E-02
     +,   1.1374242E-02,   1.0854729E-02,   1.0413620E-02
     +,   1.0037305E-02,   9.6969083E-03,   9.3619786E-03
     +,   9.0112174E-03,   8.6364420E-03,   8.2406374E-03
     +,   7.8327106E-03,   7.4223806E-03,   7.0168707E-03
     +,   6.6198832E-03,   6.2321653E-03,   5.8531538E-03
     +,   5.4826322E-03,   5.1220669E-03,   4.7749481E-03
     +,   4.4464376E-03,   4.1423789E-03,   3.8680257E-03
     +,   3.6269075E-03,   3.4202491E-03,   3.2468617E-03
     +,   3.1035531E-03,   2.9858078E-03,   2.8885815E-03
     +,   2.8069394E-03,   2.7364849E-03,   2.6735354E-03
     +,   2.6151340E-03,   2.5589382E-03,   2.5030714E-03
     +,   2.4460268E-03,   2.3866002E-03,   2.3238834E-03
     +,   2.2572775E-03,   2.1865105E-03,   2.1116645E-03
     +,   2.0331382E-03,   1.9515983E-03,   1.8679082E-03
     +,   1.7830414E-03,   1.6979963E-03,   1.6137026E-03
     +,   1.5309710E-03,   1.4504596E-03,   1.3726442E-03
     +,   1.2978270E-03,   1.2261624E-03,   1.1576798E-03
     +,   1.0923116E-03,   1.0299332E-03,   9.7039697E-04
     +,   9.1355044E-04,   8.5924991E-04,   8.0737664E-04
     +,   7.5784163E-04,   7.1058091E-04,   6.6555047E-04
     +,   6.2272092E-04,   5.8207504E-04,   5.4359366E-04
     +,   5.0725369E-04,   4.7302619E-04,   4.4087160E-04
     +,   4.1073677E-04,   3.8255681E-04,   3.5625877E-04
     +,   3.3176059E-04,   3.0897241E-04,   2.8780015E-04
     +,   2.6814948E-04,   2.4992344E-04,   2.3302887E-04
     +,   2.1737268E-04,   2.0286793E-04,   1.8942943E-04
     +,   1.7697889E-04,   1.6544080E-04,   1.5474617E-04
     +,   1.4482928E-04,   1.3563011E-04,   1.2709213E-04
     +,   1.1916290E-04,   1.1179447E-04,   1.0494160E-04
     +,   9.8563287E-05,   9.2620779E-05,   8.7079170E-05
     +,   8.1905549E-05,   7.7070392E-05,   7.2546020E-05
     +,   6.8307687E-05,   6.4332315E-05,   6.0599414E-05
     +,   5.7089903E-05,   5.3787058E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_htt95 = Yx/0.158232558139535
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1248094E-05,   6.2858882E-05
     +,   6.4433887E-05,   6.5969209E-05,   6.7461231E-05
     +,   6.8906564E-05,   7.0302092E-05,   7.1645038E-05
     +,   7.2932940E-05,   7.4163778E-05,   7.5335869E-05
     +,   7.6447970E-05,   7.7499295E-05,   7.8489487E-05
     +,   7.9418707E-05,   8.0287551E-05,   8.1097132E-05
     +,   8.1849052E-05,   8.2545397E-05,   8.3188723E-05
     +,   8.3782063E-05,   8.4328894E-05,   8.4833155E-05
     +,   8.5299238E-05,   8.5731859E-05,   8.6136126E-05
     +,   8.6517452E-05,   8.6881628E-05,   8.7234628E-05
     +,   8.7582652E-05,   8.7932138E-05,   8.8289598E-05
     +,   8.8661691E-05,   8.9055022E-05,   8.9476263E-05
     +,   8.9932073E-05,   9.0428861E-05,   9.0972993E-05
     +,   9.1570597E-05,   9.2227514E-05,   9.2949391E-05
     +,   9.3741393E-05,   9.4608389E-05,   9.5554758E-05
     +,   9.6584416E-05,   9.7700831E-05,   9.8906807E-05
     +,   1.0020476E-04,   1.0159621E-04,   1.0308239E-04
     +,   1.0466368E-04,   1.0633990E-04,   1.0811014E-04
     +,   1.0997304E-04,   1.1192626E-04,   1.1396714E-04
     +,   1.1609221E-04,   1.1829752E-04,   1.2057855E-04
     +,   1.2293021E-04,   1.2534701E-04,   1.2782309E-04
     +,   1.3035195E-04,   1.3292731E-04,   1.3554233E-04
     +,   1.3819018E-04,   1.4086394E-04,   1.4355672E-04
     +,   1.4626197E-04,   1.4897306E-04,   1.5168416E-04
     +,   1.5438939E-04,   1.5708385E-04,   1.5976300E-04
     +,   1.6242318E-04,   1.6506160E-04,   1.6767615E-04
     +,   1.7026579E-04,   1.7283061E-04,   1.7537177E-04
     +,   1.7789124E-04,   1.8039257E-04,   1.8287994E-04
     +,   1.8535901E-04,   1.8783622E-04,   1.9031919E-04
     +,   1.9281617E-04,   1.9533651E-04,   1.9788987E-04
     +,   2.0048670E-04,   2.0313780E-04,   2.0585382E-04
     +,   2.0864552E-04,   2.1152332E-04,   2.1449738E-04
     +,   2.1757671E-04,   2.2076984E-04,   2.2408352E-04
     +,   2.2752352E-04,   2.3109361E-04,   2.3479626E-04
     +,   2.3863112E-04,   2.4259651E-04,   2.4668776E-04
     +,   2.5089824E-04,   2.5521911E-04,   2.5963873E-04
     +,   2.6414305E-04,   2.6871642E-04,   2.7334088E-04
     +,   2.7799633E-04,   2.8266176E-04,   2.8731432E-04
     +,   2.9193077E-04,   2.9648718E-04,   3.0095977E-04
     +,   3.0532505E-04,   3.0956094E-04,   3.1364639E-04
     +,   3.1756281E-04,   3.2129415E-04,   3.2482742E-04
     +,   3.2815320E-04,   3.3126640E-04,   3.3416654E-04
     +,   3.3685798E-04,   3.3935060E-04,   3.4165959E-04
     +,   3.4380640E-04,   3.4581852E-04,   3.4772913E-04
     +,   3.4957769E-04,   3.5140986E-04,   3.5327676E-04
     +,   3.5523568E-04,   3.5734879E-04,   3.5968344E-04
     +,   3.6231201E-04,   3.6531119E-04,   3.6876192E-04
     +,   3.7274905E-04,   3.7736114E-04,   3.8269069E-04
     +,   3.8883474E-04,   3.9589309E-04,   4.0397100E-04
     +,   4.1317870E-04,   4.2363058E-04,   4.3544671E-04
     +,   4.4875295E-04,   4.6368124E-04,   4.8036635E-04
     +,   4.9894571E-04,   5.1955832E-04,   5.4234022E-04
     +,   5.6741695E-04,   5.9489935E-04,   6.2487787E-04
     +,   6.5741170E-04,   6.9251726E-04,   7.3016493E-04
     +,   7.7026879E-04,   8.1267906E-04,   8.5718103E-04
     +,   9.0350449E-04,   9.5132913E-04,   1.0002983E-03
     +,   1.0500490E-03,   1.1002466E-03,   1.1506213E-03
     +,   1.2010083E-03,   1.2513993E-03,   1.3019908E-03
     +,   1.3532276E-03,   1.4058400E-03,   1.4608877E-03
     +,   1.5197870E-03,   1.5843249E-03,   1.6566652E-03
     +,   1.7393313E-03,   1.8351622E-03,   1.9472466E-03
     +,   2.0788664E-03,   2.2334941E-03,   2.4148521E-03
     +,   2.6270675E-03,   2.8748661E-03,   3.1636977E-03
     +,   3.4995079E-03,   3.8880145E-03,   4.3336949E-03
     +,   4.8385630E-03,   5.4015843E-03,   6.0190861E-03
     +,   6.6859769E-03,   7.3965974E-03,   8.1446879E-03
     +,   8.9246389E-03,   9.7388783E-03,   1.0613518E-02
     +,   1.1614120E-02,   1.2843616E-02,   1.4413302E-02
     +,   1.6402241E-02,   1.8826816E-02,   2.1617062E-02
     +,   2.4594156E-02,   2.7504034E-02,   3.0162739E-02
     +,   3.2599401E-02,   3.4986753E-02,   3.7396610E-02
     +,   3.9698962E-02,   4.1728534E-02,   4.3421138E-02
     +,   4.4700500E-02,   4.5373593E-02,   4.5292486E-02
     +,   4.4545785E-02,   4.3365914E-02,   4.1850161E-02
     +,   3.9840795E-02,   3.7174933E-02,   3.4077521E-02
     +,   3.1135829E-02,   2.8769385E-02,   2.6860142E-02
     +,   2.4996659E-02,   2.2945544E-02,   2.0791357E-02
     +,   1.8733721E-02,   1.6875450E-02,   1.5189442E-02
     +,   1.3605138E-02,   1.2091879E-02,   1.0679157E-02
     +,   9.4254715E-03,   8.3749946E-03,   7.5338562E-03
     +,   6.8724379E-03,   6.3425768E-03,   5.8953301E-03
     +,   5.4916809E-03,   5.1058880E-03,   4.7241272E-03
     +,   4.3413993E-03,   3.9584129E-03,   3.5791278E-03
     +,   3.2090286E-03,   2.8539062E-03,   2.5189302E-03
     +,   2.2081730E-03,   1.9243995E-03,   1.6690285E-03
     +,   1.4422347E-03,   1.2431736E-03,   1.0702197E-03
     +,   9.2119037E-04,   7.9357525E-04,   6.8476010E-04
     +,   5.9219805E-04,   5.1352155E-04,   4.4660762E-04
     +,   3.8961126E-04,   3.4096368E-04,   2.9933671E-04
     +,   2.6361758E-04,   2.3287708E-04,   2.0633677E-04
     +,   1.8334201E-04,   1.6334470E-04,   1.4588675E-04
     +,   1.3058480E-04,   1.1711775E-04,   1.0521805E-04
     +,   9.4664130E-05,   8.5270171E-05,   7.6882701E-05
     +,   6.9372581E-05,   6.2632644E-05,   5.6571957E-05
     +,   5.1114366E-05,   4.6194364E-05,   4.1756353E-05
     +,   3.7751663E-05,   3.4138295E-05,   3.0878873E-05
     +,   2.7940225E-05,   2.5292888E-05,   2.2909911E-05
     +,   2.0767155E-05,   1.8842287E-05,   1.7115110E-05
     +,   1.5566840E-05,   1.4180417E-05,   1.2939926E-05
     +,   1.1830903E-05,   1.0839891E-05,   9.9546787E-06
     +,   9.1639467E-06,   8.4574685E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz100 = Yx/0.299212765957447
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0553241E-05,   5.2393196E-05
     +,   5.4299842E-05,   5.6275454E-05,   5.8322297E-05
     +,   6.0442646E-05,   6.2638719E-05,   6.4912645E-05
     +,   6.7266505E-05,   6.9702342E-05,   7.2222014E-05
     +,   7.4827280E-05,   7.7519748E-05,   8.0300837E-05
     +,   8.3171813E-05,   8.6133703E-05,   8.9187270E-05
     +,   9.2333074E-05,   9.5571384E-05,   9.8902157E-05
     +,   1.0232504E-04,   1.0583938E-04,   1.0944411E-04
     +,   1.1313794E-04,   1.1691893E-04,   1.2078510E-04
     +,   1.2473376E-04,   1.2876205E-04,   1.3286654E-04
     +,   1.3704340E-04,   1.4128840E-04,   1.4559689E-04
     +,   1.4996383E-04,   1.5438358E-04,   1.5885031E-04
     +,   1.6335752E-04,   1.6789851E-04,   1.7246601E-04
     +,   1.7705270E-04,   1.8165015E-04,   1.8625034E-04
     +,   1.9084444E-04,   1.9542333E-04,   1.9997769E-04
     +,   2.0449770E-04,   2.0897330E-04,   2.1339435E-04
     +,   2.1775017E-04,   2.2203008E-04,   2.2622295E-04
     +,   2.3031779E-04,   2.3430334E-04,   2.3816814E-04
     +,   2.4190114E-04,   2.4549064E-04,   2.4892559E-04
     +,   2.5219462E-04,   2.5528701E-04,   2.5819181E-04
     +,   2.6089867E-04,   2.6339761E-04,   2.6567915E-04
     +,   2.6773423E-04,   2.6955461E-04,   2.7113271E-04
     +,   2.7246177E-04,   2.7353619E-04,   2.7435092E-04
     +,   2.7490262E-04,   2.7518853E-04,   2.7520783E-04
     +,   2.7496059E-04,   2.7444868E-04,   2.7367545E-04
     +,   2.7264579E-04,   2.7136639E-04,   2.6984568E-04
     +,   2.6809378E-04,   2.6612298E-04,   2.6394700E-04
     +,   2.6158191E-04,   2.5904516E-04,   2.5635667E-04
     +,   2.5353770E-04,   2.5061163E-04,   2.4760331E-04
     +,   2.4453964E-04,   2.4144854E-04,   2.3836011E-04
     +,   2.3530501E-04,   2.3231540E-04,   2.2942433E-04
     +,   2.2666577E-04,   2.2407382E-04,   2.2168296E-04
     +,   2.1952798E-04,   2.1764264E-04,   2.1606059E-04
     +,   2.1481411E-04,   2.1393425E-04,   2.1345011E-04
     +,   2.1338870E-04,   2.1377433E-04,   2.1462844E-04
     +,   2.1596889E-04,   2.1780982E-04,   2.2016148E-04
     +,   2.2302898E-04,   2.2641335E-04,   2.3031027E-04
     +,   2.3471008E-04,   2.3959820E-04,   2.4495390E-04
     +,   2.5075185E-04,   2.5696078E-04,   2.6354502E-04
     +,   2.7046312E-04,   2.7767039E-04,   2.8511690E-04
     +,   2.9275022E-04,   3.0051492E-04,   3.0835328E-04
     +,   3.1620573E-04,   3.2401303E-04,   3.3171588E-04
     +,   3.3925564E-04,   3.4657633E-04,   3.5362373E-04
     +,   3.6034841E-04,   3.6670387E-04,   3.7264993E-04
     +,   3.7815073E-04,   3.8317757E-04,   3.8770668E-04
     +,   3.9172269E-04,   3.9521622E-04,   3.9818496E-04
     +,   4.0063341E-04,   4.0257297E-04,   4.0402153E-04
     +,   4.0500282E-04,   4.0554663E-04,   4.0568769E-04
     +,   4.0546566E-04,   4.0492363E-04,   4.0410916E-04
     +,   4.0307175E-04,   4.0186406E-04,   4.0053998E-04
     +,   3.9915528E-04,   3.9776575E-04,   3.9642863E-04
     +,   3.9520132E-04,   3.9414057E-04,   3.9330361E-04
     +,   3.9274691E-04,   3.9252706E-04,   3.9270014E-04
     +,   3.9332197E-04,   3.9444788E-04,   3.9613285E-04
     +,   3.9843214E-04,   4.0140035E-04,   4.0509173E-04
     +,   4.0956039E-04,   4.1486035E-04,   4.2104544E-04
     +,   4.2816831E-04,   4.3628222E-04,   4.4544085E-04
     +,   4.5569811E-04,   4.6710856E-04,   4.7973084E-04
     +,   4.9362762E-04,   5.0886685E-04,   5.2552746E-04
     +,   5.4370193E-04,   5.6350057E-04,   5.8505760E-04
     +,   6.0854026E-04,   6.3415454E-04,   6.6215347E-04
     +,   6.9284422E-04,   7.2659866E-04,   7.6385919E-04
     +,   8.0513407E-04,   8.5100293E-04,   9.0211170E-04
     +,   9.5916126E-04,   1.0228878E-03,   1.0940586E-03
     +,   1.1734482E-03,   1.2618148E-03,   1.3598849E-03
     +,   1.4683417E-03,   1.5877965E-03,   1.7187652E-03
     +,   1.8616468E-03,   2.0167159E-03,   2.1841102E-03
     +,   2.3638257E-03,   2.5557703E-03,   2.7598864E-03
     +,   2.9763293E-03,   3.2057681E-03,   3.4498980E-03
     +,   3.7120429E-03,   3.9978027E-03,   4.3156082E-03
     +,   4.6768636E-03,   5.0953100E-03,   5.5852989E-03
     +,   6.1589722E-03,   6.8226289E-03,   7.5731194E-03
     +,   8.3956094E-03,   9.2648342E-03,   1.0152210E-02
     +,   1.1041148E-02,   1.1949650E-02,   1.2949969E-02
     +,   1.4162636E-02,   1.5707189E-02,   1.7626680E-02
     +,   1.9846886E-02,   2.2224793E-02,   2.4658859E-02
     +,   2.7156873E-02,   2.9795675E-02,   3.2625876E-02
     +,   3.5606090E-02,   3.8570184E-02,   4.1243058E-02
     +,   4.3392226E-02,   4.5044996E-02,   4.6456225E-02
     +,   4.7739819E-02,   4.8592199E-02,   4.8486542E-02
     +,   4.7119662E-02,   4.4656485E-02,   4.1643772E-02
     +,   3.8705893E-02,   3.6192931E-02,   3.4044880E-02
     +,   3.1977531E-02,   2.9759139E-02,   2.7325142E-02
     +,   2.4722338E-02,   2.2020992E-02,   1.9285094E-02
     +,   1.6588269E-02,   1.4021115E-02,   1.1672230E-02
     +,   9.6036959E-03,   7.8402404E-03,   6.3732392E-03
     +,   5.1715313E-03,   4.1932985E-03,   3.3959649E-03
     +,   2.7426069E-03,   2.2046093E-03,   1.7613142E-03
     +,   1.3979379E-03,   1.1030730E-03,   8.6676405E-04
     +,   6.7966455E-04,   5.3296098E-04,   4.1863139E-04
     +,   3.2974611E-04,   2.6062236E-04,   2.0678609E-04
     +,   1.6479853E-04,   1.3204111E-04,   1.0651292E-04
     +,   8.6665059E-05,   7.1273695E-05,   5.9363745E-05
     +,   5.0151044E-05,   4.3009357E-05,   3.7441027E-05
     +,   3.3057211E-05,   2.9557476E-05,   2.6714035E-05
     +,   2.4356021E-05,   2.2357543E-05,   2.0626476E-05
     +,   1.9096326E-05,   1.7719660E-05,   1.6462678E-05
     +,   1.5301765E-05,   1.4220321E-05,   1.3206990E-05
     +,   1.2253848E-05,   1.1355569E-05,   1.0508364E-05
     +,   9.7096499E-06,   8.9573978E-06,   8.2500655E-06
     +,   7.5861972E-06,   6.9644821E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz105 = Yx/0.301297872340426
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz107(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0887815E-05,   5.2105301E-05
     +,   5.3332922E-05,   5.4570581E-05,   5.5818258E-05
     +,   5.7075995E-05,   5.8343885E-05,   5.9622045E-05
     +,   6.0910690E-05,   6.2210114E-05,   6.3520609E-05
     +,   6.4842585E-05,   6.6176442E-05,   6.7522662E-05
     +,   6.8881753E-05,   7.0254260E-05,   7.1640810E-05
     +,   7.3041949E-05,   7.4458309E-05,   7.5890530E-05
     +,   7.7339180E-05,   7.8804886E-05,   8.0288148E-05
     +,   8.1789585E-05,   8.3309547E-05,   8.4848536E-05
     +,   8.6406828E-05,   8.7984678E-05,   8.9582230E-05
     +,   9.1199523E-05,   9.2836504E-05,   9.4492942E-05
     +,   9.6168558E-05,   9.7862903E-05,   9.9575358E-05
     +,   1.0130529E-04,   1.0305178E-04,   1.0481391E-04
     +,   1.0659063E-04,   1.0838063E-04,   1.1018274E-04
     +,   1.1199553E-04,   1.1381753E-04,   1.1564718E-04
     +,   1.1748302E-04,   1.1932338E-04,   1.2116670E-04
     +,   1.2301138E-04,   1.2485593E-04,   1.2669885E-04
     +,   1.2853871E-04,   1.3037429E-04,   1.3220430E-04
     +,   1.3402780E-04,   1.3584373E-04,   1.3765156E-04
     +,   1.3945057E-04,   1.4124041E-04,   1.4302085E-04
     +,   1.4479186E-04,   1.4655355E-04,   1.4830630E-04
     +,   1.5005046E-04,   1.5178668E-04,   1.5351569E-04
     +,   1.5523819E-04,   1.5695517E-04,   1.5866739E-04
     +,   1.6037587E-04,   1.6208131E-04,   1.6378459E-04
     +,   1.6548626E-04,   1.6718692E-04,   1.6888673E-04
     +,   1.7058576E-04,   1.7228386E-04,   1.7398041E-04
     +,   1.7567443E-04,   1.7736464E-04,   1.7904944E-04
     +,   1.8072649E-04,   1.8239337E-04,   1.8404689E-04
     +,   1.8568366E-04,   1.8729949E-04,   1.8889012E-04
     +,   1.9045055E-04,   1.9197552E-04,   1.9345927E-04
     +,   1.9489584E-04,   1.9627890E-04,   1.9760174E-04
     +,   1.9885761E-04,   2.0003961E-04,   2.0114071E-04
     +,   2.0215397E-04,   2.0307243E-04,   2.0388924E-04
     +,   2.0459801E-04,   2.0519245E-04,   2.0566683E-04
     +,   2.0601573E-04,   2.0623440E-04,   2.0631879E-04
     +,   2.0626535E-04,   2.0607156E-04,   2.0573565E-04
     +,   2.0525664E-04,   2.0463477E-04,   2.0387108E-04
     +,   2.0296779E-04,   2.0192823E-04,   2.0075688E-04
     +,   1.9945917E-04,   1.9804215E-04,   1.9651373E-04
     +,   1.9488312E-04,   1.9316070E-04,   1.9135811E-04
     +,   1.8948830E-04,   1.8756509E-04,   1.8560387E-04
     +,   1.8362082E-04,   1.8163353E-04,   1.7966029E-04
     +,   1.7772087E-04,   1.7583574E-04,   1.7402651E-04
     +,   1.7231544E-04,   1.7072607E-04,   1.6928231E-04
     +,   1.6800895E-04,   1.6693154E-04,   1.6607596E-04
     +,   1.6546853E-04,   1.6513608E-04,   1.6510546E-04
     +,   1.6540354E-04,   1.6605720E-04,   1.6709280E-04
     +,   1.6853627E-04,   1.7041260E-04,   1.7274600E-04
     +,   1.7555931E-04,   1.7887360E-04,   1.8270842E-04
     +,   1.8708123E-04,   1.9200677E-04,   1.9749723E-04
     +,   2.0356194E-04,   2.1020777E-04,   2.1743750E-04
     +,   2.2525097E-04,   2.3364526E-04,   2.4261465E-04
     +,   2.5215017E-04,   2.6224100E-04,   2.7287556E-04
     +,   2.8404180E-04,   2.9572807E-04,   3.0792609E-04
     +,   3.2063169E-04,   3.3384646E-04,   3.4758053E-04
     +,   3.6185569E-04,   3.7670709E-04,   3.9218453E-04
     +,   4.0835587E-04,   4.2530886E-04,   4.4315215E-04
     +,   4.6201312E-04,   4.8203886E-04,   5.0339423E-04
     +,   5.2625785E-04,   5.5081473E-04,   5.7725277E-04
     +,   6.0575421E-04,   6.3648535E-04,   6.6958816E-04
     +,   7.0517435E-04,   7.4331608E-04,   7.8403746E-04
     +,   8.2731195E-04,   8.7306544E-04,   9.2117558E-04
     +,   9.7147498E-04,   1.0237597E-03,   1.0778061E-03
     +,   1.1333774E-03,   1.1902312E-03,   1.2481371E-03
     +,   1.3068843E-03,   1.3662800E-03,   1.4261596E-03
     +,   1.4863897E-03,   1.5468762E-03,   1.6075637E-03
     +,   1.6684647E-03,   1.7296976E-03,   1.7915181E-03
     +,   1.8543875E-03,   1.9190293E-03,   1.9865092E-03
     +,   2.0582736E-03,   2.1361671E-03,   2.2224260E-03
     +,   2.3196314E-03,   2.4306211E-03,   2.5584355E-03
     +,   2.7062891E-03,   2.8775928E-03,   3.0759869E-03
     +,   3.3053739E-03,   3.5698994E-03,   3.8737741E-03
     +,   4.2209928E-03,   4.6150540E-03,   5.0587915E-03
     +,   5.5542323E-03,   6.1026295E-03,   6.7049265E-03
     +,   7.3623010E-03,   8.0763884E-03,   8.8487593E-03
     +,   9.6795270E-03,   1.0566801E-02,   1.1509812E-02
     +,   1.2518169E-02,   1.3627190E-02,   1.4912625E-02
     +,   1.6487159E-02,   1.8459033E-02,   2.0862596E-02
     +,   2.3612600E-02,   2.6537117E-02,   2.9491374E-02
     +,   3.2490227E-02,   3.5751656E-02,   3.9526124E-02
     +,   4.3706633E-02,   4.7588181E-02,   5.0307211E-02
     +,   5.1674128E-02,   5.2281640E-02,   5.2684702E-02
     +,   5.2761778E-02,   5.1955406E-02,   4.9974844E-02
     +,   4.7198180E-02,   4.4357482E-02,   4.1832615E-02
     +,   3.9303944E-02,   3.6104806E-02,   3.1884372E-02
     +,   2.6922271E-02,   2.1875737E-02,   1.7324826E-02
     +,   1.3534954E-02,   1.0503081E-02,   8.1085907E-03
     +,   6.2206150E-03,   4.7357720E-03,   3.5781998E-03
     +,   2.6890470E-03,   2.0175991E-03,   1.5176598E-03
     +,   1.1483540E-03,   8.7581162E-04,   6.7368860E-04
     +,   5.2241207E-04,   4.0783780E-04,   3.1989077E-04
     +,   2.5144973E-04,   1.9751494E-04,   1.5459671E-04
     +,   1.2025572E-04,   9.2751303E-05,   7.0804250E-05
     +,   5.3422136E-05,   3.9800540E-05,   2.9259094E-05
     +,   2.1215003E-05,   1.5166269E-05,   1.0687055E-05
     +,   7.4209916E-06,   5.0768322E-06,   3.4208608E-06
     +,   2.2697218E-06,   1.4825441E-06,   9.5307405E-07
     +,   6.0291023E-07,   3.7523210E-07,   2.2973718E-07
     +,   1.3836032E-07,   8.1973873E-08,   4.7784464E-08
     +,   2.7417709E-08,   1.5495656E-08,   8.6376968E-09
     +,   4.7592890E-09,   2.6019191E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz107 = Yx/0.300854166666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.9074252E-05,   9.2773953E-05
     +,   9.6579039E-05,   1.0048738E-04,   1.0449633E-04
     +,   1.0860273E-04,   1.1280283E-04,   1.1709242E-04
     +,   1.2146660E-04,   1.2592009E-04,   1.3044685E-04
     +,   1.3504036E-04,   1.3969354E-04,   1.4439877E-04
     +,   1.4914792E-04,   1.5393239E-04,   1.5874302E-04
     +,   1.6357040E-04,   1.6840456E-04,   1.7323531E-04
     +,   1.7805211E-04,   1.8284426E-04,   1.8760080E-04
     +,   1.9231082E-04,   1.9696305E-04,   2.0154666E-04
     +,   2.0605072E-04,   2.1046451E-04,   2.1477757E-04
     +,   2.1897972E-04,   2.2306135E-04,   2.2701321E-04
     +,   2.3082666E-04,   2.3449375E-04,   2.3800717E-04
     +,   2.4136047E-04,   2.4454799E-04,   2.4756481E-04
     +,   2.5040726E-04,   2.5307250E-04,   2.5555864E-04
     +,   2.5786497E-04,   2.5999174E-04,   2.6194021E-04
     +,   2.6371307E-04,   2.6531357E-04,   2.6674647E-04
     +,   2.6801732E-04,   2.6913272E-04,   2.7010011E-04
     +,   2.7092805E-04,   2.7162573E-04,   2.7220338E-04
     +,   2.7267146E-04,   2.7304157E-04,   2.7332551E-04
     +,   2.7353573E-04,   2.7368468E-04,   2.7378547E-04
     +,   2.7385095E-04,   2.7389431E-04,   2.7392848E-04
     +,   2.7396641E-04,   2.7402033E-04,   2.7410261E-04
     +,   2.7422473E-04,   2.7439775E-04,   2.7463204E-04
     +,   2.7493699E-04,   2.7532168E-04,   2.7579351E-04
     +,   2.7635944E-04,   2.7702528E-04,   2.7779551E-04
     +,   2.7867375E-04,   2.7966229E-04,   2.8076230E-04
     +,   2.8197374E-04,   2.8329546E-04,   2.8472507E-04
     +,   2.8625882E-04,   2.8789241E-04,   2.8961990E-04
     +,   2.9143484E-04,   2.9332936E-04,   2.9529506E-04
     +,   2.9732284E-04,   2.9940266E-04,   3.0152398E-04
     +,   3.0367592E-04,   3.0584721E-04,   3.0802604E-04
     +,   3.1020088E-04,   3.1235986E-04,   3.1449154E-04
     +,   3.1658440E-04,   3.1862725E-04,   3.2060951E-04
     +,   3.2252102E-04,   3.2435206E-04,   3.2609407E-04
     +,   3.2773882E-04,   3.2927922E-04,   3.3070886E-04
     +,   3.3202255E-04,   3.3321578E-04,   3.3428540E-04
     +,   3.3522901E-04,   3.3604525E-04,   3.3673397E-04
     +,   3.3729587E-04,   3.3773237E-04,   3.3804640E-04
     +,   3.3824125E-04,   3.3832109E-04,   3.3829088E-04
     +,   3.3815624E-04,   3.3792335E-04,   3.3759914E-04
     +,   3.3719014E-04,   3.3670416E-04,   3.3614857E-04
     +,   3.3553143E-04,   3.3486044E-04,   3.3414338E-04
     +,   3.3338813E-04,   3.3260239E-04,   3.3179336E-04
     +,   3.3096867E-04,   3.3013517E-04,   3.2929948E-04
     +,   3.2846822E-04,   3.2764769E-04,   3.2684370E-04
     +,   3.2606194E-04,   3.2530839E-04,   3.2458830E-04
     +,   3.2390750E-04,   3.2327152E-04,   3.2268633E-04
     +,   3.2215819E-04,   3.2169389E-04,   3.2130067E-04
     +,   3.2098696E-04,   3.2076178E-04,   3.2063527E-04
     +,   3.2061903E-04,   3.2072634E-04,   3.2097122E-04
     +,   3.2137032E-04,   3.2194171E-04,   3.2270543E-04
     +,   3.2368375E-04,   3.2490084E-04,   3.2638316E-04
     +,   3.2815960E-04,   3.3026093E-04,   3.3272040E-04
     +,   3.3557377E-04,   3.3885898E-04,   3.4261640E-04
     +,   3.4688940E-04,   3.5172421E-04,   3.5716977E-04
     +,   3.6327937E-04,   3.7011012E-04,   3.7772488E-04
     +,   3.8619048E-04,   3.9558235E-04,   4.0598272E-04
     +,   4.1748234E-04,   4.3018072E-04,   4.4418898E-04
     +,   4.5962899E-04,   4.7663206E-04,   4.9534213E-04
     +,   5.1591336E-04,   5.3850602E-04,   5.6328828E-04
     +,   5.9043139E-04,   6.2010769E-04,   6.5248250E-04
     +,   6.8771170E-04,   7.2593690E-04,   7.6728122E-04
     +,   8.1184029E-04,   8.5967855E-04,   9.1082969E-04
     +,   9.6529099E-04,   1.0230163E-03,   1.0839251E-03
     +,   1.1479025E-03,   1.2147952E-03,   1.2844204E-03
     +,   1.3565823E-03,   1.4310766E-03,   1.5076996E-03
     +,   1.5862689E-03,   1.6666458E-03,   1.7487500E-03
     +,   1.8325708E-03,   1.9181799E-03,   2.0057426E-03
     +,   2.0955014E-03,   2.1877477E-03,   2.2828074E-03
     +,   2.3809951E-03,   2.4825837E-03,   2.5877915E-03
     +,   2.6968289E-03,   2.8099634E-03,   2.9276430E-03
     +,   3.0506672E-03,   3.1803707E-03,   3.3187591E-03
     +,   3.4685559E-03,   3.6331844E-03,   3.8166756E-03
     +,   4.0235356E-03,   4.2586727E-03,   4.5275153E-03
     +,   4.8361681E-03,   5.1914300E-03,   5.6003686E-03
     +,   6.0691372E-03,   6.6006198E-03,   7.1913209E-03
     +,   7.8285085E-03,   8.4893042E-03,   9.1435965E-03
     +,   9.7620031E-03,   1.0327435E-02,   1.0845683E-02
     +,   1.1348817E-02,   1.1888199E-02,   1.2520503E-02
     +,   1.3295476E-02,   1.4252164E-02,   1.5422079E-02
     +,   1.6830632E-02,   1.8491996E-02,   2.0403728E-02
     +,   2.2550829E-02,   2.4924282E-02,   2.7546579E-02
     +,   3.0484553E-02,   3.3823844E-02,   3.7597563E-02
     +,   4.1698527E-02,   4.5833334E-02,   4.9594652E-02
     +,   5.2657440E-02,   5.4943517E-02,   5.6516420E-02
     +,   5.7253193E-02,   5.6693960E-02,   5.4321453E-02
     +,   4.9988862E-02,   4.4070233E-02,   3.7274878E-02
     +,   3.0366153E-02,   2.3957863E-02,   1.8420139E-02
     +,   1.3879596E-02,   1.0291591E-02,   7.5323470E-03
     +,   5.4622767E-03,   3.9467886E-03,   2.8586723E-03
     +,   2.0830811E-03,   1.5262401E-03,   1.1200854E-03
     +,   8.1964699E-04,   5.9629307E-04,   4.3104272E-04
     +,   3.1010565E-04,   2.2263748E-04,   1.5994743E-04
     +,   1.1519776E-04,   8.3230771E-05,   6.0299237E-05
     +,   4.3764110E-05,   3.1785767E-05,   2.3080884E-05
     +,   1.6740889E-05,   1.2116044E-05,   8.7374319E-06
     +,   6.2668882E-06,   4.4611047E-06,   3.1444854E-06
     +,   2.1898313E-06,   1.5036036E-06,   1.0161959E-06
     +,   6.7503078E-07,   4.4026172E-07,   2.8169120E-07
     +,   1.7671151E-07,   1.0863980E-07,   6.5438293E-08
     +,   3.8609301E-08,   2.2311349E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz110 = Yx/0.295489361702128
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6141101E-04,   1.6788907E-04
     +,   1.7452936E-04,   1.8133195E-04,   1.8829691E-04
     +,   1.9542404E-04,   2.0271310E-04,   2.1016391E-04
     +,   2.1777618E-04,   2.2554971E-04,   2.3348411E-04
     +,   2.4157905E-04,   2.4983403E-04,   2.5824879E-04
     +,   2.6682290E-04,   2.7555606E-04,   2.8444760E-04
     +,   2.9349705E-04,   3.0270396E-04,   3.1206748E-04
     +,   3.2158662E-04,   3.3126035E-04,   3.4108726E-04
     +,   3.5106609E-04,   3.6119367E-04,   3.7146802E-04
     +,   3.8188556E-04,   3.9244222E-04,   4.0313270E-04
     +,   4.1395111E-04,   4.2489031E-04,   4.3594153E-04
     +,   4.4709479E-04,   4.5833888E-04,   4.6965995E-04
     +,   4.8104310E-04,   4.9247115E-04,   5.0392497E-04
     +,   5.1538384E-04,   5.2682322E-04,   5.3821865E-04
     +,   5.4954208E-04,   5.6076428E-04,   5.7185307E-04
     +,   5.8277592E-04,   5.9349742E-04,   6.0398178E-04
     +,   6.1419193E-04,   6.2409026E-04,   6.3363893E-04
     +,   6.4280018E-04,   6.5153762E-04,   6.5981393E-04
     +,   6.6759618E-04,   6.7485159E-04,   6.8155100E-04
     +,   6.8766862E-04,   6.9318077E-04,   6.9807062E-04
     +,   7.0232322E-04,   7.0593058E-04,   7.0888881E-04
     +,   7.1120047E-04,   7.1287324E-04,   7.1392127E-04
     +,   7.1436446E-04,   7.1422971E-04,   7.1354787E-04
     +,   7.1235764E-04,   7.1070163E-04,   7.0862827E-04
     +,   7.0619112E-04,   7.0344697E-04,   7.0045691E-04
     +,   6.9728441E-04,   6.9399603E-04,   6.9065992E-04
     +,   6.8734423E-04,   6.8411737E-04,   6.8104785E-04
     +,   6.7820132E-04,   6.7564158E-04,   6.7342934E-04
     +,   6.7162048E-04,   6.7026704E-04,   6.6941447E-04
     +,   6.6910306E-04,   6.6936575E-04,   6.7022804E-04
     +,   6.7170785E-04,   6.7381549E-04,   6.7655201E-04
     +,   6.7991071E-04,   6.8387581E-04,   6.8842462E-04
     +,   6.9352461E-04,   6.9913658E-04,   7.0521398E-04
     +,   7.1170373E-04,   7.1854622E-04,   7.2567770E-04
     +,   7.3302974E-04,   7.4053224E-04,   7.4811059E-04
     +,   7.5569184E-04,   7.6320278E-04,   7.7057141E-04
     +,   7.7772856E-04,   7.8460947E-04,   7.9115434E-04
     +,   7.9730869E-04,   8.0302625E-04,   8.0826663E-04
     +,   8.1300049E-04,   8.1720494E-04,   8.2086696E-04
     +,   8.2398241E-04,   8.2655763E-04,   8.2860631E-04
     +,   8.3015219E-04,   8.3122600E-04,   8.3186541E-04
     +,   8.3211617E-04,   8.3202764E-04,   8.3165441E-04
     +,   8.3105464E-04,   8.3028729E-04,   8.2941330E-04
     +,   8.2849280E-04,   8.2758395E-04,   8.2674308E-04
     +,   8.2602212E-04,   8.2546810E-04,   8.2512415E-04
     +,   8.2502491E-04,   8.2520046E-04,   8.2567183E-04
     +,   8.2645431E-04,   8.2755601E-04,   8.2897558E-04
     +,   8.3070801E-04,   8.3273812E-04,   8.3504716E-04
     +,   8.3760940E-04,   8.4039581E-04,   8.4337220E-04
     +,   8.4650278E-04,   8.4974954E-04,   8.5307320E-04
     +,   8.5643510E-04,   8.5979828E-04,   8.6312875E-04
     +,   8.6639554E-04,   8.6957344E-04,   8.7264180E-04
     +,   8.7558781E-04,   8.7840622E-04,   8.8110118E-04
     +,   8.8368537E-04,   8.8618271E-04,   8.8862691E-04
     +,   8.9106453E-04,   8.9355343E-04,   8.9616299E-04
     +,   8.9897530E-04,   9.0208469E-04,   9.0559659E-04
     +,   9.0962846E-04,   9.1430545E-04,   9.1976486E-04
     +,   9.2614768E-04,   9.3360036E-04,   9.4227184E-04
     +,   9.5230964E-04,   9.6385408E-04,   9.7703841E-04
     +,   9.9198148E-04,   1.0087844E-03,   1.0275265E-03
     +,   1.0482605E-03,   1.0710148E-03,   1.0957852E-03
     +,   1.1225414E-03,   1.1512273E-03,   1.1817701E-03
     +,   1.2140844E-03,   1.2480877E-03,   1.2837123E-03
     +,   1.3209276E-03,   1.3597505E-03,   1.4002736E-03
     +,   1.4426771E-03,   1.4872511E-03,   1.5344040E-03
     +,   1.5846780E-03,   1.6387528E-03,   1.6974346E-03
     +,   1.7616475E-03,   1.8324238E-03,   1.9108675E-03
     +,   1.9981139E-03,   2.0952933E-03,   2.2034913E-03
     +,   2.3236903E-03,   2.4567090E-03,   2.6031833E-03
     +,   2.7635137E-03,   2.9378466E-03,   3.1260753E-03
     +,   3.3278603E-03,   3.5426747E-03,   3.7698369E-03
     +,   4.0085912E-03,   4.2581805E-03,   4.5179348E-03
     +,   4.7872770E-03,   5.0658882E-03,   5.3537460E-03
     +,   5.6512780E-03,   5.9594084E-03,   6.2797228E-03
     +,   6.6144746E-03,   6.9666086E-03,   7.3396899E-03
     +,   7.7379076E-03,   8.1660030E-03,   8.6289765E-03
     +,   9.1318795E-03,   9.6791647E-03,   1.0273851E-02
     +,   1.0916609E-02,   1.1605353E-02,   1.2335454E-02
     +,   1.3100467E-02,   1.3893217E-02,   1.4706650E-02
     +,   1.5533770E-02,   1.6366899E-02,   1.7197011E-02
     +,   1.8013449E-02,   1.8804504E-02,   1.9558689E-02
     +,   2.0266436E-02,   2.0921754E-02,   2.1524727E-02
     +,   2.2083437E-02,   2.2615528E-02,   2.3145752E-02
     +,   2.3698565E-02,   2.4285799E-02,   2.4893908E-02
     +,   2.5475714E-02,   2.5952201E-02,   2.6224492E-02
     +,   2.6192602E-02,   2.5775148E-02,   2.4924355E-02
     +,   2.3634158E-02,   2.1940636E-02,   1.9917229E-02
     +,   1.7665368E-02,   1.5301994E-02,   1.2945225E-02
     +,   1.0700932E-02,   8.6522838E-03,   6.8533043E-03
     +,   5.3284685E-03,   4.0767454E-03,   3.0780907E-03
     +,   2.3009060E-03,   1.7087837E-03,   1.2655312E-03
     +,   9.3824958E-04,   6.9890451E-04,   5.2476261E-04
     +,   3.9810676E-04,   3.0554924E-04,   2.3728535E-04
     +,   1.8629507E-04,   1.4766656E-04,   1.1800134E-04
     +,   9.4964678E-05,   7.6932141E-05,   6.2752100E-05
     +,   5.1576422E-05,   4.2759944E-05,   3.5794241E-05
     +,   3.0271789E-05,   2.5864312E-05,   2.2308011E-05
     +,   1.9394978E-05,   1.6964203E-05,   1.4894880E-05
     +,   1.3098645E-05,   1.1513373E-05,   1.0096589E-05
     +,   8.8204879E-06,   7.6671222E-06,   6.6251728E-06
     +,   5.6870012E-06,   4.8470370E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz115 = Yx/0.234804347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1614876E-04,   2.2573289E-04
     +,   2.3547377E-04,   2.4535437E-04,   2.5535695E-04
     +,   2.6546282E-04,   2.7565329E-04,   2.8590881E-04
     +,   2.9621008E-04,   3.0653796E-04,   3.1687343E-04
     +,   3.2719795E-04,   3.3749393E-04,   3.4774453E-04
     +,   3.5793404E-04,   3.6804870E-04,   3.7807558E-04
     +,   3.8800418E-04,   3.9782544E-04,   4.0753311E-04
     +,   4.1712265E-04,   4.2659236E-04,   4.3594235E-04
     +,   4.4517685E-04,   4.5430081E-04,   4.6332317E-04
     +,   4.7225496E-04,   4.8110998E-04,   4.8990414E-04
     +,   4.9865589E-04,   5.0738588E-04,   5.1611674E-04
     +,   5.2487268E-04,   5.3367967E-04,   5.4256443E-04
     +,   5.5155449E-04,   5.6067848E-04,   5.6996464E-04
     +,   5.7944079E-04,   5.8913452E-04,   5.9907202E-04
     +,   6.0927734E-04,   6.1977375E-04,   6.3058111E-04
     +,   6.4171664E-04,   6.5319409E-04,   6.6502386E-04
     +,   6.7721191E-04,   6.8975979E-04,   7.0266426E-04
     +,   7.1591680E-04,   7.2950433E-04,   7.4340648E-04
     +,   7.5759977E-04,   7.7205256E-04,   7.8672846E-04
     +,   8.0158625E-04,   8.1657741E-04,   8.3164923E-04
     +,   8.4674347E-04,   8.6179737E-04,   8.7674451E-04
     +,   8.9151348E-04,   9.0603018E-04,   9.2021894E-04
     +,   9.3400112E-04,   9.4729796E-04,   9.6003065E-04
     +,   9.7212149E-04,   9.8349317E-04,   9.9407253E-04
     +,   1.0037887E-03,   1.0125778E-03,   1.0203787E-03
     +,   1.0271390E-03,   1.0328121E-03,   1.0373598E-03
     +,   1.0407532E-03,   1.0429722E-03,   1.0440063E-03
     +,   1.0438557E-03,   1.0425310E-03,   1.0400526E-03
     +,   1.0364524E-03,   1.0317729E-03,   1.0260639E-03
     +,   1.0193879E-03,   1.0118149E-03,   1.0034242E-03
     +,   9.9430070E-04,   9.8453625E-04,   9.7422930E-04
     +,   9.6348184E-04,   9.5239829E-04,   9.4108615E-04
     +,   9.2965242E-04,   9.1820385E-04,   9.0684515E-04
     +,   8.9567777E-04,   8.8480028E-04,   8.7430346E-04
     +,   8.6427288E-04,   8.5478573E-04,   8.4591156E-04
     +,   8.3771156E-04,   8.3023502E-04,   8.2352245E-04
     +,   8.1760419E-04,   8.1249757E-04,   8.0821087E-04
     +,   8.0474076E-04,   8.0207217E-04,   8.0018205E-04
     +,   7.9903373E-04,   7.9858437E-04,   7.9878047E-04
     +,   7.9956150E-04,   8.0085831E-04,   8.0259802E-04
     +,   8.0470112E-04,   8.0708449E-04,   8.0966263E-04
     +,   8.1234839E-04,   8.1505551E-04,   8.1769720E-04
     +,   8.2019041E-04,   8.2245492E-04,   8.2441547E-04
     +,   8.2600379E-04,   8.2715641E-04,   8.2781987E-04
     +,   8.2794880E-04,   8.2750688E-04,   8.2646863E-04
     +,   8.2481897E-04,   8.2255399E-04,   8.1968046E-04
     +,   8.1621640E-04,   8.1219198E-04,   8.0764532E-04
     +,   8.0262718E-04,   7.9719670E-04,   7.9142314E-04
     +,   7.8538194E-04,   7.7915611E-04,   7.7283400E-04
     +,   7.6650956E-04,   7.6027762E-04,   7.5423735E-04
     +,   7.4848573E-04,   7.4311922E-04,   7.3823310E-04
     +,   7.3391531E-04,   7.3025038E-04,   7.2731578E-04
     +,   7.2517962E-04,   7.2390155E-04,   7.2353112E-04
     +,   7.2410621E-04,   7.2565360E-04,   7.2818872E-04
     +,   7.3171436E-04,   7.3622196E-04,   7.4169080E-04
     +,   7.4809213E-04,   7.5538590E-04,   7.6352461E-04
     +,   7.7245454E-04,   7.8211713E-04,   7.9245365E-04
     +,   8.0340379E-04,   8.1491069E-04,   8.2692335E-04
     +,   8.3940121E-04,   8.5231365E-04,   8.6564641E-04
     +,   8.7940414E-04,   8.9361263E-04,   9.0832246E-04
     +,   9.2361280E-04,   9.3959417E-04,   9.5641048E-04
     +,   9.7424228E-04,   9.9330931E-04,   1.0138712E-03
     +,   1.0362333E-03,   1.0607387E-03,   1.0877772E-03
     +,   1.1177803E-03,   1.1512110E-03,   1.1885668E-03
     +,   1.2303619E-03,   1.2771164E-03,   1.3293334E-03
     +,   1.3874740E-03,   1.4519371E-03,   1.5230076E-03
     +,   1.6008326E-03,   1.6853863E-03,   1.7764355E-03
     +,   1.8735098E-03,   1.9758937E-03,   2.0826533E-03
     +,   2.1926544E-03,   2.3046180E-03,   2.4172293E-03
     +,   2.5292479E-03,   2.6396273E-03,   2.7476782E-03
     +,   2.8532050E-03,   2.9566193E-03,   3.0590186E-03
     +,   3.1621992E-03,   3.2686205E-03,   3.3812826E-03
     +,   3.5035331E-03,   3.6388207E-03,   3.7904666E-03
     +,   3.9613876E-03,   4.1538873E-03,   4.3695210E-03
     +,   4.6090535E-03,   4.8724134E-03,   5.1587988E-03
     +,   5.4667215E-03,   5.7940995E-03,   6.1382223E-03
     +,   6.4958343E-03,   6.8632672E-03,   7.2367066E-03
     +,   7.6125874E-03,   7.9882909E-03,   8.3628818E-03
     +,   8.7375324E-03,   9.1157006E-03,   9.5027611E-03
     +,   9.9050831E-03,   1.0328927E-02,   1.0779500E-02
     +,   1.1260574E-02,   1.1774686E-02,   1.2323679E-02
     +,   1.2909409E-02,   1.3533825E-02,   1.4198165E-02
     +,   1.4901316E-02,   1.5637701E-02,   1.6395334E-02
     +,   1.7154673E-02,   1.7888112E-02,   1.8561378E-02
     +,   1.9135367E-02,   1.9569037E-02,   1.9822884E-02
     +,   1.9862626E-02,   1.9662526E-02,   1.9208364E-02
     +,   1.8499659E-02,   1.7550606E-02,   1.6389718E-02
     +,   1.5058039E-02,   1.3606113E-02,   1.2089458E-02
     +,   1.0563923E-02,   9.0811690E-03,   7.6845167E-03
     +,   6.4065307E-03,   5.2680946E-03,   4.2787204E-03
     +,   3.4380851E-03,   2.7383333E-03,   2.1665604E-03
     +,   1.7070064E-03,   1.3429176E-03,   1.0579736E-03
     +,   8.3719927E-04,   6.6740857E-04,   5.3744472E-04
     +,   4.3810622E-04,   3.6201999E-04,   3.0338694E-04
     +,   2.5774908E-04,   2.2172896E-04,   1.9281768E-04
     +,   1.6917309E-04,   1.4946560E-04,   1.3274176E-04
     +,   1.1832351E-04,   1.0572995E-04,   9.4614719E-05
     +,   8.4726395E-05,   7.5875236E-05,   6.7915709E-05
     +,   6.0731010E-05,   5.4226985E-05,   4.8325135E-05
     +,   4.2961219E-05,   3.8081420E-05,   3.3641965E-05
     +,   2.9606166E-05,   2.5944086E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz120 = Yx/0.188681818181818
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz60(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9238593E-04,   3.3000397E-04
     +,   3.7311050E-04,   4.2272909E-04,   4.8006952E-04
     +,   5.4654368E-04,   6.2376726E-04,   7.1355171E-04
     +,   8.1786810E-04,   9.3879708E-04,   1.0784325E-03
     +,   1.2387823E-03,   1.4216483E-03,   1.6285236E-03
     +,   1.8605406E-03,   2.1185030E-03,   2.4030253E-03
     +,   2.7147648E-03,   3.0547192E-03,   3.4244650E-03
     +,   3.8262717E-03,   4.2631137E-03,   4.7386000E-03
     +,   5.2571767E-03,   5.8246232E-03,   6.4491737E-03
     +,   7.1426132E-03,   7.9208147E-03,   8.8026924E-03
     +,   9.8071983E-03,   1.0948282E-02,   1.2229635E-02
     +,   1.3640777E-02,   1.5155777E-02,   1.6735323E-02
     +,   1.8330501E-02,   1.9887609E-02,   2.1353282E-02
     +,   2.2680918E-02,   2.3837896E-02,   2.4811756E-02
     +,   2.5610531E-02,   2.6254380E-02,   2.6760420E-02
     +,   2.7128393E-02,   2.7335757E-02,   2.7346108E-02
     +,   2.7126418E-02,   2.6662380E-02,   2.5963280E-02
     +,   2.5056625E-02,   2.3977982E-02,   2.2763910E-02
     +,   2.1450335E-02,   2.0073745E-02,   1.8671058E-02
     +,   1.7276919E-02,   1.5920149E-02,   1.4622112E-02
     +,   1.3397551E-02,   1.2257273E-02,   1.1210033E-02
     +,   1.0262798E-02,   9.4190510E-03,   8.6771389E-03
     +,   8.0293240E-03,   7.4622696E-03,   6.9593308E-03
     +,   6.5031550E-03,   6.0785017E-03,   5.6739333E-03
     +,   5.2826176E-03,   4.9018655E-03,   4.5322636E-03
     +,   4.1762977E-03,   3.8372569E-03,   3.5184009E-03
     +,   3.2224180E-03,   2.9511738E-03,   2.7057126E-03
     +,   2.4863370E-03,   2.2926440E-03,   2.1236870E-03
     +,   1.9780146E-03,   1.8538034E-03,   1.7489174E-03
     +,   1.6610444E-03,   1.5877748E-03,   1.5267365E-03
     +,   1.4756711E-03,   1.4325172E-03,   1.3954646E-03
     +,   1.3629781E-03,   1.3338001E-03,   1.3069386E-03
     +,   1.2816450E-03,   1.2573757E-03,   1.2337596E-03
     +,   1.2105580E-03,   1.1876401E-03,   1.1649446E-03
     +,   1.1424662E-03,   1.1202249E-03,   1.0982663E-03
     +,   1.0766387E-03,   1.0553942E-03,   1.0345825E-03
     +,   1.0142517E-03,   9.9444203E-04,   9.7519183E-04
     +,   9.5653889E-04,   9.3851675E-04,   9.2116062E-04
     +,   9.0450706E-04,   8.8859181E-04,   8.7345316E-04
     +,   8.5912942E-04,   8.4565801E-04,   8.3307695E-04
     +,   8.2141947E-04,   8.1071554E-04,   8.0099056E-04
     +,   7.9226150E-04,   7.8453845E-04,   7.7782199E-04
     +,   7.7210186E-04,   7.6735840E-04,   7.6356129E-04
     +,   7.6066802E-04,   7.5862627E-04,   7.5737305E-04
     +,   7.5683591E-04,   7.5693405E-04,   7.5758045E-04
     +,   7.5867918E-04,   7.6013309E-04,   7.6184014E-04
     +,   7.6369726E-04,   7.6560199E-04,   7.6745445E-04
     +,   7.6915720E-04,   7.7061891E-04,   7.7175535E-04
     +,   7.7248941E-04,   7.7275408E-04,   7.7249220E-04
     +,   7.7165791E-04,   7.7021722E-04,   7.6814869E-04
     +,   7.6544360E-04,   7.6210476E-04,   7.5814774E-04
     +,   7.5360044E-04,   7.4850151E-04,   7.4289995E-04
     +,   7.3685526E-04,   7.3043449E-04,   7.2371121E-04
     +,   7.1676628E-04,   7.0968480E-04,   7.0255366E-04
     +,   6.9546211E-04,   6.8849884E-04,   6.8175286E-04
     +,   6.7530747E-04,   6.6924398E-04,   6.6363695E-04
     +,   6.5855583E-04,   6.5406185E-04,   6.5020728E-04
     +,   6.4703665E-04,   6.4458395E-04,   6.4287393E-04
     +,   6.4192002E-04,   6.4172730E-04,   6.4228958E-04
     +,   6.4359122E-04,   6.4560724E-04,   6.4830331E-04
     +,   6.5163756E-04,   6.5556099E-04,   6.6001684E-04
     +,   6.6494284E-04,   6.7027257E-04,   6.7593559E-04
     +,   6.8185816E-04,   6.8796473E-04,   6.9417967E-04
     +,   7.0042617E-04,   7.0662936E-04,   7.1271567E-04
     +,   7.1861490E-04,   7.2425860E-04,   7.2958367E-04
     +,   7.3453138E-04,   7.3904695E-04,   7.4308191E-04
     +,   7.4659230E-04,   7.4954092E-04,   7.5189612E-04
     +,   7.5363158E-04,   7.5472699E-04,   7.5516757E-04
     +,   7.5494422E-04,   7.5405237E-04,   7.5249351E-04
     +,   7.5027236E-04,   7.4739830E-04,   7.4388465E-04
     +,   7.3974737E-04,   7.3500647E-04,   7.2968350E-04
     +,   7.2380312E-04,   7.1739109E-04,   7.1047421E-04
     +,   7.0308225E-04,   6.9524371E-04,   6.8698864E-04
     +,   6.7834713E-04,   6.6934898E-04,   6.6002505E-04
     +,   6.5040361E-04,   6.4051419E-04,   6.3038588E-04
     +,   6.2004570E-04,   6.0951995E-04,   5.9883506E-04
     +,   5.8801559E-04,   5.7708554E-04,   5.6606665E-04
     +,   5.5498042E-04,   5.4384815E-04,   5.3268805E-04
     +,   5.2151812E-04,   5.1035522E-04,   4.9921480E-04
     +,   4.8811096E-04,   4.7705727E-04,   4.6606653E-04
     +,   4.5514904E-04,   4.4431462E-04,   4.3357286E-04
     +,   4.2293215E-04,   4.1239933E-04,   4.0198045E-04
     +,   3.9168133E-04,   3.8150742E-04,   3.7146252E-04
     +,   3.6154955E-04,   3.5177253E-04,   3.4213372E-04
     +,   3.3263463E-04,   3.2327764E-04,   3.1406441E-04
     +,   3.0499572E-04,   2.9607225E-04,   2.8729517E-04
     +,   2.7866536E-04,   2.7018314E-04,   2.6184868E-04
     +,   2.5366267E-04,   2.4562591E-04,   2.3773847E-04
     +,   2.3000059E-04,   2.2241317E-04,   2.1497642E-04
     +,   2.0769051E-04,   2.0055614E-04,   1.9357413E-04
     +,   1.8674452E-04,   1.8006763E-04,   1.7354407E-04
     +,   1.6717444E-04,   1.6095885E-04,   1.5489718E-04
     +,   1.4899009E-04,   1.4323716E-04,   1.3763882E-04
     +,   1.3219443E-04,   1.2690393E-04,   1.2176653E-04
     +,   1.1678197E-04,   1.1194908E-04,   1.0726719E-04
     +,   1.0273496E-04,   9.8351244E-05,   9.4114512E-05
     +,   9.0022906E-05,   8.6074899E-05,   8.2268249E-05
     +,   7.8601050E-05,   7.5070791E-05,   7.1675233E-05
     +,   6.8411588E-05,   6.5277367E-05,   6.2269552E-05
     +,   5.9385402E-05,   5.6621713E-05,   5.3975560E-05
     +,   5.1443611E-05,   4.9022772E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz60 = Yx/0.233891304347826
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz65(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2735835E-04,   1.3480471E-04
     +,   1.4273789E-04,   1.5118992E-04,   1.6019309E-04
     +,   1.6978002E-04,   1.7998337E-04,   1.9083625E-04
     +,   2.0237225E-04,   2.1462710E-04,   2.2763852E-04
     +,   2.4144897E-04,   2.5610713E-04,   2.7167113E-04
     +,   2.8821168E-04,   3.0581528E-04,   3.2458972E-04
     +,   3.4466753E-04,   3.6621231E-04,   3.8942433E-04
     +,   4.1454809E-04,   4.4188250E-04,   4.7179279E-04
     +,   5.0473126E-04,   5.4125366E-04,   5.8205734E-04
     +,   6.2800909E-04,   6.8018859E-04,   7.3992833E-04
     +,   8.0885144E-04,   8.8890514E-04,   9.8237896E-04
     +,   1.0919039E-03,   1.2204372E-03,   1.3712092E-03
     +,   1.5476586E-03,   1.7533414E-03,   1.9918387E-03
     +,   2.2667369E-03,   2.5816034E-03,   2.9401709E-03
     +,   3.3464716E-03,   3.8050239E-03,   4.3208506E-03
     +,   4.8992760E-03,   5.5456320E-03,   6.2652286E-03
     +,   7.0640347E-03,   7.9503180E-03,   8.9366222E-03
     +,   1.0040784E-02,   1.1284180E-02,   1.2686414E-02
     +,   1.4257282E-02,   1.5987998E-02,   1.7845184E-02
     +,   1.9768134E-02,   2.1672716E-02,   2.3464480E-02
     +,   2.5063125E-02,   2.6432540E-02,   2.7599182E-02
     +,   2.8638816E-02,   2.9627908E-02,   3.0582085E-02
     +,   3.1421192E-02,   3.1987976E-02,   3.2113459E-02
     +,   3.1694211E-02,   3.0739408E-02,   2.9365633E-02
     +,   2.7747242E-02,   2.6049826E-02,   2.4382800E-02
     +,   2.2787007E-02,   2.1257404E-02,   1.9777896E-02
     +,   1.8348353E-02,   1.6990760E-02,   1.5737293E-02
     +,   1.4610048E-02,   1.3606074E-02,   1.2696028E-02
     +,   1.1836408E-02,   1.0988434E-02,   1.0133171E-02
     +,   9.2767887E-03,   8.4442841E-03,   7.6676570E-03
     +,   6.9736447E-03,   6.3765189E-03,   5.8766827E-03
     +,   5.4635517E-03,   5.1203179E-03,   4.8285048E-03
     +,   4.5712865E-03,   4.3351827E-03,   4.1107251E-03
     +,   3.8922410E-03,   3.6773027E-03,   3.4658816E-03
     +,   3.2595897E-03,   3.0608168E-03,   2.8721669E-03
     +,   2.6959120E-03,   2.5337236E-03,   2.3865392E-03
     +,   2.2545550E-03,   2.1373064E-03,   2.0338250E-03
     +,   1.9428130E-03,   1.8627740E-03,   1.7921748E-03
     +,   1.7295285E-03,   1.6734890E-03,   1.6228833E-03
     +,   1.5767410E-03,   1.5342893E-03,   1.4949457E-03
     +,   1.4582826E-03,   1.4240057E-03,   1.3919256E-03
     +,   1.3619221E-03,   1.3339196E-03,   1.3078720E-03
     +,   1.2837430E-03,   1.2614934E-03,   1.2410808E-03
     +,   1.2224473E-03,   1.2055236E-03,   1.1902252E-03
     +,   1.1764525E-03,   1.1640934E-03,   1.1530236E-03
     +,   1.1431079E-03,   1.1342003E-03,   1.1261500E-03
     +,   1.1188006E-03,   1.1119905E-03,   1.1055616E-03
     +,   1.0993539E-03,   1.0932183E-03,   1.0870119E-03
     +,   1.0806003E-03,   1.0738656E-03,   1.0667038E-03
     +,   1.0590272E-03,   1.0507670E-03,   1.0418727E-03
     +,   1.0323100E-03,   1.0220631E-03,   1.0111359E-03
     +,   9.9954428E-04,   9.8732184E-04,   9.7451353E-04
     +,   9.6117635E-04,   9.4737893E-04,   9.3319581E-04
     +,   9.1870973E-04,   9.0400875E-04,   8.8918483E-04
     +,   8.7433215E-04,   8.5954618E-04,   8.4492390E-04
     +,   8.3055976E-04,   8.1654737E-04,   8.0297684E-04
     +,   7.8993582E-04,   7.7750545E-04,   7.6576194E-04
     +,   7.5477682E-04,   7.4461207E-04,   7.3532376E-04
     +,   7.2695856E-04,   7.1955490E-04,   7.1314111E-04
     +,   7.0773688E-04,   7.0335169E-04,   6.9998461E-04
     +,   6.9762609E-04,   6.9625571E-04,   6.9584494E-04
     +,   6.9635489E-04,   6.9774082E-04,   6.9994834E-04
     +,   7.0291740E-04,   7.0658093E-04,   7.1086740E-04
     +,   7.1570062E-04,   7.2100078E-04,   7.2668545E-04
     +,   7.3267095E-04,   7.3887152E-04,   7.4520131E-04
     +,   7.5157493E-04,   7.5790880E-04,   7.6411944E-04
     +,   7.7012647E-04,   7.7585212E-04,   7.8122178E-04
     +,   7.8616408E-04,   7.9061196E-04,   7.9450296E-04
     +,   7.9777912E-04,   8.0038788E-04,   8.0228189E-04
     +,   8.0342009E-04,   8.0376648E-04,   8.0329360E-04
     +,   8.0197887E-04,   7.9980539E-04,   7.9676585E-04
     +,   7.9285813E-04,   7.8808767E-04,   7.8246463E-04
     +,   7.7600864E-04,   7.6874392E-04,   7.6070050E-04
     +,   7.5191370E-04,   7.4242381E-04,   7.3227583E-04
     +,   7.2151714E-04,   7.1019848E-04,   6.9837400E-04
     +,   6.8609702E-04,   6.7342166E-04,   6.6040293E-04
     +,   6.4709561E-04,   6.3355145E-04,   6.1981956E-04
     +,   6.0594874E-04,   5.9198373E-04,   5.7796558E-04
     +,   5.6393212E-04,   5.4991827E-04,   5.3595385E-04
     +,   5.2206550E-04,   5.0827692E-04,   4.9460842E-04
     +,   4.8107625E-04,   4.6769361E-04,   4.5447235E-04
     +,   4.4142181E-04,   4.2854858E-04,   4.1585776E-04
     +,   4.0335412E-04,   3.9104142E-04,   3.7892212E-04
     +,   3.6699808E-04,   3.5527244E-04,   3.4374691E-04
     +,   3.3242375E-04,   3.2130585E-04,   3.1039657E-04
     +,   2.9969902E-04,   2.8921629E-04,   2.7895271E-04
     +,   2.6891290E-04,   2.5910069E-04,   2.4952012E-04
     +,   2.4017575E-04,   2.3107199E-04,   2.2221240E-04
     +,   2.1360010E-04,   2.0523858E-04,   1.9713002E-04
     +,   1.8927584E-04,   1.8167743E-04,   1.7433538E-04
     +,   1.6724889E-04,   1.6041663E-04,   1.5383675E-04
     +,   1.4750662E-04,   1.4142263E-04,   1.3558027E-04
     +,   1.2997499E-04,   1.2460099E-04,   1.1945266E-04
     +,   1.1452305E-04,   1.0980561E-04,   1.0529288E-04
     +,   1.0097761E-04,   9.6851923E-05,   9.2908187E-05
     +,   8.9138419E-05,   8.5534986E-05,   8.2089988E-05
     +,   7.8795711E-05,   7.5644843E-05,   7.2629904E-05
     +,   6.9744026E-05,   6.6980254E-05,   6.4332169E-05
     +,   6.1793471E-05,   5.9358368E-05,   5.7021141E-05
     +,   5.4776654E-05,   5.2619827E-05,   5.0546198E-05
     +,   4.8551312E-05,   4.6631278E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz65 = Yx/0.254891304347826
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz70(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5290445E-05,   7.9075646E-05
     +,   8.3049083E-05,   8.7217282E-05,   9.1586524E-05
     +,   9.6162781E-05,   1.0095179E-04,   1.0595889E-04
     +,   1.1118899E-04,   1.1664691E-04,   1.2233685E-04
     +,   1.2826266E-04,   1.3442790E-04,   1.4083581E-04
     +,   1.4748938E-04,   1.5439128E-04,   1.6154422E-04
     +,   1.6895081E-04,   1.7661373E-04,   1.8453611E-04
     +,   1.9272145E-04,   2.0117400E-04,   2.0989905E-04
     +,   2.1890384E-04,   2.2819653E-04,   2.3778892E-04
     +,   2.4769540E-04,   2.5793427E-04,   2.6852908E-04
     +,   2.7950943E-04,   2.9091223E-04,   3.0278321E-04
     +,   3.1517912E-04,   3.2816938E-04,   3.4183907E-04
     +,   3.5629203E-04,   3.7165510E-04,   3.8808290E-04
     +,   4.0576587E-04,   4.2493542E-04,   4.4587854E-04
     +,   4.6894600E-04,   4.9456937E-04,   5.2327628E-04
     +,   5.5570801E-04,   5.9263967E-04,   6.3499634E-04
     +,   6.8387255E-04,   7.4054772E-04,   8.0649846E-04
     +,   8.8341470E-04,   9.7321148E-04,   1.0780460E-03
     +,   1.2003526E-03,   1.3428556E-03,   1.5086288E-03
     +,   1.7011047E-03,   1.9240903E-03,   2.1817519E-03
     +,   2.4785995E-03,   2.8194755E-03,   3.2095555E-03
     +,   3.6542353E-03,   4.1588028E-03,   4.7276011E-03
     +,   5.3626448E-03,   6.0624518E-03,   6.8213926E-03
     +,   7.6311179E-03,   8.4838709E-03,   9.3781278E-03
     +,   1.0325151E-02,   1.1355686E-02,   1.2523182E-02
     +,   1.3899417E-02,   1.5556133E-02,   1.7532805E-02
     +,   1.9802803E-02,   2.2260096E-02,   2.4742413E-02
     +,   2.7080216E-02,   2.9137410E-02,   3.0817382E-02
     +,   3.2050356E-02,   3.2794375E-02,   3.3059858E-02
     +,   3.2924540E-02,   3.2508865E-02,   3.1922553E-02
     +,   3.1221347E-02,   3.0402662E-02,   2.9437788E-02
     +,   2.8314030E-02,   2.7059630E-02,   2.5738187E-02
     +,   2.4417114E-02,   2.3130715E-02,   2.1863408E-02
     +,   2.0563679E-02,   1.9183861E-02,   1.7717859E-02
     +,   1.6214076E-02,   1.4755529E-02,   1.3423005E-02
     +,   1.2262611E-02,   1.1273893E-02,   1.0420014E-02
     +,   9.6505471E-03,   8.9237140E-03,   8.2184663E-03
     +,   7.5340942E-03,   6.8816929E-03,   6.2745907E-03
     +,   5.7217921E-03,   5.2262191E-03,   4.7857855E-03
     +,   4.3958784E-03,   4.0512681E-03,   3.7473738E-03
     +,   3.4804356E-03,   3.2473831E-03,   3.0454721E-03
     +,   2.8718994E-03,   2.7236540E-03,   2.5974771E-03
     +,   2.4899782E-03,   2.3977638E-03,   2.3176249E-03
     +,   2.2466509E-03,   2.1823337E-03,   2.1225903E-03
     +,   2.0657759E-03,   2.0106477E-03,   1.9563341E-03
     +,   1.9022686E-03,   1.8481452E-03,   1.7938680E-03
     +,   1.7395007E-03,   1.6852116E-03,   1.6312452E-03
     +,   1.5778829E-03,   1.5254186E-03,   1.4741266E-03
     +,   1.4242528E-03,   1.3760119E-03,   1.3295686E-03
     +,   1.2850444E-03,   1.2425213E-03,   1.2020480E-03
     +,   1.1636380E-03,   1.1272796E-03,   1.0929460E-03
     +,   1.0605975E-03,   1.0301834E-03,   1.0016470E-03
     +,   9.7493187E-04,   9.4998156E-04,   9.2673651E-04
     +,   9.0514187E-04,   8.8514603E-04,   8.6669734E-04
     +,   8.4974983E-04,   8.3425950E-04,   8.2018564E-04
     +,   8.0749026E-04,   7.9613656E-04,   7.8609021E-04
     +,   7.7731709E-04,   7.6978176E-04,   7.6344761E-04
     +,   7.5827545E-04,   7.5422163E-04,   7.5123925E-04
     +,   7.4927422E-04,   7.4826821E-04,   7.4815610E-04
     +,   7.4886758E-04,   7.5032760E-04,   7.5245497E-04
     +,   7.5516611E-04,   7.5837446E-04,   7.6199294E-04
     +,   7.6593208E-04,   7.7010569E-04,   7.7442749E-04
     +,   7.7881658E-04,   7.8319316E-04,   7.8748487E-04
     +,   7.9162302E-04,   7.9554407E-04,   7.9919241E-04
     +,   8.0251606E-04,   8.0547156E-04,   8.0802001E-04
     +,   8.1012887E-04,   8.1177155E-04,   8.1292720E-04
     +,   8.1357989E-04,   8.1371999E-04,   8.1334176E-04
     +,   8.1244437E-04,   8.1103272E-04,   8.0911384E-04
     +,   8.0670003E-04,   8.0380740E-04,   8.0045336E-04
     +,   7.9666002E-04,   7.9244992E-04,   7.8784802E-04
     +,   7.8288023E-04,   7.7757175E-04,   7.7194843E-04
     +,   7.6603453E-04,   7.5985258E-04,   7.5342308E-04
     +,   7.4676337E-04,   7.3988910E-04,   7.3281047E-04
     +,   7.2553579E-04,   7.1806874E-04,   7.1040960E-04
     +,   7.0255517E-04,   6.9450057E-04,   6.8623701E-04
     +,   6.7775376E-04,   6.6903926E-04,   6.6008110E-04
     +,   6.5086735E-04,   6.4138579E-04,   6.3162571E-04
     +,   6.2157883E-04,   6.1123940E-04,   6.0060411E-04
     +,   5.8967259E-04,   5.7844975E-04,   5.6694233E-04
     +,   5.5516133E-04,   5.4312224E-04,   5.3084362E-04
     +,   5.1834679E-04,   5.0565583E-04,   4.9279863E-04
     +,   4.7980458E-04,   4.6670414E-04,   4.5352918E-04
     +,   4.4031229E-04,   4.2708692E-04,   4.1388557E-04
     +,   4.0073897E-04,   3.8767909E-04,   3.7473487E-04
     +,   3.6193352E-04,   3.4930126E-04,   3.3686199E-04
     +,   3.2463693E-04,   3.1264473E-04,   3.0090255E-04
     +,   2.8942531E-04,   2.7822505E-04,   2.6731114E-04
     +,   2.5669212E-04,   2.4637423E-04,   2.3636123E-04
     +,   2.2665529E-04,   2.1725782E-04,   2.0816820E-04
     +,   1.9938423E-04,   1.9090352E-04,   1.8272256E-04
     +,   1.7483640E-04,   1.6723960E-04,   1.5992657E-04
     +,   1.5289114E-04,   1.4612646E-04,   1.3962529E-04
     +,   1.3338086E-04,   1.2738544E-04,   1.2163190E-04
     +,   1.1611245E-04,   1.1081988E-04,   1.0574639E-04
     +,   1.0088483E-04,   9.6227719E-05,   9.1767935E-05
     +,   8.7498214E-05,   8.3411782E-05,   7.9501668E-05
     +,   7.5761098E-05,   7.2183742E-05,   6.8763053E-05
     +,   6.5493034E-05,   6.2367464E-05,   5.9380727E-05
     +,   5.6526937E-05,   5.3800810E-05,   5.1196865E-05
     +,   4.8710157E-05,   4.6335557E-05,   4.4068474E-05
     +,   4.1904164E-05,   3.9838345E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz70 = Yx/0.261586956521739
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.5311964E-05,   8.8573688E-05
     +,   9.1879636E-05,   9.5224132E-05,   9.8601049E-05
     +,   1.0200381E-04,   1.0542530E-04,   1.0885800E-04
     +,   1.1229391E-04,   1.1572473E-04,   1.1914168E-04
     +,   1.2253568E-04,   1.2589729E-04,   1.2921692E-04
     +,   1.3248474E-04,   1.3569079E-04,   1.3882513E-04
     +,   1.4187767E-04,   1.4483862E-04,   1.4769835E-04
     +,   1.5044745E-04,   1.5307700E-04,   1.5557861E-04
     +,   1.5794468E-04,   1.6016813E-04,   1.6224323E-04
     +,   1.6416512E-04,   1.6593041E-04,   1.6753720E-04
     +,   1.6898537E-04,   1.7027676E-04,   1.7141549E-04
     +,   1.7240811E-04,   1.7326410E-04,   1.7399585E-04
     +,   1.7461921E-04,   1.7515372E-04,   1.7562284E-04
     +,   1.7605428E-04,   1.7648037E-04,   1.7693822E-04
     +,   1.7746973E-04,   1.7812237E-04,   1.7894876E-04
     +,   1.8000724E-04,   1.8136192E-04,   1.8308299E-04
     +,   1.8524732E-04,   1.8793863E-04,   1.9124903E-04
     +,   1.9527962E-04,   2.0014307E-04,   2.0596529E-04
     +,   2.1288976E-04,   2.2107986E-04,   2.3072548E-04
     +,   2.4204687E-04,   2.5530066E-04,   2.7078600E-04
     +,   2.8884865E-04,   3.0988577E-04,   3.3434716E-04
     +,   3.6273425E-04,   3.9559885E-04,   4.3353779E-04
     +,   4.7718053E-04,   5.2719121E-04,   5.8425107E-04
     +,   6.4907409E-04,   7.2240061E-04,   8.0503878E-04
     +,   8.9788245E-04,   1.0019888E-03,   1.1186197E-03
     +,   1.2493352E-03,   1.3960521E-03,   1.5610836E-03
     +,   1.7471489E-03,   1.9573355E-03,   2.1949438E-03
     +,   2.4632020E-03,   2.7649603E-03,   3.1022823E-03
     +,   3.4763687E-03,   3.8877756E-03,   4.3375399E-03
     +,   4.8287576E-03,   5.3688795E-03,   5.9716362E-03
     +,   6.6584977E-03,   7.4582351E-03,   8.4034130E-03
     +,   9.5225954E-03,   1.0829255E-02,   1.2312047E-02
     +,   1.3934630E-02,   1.5649216E-02,   1.7416684E-02
     +,   1.9220885E-02,   2.1066524E-02,   2.2965482E-02
     +,   2.4919491E-02,   2.6909411E-02,   2.8890043E-02
     +,   3.0783772E-02,   3.2463286E-02,   3.3745635E-02
     +,   3.4445811E-02,   3.4483939E-02,   3.3943169E-02
     +,   3.3001956E-02,   3.1810720E-02,   3.0450147E-02
     +,   2.8979858E-02,   2.7470719E-02,   2.5972493E-02
     +,   2.4480043E-02,   2.2958482E-02,   2.1397425E-02
     +,   1.9829636E-02,   1.8304296E-02,   1.6856046E-02
     +,   1.5500532E-02,   1.4247234E-02,   1.3107292E-02
     +,   1.2089667E-02,   1.1194794E-02,   1.0414863E-02
     +,   9.7375112E-03,   9.1493689E-03,   8.6364429E-03
     +,   8.1844954E-03,   7.7802977E-03,   7.4137505E-03
     +,   7.0785098E-03,   6.7709703E-03,   6.4882087E-03
     +,   6.2262383E-03,   5.9795510E-03,   5.7418961E-03
     +,   5.5077053E-03,   5.2732779E-03,   5.0372621E-03
     +,   4.8004119E-03,   4.5648627E-03,   4.3331357E-03
     +,   4.1074613E-03,   3.8893959E-03,   3.6797442E-03
     +,   3.4787380E-03,   3.2862832E-03,   3.1022329E-03
     +,   2.9265066E-03,   2.7591649E-03,   2.6003877E-03
     +,   2.4504291E-03,   2.3095314E-03,   2.1778503E-03
     +,   2.0554215E-03,   1.9421583E-03,   1.8378365E-03
     +,   1.7421194E-03,   1.6545972E-03,   1.5747958E-03
     +,   1.5022017E-03,   1.4362754E-03,   1.3764701E-03
     +,   1.3222374E-03,   1.2730320E-03,   1.2283231E-03
     +,   1.1876109E-03,   1.1504311E-03,   1.1163605E-03
     +,   1.0850299E-03,   1.0561274E-03,   1.0293960E-03
     +,   1.0046322E-03,   9.8168396E-04,   9.6044224E-04
     +,   9.4083004E-04,   9.2279591E-04,   9.0630644E-04
     +,   8.9133828E-04,   8.7786710E-04,   8.6586759E-04
     +,   8.5530779E-04,   8.4614428E-04,   8.3832262E-04
     +,   8.3177502E-04,   8.2642271E-04,   8.2217297E-04
     +,   8.1892294E-04,   8.1656111E-04,   8.1496767E-04
     +,   8.1401743E-04,   8.1358262E-04,   8.1353250E-04
     +,   8.1373949E-04,   8.1407907E-04,   8.1443402E-04
     +,   8.1469340E-04,   8.1475981E-04,   8.1454642E-04
     +,   8.1398198E-04,   8.1300974E-04,   8.1159041E-04
     +,   8.0969947E-04,   8.0733036E-04,   8.0449117E-04
     +,   8.0120284E-04,   7.9750002E-04,   7.9342630E-04
     +,   7.8903238E-04,   7.8437338E-04,   7.7950588E-04
     +,   7.7448372E-04,   7.6935766E-04,   7.6417008E-04
     +,   7.5895386E-04,   7.5373054E-04,   7.4850832E-04
     +,   7.4328238E-04,   7.3803397E-04,   7.3273160E-04
     +,   7.2733045E-04,   7.2177523E-04,   7.1600178E-04
     +,   7.0994144E-04,   7.0351874E-04,   6.9665979E-04
     +,   6.8929273E-04,   6.8134931E-04,   6.7276938E-04
     +,   6.6350203E-04,   6.5350987E-04,   6.4276671E-04
     +,   6.3126103E-04,   6.1899656E-04,   6.0599239E-04
     +,   5.9227989E-04,   5.7790481E-04,   5.6292524E-04
     +,   5.4740917E-04,   5.3143292E-04,   5.1507767E-04
     +,   4.9843098E-04,   4.8158158E-04,   4.6461710E-04
     +,   4.4762314E-04,   4.3068294E-04,   4.1387262E-04
     +,   3.9726205E-04,   3.8091475E-04,   3.6488549E-04
     +,   3.4922059E-04,   3.3395700E-04,   3.1912467E-04
     +,   3.0474618E-04,   2.9083513E-04,   2.7739894E-04
     +,   2.6444026E-04,   2.5195660E-04,   2.3994055E-04
     +,   2.2838151E-04,   2.1726787E-04,   2.0658507E-04
     +,   1.9631769E-04,   1.8645039E-04,   1.7696820E-04
     +,   1.6785564E-04,   1.5909821E-04,   1.5068283E-04
     +,   1.4259754E-04,   1.3483084E-04,   1.2737235E-04
     +,   1.2021353E-04,   1.1334575E-04,   1.0676221E-04
     +,   1.0045579E-04,   9.4420808E-05,   8.8651184E-05
     +,   8.3141829E-05,   7.7887125E-05,   7.2882118E-05
     +,   6.8121197E-05,   6.3599175E-05,   5.9310238E-05
     +,   5.5248365E-05,   5.1407693E-05,   4.7781505E-05
     +,   4.4363391E-05,   4.1146195E-05,   3.8122973E-05
     +,   3.5286179E-05,   3.2628493E-05,   3.0142148E-05
     +,   2.7819602E-05,   2.5653013E-05,   2.3634799E-05
     +,   2.1757205E-05,   2.0012798E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz75 = Yx/0.264808510638298
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.4439566E-05,   5.6182816E-05
     +,   5.7944348E-05,   5.9721704E-05,   6.1512379E-05
     +,   6.3313797E-05,   6.5123400E-05,   6.6938599E-05
     +,   6.8756824E-05,   7.0575676E-05,   7.2392744E-05
     +,   7.4205855E-05,   7.6012948E-05,   7.7812270E-05
     +,   7.9602294E-05,   8.1381848E-05,   8.3150167E-05
     +,   8.4906875E-05,   8.6652093E-05,   8.8386449E-05
     +,   9.0111156E-05,   9.1828188E-05,   9.3539893E-05
     +,   9.5249656E-05,   9.6961303E-05,   9.8679666E-05
     +,   1.0041023E-04,   1.0215928E-04,   1.0393391E-04
     +,   1.0574198E-04,   1.0759212E-04,   1.0949365E-04
     +,   1.1145649E-04,   1.1349126E-04,   1.1560901E-04
     +,   1.1782120E-04,   1.2013961E-04,   1.2257614E-04
     +,   1.2514285E-04,   1.2785147E-04,   1.3071370E-04
     +,   1.3374066E-04,   1.3694294E-04,   1.4033042E-04
     +,   1.4391210E-04,   1.4769596E-04,   1.5168895E-04
     +,   1.5589673E-04,   1.6032379E-04,   1.6497339E-04
     +,   1.6984751E-04,   1.7494704E-04,   1.8027185E-04
     +,   1.8582119E-04,   1.9159334E-04,   1.9758675E-04
     +,   2.0379988E-04,   2.1023177E-04,   2.1688237E-04
     +,   2.2375355E-04,   2.3084911E-04,   2.3817591E-04
     +,   2.4574378E-04,   2.5356730E-04,   2.6166593E-04
     +,   2.7006419E-04,   2.7879380E-04,   2.8789317E-04
     +,   2.9740980E-04,   3.0739998E-04,   3.1793196E-04
     +,   3.2908557E-04,   3.4095714E-04,   3.5365947E-04
     +,   3.6732719E-04,   3.8212017E-04,   3.9822765E-04
     +,   4.1587287E-04,   4.3532118E-04,   4.5688433E-04
     +,   4.8092398E-04,   5.0786126E-04,   5.3817627E-04
     +,   5.7241815E-04,   6.1120093E-04,   6.5521698E-04
     +,   7.0523028E-04,   7.6209829E-04,   8.2676613E-04
     +,   9.0029225E-04,   9.8385534E-04,   1.0787619E-03
     +,   1.1864522E-03,   1.3085158E-03,   1.4466840E-03
     +,   1.6028249E-03,   1.7789856E-03,   1.9773804E-03
     +,   2.2004617E-03,   2.4508899E-03,   2.7315917E-03
     +,   3.0457147E-03,   3.3967532E-03,   3.7886826E-03
     +,   4.2264350E-03,   4.7165211E-03,   5.2677328E-03
     +,   5.8917259E-03,   6.6030361E-03,   7.4180001E-03
     +,   8.3524045E-03,   9.4187483E-03,   1.0622784E-02
     +,   1.1961002E-02,   1.3417581E-02,   1.4963623E-02
     +,   1.6560199E-02,   1.8171594E-02,   1.9784167E-02
     +,   2.1420138E-02,   2.3125442E-02,   2.4923878E-02
     +,   2.6760215E-02,   2.8492648E-02,   2.9979520E-02
     +,   3.1201305E-02,   3.2267168E-02,   3.3247903E-02
     +,   3.4012415E-02,   3.4287535E-02,   3.3904575E-02
     +,   3.2959837E-02,   3.1728942E-02,   3.0452842E-02
     +,   2.9207040E-02,   2.7933873E-02,   2.6568908E-02
     +,   2.5142638E-02,   2.3775645E-02,   2.2580655E-02
     +,   2.1570561E-02,   2.0655226E-02,   1.9713357E-02
     +,   1.8663861E-02,   1.7490668E-02,   1.6228516E-02
     +,   1.4936796E-02,   1.3675897E-02,   1.2490430E-02
     +,   1.1402373E-02,   1.0414839E-02,   9.5212776E-03
     +,   8.7141544E-03,   7.9889111E-03,   7.3438161E-03
     +,   6.7777843E-03,   6.2881545E-03,   5.8694459E-03
     +,   5.5132373E-03,   5.2088392E-03,   4.9443091E-03
     +,   4.7078379E-03,   4.4889650E-03,   4.2794743E-03
     +,   4.0738597E-03,   3.8693149E-03,   3.6654151E-03
     +,   3.4635598E-03,   3.2663269E-03,   3.0768779E-03
     +,   2.8984128E-03,   2.7337123E-03,   2.5847813E-03
     +,   2.4526860E-03,   2.3375256E-03,   2.2384892E-03
     +,   2.1540688E-03,   2.0823090E-03,   2.0210557E-03
     +,   1.9681791E-03,   1.9217568E-03,   1.8801767E-03
     +,   1.8421819E-03,   1.8068596E-03,   1.7736016E-03
     +,   1.7420519E-03,   1.7120350E-03,   1.6834993E-03
     +,   1.6564730E-03,   1.6310259E-03,   1.6072415E-03
     +,   1.5852051E-03,   1.5649924E-03,   1.5466590E-03
     +,   1.5302337E-03,   1.5157154E-03,   1.5030646E-03
     +,   1.4922061E-03,   1.4830137E-03,   1.4753180E-03
     +,   1.4689079E-03,   1.4635294E-03,   1.4588959E-03
     +,   1.4547000E-03,   1.4506237E-03,   1.4463540E-03
     +,   1.4415963E-03,   1.4360847E-03,   1.4296039E-03
     +,   1.4219859E-03,   1.4131247E-03,   1.4029762E-03
     +,   1.3915577E-03,   1.3789418E-03,   1.3652473E-03
     +,   1.3506328E-03,   1.3352811E-03,   1.3193834E-03
     +,   1.3031340E-03,   1.2867100E-03,   1.2702658E-03
     +,   1.2539218E-03,   1.2377643E-03,   1.2218363E-03
     +,   1.2061392E-03,   1.1906383E-03,   1.1752642E-03
     +,   1.1599209E-03,   1.1444925E-03,   1.1288502E-03
     +,   1.1128628E-03,   1.0964040E-03,   1.0793558E-03
     +,   1.0616186E-03,   1.0431127E-03,   1.0237813E-03
     +,   1.0035915E-03,   9.8253612E-04,   9.6063147E-04
     +,   9.3791261E-04,   9.1443234E-04,   8.9025887E-04
     +,   8.6547149E-04,   8.4015465E-04,   8.1439584E-04
     +,   7.8828511E-04,   7.6191069E-04,   7.3535554E-04
     +,   7.0869783E-04,   6.8201218E-04,   6.5536523E-04
     +,   6.2881835E-04,   6.0242938E-04,   5.7625124E-04
     +,   5.5033254E-04,   5.2471872E-04,   4.9945549E-04
     +,   4.7458717E-04,   4.5015517E-04,   4.2620121E-04
     +,   4.0276733E-04,   3.7989562E-04,   3.5762507E-04
     +,   3.3599383E-04,   3.1503968E-04,   2.9479639E-04
     +,   2.7529427E-04,   2.5656141E-04,   2.3862132E-04
     +,   2.2149172E-04,   2.0518576E-04,   1.8971201E-04
     +,   1.7507386E-04,   1.6126843E-04,   1.4828783E-04
     +,   1.3612051E-04,   1.2474890E-04,   1.1415277E-04
     +,   1.0430698E-04,   9.5184507E-05,   8.6754590E-05
     +,   7.8985657E-05,   7.1843475E-05,   6.5293905E-05
     +,   5.9301354E-05,   5.3830969E-05,   4.8847611E-05
     +,   4.4316854E-05,   4.0205610E-05,   3.6481339E-05
     +,   3.3113454E-05,   3.0072311E-05,   2.7330289E-05
     +,   2.4861027E-05,   2.2640199E-05,   2.0644829E-05
     +,   1.8853883E-05,   1.7247696E-05,   1.5808384E-05
     +,   1.4519353E-05,   1.3365602E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz80 = Yx/0.284170212765957
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7029309E-05,   4.8619968E-05
     +,   5.0239567E-05,   5.1887186E-05,   5.3561816E-05
     +,   5.5262361E-05,   5.6987607E-05,   5.8736296E-05
     +,   6.0506980E-05,   6.2298306E-05,   6.4108666E-05
     +,   6.5936481E-05,   6.7780049E-05,   6.9637608E-05
     +,   7.1507355E-05,   7.3387448E-05,   7.5275966E-05
     +,   7.7171004E-05,   7.9070640E-05,   8.0972895E-05
     +,   8.2875828E-05,   8.4777545E-05,   8.6676177E-05
     +,   8.8569926E-05,   9.0457004E-05,   9.2335809E-05
     +,   9.4204799E-05,   9.6062591E-05,   9.7907934E-05
     +,   9.9739780E-05,   1.0155727E-04,   1.0335985E-04
     +,   1.0514708E-04,   1.0691897E-04,   1.0867571E-04
     +,   1.1041785E-04,   1.1214638E-04,   1.1386259E-04
     +,   1.1556824E-04,   1.1726546E-04,   1.1895696E-04
     +,   1.2064583E-04,   1.2233568E-04,   1.2403069E-04
     +,   1.2573559E-04,   1.2745560E-04,   1.2919650E-04
     +,   1.3096469E-04,   1.3276709E-04,   1.3461115E-04
     +,   1.3650492E-04,   1.3845696E-04,   1.4047620E-04
     +,   1.4257229E-04,   1.4475491E-04,   1.4703447E-04
     +,   1.4942151E-04,   1.5192687E-04,   1.5456147E-04
     +,   1.5733654E-04,   1.6026315E-04,   1.6335254E-04
     +,   1.6661553E-04,   1.7006307E-04,   1.7370604E-04
     +,   1.7755467E-04,   1.8161937E-04,   1.8590999E-04
     +,   1.9043680E-04,   1.9520936E-04,   2.0023798E-04
     +,   2.0553290E-04,   2.1110554E-04,   2.1696753E-04
     +,   2.2313272E-04,   2.2961666E-04,   2.3643720E-04
     +,   2.4361495E-04,   2.5117499E-04,   2.5914656E-04
     +,   2.6756345E-04,   2.7646622E-04,   2.8590052E-04
     +,   2.9592001E-04,   3.0658414E-04,   3.1796106E-04
     +,   3.3012469E-04,   3.4315739E-04,   3.5714597E-04
     +,   3.7218418E-04,   3.8836969E-04,   4.0580245E-04
     +,   4.2458295E-04,   4.4481241E-04,   4.6658923E-04
     +,   4.9000507E-04,   5.1514810E-04,   5.4209476E-04
     +,   5.7091506E-04,   6.0166506E-04,   6.3439202E-04
     +,   6.6912861E-04,   7.0589880E-04,   7.4471236E-04
     +,   7.8557344E-04,   8.2848081E-04,   8.7343279E-04
     +,   9.2044100E-04,   9.6955261E-04,   1.0208843E-03
     +,   1.0746637E-03,   1.1313157E-03,   1.1915460E-03
     +,   1.2564834E-03,   1.3278060E-03,   1.4079204E-03
     +,   1.5001023E-03,   1.6086436E-03,   1.7389018E-03
     +,   1.8972708E-03,   2.0909596E-03,   2.3274950E-03
     +,   2.6139589E-03,   2.9559582E-03,   3.3564535E-03
     +,   3.8147648E-03,   4.3264143E-03,   4.8840023E-03
     +,   5.4798312E-03,   6.1095641E-03,   6.7766076E-03
     +,   7.4950289E-03,   8.2897795E-03,   9.1921249E-03
     +,   1.0231229E-02,   1.1424808E-02,   1.2774796E-02
     +,   1.4272556E-02,   1.5911626E-02,   1.7699273E-02
     +,   1.9657087E-02,   2.1805428E-02,   2.4137700E-02
     +,   2.6597261E-02,   2.9062059E-02,   3.1334139E-02
     +,   3.3156693E-02,   3.4313213E-02,   3.4789804E-02
     +,   3.4833472E-02,   3.4768205E-02,   3.4713395E-02
     +,   3.4509212E-02,   3.3919457E-02,   3.2862935E-02
     +,   3.1460885E-02,   2.9930016E-02,   2.8446123E-02
     +,   2.7046740E-02,   2.5613384E-02,   2.3964791E-02
     +,   2.2014162E-02,   1.9861061E-02,   1.7734636E-02
     +,   1.5843334E-02,   1.4265941E-02,   1.2953611E-02
     +,   1.1805446E-02,   1.0740845E-02,   9.7279316E-03
     +,   8.7741995E-03,   7.9036523E-03,   7.1376697E-03
     +,   6.4854836E-03,   5.9429947E-03,   5.4967119E-03
     +,   5.1297923E-03,   4.8271879E-03,   4.5783371E-03
     +,   4.3773032E-03,   4.2212727E-03,   4.1085584E-03
     +,   4.0369392E-03,   4.0027620E-03,   4.0007355E-03
     +,   4.0241675E-03,   4.0654684E-03,   4.1167140E-03
     +,   4.1701901E-03,   4.2188368E-03,   4.2566266E-03
     +,   4.2787907E-03,   4.2819465E-03,   4.2641591E-03
     +,   4.2248508E-03,   4.1647004E-03,   4.0854313E-03
     +,   3.9895852E-03,   3.8802209E-03,   3.7606449E-03
     +,   3.6341436E-03,   3.5037550E-03,   3.3721083E-03
     +,   3.2413416E-03,   3.1131110E-03,   2.9886260E-03
     +,   2.8687331E-03,   2.7540259E-03,   2.6449130E-03
     +,   2.5416790E-03,   2.4445152E-03,   2.3535364E-03
     +,   2.2687593E-03,   2.1900916E-03,   2.1173195E-03
     +,   2.0501190E-03,   1.9880591E-03,   1.9306218E-03
     +,   1.8772391E-03,   1.8273267E-03,   1.7803075E-03
     +,   1.7356357E-03,   1.6928170E-03,   1.6514154E-03
     +,   1.6110464E-03,   1.5713776E-03,   1.5321256E-03
     +,   1.4930448E-03,   1.4539151E-03,   1.4145484E-03
     +,   1.3747826E-03,   1.3344859E-03,   1.2935520E-03
     +,   1.2519095E-03,   1.2095311E-03,   1.1664235E-03
     +,   1.1226366E-03,   1.0782619E-03,   1.0334293E-03
     +,   9.8829914E-04,   9.4305573E-04,   8.9790567E-04
     +,   8.5306610E-04,   8.0875296E-04,   7.6517661E-04
     +,   7.2254002E-04,   6.8102783E-04,   6.4080005E-04
     +,   6.0199469E-04,   5.6472595E-04,   5.2907929E-04
     +,   4.9511477E-04,   4.6287023E-04,   4.3236095E-04
     +,   4.0358052E-04,   3.7650537E-04,   3.5109857E-04
     +,   3.2731070E-04,   3.0508178E-04,   2.8434407E-04
     +,   2.6502652E-04,   2.4705453E-04,   2.3035094E-04
     +,   2.1483834E-04,   2.0044208E-04,   1.8708792E-04
     +,   1.7470426E-04,   1.6322358E-04,   1.5258156E-04
     +,   1.4271693E-04,   1.3357212E-04,   1.2509389E-04
     +,   1.1723256E-04,   1.0994118E-04,   1.0317628E-04
     +,   9.6898118E-05,   9.1068898E-05,   8.5654348E-05
     +,   8.0622071E-05,   7.5942633E-05,   7.1588154E-05
     +,   6.7533460E-05,   6.3754691E-05,   6.0230388E-05
     +,   5.6940269E-05,   5.3866101E-05,   5.0990817E-05
     +,   4.8298785E-05,   4.5775971E-05,   4.3409178E-05
     +,   4.1186671E-05,   3.9097507E-05,   3.7131955E-05
     +,   3.5280918E-05,   3.3536377E-05,   3.1890802E-05
     +,   3.0337549E-05,   2.8870400E-05,   2.7483864E-05
     +,   2.6172753E-05,   2.4932502E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz85 = Yx/0.278510638297872
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2724721E-05,   5.4572218E-05
     +,   5.6452591E-05,   5.8363872E-05,   6.0303948E-05
     +,   6.2270534E-05,   6.4261178E-05,   6.6273278E-05
     +,   6.8304042E-05,   7.0350696E-05,   7.2410199E-05
     +,   7.4479460E-05,   7.6555269E-05,   7.8634344E-05
     +,   8.0713377E-05,   8.2788953E-05,   8.4857689E-05
     +,   8.6916145E-05,   8.8960936E-05,   9.0988658E-05
     +,   9.2996008E-05,   9.4979761E-05,   9.6936717E-05
     +,   9.8864017E-05,   1.0075864E-04,   1.0261800E-04
     +,   1.0443960E-04,   1.0622117E-04,   1.0796079E-04
     +,   1.0965665E-04,   1.1130737E-04,   1.1291197E-04
     +,   1.1446968E-04,   1.1598018E-04,   1.1744361E-04
     +,   1.1886048E-04,   1.2023184E-04,   1.2155915E-04
     +,   1.2284449E-04,   1.2409035E-04,   1.2529991E-04
     +,   1.2647675E-04,   1.2762522E-04,   1.2875011E-04
     +,   1.2985688E-04,   1.3095162E-04,   1.3204091E-04
     +,   1.3313195E-04,   1.3423254E-04,   1.3535094E-04
     +,   1.3649595E-04,   1.3767670E-04,   1.3890288E-04
     +,   1.4018430E-04,   1.4153117E-04,   1.4295369E-04
     +,   1.4446219E-04,   1.4606687E-04,   1.4777780E-04
     +,   1.4960468E-04,   1.5155680E-04,   1.5364280E-04
     +,   1.5587051E-04,   1.5824716E-04,   1.6077873E-04
     +,   1.6347012E-04,   1.6632515E-04,   1.6934593E-04
     +,   1.7253368E-04,   1.7588762E-04,   1.7940602E-04
     +,   1.8308513E-04,   1.8692030E-04,   1.9090502E-04
     +,   1.9503209E-04,   1.9929302E-04,   2.0367852E-04
     +,   2.0817858E-04,   2.1278321E-04,   2.1748264E-04
     +,   2.2226697E-04,   2.2712779E-04,   2.3205747E-04
     +,   2.3705057E-04,   2.4210323E-04,   2.4721469E-04
     +,   2.5238661E-04,   2.5762440E-04,   2.6293646E-04
     +,   2.6833566E-04,   2.7383870E-04,   2.7946601E-04
     +,   2.8524213E-04,   2.9119579E-04,   2.9735957E-04
     +,   3.0376905E-04,   3.1046305E-04,   3.1748251E-04
     +,   3.2487095E-04,   3.3267200E-04,   3.4093109E-04
     +,   3.4969157E-04,   3.5899767E-04,   3.6888997E-04
     +,   3.7940784E-04,   3.9058746E-04,   4.0246148E-04
     +,   4.1505849E-04,   4.2840510E-04,   4.4252590E-04
     +,   4.5744242E-04,   4.7317991E-04,   4.8976572E-04
     +,   5.0723652E-04,   5.2564096E-04,   5.4504961E-04
     +,   5.6555792E-04,   5.8730226E-04,   6.1046315E-04
     +,   6.3528342E-04,   6.6207821E-04,   6.9124508E-04
     +,   7.2327675E-04,   7.5877382E-04,   7.9844752E-04
     +,   8.4311597E-04,   8.9370710E-04,   9.5123018E-04
     +,   1.0167573E-03,   1.0913681E-03,   1.1761039E-03
     +,   1.2718725E-03,   1.3793893E-03,   1.4990591E-03
     +,   1.6309350E-03,   1.7746765E-03,   1.9295851E-03
     +,   2.0947456E-03,   2.2692983E-03,   2.4527868E-03
     +,   2.6456034E-03,   2.8494706E-03,   3.0679496E-03
     +,   3.3068804E-03,   3.5747634E-03,   3.8831369E-03
     +,   4.2466288E-03,   4.6824436E-03,   5.2088336E-03
     +,   5.8422503E-03,   6.5930937E-03,   7.4609127E-03
     +,   8.4310174E-03,   9.4748912E-03,   1.0556442E-02
     +,   1.1644039E-02,   1.2724061E-02,   1.3808266E-02
     +,   1.4929201E-02,   1.6125334E-02,   1.7425098E-02
     +,   1.8835215E-02,   2.0332254E-02,   2.1858925E-02
     +,   2.3338020E-02,   2.4710713E-02,   2.5966574E-02
     +,   2.7115429E-02,   2.8105538E-02,   2.8777165E-02
     +,   2.8926734E-02,   2.8445655E-02,   2.7408872E-02
     +,   2.6037855E-02,   2.4585515E-02,   2.3251526E-02
     +,   2.2179678E-02,   2.1481782E-02,   2.1215668E-02
     +,   2.1325652E-02,   2.1618253E-02,   2.1819759E-02
     +,   2.1687217E-02,   2.1102998E-02,   2.0101998E-02
     +,   1.8831939E-02,   1.7481821E-02,   1.6218381E-02
     +,   1.5149465E-02,   1.4314395E-02,   1.3693026E-02
     +,   1.3226354E-02,   1.2840324E-02,   1.2465364E-02
     +,   1.2048976E-02,   1.1561790E-02,   1.0998542E-02
     +,   1.0373782E-02,   9.7135548E-03,   9.0461066E-03
     +,   8.3954390E-03,   7.7789328E-03,   7.2078947E-03
     +,   6.6886623E-03,   6.2230914E-03,   5.8086202E-03
     +,   5.4391893E-03,   5.1073148E-03,   4.8065647E-03
     +,   4.5334809E-03,   4.2881677E-03,   4.0733507E-03
     +,   3.8925863E-03,   3.7483270E-03,   3.6406065E-03
     +,   3.5664837E-03,   3.5202657E-03,   3.4942713E-03
     +,   3.4798658E-03,   3.4684991E-03,   3.4525935E-03
     +,   3.4261667E-03,   3.3851836E-03,   3.3275995E-03
     +,   3.2531722E-03,   3.1631126E-03,   3.0596349E-03
     +,   2.9455160E-03,   2.8236841E-03,   2.6969141E-03
     +,   2.5676528E-03,   2.4379049E-03,   2.3092278E-03
     +,   2.1827761E-03,   2.0593926E-03,   1.9396681E-03
     +,   1.8240288E-03,   1.7127991E-03,   1.6062350E-03
     +,   1.5045356E-03,   1.4078572E-03,   1.3163122E-03
     +,   1.2299597E-03,   1.1487865E-03,   1.0727132E-03
     +,   1.0015960E-03,   9.3522784E-04,   8.7334408E-04
     +,   8.1564073E-04,   7.6179736E-04,   7.1147905E-04
     +,   6.6435710E-04,   6.2012649E-04,   5.7850726E-04
     +,   5.3925178E-04,   5.0214917E-04,   4.6702605E-04
     +,   4.3374323E-04,   4.0218956E-04,   3.7227906E-04
     +,   3.4394863E-04,   3.1714982E-04,   2.9184300E-04
     +,   2.6799564E-04,   2.4558025E-04,   2.2456751E-04
     +,   2.0492663E-04,   1.8662504E-04,   1.6962629E-04
     +,   1.5388813E-04,   1.3936438E-04,   1.2600563E-04
     +,   1.1375872E-04,   1.0256650E-04,   9.2369875E-05
     +,   8.3108956E-05,   7.4721822E-05,   6.7147594E-05
     +,   6.0324994E-05,   5.4194825E-05,   4.8698854E-05
     +,   4.3781816E-05,   3.9390339E-05,   3.5474575E-05
     +,   3.1987183E-05,   2.8884569E-05,   2.6126059E-05
     +,   2.3674316E-05,   2.1495473E-05,   1.9558483E-05
     +,   1.7835593E-05,   1.6301643E-05,   1.4934350E-05
     +,   1.3713706E-05,   1.2622161E-05,   1.1644062E-05
     +,   1.0765785E-05,   9.9752515E-06,   9.2619939E-06
     +,   8.6167829E-06,   8.0316422E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz90 = Yx/0.270468085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A2016N_tt_hzonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5847875E-05,   4.7243815E-05
     +,   4.8681537E-05,   5.0161623E-05,   5.1684510E-05
     +,   5.3250475E-05,   5.4859593E-05,   5.6511759E-05
     +,   5.8206613E-05,   5.9943675E-05,   6.1722109E-05
     +,   6.3540829E-05,   6.5398563E-05,   6.7293695E-05
     +,   6.9224334E-05,   7.1188319E-05,   7.3183175E-05
     +,   7.5206168E-05,   7.7254241E-05,   7.9324047E-05
     +,   8.1411992E-05,   8.3514205E-05,   8.5626503E-05
     +,   8.7744666E-05,   8.9863934E-05,   9.1979695E-05
     +,   9.4086950E-05,   9.6180687E-05,   9.8255761E-05
     +,   1.0030695E-04,   1.0232905E-04,   1.0431684E-04
     +,   1.0626528E-04,   1.0816928E-04,   1.1002406E-04
     +,   1.1182504E-04,   1.1356788E-04,   1.1524857E-04
     +,   1.1686359E-04,   1.1840971E-04,   1.1988440E-04
     +,   1.2128554E-04,   1.2261169E-04,   1.2386209E-04
     +,   1.2503687E-04,   1.2613666E-04,   1.2716325E-04
     +,   1.2811915E-04,   1.2900791E-04,   1.2983409E-04
     +,   1.3060337E-04,   1.3132236E-04,   1.3199903E-04
     +,   1.3264232E-04,   1.3326250E-04,   1.3387094E-04
     +,   1.3448039E-04,   1.3510465E-04,   1.3575876E-04
     +,   1.3645907E-04,   1.3722290E-04,   1.3806883E-04
     +,   1.3901629E-04,   1.4008580E-04,   1.4129870E-04
     +,   1.4267693E-04,   1.4424318E-04,   1.4602041E-04
     +,   1.4803198E-04,   1.5030107E-04,   1.5285109E-04
     +,   1.5570452E-04,   1.5888375E-04,   1.6240973E-04
     +,   1.6630266E-04,   1.7058120E-04,   1.7526226E-04
     +,   1.8036045E-04,   1.8588849E-04,   1.9185670E-04
     +,   1.9827207E-04,   2.0513931E-04,   2.1245927E-04
     +,   2.2023026E-04,   2.2844647E-04,   2.3709949E-04
     +,   2.4617670E-04,   2.5566301E-04,   2.6553942E-04
     +,   2.7578461E-04,   2.8637506E-04,   2.9728434E-04
     +,   3.0848436E-04,   3.1994682E-04,   3.3164280E-04
     +,   3.4354275E-04,   3.5561953E-04,   3.6784631E-04
     +,   3.8020016E-04,   3.9266000E-04,   4.0520992E-04
     +,   4.1783703E-04,   4.3053462E-04,   4.4329965E-04
     +,   4.5613476E-04,   4.6904833E-04,   4.8205198E-04
     +,   4.9516081E-04,   5.0839508E-04,   5.2177563E-04
     +,   5.3532433E-04,   5.4906379E-04,   5.6301442E-04
     +,   5.7719427E-04,   5.9161813E-04,   6.0629728E-04
     +,   6.2123727E-04,   6.3644192E-04,   6.5190898E-04
     +,   6.6763605E-04,   6.8362057E-04,   6.9986138E-04
     +,   7.1636186E-04,   7.3313573E-04,   7.5020920E-04
     +,   7.6762348E-04,   7.8544114E-04,   8.0374698E-04
     +,   8.2265440E-04,   8.4230269E-04,   8.6286332E-04
     +,   8.8453369E-04,   9.0753939E-04,   9.3212666E-04
     +,   9.5855811E-04,   9.8710519E-04,   1.0180353E-03
     +,   1.0516053E-03,   1.0880495E-03,   1.1275719E-03
     +,   1.1703350E-03,   1.2164576E-03,   1.2660227E-03
     +,   1.3190797E-03,   1.3756509E-03,   1.4357651E-03
     +,   1.4994764E-03,   1.5668795E-03,   1.6381444E-03
     +,   1.7135291E-03,   1.7933927E-03,   1.8781666E-03
     +,   1.9683433E-03,   2.0644478E-03,   2.1669734E-03
     +,   2.2763526E-03,   2.3929100E-03,   2.5168872E-03
     +,   2.6484274E-03,   2.7875984E-03,   2.9344268E-03
     +,   3.0888554E-03,   3.2506348E-03,   3.4192179E-03
     +,   3.5935855E-03,   3.7721726E-03,   3.9529381E-03
     +,   4.1337549E-03,   4.3130829E-03,   4.4909562E-03
     +,   4.6701627E-03,   4.8576193E-03,   5.0658397E-03
     +,   5.3144181E-03,   5.6309006E-03,   6.0500214E-03
     +,   6.6093807E-03,   7.3407535E-03,   8.2591716E-03
     +,   9.3563152E-03,   1.0607268E-02,   1.1995777E-02
     +,   1.3549162E-02,   1.5353987E-02,   1.7518779E-02
     +,   2.0082472E-02,   2.2928933E-02,   2.5800383E-02
     +,   2.8438309E-02,   3.0745337E-02,   3.2798339E-02
     +,   3.4686435E-02,   3.6359485E-02,   3.7638206E-02
     +,   3.8318798E-02,   3.8275238E-02,   3.7574403E-02
     +,   3.6542762E-02,   3.5621937E-02,   3.5049822E-02
     +,   3.4678254E-02,   3.4131177E-02,   3.3113535E-02
     +,   3.1544983E-02,   2.9478572E-02,   2.7018806E-02
     +,   2.4345236E-02,   2.1730419E-02,   1.9452542E-02
     +,   1.7661408E-02,   1.6319346E-02,   1.5259822E-02
     +,   1.4305911E-02,   1.3358464E-02,   1.2410132E-02
     +,   1.1504083E-02,   1.0682640E-02,   9.9585438E-03
     +,   9.3142493E-03,   8.7178387E-03,   8.1406236E-03
     +,   7.5681442E-03,   7.0021464E-03,   6.4560287E-03
     +,   5.9475675E-03,   5.4922253E-03,   5.0989119E-03
     +,   4.7685788E-03,   4.4951946E-03,   4.2681224E-03
     +,   4.0748562E-03,   3.9033294E-03,   3.7434637E-03
     +,   3.5878678E-03,   3.4318855E-03,   3.2731534E-03
     +,   3.1110311E-03,   2.9460383E-03,   2.7793606E-03
     +,   2.6125084E-03,   2.4470864E-03,   2.2846661E-03
     +,   2.1266735E-03,   1.9743245E-03,   1.8285888E-03
     +,   1.6901961E-03,   1.5596161E-03,   1.4370680E-03
     +,   1.3225687E-03,   1.2159749E-03,   1.1170033E-03
     +,   1.0252866E-03,   9.4041269E-04,   8.6194667E-04
     +,   7.8944856E-04,   7.2249217E-04,   6.6067599E-04
     +,   6.0362415E-04,   5.5098295E-04,   5.0242577E-04
     +,   4.5765433E-04,   4.1639415E-04,   3.7839098E-04
     +,   3.4341324E-04,   3.1125217E-04,   2.8171443E-04
     +,   2.5462316E-04,   2.2981687E-04,   2.0714554E-04
     +,   1.8646676E-04,   1.6764557E-04,   1.5055419E-04
     +,   1.3506916E-04,   1.2106997E-04,   1.0844022E-04
     +,   9.7068470E-05,   8.6846201E-05,   7.7670957E-05
     +,   6.9444424E-05,   6.2075233E-05,   5.5477260E-05
     +,   4.9571816E-05,   4.4286058E-05,   3.9554463E-05
     +,   3.5317298E-05,   3.1521577E-05,   2.8119628E-05
     +,   2.5069168E-05,   2.2333037E-05,   1.9878044E-05
     +,   1.7675193E-05,   1.5698572E-05,   1.3925509E-05
     +,   1.2335659E-05,   1.0911118E-05,   9.6357126E-06
     +,   8.4951043E-06,   7.4762388E-06,   6.5674549E-06
     +,   5.7580651E-06,   5.0384651E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A2016N_tt_hzonly_ttz95 = Yx/0.293702127659574
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0413077E-06,   9.2191549E-06
     +,   9.3958615E-06,   9.5714258E-06,   9.7458660E-06
     +,   9.9192248E-06,   1.0091564E-05,   1.0262970E-05
     +,   1.0433547E-05,   1.0603436E-05,   1.0772792E-05
     +,   1.0941803E-05,   1.1110681E-05,   1.1279671E-05
     +,   1.1449042E-05,   1.1619105E-05,   1.1790185E-05
     +,   1.1962659E-05,   1.2136927E-05,   1.2313425E-05
     +,   1.2492624E-05,   1.2675036E-05,   1.2861209E-05
     +,   1.3051735E-05,   1.3247222E-05,   1.3448349E-05
     +,   1.3655814E-05,   1.3870361E-05,   1.4092771E-05
     +,   1.4323868E-05,   1.4564501E-05,   1.4815578E-05
     +,   1.5078024E-05,   1.5352805E-05,   1.5640917E-05
     +,   1.5943389E-05,   1.6261276E-05,   1.6595650E-05
     +,   1.6947624E-05,   1.7318307E-05,   1.7708848E-05
     +,   1.8120401E-05,   1.8554138E-05,   1.9011251E-05
     +,   1.9492951E-05,   2.0000472E-05,   2.0535092E-05
     +,   2.1098122E-05,   2.1690923E-05,   2.2314949E-05
     +,   2.2971763E-05,   2.3663031E-05,   2.4390600E-05
     +,   2.5156558E-05,   2.5963176E-05,   2.6813137E-05
     +,   2.7709439E-05,   2.8655546E-05,   2.9655448E-05
     +,   3.0713745E-05,   3.1835705E-05,   3.3027412E-05
     +,   3.4295663E-05,   3.5648307E-05,   3.7094160E-05
     +,   3.8642916E-05,   4.0305491E-05,   4.2093656E-05
     +,   4.4020413E-05,   4.6099500E-05,   4.8345770E-05
     +,   5.0774557E-05,   5.3402080E-05,   5.6244644E-05
     +,   5.9318987E-05,   6.2641833E-05,   6.6229390E-05
     +,   7.0097303E-05,   7.4260686E-05,   7.8733741E-05
     +,   8.3529034E-05,   8.8658620E-05,   9.4132549E-05
     +,   9.9960431E-05,   1.0615002E-04,   1.1270909E-04
     +,   1.1964393E-04,   1.2696169E-04,   1.3466857E-04
     +,   1.4277226E-04,   1.5128132E-04,   1.6020511E-04
     +,   1.6955404E-04,   1.7934080E-04,   1.8957895E-04
     +,   2.0028165E-04,   2.1146316E-04,   2.2313507E-04
     +,   2.3530763E-04,   2.4798512E-04,   2.6116797E-04
     +,   2.7484589E-04,   2.8900127E-04,   3.0360257E-04
     +,   3.1860615E-04,   3.3395429E-04,   3.4957283E-04
     +,   3.6537193E-04,   3.8124830E-04,   3.9708498E-04
     +,   4.1275207E-04,   4.2811289E-04,   4.4302337E-04
     +,   4.5734071E-04,   4.7092262E-04,   4.8363674E-04
     +,   4.9536122E-04,   5.0599215E-04,   5.1544473E-04
     +,   5.2365998E-04,   5.3060427E-04,   5.3627335E-04
     +,   5.4069160E-04,   5.4391479E-04,   5.4602721E-04
     +,   5.4714188E-04,   5.4739817E-04,   5.4695993E-04
     +,   5.4601283E-04,   5.4476183E-04,   5.4342655E-04
     +,   5.4224097E-04,   5.4144574E-04,   5.4128689E-04
     +,   5.4200826E-04,   5.4384791E-04,   5.4702978E-04
     +,   5.5175595E-04,   5.5820000E-04,   5.6649727E-04
     +,   5.7673489E-04,   5.8894488E-04,   6.0309831E-04
     +,   6.1909913E-04,   6.3678029E-04,   6.5590831E-04
     +,   6.7618949E-04,   6.9727493E-04,   7.1878178E-04
     +,   7.4031204E-04,   7.6147798E-04,   7.8193174E-04
     +,   8.0140220E-04,   8.1973377E-04,   8.3692814E-04
     +,   8.5318653E-04,   8.6895522E-04,   8.8496425E-04
     +,   9.0225920E-04,   9.2220813E-04,   9.4649382E-04
     +,   9.7705342E-04,   1.0159720E-03,   1.0653097E-03
     +,   1.1268784E-03,   1.2019636E-03,   1.2910188E-03
     +,   1.3934084E-03,   1.5072386E-03,   1.6293318E-03
     +,   1.7554082E-03,   1.8805088E-03,   1.9996278E-03
     +,   2.1084575E-03,   2.2041413E-03,   2.2859185E-03
     +,   2.3554182E-03,   2.4165455E-03,   2.4749092E-03
     +,   2.5367979E-03,   2.6079151E-03,   2.6920601E-03
     +,   2.7900946E-03,   2.8994640E-03,   3.0144078E-03
     +,   3.1269395E-03,   3.2284320E-03,   3.3115991E-03
     +,   3.3724566E-03,   3.4121291E-03,   3.4383901E-03
     +,   3.4670965E-03,   3.5235279E-03,   3.6430240E-03
     +,   3.8701114E-03,   4.2567663E-03,   4.8642056E-03
     +,   5.7718195E-03,   7.0875916E-03,   8.9654895E-03
     +,   1.1715587E-02,   1.6079700E-02,   2.3108263E-02
     +,   3.3575848E-02,   5.0310548E-02,   7.6990113E-02
     +,   0.1136680    ,   0.1603492    ,   0.2146974    
     +,   0.2561395    ,   0.2557161    ,   0.2124869    
     +,   0.1515416    ,   9.9074662E-02,   6.1546165E-02
     +,   3.6270101E-02,   2.0992516E-02,   1.2559889E-02
     +,   7.8998562E-03,   5.0640861E-03,   3.2377592E-03
     +,   2.0925216E-03,   1.4044888E-03,   9.9264504E-04
     +,   7.3574769E-04,   5.6596106E-04,   4.4776424E-04
     +,   3.6194088E-04,   2.9751175E-04,   2.4791819E-04
     +,   2.0903052E-04,   1.7807768E-04,   1.5310437E-04
     +,   1.3270145E-04,   1.1585269E-04,   1.0182227E-04
     +,   9.0071924E-05,   8.0195430E-05,   7.1871516E-05
     +,   6.4834858E-05,   5.8860958E-05,   5.3758387E-05
     +,   4.9364142E-05,   4.5540884E-05,   4.2175012E-05
     +,   3.9174403E-05,   3.6465510E-05,   3.3990527E-05
     +,   3.1705022E-05,   2.9575685E-05,   2.7577687E-05
     +,   2.5693056E-05,   2.3909151E-05,   2.2217197E-05
     +,   2.0611100E-05,   1.9086718E-05,   1.7641287E-05
     +,   1.6272816E-05,   1.4979641E-05,   1.3760256E-05
     +,   1.2613239E-05,   1.1537039E-05,   1.0529859E-05
     +,   9.5897121E-06,   8.7145081E-06,   7.9018791E-06
     +,   7.1493087E-06,   6.4542032E-06,   5.8138617E-06
     +,   5.2254750E-06,   4.6862010E-06,   4.1932258E-06
     +,   3.7437405E-06,   3.3349393E-06,   2.9640782E-06
     +,   2.6285147E-06,   2.3256446E-06,   2.0529976E-06
     +,   1.8081686E-06,   1.5888958E-06,   1.3930016E-06
     +,   1.2184529E-06,   1.0633125E-06,   9.2578426E-07
     +,   8.0417442E-07,   6.9692294E-07,   6.0257361E-07
     +,   5.1978475E-07,   4.4733034E-07,   3.8407859E-07
     +,   3.2900527E-07,   2.8117182E-07,   2.3973516E-07
     +,   2.0392855E-07,   1.7306753E-07,   1.4653455E-07
     +,   1.2378167E-07,   1.0431818E-07,   8.7711470E-08
     +,   7.3576786E-08,   6.1577026E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_hatt100 = Yx/0.46312
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8596784E-05,   1.9051562E-05
     +,   1.9506941E-05,   1.9962990E-05,   2.0419855E-05
     +,   2.0877742E-05,   2.1336944E-05,   2.1797840E-05
     +,   2.2260885E-05,   2.2726656E-05,   2.3195795E-05
     +,   2.3669058E-05,   2.4147303E-05,   2.4631490E-05
     +,   2.5122697E-05,   2.5622106E-05,   2.6131005E-05
     +,   2.6650812E-05,   2.7183049E-05,   2.7729337E-05
     +,   2.8291433E-05,   2.8871189E-05,   2.9470557E-05
     +,   3.0091633E-05,   3.0736537E-05,   3.1407570E-05
     +,   3.2107055E-05,   3.2837423E-05,   3.3601169E-05
     +,   3.4400848E-05,   3.5239067E-05,   3.6118476E-05
     +,   3.7041744E-05,   3.8011556E-05,   3.9030580E-05
     +,   4.0101484E-05,   4.1226889E-05,   4.2409320E-05
     +,   4.3651333E-05,   4.4955206E-05,   4.6323275E-05
     +,   4.7757640E-05,   4.9260230E-05,   5.0832805E-05
     +,   5.2476909E-05,   5.4193835E-05,   5.5984601E-05
     +,   5.7849978E-05,   5.9790360E-05,   6.1805862E-05
     +,   6.3896223E-05,   6.6060798E-05,   6.8298512E-05
     +,   7.0608083E-05,   7.2987437E-05,   7.5434466E-05
     +,   7.7946410E-05,   8.0520105E-05,   8.3152030E-05
     +,   8.5838190E-05,   8.8574241E-05,   9.1355469E-05
     +,   9.4176692E-05,   9.7032607E-05,   9.9917728E-05
     +,   1.0282602E-04,   1.0575171E-04,   1.0868860E-04
     +,   1.1163090E-04,   1.1457247E-04,   1.1750786E-04
     +,   1.2043138E-04,   1.2333838E-04,   1.2622410E-04
     +,   1.2908498E-04,   1.3191791E-04,   1.3472076E-04
     +,   1.3749240E-04,   1.4023294E-04,   1.4294394E-04
     +,   1.4562807E-04,   1.4828985E-04,   1.5093520E-04
     +,   1.5357221E-04,   1.5621042E-04,   1.5886176E-04
     +,   1.6153992E-04,   1.6426110E-04,   1.6704322E-04
     +,   1.6990684E-04,   1.7287466E-04,   1.7597142E-04
     +,   1.7922423E-04,   1.8266229E-04,   1.8631687E-04
     +,   1.9022093E-04,   1.9440944E-04,   1.9891847E-04
     +,   2.0378573E-04,   2.0904906E-04,   2.1474762E-04
     +,   2.2091964E-04,   2.2760365E-04,   2.3483632E-04
     +,   2.4265304E-04,   2.5108698E-04,   2.6016781E-04
     +,   2.6992103E-04,   2.8036875E-04,   2.9152792E-04
     +,   3.0340906E-04,   3.1601786E-04,   3.2935277E-04
     +,   3.4340724E-04,   3.5816710E-04,   3.7361411E-04
     +,   3.8972244E-04,   4.0646413E-04,   4.2380524E-04
     +,   4.4171029E-04,   4.6014262E-04,   4.7906311E-04
     +,   4.9843278E-04,   5.1821547E-04,   5.3837622E-04
     +,   5.5888097E-04,   5.7970075E-04,   6.0080976E-04
     +,   6.2218867E-04,   6.4382469E-04,   6.6571927E-04
     +,   6.8788911E-04,   7.1037741E-04,   7.3326059E-04
     +,   7.5666670E-04,   7.8078866E-04,   8.0590206E-04
     +,   8.3238858E-04,   8.6075976E-04,   8.9167478E-04
     +,   9.2595693E-04,   9.6460234E-04,   1.0087783E-03
     +,   1.0598018E-03,   1.1190871E-03,   1.1880883E-03
     +,   1.2681937E-03,   1.3605921E-03,   1.4661312E-03
     +,   1.5851717E-03,   1.7174344E-03,   1.8618772E-03
     +,   2.0166507E-03,   2.1791346E-03,   2.3460356E-03
     +,   2.5135931E-03,   2.6778635E-03,   2.8350623E-03
     +,   2.9818970E-03,   3.1158340E-03,   3.2353573E-03
     +,   3.3400711E-03,   3.4307078E-03,   3.5090670E-03
     +,   3.5778864E-03,   3.6406524E-03,   3.7014014E-03
     +,   3.7645106E-03,   3.8344606E-03,   3.9155530E-03
     +,   4.0115793E-03,   4.1254610E-03,   4.2589041E-03
     +,   4.4120508E-03,   4.5832312E-03,   4.7689728E-03
     +,   4.9641291E-03,   5.1623215E-03,   5.3566541E-03
     +,   5.5405693E-03,   5.7087499E-03,   5.8577764E-03
     +,   5.9865150E-03,   6.0959673E-03,   6.1887135E-03
     +,   6.2681390E-03,   6.3379565E-03,   6.4021503E-03
     +,   6.4656297E-03,   6.5349643E-03,   6.6188136E-03
     +,   6.7272014E-03,   6.8695950E-03,   7.0527019E-03
     +,   7.2791763E-03,   7.5485064E-03,   7.8597469E-03
     +,   8.2143340E-03,   8.6159743E-03,   9.0659307E-03
     +,   9.5553752E-03,   1.0060669E-02,   1.0547056E-02
     +,   1.0982045E-02,   1.1357093E-02,   1.1723012E-02
     +,   1.2241445E-02,   1.3210540E-02,   1.4990604E-02
     +,   1.7831519E-02,   2.1783696E-02,   2.7252596E-02
     +,   3.6843702E-02,   5.6432907E-02,   9.1394998E-02
     +,   0.1464785    ,   0.2200772    ,   0.2760095    
     +,   0.2598557    ,   0.1764925    ,   8.9300580E-02
     +,   3.5474811E-02,   1.1391955E-02,   3.2009941E-03
     +,   9.3603093E-04,   3.7832221E-04,   2.4392072E-04
     +,   1.9855102E-04,   1.7137700E-04,   1.4813276E-04
     +,   1.2608348E-04,   1.0593465E-04,   8.8480665E-05
     +,   7.3676572E-05,   6.1058287E-05,   5.0228860E-05
     +,   4.1004459E-05,   3.3329881E-05,   2.7155516E-05
     +,   2.2371354E-05,   1.8802601E-05,   1.6236383E-05
     +,   1.4453708E-05,   1.3254140E-05,   1.2469560E-05
     +,   1.1968210E-05,   1.1652409E-05,   1.1453148E-05
     +,   1.1323750E-05,   1.1233861E-05,   1.1164449E-05
     +,   1.1104002E-05,   1.1045824E-05,   1.0986163E-05
     +,   1.0923004E-05,   1.0855339E-05,   1.0782718E-05
     +,   1.0704985E-05,   1.0622141E-05,   1.0534261E-05
     +,   1.0441474E-05,   1.0343928E-05,   1.0241781E-05
     +,   1.0135193E-05,   1.0024350E-05,   9.9094241E-06
     +,   9.7905968E-06,   9.6680606E-06,   9.5420082E-06
     +,   9.4126299E-06,   9.2801156E-06,   9.1446655E-06
     +,   9.0064850E-06,   8.8657680E-06,   8.7227081E-06
     +,   8.5775146E-06,   8.4303765E-06,   8.2814995E-06
     +,   8.1310709E-06,   7.9792953E-06,   7.8263538E-06
     +,   7.6724455E-06,   7.5177486E-06,   7.3624547E-06
     +,   7.2067337E-06,   7.0507731E-06,   6.8947356E-06
     +,   6.7387864E-06,   6.5830959E-06,   6.4278138E-06
     +,   6.2731006E-06,   6.1190940E-06,   5.9659478E-06
     +,   5.8137853E-06,   5.6627491E-06,   5.5129535E-06
     +,   5.3645276E-06,   5.2175747E-06,   5.0722119E-06
     +,   4.9285309E-06,   4.7866361E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_hatt102 = Yx/0.4347
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4302248E-05,   3.5183599E-05
     +,   3.6058700E-05,   3.6926322E-05,   3.7785405E-05
     +,   3.8635029E-05,   3.9474515E-05,   4.0303414E-05
     +,   4.1121537E-05,   4.1929092E-05,   4.2726602E-05
     +,   4.3514996E-05,   4.4295688E-05,   4.5070581E-05
     +,   4.5842116E-05,   4.6613306E-05,   4.7387843E-05
     +,   4.8170019E-05,   4.8964852E-05,   4.9778075E-05
     +,   5.0616156E-05,   5.1486313E-05,   5.2396499E-05
     +,   5.3355485E-05,   5.4372631E-05,   5.5458117E-05
     +,   5.6622655E-05,   5.7877602E-05,   5.9234742E-05
     +,   6.0706345E-05,   6.2304905E-05,   6.4043110E-05
     +,   6.5933717E-05,   6.7989356E-05,   7.0222479E-05
     +,   7.2645118E-05,   7.5268821E-05,   7.8104524E-05
     +,   8.1162565E-05,   8.4452236E-05,   8.7982386E-05
     +,   9.1760863E-05,   9.5794938E-05,   1.0009137E-04
     +,   1.0465662E-04,   1.0949723E-04,   1.1462020E-04
     +,   1.2003347E-04,   1.2574662E-04,   1.3177138E-04
     +,   1.3812237E-04,   1.4481808E-04,   1.5188132E-04
     +,   1.5934078E-04,   1.6723054E-04,   1.7559247E-04
     +,   1.8447601E-04,   1.9393933E-04,   2.0405048E-04
     +,   2.1488835E-04,   2.2654419E-04,   2.3912384E-04
     +,   2.5274896E-04,   2.6756222E-04,   2.8373036E-04
     +,   3.0144776E-04,   3.2094569E-04,   3.4249472E-04
     +,   3.6641717E-04,   3.9309068E-04,   4.2296672E-04
     +,   4.5658267E-04,   4.9460150E-04,   5.3785939E-04
     +,   5.8746332E-04,   6.4492587E-04,   7.1234093E-04
     +,   7.9260423E-04,   8.8962086E-04,   1.0084361E-03
     +,   1.1552135E-03,   1.3370842E-03,   1.5618717E-03
     +,   1.8381377E-03,   2.1759067E-03,   2.5888181E-03
     +,   3.0973251E-03,   3.7318696E-03,   4.5326469E-03
     +,   5.5429679E-03,   6.7937034E-03,   8.2850438E-03
     +,   9.9948701E-03,   1.1960004E-02,   1.4403695E-02
     +,   1.7725812E-02,   2.2268398E-02,   2.8201299E-02
     +,   3.5776805E-02,   4.5288149E-02,   5.5925794E-02
     +,   6.5510295E-02,   7.3941030E-02,   8.3404459E-02
     +,   9.3085937E-02,   9.9922776E-02,   0.1010649    
     +,   9.8152786E-02,   9.5224105E-02,   9.1646492E-02
     +,   8.5427925E-02,   7.6287732E-02,   6.7322418E-02
     +,   5.9751179E-02,   5.2144773E-02,   4.5220669E-02
     +,   3.9916154E-02,   3.5189059E-02,   3.0311456E-02
     +,   2.5787087E-02,   2.2285707E-02,   1.9936716E-02
     +,   1.8404607E-02,   1.7250886E-02,   1.6165460E-02
     +,   1.5009694E-02,   1.3783423E-02,   1.2563364E-02
     +,   1.1430373E-02,   1.0424947E-02,   9.5450552E-03
     +,   8.7669585E-03,   8.0645336E-03,   7.4198176E-03
     +,   6.8248888E-03,   6.2787356E-03,   5.7821581E-03
     +,   5.3339987E-03,   4.9302103E-03,   4.5652818E-03
     +,   4.2342972E-03,   3.9340504E-03,   3.6629075E-03
     +,   3.4198521E-03,   3.2034551E-03,   3.0111852E-03
     +,   2.8394547E-03,   2.6840840E-03,   2.5409318E-03
     +,   2.4064754E-03,   2.2781712E-03,   2.1545633E-03
     +,   2.0351557E-03,   1.9201643E-03,   1.8102265E-03
     +,   1.7061346E-03,   1.6086136E-03,   1.5181757E-03
     +,   1.4350697E-03,   1.3592782E-03,   1.2905488E-03
     +,   1.2284587E-03,   1.1724856E-03,   1.1220627E-03
     +,   1.0766191E-03,   1.0356144E-03,   9.9855743E-04
     +,   9.6500869E-04,   9.3457627E-04,   9.0691581E-04
     +,   8.8172517E-04,   8.5873704E-04,   8.3771226E-04
     +,   8.1843761E-04,   8.0072548E-04,   7.8440522E-04
     +,   7.6932326E-04,   7.5534196E-04,   7.4233371E-04
     +,   7.3017902E-04,   7.1876385E-04,   7.0797850E-04
     +,   6.9771329E-04,   6.8785867E-04,   6.7830202E-04
     +,   6.6893146E-04,   6.5963209E-04,   6.5028941E-04
     +,   6.4079015E-04,   6.3102582E-04,   6.2089390E-04
     +,   6.1030092E-04,   5.9916626E-04,   5.8742415E-04
     +,   5.7502510E-04,   5.6193775E-04,   5.4815115E-04
     +,   5.3367473E-04,   5.1853608E-04,   5.0278025E-04
     +,   4.8647105E-04,   4.6968571E-04,   4.5251093E-04
     +,   4.3504237E-04,   4.1738179E-04,   3.9963127E-04
     +,   3.8189095E-04,   3.6425915E-04,   3.4682659E-04
     +,   3.2967568E-04,   3.1287814E-04,   2.9649696E-04
     +,   2.8058342E-04,   2.6517734E-04,   2.5030758E-04
     +,   2.3599446E-04,   2.2224915E-04,   2.0907450E-04
     +,   1.9646673E-04,   1.8441840E-04,   1.7291697E-04
     +,   1.6194710E-04,   1.5149261E-04,   1.4153641E-04
     +,   1.3206054E-04,   1.2304774E-04,   1.1448184E-04
     +,   1.0634788E-04,   9.8631310E-05,   9.1318718E-05
     +,   8.4398162E-05,   7.7858494E-05,   7.1688730E-05
     +,   6.5878317E-05,   6.0417504E-05,   5.5296001E-05
     +,   5.0503324E-05,   4.6029130E-05,   4.1862626E-05
     +,   3.7992340E-05,   3.4406385E-05,   3.1092703E-05
     +,   2.8038839E-05,   2.5231793E-05,   2.2658385E-05
     +,   2.0305475E-05,   1.8159864E-05,   1.6208272E-05
     +,   1.4437607E-05,   1.2835213E-05,   1.1388593E-05
     +,   1.0085692E-05,   8.9150208E-06,   7.8655939E-06
     +,   6.9269267E-06,   6.0891348E-06,   5.3429976E-06
     +,   4.6798932E-06,   4.0917671E-06,   3.5711710E-06
     +,   3.1112741E-06,   2.7058015E-06,   2.3489847E-06
     +,   2.0355728E-06,   1.7608219E-06,   1.5204058E-06
     +,   1.3104211E-06,   1.1273663E-06,   9.6809003E-07
     +,   8.2976118E-07,   7.0984822E-07,   6.0610182E-07
     +,   5.1651824E-07,   4.3931240E-07,   3.7290300E-07
     +,   3.1589812E-07,   2.6706158E-07,   2.2531148E-07
     +,   1.8969122E-07,   1.5936664E-07,   1.3360378E-07
     +,   1.1176508E-07,   9.3292059E-08,   7.7701571E-08
     +,   6.4572454E-08,   5.3541850E-08,   4.4295174E-08
     +,   3.6561676E-08,   3.0109213E-08,   2.4737927E-08
     +,   2.0277595E-08,   1.6582339E-08,   1.3528528E-08
     +,   1.1010802E-08,   8.9402681E-09,   7.2415896E-09
     +,   5.8515361E-09,   4.7167976E-09,   3.7928611E-09
     +,   3.0424177E-09,   2.4344726E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_hatt75 = Yx/0.45108
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.4048615E-06,   9.0521216E-06
     +,   9.7402190E-06,   1.0470487E-05,   1.1244142E-05
     +,   1.2062270E-05,   1.2925799E-05,   1.3835477E-05
     +,   1.4791833E-05,   1.5795231E-05,   1.6845737E-05
     +,   1.7943181E-05,   1.9087114E-05,   2.0276795E-05
     +,   2.1511180E-05,   2.2788927E-05,   2.4108365E-05
     +,   2.5467516E-05,   2.6864105E-05,   2.8295546E-05
     +,   2.9758994E-05,   3.1251355E-05,   3.2769294E-05
     +,   3.4309389E-05,   3.5867946E-05,   3.7441383E-05
     +,   3.9026054E-05,   4.0618390E-05,   4.2215066E-05
     +,   4.3813041E-05,   4.5409677E-05,   4.7002904E-05
     +,   4.8591359E-05,   5.0174465E-05,   5.1752708E-05
     +,   5.3327731E-05,   5.4902481E-05,   5.6481469E-05
     +,   5.8070982E-05,   5.9679005E-05,   6.1315768E-05
     +,   6.2993597E-05,   6.4727166E-05,   6.6533597E-05
     +,   6.8432535E-05,   7.0446142E-05,   7.2599127E-05
     +,   7.4918629E-05,   7.7434073E-05,   8.0176913E-05
     +,   8.3180479E-05,   8.6479376E-05,   9.0109119E-05
     +,   9.4105853E-05,   9.8504992E-05,   1.0334144E-04
     +,   1.0864813E-04,   1.1445534E-04,   1.2079007E-04
     +,   1.2767495E-04,   1.3512735E-04,   1.4315876E-04
     +,   1.5177333E-04,   1.6096827E-04,   1.7073279E-04
     +,   1.8104659E-04,   1.9188195E-04,   2.0320081E-04
     +,   2.1495827E-04,   2.2709963E-04,   2.3956464E-04
     +,   2.5228536E-04,   2.6519093E-04,   2.7820616E-04
     +,   2.9125653E-04,   3.0427004E-04,   3.1717878E-04
     +,   3.2992370E-04,   3.4245913E-04,   3.5475567E-04
     +,   3.6680413E-04,   3.7862302E-04,   3.9026130E-04
     +,   4.0180871E-04,   4.1340006E-04,   4.2522955E-04
     +,   4.3756037E-04,   4.5074630E-04,   4.6525040E-04
     +,   4.8167899E-04,   5.0081965E-04,   5.2369118E-04
     +,   5.5160967E-04,   5.8627251E-04,   6.2985386E-04
     +,   6.8509899E-04,   7.5541809E-04,   8.4489142E-04
     +,   9.5820054E-04,   1.1003594E-03,   1.2763599E-03
     +,   1.4907185E-03,   1.7473282E-03,   2.0498158E-03
     +,   2.4031047E-03,   2.8164396E-03,   3.3080515E-03
     +,   3.9108186E-03,   4.6768608E-03,   5.6778360E-03
     +,   6.9978372E-03,   8.7170675E-03,   1.0883962E-02
     +,   1.3484437E-02,   1.6441904E-02,   1.9686719E-02
     +,   2.3249332E-02,   2.7393354E-02,   3.2860491E-02
     +,   4.0397882E-02,   4.9500588E-02,   6.0315799E-02
     +,   7.5006962E-02,   9.2369922E-02,   0.1086502    
     +,   0.1197094    ,   0.1260790    ,   0.1284886    
     +,   0.1252921    ,   0.1223150    ,   0.1223493    
     +,   0.1141995    ,   9.7195923E-02,   7.8646779E-02
     +,   6.4879909E-02,   5.6656364E-02,   4.9484003E-02
     +,   4.2025588E-02,   3.5281990E-02,   2.9930849E-02
     +,   2.5995549E-02,   2.3127051E-02,   2.0984437E-02
     +,   1.9263746E-02,   1.7658997E-02,   1.5992094E-02
     +,   1.4301548E-02,   1.2744111E-02,   1.1433708E-02
     +,   1.0375863E-02,   9.5079420E-03,   8.7626418E-03
     +,   8.0981301E-03,   7.4955262E-03,   6.9460347E-03
     +,   6.4424002E-03,   5.9768804E-03,   5.5426592E-03
     +,   5.1358920E-03,   4.7564898E-03,   4.4073872E-03
     +,   4.0927217E-03,   3.8156256E-03,   3.5764736E-03
     +,   3.3721942E-03,   3.1968644E-03,   3.0431307E-03
     +,   2.9038847E-03,   2.7735892E-03,   2.6489759E-03
     +,   2.5290058E-03,   2.4143104E-03,   2.3064113E-03
     +,   2.2069311E-03,   2.1170022E-03,   2.0368760E-03
     +,   1.9658117E-03,   1.9021652E-03,   1.8436142E-03
     +,   1.7874936E-03,   1.7311419E-03,   1.6722403E-03
     +,   1.6090613E-03,   1.5406243E-03,   1.4667513E-03
     +,   1.3880193E-03,   1.3056195E-03,   1.2211590E-03
     +,   1.1364605E-03,   1.0533566E-03,   9.7350392E-04
     +,   8.9826272E-04,   8.2862581E-04,   7.6518755E-04
     +,   7.0816185E-04,   6.5743714E-04,   6.1264937E-04
     +,   5.7325541E-04,   5.3860561E-04,   5.0801173E-04
     +,   4.8080084E-04,   4.5634844E-04,   4.3410083E-04
     +,   4.1358892E-04,   3.9442943E-04,   3.7631931E-04
     +,   3.5902680E-04,   3.4238276E-04,   3.2626837E-04
     +,   3.1060344E-04,   2.9533741E-04,   2.8044355E-04
     +,   2.6591014E-04,   2.5173509E-04,   2.3792274E-04
     +,   2.2448211E-04,   2.1142386E-04,   1.9875818E-04
     +,   1.8649487E-04,   1.7464402E-04,   1.6321364E-04
     +,   1.5221028E-04,   1.4164028E-04,   1.3150868E-04
     +,   1.2181880E-04,   1.1257278E-04,   1.0377228E-04
     +,   9.5417687E-05,   8.7507527E-05,   8.0039026E-05
     +,   7.3008479E-05,   6.6410590E-05,   6.0238061E-05
     +,   5.4482069E-05,   4.9132777E-05,   4.4178247E-05
     +,   3.9605162E-05,   3.5399211E-05,   3.1544867E-05
     +,   2.8025352E-05,   2.4823144E-05,   2.1920339E-05
     +,   1.9298617E-05,   1.6939295E-05,   1.4823758E-05
     +,   1.2933725E-05,   1.1251272E-05,   9.7588791E-06
     +,   8.4397043E-06,   7.2777821E-06,   6.2578606E-06
     +,   5.3656090E-06,   4.5876914E-06,   3.9117222E-06
     +,   3.3262340E-06,   2.8207278E-06,   2.3856701E-06
     +,   2.0124155E-06,   1.6931490E-06,   1.4208722E-06
     +,   1.1893612E-06,   9.9308704E-07,   8.2715371E-07
     +,   6.8725825E-07,   5.6964609E-07,   4.7103063E-07
     +,   3.8856098E-07,   3.1977606E-07,   2.6255447E-07
     +,   2.1507149E-07,   1.7576725E-07,   1.4331486E-07
     +,   1.1658627E-07,   9.4624745E-08,   7.6623081E-08
     +,   6.1903698E-08,   4.9896073E-08,   4.0124668E-08
     +,   3.2191419E-08,   2.5766338E-08,   2.0574811E-08
     +,   1.6390331E-08,   1.3025461E-08,   1.0326406E-08
     +,   8.1665581E-09,   6.4425665E-09,   5.0698423E-09
     +,   3.9795234E-09,   3.1157574E-09,   2.4331757E-09
     +,   1.8952055E-09,   1.4722865E-09,   1.1407163E-09
     +,   8.8144042E-10,   6.7925671E-10,   5.2201332E-10
     +,   4.0006698E-10,   3.0575179E-10,   2.3301680E-10
     +,   1.7708010E-10,   1.3418815E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_hatt80 = Yx/0.530078431372549
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.7879916E-06,   9.2196015E-06
     +,   9.6617214E-06,   1.0113874E-05,   1.0575531E-05
     +,   1.1046106E-05,   1.1524967E-05,   1.2011427E-05
     +,   1.2504738E-05,   1.3004136E-05,   1.3508779E-05
     +,   1.4017795E-05,   1.4530272E-05,   1.5045270E-05
     +,   1.5561802E-05,   1.6078875E-05,   1.6595472E-05
     +,   1.7110553E-05,   1.7623093E-05,   1.8132065E-05
     +,   1.8636454E-05,   1.9135277E-05,   1.9627576E-05
     +,   2.0112479E-05,   2.0589132E-05,   2.1056811E-05
     +,   2.1514865E-05,   2.1962773E-05,   2.2400156E-05
     +,   2.2826805E-05,   2.3242710E-05,   2.3648083E-05
     +,   2.4043391E-05,   2.4429393E-05,   2.4807179E-05
     +,   2.5178206E-05,   2.5544343E-05,   2.5907906E-05
     +,   2.6271733E-05,   2.6639162E-05,   2.7014155E-05
     +,   2.7401282E-05,   2.7805783E-05,   2.8233590E-05
     +,   2.8691344E-05,   2.9186407E-05,   2.9726863E-05
     +,   3.0321484E-05,   3.0979700E-05,   3.1711519E-05
     +,   3.2527438E-05,   3.3438318E-05,   3.4455206E-05
     +,   3.5589270E-05,   3.6851347E-05,   3.8251961E-05
     +,   3.9800863E-05,   4.1506810E-05,   4.3377247E-05
     +,   4.5417943E-05,   4.7632744E-05,   5.0023235E-05
     +,   5.2588231E-05,   5.5323959E-05,   5.8223603E-05
     +,   6.1276900E-05,   6.4470645E-05,   6.7788074E-05
     +,   7.1209579E-05,   7.4712283E-05,   7.8271063E-05
     +,   8.1858154E-05,   8.5444604E-05,   8.8999936E-05
     +,   9.2493719E-05,   9.5896074E-05,   9.9178375E-05
     +,   1.0231435E-04,   1.0528151E-04,   1.0806193E-04
     +,   1.1064319E-04,   1.1302026E-04,   1.1519616E-04
     +,   1.1718392E-04,   1.1900748E-04,   1.2070383E-04
     +,   1.2232394E-04,   1.2393491E-04,   1.2562120E-04
     +,   1.2748600E-04,   1.2965244E-04,   1.3226397E-04
     +,   1.3548406E-04,   1.3949556E-04,   1.4449842E-04
     +,   1.5070547E-04,   1.5833929E-04,   1.6762462E-04
     +,   1.7878388E-04,   1.9202860E-04,   2.0755606E-04
     +,   2.2554226E-04,   2.4614501E-04,   2.6950234E-04
     +,   2.9574602E-04,   3.2501476E-04,   3.5747394E-04
     +,   3.9334697E-04,   4.3295472E-04,   4.7675575E-04
     +,   5.2538986E-04,   5.7973468E-04,   6.4093585E-04
     +,   7.1044773E-04,   7.9001649E-04,   8.8166009E-04
     +,   9.8754501E-04,   1.1098434E-03,   1.2504738E-03
     +,   1.4108781E-03,   1.5918533E-03,   1.7936499E-03
     +,   2.0165427E-03,   2.2619786E-03,   2.5341148E-03
     +,   2.8412871E-03,   3.1968323E-03,   3.6183966E-03
     +,   4.1258475E-03,   4.7377986E-03,   5.4685348E-03
     +,   6.3287532E-03,   7.3402831E-03,   8.5732983E-03
     +,   1.0193896E-02,   1.2482397E-02,   1.5807267E-02
     +,   2.0487173E-02,   2.6387027E-02,   3.3000320E-02
     +,   4.1022375E-02,   5.2312668E-02,   6.6011019E-02
     +,   7.9941109E-02,   9.8821685E-02,   0.1228040    
     +,   0.1378104    ,   0.1496184    ,   0.1571009    
     +,   0.1524110    ,   0.1409277    ,   0.1278274    
     +,   0.1150412    ,   9.7672835E-02,   8.2045466E-02
     +,   6.9782354E-02,   5.9767619E-02,   5.0008174E-02
     +,   4.1138247E-02,   3.3824828E-02,   2.8449375E-02
     +,   2.4835624E-02,   2.2069873E-02,   1.9492658E-02
     +,   1.7027318E-02,   1.4834878E-02,   1.3015745E-02
     +,   1.1564137E-02,   1.0424145E-02,   9.5187919E-03
     +,   8.7613249E-03,   8.0770710E-03,   7.4222959E-03
     +,   6.7841378E-03,   6.1674356E-03,   5.5823294E-03
     +,   5.0387499E-03,   4.5454213E-03,   4.1097221E-03
     +,   3.7367588E-03,   3.4280266E-03,   3.1803125E-03
     +,   2.9855210E-03,   2.8317266E-03,   2.7052227E-03
     +,   2.5929338E-03,   2.4844827E-03,   2.3733841E-03
     +,   2.2571667E-03,   2.1365702E-03,   2.0142079E-03
     +,   1.8931899E-03,   1.7760659E-03,   1.6642507E-03
     +,   1.5579545E-03,   1.4564968E-03,   1.3587875E-03
     +,   1.2637930E-03,   1.1708662E-03,   1.0799045E-03
     +,   9.9133106E-04,   9.0593821E-04,   8.2467683E-04
     +,   7.4845529E-04,   6.7798822E-04,   6.1368785E-04
     +,   5.5564614E-04,   5.0366798E-04,   4.5733072E-04
     +,   4.1606367E-04,   3.7923062E-04,   3.4619941E-04
     +,   3.1638553E-04,   2.8928163E-04,   2.6446904E-04
     +,   2.4161971E-04,   2.2048347E-04,   2.0087366E-04
     +,   1.8265365E-04,   1.6572481E-04,   1.5001121E-04
     +,   1.3545269E-04,   1.2199882E-04,   1.0960345E-04
     +,   9.8221026E-05,   8.7805711E-05,   7.8311023E-05
     +,   6.9688940E-05,   6.1889041E-05,   5.4859742E-05
     +,   4.8548965E-05,   4.2904085E-05,   3.7872211E-05
     +,   3.3401193E-05,   2.9440560E-05,   2.5941146E-05
     +,   2.2856088E-05,   2.0141351E-05,   1.7755774E-05
     +,   1.5661170E-05,   1.3822675E-05,   1.2208829E-05
     +,   1.0791397E-05,   9.5452160E-06,   8.4480916E-06
     +,   7.4806985E-06,   6.6262201E-06,   5.8700703E-06
     +,   5.1997104E-06,   4.6044524E-06,   4.0750842E-06
     +,   3.6037329E-06,   3.1836855E-06,   2.8091688E-06
     +,   2.4751830E-06,   2.1773922E-06,   1.9120341E-06
     +,   1.6757958E-06,   1.4657312E-06,   1.2792141E-06
     +,   1.1139008E-06,   9.6767440E-07,   8.3860635E-07
     +,   7.2494493E-07,   6.2510361E-07,   5.3762517E-07
     +,   4.6118069E-07,   3.9456361E-07,   3.3667504E-07
     +,   2.8651266E-07,   2.4316904E-07,   2.0582719E-07
     +,   1.7375113E-07,   1.4627800E-07,   1.2281562E-07
     +,   1.0283875E-07,   8.5878341E-08,   7.1522102E-08
     +,   5.9404975E-08,   4.9208243E-08,   4.0651919E-08
     +,   3.3493436E-08,   2.7521358E-08,   2.2553746E-08
     +,   1.8433241E-08,   1.5025407E-08,   1.2214906E-08
     +,   9.9035908E-09,   8.0082945E-09,   6.4584351E-09
     +,   5.1947082E-09,   4.1671266E-09,   3.3339598E-09
     +,   2.6602742E-09,   2.1170961E-09,   1.6803415E-09
     +,   1.3301584E-09,   1.0501496E-09,   8.2688978E-10
     +,   6.4936007E-10,   5.0859322E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_hatt85 = Yx/0.549019607843137
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3452175E-05,   1.4259785E-05
     +,   1.5097295E-05,   1.5964457E-05,   1.6860926E-05
     +,   1.7786248E-05,   1.8739869E-05,   1.9721117E-05
     +,   2.0729223E-05,   2.1763342E-05,   2.2822478E-05
     +,   2.3905563E-05,   2.5011419E-05,   2.6138787E-05
     +,   2.7286305E-05,   2.8452527E-05,   2.9635939E-05
     +,   3.0834937E-05,   3.2047854E-05,   3.3272972E-05
     +,   3.4508499E-05,   3.5752611E-05,   3.7003410E-05
     +,   3.8259062E-05,   3.9517552E-05,   4.0776991E-05
     +,   4.2035412E-05,   4.3290856E-05,   4.4541375E-05
     +,   4.5785033E-05,   4.7019919E-05,   4.8244132E-05
     +,   4.9455859E-05,   5.0653271E-05,   5.1834642E-05
     +,   5.2998275E-05,   5.4142569E-05,   5.5265944E-05
     +,   5.6367011E-05,   5.7444351E-05,   5.8496738E-05
     +,   5.9523027E-05,   6.0522179E-05,   6.1493309E-05
     +,   6.2435662E-05,   6.3348612E-05,   6.4231746E-05
     +,   6.5084772E-05,   6.5907610E-05,   6.6700341E-05
     +,   6.7463283E-05,   6.8196940E-05,   6.8902009E-05
     +,   6.9579502E-05,   7.0230497E-05,   7.0856469E-05
     +,   7.1458999E-05,   7.2039969E-05,   7.2601426E-05
     +,   7.3145668E-05,   7.3675154E-05,   7.4192547E-05
     +,   7.4700642E-05,   7.5202413E-05,   7.5700962E-05
     +,   7.6199431E-05,   7.6701093E-05,   7.7209210E-05
     +,   7.7727178E-05,   7.8258301E-05,   7.8806079E-05
     +,   7.9373953E-05,   7.9965554E-05,   8.0584614E-05
     +,   8.1235223E-05,   8.1921891E-05,   8.2649654E-05
     +,   8.3424369E-05,   8.4253043E-05,   8.5144056E-05
     +,   8.6107517E-05,   8.7155793E-05,   8.8303794E-05
     +,   8.9569592E-05,   9.0974732E-05,   9.2544913E-05
     +,   9.4310017E-05,   9.6304917E-05,   9.8569195E-05
     +,   1.0114764E-04,   1.0409008E-04,   1.0745072E-04
     +,   1.1128793E-04,   1.1566379E-04,   1.2064291E-04
     +,   1.2629082E-04,   1.3267393E-04,   1.3985655E-04
     +,   1.4790111E-04,   1.5686480E-04,   1.6680016E-04
     +,   1.7775109E-04,   1.8975412E-04,   2.0283394E-04
     +,   2.1700440E-04,   2.3226609E-04,   2.4860338E-04
     +,   2.6598343E-04,   2.8435551E-04,   3.0364867E-04
     +,   3.2376786E-04,   3.4459823E-04,   3.6599991E-04
     +,   3.8781529E-04,   4.0986735E-04,   4.3197165E-04
     +,   4.5393876E-04,   4.7559277E-04,   4.9677840E-04
     +,   5.1738491E-04,   5.3736352E-04,   5.5674918E-04
     +,   5.7568832E-04,   5.9446931E-04,   6.1355135E-04
     +,   6.3359470E-04,   6.5549108E-04,   6.8037474E-04
     +,   7.0962316E-04,   7.4480951E-04,   7.8762451E-04
     +,   8.3972182E-04,   9.0252922E-04,   9.7699498E-04
     +,   1.0633569E-03,   1.1609488E-03,   1.2681336E-03
     +,   1.3824491E-03,   1.5010352E-03,   1.6213321E-03
     +,   1.7420469E-03,   1.8642882E-03,   1.9927013E-03
     +,   2.1363108E-03,   2.3088655E-03,   2.5284975E-03
     +,   2.8166224E-03,   3.1963615E-03,   3.6908335E-03
     +,   4.3211970E-03,   5.1035862E-03,   6.0442179E-03
     +,   7.1348851E-03,   8.3582085E-03,   9.7204978E-03
     +,   1.1315416E-02,   1.3355772E-02,   1.6089233E-02
     +,   1.9748876E-02,   2.4806777E-02,   3.1926405E-02
     +,   4.0965129E-02,   5.1598806E-02,   6.6001140E-02
     +,   8.7658025E-02,   0.1135380    ,   0.1324956    
     +,   0.1447277    ,   0.1569039    ,   0.1698201    
     +,   0.1655951    ,   0.1409485    ,   0.1190304    
     +,   0.1045988    ,   8.8122733E-02,   7.2412744E-02
     +,   5.8963470E-02,   4.7927879E-02,   3.9010122E-02
     +,   3.1188214E-02,   2.4622524E-02,   1.9948719E-02
     +,   1.6849561E-02,   1.4651001E-02,   1.2933994E-02
     +,   1.1493869E-02,   1.0208760E-02,   9.0112202E-03
     +,   7.8942589E-03,   6.8944725E-03,   6.0523422E-03
     +,   5.3798910E-03,   4.8545413E-03,   4.4337916E-03
     +,   4.0742522E-03,   3.7441202E-03,   3.4268526E-03
     +,   3.1188293E-03,   2.8243593E-03,   2.5505144E-03
     +,   2.3031991E-03,   2.0849756E-03,   1.8946680E-03
     +,   1.7282480E-03,   1.5802919E-03,   1.4453831E-03
     +,   1.3191453E-03,   1.1987326E-03,   1.0828206E-03
     +,   9.7129785E-04,   8.6483423E-04,   7.6445669E-04
     +,   6.7119871E-04,   5.8586523E-04,   5.0892652E-04
     +,   4.4049486E-04,   3.8035540E-04,   3.2802951E-04
     +,   2.8286531E-04,   2.4411775E-04,   2.1100686E-04
     +,   1.8277364E-04,   1.5871422E-04,   1.3819567E-04
     +,   1.2066281E-04,   1.0563912E-04,   9.2721770E-05
     +,   8.1572536E-05,   7.1908813E-05,   6.3496002E-05
     +,   5.6140452E-05,   4.9682210E-05,   4.3988879E-05
     +,   3.8951439E-05,   3.4480538E-05,   3.0502018E-05
     +,   2.6954594E-05,   2.3787552E-05,   2.0958365E-05
     +,   1.8430912E-05,   1.6174281E-05,   1.4161783E-05
     +,   1.2369906E-05,   1.0777554E-05,   9.3657227E-06
     +,   8.1171684E-06,   7.0160681E-06,   6.0477664E-06
     +,   5.1987558E-06,   4.4566464E-06,   3.8099472E-06
     +,   3.2481073E-06,   2.7615106E-06,   2.3413811E-06
     +,   1.9797294E-06,   1.6693450E-06,   1.4037662E-06
     +,   1.1772057E-06,   9.8449436E-07,   8.2105100E-07
     +,   6.8284061E-07,   5.6631279E-07,   4.6834913E-07
     +,   3.8623097E-07,   3.1760217E-07,   2.6041411E-07
     +,   2.1289996E-07,   1.7354289E-07,   1.4104208E-07
     +,   1.1428389E-07,   9.2320924E-08,   7.4350439E-08
     +,   5.9693328E-08,   4.7776130E-08,   3.8117420E-08
     +,   3.0314983E-08,   2.4032241E-08,   1.8990194E-08
     +,   1.4957019E-08,   1.1741867E-08,   9.1873043E-09
     +,   7.1646542E-09,   5.5685496E-09,   4.3134647E-09
     +,   3.3299015E-09,   2.5618689E-09,   1.9642217E-09
     +,   1.5007914E-09,   1.1427377E-09,   8.6707069E-10
     +,   6.5560835E-10,   4.9397170E-10,   3.7087566E-10
     +,   2.7746577E-10,   2.0684614E-10,   1.5364854E-10
     +,   1.1372464E-10,   8.3871264E-11,   6.1632019E-11
     +,   4.5125421E-11,   3.2920156E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_hatt90 = Yx/0.522666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2860730E-05,   1.3121316E-05
     +,   1.3384814E-05,   1.3652208E-05,   1.3924560E-05
     +,   1.4203012E-05,   1.4488775E-05,   1.4783119E-05
     +,   1.5087362E-05,   1.5402878E-05,   1.5731068E-05
     +,   1.6073338E-05,   1.6431119E-05,   1.6805827E-05
     +,   1.7198856E-05,   1.7611568E-05,   1.8045279E-05
     +,   1.8501223E-05,   1.8980561E-05,   1.9484369E-05
     +,   2.0013593E-05,   2.0569070E-05,   2.1151485E-05
     +,   2.1761414E-05,   2.2399212E-05,   2.3065129E-05
     +,   2.3759207E-05,   2.4481320E-05,   2.5231177E-05
     +,   2.6008292E-05,   2.6812018E-05,   2.7641539E-05
     +,   2.8495864E-05,   2.9373883E-05,   3.0274326E-05
     +,   3.1195825E-05,   3.2136893E-05,   3.3095967E-05
     +,   3.4071483E-05,   3.5061730E-05,   3.6065103E-05
     +,   3.7079953E-05,   3.8104674E-05,   3.9137758E-05
     +,   4.0177751E-05,   4.1223349E-05,   4.2273365E-05
     +,   4.3326774E-05,   4.4382727E-05,   4.5440560E-05
     +,   4.6499808E-05,   4.7560225E-05,   4.8621747E-05
     +,   4.9684611E-05,   5.0749102E-05,   5.1815896E-05
     +,   5.2885720E-05,   5.3959564E-05,   5.5038559E-05
     +,   5.6123954E-05,   5.7217170E-05,   5.8319703E-05
     +,   5.9433100E-05,   6.0559003E-05,   6.1699124E-05
     +,   6.2855026E-05,   6.4028442E-05,   6.5220862E-05
     +,   6.6433888E-05,   6.7668909E-05,   6.8927322E-05
     +,   7.0210284E-05,   7.1519033E-05,   7.2854455E-05
     +,   7.4217489E-05,   7.5608958E-05,   7.7029486E-05
     +,   7.8479592E-05,   7.9959878E-05,   8.1470775E-05
     +,   8.3012666E-05,   8.4586041E-05,   8.6191190E-05
     +,   8.7828761E-05,   8.9499066E-05,   9.1202870E-05
     +,   9.2940776E-05,   9.4713658E-05,   9.6522352E-05
     +,   9.8367920E-05,   1.0025164E-04,   1.0217468E-04
     +,   1.0413837E-04,   1.0614421E-04,   1.0819380E-04
     +,   1.1028856E-04,   1.1243029E-04,   1.1462044E-04
     +,   1.1686090E-04,   1.1915326E-04,   1.2149953E-04
     +,   1.2390157E-04,   1.2636193E-04,   1.2888316E-04
     +,   1.3146858E-04,   1.3412234E-04,   1.3684953E-04
     +,   1.3965633E-04,   1.4255075E-04,   1.4554271E-04
     +,   1.4864396E-04,   1.5186914E-04,   1.5523522E-04
     +,   1.5876247E-04,   1.6247391E-04,   1.6639606E-04
     +,   1.7055823E-04,   1.7499326E-04,   1.7973647E-04
     +,   1.8482644E-04,   1.9030459E-04,   1.9621487E-04
     +,   2.0260402E-04,   2.0952284E-04,   2.1702643E-04
     +,   2.2517466E-04,   2.3403545E-04,   2.4368435E-04
     +,   2.5420886E-04,   2.6570776E-04,   2.7829481E-04
     +,   2.9209594E-04,   3.0725123E-04,   3.2390756E-04
     +,   3.4221611E-04,   3.6232264E-04,   3.8435447E-04
     +,   4.0840884E-04,   4.3454018E-04,   4.6274651E-04
     +,   4.9295701E-04,   5.2502839E-04,   5.5875146E-04
     +,   5.9386302E-04,   6.3007325E-04,   6.6711946E-04
     +,   7.0483185E-04,   7.4322516E-04,   7.8261911E-04
     +,   8.2376896E-04,   8.6799997E-04,   9.1729307E-04
     +,   9.7430474E-04,   1.0422355E-03,   1.1245119E-03
     +,   1.2242422E-03,   1.3435120E-03,   1.4826142E-03
     +,   1.6393885E-03,   1.8088699E-03,   1.9835222E-03
     +,   2.1540367E-03,   2.3107287E-03,   2.4454284E-03
     +,   2.5535796E-03,   2.6363647E-03,   2.7026313E-03
     +,   2.7702386E-03,   2.8660919E-03,   3.0238274E-03
     +,   3.2781237E-03,   3.6561855E-03,   4.1705118E-03
     +,   4.8219296E-03,   5.6242710E-03,   6.6536372E-03
     +,   8.0967303E-03,   1.0243582E-02,   1.3396346E-02
     +,   1.7754626E-02,   2.3410797E-02,   3.0643281E-02
     +,   4.0549625E-02,   5.4130144E-02,   7.1321778E-02
     +,   9.7079687E-02,   0.1304453    ,   0.1623908    
     +,   0.1840892    ,   0.1932016    ,   0.1866329    
     +,   0.1629890    ,   0.1388208    ,   0.1143297    
     +,   8.7972015E-02,   7.0787273E-02,   5.7324223E-02
     +,   4.4174407E-02,   3.3977285E-02,   2.6932487E-02
     +,   2.1679046E-02,   1.7436983E-02,   1.4009964E-02
     +,   1.1277516E-02,   9.0723857E-03,   7.2619324E-03
     +,   5.7921321E-03,   4.6414388E-03,   3.7700629E-03
     +,   3.1154619E-03,   2.6135973E-03,   2.2150979E-03
     +,   1.8879286E-03,   1.6127807E-03,   1.3778531E-03
     +,   1.1754828E-03,   1.0003753E-03,   8.4869401E-04
     +,   7.1754260E-04,   6.0461264E-04,   5.0792005E-04
     +,   4.2567169E-04,   3.5618813E-04,   2.9786688E-04
     +,   2.4918138E-04,   2.0870530E-04,   1.7513843E-04
     +,   1.4732302E-04,   1.2425330E-04,   1.0507846E-04
     +,   8.9093810E-05,   7.5723838E-05,   6.4502507E-05
     +,   5.5055316E-05,   4.7082009E-05,   4.0339000E-05
     +,   3.4627938E-05,   2.9785777E-05,   2.5676769E-05
     +,   2.2186585E-05,   1.9218582E-05,   1.6690878E-05
     +,   1.4533852E-05,   1.2688293E-05,   1.1104196E-05
     +,   9.7396223E-06,   8.5594811E-06,   7.5345411E-06
     +,   6.6406351E-06,   5.8579330E-06,   5.1700576E-06
     +,   4.5635520E-06,   4.0273744E-06,   3.5523815E-06
     +,   3.1309326E-06,   2.7566141E-06,   2.4240126E-06
     +,   2.1284859E-06,   1.8659969E-06,   1.6330187E-06
     +,   1.4264565E-06,   1.2435589E-06,   1.0818534E-06
     +,   9.3912399E-07,   8.1338624E-07,   7.0283568E-07
     +,   6.0584199E-07,   5.2093753E-07,   4.4679265E-07
     +,   3.8220043E-07,   3.2607207E-07,   2.7742871E-07
     +,   2.3538814E-07,   1.9915423E-07,   1.6801371E-07
     +,   1.4133069E-07,   1.1853417E-07,   9.9118672E-08
     +,   8.2633036E-08,   6.8680045E-08,   5.6907513E-08
     +,   4.7007372E-08,   3.8708407E-08,   3.1774960E-08
     +,   2.6001150E-08,   2.1209335E-08,   1.7245691E-08
     +,   1.3978004E-08,   1.1293348E-08,   9.0950119E-09
     +,   7.3011401E-09,   5.8421805E-09,   4.6597397E-09
     +,   3.7045953E-09,   2.9357445E-09,   2.3189235E-09
     +,   1.8257852E-09,   1.4328508E-09,   1.1208464E-09
     +,   8.7393220E-10,   6.7920752E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_hatt95 = Yx/0.504686274509804
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4813671E-05,   4.7168603E-05
     +,   4.9652601E-05,   5.2269083E-05,   5.5021010E-05
     +,   5.7910929E-05,   6.0940823E-05,   6.4112079E-05
     +,   6.7425346E-05,   7.0880778E-05,   7.4477575E-05
     +,   7.8214194E-05,   8.2088227E-05,   8.6096436E-05
     +,   9.0234564E-05,   9.4497482E-05,   9.8879129E-05
     +,   1.0337248E-04,   1.0796948E-04,   1.1266125E-04
     +,   1.1743801E-04,   1.2228894E-04,   1.2720266E-04
     +,   1.3216703E-04,   1.3716886E-04,   1.4219488E-04
     +,   1.4723101E-04,   1.5226292E-04,   1.5727585E-04
     +,   1.6225508E-04,   1.6718579E-04,   1.7205316E-04
     +,   1.7684278E-04,   1.8154057E-04,   1.8613297E-04
     +,   1.9060701E-04,   1.9495067E-04,   1.9915265E-04
     +,   2.0320299E-04,   2.0709251E-04,   2.1081383E-04
     +,   2.1436036E-04,   2.1772743E-04,   2.2091155E-04
     +,   2.2391103E-04,   2.2672564E-04,   2.2935700E-04
     +,   2.3180805E-04,   2.3408353E-04,   2.3618998E-04
     +,   2.3813511E-04,   2.3992827E-04,   2.4158030E-04
     +,   2.4310322E-04,   2.4451045E-04,   2.4581622E-04
     +,   2.4703599E-04,   2.4818574E-04,   2.4928257E-04
     +,   2.5034344E-04,   2.5138591E-04,   2.5242809E-04
     +,   2.5348732E-04,   2.5458139E-04,   2.5572756E-04
     +,   2.5694215E-04,   2.5824149E-04,   2.5964054E-04
     +,   2.6115353E-04,   2.6279330E-04,   2.6457183E-04
     +,   2.6649938E-04,   2.6858519E-04,   2.7083652E-04
     +,   2.7325947E-04,   2.7585847E-04,   2.7863641E-04
     +,   2.8159414E-04,   2.8473168E-04,   2.8804727E-04
     +,   2.9153749E-04,   2.9519844E-04,   2.9902408E-04
     +,   3.0300816E-04,   3.0714303E-04,   3.1142129E-04
     +,   3.1583416E-04,   3.2037351E-04,   3.2503062E-04
     +,   3.2979788E-04,   3.3466815E-04,   3.3963495E-04
     +,   3.4469314E-04,   3.4983931E-04,   3.5507217E-04
     +,   3.6039189E-04,   3.6580180E-04,   3.7130745E-04
     +,   3.7691742E-04,   3.8264357E-04,   3.8850127E-04
     +,   3.9450830E-04,   4.0068713E-04,   4.0706273E-04
     +,   4.1366328E-04,   4.2052064E-04,   4.2766897E-04
     +,   4.3514403E-04,   4.4298390E-04,   4.5122736E-04
     +,   4.5991252E-04,   4.6907761E-04,   4.7875737E-04
     +,   4.8898399E-04,   4.9978384E-04,   5.1117834E-04
     +,   5.2318006E-04,   5.3579314E-04,   5.4901023E-04
     +,   5.6281290E-04,   5.7717029E-04,   5.9203577E-04
     +,   6.0734840E-04,   6.2303373E-04,   6.3900097E-04
     +,   6.5514405E-04,   6.7134475E-04,   6.8747037E-04
     +,   7.0337916E-04,   7.1891834E-04,   7.3393108E-04
     +,   7.4825418E-04,   7.6172681E-04,   7.7418896E-04
     +,   7.8548735E-04,   7.9547876E-04,   8.0403191E-04
     +,   8.1103033E-04,   8.1637834E-04,   8.1999798E-04
     +,   8.2183653E-04,   8.2186260E-04,   8.2007045E-04
     +,   8.1647770E-04,   8.1112637E-04,   8.0408156E-04
     +,   7.9542759E-04,   7.8526919E-04,   7.7372725E-04
     +,   7.6093560E-04,   7.4703927E-04,   7.3219131E-04
     +,   7.1654952E-04,   7.0027355E-04,   6.8352191E-04
     +,   6.6645193E-04,   6.4921653E-04,   6.3196197E-04
     +,   6.1482773E-04,   5.9794734E-04,   5.8144587E-04
     +,   5.6544167E-04,   5.5004930E-04,   5.3537602E-04
     +,   5.2152760E-04,   5.0860731E-04,   4.9672090E-04
     +,   4.8597786E-04,   4.7649309E-04,   4.6839198E-04
     +,   4.6181455E-04,   4.5691940E-04,   4.5388742E-04
     +,   4.5293040E-04,   4.5429476E-04,   4.5827072E-04
     +,   4.6519941E-04,   4.7547999E-04,   4.8957794E-04
     +,   5.0803286E-04,   5.3146470E-04,   5.6057400E-04
     +,   5.9614354E-04,   6.3903193E-04,   6.9016445E-04
     +,   7.5050100E-04,   8.2101388E-04,   9.0264436E-04
     +,   9.9625310E-04,   1.1025432E-03,   1.2220150E-03
     +,   1.3548899E-03,   1.5010405E-03,   1.6599501E-03
     +,   1.8307006E-03,   2.0119743E-03,   2.2020864E-03
     +,   2.3990769E-03,   2.6008389E-03,   2.8052619E-03
     +,   3.0103847E-03,   3.2146061E-03,   3.4169266E-03
     +,   3.6172173E-03,   3.8165611E-03,   4.0177340E-03
     +,   4.2256969E-03,   4.4479799E-03,   4.6948330E-03
     +,   4.9788305E-03,   5.3136600E-03,   5.7121296E-03
     +,   6.1837141E-03,   6.7322538E-03,   7.3545785E-03
     +,   8.0410494E-03,   8.7784799E-03,   9.5557747E-03
     +,   1.0371350E-02,   1.1241428E-02,   1.2208321E-02
     +,   1.3349565E-02,   1.4791017E-02,   1.6719040E-02
     +,   1.9363126E-02,   2.2912949E-02,   2.7394006E-02
     +,   3.2619093E-02,   3.8293980E-02,   4.4171844E-02
     +,   5.0120711E-02,   5.6111671E-02,   6.2127195E-02
     +,   6.8026550E-02,   7.3541678E-02,   7.8376397E-02
     +,   8.2262740E-02,   8.5101120E-02,   8.7083869E-02
     +,   8.8140979E-02,   8.7436765E-02,   8.4319681E-02
     +,   7.9185978E-02,   7.2842196E-02,   6.5968722E-02
     +,   5.9130441E-02,   5.2562851E-02,   4.6224397E-02
     +,   4.0161688E-02,   3.4555007E-02,   2.9521896E-02
     +,   2.5048209E-02,   2.1063156E-02,   1.7516283E-02
     +,   1.4394618E-02,   1.1704343E-02,   9.4484659E-03
     +,   7.6121809E-03,   6.1572343E-03,   5.0253225E-03
     +,   4.1480535E-03,   3.4594340E-03,   2.9053609E-03
     +,   2.4473008E-03,   2.0607668E-03,   1.7311639E-03
     +,   1.4496912E-03,   1.2103290E-03,   1.0081038E-03
     +,   8.3838077E-04,   6.9672434E-04,   5.7897944E-04
     +,   4.8137529E-04,   4.0059289E-04,   3.3378892E-04
     +,   2.7857098E-04,   2.3292952E-04,   1.9519431E-04
     +,   1.6396779E-04,   1.3809021E-04,   1.1659492E-04
     +,   9.8686360E-05,   8.3709769E-05,   7.1134418E-05
     +,   6.0530099E-05,   5.1552630E-05,   4.3925302E-05
     +,   3.7426304E-05,   3.1877382E-05,   2.7132970E-05
     +,   2.3074133E-05,   1.9601524E-05,   1.6632102E-05
     +,   1.4094974E-05,   1.1929775E-05,   1.0084236E-05
     +,   8.5134106E-06,   7.1781628E-06,   6.0447692E-06
     +,   5.0838912E-06,   4.2703145E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_hatt100 = Yx/0.46312
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.9005953E-05,   7.1705785E-05
     +,   7.4543292E-05,   7.7525976E-05,   8.0661295E-05
     +,   8.3956860E-05,   8.7420238E-05,   9.1058748E-05
     +,   9.4879681E-05,   9.8890123E-05,   1.0309668E-04
     +,   1.0750553E-04,   1.1212243E-04,   1.1695239E-04
     +,   1.2199970E-04,   1.2726782E-04,   1.3275931E-04
     +,   1.3847552E-04,   1.4441677E-04,   1.5058205E-04
     +,   1.5696911E-04,   1.6357400E-04,   1.7039139E-04
     +,   1.7741469E-04,   1.8463495E-04,   1.9204231E-04
     +,   1.9962472E-04,   2.0736874E-04,   2.1525902E-04
     +,   2.2327885E-04,   2.3140981E-04,   2.3963195E-04
     +,   2.4792424E-04,   2.5626415E-04,   2.6462827E-04
     +,   2.7299227E-04,   2.8133107E-04,   2.8961929E-04
     +,   2.9783160E-04,   3.0594200E-04,   3.1392556E-04
     +,   3.2175751E-04,   3.2941447E-04,   3.3687390E-04
     +,   3.4411493E-04,   3.5111859E-04,   3.5786795E-04
     +,   3.6434890E-04,   3.7054965E-04,   3.7646198E-04
     +,   3.8208050E-04,   3.8740321E-04,   3.9243282E-04
     +,   3.9717538E-04,   4.0164078E-04,   4.0584346E-04
     +,   4.0980274E-04,   4.1354171E-04,   4.1708804E-04
     +,   4.2047363E-04,   4.2373518E-04,   4.2691338E-04
     +,   4.3005199E-04,   4.3319992E-04,   4.3640847E-04
     +,   4.3973207E-04,   4.4322797E-04,   4.4695512E-04
     +,   4.5097453E-04,   4.5534706E-04,   4.6013488E-04
     +,   4.6539825E-04,   4.7119785E-04,   4.7759051E-04
     +,   4.8463134E-04,   4.9237092E-04,   5.0085608E-04
     +,   5.1012670E-04,   5.2021816E-04,   5.3115847E-04
     +,   5.4296781E-04,   5.5565860E-04,   5.6923431E-04
     +,   5.8369100E-04,   5.9901335E-04,   6.1517977E-04
     +,   6.3215708E-04,   6.4990559E-04,   6.6837505E-04
     +,   6.8750943E-04,   7.0724549E-04,   7.2751206E-04
     +,   7.4823236E-04,   7.6932751E-04,   7.9071487E-04
     +,   8.1230723E-04,   8.3401956E-04,   8.5576443E-04
     +,   8.7745773E-04,   8.9901598E-04,   9.2036207E-04
     +,   9.4141893E-04,   9.6211978E-04,   9.8240084E-04
     +,   1.0022064E-03,   1.0214880E-03,   1.0402034E-03
     +,   1.0583196E-03,   1.0758118E-03,   1.0926619E-03
     +,   1.1088602E-03,   1.1244050E-03,   1.1393001E-03
     +,   1.1535557E-03,   1.1671913E-03,   1.1802268E-03
     +,   1.1926909E-03,   1.2046139E-03,   1.2160292E-03
     +,   1.2269721E-03,   1.2374807E-03,   1.2475918E-03
     +,   1.2573418E-03,   1.2667640E-03,   1.2758923E-03
     +,   1.2847540E-03,   1.2933741E-03,   1.3017688E-03
     +,   1.3099501E-03,   1.3179228E-03,   1.3256827E-03
     +,   1.3332170E-03,   1.3405030E-03,   1.3475099E-03
     +,   1.3541962E-03,   1.3605108E-03,   1.3663947E-03
     +,   1.3717775E-03,   1.3765827E-03,   1.3807290E-03
     +,   1.3841260E-03,   1.3866833E-03,   1.3883060E-03
     +,   1.3889016E-03,   1.3883814E-03,   1.3866588E-03
     +,   1.3836586E-03,   1.3793148E-03,   1.3735736E-03
     +,   1.3663975E-03,   1.3577655E-03,   1.3476765E-03
     +,   1.3361510E-03,   1.3232310E-03,   1.3089816E-03
     +,   1.2934926E-03,   1.2768756E-03,   1.2592705E-03
     +,   1.2408331E-03,   1.2217488E-03,   1.2022182E-03
     +,   1.1824631E-03,   1.1627242E-03,   1.1432539E-03
     +,   1.1243213E-03,   1.1062055E-03,   1.0891969E-03
     +,   1.0735933E-03,   1.0596975E-03,   1.0478215E-03
     +,   1.0382779E-03,   1.0313913E-03,   1.0274849E-03
     +,   1.0268925E-03,   1.0299511E-03,   1.0370087E-03
     +,   1.0484209E-03,   1.0645502E-03,   1.0857692E-03
     +,   1.1124512E-03,   1.1449769E-03,   1.1837163E-03
     +,   1.2290268E-03,   1.2812442E-03,   1.3406767E-03
     +,   1.4075821E-03,   1.4821709E-03,   1.5645975E-03
     +,   1.6549616E-03,   1.7533044E-03,   1.8596299E-03
     +,   1.9739196E-03,   2.0961328E-03,   2.2262442E-03
     +,   2.3642550E-03,   2.5102042E-03,   2.6641351E-03
     +,   2.8260907E-03,   2.9960754E-03,   3.1739951E-03
     +,   3.3595564E-03,   3.5522198E-03,   3.7511194E-03
     +,   3.9550117E-03,   4.1622110E-03,   4.3706647E-03
     +,   4.5779743E-03,   4.7815046E-03,   4.9785720E-03
     +,   5.1666391E-03,   5.3435625E-03,   5.5077942E-03
     +,   5.6586242E-03,   5.7963356E-03,   5.9223007E-03
     +,   6.0389820E-03,   6.1498759E-03,   6.2593720E-03
     +,   6.3725752E-03,   6.4950562E-03,   6.6325343E-03
     +,   6.7905104E-03,   6.9737150E-03,   7.1855779E-03
     +,   7.4277353E-03,   7.6997671E-03,   7.9994081E-03
     +,   8.3233193E-03,   8.6682178E-03,   9.0322001E-03
     +,   9.4157467E-03,   9.8226685E-03,   1.0261041E-02
     +,   1.0744466E-02,   1.1293493E-02,   1.1936438E-02
     +,   1.2708678E-02,   1.3652080E-02,   1.4819013E-02
     +,   1.6284667E-02,   1.8162403E-02,   2.0602990E-02
     +,   2.3755902E-02,   2.7693372E-02,   3.2343570E-02
     +,   3.7507601E-02,   4.2987037E-02,   4.8722547E-02
     +,   5.4779943E-02,   6.1155766E-02,   6.7590639E-02
     +,   7.3565789E-02,   7.8453146E-02,   8.1694946E-02
     +,   8.2952909E-02,   8.2166471E-02,   7.9462305E-02
     +,   7.5013854E-02,   6.9018774E-02,   6.1779443E-02
     +,   5.3746164E-02,   4.5467850E-02,   3.7492625E-02
     +,   3.0258946E-02,   2.4013722E-02,   1.8803280E-02
     +,   1.4542686E-02,   1.1104976E-02,   8.3730994E-03
     +,   6.2468811E-03,   4.6314332E-03,   3.4304317E-03
     +,   2.5501295E-03,   1.9075415E-03,   1.4361193E-03
     +,   1.0866267E-03,   8.2451862E-04,   6.2624289E-04
     +,   4.7559818E-04,   3.6110991E-04,   2.7426358E-04
     +,   2.0854342E-04,   1.5886969E-04,   1.2130794E-04
     +,   9.2843416E-05,   7.1211594E-05,   5.4728327E-05
     +,   4.2149146E-05,   3.2550961E-05,   2.5238818E-05
     +,   1.9683855E-05,   1.5477175E-05,   1.2301824E-05
     +,   9.9113431E-06,   8.1157286E-06,   6.7691876E-06
     +,   5.7611223E-06,   5.0078920E-06,   4.4466569E-06
     +,   4.0300461E-06,   3.7223647E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_hatt102 = Yx/0.4347
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5599573E-04,   3.8200198E-04
     +,   4.0950871E-04,   4.3860258E-04,   4.6937467E-04
     +,   5.0191965E-04,   5.3633319E-04,   5.7271047E-04
     +,   6.1114173E-04,   6.5171369E-04,   6.9450313E-04
     +,   7.3957909E-04,   7.8700139E-04,   8.3682220E-04
     +,   8.8908977E-04,   9.4385399E-04,   1.0011744E-03
     +,   1.0611262E-03,   1.1238136E-03,   1.1893781E-03
     +,   1.2580081E-03,   1.3299460E-03,   1.4054894E-03
     +,   1.4850001E-03,   1.5688819E-03,   1.6575869E-03
     +,   1.7515838E-03,   1.8513395E-03,   1.9572868E-03
     +,   2.0697911E-03,   2.1891003E-03,   2.3153047E-03
     +,   2.4482876E-03,   2.5876726E-03,   2.7327901E-03
     +,   2.8826541E-03,   3.0359605E-03,   3.1911279E-03
     +,   3.3464250E-03,   3.5000895E-03,   3.6506245E-03
     +,   3.7970648E-03,   3.9393487E-03,   4.0786644E-03
     +,   4.2177234E-03,   4.3608653E-03,   4.5139440E-03
     +,   4.6838569E-03,   4.8777470E-03,   5.1020002E-03
     +,   5.3610690E-03,   5.6565446E-03,   5.9866202E-03
     +,   6.3463203E-03,   6.7283879E-03,   7.1250270E-03
     +,   7.5299330E-03,   7.9404674E-03,   8.3593428E-03
     +,   8.7954830E-03,   9.2633516E-03,   9.7805243E-03
     +,   1.0363223E-02,   1.1021087E-02,   1.1752856E-02
     +,   1.2546005E-02,   1.3382176E-02,   1.4247048E-02
     +,   1.5141073E-02,   1.6084319E-02,   1.7113516E-02
     +,   1.8270338E-02,   1.9587243E-02,   2.1074876E-02
     +,   2.2719122E-02,   2.4487756E-02,   2.6342053E-02
     +,   2.8241305E-02,   3.0135827E-02,   3.1962104E-02
     +,   3.3659440E-02,   3.5205353E-02,   3.6638901E-02
     +,   3.8044672E-02,   3.9494406E-02,   4.0976211E-02
     +,   4.2378604E-02,   4.3592755E-02,   4.4675708E-02
     +,   4.5867931E-02,   4.7356889E-02,   4.9007263E-02
     +,   5.0387900E-02,   5.1076680E-02,   5.0899979E-02
     +,   4.9922682E-02,   4.8324995E-02,   4.6318740E-02
     +,   4.4085369E-02,   4.1717090E-02,   3.9226491E-02
     +,   3.6627315E-02,   3.3975434E-02,   3.1320106E-02
     +,   2.8649224E-02,   2.5917711E-02,   2.3129441E-02
     +,   2.0380303E-02,   1.7822934E-02,   1.5591897E-02
     +,   1.3748447E-02,   1.2272972E-02,   1.1095216E-02
     +,   1.0131426E-02,   9.3102958E-03,   8.5822241E-03
     +,   7.9184258E-03,   7.3052510E-03,   6.7383968E-03
     +,   6.2177051E-03,   5.7435976E-03,   5.3151092E-03
     +,   4.9292431E-03,   4.5813327E-03,   4.2658788E-03
     +,   3.9774682E-03,   3.7113598E-03,   3.4639642E-03
     +,   3.2328512E-03,   3.0166947E-03,   2.8149746E-03
     +,   2.6276922E-03,   2.4550308E-03,   2.2971530E-03
     +,   2.1539917E-03,   2.0251833E-03,   1.9100704E-03
     +,   1.8077204E-03,   1.7169905E-03,   1.6366191E-03
     +,   1.5653020E-03,   1.5017551E-03,   1.4447623E-03
     +,   1.3932188E-03,   1.3461624E-03,   1.3027678E-03
     +,   1.2623573E-03,   1.2243969E-03,   1.1884806E-03
     +,   1.1543133E-03,   1.1216972E-03,   1.0905121E-03
     +,   1.0607014E-03,   1.0322478E-03,   1.0051631E-03
     +,   9.7947475E-04,   9.5521461E-04,   9.3240617E-04
     +,   9.1106113E-04,   8.9117658E-04,   8.7272836E-04
     +,   8.5567188E-04,   8.3994586E-04,   8.2547189E-04
     +,   8.1215962E-04,   7.9990720E-04,   7.8861084E-04
     +,   7.7816687E-04,   7.6847349E-04,   7.5943710E-04
     +,   7.5097644E-04,   7.4302295E-04,   7.3552155E-04
     +,   7.2843401E-04,   7.2173792E-04,   7.1542559E-04
     +,   7.0950331E-04,   7.0399063E-04,   6.9891603E-04
     +,   6.9431541E-04,   6.9022883E-04,   6.8669935E-04
     +,   6.8376795E-04,   6.8147120E-04,   6.7984062E-04
     +,   6.7889690E-04,   6.7865185E-04,   6.7910383E-04
     +,   6.8023766E-04,   6.8202429E-04,   6.8442064E-04
     +,   6.8736810E-04,   6.9079525E-04,   6.9461775E-04
     +,   6.9873943E-04,   7.0305605E-04,   7.0745347E-04
     +,   7.1181328E-04,   7.1601319E-04,   7.1993063E-04
     +,   7.2344323E-04,   7.2643376E-04,   7.2878972E-04
     +,   7.3040783E-04,   7.3119334E-04,   7.3106511E-04
     +,   7.2995317E-04,   7.2780252E-04,   7.2457333E-04
     +,   7.2024052E-04,   7.1479578E-04,   7.0824381E-04
     +,   7.0060685E-04,   6.9192000E-04,   6.8223005E-04
     +,   6.7159801E-04,   6.6009437E-04,   6.4779690E-04
     +,   6.3479197E-04,   6.2117155E-04,   6.0702977E-04
     +,   5.9246231E-04,   5.7756656E-04,   5.6243758E-04
     +,   5.4716680E-04,   5.3184078E-04,   5.1654270E-04
     +,   5.0134800E-04,   4.8632413E-04,   4.7153153E-04
     +,   4.5702254E-04,   4.4284161E-04,   4.2902344E-04
     +,   4.1559528E-04,   4.0257734E-04,   3.8998111E-04
     +,   3.7781167E-04,   3.6606839E-04,   3.5474525E-04
     +,   3.4383041E-04,   3.3330888E-04,   3.2316230E-04
     +,   3.1337020E-04,   3.0390997E-04,   2.9475748E-04
     +,   2.8588917E-04,   2.7728151E-04,   2.6891087E-04
     +,   2.6075490E-04,   2.5279346E-04,   2.4500713E-04
     +,   2.3737851E-04,   2.2989286E-04,   2.2253749E-04
     +,   2.1530130E-04,   2.0817546E-04,   2.0115371E-04
     +,   1.9423164E-04,   1.8740639E-04,   1.8067675E-04
     +,   1.7404344E-04,   1.6750846E-04,   1.6107461E-04
     +,   1.5474568E-04,   1.4852660E-04,   1.4242243E-04
     +,   1.3643864E-04,   1.3058101E-04,   1.2485564E-04
     +,   1.1926810E-04,   1.1382349E-04,   1.0852725E-04
     +,   1.0338412E-04,   9.8398057E-05,   9.3572424E-05
     +,   8.8910470E-05,   8.4414103E-05,   8.0085163E-05
     +,   7.5924232E-05,   7.1931674E-05,   6.8106754E-05
     +,   6.4448548E-05,   6.0955052E-05,   5.7624162E-05
     +,   5.4452739E-05,   5.1437666E-05,   4.8575024E-05
     +,   4.5860583E-05,   4.3290027E-05,   4.0858380E-05
     +,   3.8560840E-05,   3.6392114E-05,   3.4347053E-05
     +,   3.2420176E-05,   3.0606188E-05,   2.8899616E-05
     +,   2.7295180E-05,   2.5787524E-05,   2.4371549E-05
     +,   2.3042101E-05,   2.1794351E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_hatt75 = Yx/0.45108
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3584465E-04,   1.4476659E-04
     +,   1.5431580E-04,   1.6454091E-04,   1.7549390E-04
     +,   1.8722954E-04,   1.9980587E-04,   2.1328407E-04
     +,   2.2772809E-04,   2.4320518E-04,   2.5978460E-04
     +,   2.7753774E-04,   2.9653785E-04,   3.1685823E-04
     +,   3.3857263E-04,   3.6175316E-04,   3.8646866E-04
     +,   4.1278379E-04,   4.4075609E-04,   4.7043423E-04
     +,   5.0185499E-04,   5.3504115E-04,   5.6999654E-04
     +,   6.0670776E-04,   6.4513378E-04,   6.8521150E-04
     +,   7.2684808E-04,   7.6992111E-04,   8.1427844E-04
     +,   8.5973868E-04,   9.0609409E-04,   9.5311290E-04
     +,   1.0005453E-03,   1.0481329E-03,   1.0956161E-03
     +,   1.1427476E-03,   1.1893032E-03,   1.2351017E-03
     +,   1.2800202E-03,   1.3240046E-03,   1.3671018E-03
     +,   1.4094647E-03,   1.4513760E-03,   1.4932584E-03
     +,   1.5356841E-03,   1.5793799E-03,   1.6252210E-03
     +,   1.6742151E-03,   1.7274711E-03,   1.7861687E-03
     +,   1.8514954E-03,   1.9245888E-03,   2.0064639E-03
     +,   2.0979531E-03,   2.1996272E-03,   2.3117701E-03
     +,   2.4343403E-03,   2.5669800E-03,   2.7090576E-03
     +,   2.8597249E-03,   3.0180165E-03,   3.1829672E-03
     +,   3.3537406E-03,   3.5298420E-03,   3.7113165E-03
     +,   3.8989987E-03,   4.0948391E-03,   4.3021478E-03
     +,   4.5258221E-03,   4.7722887E-03,   5.0492585E-03
     +,   5.3650476E-03,   5.7277465E-03,   6.1441045E-03
     +,   6.6187908E-03,   7.1539418E-03,   7.7493913E-03
     +,   8.4036421E-03,   9.1154370E-03,   9.8856743E-03
     +,   1.0719151E-02,   1.1626263E-02,   1.2622750E-02
     +,   1.3727103E-02,   1.4953373E-02,   1.6301068E-02
     +,   1.7744990E-02,   1.9232830E-02,   2.0692952E-02
     +,   2.2052517E-02,   2.3258701E-02,   2.4301931E-02
     +,   2.5241554E-02,   2.6221758E-02,   2.7448818E-02
     +,   2.9112261E-02,   3.1295240E-02,   3.3942237E-02
     +,   3.6898516E-02,   3.9965533E-02,   4.2943690E-02
     +,   4.5672465E-02,   4.8078272E-02,   5.0211981E-02
     +,   5.2206088E-02,   5.4108370E-02,   5.5845339E-02
     +,   5.7514410E-02,   5.9503324E-02,   6.1992060E-02
     +,   6.4551860E-02,   6.6543266E-02,   6.7705683E-02
     +,   6.8125874E-02,   6.7802779E-02,   6.6443220E-02
     +,   6.3710444E-02,   5.9646700E-02,   5.4714274E-02
     +,   4.9421351E-02,   4.4086181E-02,   3.8919181E-02
     +,   3.4113050E-02,   2.9819891E-02,   2.6122268E-02
     +,   2.3024518E-02,   2.0453449E-02,   1.8288851E-02
     +,   1.6414082E-02,   1.4749562E-02,   1.3252902E-02
     +,   1.1905058E-02,   1.0697942E-02,   9.6277846E-03
     +,   8.6897518E-03,   7.8746732E-03,   7.1685677E-03
     +,   6.5548555E-03,   6.0173115E-03,   5.5420096E-03
     +,   5.1177964E-03,   4.7360030E-03,   4.3900665E-03
     +,   4.0752678E-03,   3.7884393E-03,   3.5275070E-03
     +,   3.2909997E-03,   3.0775815E-03,   2.8856799E-03
     +,   2.7133573E-03,   2.5583657E-03,   2.4183183E-03
     +,   2.2908689E-03,   2.1738550E-03,   2.0654108E-03
     +,   1.9640189E-03,   1.8684885E-03,   1.7779223E-03
     +,   1.6916693E-03,   1.6092936E-03,   1.5305114E-03
     +,   1.4551637E-03,   1.3831991E-03,   1.3146368E-03
     +,   1.2495453E-03,   1.1880295E-03,   1.1302162E-03
     +,   1.0762352E-03,   1.0262032E-03,   9.8021561E-04
     +,   9.3834277E-04,   9.0061984E-04,   8.6704025E-04
     +,   8.3756022E-04,   8.1210036E-04,   7.9054385E-04
     +,   7.7274133E-04,   7.5851794E-04,   7.4767286E-04
     +,   7.3998579E-04,   7.3521992E-04,   7.3312660E-04
     +,   7.3344668E-04,   7.3591352E-04,   7.4025604E-04
     +,   7.4620085E-04,   7.5347337E-04,   7.6180155E-04
     +,   7.7091763E-04,   7.8055821E-04,   7.9046946E-04
     +,   8.0040778E-04,   8.1014138E-04,   8.1945315E-04
     +,   8.2814344E-04,   8.3602901E-04,   8.4294629E-04
     +,   8.4875379E-04,   8.5332937E-04,   8.5657416E-04
     +,   8.5840985E-04,   8.5878023E-04,   8.5765077E-04
     +,   8.5500511E-04,   8.5084827E-04,   8.4520207E-04
     +,   8.3810446E-04,   8.2960853E-04,   8.1978092E-04
     +,   8.0869958E-04,   7.9645176E-04,   7.8313414E-04
     +,   7.6884928E-04,   7.5370533E-04,   7.3781336E-04
     +,   7.2128663E-04,   7.0424104E-04,   6.8678969E-04
     +,   6.6904508E-04,   6.5111771E-04,   6.3311378E-04
     +,   6.1513332E-04,   5.9727347E-04,   5.7962374E-04
     +,   5.6226604E-04,   5.4527511E-04,   5.2871741E-04
     +,   5.1265152E-04,   4.9712602E-04,   4.8218024E-04
     +,   4.6784568E-04,   4.5414449E-04,   4.4108916E-04
     +,   4.2868350E-04,   4.1692494E-04,   4.0580158E-04
     +,   3.9529506E-04,   3.8538102E-04,   3.7603002E-04
     +,   3.6720684E-04,   3.5887284E-04,   3.5098696E-04
     +,   3.4350576E-04,   3.3638396E-04,   3.2957617E-04
     +,   3.2303750E-04,   3.1672404E-04,   3.1059296E-04
     +,   3.0460354E-04,   2.9871860E-04,   2.9290307E-04
     +,   2.8712541E-04,   2.8135770E-04,   2.7557628E-04
     +,   2.6976041E-04,   2.6389337E-04,   2.5796253E-04
     +,   2.5195914E-04,   2.4587711E-04,   2.3971393E-04
     +,   2.3347043E-04,   2.2715045E-04,   2.2075954E-04
     +,   2.1430575E-04,   2.0779956E-04,   2.0125248E-04
     +,   1.9467712E-04,   1.8808780E-04,   1.8149920E-04
     +,   1.7492638E-04,   1.6838430E-04,   1.6188846E-04
     +,   1.5545401E-04,   1.4909530E-04,   1.4282601E-04
     +,   1.3665974E-04,   1.3060833E-04,   1.2468349E-04
     +,   1.1889511E-04,   1.1325270E-04,   1.0776394E-04
     +,   1.0243599E-04,   9.7274315E-05,   9.2283721E-05
     +,   8.7467422E-05,   8.2828097E-05,   7.8366982E-05
     +,   7.4084368E-05,   6.9980088E-05,   6.6052577E-05
     +,   6.2300023E-05,   5.8719525E-05,   5.5307988E-05
     +,   5.2061343E-05,   4.8975591E-05,   4.6045854E-05
     +,   4.3267377E-05,   4.0634794E-05,   3.8142931E-05
     +,   3.5786128E-05,   3.3558987E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_hatt80 = Yx/0.530078431372549
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.4729530E-05,   8.7440327E-05
     +,   9.0190857E-05,   9.2979230E-05,   9.5803538E-05
     +,   9.8661891E-05,   1.0155230E-04,   1.0447283E-04
     +,   1.0742157E-04,   1.1039688E-04,   1.1339715E-04
     +,   1.1642103E-04,   1.1946748E-04,   1.2253589E-04
     +,   1.2562617E-04,   1.2873873E-04,   1.3187480E-04
     +,   1.3503633E-04,   1.3822642E-04,   1.4144916E-04
     +,   1.4470998E-04,   1.4801581E-04,   1.5137525E-04
     +,   1.5479882E-04,   1.5829889E-04,   1.6189042E-04
     +,   1.6559071E-04,   1.6941979E-04,   1.7340046E-04
     +,   1.7755886E-04,   1.8192404E-04,   1.8652865E-04
     +,   1.9140872E-04,   1.9660384E-04,   2.0215672E-04
     +,   2.0811401E-04,   2.1452502E-04,   2.2144214E-04
     +,   2.2892086E-04,   2.3701803E-04,   2.4579282E-04
     +,   2.5530517E-04,   2.6561541E-04,   2.7678334E-04
     +,   2.8886789E-04,   3.0192570E-04,   3.1601090E-04
     +,   3.3117388E-04,   3.4746114E-04,   3.6491457E-04
     +,   3.8357143E-04,   4.0346436E-04,   4.2462151E-04
     +,   4.4706889E-04,   4.7082789E-04,   4.9592165E-04
     +,   5.2237354E-04,   5.5021018E-04,   5.7946402E-04
     +,   6.1017578E-04,   6.4239552E-04,   6.7618513E-04
     +,   7.1161630E-04,   7.4877357E-04,   7.8775012E-04
     +,   8.2864106E-04,   8.7154389E-04,   9.1654167E-04
     +,   9.6370763E-04,   1.0130795E-03,   1.0646689E-03
     +,   1.1184391E-03,   1.1743172E-03,   1.2321863E-03
     +,   1.2919090E-03,   1.3533519E-03,   1.4164139E-03
     +,   1.4810847E-03,   1.5475051E-03,   1.6160371E-03
     +,   1.6873210E-03,   1.7623423E-03,   1.8424387E-03
     +,   1.9293046E-03,   2.0248878E-03,   2.1312803E-03
     +,   2.2505005E-03,   2.3843029E-03,   2.5339448E-03
     +,   2.7000867E-03,   2.8828245E-03,   3.0819054E-03
     +,   3.2972686E-03,   3.5298455E-03,   3.7825997E-03
     +,   4.0616309E-03,   4.3772091E-03,   4.7440389E-03
     +,   5.1804241E-03,   5.7055047E-03,   6.3347942E-03
     +,   7.0744092E-03,   7.9165800E-03,   8.8382503E-03
     +,   9.8059438E-03,   1.0786319E-02,   1.1759738E-02
     +,   1.2731678E-02,   1.3735209E-02,   1.4821879E-02
     +,   1.6044065E-02,   1.7438227E-02,   1.9015228E-02
     +,   2.0758975E-02,   2.2630582E-02,   2.4593093E-02
     +,   2.6667988E-02,   2.8983170E-02,   3.1695083E-02
     +,   3.4779105E-02,   3.7964478E-02,   4.1038673E-02
     +,   4.4133294E-02,   4.7519047E-02,   5.1297996E-02
     +,   5.5379171E-02,   5.9427433E-02,   6.3028671E-02
     +,   6.6231728E-02,   6.9494650E-02,   7.3106855E-02
     +,   7.6945156E-02,   8.0587283E-02,   8.3550550E-02
     +,   8.4990054E-02,   8.4157094E-02,   8.1859462E-02
     +,   7.9088546E-02,   7.5089537E-02,   6.8970449E-02
     +,   6.1450526E-02,   5.4178882E-02,   4.8073463E-02
     +,   4.2715196E-02,   3.7411045E-02,   3.2171126E-02
     +,   2.7450053E-02,   2.3521638E-02,   2.0307451E-02
     +,   1.7572615E-02,   1.5144273E-02,   1.2981515E-02
     +,   1.1120909E-02,   9.5972810E-03,   8.4040835E-03
     +,   7.4961074E-03,   6.8101431E-03,   6.2836441E-03
     +,   5.8645094E-03,   5.5132983E-03,   5.2019386E-03
     +,   4.9116500E-03,   4.6310537E-03,   4.3545384E-03
     +,   4.0807030E-03,   3.8108830E-03,   3.5477970E-03
     +,   3.2944966E-03,   3.0536286E-03,   2.8271643E-03
     +,   2.6163547E-03,   2.4218501E-03,   2.2438595E-03
     +,   2.0823071E-03,   1.9369548E-03,   1.8074053E-03
     +,   1.6931454E-03,   1.5935507E-03,   1.5078896E-03
     +,   1.4353350E-03,   1.3749908E-03,   1.3259337E-03
     +,   1.2872239E-03,   1.2579320E-03,   1.2371568E-03
     +,   1.2240334E-03,   1.2177286E-03,   1.2174422E-03
     +,   1.2223984E-03,   1.2318328E-03,   1.2449871E-03
     +,   1.2611003E-03,   1.2794037E-03,   1.2991225E-03
     +,   1.3194749E-03,   1.3396859E-03,   1.3589925E-03
     +,   1.3766622E-03,   1.3920084E-03,   1.4044074E-03
     +,   1.4133101E-03,   1.4182627E-03,   1.4189164E-03
     +,   1.4150330E-03,   1.4064920E-03,   1.3932883E-03
     +,   1.3755279E-03,   1.3534216E-03,   1.3272699E-03
     +,   1.2974500E-03,   1.2643952E-03,   1.2285850E-03
     +,   1.1905230E-03,   1.1507167E-03,   1.1096648E-03
     +,   1.0678486E-03,   1.0257155E-03,   9.8367024E-04
     +,   9.4207027E-04,   9.0122886E-04,   8.6140301E-04
     +,   8.2280260E-04,   7.8559242E-04,   7.4989436E-04
     +,   7.1578985E-04,   6.8332627E-04,   6.5252453E-04
     +,   6.2338152E-04,   5.9587165E-04,   5.6995387E-04
     +,   5.4557552E-04,   5.2267394E-04,   5.0117692E-04
     +,   4.8100654E-04,   4.6208303E-04,   4.4432099E-04
     +,   4.2763405E-04,   4.1193640E-04,   3.9714199E-04
     +,   3.8316526E-04,   3.6992264E-04,   3.5733462E-04
     +,   3.4532489E-04,   3.3382070E-04,   3.2275464E-04
     +,   3.1206524E-04,   3.0169685E-04,   2.9159940E-04
     +,   2.8172901E-04,   2.7204974E-04,   2.6253035E-04
     +,   2.5314640E-04,   2.4387959E-04,   2.3471736E-04
     +,   2.2565165E-04,   2.1667886E-04,   2.0780042E-04
     +,   1.9902096E-04,   1.9034755E-04,   1.8178974E-04
     +,   1.7335935E-04,   1.6506965E-04,   1.5693398E-04
     +,   1.4896618E-04,   1.4118078E-04,   1.3359109E-04
     +,   1.2620979E-04,   1.1904896E-04,   1.1211956E-04
     +,   1.0543068E-04,   9.8990015E-05,   9.2804177E-05
     +,   8.6878055E-05,   8.1214668E-05,   7.5815435E-05
     +,   7.0680930E-05,   6.5809421E-05,   6.1198618E-05
     +,   5.6844332E-05,   5.2741882E-05,   4.8884984E-05
     +,   4.5266977E-05,   4.1880026E-05,   3.8716054E-05
     +,   3.5766094E-05,   3.3021141E-05,   3.0471647E-05
     +,   2.8107874E-05,   2.5920250E-05,   2.3898872E-05
     +,   2.2034208E-05,   2.0316582E-05,   1.8736771E-05
     +,   1.7285583E-05,   1.5954303E-05,   1.4734369E-05
     +,   1.3617731E-05,   1.2596563E-05,   1.1663558E-05
     +,   1.0811687E-05,   1.0034428E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_hatt85 = Yx/0.549019607843137
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8677742E-05,   7.1464958E-05
     +,   7.4378462E-05,   7.7425910E-05,   8.0614911E-05
     +,   8.3953026E-05,   8.7447610E-05,   9.1105707E-05
     +,   9.4933748E-05,   9.8937737E-05,   1.0312275E-04
     +,   1.0749277E-04,   1.1205076E-04,   1.1679825E-04
     +,   1.2173525E-04,   1.2686013E-04,   1.3216936E-04
     +,   1.3765739E-04,   1.4331669E-04,   1.4913738E-04
     +,   1.5510742E-04,   1.6121237E-04,   1.6743544E-04
     +,   1.7375805E-04,   1.8015857E-04,   1.8661421E-04
     +,   1.9309981E-04,   1.9958858E-04,   2.0605254E-04
     +,   2.1246234E-04,   2.1878803E-04,   2.2499920E-04
     +,   2.3106531E-04,   2.3695643E-04,   2.4264320E-04
     +,   2.4809758E-04,   2.5329326E-04,   2.5820578E-04
     +,   2.6281361E-04,   2.6709744E-04,   2.7104153E-04
     +,   2.7463352E-04,   2.7786475E-04,   2.8073043E-04
     +,   2.8322972E-04,   2.8536606E-04,   2.8714683E-04
     +,   2.8858360E-04,   2.8969211E-04,   2.9049141E-04
     +,   2.9100481E-04,   2.9125850E-04,   2.9128217E-04
     +,   2.9110815E-04,   2.9077131E-04,   2.9030890E-04
     +,   2.8975983E-04,   2.8916454E-04,   2.8856503E-04
     +,   2.8800438E-04,   2.8752611E-04,   2.8717489E-04
     +,   2.8699543E-04,   2.8703338E-04,   2.8733429E-04
     +,   2.8794396E-04,   2.8890878E-04,   2.9027485E-04
     +,   2.9208881E-04,   2.9439706E-04,   2.9724566E-04
     +,   3.0068052E-04,   3.0474676E-04,   3.0948783E-04
     +,   3.1494605E-04,   3.2116109E-04,   3.2816941E-04
     +,   3.3600329E-04,   3.4469090E-04,   3.5425520E-04
     +,   3.6471186E-04,   3.7607143E-04,   3.8833704E-04
     +,   4.0150568E-04,   4.1556801E-04,   4.3051140E-04
     +,   4.4631827E-04,   4.6297332E-04,   4.8046131E-04
     +,   4.9877551E-04,   5.1791983E-04,   5.3791236E-04
     +,   5.5879098E-04,   5.8061944E-04,   6.0349092E-04
     +,   6.2752818E-04,   6.5289187E-04,   6.7977369E-04
     +,   7.0840289E-04,   7.3903584E-04,   7.7195599E-04
     +,   8.0746290E-04,   8.4586843E-04,   8.8748452E-04
     +,   9.3262270E-04,   9.8159537E-04,   1.0347174E-03
     +,   1.0923322E-03,   1.1548500E-03,   1.2227971E-03
     +,   1.2968779E-03,   1.3780718E-03,   1.4677054E-03
     +,   1.5675533E-03,   1.6798889E-03,   1.8075433E-03
     +,   1.9538763E-03,   2.1227729E-03,   2.3185075E-03
     +,   2.5456613E-03,   2.8089264E-03,   3.1128053E-03
     +,   3.4612222E-03,   3.8569376E-03,   4.3008151E-03
     +,   4.7910609E-03,   5.3230743E-03,   5.8900341E-03
     +,   6.4850235E-03,   7.1038147E-03,   7.7477773E-03
     +,   8.4242597E-03,   9.1441041E-03,   9.9165635E-03
     +,   1.0746741E-02,   1.1641080E-02,   1.2624945E-02
     +,   1.3767865E-02,   1.5197551E-02,   1.7071068E-02
     +,   1.9484675E-02,   2.2360962E-02,   2.5418563E-02
     +,   2.8304208E-02,   3.0838439E-02,   3.3211716E-02
     +,   3.5945442E-02,   3.9538685E-02,   4.4045653E-02
     +,   4.9026664E-02,   5.3845894E-02,   5.7988752E-02
     +,   6.1485652E-02,   6.5190777E-02,   7.0023403E-02
     +,   7.5870328E-02,   8.1835650E-02,   8.6612701E-02
     +,   8.8086866E-02,   8.5515581E-02,   8.1539378E-02
     +,   7.8408018E-02,   7.5422518E-02,   7.1300231E-02
     +,   6.5560959E-02,   5.8567092E-02,   5.1199481E-02
     +,   4.4080067E-02,   3.7368294E-02,   3.1057192E-02
     +,   2.5252281E-02,   2.0223657E-02,   1.6210755E-02
     +,   1.3240413E-02,   1.1149768E-02,   9.7228065E-03
     +,   8.7842997E-03,   8.2103545E-03,   7.9048574E-03
     +,   7.7858004E-03,   7.7861426E-03,   7.8572771E-03
     +,   7.9673138E-03,   8.0953138E-03,   8.2249809E-03
     +,   8.3405003E-03,   8.4253009E-03,   8.4630447E-03
     +,   8.4398696E-03,   8.3468612E-03,   8.1817554E-03
     +,   7.9493802E-03,   7.6606106E-03,   7.3301354E-03
     +,   6.9736447E-03,   6.6053364E-03,   6.2362594E-03
     +,   5.8737826E-03,   5.5220397E-03,   5.1830104E-03
     +,   4.8577245E-03,   4.5471154E-03,   4.2524575E-03
     +,   3.9753909E-03,   3.7177186E-03,   3.4809816E-03
     +,   3.2661962E-03,   3.0736658E-03,   2.9029227E-03
     +,   2.7527588E-03,   2.6213673E-03,   2.5065220E-03
     +,   2.4057352E-03,   2.3164232E-03,   2.2360575E-03
     +,   2.1622893E-03,   2.0930239E-03,   2.0264736E-03
     +,   1.9611828E-03,   1.8960481E-03,   1.8302766E-03
     +,   1.7633737E-03,   1.6951052E-03,   1.6254584E-03
     +,   1.5545904E-03,   1.4827928E-03,   1.4104528E-03
     +,   1.3380183E-03,   1.2659527E-03,   1.1947200E-03
     +,   1.1247633E-03,   1.0564878E-03,   9.9024363E-04
     +,   9.2632737E-04,   8.6498650E-04,   8.0640690E-04
     +,   7.5072411E-04,   6.9803058E-04,   6.4837700E-04
     +,   6.0177292E-04,   5.5819668E-04,   5.1760121E-04
     +,   4.7991448E-04,   4.4504117E-04,   4.1286836E-04
     +,   3.8327015E-04,   3.5610920E-04,   3.3123692E-04
     +,   3.0849827E-04,   2.8773808E-04,   2.6879751E-04
     +,   2.5151958E-04,   2.3575277E-04,   2.2135091E-04
     +,   2.0817468E-04,   1.9609352E-04,   1.8498751E-04
     +,   1.7474673E-04,   1.6527138E-04,   1.5647209E-04
     +,   1.4827042E-04,   1.4059752E-04,   1.3339330E-04
     +,   1.2660596E-04,   1.2019200E-04,   1.1411397E-04
     +,   1.0834037E-04,   1.0284517E-04,   9.7606608E-05
     +,   9.2606242E-05,   8.7828681E-05,   8.3261228E-05
     +,   7.8893223E-05,   7.4715186E-05,   7.0718976E-05
     +,   6.6897730E-05,   6.3244806E-05,   5.9754624E-05
     +,   5.6421453E-05,   5.3240390E-05,   5.0206236E-05
     +,   4.7314432E-05,   4.4560078E-05,   4.1938754E-05
     +,   3.9445775E-05,   3.7076821E-05,   3.4827386E-05
     +,   3.2693060E-05,   3.0669642E-05,   2.8752762E-05
     +,   2.6938345E-05,   2.5222160E-05,   2.3600243E-05
     +,   2.2068523E-05,   2.0623182E-05,   1.9260324E-05
     +,   1.7976301E-05,   1.6767386E-05,   1.5630123E-05
     +,   1.4560986E-05,   1.3556695E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_hatt90 = Yx/0.522666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0886913E-05,   4.2557847E-05
     +,   4.4250592E-05,   4.5962137E-05,   4.7689402E-05
     +,   4.9429163E-05,   5.1178195E-05,   5.2933188E-05
     +,   5.4690867E-05,   5.6447989E-05,   5.8201338E-05
     +,   5.9947775E-05,   6.1684332E-05,   6.3408115E-05
     +,   6.5116481E-05,   6.6806955E-05,   6.8477311E-05
     +,   7.0125585E-05,   7.1750095E-05,   7.3349504E-05
     +,   7.4922755E-05,   7.6469150E-05,   7.7988356E-05
     +,   7.9480458E-05,   8.0945749E-05,   8.2385101E-05
     +,   8.3799598E-05,   8.5190753E-05,   8.6560445E-05
     +,   8.7910812E-05,   8.9244408E-05,   9.0563954E-05
     +,   9.1872556E-05,   9.3173505E-05,   9.4470219E-05
     +,   9.5766474E-05,   9.7066011E-05,   9.8372671E-05
     +,   9.9690551E-05,   1.0102347E-04,   1.0237545E-04
     +,   1.0375040E-04,   1.0515210E-04,   1.0658422E-04
     +,   1.0805031E-04,   1.0955375E-04,   1.1109760E-04
     +,   1.1268489E-04,   1.1431833E-04,   1.1600036E-04
     +,   1.1773338E-04,   1.1951935E-04,   1.2136019E-04
     +,   1.2325775E-04,   1.2521347E-04,   1.2722907E-04
     +,   1.2930603E-04,   1.3144604E-04,   1.3365077E-04
     +,   1.3592222E-04,   1.3826267E-04,   1.4067467E-04
     +,   1.4316136E-04,   1.4572644E-04,   1.4837430E-04
     +,   1.5110988E-04,   1.5393921E-04,   1.5686885E-04
     +,   1.5990669E-04,   1.6306108E-04,   1.6634178E-04
     +,   1.6975893E-04,   1.7332404E-04,   1.7704885E-04
     +,   1.8094610E-04,   1.8502885E-04,   1.8931023E-04
     +,   1.9380327E-04,   1.9852095E-04,   2.0347557E-04
     +,   2.0867791E-04,   2.1413800E-04,   2.1986340E-04
     +,   2.2586016E-04,   2.3213090E-04,   2.3867613E-04
     +,   2.4549227E-04,   2.5257262E-04,   2.5990614E-04
     +,   2.6747817E-04,   2.7527031E-04,   2.8325937E-04
     +,   2.9141837E-04,   2.9971753E-04,   3.0812388E-04
     +,   3.1660154E-04,   3.2511371E-04,   3.3362213E-04
     +,   3.4208983E-04,   3.5048055E-04,   3.5876213E-04
     +,   3.6690533E-04,   3.7488836E-04,   3.8269520E-04
     +,   3.9031979E-04,   3.9776633E-04,   4.0504942E-04
     +,   4.1219665E-04,   4.1924903E-04,   4.2626160E-04
     +,   4.3330211E-04,   4.4045303E-04,   4.4780783E-04
     +,   4.5547259E-04,   4.6356098E-04,   4.7219486E-04
     +,   4.8149840E-04,   4.9159699E-04,   5.0261163E-04
     +,   5.1465636E-04,   5.2783487E-04,   5.4223416E-04
     +,   5.5792293E-04,   5.7494995E-04,   5.9334142E-04
     +,   6.1309797E-04,   6.3420023E-04,   6.5660535E-04
     +,   6.8025762E-04,   7.0508604E-04,   7.3102076E-04
     +,   7.5799337E-04,   7.8595523E-04,   8.1488263E-04
     +,   8.4479479E-04,   8.7576266E-04,   9.0792042E-04
     +,   9.4147783E-04,   9.7672641E-04,   1.0140449E-03
     +,   1.0538901E-03,   1.0967924E-03,   1.1433417E-03
     +,   1.1941551E-03,   1.2498433E-03,   1.3109755E-03
     +,   1.3780267E-03,   1.4513270E-03,   1.5310148E-03
     +,   1.6170036E-03,   1.7089485E-03,   1.8062302E-03
     +,   1.9079703E-03,   2.0130887E-03,   2.1203584E-03
     +,   2.2285087E-03,   2.3363505E-03,   2.4429506E-03
     +,   2.5477798E-03,   2.6508635E-03,   2.7529323E-03
     +,   2.8554951E-03,   2.9607855E-03,   3.0716453E-03
     +,   3.1911854E-03,   3.3223631E-03,   3.4674108E-03
     +,   3.6273380E-03,   3.8016338E-03,   3.9883507E-03
     +,   4.1846787E-03,   4.3881396E-03,   4.5981547E-03
     +,   4.8176614E-03,   5.0542662E-03,   5.3205215E-03
     +,   5.6328173E-03,   6.0092509E-03,   6.4673834E-03
     +,   7.0235492E-03,   7.6950849E-03,   8.5050445E-03
     +,   9.4857765E-03,   1.0676514E-02,   1.2114952E-02
     +,   1.3836321E-02,   1.5897308E-02,   1.8415283E-02
     +,   2.1573100E-02,   2.5554011E-02,   3.0460097E-02
     +,   3.6314644E-02,   4.3149672E-02,   5.1020399E-02
     +,   5.9641168E-02,   6.7883946E-02,   7.4595869E-02
     +,   7.9840817E-02,   8.4179521E-02,   8.7833315E-02
     +,   9.0306431E-02,   9.0819068E-02,   8.9358047E-02
     +,   8.6024858E-02,   8.0632910E-02,   7.3726617E-02
     +,   6.6747472E-02,   6.0594916E-02,   5.5314731E-02
     +,   5.0545491E-02,   4.5891199E-02,   4.1405652E-02
     +,   3.7461843E-02,   3.4253091E-02,   3.1709988E-02
     +,   2.9636890E-02,   2.7752817E-02,   2.5778994E-02
     +,   2.3585713E-02,   2.1234207E-02,   1.8890109E-02
     +,   1.6709870E-02,   1.4776335E-02,   1.3096595E-02
     +,   1.1636552E-02,   1.0356848E-02,   9.2302626E-03
     +,   8.2412614E-03,   7.3781409E-03,   6.6272514E-03
     +,   5.9722471E-03,   5.3965691E-03,   4.8858952E-03
     +,   4.4290032E-03,   4.0172548E-03,   3.6436976E-03
     +,   3.3026529E-03,   2.9897047E-03,   2.7017456E-03
     +,   2.4368735E-03,   2.1941403E-03,   1.9731340E-03
     +,   1.7735634E-03,   1.5949419E-03,   1.4364277E-03
     +,   1.2967971E-03,   1.1744754E-03,   1.0676429E-03
     +,   9.7436958E-04,   8.9274038E-04,   8.2093966E-04
     +,   7.5733114E-04,   7.0050196E-04,   6.4926810E-04
     +,   6.0266530E-04,   5.5992859E-04,   5.2046694E-04
     +,   4.8382557E-04,   4.4965482E-04,   4.1768682E-04
     +,   3.8771541E-04,   3.5957803E-04,   3.3314104E-04
     +,   3.0829484E-04,   2.8494824E-04,   2.6302066E-04
     +,   2.4244175E-04,   2.2315023E-04,   2.0509047E-04
     +,   1.8821021E-04,   1.7246090E-04,   1.5779692E-04
     +,   1.4417415E-04,   1.3154819E-04,   1.1987476E-04
     +,   1.0911055E-04,   9.9210280E-05,   9.0129601E-05
     +,   8.1822443E-05,   7.4243660E-05,   6.7347035E-05
     +,   6.1087536E-05,   5.5419914E-05,   5.0300503E-05
     +,   4.5686131E-05,   4.1535677E-05,   3.7809241E-05
     +,   3.4468787E-05,   3.1478648E-05,   2.8804840E-05
     +,   2.6415957E-05,   2.4282475E-05,   2.2377413E-05
     +,   2.0675718E-05,   1.9154731E-05,   1.7793658E-05
     +,   1.6573873E-05,   1.5478472E-05,   1.4492455E-05
     +,   1.3602330E-05,   1.2796248E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_hatt95 = Yx/0.504686274509804
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5686553E-05,   3.6938702E-05
     +,   3.8203842E-05,   3.9480248E-05,   4.0766092E-05
     +,   4.2059481E-05,   4.3358436E-05,   4.4660897E-05
     +,   4.5964738E-05,   4.7267829E-05,   4.8567916E-05
     +,   4.9862741E-05,   5.1150007E-05,   5.2427396E-05
     +,   5.3692569E-05,   5.4943182E-05,   5.6176897E-05
     +,   5.7391408E-05,   5.8584392E-05,   5.9753591E-05
     +,   6.0896804E-05,   6.2011844E-05,   6.3096624E-05
     +,   6.4149142E-05,   6.5167405E-05,   6.6149609E-05
     +,   6.7093984E-05,   6.7998903E-05,   6.8862813E-05
     +,   6.9684342E-05,   7.0462193E-05,   7.1195216E-05
     +,   7.1882430E-05,   7.2522940E-05,   7.3116040E-05
     +,   7.3661162E-05,   7.4157833E-05,   7.4605799E-05
     +,   7.5004922E-05,   7.5355179E-05,   7.5656739E-05
     +,   7.5909877E-05,   7.6114993E-05,   7.6272649E-05
     +,   7.6383527E-05,   7.6448414E-05,   7.6468212E-05
     +,   7.6443932E-05,   7.6376688E-05,   7.6267679E-05
     +,   7.6118202E-05,   7.5929616E-05,   7.5703370E-05
     +,   7.5440919E-05,   7.5143827E-05,   7.4813688E-05
     +,   7.4452117E-05,   7.4060743E-05,   7.3641262E-05
     +,   7.3195341E-05,   7.2724659E-05,   7.2230876E-05
     +,   7.1715709E-05,   7.1180766E-05,   7.0627677E-05
     +,   7.0058086E-05,   6.9473492E-05,   6.8875488E-05
     +,   6.8265530E-05,   6.7645073E-05,   6.7015477E-05
     +,   6.6378132E-05,   6.5734268E-05,   6.5085158E-05
     +,   6.4431944E-05,   6.3775718E-05,   6.3117528E-05
     +,   6.2458399E-05,   6.1799197E-05,   6.1140781E-05
     +,   6.0483973E-05,   5.9829476E-05,   5.9177986E-05
     +,   5.8530062E-05,   5.7886311E-05,   5.7247184E-05
     +,   5.6613138E-05,   5.5984521E-05,   5.5361699E-05
     +,   5.4744924E-05,   5.4134402E-05,   5.3530333E-05
     +,   5.2932868E-05,   5.2342089E-05,   5.1758012E-05
     +,   5.1180694E-05,   5.0610073E-05,   5.0046143E-05
     +,   4.9488761E-05,   4.8937862E-05,   4.8393260E-05
     +,   4.7854835E-05,   4.7322370E-05,   4.6795682E-05
     +,   4.6274537E-05,   4.5758687E-05,   4.5247896E-05
     +,   4.4741930E-05,   4.4240507E-05,   4.3743330E-05
     +,   4.3250166E-05,   4.2760705E-05,   4.2274700E-05
     +,   4.1791838E-05,   4.1311883E-05,   4.0834540E-05
     +,   4.0359570E-05,   3.9886687E-05,   3.9415678E-05
     +,   3.8946280E-05,   3.8478272E-05,   3.8011429E-05
     +,   3.7545586E-05,   3.7080521E-05,   3.6616049E-05
     +,   3.6152036E-05,   3.5688303E-05,   3.5224752E-05
     +,   3.4761226E-05,   3.4297653E-05,   3.3833923E-05
     +,   3.3369983E-05,   3.2905751E-05,   3.2441218E-05
     +,   3.1976331E-05,   3.1511063E-05,   3.1045434E-05
     +,   3.0579471E-05,   3.0113188E-05,   2.9646602E-05
     +,   2.9179788E-05,   2.8712833E-05,   2.8245793E-05
     +,   2.7778749E-05,   2.7311848E-05,   2.6845202E-05
     +,   2.6378961E-05,   2.5913338E-05,   2.5448602E-05
     +,   2.4985091E-05,   2.4523266E-05,   2.4063802E-05
     +,   2.3607659E-05,   2.3156190E-05,   2.2711280E-05
     +,   2.2275666E-05,   2.1853119E-05,   2.1448801E-05
     +,   2.1069665E-05,   2.0724943E-05,   2.0426527E-05
     +,   2.0189484E-05,   2.0032412E-05,   1.9977640E-05
     +,   2.0051226E-05,   2.0282585E-05,   2.0703714E-05
     +,   2.1347854E-05,   2.2247707E-05,   2.3433115E-05
     +,   2.4928264E-05,   2.6748845E-05,   2.8899687E-05
     +,   3.1373016E-05,   3.4148106E-05,   3.7194259E-05
     +,   4.0476913E-05,   4.3968375E-05,   4.7664791E-05
     +,   5.1609426E-05,   5.5921188E-05,   6.0827031E-05
     +,   6.6695051E-05,   7.4062315E-05,   8.3650637E-05
     +,   9.6363750E-05,   1.1326336E-04,   1.3552886E-04
     +,   1.6440880E-04,   2.0118800E-04,   2.4721559E-04
     +,   3.0401981E-04,   3.7354577E-04,   4.5854170E-04
     +,   5.6306459E-04,   6.9301500E-04,   8.5655053E-04
     +,   1.0641911E-03,   1.3283729E-03,   1.6621770E-03
     +,   2.0771241E-03,   2.5801284E-03,   3.1699955E-03
     +,   3.8340159E-03,   4.5456206E-03,   5.2643074E-03
     +,   5.9381891E-03,   6.5095290E-03,   6.9227209E-03
     +,   7.1330946E-03,   7.1146716E-03,   6.8650427E-03
     +,   6.4061591E-03,   5.7806191E-03,   5.0445460E-03
     +,   4.2587542E-03,   3.4800703E-03,   2.7545691E-03
     +,   2.1139076E-03,   1.5747059E-03,   1.1402428E-03
     +,   8.0386602E-04,   5.5280537E-04,   3.7159325E-04
     +,   2.4470143E-04,   1.5823077E-04,   1.0071234E-04
     +,   6.3254556E-05,   3.9306677E-05,   2.4242769E-05
     +,   1.4905499E-05,   9.1966576E-06,   5.7516190E-06
     +,   3.6984291E-06,   2.4880812E-06,   1.7794630E-06
     +,   1.3639855E-06,   1.1163520E-06,   9.6285385E-07
     +,   8.6118337E-07,   7.8772911E-07,   7.2970414E-07
     +,   6.8038656E-07,   6.3634315E-07,   5.9585932E-07
     +,   5.5808704E-07,   5.2259719E-07,   4.8915280E-07
     +,   4.5760575E-07,   4.2784987E-07,   3.9979338E-07
     +,   3.7335306E-07,   3.4845198E-07,   3.2501663E-07
     +,   3.0297431E-07,   2.8225563E-07,   2.6279449E-07
     +,   2.4452729E-07,   2.2739151E-07,   2.1132753E-07
     +,   1.9627855E-07,   1.8219048E-07,   1.6901018E-07
     +,   1.5668705E-07,   1.4517373E-07,   1.3442383E-07
     +,   1.2439314E-07,   1.1504010E-07,   1.0632503E-07
     +,   9.8209547E-08,   9.0657224E-08,   8.3633857E-08
     +,   7.7107075E-08,   7.1045541E-08,   6.5419734E-08
     +,   6.0202112E-08,   5.5365998E-08,   5.0886850E-08
     +,   4.6740738E-08,   4.2905775E-08,   3.9360742E-08
     +,   3.6086153E-08,   3.3063163E-08,   3.0274531E-08
     +,   2.7703630E-08,   2.5335211E-08,   2.3154703E-08
     +,   2.1148498E-08,   1.9304006E-08,   1.7609247E-08
     +,   1.6053182E-08,   1.4625347E-08,   1.3316124E-08
     +,   1.2116413E-08,   1.1017847E-08,   1.0012506E-08
     +,   9.0931618E-09,   8.2529708E-09,   7.4856832E-09
     +,   6.7854020E-09,   6.1467378E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_hatt100 = Yx/0.0268709677419355
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7272558E-05,   1.7685161E-05
     +,   1.8107694E-05,   1.8540039E-05,   1.8982033E-05
     +,   1.9433486E-05,   1.9894165E-05,   2.0363803E-05
     +,   2.0842086E-05,   2.1328686E-05,   2.1823213E-05
     +,   2.2325248E-05,   2.2834334E-05,   2.3349983E-05
     +,   2.3871662E-05,   2.4398807E-05,   2.4930818E-05
     +,   2.5467072E-05,   2.6006899E-05,   2.6549613E-05
     +,   2.7094495E-05,   2.7640799E-05,   2.8187747E-05
     +,   2.8734581E-05,   2.9280451E-05,   2.9824561E-05
     +,   3.0366071E-05,   3.0904117E-05,   3.1437856E-05
     +,   3.1966418E-05,   3.2488937E-05,   3.3004551E-05
     +,   3.3512399E-05,   3.4011628E-05,   3.4501394E-05
     +,   3.4980862E-05,   3.5449222E-05,   3.5905676E-05
     +,   3.6349469E-05,   3.6779824E-05,   3.7196049E-05
     +,   3.7597452E-05,   3.7983391E-05,   3.8353239E-05
     +,   3.8706454E-05,   3.9042494E-05,   3.9360901E-05
     +,   3.9661249E-05,   3.9943199E-05,   4.0206436E-05
     +,   4.0450745E-05,   4.0675961E-05,   4.0881998E-05
     +,   4.1068892E-05,   4.1236701E-05,   4.1385636E-05
     +,   4.1515974E-05,   4.1628125E-05,   4.1722615E-05
     +,   4.1800093E-05,   4.1861353E-05,   4.1907315E-05
     +,   4.1939082E-05,   4.1957923E-05,   4.1965272E-05
     +,   4.1962772E-05,   4.1952255E-05,   4.1935808E-05
     +,   4.1915700E-05,   4.1894469E-05,   4.1874915E-05
     +,   4.1860076E-05,   4.1853298E-05,   4.1858188E-05
     +,   4.1878655E-05,   4.1918916E-05,   4.1983476E-05
     +,   4.2077165E-05,   4.2205094E-05,   4.2372703E-05
     +,   4.2585703E-05,   4.2850093E-05,   4.3172127E-05
     +,   4.3558346E-05,   4.4015436E-05,   4.4550368E-05
     +,   4.5170193E-05,   4.5882149E-05,   4.6693469E-05
     +,   4.7611502E-05,   4.8643542E-05,   4.9796770E-05
     +,   5.1078176E-05,   5.2494626E-05,   5.4052711E-05
     +,   5.5758523E-05,   5.7617875E-05,   5.9635884E-05
     +,   6.1817278E-05,   6.4165848E-05,   6.6684879E-05
     +,   6.9376532E-05,   7.2242328E-05,   7.5282449E-05
     +,   7.8496261E-05,   8.1881997E-05,   8.5436441E-05
     +,   8.9155074E-05,   9.3032322E-05,   9.7061231E-05
     +,   1.0123302E-04,   1.0553808E-04,   1.0996477E-04
     +,   1.1450061E-04,   1.1913111E-04,   1.2384102E-04
     +,   1.2861314E-04,   1.3342961E-04,   1.3827081E-04
     +,   1.4311644E-04,   1.4794532E-04,   1.5273505E-04
     +,   1.5746258E-04,   1.6210468E-04,   1.6663771E-04
     +,   1.7103754E-04,   1.7528058E-04,   1.7934304E-04
     +,   1.8320218E-04,   1.8683534E-04,   1.9022147E-04
     +,   1.9334015E-04,   1.9617284E-04,   1.9870220E-04
     +,   2.0091301E-04,   2.0279203E-04,   2.0432810E-04
     +,   2.0551245E-04,   2.0633885E-04,   2.0680370E-04
     +,   2.0690590E-04,   2.0664734E-04,   2.0603251E-04
     +,   2.0506875E-04,   2.0376623E-04,   2.0213774E-04
     +,   2.0019876E-04,   1.9796740E-04,   1.9546429E-04
     +,   1.9271232E-04,   1.8973647E-04,   1.8656396E-04
     +,   1.8322410E-04,   1.7974763E-04,   1.7616700E-04
     +,   1.7251642E-04,   1.6883157E-04,   1.6514926E-04
     +,   1.6150778E-04,   1.5794724E-04,   1.5450895E-04
     +,   1.5123603E-04,   1.4817390E-04,   1.4537048E-04
     +,   1.4287628E-04,   1.4074525E-04,   1.3903547E-04
     +,   1.3780953E-04,   1.3713498E-04,   1.3708511E-04
     +,   1.3773920E-04,   1.3918272E-04,   1.4150735E-04
     +,   1.4481060E-04,   1.4919462E-04,   1.5476531E-04
     +,   1.6163022E-04,   1.6989549E-04,   1.7966262E-04
     +,   1.9102560E-04,   2.0406660E-04,   2.1885104E-04
     +,   2.3542513E-04,   2.5381520E-04,   2.7402616E-04
     +,   2.9604111E-04,   3.1982429E-04,   3.4532486E-04
     +,   3.7247696E-04,   4.0119636E-04,   4.3138539E-04
     +,   4.6292852E-04,   4.9569836E-04,   5.2957254E-04
     +,   5.6447351E-04,   6.0042529E-04,   6.3763716E-04
     +,   6.7661802E-04,   7.1831740E-04,   7.6428551E-04
     +,   8.1686053E-04,   8.7938673E-04,   9.5645658E-04
     +,   1.0541253E-03,   1.1800191E-03,   1.3432336E-03
     +,   1.5537939E-03,   1.8215103E-03,   2.1541764E-03
     +,   2.5551890E-03,   3.0208698E-03,   3.5380675E-03
     +,   4.0828665E-03,   4.6210992E-03,   5.1109293E-03
     +,   5.5076028E-03,   5.7697431E-03,   5.8659371E-03
     +,   5.7801437E-03,   5.5148178E-03,   5.0908285E-03
     +,   4.5442223E-03,   3.9206035E-03,   3.2682999E-03
     +,   2.6317604E-03,   2.0465732E-03,   1.5366994E-03
     +,   1.1139609E-03,   7.7948801E-04,   5.2644149E-04
     +,   3.4312269E-04,   2.1580976E-04,   1.3096843E-04
     +,   7.6681084E-05,   4.3312481E-05,   2.3599216E-05
     +,   1.2402258E-05,   6.2864606E-06,   3.0733643E-06
     +,   1.4492110E-06,   6.5920233E-07,   2.8938038E-07
     +,   1.2272035E-07,   5.0383328E-08,   2.0120504E-08
     +,   7.8984526E-09,   3.1167851E-09,   1.2905392E-09
     +,   5.9817479E-10,   3.2847791E-10,   2.1384788E-10
     +,   1.5682720E-10,   1.2267720E-10,   9.8981323E-11
     +,   8.1068034E-11,   6.6942674E-11,   5.5574798E-11
     +,   4.6322959E-11,   3.8736205E-11,   3.2478069E-11
     +,   2.7290160E-11,   2.2971059E-11,   1.9361767E-11
     +,   1.6336061E-11,   1.3793119E-11,   1.1651334E-11
     +,   9.8443519E-12,   8.3179687E-12,   7.0274789E-12
     +,   5.9357185E-12,   5.0117415E-12,   4.2296960E-12
     +,   3.5678379E-12,   3.0077967E-12,   2.5340526E-12
     +,   2.1335217E-12,   1.7950372E-12,   1.5091800E-12
     +,   1.2679086E-12,   1.0644204E-12,   8.9291552E-13
     +,   7.4848146E-13,   6.2693215E-13,   5.2472718E-13
     +,   4.3885129E-13,   3.6675640E-13,   3.0627784E-13
     +,   2.5558266E-13,   2.1312497E-13,   1.7759173E-13
     +,   1.4787947E-13,   1.2305166E-13,   1.0232308E-13
     +,   8.5029091E-14,   7.0612251E-14,   5.8601968E-14
     +,   4.8604523E-14,   4.0288106E-14,   3.3375212E-14
     +,   2.7632673E-14,   2.2865878E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_hatt102 = Yx/0.0268709677419355
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8656710E-05,   2.9719327E-05
     +,   3.0868079E-05,   3.2109732E-05,   3.3451004E-05
     +,   3.4898479E-05,   3.6458561E-05,   3.8137350E-05
     +,   3.9940598E-05,   4.1873696E-05,   4.3941483E-05
     +,   4.6148245E-05,   4.8497677E-05,   5.0992832E-05
     +,   5.3636089E-05,   5.6429166E-05,   5.9373182E-05
     +,   6.2468702E-05,   6.5715882E-05,   6.9114649E-05
     +,   7.2664923E-05,   7.6366981E-05,   8.0221726E-05
     +,   8.4231535E-05,   8.8399996E-05,   9.2733491E-05
     +,   9.7241056E-05,   1.0193531E-04,   1.0683302E-04
     +,   1.1195554E-04,   1.1732917E-04,   1.2298534E-04
     +,   1.2896031E-04,   1.3529476E-04,   1.4203283E-04
     +,   1.4922088E-04,   1.5690559E-04,   1.6513163E-04
     +,   1.7393992E-04,   1.8336312E-04,   1.9342494E-04
     +,   2.0413545E-04,   2.1548936E-04,   2.2746369E-04
     +,   2.4001626E-04,   2.5308470E-04,   2.6658725E-04
     +,   2.8042356E-04,   2.9447727E-04,   3.0861964E-04
     +,   3.2271363E-04,   3.3661991E-04,   3.5020232E-04
     +,   3.6333612E-04,   3.7591293E-04,   3.8785077E-04
     +,   3.9909882E-04,   4.0964512E-04,   4.1952170E-04
     +,   4.2880778E-04,   4.3763052E-04,   4.4616376E-04
     +,   4.5462171E-04,   4.6325082E-04,   4.7231815E-04
     +,   4.8209852E-04,   4.9286836E-04,   5.0490245E-04
     +,   5.1849592E-04,   5.3400599E-04,   5.5193907E-04
     +,   5.7306956E-04,   5.9860462E-04,   6.3033652E-04
     +,   6.7075464E-04,   7.2301284E-04,   7.9067581E-04
     +,   8.7722286E-04,   9.8537561E-04,   1.1164333E-03
     +,   1.2698876E-03,   1.4435966E-03,   1.6344386E-03
     +,   1.8393709E-03,   2.0564068E-03,   2.2855345E-03
     +,   2.5292425E-03,   2.7925987E-03,   3.0823357E-03
     +,   3.4067763E-03,   3.7821189E-03,   4.2516254E-03
     +,   4.9139410E-03,   5.9440103E-03,   7.5882436E-03
     +,   1.0085278E-02,   1.3441572E-02,   1.7209215E-02
     +,   2.0629870E-02,   2.3050534E-02,   2.4291465E-02
     +,   2.5064798E-02,   2.6565777E-02,   2.8894898E-02
     +,   3.1002549E-02,   3.2054633E-02,   3.1691507E-02
     +,   2.9811399E-02,   2.6758745E-02,   2.3095198E-02
     +,   1.9294485E-02,   1.5860455E-02,   1.3069432E-02
     +,   1.0792290E-02,   8.8436883E-03,   7.1859057E-03
     +,   5.8235605E-03,   4.7264122E-03,   3.8450356E-03
     +,   3.1375713E-03,   2.5780036E-03,   2.1464499E-03
     +,   1.8188370E-03,   1.5677175E-03,   1.3690728E-03
     +,   1.2063178E-03,   1.0696271E-03,   9.5339265E-04
     +,   8.5399754E-04,   7.6867372E-04,   6.9503410E-04
     +,   6.3101010E-04,   5.7485740E-04,   5.2519958E-04
     +,   4.8100366E-04,   4.4152921E-04,   4.0625324E-04
     +,   3.7478295E-04,   3.4678477E-04,   3.2193994E-04
     +,   2.9992239E-04,   2.8039355E-04,   2.6301027E-04
     +,   2.4744138E-04,   2.3338315E-04,   2.2056662E-04
     +,   2.0876505E-04,   1.9779519E-04,   1.8751397E-04
     +,   1.7781294E-04,   1.6861316E-04,   1.5985990E-04
     +,   1.5151626E-04,   1.4355796E-04,   1.3596985E-04
     +,   1.2874304E-04,   1.2187176E-04,   1.1535097E-04
     +,   1.0917533E-04,   1.0333867E-04,   9.7832271E-05
     +,   9.2645059E-05,   8.7763910E-05,   8.3173458E-05
     +,   7.8856152E-05,   7.4793032E-05,   7.0964583E-05
     +,   6.7350848E-05,   6.3931882E-05,   6.0688406E-05
     +,   5.7602516E-05,   5.4657674E-05,   5.1838921E-05
     +,   4.9133097E-05,   4.6529291E-05,   4.4018234E-05
     +,   4.1592546E-05,   3.9246763E-05,   3.6976948E-05
     +,   3.4780434E-05,   3.2655706E-05,   3.0602343E-05
     +,   2.8620643E-05,   2.6711296E-05,   2.4875311E-05
     +,   2.3113980E-05,   2.1428570E-05,   1.9820123E-05
     +,   1.8289436E-05,   1.6837157E-05,   1.5463411E-05
     +,   1.4167931E-05,   1.2950120E-05,   1.1808950E-05
     +,   1.0742926E-05,   9.7501816E-06,   8.8285742E-06
     +,   7.9756610E-06,   7.1886825E-06,   6.4646811E-06
     +,   5.8005912E-06,   5.1932238E-06,   4.6392802E-06
     +,   4.1354410E-06,   3.6784418E-06,   3.2650098E-06
     +,   2.8919512E-06,   2.5561860E-06,   2.2547476E-06
     +,   1.9847771E-06,   1.7435588E-06,   1.5285453E-06
     +,   1.3373382E-06,   1.1676832E-06,   1.0174851E-06
     +,   8.8481272E-07,   7.6788291E-07,   6.6504953E-07
     +,   5.7480713E-07,   4.9579131E-07,   4.2675285E-07
     +,   3.6656039E-07,   3.1419680E-07,   2.6874406E-07
     +,   2.2937532E-07,   1.9535024E-07,   1.6600987E-07
     +,   1.4076652E-07,   1.1909643E-07,   1.0053562E-07
     +,   8.4674994E-08,   7.1153778E-08,   5.9653487E-08
     +,   4.9895000E-08,   4.1634920E-08,   3.4659788E-08
     +,   2.8783953E-08,   2.3846550E-08,   1.9708155E-08
     +,   1.6248045E-08,   1.3362286E-08,   1.0961783E-08
     +,   8.9701002E-09,   7.3218609E-09,   5.9613359E-09
     +,   4.8412980E-09,   3.9216856E-09,   3.1686158E-09
     +,   2.5535487E-09,   2.0525734E-09,   1.6456045E-09
     +,   1.3158863E-09,   1.0494859E-09,   8.3483348E-10
     +,   6.6234329E-10,   5.2410670E-10,   4.1362880E-10
     +,   3.2557912E-10,   2.5559532E-10,   2.0012132E-10
     +,   1.5627173E-10,   1.2170695E-10,   9.4535373E-11
     +,   7.3233787E-11,   5.6581313E-11,   4.3598812E-11
     +,   3.3505091E-11,   2.5679446E-11,   1.9629142E-11
     +,   1.4964207E-11,   1.1377261E-11,   8.6269516E-12
     +,   6.5240205E-12,   4.9204950E-12,   3.7011028E-12
     +,   2.7764657E-12,   2.0772141E-12,   1.5499154E-12
     +,   1.1533579E-12,   8.5596553E-13,   6.3354427E-13
     +,   4.6766426E-13,   3.4428490E-13,   2.5277770E-13
     +,   1.8509195E-13,   1.3516723E-13,   9.8443538E-14
     +,   7.1504048E-14,   5.1797620E-14,   3.7420950E-14
     +,   2.6962314E-14,   1.9374264E-14,   1.3884484E-14
     +,   9.9234035E-15,   7.0733693E-15,   5.0282773E-15
     +,   3.5649088E-15,   2.5205958E-15,   1.7774368E-15
     +,   1.2500043E-15,   8.7672839E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_hatt75 = Yx/0.128833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3277210E-05,   4.6023357E-05
     +,   4.8962571E-05,   5.2099705E-05,   5.5437962E-05
     +,   5.8978741E-05,   6.2721338E-05,   6.6662818E-05
     +,   7.0797723E-05,   7.5118296E-05,   7.9613928E-05
     +,   8.4271378E-05,   8.9074791E-05,   9.4005649E-05
     +,   9.9043042E-05,   1.0416374E-04,   1.0934250E-04
     +,   1.1455233E-04,   1.1976482E-04,   1.2495063E-04
     +,   1.3007982E-04,   1.3512230E-04,   1.4004832E-04
     +,   1.4482917E-04,   1.4943698E-04,   1.5384606E-04
     +,   1.5803261E-04,   1.6197533E-04,   1.6565580E-04
     +,   1.6905871E-04,   1.7217195E-04,   1.7498691E-04
     +,   1.7749863E-04,   1.7970552E-04,   1.8160950E-04
     +,   1.8321606E-04,   1.8453388E-04,   1.8557481E-04
     +,   1.8635369E-04,   1.8688798E-04,   1.8719773E-04
     +,   1.8730528E-04,   1.8723498E-04,   1.8701307E-04
     +,   1.8666721E-04,   1.8622661E-04,   1.8572151E-04
     +,   1.8518310E-04,   1.8464314E-04,   1.8413381E-04
     +,   1.8368736E-04,   1.8333578E-04,   1.8311043E-04
     +,   1.8304173E-04,   1.8315860E-04,   1.8348804E-04
     +,   1.8405492E-04,   1.8488102E-04,   1.8598502E-04
     +,   1.8738188E-04,   1.8908260E-04,   1.9109395E-04
     +,   1.9341816E-04,   1.9605338E-04,   1.9899367E-04
     +,   2.0222893E-04,   2.0574639E-04,   2.0953020E-04
     +,   2.1356341E-04,   2.1782778E-04,   2.2230568E-04
     +,   2.2697987E-04,   2.3183538E-04,   2.3685857E-04
     +,   2.4203831E-04,   2.4736515E-04,   2.5283059E-04
     +,   2.5842633E-04,   2.6414462E-04,   2.6997749E-04
     +,   2.7591846E-04,   2.8196740E-04,   2.8813625E-04
     +,   2.9446188E-04,   3.0102156E-04,   3.0795619E-04
     +,   3.1549638E-04,   3.2399746E-04,   3.3397149E-04
     +,   3.4612342E-04,   3.6137830E-04,   3.8089347E-04
     +,   4.0605103E-04,   4.3841993E-04,   4.7967941E-04
     +,   5.3150079E-04,   5.9541466E-04,   6.7264459E-04
     +,   7.6397380E-04,   8.6959219E-04,   9.8898693E-04
     +,   1.1207559E-03,   1.2624487E-03,   1.4103691E-03
     +,   1.5596368E-03,   1.7046515E-03,   1.8402816E-03
     +,   1.9639875E-03,   2.0788303E-03,   2.1969937E-03
     +,   2.3427471E-03,   2.5530029E-03,   2.8732202E-03
     +,   3.3481219E-03,   4.0088329E-03,   4.8609884E-03
     +,   5.8782641E-03,   7.0059863E-03,   8.1746504E-03
     +,   9.3176067E-03,   1.0379337E-02,   1.1307054E-02
     +,   1.2035154E-02,   1.2481662E-02,   1.2567214E-02
     +,   1.2250558E-02,   1.1564140E-02,   1.0624399E-02
     +,   9.5908698E-03,   8.5857278E-03,   7.6344097E-03
     +,   6.6842912E-03,   5.6831064E-03,   4.6437122E-03
     +,   3.6433020E-03,   2.7735853E-03,   2.0915940E-03
     +,   1.6029276E-03,   1.2750201E-03,   1.0608210E-03
     +,   9.1718463E-04,   8.1322057E-04,   7.3084777E-04
     +,   6.6153950E-04,   6.0229388E-04,   5.5241765E-04
     +,   5.1162147E-04,   4.7920973E-04,   4.5396350E-04
     +,   4.3434300E-04,   4.1875741E-04,   4.0577422E-04
     +,   3.9423269E-04,   3.8327719E-04,   3.7233887E-04
     +,   3.6109032E-04,   3.4939084E-04,   3.3723301E-04
     +,   3.2469683E-04,   3.1191218E-04,   2.9902477E-04
     +,   2.8617523E-04,   2.7348442E-04,   2.6104477E-04
     +,   2.4891688E-04,   2.3713254E-04,   2.2570026E-04
     +,   2.1461073E-04,   2.0384279E-04,   1.9337032E-04
     +,   1.8316809E-04,   1.7321481E-04,   1.6349502E-04
     +,   1.5400103E-04,   1.4473400E-04,   1.3570147E-04
     +,   1.2691702E-04,   1.1839937E-04,   1.1016987E-04
     +,   1.0225043E-04,   9.4662500E-05,   8.7426131E-05
     +,   8.0558464E-05,   7.4072472E-05,   6.7977038E-05
     +,   6.2277053E-05,   5.6972971E-05,   5.2060699E-05
     +,   4.7532372E-05,   4.3377127E-05,   3.9580769E-05
     +,   3.6126734E-05,   3.2996879E-05,   3.0171685E-05
     +,   2.7630564E-05,   2.5352552E-05,   2.3316794E-05
     +,   2.1502668E-05,   1.9889980E-05,   1.8459317E-05
     +,   1.7192286E-05,   1.6071523E-05,   1.5080712E-05
     +,   1.4204742E-05,   1.3429775E-05,   1.2743091E-05
     +,   1.2133147E-05,   1.1589581E-05,   1.1103103E-05
     +,   1.0665420E-05,   1.0269195E-05,   9.9080207E-06
     +,   9.5762925E-06,   9.2691471E-06,   8.9823861E-06
     +,   8.7124545E-06,   8.4563344E-06,   8.2114802E-06
     +,   7.9757720E-06,   7.7474915E-06,   7.5252210E-06
     +,   7.3078277E-06,   7.0944361E-06,   6.8843751E-06
     +,   6.6771345E-06,   6.4723508E-06,   6.2697964E-06
     +,   6.0693446E-06,   5.8709320E-06,   5.6745635E-06
     +,   5.4803077E-06,   5.2882706E-06,   5.0985736E-06
     +,   4.9113605E-06,   4.7268063E-06,   4.5450706E-06
     +,   4.3663213E-06,   4.1907333E-06,   4.0184746E-06
     +,   3.8496974E-06,   3.6845440E-06,   3.5231535E-06
     +,   3.3656556E-06,   3.2121545E-06,   3.0627421E-06
     +,   2.9175064E-06,   2.7765191E-06,   2.6398300E-06
     +,   2.5074758E-06,   2.3794921E-06,   2.2558875E-06
     +,   2.1366607E-06,   2.0218047E-06,   1.9113006E-06
     +,   1.8051126E-06,   1.7031936E-06,   1.6054952E-06
     +,   1.5119595E-06,   1.4225141E-06,   1.3370800E-06
     +,   1.2555765E-06,   1.1779189E-06,   1.1040087E-06
     +,   1.0337465E-06,   9.6703388E-07,   9.0376301E-07
     +,   8.4382350E-07,   7.8710724E-07,   7.3350367E-07
     +,   6.8289791E-07,   6.3517535E-07,   5.9022358E-07
     +,   5.4793071E-07,   5.0818284E-07,   4.7086723E-07
     +,   4.3587625E-07,   4.0309925E-07,   3.7243203E-07
     +,   3.4376851E-07,   3.1700904E-07,   2.9205259E-07
     +,   2.6880477E-07,   2.4717053E-07,   2.2706119E-07
     +,   2.0838822E-07,   1.9106878E-07,   1.7502153E-07
     +,   1.6016848E-07,   1.4643651E-07,   1.3375356E-07
     +,   1.2205282E-07,   1.1126902E-07,   1.0134141E-07
     +,   9.2211224E-08,   8.3823707E-08,   7.6126184E-08
     +,   6.9069699E-08,   6.2607327E-08,   5.6695566E-08
     +,   5.1292840E-08,   4.6360832E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_hatt80 = Yx/0.0589166666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2097100E-05,   2.3318607E-05
     +,   2.4560954E-05,   2.5820700E-05,   2.7094187E-05
     +,   2.8377552E-05,   2.9666762E-05,   3.0957646E-05
     +,   3.2245887E-05,   3.3527147E-05,   3.4796998E-05
     +,   3.6050988E-05,   3.7284710E-05,   3.8493810E-05
     +,   3.9674029E-05,   4.0821233E-05,   4.1931467E-05
     +,   4.3000960E-05,   4.4026187E-05,   4.5003864E-05
     +,   4.5930996E-05,   4.6804918E-05,   4.7623253E-05
     +,   4.8384052E-05,   4.9085629E-05,   4.9726790E-05
     +,   5.0306633E-05,   5.0824721E-05,   5.1280986E-05
     +,   5.1675819E-05,   5.2009986E-05,   5.2284755E-05
     +,   5.2501800E-05,   5.2663279E-05,   5.2771855E-05
     +,   5.2830692E-05,   5.2843552E-05,   5.2814790E-05
     +,   5.2749416E-05,   5.2653239E-05,   5.2532829E-05
     +,   5.2395761E-05,   5.2250543E-05,   5.2106912E-05
     +,   5.1975854E-05,   5.1869785E-05,   5.1802639E-05
     +,   5.1790084E-05,   5.1849565E-05,   5.2000458E-05
     +,   5.2264146E-05,   5.2664058E-05,   5.3225656E-05
     +,   5.3976441E-05,   5.4945667E-05,   5.6164332E-05
     +,   5.7664667E-05,   5.9479829E-05,   6.1643288E-05
     +,   6.4188229E-05,   6.7146684E-05,   7.0548740E-05
     +,   7.4421194E-05,   7.8786979E-05,   8.3663690E-05
     +,   8.9061941E-05,   9.4985131E-05,   1.0142702E-04
     +,   1.0837203E-04,   1.1579278E-04,   1.2365104E-04
     +,   1.3189545E-04,   1.4046332E-04,   1.4927889E-04
     +,   1.5825569E-04,   1.6729697E-04,   1.7629655E-04
     +,   1.8514141E-04,   1.9371459E-04,   2.0189740E-04
     +,   2.0957163E-04,   2.1662482E-04,   2.2295155E-04
     +,   2.2845893E-04,   2.3306826E-04,   2.3671972E-04
     +,   2.3937431E-04,   2.4101725E-04,   2.4165967E-04
     +,   2.4134049E-04,   2.4012756E-04,   2.3811782E-04
     +,   2.3543749E-04,   2.3224062E-04,   2.2870740E-04
     +,   2.2504207E-04,   2.2146845E-04,   2.1822639E-04
     +,   2.1556538E-04,   2.1373871E-04,   2.1299478E-04
     +,   2.1356891E-04,   2.1567267E-04,   2.1948271E-04
     +,   2.2512942E-04,   2.3268476E-04,   2.4215068E-04
     +,   2.5344940E-04,   2.6641888E-04,   2.8081163E-04
     +,   2.9630124E-04,   3.1250337E-04,   3.2900259E-04
     +,   3.4540109E-04,   3.6137155E-04,   3.7672851E-04
     +,   3.9149274E-04,   4.0595551E-04,   4.2070955E-04
     +,   4.3664640E-04,   4.5489124E-04,   4.7667520E-04
     +,   5.0315243E-04,   5.3519080E-04,   5.7318714E-04
     +,   6.1696710E-04,   6.6586107E-04,   7.1895611E-04
     +,   7.7557866E-04,   8.3589263E-04,   9.0156490E-04
     +,   9.7629469E-04,   1.0660894E-03,   1.1790424E-03
     +,   1.3245184E-03,   1.5116415E-03,   1.7472085E-03
     +,   2.0334667E-03,   2.3663202E-03,   2.7344755E-03
     +,   3.1198396E-03,   3.4991717E-03,   3.8467045E-03
     +,   4.1373288E-03,   4.3501384E-03,   4.4718822E-03
     +,   4.4991765E-03,   4.4385497E-03,   4.3037152E-03
     +,   4.1108183E-03,   3.8737105E-03,   3.6015648E-03
     +,   3.2998261E-03,   2.9736531E-03,   2.6316007E-03
     +,   2.2871636E-03,   1.9572205E-03,   1.6582650E-03
     +,   1.4024152E-03,   1.1949310E-03,   1.0339820E-03
     +,   9.1246137E-04,   8.2069426E-04,   7.4898230E-04
     +,   6.8932481E-04,   6.3614704E-04,   5.8622629E-04
     +,   5.3815666E-04,   4.9168809E-04,   4.4714363E-04
     +,   4.0500614E-04,   3.6567223E-04,   3.2934928E-04
     +,   2.9604923E-04,   2.6563319E-04,   2.3786539E-04
     +,   2.1247432E-04,   1.8919924E-04,   1.6781634E-04
     +,   1.4814924E-04,   1.3007045E-04,   1.1349348E-04
     +,   9.8359422E-05,   8.4623221E-05,   7.2244358E-05
     +,   6.1179577E-05,   5.1377148E-05,   4.2774143E-05
     +,   3.5297424E-05,   2.8865436E-05,   2.3389091E-05
     +,   1.8775223E-05,   1.4929547E-05,   1.1758762E-05
     +,   9.1726824E-06,   7.0864144E-06,   5.4217890E-06
     +,   4.1081180E-06,   3.0826482E-06,   2.2907925E-06
     +,   1.6859292E-06,   1.2288469E-06,   8.8708492E-07
     +,   6.3422505E-07,   4.4910337E-07,   3.1497120E-07
     +,   2.1878083E-07,   1.5050800E-07,   1.0254566E-07
     +,   6.9192922E-08,   4.6234756E-08,   3.0592958E-08
     +,   2.0044773E-08,   1.3003927E-08,   8.3522949E-09
     +,   5.3109277E-09,   3.3430527E-09,   2.0829867E-09
     +,   1.2845818E-09,   7.8406476E-10,   4.7360904E-10
     +,   2.8309388E-10,   1.6744107E-10,   9.7993606E-11
     +,   5.6742236E-11,   3.2505530E-11,   1.8422016E-11
     +,   1.0328479E-11,   5.7283505E-12,   3.1426333E-12
     +,   1.7053879E-12,   9.1541347E-13,   4.8602306E-13
     +,   2.5522602E-13,   1.3256762E-13,   6.8105901E-14
     +,   3.4606761E-14,   1.7393517E-14,   8.6476761E-15
     +,   4.2533179E-15,   2.0698218E-15,   9.9687646E-16
     +,   4.7539671E-16,   2.2463801E-16,   1.0530083E-16
     +,   4.9064622E-17,   2.2797515E-17,   1.0616542E-17
     +,   4.9938325E-18,   2.3995656E-18,   1.1949419E-18
     +,   6.2633237E-19,   3.4972359E-19,   2.0876433E-19
     +,   1.3238571E-19,   8.8039792E-20,   6.0531617E-20
     +,   4.2511616E-20,   3.0232072E-20,   2.1645666E-20
     +,   1.5548666E-20,   1.1182444E-20,   8.0421932E-21
     +,   5.7797513E-21,   4.1493872E-21,   2.9751388E-21
     +,   2.1302316E-21,   1.5230569E-21,   1.0873498E-21
     +,   7.7512220E-22,   5.5171473E-22,   3.9210590E-22
     +,   2.7825108E-22,   1.9715705E-22,   1.3948342E-22
     +,   9.8532324E-23,   6.9497428E-23,   4.8944484E-23
     +,   3.4417045E-23,   2.4164878E-23,   1.6940638E-23
     +,   1.1858202E-23,   8.2877813E-24,   5.7836623E-24
     +,   4.0299444E-24,   2.8037432E-24,   1.9476550E-24
     +,   1.3508854E-24,   9.3555107E-25,   6.4691510E-25
     +,   4.4665196E-25,   3.0790733E-25,   2.1194079E-25
     +,   1.4565910E-25,   9.9954914E-26,   6.8485570E-26
     +,   4.6852991E-26,   3.2003964E-26,   2.1827886E-26
     +,   1.4864523E-26,   1.0107179E-26
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_hatt85 = Yx/0.0266451612903226
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3505339E-06,   7.5487487E-06
     +,   7.7463728E-06,   7.9431429E-06,   8.1388007E-06
     +,   8.3331042E-06,   8.5258380E-06,   8.7168173E-06
     +,   8.9058913E-06,   9.0929616E-06,   9.2779828E-06
     +,   9.4609859E-06,   9.6420808E-06,   9.8214805E-06
     +,   9.9995177E-06,   1.0176659E-05,   1.0353536E-05
     +,   1.0530959E-05,   1.0709953E-05,   1.0891777E-05
     +,   1.1077969E-05,   1.1270356E-05,   1.1471098E-05
     +,   1.1682740E-05,   1.1908197E-05,   1.2150842E-05
     +,   1.2414504E-05,   1.2703507E-05,   1.3022696E-05
     +,   1.3377447E-05,   1.3773711E-05,   1.4217992E-05
     +,   1.4717366E-05,   1.5279473E-05,   1.5912483E-05
     +,   1.6625110E-05,   1.7426517E-05,   1.8326309E-05
     +,   1.9334513E-05,   2.0461361E-05,   2.1717442E-05
     +,   2.3113425E-05,   2.4660061E-05,   2.6368096E-05
     +,   2.8248158E-05,   3.0310701E-05,   3.2565902E-05
     +,   3.5023586E-05,   3.7693182E-05,   4.0583654E-05
     +,   4.3703429E-05,   4.7060399E-05,   5.0661798E-05
     +,   5.4514461E-05,   5.8624119E-05,   6.2996289E-05
     +,   6.7635367E-05,   7.2545023E-05,   7.7727913E-05
     +,   8.3185623E-05,   8.8918401E-05,   9.4925097E-05
     +,   1.0120232E-04,   1.0774510E-04,   1.1454600E-04
     +,   1.2159404E-04,   1.2887592E-04,   1.3637365E-04
     +,   1.4406617E-04,   1.5192697E-04,   1.5992578E-04
     +,   1.6802622E-04,   1.7618791E-04,   1.8436428E-04
     +,   1.9250449E-04,   2.0055304E-04,   2.0844965E-04
     +,   2.1613052E-04,   2.2352960E-04,   2.3057908E-04
     +,   2.3720996E-04,   2.4335456E-04,   2.4894672E-04
     +,   2.5392423E-04,   2.5822927E-04,   2.6181093E-04
     +,   2.6462518E-04,   2.6663745E-04,   2.6782259E-04
     +,   2.6816624E-04,   2.6766525E-04,   2.6632781E-04
     +,   2.6417407E-04,   2.6123502E-04,   2.5755237E-04
     +,   2.5317815E-04,   2.4817267E-04,   2.4260436E-04
     +,   2.3654707E-04,   2.3007994E-04,   2.2328415E-04
     +,   2.1624283E-04,   2.0903783E-04,   2.0174972E-04
     +,   1.9445478E-04,   1.8722430E-04,   1.8012407E-04
     +,   1.7321260E-04,   1.6654035E-04,   1.6014931E-04
     +,   1.5407355E-04,   1.4833754E-04,   1.4295800E-04
     +,   1.3794262E-04,   1.3329201E-04,   1.2899890E-04
     +,   1.2505022E-04,   1.2142682E-04,   1.1810547E-04
     +,   1.1505913E-04,   1.1225839E-04,   1.0967312E-04
     +,   1.0727358E-04,   1.0503173E-04,   1.0292335E-04
     +,   1.0092980E-04,   9.9039811E-05,   9.7251890E-05
     +,   9.5576135E-05,   9.4036979E-05,   9.2674818E-05
     +,   9.1548580E-05,   9.0737194E-05,   9.0341462E-05
     +,   9.0485155E-05,   9.1315873E-05,   9.3005481E-05
     +,   9.5750132E-05,   9.9770521E-05,   1.0531244E-04
     +,   1.1264795E-04,   1.2207907E-04,   1.3394568E-04
     +,   1.4863716E-04,   1.6660799E-04,   1.8840468E-04
     +,   2.1469429E-04,   2.4629681E-04,   2.8422082E-04
     +,   3.2969791E-04,   3.8420115E-04,   4.4943910E-04
     +,   5.2732229E-04,   6.1988342E-04,   7.2912371E-04
     +,   8.5678045E-04,   1.0040303E-03,   1.1711470E-03
     +,   1.3571247E-03,   1.5593386E-03,   1.7733764E-03
     +,   1.9930115E-03,   2.2103987E-03,   2.4165390E-03
     +,   2.6019353E-03,   2.7573346E-03,   2.8745297E-03
     +,   2.9471063E-03,   2.9710743E-03,   2.9452937E-03
     +,   2.8716847E-03,   2.7551707E-03,   2.6033041E-03
     +,   2.4255954E-03,   2.2326251E-03,   2.0349319E-03
     +,   1.8419793E-03,   1.6612891E-03,   1.4978801E-03
     +,   1.3541217E-03,   1.2300096E-03,   1.1237344E-03
     +,   1.0323891E-03,   9.5267547E-04,   8.8148669E-04
     +,   8.1628130E-04,   7.5523357E-04,   6.9720775E-04
     +,   6.4163347E-04,   5.8833719E-04,   5.3736637E-04
     +,   4.8886717E-04,   4.4300506E-04,   3.9991763E-04
     +,   3.5969404E-04,   3.2237530E-04,   2.8795717E-04
     +,   2.5639043E-04,   2.2758142E-04,   2.0140070E-04
     +,   1.7769106E-04,   1.5627548E-04,   1.3696720E-04
     +,   1.1958218E-04,   1.0394966E-04,   8.9914218E-05
     +,   7.7340374E-05,   6.6112276E-05,   5.6129727E-05
     +,   4.7303522E-05,   3.9551836E-05,   3.2796866E-05
     +,   2.6961447E-05,   2.1967307E-05,   1.7735250E-05
     +,   1.4185946E-05,   1.1240685E-05,   8.8227089E-06
     +,   6.8589570E-06,   5.2814312E-06,   4.0277973E-06
     +,   3.0422409E-06,   2.2757561E-06,   1.6860122E-06
     +,   1.2370455E-06,   8.9884594E-07,   6.4677243E-07
     +,   4.6086566E-07,   3.2518642E-07,   2.2719645E-07
     +,   1.5716883E-07,   1.0764909E-07,   7.2997082E-08
     +,   4.9002978E-08,   3.2564806E-08,   2.1421688E-08
     +,   1.3947878E-08,   8.9886516E-09,   5.7331850E-09
     +,   3.6189731E-09,   2.2606648E-09,   1.3974533E-09
     +,   8.5483037E-10,   5.1742333E-10,   3.0990085E-10
     +,   1.8366184E-10,   1.0770954E-10,   6.2510101E-11
     +,   3.5905137E-11,   2.0416639E-11,   1.1497046E-11
     +,   6.4153067E-12,   3.5506893E-12,   1.9523784E-12
     +,   1.0691742E-12,   5.8541101E-13,   3.2240009E-13
     +,   1.8013581E-13,   1.0328955E-13,   6.1598770E-14
     +,   3.8689284E-14,   2.5786827E-14,   1.8231417E-14
     +,   1.3565794E-14,   1.0499114E-14,   8.3516771E-15
     +,   6.7621745E-15,   5.5344205E-15,   4.5576082E-15
     +,   3.7655485E-15,   3.1159581E-15,   2.5798040E-15
     +,   2.1358169E-15,   1.7675592E-15,   1.4619558E-15
     +,   1.2083850E-15,   9.9806464E-16,   8.2372927E-16
     +,   6.7931577E-16,   5.5978650E-16,   4.6092267E-16
     +,   3.7922184E-16,   3.1175466E-16,   2.5608982E-16
     +,   2.1019614E-16,   1.7239155E-16,   1.4127465E-16
     +,   1.1568192E-16,   9.4651233E-17,   7.7382005E-17
     +,   6.3213996E-17,   5.1598776E-17,   4.2084786E-17
     +,   3.4297605E-17,   2.7929423E-17,   2.2725482E-17
     +,   1.8476672E-17,   1.5010231E-17,   1.2184602E-17
     +,   9.8829670E-18,   8.0098240E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_hatt90 = Yx/0.0200344827586207
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5695292E-05,   1.6348133E-05
     +,   1.7013550E-05,   1.7691404E-05,   1.8381621E-05
     +,   1.9084158E-05,   1.9799054E-05,   2.0526400E-05
     +,   2.1266364E-05,   2.2019203E-05,   2.2785236E-05
     +,   2.3564873E-05,   2.4358595E-05,   2.5166974E-05
     +,   2.5990646E-05,   2.6830332E-05,   2.7686810E-05
     +,   2.8560913E-05,   2.9453522E-05,   3.0365549E-05
     +,   3.1297910E-05,   3.2251537E-05,   3.3227308E-05
     +,   3.4226123E-05,   3.5248715E-05,   3.6295820E-05
     +,   3.7368009E-05,   3.8465707E-05,   3.9589188E-05
     +,   4.0738509E-05,   4.1913518E-05,   4.3113807E-05
     +,   4.4338678E-05,   4.5587152E-05,   4.6857931E-05
     +,   4.8149363E-05,   4.9459471E-05,   5.0785860E-05
     +,   5.2125892E-05,   5.3476371E-05,   5.4833898E-05
     +,   5.6194622E-05,   5.7554378E-05,   5.8908652E-05
     +,   6.0252612E-05,   6.1581188E-05,   6.2889019E-05
     +,   6.4170563E-05,   6.5420107E-05,   6.6631808E-05
     +,   6.7799767E-05,   6.8918067E-05,   6.9980837E-05
     +,   7.0982314E-05,   7.1916838E-05,   7.2779061E-05
     +,   7.3563824E-05,   7.4266318E-05,   7.4882133E-05
     +,   7.5407290E-05,   7.5838259E-05,   7.6172080E-05
     +,   7.6406308E-05,   7.6539109E-05,   7.6569268E-05
     +,   7.6496181E-05,   7.6319928E-05,   7.6041200E-05
     +,   7.5661366E-05,   7.5182455E-05,   7.4607065E-05
     +,   7.3938500E-05,   7.3180534E-05,   7.2337636E-05
     +,   7.1414703E-05,   7.0417111E-05,   6.9350754E-05
     +,   6.8221932E-05,   6.7037268E-05,   6.5803666E-05
     +,   6.4528467E-05,   6.3219079E-05,   6.1883249E-05
     +,   6.0528804E-05,   5.9163791E-05,   5.7796249E-05
     +,   5.6434459E-05,   5.5086595E-05,   5.3761050E-05
     +,   5.2466105E-05,   5.1210092E-05,   5.0001421E-05
     +,   4.8848531E-05,   4.7759764E-05,   4.6743473E-05
     +,   4.5808145E-05,   4.4962097E-05,   4.4213739E-05
     +,   4.3571363E-05,   4.3043299E-05,   4.2637683E-05
     +,   4.2362633E-05,   4.2226031E-05,   4.2235566E-05
     +,   4.2398620E-05,   4.2722244E-05,   4.3212975E-05
     +,   4.3876797E-05,   4.4719050E-05,   4.5744320E-05
     +,   4.6956142E-05,   4.8357189E-05,   4.9948743E-05
     +,   5.1731000E-05,   5.3702446E-05,   5.5860266E-05
     +,   5.8199676E-05,   6.0714407E-05,   6.3395979E-05
     +,   6.6234243E-05,   6.9217080E-05,   7.2330186E-05
     +,   7.5557298E-05,   7.8880410E-05,   8.2279723E-05
     +,   8.5733380E-05,   8.9218382E-05,   9.2709961E-05
     +,   9.6182572E-05,   9.9609446E-05,   1.0296354E-04
     +,   1.0621714E-04,   1.0934311E-04,   1.1231428E-04
     +,   1.1510481E-04,   1.1769011E-04,   1.2004749E-04
     +,   1.2215679E-04,   1.2400122E-04,   1.2556798E-04
     +,   1.2684906E-04,   1.2784239E-04,   1.2855280E-04
     +,   1.2899318E-04,   1.2918550E-04,   1.2916178E-04
     +,   1.2896481E-04,   1.2864840E-04,   1.2827705E-04
     +,   1.2792458E-04,   1.2767172E-04,   1.2760279E-04
     +,   1.2780057E-04,   1.2834019E-04,   1.2928214E-04
     +,   1.3066476E-04,   1.3249698E-04,   1.3475302E-04
     +,   1.3736961E-04,   1.4024801E-04,   1.4326411E-04
     +,   1.4628809E-04,   1.4921674E-04,   1.5202234E-04
     +,   1.5481608E-04,   1.5792309E-04,   1.6195764E-04
     +,   1.6788137E-04,   1.7702389E-04,   1.9105199E-04
     +,   2.1189822E-04,   2.4170424E-04,   2.8287902E-04
     +,   3.3837903E-04,   4.1226804E-04,   5.1053363E-04
     +,   6.4196321E-04,   8.1887521E-04,   1.0575557E-03
     +,   1.3781952E-03,   1.8038707E-03,   2.3578391E-03
     +,   3.0586701E-03,   3.9135017E-03,   4.9105720E-03
     +,   6.0126712E-03,   7.1530850E-03,   8.2358215E-03
     +,   9.1432277E-03,   9.7545953E-03,   9.9747917E-03
     +,   9.7631942E-03,   9.1494145E-03,   8.2261469E-03
     +,   7.1214861E-03,   5.9643155E-03,   4.8576919E-03
     +,   3.8675598E-03,   3.0252268E-03,   2.3367757E-03
     +,   1.7928137E-03,   1.3756242E-03,   1.0638456E-03
     +,   8.3563110E-04,   6.7077635E-04,   5.5192999E-04
     +,   4.6507214E-04,   3.9938660E-04,   3.4688675E-04
     +,   3.0202334E-04,   2.6132917E-04,   2.2304515E-04
     +,   1.8668645E-04,   1.5257321E-04,   1.2139044E-04
     +,   9.3834344E-05,   7.0380163E-05,   5.1179257E-05
     +,   3.6064528E-05,   2.4621277E-05,   1.6283328E-05
     +,   1.0432593E-05,   6.4765236E-06,   3.8972107E-06
     +,   2.2745430E-06,   1.2889469E-06,   7.1063380E-07
     +,   3.8256351E-07,   2.0242312E-07,   1.0651912E-07
     +,   5.6867815E-08,   3.1729218E-08,   1.9149468E-08
     +,   1.2807527E-08,   9.4839852E-09,   7.5964266E-09
     +,   6.3930483E-09,   5.5269460E-09,   4.8412696E-09
     +,   4.2652721E-09,   3.7660746E-09,   3.3270910E-09
     +,   2.9386640E-09,   2.5941644E-09,   2.2884472E-09
     +,   2.0172026E-09,   1.7766764E-09,   1.5635243E-09
     +,   1.3747660E-09,   1.2077572E-09,   1.0601076E-09
     +,   9.2968300E-10,   8.1457785E-10,   7.1308781E-10
     +,   6.2368039E-10,   5.4498756E-10,   4.7579229E-10
     +,   4.1500578E-10,   3.6165590E-10,   3.1487499E-10
     +,   2.7389446E-10,   2.3803032E-10,   2.0667308E-10
     +,   1.7928131E-10,   1.5537779E-10,   1.3453780E-10
     +,   1.1638543E-10,   1.0058980E-10,   8.6858361E-11
     +,   7.4932414E-11,   6.4584310E-11,   5.5614020E-11
     +,   4.7845807E-11,   4.1124829E-11,   3.5315230E-11
     +,   3.0298628E-11,   2.5970569E-11,   2.2240395E-11
     +,   1.9028347E-11,   1.6265300E-11,   1.3890597E-11
     +,   1.1851742E-11,   1.0102779E-11,   8.6040194E-12
     +,   7.3208340E-12,   6.2233070E-12,   5.2854457E-12
     +,   4.4847693E-12,   3.8018985E-12,   3.2200165E-12
     +,   2.7247007E-12,   2.3034367E-12,   1.9455188E-12
     +,   1.6416960E-12,   1.3840496E-12,   1.1657565E-12
     +,   9.8099621E-13,   8.2475086E-13,   6.9275678E-13
     +,   5.8134807E-13,   4.8740889E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_hatt95 = Yx/0.0345757575757576
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1968069E-04,   1.2397429E-04
     +,   1.2832138E-04,   1.3271619E-04,   1.3715266E-04
     +,   1.4162442E-04,   1.4612493E-04,   1.5064742E-04
     +,   1.5518483E-04,   1.5973029E-04,   1.6427659E-04
     +,   1.6881648E-04,   1.7334281E-04,   1.7784827E-04
     +,   1.8232576E-04,   1.8676833E-04,   1.9116903E-04
     +,   1.9552135E-04,   1.9981868E-04,   2.0405503E-04
     +,   2.0822437E-04,   2.1232128E-04,   2.1634060E-04
     +,   2.2027781E-04,   2.2412826E-04,   2.2788835E-04
     +,   2.3155473E-04,   2.3512448E-04,   2.3859530E-04
     +,   2.4196533E-04,   2.4523318E-04,   2.4839820E-04
     +,   2.5146001E-04,   2.5441917E-04,   2.5727623E-04
     +,   2.6003271E-04,   2.6269042E-04,   2.6525164E-04
     +,   2.6771962E-04,   2.7009734E-04,   2.7238886E-04
     +,   2.7459842E-04,   2.7673069E-04,   2.7879092E-04
     +,   2.8078453E-04,   2.8271749E-04,   2.8459608E-04
     +,   2.8642680E-04,   2.8821666E-04,   2.8997267E-04
     +,   2.9170231E-04,   2.9341315E-04,   2.9511287E-04
     +,   2.9680942E-04,   2.9851080E-04,   3.0022513E-04
     +,   3.0196036E-04,   3.0372426E-04,   3.0552529E-04
     +,   3.0737085E-04,   3.0926862E-04,   3.1122597E-04
     +,   3.1324988E-04,   3.1534716E-04,   3.1752416E-04
     +,   3.1978649E-04,   3.2213982E-04,   3.2458876E-04
     +,   3.2713747E-04,   3.2978965E-04,   3.3254808E-04
     +,   3.3541501E-04,   3.3839178E-04,   3.4147891E-04
     +,   3.4467652E-04,   3.4798373E-04,   3.5139878E-04
     +,   3.5491891E-04,   3.5854097E-04,   3.6226108E-04
     +,   3.6607412E-04,   3.6997462E-04,   3.7395608E-04
     +,   3.7801146E-04,   3.8213294E-04,   3.8631217E-04
     +,   3.9053979E-04,   3.9480650E-04,   3.9910147E-04
     +,   4.0341364E-04,   4.0773212E-04,   4.1204441E-04
     +,   4.1633777E-04,   4.2059913E-04,   4.2481488E-04
     +,   4.2897076E-04,   4.3305216E-04,   4.3704390E-04
     +,   4.4093080E-04,   4.4469669E-04,   4.4832536E-04
     +,   4.5180047E-04,   4.5510550E-04,   4.5822322E-04
     +,   4.6113698E-04,   4.6383013E-04,   4.6628612E-04
     +,   4.6848826E-04,   4.7042081E-04,   4.7206890E-04
     +,   4.7341723E-04,   4.7445259E-04,   4.7516241E-04
     +,   4.7553520E-04,   4.7556069E-04,   4.7523068E-04
     +,   4.7453851E-04,   4.7347863E-04,   4.7204888E-04
     +,   4.7024741E-04,   4.6807571E-04,   4.6553736E-04
     +,   4.6263781E-04,   4.5938476E-04,   4.5578839E-04
     +,   4.5186112E-04,   4.4761738E-04,   4.4307366E-04
     +,   4.3824842E-04,   4.3316261E-04,   4.2783783E-04
     +,   4.2229844E-04,   4.1656898E-04,   4.1067629E-04
     +,   4.0464851E-04,   3.9851366E-04,   3.9230176E-04
     +,   3.8604325E-04,   3.7976925E-04,   3.7351093E-04
     +,   3.6730093E-04,   3.6117181E-04,   3.5515701E-04
     +,   3.4928974E-04,   3.4360448E-04,   3.3813616E-04
     +,   3.3291979E-04,   3.2799196E-04,   3.2338951E-04
     +,   3.1915001E-04,   3.1531215E-04,   3.1191582E-04
     +,   3.0900163E-04,   3.0661121E-04,   3.0478730E-04
     +,   3.0357367E-04,   3.0301535E-04,   3.0315804E-04
     +,   3.0404827E-04,   3.0573408E-04,   3.0826396E-04
     +,   3.1168797E-04,   3.1605698E-04,   3.2142302E-04
     +,   3.2784013E-04,   3.3536466E-04,   3.4405486E-04
     +,   3.5397205E-04,   3.6518188E-04,   3.7775550E-04
     +,   3.9176861E-04,   4.0730523E-04,   4.2445818E-04
     +,   4.4333277E-04,   4.6404521E-04,   4.8672938E-04
     +,   5.1153929E-04,   5.3864910E-04,   5.6825852E-04
     +,   6.0059864E-04,   6.3593185E-04,   6.7455193E-04
     +,   7.1678613E-04,   7.6299510E-04,   8.1356749E-04
     +,   8.6890458E-04,   9.2941313E-04,   9.9549373E-04
     +,   1.0675127E-03,   1.1457747E-03,   1.2305091E-03
     +,   1.3218349E-03,   1.4197307E-03,   1.5240174E-03
     +,   1.6343548E-03,   1.7502320E-03,   1.8709786E-03
     +,   1.9958059E-03,   2.1238674E-03,   2.2543261E-03
     +,   2.3864240E-03,   2.5195654E-03,   2.6533918E-03
     +,   2.7877984E-03,   2.9229177E-03,   3.0591260E-03
     +,   3.1969829E-03,   3.3372105E-03,   3.4807180E-03
     +,   3.6286921E-03,   3.7827014E-03,   3.9448026E-03
     +,   4.1176020E-03,   4.3042488E-03,   4.5083282E-03
     +,   4.7337860E-03,   4.9850992E-03,   5.2677728E-03
     +,   5.5891532E-03,   5.9592249E-03,   6.3908999E-03
     +,   6.8988446E-03,   7.4965404E-03,   8.1919543E-03
     +,   8.9832535E-03,   9.8563908E-03,   1.0786261E-02
     +,   1.1741744E-02,   1.2692715E-02,   1.3616047E-02
     +,   1.4497747E-02,   1.5330959E-02,   1.6110655E-02
     +,   1.6829133E-02,   1.7474314E-02,   1.8033179E-02
     +,   1.8498003E-02,   1.8871417E-02,   1.9165594E-02
     +,   1.9393001E-02,   1.9551842E-02,   1.9614749E-02
     +,   1.9529438E-02,   1.9234573E-02,   1.8684654E-02
     +,   1.7871821E-02,   1.6833425E-02,   1.5641890E-02
     +,   1.4382862E-02,   1.3132026E-02,   1.1939531E-02
     +,   1.0826514E-02,   9.7914897E-03,   8.8213421E-03
     +,   7.9019796E-03,   7.0251166E-03,   6.1906520E-03
     +,   5.4050977E-03,   4.6782196E-03,   4.0194849E-03
     +,   3.4353598E-03,   2.9278132E-03,   2.4941964E-03
     +,   2.1281296E-03,   1.8209277E-03,   1.5629932E-03
     +,   1.3450907E-03,   1.1591983E-03,   9.9888176E-04
     +,   8.5932593E-04,   7.3713408E-04,   6.2999188E-04
     +,   5.3629902E-04,   4.5485306E-04,   3.8463000E-04
     +,   3.2465011E-04,   2.7390357E-04,   2.3135706E-04
     +,   1.9596542E-04,   1.6671949E-04,   1.4267006E-04
     +,   1.2296137E-04,   1.0683824E-04,   9.3654395E-05
     +,   8.2863342E-05,   7.4012343E-05,   6.6727844E-05
     +,   6.0704431E-05,   5.5693909E-05,   5.1494109E-05
     +,   4.7941929E-05,   4.4905373E-05,   4.2278909E-05
     +,   3.9978058E-05,   3.7936330E-05,   3.6101388E-05
     +,   3.4432996E-05,   3.2900203E-05,   3.1479893E-05
     +,   3.0154790E-05,   2.8912465E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_hatt100 = Yx/0.166568181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1734520E-04,   4.3667579E-04
     +,   4.5615158E-04,   4.7571160E-04,   4.9529242E-04
     +,   5.1482848E-04,   5.3425325E-04,   5.5349874E-04
     +,   5.7249668E-04,   5.9118005E-04,   6.0948130E-04
     +,   6.2733598E-04,   6.4468035E-04,   6.6145457E-04
     +,   6.7760178E-04,   6.9306925E-04,   7.0780818E-04
     +,   7.2177500E-04,   7.3493231E-04,   7.4724696E-04
     +,   7.5869297E-04,   7.6925033E-04,   7.7890453E-04
     +,   7.8764983E-04,   7.9548452E-04,   8.0241461E-04
     +,   8.0845290E-04,   8.1361714E-04,   8.1793213E-04
     +,   8.2142762E-04,   8.2413916E-04,   8.2610617E-04
     +,   8.2737359E-04,   8.2798954E-04,   8.2800625E-04
     +,   8.2747830E-04,   8.2646171E-04,   8.2501525E-04
     +,   8.2319981E-04,   8.2107406E-04,   8.1869873E-04
     +,   8.1613229E-04,   8.1343431E-04,   8.1065932E-04
     +,   8.0786267E-04,   8.0509449E-04,   8.0240268E-04
     +,   7.9983199E-04,   7.9742156E-04,   7.9520699E-04
     +,   7.9321855E-04,   7.9148210E-04,   7.9001772E-04
     +,   7.8884041E-04,   7.8795897E-04,   7.8737870E-04
     +,   7.8709685E-04,   7.8710733E-04,   7.8739808E-04
     +,   7.8795291E-04,   7.8875077E-04,   7.8976632E-04
     +,   7.9097069E-04,   7.9233258E-04,   7.9381763E-04
     +,   7.9538929E-04,   7.9701038E-04,   7.9864252E-04
     +,   8.0024794E-04,   8.0178975E-04,   8.0323161E-04
     +,   8.0454018E-04,   8.0568448E-04,   8.0663688E-04
     +,   8.0737408E-04,   8.0787559E-04,   8.0812786E-04
     +,   8.0812065E-04,   8.0784998E-04,   8.0731662E-04
     +,   8.0652698E-04,   8.0549321E-04,   8.0423069E-04
     +,   8.0276281E-04,   8.0111483E-04,   7.9931668E-04
     +,   7.9740246E-04,   7.9540792E-04,   7.9337205E-04
     +,   7.9133408E-04,   7.8933511E-04,   7.8741554E-04
     +,   7.8561413E-04,   7.8396779E-04,   7.8251236E-04
     +,   7.8128034E-04,   7.8029832E-04,   7.7958975E-04
     +,   7.7917386E-04,   7.7906263E-04,   7.7926333E-04
     +,   7.7977747E-04,   7.8059977E-04,   7.8171969E-04
     +,   7.8311999E-04,   7.8477780E-04,   7.8666501E-04
     +,   7.8874920E-04,   7.9099234E-04,   7.9335255E-04
     +,   7.9578691E-04,   7.9824618E-04,   8.0068345E-04
     +,   8.0304808E-04,   8.0529135E-04,   8.0736325E-04
     +,   8.0921728E-04,   8.1080862E-04,   8.1209373E-04
     +,   8.1303436E-04,   8.1359735E-04,   8.1375235E-04
     +,   8.1347569E-04,   8.1274798E-04,   8.1155723E-04
     +,   8.0989569E-04,   8.0776273E-04,   8.0516405E-04
     +,   8.0211082E-04,   7.9862028E-04,   7.9471432E-04
     +,   7.9042075E-04,   7.8577164E-04,   7.8080414E-04
     +,   7.7555788E-04,   7.7007618E-04,   7.6440535E-04
     +,   7.5859344E-04,   7.5268873E-04,   7.4674195E-04
     +,   7.4080209E-04,   7.3492015E-04,   7.2914344E-04
     +,   7.2351901E-04,   7.1809144E-04,   7.1290362E-04
     +,   7.0799375E-04,   7.0339901E-04,   6.9915131E-04
     +,   6.9527986E-04,   6.9180818E-04,   6.8875880E-04
     +,   6.8614807E-04,   6.8398932E-04,   6.8229123E-04
     +,   6.8106025E-04,   6.8029907E-04,   6.8000739E-04
     +,   6.8018213E-04,   6.8081904E-04,   6.8191189E-04
     +,   6.8345421E-04,   6.8543828E-04,   6.8785815E-04
     +,   6.9070724E-04,   6.9398148E-04,   6.9767906E-04
     +,   7.0180034E-04,   7.0634857E-04,   7.1133149E-04
     +,   7.1675784E-04,   7.2264246E-04,   7.2900206E-04
     +,   7.3585764E-04,   7.4323249E-04,   7.5115287E-04
     +,   7.5964857E-04,   7.6875096E-04,   7.7849312E-04
     +,   7.8891282E-04,   8.0005033E-04,   8.1195077E-04
     +,   8.2466466E-04,   8.3825219E-04,   8.5278467E-04
     +,   8.6834602E-04,   8.8503945E-04,   9.0298738E-04
     +,   9.2233962E-04,   9.4326911E-04,   9.6598268E-04
     +,   9.9071569E-04,   1.0177339E-03,   1.0473285E-03
     +,   1.0798174E-03,   1.1155367E-03,   1.1548273E-03
     +,   1.1980307E-03,   1.2454782E-03,   1.2974776E-03
     +,   1.3542983E-03,   1.4161598E-03,   1.4832281E-03
     +,   1.5556056E-03,   1.6333151E-03,   1.7163163E-03
     +,   1.8044915E-03,   1.8976495E-03,   1.9955297E-03
     +,   2.0978129E-03,   2.2041253E-03,   2.3140304E-03
     +,   2.4270429E-03,   2.5426289E-03,   2.6602272E-03
     +,   2.7792361E-03,   2.8990696E-03,   3.0191846E-03
     +,   3.1391669E-03,   3.2587789E-03,   3.3781179E-03
     +,   3.4976990E-03,   3.6185756E-03,   3.7424774E-03
     +,   3.8718821E-03,   4.0100561E-03,   4.1610287E-03
     +,   4.3294989E-03,   4.5206784E-03,   4.7400109E-03
     +,   4.9928343E-03,   5.2839676E-03,   5.6173010E-03
     +,   5.9953667E-03,   6.4189089E-03,   6.8867095E-03
     +,   7.3954226E-03,   7.9397280E-03,   8.5126525E-03
     +,   9.1061611E-03,   9.7118812E-03,   1.0321772E-02
     +,   1.0928787E-02,   1.1527389E-02,   1.2113489E-02
     +,   1.2684109E-02,   1.3236503E-02,   1.3767325E-02
     +,   1.4271357E-02,   1.4740522E-02,   1.5163518E-02
     +,   1.5525684E-02,   1.5809825E-02,   1.5997393E-02
     +,   1.6070351E-02,   1.6012946E-02,   1.5813606E-02
     +,   1.5466323E-02,   1.4971788E-02,   1.4337476E-02
     +,   1.3577722E-02,   1.2712507E-02,   1.1766130E-02
     +,   1.0765482E-02,   9.7383149E-03,   8.7112775E-03
     +,   7.7084340E-03,   6.7502242E-03,   5.8526788E-03
     +,   5.0271000E-03,   4.2802808E-03,   3.6150343E-03
     +,   3.0307462E-03,   2.5240972E-03,   2.0898799E-03
     +,   1.7216926E-03,   1.4124478E-03,   1.1549362E-03
     +,   9.4210595E-04,   7.6737494E-04,   6.2472990E-04
     +,   5.0885102E-04,   4.1509295E-04,   3.3949327E-04
     +,   2.7869790E-04,   2.2991696E-04,   1.9083840E-04
     +,   1.5956505E-04,   1.3455092E-04,   1.1453527E-04
     +,   9.8499193E-05,   8.5616703E-05,   7.5223412E-05
     +,   6.6783796E-05,   5.9869875E-05,   5.4139578E-05
     +,   4.9322753E-05,   4.5206718E-05,   4.1626950E-05
     +,   3.8457183E-05,   3.5602952E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_hatt102 = Yx/0.166090909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7906079E-04,   1.8810034E-04
     +,   1.9741968E-04,   2.0702348E-04,   2.1691788E-04
     +,   2.2711090E-04,   2.3761271E-04,   2.4843623E-04
     +,   2.5959761E-04,   2.7111729E-04,   2.8301918E-04
     +,   2.9533246E-04,   3.0809123E-04,   3.2133466E-04
     +,   3.3510756E-04,   3.4945933E-04,   3.6444410E-04
     +,   3.8011922E-04,   3.9654411E-04,   4.1377844E-04
     +,   4.3187951E-04,   4.5089988E-04,   4.7088350E-04
     +,   4.9186411E-04,   5.1385775E-04,   5.3686363E-04
     +,   5.6085747E-04,   5.8578956E-04,   6.1158219E-04
     +,   6.3812907E-04,   6.6529383E-04,   6.9291331E-04
     +,   7.2080031E-04,   7.4874843E-04,   7.7654026E-04
     +,   8.0395467E-04,   8.3078077E-04,   8.5682626E-04
     +,   8.8193623E-04,   9.0599858E-04,   9.2896377E-04
     +,   9.5085247E-04,   9.7176502E-04,   9.9188811E-04
     +,   1.0114958E-03,   1.0309459E-03,   1.0506742E-03
     +,   1.0711799E-03,   1.0930090E-03,   1.1167330E-03
     +,   1.1429236E-03,   1.1721280E-03,   1.2048417E-03
     +,   1.2414876E-03,   1.2823909E-03,   1.3277716E-03
     +,   1.3777299E-03,   1.4322483E-03,   1.4912024E-03
     +,   1.5543696E-03,   1.6214510E-03,   1.6921051E-03
     +,   1.7659623E-03,   1.8426669E-03,   1.9219033E-03
     +,   2.0033997E-03,   2.0869724E-03,   2.1725071E-03
     +,   2.2599827E-03,   2.3494447E-03,   2.4410130E-03
     +,   2.5348484E-03,   2.6311511E-03,   2.7301265E-03
     +,   2.8319922E-03,   2.9369381E-03,   3.0451147E-03
     +,   3.1566143E-03,   3.2714298E-03,   3.3894200E-03
     +,   3.5102237E-03,   3.6332456E-03,   3.7575234E-03
     +,   3.8817304E-03,   4.0040817E-03,   4.1223499E-03
     +,   4.2338730E-03,   4.3356544E-03,   4.4244477E-03
     +,   4.4969488E-03,   4.5499704E-03,   4.5806565E-03
     +,   4.5866836E-03,   4.5664459E-03,   4.5191837E-03
     +,   4.4450890E-03,   4.3453090E-03,   4.2219306E-03
     +,   4.0778494E-03,   3.9166515E-03,   3.7424017E-03
     +,   3.5594397E-03,   3.3721318E-03,   3.1846920E-03
     +,   3.0009402E-03,   2.8241714E-03,   2.6570335E-03
     +,   2.5014584E-03,   2.3586256E-03,   2.2290063E-03
     +,   2.1124484E-03,   2.0082465E-03,   1.9152934E-03
     +,   1.8321880E-03,   1.7573910E-03,   1.6893260E-03
     +,   1.6264920E-03,   1.5675388E-03,   1.5113293E-03
     +,   1.4569624E-03,   1.4037880E-03,   1.3514011E-03
     +,   1.2996137E-03,   1.2484217E-03,   1.1979645E-03
     +,   1.1484926E-03,   1.1003163E-03,   1.0537804E-03
     +,   1.0092214E-03,   9.6695451E-04,   9.2724507E-04
     +,   8.9030567E-04,   8.5627899E-04,   8.2524819E-04
     +,   7.9722871E-04,   7.7217916E-04,   7.5000984E-04
     +,   7.3058764E-04,   7.1374571E-04,   6.9929328E-04
     +,   6.8702456E-04,   6.7672360E-04,   6.6817307E-04
     +,   6.6115666E-04,   6.5546628E-04,   6.5090432E-04
     +,   6.4728473E-04,   6.4443727E-04,   6.4220821E-04
     +,   6.4045907E-04,   6.3906988E-04,   6.3793769E-04
     +,   6.3697691E-04,   6.3611887E-04,   6.3530990E-04
     +,   6.3451286E-04,   6.3370517E-04,   6.3287560E-04
     +,   6.3202530E-04,   6.3116639E-04,   6.3031778E-04
     +,   6.2950718E-04,   6.2876591E-04,   6.2813080E-04
     +,   6.2763924E-04,   6.2733016E-04,   6.2724174E-04
     +,   6.2740990E-04,   6.2786875E-04,   6.2864757E-04
     +,   6.2977162E-04,   6.3126150E-04,   6.3313171E-04
     +,   6.3539203E-04,   6.3804595E-04,   6.4109190E-04
     +,   6.4452284E-04,   6.4832618E-04,   6.5248495E-04
     +,   6.5697829E-04,   6.6178059E-04,   6.6686346E-04
     +,   6.7219522E-04,   6.7774160E-04,   6.8346708E-04
     +,   6.8933441E-04,   6.9530366E-04,   7.0133671E-04
     +,   7.0739299E-04,   7.1343308E-04,   7.1941665E-04
     +,   7.2530488E-04,   7.3105859E-04,   7.3663960E-04
     +,   7.4201036E-04,   7.4713450E-04,   7.5197621E-04
     +,   7.5650006E-04,   7.6067302E-04,   7.6446176E-04
     +,   7.6783425E-04,   7.7076029E-04,   7.7320985E-04
     +,   7.7515584E-04,   7.7657081E-04,   7.7743147E-04
     +,   7.7771465E-04,   7.7740097E-04,   7.7647367E-04
     +,   7.7491853E-04,   7.7272643E-04,   7.6989137E-04
     +,   7.6641125E-04,   7.6229032E-04,   7.5753534E-04
     +,   7.5216062E-04,   7.4618420E-04,   7.3963008E-04
     +,   7.3252531E-04,   7.2490406E-04,   7.1680348E-04
     +,   7.0826418E-04,   6.9933041E-04,   6.9004920E-04
     +,   6.8046857E-04,   6.7063718E-04,   6.6060410E-04
     +,   6.5041776E-04,   6.4012432E-04,   6.2976760E-04
     +,   6.1938836E-04,   6.0902396E-04,   5.9870683E-04
     +,   5.8846461E-04,   5.7832123E-04,   5.6829391E-04
     +,   5.5839587E-04,   5.4863514E-04,   5.3901551E-04
     +,   5.2953517E-04,   5.2018947E-04,   5.1096937E-04
     +,   5.0186395E-04,   4.9285934E-04,   4.8393910E-04
     +,   4.7508685E-04,   4.6628498E-04,   4.5751591E-04
     +,   4.4876192E-04,   4.4000742E-04,   4.3123690E-04
     +,   4.2243648E-04,   4.1359497E-04,   4.0470302E-04
     +,   3.9575296E-04,   3.8673973E-04,   3.7766062E-04
     +,   3.6851576E-04,   3.5930678E-04,   3.5003750E-04
     +,   3.4071421E-04,   3.3134519E-04,   3.2193985E-04
     +,   3.1250872E-04,   3.0306494E-04,   2.9362153E-04
     +,   2.8419221E-04,   2.7479223E-04,   2.6543703E-04
     +,   2.5614165E-04,   2.4692109E-04,   2.3779104E-04
     +,   2.2876674E-04,   2.1986241E-04,   2.1109157E-04
     +,   2.0246801E-04,   1.9400372E-04,   1.8571064E-04
     +,   1.7759901E-04,   1.6967891E-04,   1.6195860E-04
     +,   1.5444601E-04,   1.4714728E-04,   1.4006837E-04
     +,   1.3321334E-04,   1.2658596E-04,   1.2018861E-04
     +,   1.1402243E-04,   1.0808848E-04,   1.0238610E-04
     +,   9.6914562E-05,   9.1671565E-05,   8.6654982E-05
     +,   8.1861181E-05,   7.7286728E-05,   7.2926989E-05
     +,   6.8777430E-05,   6.4832588E-05,   6.1087158E-05
     +,   5.7535031E-05,   5.4170319E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_hatt75 = Yx/0.0768157894736842
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.9651621E-05,   9.4377581E-05
     +,   9.9374200E-05,   1.0465500E-04,   1.1023316E-04
     +,   1.1612142E-04,   1.2233178E-04,   1.2887533E-04
     +,   1.3576189E-04,   1.4300036E-04,   1.5059760E-04
     +,   1.5855896E-04,   1.6688785E-04,   1.7558550E-04
     +,   1.8465117E-04,   1.9408161E-04,   2.0387139E-04
     +,   2.1401285E-04,   2.2449595E-04,   2.3530869E-04
     +,   2.4643698E-04,   2.5786515E-04,   2.6957560E-04
     +,   2.8155086E-04,   2.9377072E-04,   3.0621648E-04
     +,   3.1886864E-04,   3.3170849E-04,   3.4471889E-04
     +,   3.5788454E-04,   3.7119290E-04,   3.8463544E-04
     +,   3.9820833E-04,   4.1191399E-04,   4.2576264E-04
     +,   4.3977372E-04,   4.5397840E-04,   4.6842170E-04
     +,   4.8316614E-04,   4.9829192E-04,   5.1390333E-04
     +,   5.3012947E-04,   5.4712751E-04,   5.6508440E-04
     +,   5.8421883E-04,   6.0477963E-04,   6.2704500E-04
     +,   6.5131608E-04,   6.7791168E-04,   7.0715649E-04
     +,   7.3936867E-04,   7.7484292E-04,   8.1383175E-04
     +,   8.5652905E-04,   9.0304343E-04,   9.5338863E-04
     +,   1.0074598E-03,   1.0650323E-03,   1.1257526E-03
     +,   1.1891501E-03,   1.2546483E-03,   1.3215954E-03
     +,   1.3892913E-03,   1.4570357E-03,   1.5241740E-03
     +,   1.5901312E-03,   1.6544758E-03,   1.7169407E-03
     +,   1.7774736E-03,   1.8362377E-03,   1.8936397E-03
     +,   1.9503068E-03,   2.0070858E-03,   2.0649983E-03
     +,   2.1251985E-03,   2.1889156E-03,   2.2573755E-03
     +,   2.3317253E-03,   2.4129569E-03,   2.5018263E-03
     +,   2.5987867E-03,   2.7039617E-03,   2.8171381E-03
     +,   2.9377977E-03,   3.0651670E-03,   3.1983259E-03
     +,   3.3362550E-03,   3.4779520E-03,   3.6224565E-03
     +,   3.7689132E-03,   3.9165905E-03,   4.0649101E-03
     +,   4.2134947E-03,   4.3622544E-03,   4.5114295E-03
     +,   4.6616136E-03,   4.8137242E-03,   4.9687829E-03
     +,   5.1276507E-03,   5.2905683E-03,   5.4567843E-03
     +,   5.6241564E-03,   5.7891030E-03,   5.9467428E-03
     +,   6.0914732E-03,   6.2177293E-03,   6.3209133E-03
     +,   6.3981218E-03,   6.4486875E-03,   6.4740987E-03
     +,   6.4776242E-03,   6.4633982E-03,   6.4354902E-03
     +,   6.3969726E-03,   6.3493201E-03,   6.2922272E-03
     +,   6.2238211E-03,   6.1412253E-03,   6.0412800E-03
     +,   5.9212432E-03,   5.7793478E-03,   5.6151808E-03
     +,   5.4297345E-03,   5.2253520E-03,   5.0054262E-03
     +,   4.7741379E-03,   4.5360201E-03,   4.2956746E-03
     +,   4.0574116E-03,   3.8250282E-03,   3.6015960E-03
     +,   3.3893844E-03,   3.1897821E-03,   3.0034110E-03
     +,   2.8301869E-03,   2.6695179E-03,   2.5204797E-03
     +,   2.3819841E-03,   2.2529028E-03,   2.1321748E-03
     +,   2.0188759E-03,   1.9122204E-03,   1.8115594E-03
     +,   1.7163752E-03,   1.6262693E-03,   1.5409392E-03
     +,   1.4601711E-03,   1.3838393E-03,   1.3118880E-03
     +,   1.2443111E-03,   1.1811341E-03,   1.1224014E-03
     +,   1.0681450E-03,   1.0183583E-03,   9.7299262E-04
     +,   9.3194342E-04,   8.9505082E-04,   8.6209952E-04
     +,   8.3283143E-04,   8.0695888E-04,   7.8417099E-04
     +,   7.6415099E-04,   7.4658287E-04,   7.3116092E-04
     +,   7.1759266E-04,   7.0560275E-04,   6.9493597E-04
     +,   6.8535685E-04,   6.7664770E-04,   6.6860998E-04
     +,   6.6106435E-04,   6.5384893E-04,   6.4681936E-04
     +,   6.3984928E-04,   6.3283171E-04,   6.2567723E-04
     +,   6.1831460E-04,   6.1069214E-04,   6.0277554E-04
     +,   5.9454865E-04,   5.8601121E-04,   5.7718001E-04
     +,   5.6808663E-04,   5.5877439E-04,   5.4929883E-04
     +,   5.3972611E-04,   5.3012988E-04,   5.2059023E-04
     +,   5.1119144E-04,   5.0202204E-04,   4.9317040E-04
     +,   4.8472479E-04,   4.7677243E-04,   4.6939636E-04
     +,   4.6267587E-04,   4.5668325E-04,   4.5148545E-04
     +,   4.4714109E-04,   4.4369994E-04,   4.4120316E-04
     +,   4.3968190E-04,   4.3915736E-04,   4.3963984E-04
     +,   4.4112941E-04,   4.4361514E-04,   4.4707549E-04
     +,   4.5147823E-04,   4.5678118E-04,   4.6293176E-04
     +,   4.6986816E-04,   4.7752002E-04,   4.8580856E-04
     +,   4.9464701E-04,   5.0394400E-04,   5.1360088E-04
     +,   5.2351557E-04,   5.3358171E-04,   5.4369157E-04
     +,   5.5373635E-04,   5.6360679E-04,   5.7319563E-04
     +,   5.8239832E-04,   5.9111317E-04,   5.9924414E-04
     +,   6.0670066E-04,   6.1339949E-04,   6.1926455E-04
     +,   6.2422879E-04,   6.2823389E-04,   6.3123170E-04
     +,   6.3318381E-04,   6.3406245E-04,   6.3384970E-04
     +,   6.3253863E-04,   6.3013221E-04,   6.2664313E-04
     +,   6.2209420E-04,   6.1651581E-04,   6.0994766E-04
     +,   6.0243660E-04,   5.9403497E-04,   5.8480253E-04
     +,   5.7480251E-04,   5.6410226E-04,   5.5277144E-04
     +,   5.4088165E-04,   5.2850606E-04,   5.1571685E-04
     +,   5.0258491E-04,   4.8918097E-04,   4.7557184E-04
     +,   4.6182168E-04,   4.4799136E-04,   4.3413849E-04
     +,   4.2031516E-04,   4.0656864E-04,   3.9294298E-04
     +,   3.7947725E-04,   3.6620506E-04,   3.5315505E-04
     +,   3.4035288E-04,   3.2781978E-04,   3.1557205E-04
     +,   3.0362248E-04,   2.9198173E-04,   2.8065665E-04
     +,   2.6965063E-04,   2.5896652E-04,   2.4860460E-04
     +,   2.3856279E-04,   2.2883796E-04,   2.1942631E-04
     +,   2.1032341E-04,   2.0152349E-04,   1.9302023E-04
     +,   1.8480822E-04,   1.7688047E-04,   1.6923124E-04
     +,   1.6185368E-04,   1.5474208E-04,   1.4788992E-04
     +,   1.4129165E-04,   1.3494107E-04,   1.2883304E-04
     +,   1.2296153E-04,   1.1732159E-04,   1.1190766E-04
     +,   1.0671443E-04,   1.0173688E-04,   9.6969568E-05
     +,   9.2407507E-05,   8.8045104E-05,   8.3877356E-05
     +,   7.9898564E-05,   7.6103497E-05,   7.2486393E-05
     +,   6.9041809E-05,   6.5763845E-05,   6.2646941E-05
     +,   5.9685066E-05,   5.6872566E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_hatt80 = Yx/0.100625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5428686E-05,   4.6891520E-05
     +,   4.8372523E-05,   4.9871443E-05,   5.1388128E-05
     +,   5.2922547E-05,   5.4474767E-05,   5.6045010E-05
     +,   5.7633650E-05,   5.9241243E-05,   6.0868530E-05
     +,   6.2516476E-05,   6.4186272E-05,   6.5879358E-05
     +,   6.7597510E-05,   6.9342786E-05,   7.1117625E-05
     +,   7.2924820E-05,   7.4767646E-05,   7.6649769E-05
     +,   7.8575416E-05,   8.0549340E-05,   8.2576844E-05
     +,   8.4664054E-05,   8.6817439E-05,   8.9044515E-05
     +,   9.1353380E-05,   9.3753020E-05,   9.6253199E-05
     +,   9.8864606E-05,   1.0159873E-04,   1.0446812E-04
     +,   1.0748608E-04,   1.1066695E-04,   1.1402590E-04
     +,   1.1757899E-04,   1.2134306E-04,   1.2533563E-04
     +,   1.2957523E-04,   1.3408039E-04,   1.3887050E-04
     +,   1.4396505E-04,   1.4938365E-04,   1.5514575E-04
     +,   1.6127044E-04,   1.6777645E-04,   1.7468120E-04
     +,   1.8200139E-04,   1.8975211E-04,   1.9794673E-04
     +,   2.0659680E-04,   2.1571155E-04,   2.2529768E-04
     +,   2.3536020E-04,   2.4590024E-04,   2.5691793E-04
     +,   2.6841034E-04,   2.8037291E-04,   2.9279993E-04
     +,   3.0568521E-04,   3.1902280E-04,   3.3280847E-04
     +,   3.4704051E-04,   3.6172231E-04,   3.7686375E-04
     +,   3.9248131E-04,   4.0860349E-04,   4.2526834E-04
     +,   4.4252997E-04,   4.6045467E-04,   4.7912737E-04
     +,   4.9864675E-04,   5.1913003E-04,   5.4070615E-04
     +,   5.6351727E-04,   5.8771431E-04,   6.1344850E-04
     +,   6.4086658E-04,   6.7010551E-04,   7.0128124E-04
     +,   7.3447678E-04,   7.6974038E-04,   8.0707169E-04
     +,   8.4642437E-04,   8.8769954E-04,   9.3076198E-04
     +,   9.7544742E-04,   1.0216021E-03,   1.0691081E-03
     +,   1.1179530E-03,   1.1682833E-03,   1.2204722E-03
     +,   1.2751868E-03,   1.3334429E-03,   1.3966215E-03
     +,   1.4664353E-03,   1.5448630E-03,   1.6339918E-03
     +,   1.7358323E-03,   1.8520714E-03,   1.9838556E-03
     +,   2.1315599E-03,   2.2946892E-03,   2.4718053E-03
     +,   2.6606275E-03,   2.8581847E-03,   3.0610245E-03
     +,   3.2654989E-03,   3.4680781E-03,   3.6656680E-03
     +,   3.8559630E-03,   4.0379236E-03,   4.2121406E-03
     +,   4.3812585E-03,   4.5501310E-03,   4.7258227E-03
     +,   4.9171643E-03,   5.1341485E-03,   5.3868853E-03
     +,   5.6845192E-03,   6.0338937E-03,   6.4382814E-03
     +,   6.8961703E-03,   7.4003958E-03,   7.9375431E-03
     +,   8.4879082E-03,   9.0262340E-03,   9.5231989E-03
     +,   9.9481177E-03,   1.0272766E-02,   1.0475859E-02
     +,   1.0547415E-02,   1.0491427E-02,   1.0325790E-02
     +,   1.0078722E-02,   9.7827567E-03,   9.4676167E-03
     +,   9.1544064E-03,   8.8526802E-03,   8.5610161E-03
     +,   8.2703996E-03,   7.9689976E-03,   7.6465397E-03
     +,   7.2973426E-03,   6.9213035E-03,   6.5230997E-03
     +,   6.1104414E-03,   5.6920596E-03,   5.2759936E-03
     +,   4.8686001E-03,   4.4743293E-03,   4.0960545E-03
     +,   3.7356070E-03,   3.3943288E-03,   3.0734492E-03
     +,   2.7742691E-03,   2.4980481E-03,   2.2458001E-03
     +,   2.0181264E-03,   1.8150799E-03,   1.6360752E-03
     +,   1.4799522E-03,   1.3450903E-03,   1.2295449E-03
     +,   1.1311924E-03,   1.0478920E-03,   9.7759650E-04
     +,   9.1843581E-04,   8.6875568E-04,   8.2714553E-04
     +,   7.9242856E-04,   7.6363719E-04,   7.3997444E-04
     +,   7.2078319E-04,   7.0551154E-04,   6.9368148E-04
     +,   6.8486715E-04,   6.7868154E-04,   6.7476422E-04
     +,   6.7277829E-04,   6.7240582E-04,   6.7334925E-04
     +,   6.7533128E-04,   6.7809480E-04,   6.8140461E-04
     +,   6.8504713E-04,   6.8882987E-04,   6.9258158E-04
     +,   6.9615134E-04,   6.9940824E-04,   7.0223940E-04
     +,   7.0455030E-04,   7.0626324E-04,   7.0731621E-04
     +,   7.0766214E-04,   7.0726906E-04,   7.0611772E-04
     +,   7.0420257E-04,   7.0153066E-04,   6.9811981E-04
     +,   6.9400022E-04,   6.8921311E-04,   6.8380922E-04
     +,   6.7784940E-04,   6.7140377E-04,   6.6455046E-04
     +,   6.5737375E-04,   6.4996537E-04,   6.4242230E-04
     +,   6.3484325E-04,   6.2733033E-04,   6.1998639E-04
     +,   6.1291282E-04,   6.0620892E-04,   5.9996889E-04
     +,   5.9428200E-04,   5.8922917E-04,   5.8488263E-04
     +,   5.8130361E-04,   5.7854288E-04,   5.7663670E-04
     +,   5.7560881E-04,   5.7546661E-04,   5.7620439E-04
     +,   5.7779945E-04,   5.8021391E-04,   5.8339466E-04
     +,   5.8727304E-04,   5.9176673E-04,   5.9678010E-04
     +,   6.0220453E-04,   6.0792197E-04,   6.1380432E-04
     +,   6.1971718E-04,   6.2552089E-04,   6.3107262E-04
     +,   6.3623011E-04,   6.4085255E-04,   6.4480363E-04
     +,   6.4795394E-04,   6.5018435E-04,   6.5138529E-04
     +,   6.5146259E-04,   6.5033621E-04,   6.4794323E-04
     +,   6.4423901E-04,   6.3919788E-04,   6.3281192E-04
     +,   6.2509364E-04,   6.1607471E-04,   6.0580351E-04
     +,   5.9434597E-04,   5.8178330E-04,   5.6821114E-04
     +,   5.5373483E-04,   5.3846970E-04,   5.2253879E-04
     +,   5.0606928E-04,   4.8918946E-04,   4.7202734E-04
     +,   4.5470940E-04,   4.3735749E-04,   4.2008547E-04
     +,   4.0299897E-04,   3.8619642E-04,   3.6976332E-04
     +,   3.5377446E-04,   3.3829358E-04,   3.2337281E-04
     +,   3.0905119E-04,   2.9535702E-04,   2.8230823E-04
     +,   2.6991294E-04,   2.5816911E-04,   2.4706699E-04
     +,   2.3659041E-04,   2.2671628E-04,   2.1741762E-04
     +,   2.0866276E-04,   2.0041825E-04,   1.9264780E-04
     +,   1.8531550E-04,   1.7838409E-04,   1.7181790E-04
     +,   1.6558154E-04,   1.5964222E-04,   1.5396837E-04
     +,   1.4853077E-04,   1.4330327E-04,   1.3826159E-04
     +,   1.3338478E-04,   1.2865377E-04,   1.2405273E-04
     +,   1.1956765E-04,   1.1518734E-04,   1.1090226E-04
     +,   1.0670530E-04,   1.0259055E-04,   9.8554323E-05
     +,   9.4593575E-05,   9.0707101E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_hatt85 = Yx/0.110292682926829
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.2557501E-05,   7.5819808E-05
     +,   7.9158926E-05,   8.2571969E-05,   8.6055770E-05
     +,   8.9606969E-05,   9.3221905E-05,   9.6896794E-05
     +,   1.0062755E-04,   1.0441026E-04,   1.0824069E-04
     +,   1.1211462E-04,   1.1602799E-04,   1.1997672E-04
     +,   1.2395698E-04,   1.2796519E-04,   1.3199805E-04
     +,   1.3605264E-04,   1.4012652E-04,   1.4421792E-04
     +,   1.4832552E-04,   1.5244879E-04,   1.5658791E-04
     +,   1.6074415E-04,   1.6491924E-04,   1.6911626E-04
     +,   1.7333904E-04,   1.7759256E-04,   1.8188266E-04
     +,   1.8621642E-04,   1.9060179E-04,   1.9504766E-04
     +,   1.9956383E-04,   2.0416098E-04,   2.0885043E-04
     +,   2.1364409E-04,   2.1855420E-04,   2.2359318E-04
     +,   2.2877392E-04,   2.3410827E-04,   2.3960843E-04
     +,   2.4528542E-04,   2.5114955E-04,   2.5720953E-04
     +,   2.6347273E-04,   2.6994469E-04,   2.7662862E-04
     +,   2.8352556E-04,   2.9063388E-04,   2.9794901E-04
     +,   3.0546359E-04,   3.1316691E-04,   3.2104505E-04
     +,   3.2908161E-04,   3.3725583E-04,   3.4554469E-04
     +,   3.5392231E-04,   3.6235992E-04,   3.7082683E-04
     +,   3.7929020E-04,   3.8771605E-04,   3.9606943E-04
     +,   4.0431507E-04,   4.1241816E-04,   4.2034540E-04
     +,   4.2806435E-04,   4.3554581E-04,   4.4276283E-04
     +,   4.4969324E-04,   4.5631817E-04,   4.6262459E-04
     +,   4.6860386E-04,   4.7425408E-04,   4.7957868E-04
     +,   4.8458719E-04,   4.8929569E-04,   4.9372605E-04
     +,   4.9790600E-04,   5.0186849E-04,   5.0565199E-04
     +,   5.0929835E-04,   5.1285414E-04,   5.1636779E-04
     +,   5.1989080E-04,   5.2347564E-04,   5.2717549E-04
     +,   5.3104392E-04,   5.3513417E-04,   5.3949864E-04
     +,   5.4418854E-04,   5.4925570E-04,   5.5475015E-04
     +,   5.6072220E-04,   5.6722370E-04,   5.7430635E-04
     +,   5.8202428E-04,   5.9043488E-04,   5.9959618E-04
     +,   6.0957088E-04,   6.2042219E-04,   6.3221576E-04
     +,   6.4501644E-04,   6.5888878E-04,   6.7389267E-04
     +,   6.9008704E-04,   7.0752617E-04,   7.2626187E-04
     +,   7.4634643E-04,   7.6784129E-04,   7.9082383E-04
     +,   8.1539428E-04,   8.4169419E-04,   8.6991274E-04
     +,   9.0030232E-04,   9.3317736E-04,   9.6892397E-04
     +,   1.0079828E-03,   1.0508427E-03,   1.0980075E-03
     +,   1.1499880E-03,   1.2072749E-03,   1.2703408E-03
     +,   1.3396731E-03,   1.4158447E-03,   1.4996282E-03
     +,   1.5921383E-03,   1.6950136E-03,   1.8105328E-03
     +,   1.9416778E-03,   2.0919954E-03,   2.2652890E-03
     +,   2.4650237E-03,   2.6936324E-03,   2.9516695E-03
     +,   3.2372181E-03,   3.5455339E-03,   3.8691834E-03
     +,   4.1987351E-03,   4.5239208E-03,   4.8350566E-03
     +,   5.1245918E-03,   5.3886636E-03,   5.6284391E-03
     +,   5.8509936E-03,   6.0694311E-03,   6.3020419E-03
     +,   6.5701762E-03,   6.8951175E-03,   7.2945184E-03
     +,   7.7791926E-03,   8.3506200E-03,   8.9992341E-03
     +,   9.7033372E-03,   1.0428544E-02,   1.1128147E-02
     +,   1.1745941E-02,   1.2222821E-02,   1.2507192E-02
     +,   1.2567029E-02,   1.2400032E-02,   1.2037367E-02
     +,   1.1538610E-02,   1.0978715E-02,   1.0430750E-02
     +,   9.9498508E-03,   9.5633063E-03,   9.2687942E-03
     +,   9.0400120E-03,   8.8372137E-03,   8.6190905E-03
     +,   8.3530564E-03,   8.0216592E-03,   7.6245130E-03
     +,   7.1759154E-03,   6.6996263E-03,   6.2225093E-03
     +,   5.7689450E-03,   5.3571458E-03,   4.9976185E-03
     +,   4.6935729E-03,   4.4424939E-03,   4.2380872E-03
     +,   4.0720860E-03,   3.9356318E-03,   3.8202459E-03
     +,   3.7183885E-03,   3.6237268E-03,   3.5311971E-03
     +,   3.4369987E-03,   3.3384848E-03,   3.2340209E-03
     +,   3.1228701E-03,   3.0050701E-03,   2.8813037E-03
     +,   2.7527679E-03,   2.6210407E-03,   2.4879456E-03
     +,   2.3553893E-03,   2.2252065E-03,   2.0990423E-03
     +,   1.9782665E-03,   1.8639173E-03,   1.7566726E-03
     +,   1.6568946E-03,   1.5646805E-03,   1.4799165E-03
     +,   1.4023513E-03,   1.3316666E-03,   1.2675207E-03
     +,   1.2095750E-03,   1.1575186E-03,   1.1110706E-03
     +,   1.0699710E-03,   1.0339624E-03,   1.0027795E-03
     +,   9.7613153E-04,   9.5369469E-04,   9.3510270E-04
     +,   9.1994682E-04,   9.0778514E-04,   8.9814496E-04
     +,   8.9053903E-04,   8.8447821E-04,   8.7948272E-04
     +,   8.7509718E-04,   8.7090052E-04,   8.6651533E-04
     +,   8.6161407E-04,   8.5592340E-04,   8.4922556E-04
     +,   8.4135833E-04,   8.3221204E-04,   8.2172651E-04
     +,   8.0988521E-04,   7.9671125E-04,   7.8226085E-04
     +,   7.6661719E-04,   7.4988522E-04,   7.3218800E-04
     +,   7.1365741E-04,   6.9443276E-04,   6.7465764E-04
     +,   6.5447495E-04,   6.3402270E-04,   6.1343360E-04
     +,   5.9283408E-04,   5.7234068E-04,   5.5205921E-04
     +,   5.3208356E-04,   5.1249826E-04,   4.9337442E-04
     +,   4.7477122E-04,   4.5673823E-04,   4.3931321E-04
     +,   4.2252292E-04,   4.0638464E-04,   3.9090775E-04
     +,   3.7609343E-04,   3.6193544E-04,   3.4842110E-04
     +,   3.3553349E-04,   3.2325168E-04,   3.1155036E-04
     +,   3.0040179E-04,   2.8977761E-04,   2.7964689E-04
     +,   2.6997877E-04,   2.6074273E-04,   2.5190893E-04
     +,   2.4344749E-04,   2.3533010E-04,   2.2753028E-04
     +,   2.2002312E-04,   2.1278493E-04,   2.0579409E-04
     +,   1.9903114E-04,   1.9247810E-04,   1.8611932E-04
     +,   1.7994031E-04,   1.7392906E-04,   1.6807432E-04
     +,   1.6236721E-04,   1.5679951E-04,   1.5136495E-04
     +,   1.4605781E-04,   1.4087398E-04,   1.3580981E-04
     +,   1.3086246E-04,   1.2603022E-04,   1.2131135E-04
     +,   1.1670515E-04,   1.1221076E-04,   1.0782812E-04
     +,   1.0355685E-04,   9.9397257E-05,   9.5349264E-05
     +,   9.1413152E-05,   8.7588880E-05,   8.3876766E-05
     +,   8.0276513E-05,   7.6788230E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_hatt90 = Yx/0.131833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5884368E-05,   4.7465379E-05
     +,   4.9101523E-05,   5.0793820E-05,   5.2543161E-05
     +,   5.4350370E-05,   5.6216057E-05,   5.8140762E-05
     +,   6.0124828E-05,   6.2168547E-05,   6.4271953E-05
     +,   6.6434943E-05,   6.8657268E-05,   7.0938535E-05
     +,   7.3278148E-05,   7.5675336E-05,   7.8129189E-05
     +,   8.0638602E-05,   8.3202351E-05,   8.5818974E-05
     +,   8.8486930E-05,   9.1204427E-05,   9.3969582E-05
     +,   9.6780444E-05,   9.9634621E-05,   1.0252991E-04
     +,   1.0546378E-04,   1.0843353E-04,   1.1143643E-04
     +,   1.1446953E-04,   1.1752972E-04,   1.2061384E-04
     +,   1.2371849E-04,   1.2684015E-04,   1.2997517E-04
     +,   1.3311974E-04,   1.3626984E-04,   1.3942138E-04
     +,   1.4257010E-04,   1.4571146E-04,   1.4884099E-04
     +,   1.5195385E-04,   1.5504513E-04,   1.5810975E-04
     +,   1.6114251E-04,   1.6413809E-04,   1.6709109E-04
     +,   1.6999590E-04,   1.7284685E-04,   1.7563839E-04
     +,   1.7836473E-04,   1.8102030E-04,   1.8359926E-04
     +,   1.8609635E-04,   1.8850589E-04,   1.9082290E-04
     +,   1.9304213E-04,   1.9515898E-04,   1.9716902E-04
     +,   1.9906822E-04,   2.0085297E-04,   2.0252024E-04
     +,   2.0406728E-04,   2.0549224E-04,   2.0679360E-04
     +,   2.0797069E-04,   2.0902346E-04,   2.0995246E-04
     +,   2.1075917E-04,   2.1144554E-04,   2.1201452E-04
     +,   2.1246962E-04,   2.1281504E-04,   2.1305574E-04
     +,   2.1319740E-04,   2.1324608E-04,   2.1320854E-04
     +,   2.1309211E-04,   2.1290434E-04,   2.1265337E-04
     +,   2.1234754E-04,   2.1199531E-04,   2.1160547E-04
     +,   2.1118672E-04,   2.1074778E-04,   2.1029734E-04
     +,   2.0984396E-04,   2.0939573E-04,   2.0896074E-04
     +,   2.0854668E-04,   2.0816071E-04,   2.0780973E-04
     +,   2.0750026E-04,   2.0723822E-04,   2.0702925E-04
     +,   2.0687855E-04,   2.0679091E-04,   2.0677094E-04
     +,   2.0682294E-04,   2.0695123E-04,   2.0716003E-04
     +,   2.0745370E-04,   2.0783709E-04,   2.0831561E-04
     +,   2.0889529E-04,   2.0958348E-04,   2.1038864E-04
     +,   2.1132122E-04,   2.1239372E-04,   2.1362086E-04
     +,   2.1502050E-04,   2.1661373E-04,   2.1842544E-04
     +,   2.2048435E-04,   2.2282409E-04,   2.2548292E-04
     +,   2.2850397E-04,   2.3193598E-04,   2.3583276E-04
     +,   2.4025326E-04,   2.4526182E-04,   2.5092650E-04
     +,   2.5731948E-04,   2.6451578E-04,   2.7259256E-04
     +,   2.8162639E-04,   2.9169375E-04,   3.0286700E-04
     +,   3.1521503E-04,   3.2879796E-04,   3.4366947E-04
     +,   3.5987017E-04,   3.7743014E-04,   3.9636416E-04
     +,   4.1667387E-04,   4.3834539E-04,   4.6134921E-04
     +,   4.8564130E-04,   5.1116524E-04,   5.3785485E-04
     +,   5.6563219E-04,   5.9441215E-04,   6.2410696E-04
     +,   6.5462710E-04,   6.8587949E-04,   7.1777572E-04
     +,   7.5023103E-04,   7.8316260E-04,   8.1649574E-04
     +,   8.5016777E-04,   8.8412774E-04,   9.1834232E-04
     +,   9.5280167E-04,   9.8753173E-04,   1.0226016E-03
     +,   1.0581310E-03,   1.0943051E-03,   1.1313887E-03
     +,   1.1697329E-03,   1.2097773E-03,   1.2520638E-03
     +,   1.2972320E-03,   1.3460098E-03,   1.3992181E-03
     +,   1.4577612E-03,   1.5226207E-03,   1.5948475E-03
     +,   1.6755718E-03,   1.7660223E-03,   1.8675617E-03
     +,   1.9817126E-03,   2.1102123E-03,   2.2550048E-03
     +,   2.4181493E-03,   2.6015760E-03,   2.8067969E-03
     +,   3.0345672E-03,   3.2847028E-03,   3.5562869E-03
     +,   3.8482579E-03,   4.1602091E-03,   4.4930167E-03
     +,   4.8490190E-03,   5.2315691E-03,   5.6444565E-03
     +,   6.0919169E-03,   6.5797251E-03,   7.1167224E-03
     +,   7.7146934E-03,   8.3847484E-03,   9.1306316E-03
     +,   9.9419504E-03,   1.0792730E-02,   1.1647635E-02
     +,   1.2473164E-02,   1.3247419E-02,   1.3963015E-02
     +,   1.4622266E-02,   1.5226530E-02,   1.5764264E-02
     +,   1.6204610E-02,   1.6502518E-02,   1.6614806E-02
     +,   1.6517686E-02,   1.6214024E-02,   1.5727863E-02
     +,   1.5093898E-02,   1.4350940E-02,   1.3539634E-02
     +,   1.2700084E-02,   1.1867120E-02,   1.1065951E-02
     +,   1.0311192E-02,   9.6091973E-03,   8.9614298E-03
     +,   8.3667254E-03,   7.8223506E-03,   7.3245117E-03
     +,   6.8683578E-03,   6.4477636E-03,   6.0551306E-03
     +,   5.6821979E-03,   5.3215986E-03,   4.9685054E-03
     +,   4.6216385E-03,   4.2831819E-03,   3.9576893E-03
     +,   3.6504681E-03,   3.3660282E-03,   3.1070374E-03
     +,   2.8739288E-03,   2.6650429E-03,   2.4772021E-03
     +,   2.3064977E-03,   2.1490366E-03,   2.0014902E-03
     +,   1.8614134E-03,   1.7273354E-03,   1.5986376E-03
     +,   1.4753186E-03,   1.3577617E-03,   1.2465089E-03
     +,   1.1420847E-03,   1.0448754E-03,   9.5508376E-04
     +,   8.7272492E-04,   7.9763564E-04,   7.2950561E-04
     +,   6.6792197E-04,   6.1241211E-04,   5.6246418E-04
     +,   5.1756081E-04,   4.7719970E-04,   4.4090283E-04
     +,   4.0822322E-04,   3.7875184E-04,   3.5212122E-04
     +,   3.2800218E-04,   3.0610178E-04,   2.8616187E-04
     +,   2.6795809E-04,   2.5129397E-04,   2.3599752E-04
     +,   2.2191879E-04,   2.0892857E-04,   1.9691241E-04
     +,   1.8577019E-04,   1.7541477E-04,   1.6576961E-04
     +,   1.5676646E-04,   1.4834551E-04,   1.4045447E-04
     +,   1.3304738E-04,   1.2608331E-04,   1.1952624E-04
     +,   1.1334521E-04,   1.0751211E-04,   1.0200289E-04
     +,   9.6795578E-05,   9.1871305E-05,   8.7212626E-05
     +,   8.2804348E-05,   7.8632154E-05,   7.4683543E-05
     +,   7.0946386E-05,   6.7409906E-05,   6.4063650E-05
     +,   6.0897699E-05,   5.7902977E-05,   5.5070341E-05
     +,   5.2391431E-05,   4.9857837E-05,   4.7461759E-05
     +,   4.5195429E-05,   4.3051565E-05,   4.1022995E-05
     +,   3.9103033E-05,   3.7285074E-05,   3.5563033E-05
     +,   3.3930952E-05,   3.2383381E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_hatt95 = Yx/0.140651162790698
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.2462250E-06,   6.4804890E-06
     +,   6.7171873E-06,   6.9560738E-06,   7.1969048E-06
     +,   7.4394470E-06,   7.6834694E-06,   7.9287556E-06
     +,   8.1750977E-06,   8.4223157E-06,   8.6702366E-06
     +,   8.9187088E-06,   9.1676102E-06,   9.4168381E-06
     +,   9.6663225E-06,   9.9160206E-06,   1.0165927E-05
     +,   1.0416070E-05,   1.0666515E-05,   1.0917367E-05
     +,   1.1168774E-05,   1.1420931E-05,   1.1674072E-05
     +,   1.1928500E-05,   1.2184536E-05,   1.2442588E-05
     +,   1.2703099E-05,   1.2966579E-05,   1.3233588E-05
     +,   1.3504763E-05,   1.3780790E-05,   1.4062435E-05
     +,   1.4350526E-05,   1.4645960E-05,   1.4949718E-05
     +,   1.5262849E-05,   1.5586482E-05,   1.5921822E-05
     +,   1.6270178E-05,   1.6632901E-05,   1.7011471E-05
     +,   1.7407428E-05,   1.7822404E-05,   1.8258108E-05
     +,   1.8716346E-05,   1.9199002E-05,   1.9708015E-05
     +,   2.0245428E-05,   2.0813324E-05,   2.1413860E-05
     +,   2.2049226E-05,   2.2721655E-05,   2.3433393E-05
     +,   2.4186727E-05,   2.4983863E-05,   2.5827052E-05
     +,   2.6718440E-05,   2.7660126E-05,   2.8654082E-05
     +,   2.9702163E-05,   3.0806066E-05,   3.1967309E-05
     +,   3.3187123E-05,   3.4466575E-05,   3.5806464E-05
     +,   3.7207144E-05,   3.8668804E-05,   4.0191080E-05
     +,   4.1773394E-05,   4.3414577E-05,   4.5113196E-05
     +,   4.6867193E-05,   4.8674232E-05,   5.0531315E-05
     +,   5.2435142E-05,   5.4381955E-05,   5.6367455E-05
     +,   5.8386882E-05,   6.0435254E-05,   6.2507213E-05
     +,   6.4596941E-05,   6.6698558E-05,   6.8805799E-05
     +,   7.0912531E-05,   7.3012256E-05,   7.5098891E-05
     +,   7.7166151E-05,   7.9208337E-05,   8.1219776E-05
     +,   8.3195569E-05,   8.5131454E-05,   8.7023844E-05
     +,   8.8870140E-05,   9.0668975E-05,   9.2420480E-05
     +,   9.4126117E-05,   9.5789481E-05,   9.7416094E-05
     +,   9.9014062E-05,   1.0059401E-04,   1.0216983E-04
     +,   1.0375855E-04,   1.0538108E-04,   1.0706206E-04
     +,   1.0883046E-04,   1.1071967E-04,   1.1276751E-04
     +,   1.1501608E-04,   1.1751219E-04,   1.2030641E-04
     +,   1.2345267E-04,   1.2700795E-04,   1.3103068E-04
     +,   1.3558027E-04,   1.4071492E-04,   1.4649115E-04
     +,   1.5296099E-04,   1.6017149E-04,   1.6816199E-04
     +,   1.7696393E-04,   1.8659928E-04,   1.9707932E-04
     +,   2.0840505E-04,   2.2056824E-04,   2.3355227E-04
     +,   2.4733215E-04,   2.6188014E-04,   2.7716460E-04
     +,   2.9315639E-04,   3.0982870E-04,   3.2716230E-04
     +,   3.4514416E-04,   3.6377343E-04,   3.8305621E-04
     +,   4.0301032E-04,   4.2366236E-04,   4.4504466E-04
     +,   4.6719500E-04,   4.9015862E-04,   5.1398616E-04
     +,   5.3873518E-04,   5.6447671E-04,   5.9130462E-04
     +,   6.1934366E-04,   6.4876094E-04,   6.7978300E-04
     +,   7.1271503E-04,   7.4794976E-04,   7.8598771E-04
     +,   8.2745054E-04,   8.7308470E-04,   9.2374970E-04
     +,   9.8039384E-04,   1.0440075E-03,   1.1155371E-03
     +,   1.1957702E-03,   1.2852149E-03,   1.3839923E-03
     +,   1.4917672E-03,   1.6077555E-03,   1.7308762E-03
     +,   1.8599852E-03,   1.9941747E-03,   2.1330866E-03
     +,   2.2771419E-03,   2.4276308E-03,   2.5866628E-03
     +,   2.7571579E-03,   2.9430999E-03,   3.1504950E-03
     +,   3.3896323E-03,   3.6789426E-03,   4.0494855E-03
     +,   4.5470055E-03,   5.2268547E-03,   6.1384533E-03
     +,   7.3014433E-03,   8.6868564E-03,   1.0227187E-02
     +,   1.1868949E-02,   1.3635733E-02,   1.5628109E-02
     +,   1.7925465E-02,   2.0504383E-02,   2.3401450E-02
     +,   2.7022159E-02,   3.2251105E-02,   4.0485401E-02
     +,   5.2274738E-02,   6.4794518E-02,   7.4799627E-02
     +,   8.3130941E-02,   9.2202485E-02,   0.1010701    
     +,   0.1036881    ,   0.1038241    ,   0.1059913    
     +,   0.1005732    ,   8.7794118E-02,   7.3945291E-02
     +,   6.2801890E-02,   5.4188378E-02,   4.6630319E-02
     +,   3.9475814E-02,   3.3691064E-02,   2.9444357E-02
     +,   2.5816601E-02,   2.2357939E-02,   1.9443465E-02
     +,   1.7450662E-02,   1.6170161E-02,   1.5024759E-02
     +,   1.3592280E-02,   1.1852955E-02,   1.0041340E-02
     +,   8.3780335E-03,   6.9447989E-03,   5.7214848E-03
     +,   4.6660812E-03,   3.7547848E-03,   2.9793265E-03
     +,   2.3330036E-03,   1.8042825E-03,   1.3781396E-03
     +,   1.0392086E-03,   7.7345927E-04,   5.6840031E-04
     +,   4.1281866E-04,   2.9668640E-04,   2.1126086E-04
     +,   1.4919425E-04,   1.0454375E-04,   7.2673945E-05
     +,   5.0079540E-05,   3.4168297E-05,   2.3046434E-05
     +,   1.5341984E-05,   1.0063591E-05,   6.4947635E-06
     +,   4.1183289E-06,   2.5628237E-06,   1.5636826E-06
     +,   9.3472403E-07,   5.4707914E-07,   3.1335085E-07
     +,   1.7557753E-07,   9.6215082E-08,   5.1551684E-08
     +,   2.7000764E-08,   1.3822727E-08,   6.9156214E-09
     +,   3.3809056E-09,   1.6149995E-09,   7.5376244E-10
     +,   3.4371292E-10,   1.5312805E-10,   6.6660885E-11
     +,   2.8365154E-11,   1.1805074E-11,   4.8118618E-12
     +,   1.9266448E-12,   7.6240712E-13,   3.0186441E-13
     +,   1.2242667E-13,   5.2884915E-14,   2.5535460E-14
     +,   1.4224099E-14,   9.0491062E-15,   6.3132093E-15
     +,   4.6364529E-15,   3.4897796E-15,   2.6545634E-15
     +,   2.0273344E-15,   1.5500583E-15,   1.1850622E-15
     +,   9.0553635E-16,   6.9144687E-16,   5.2757500E-16
     +,   4.0222482E-16,   3.0642470E-16,   2.3326369E-16
     +,   1.7744017E-16,   1.3487617E-16,   1.0244983E-16
     +,   7.7763514E-17,   5.8985025E-17,   4.4710207E-17
     +,   3.3866452E-17,   2.5635455E-17,   1.9391567E-17
     +,   1.4658681E-17,   1.1073346E-17,   8.3593227E-18
     +,   6.3061239E-18,   4.7539939E-18,   3.5813715E-18
     +,   2.6961187E-18,   2.0282289E-18,   1.5247031E-18
     +,   1.1453360E-18,   8.5972991E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt100 = Yx/0.4235
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.3096187E-06,   5.5827645E-06
     +,   5.8630026E-06,   6.1500705E-06,   6.4436813E-06
     +,   6.7435226E-06,   7.0492570E-06,   7.3605233E-06
     +,   7.6769375E-06,   7.9981110E-06,   8.3236164E-06
     +,   8.6530263E-06,   8.9858868E-06,   9.3217459E-06
     +,   9.6601316E-06,   1.0000574E-05,   1.0342594E-05
     +,   1.0685714E-05,   1.1029454E-05,   1.1373343E-05
     +,   1.1716911E-05,   1.2059699E-05,   1.2401252E-05
     +,   1.2741153E-05,   1.3078959E-05,   1.3414286E-05
     +,   1.3746738E-05,   1.4075959E-05,   1.4401609E-05
     +,   1.4723370E-05,   1.5040954E-05,   1.5354097E-05
     +,   1.5662559E-05,   1.5966136E-05,   1.6264647E-05
     +,   1.6557946E-05,   1.6845906E-05,   1.7128436E-05
     +,   1.7405482E-05,   1.7677005E-05,   1.7943004E-05
     +,   1.8203504E-05,   1.8458561E-05,   1.8708251E-05
     +,   1.8952685E-05,   1.9191995E-05,   1.9426339E-05
     +,   1.9655901E-05,   1.9880888E-05,   2.0101525E-05
     +,   2.0318066E-05,   2.0530782E-05,   2.0739957E-05
     +,   2.0945909E-05,   2.1148950E-05,   2.1349431E-05
     +,   2.1547708E-05,   2.1744150E-05,   2.1939150E-05
     +,   2.2133092E-05,   2.2326400E-05,   2.2519485E-05
     +,   2.2712775E-05,   2.2906715E-05,   2.3101768E-05
     +,   2.3298371E-05,   2.3497027E-05,   2.3698198E-05
     +,   2.3902401E-05,   2.4110135E-05,   2.4321940E-05
     +,   2.4538373E-05,   2.4760026E-05,   2.4987508E-05
     +,   2.5221494E-05,   2.5462694E-05,   2.5711883E-05
     +,   2.5969915E-05,   2.6237720E-05,   2.6516365E-05
     +,   2.6807005E-05,   2.7110973E-05,   2.7429722E-05
     +,   2.7764961E-05,   2.8118549E-05,   2.8492641E-05
     +,   2.8889608E-05,   2.9312176E-05,   2.9763320E-05
     +,   3.0246432E-05,   3.0765237E-05,   3.1323860E-05
     +,   3.1926756E-05,   3.2578882E-05,   3.3285563E-05
     +,   3.4052460E-05,   3.4885714E-05,   3.5791672E-05
     +,   3.6777106E-05,   3.7848899E-05,   3.9014245E-05
     +,   4.0280283E-05,   4.1654283E-05,   4.3143275E-05
     +,   4.4754182E-05,   4.6493653E-05,   4.8367827E-05
     +,   5.0382307E-05,   5.2542302E-05,   5.4852444E-05
     +,   5.7316611E-05,   5.9938477E-05,   6.2721141E-05
     +,   6.5667933E-05,   6.8782152E-05,   7.2068273E-05
     +,   7.5531745E-05,   7.9180616E-05,   8.3025538E-05
     +,   8.7081600E-05,   9.1369082E-05,   9.5914518E-05
     +,   1.0075206E-04,   1.0592506E-04,   1.1148727E-04
     +,   1.1750292E-04,   1.2404929E-04,   1.3121567E-04
     +,   1.3910572E-04,   1.4783579E-04,   1.5753717E-04
     +,   1.6835376E-04,   1.8044458E-04,   1.9398017E-04
     +,   2.0914456E-04,   2.2613270E-04,   2.4514657E-04
     +,   2.6639126E-04,   2.9006964E-04,   3.1637182E-04
     +,   3.4545970E-04,   3.7745264E-04,   4.1241077E-04
     +,   4.5031478E-04,   4.9104454E-04,   5.3437497E-04
     +,   5.7997013E-04,   6.2739226E-04,   6.7613024E-04
     +,   7.2565250E-04,   7.7547110E-04,   8.2522345E-04
     +,   8.7477831E-04,   9.2434627E-04,   9.7458425E-04
     +,   1.0266785E-03,   1.0823950E-03,   1.1440682E-03
     +,   1.2144862E-03,   1.2966715E-03,   1.3935859E-03
     +,   1.5077710E-03,   1.6410424E-03,   1.7943827E-03
     +,   1.9681528E-03,   2.1626141E-03,   2.3786202E-03
     +,   2.6181438E-03,   2.8841314E-03,   3.1792885E-03
     +,   3.5039636E-03,   3.8540405E-03,   4.2203218E-03
     +,   4.5907428E-03,   4.9557984E-03,   5.3153611E-03
     +,   5.6827464E-03,   6.0817963E-03,   6.5366044E-03
     +,   7.0614438E-03,   7.6648272E-03,   8.3758589E-03
     +,   9.2743393E-03,   1.0477441E-02,   1.2064260E-02
     +,   1.4024941E-02,   1.6338099E-02,   1.9084129E-02
     +,   2.2469262E-02,   2.6915664E-02,   3.2872416E-02
     +,   3.9638460E-02,   4.5792159E-02,   5.2564107E-02
     +,   6.1432485E-02,   7.1801692E-02,   8.4974222E-02
     +,   9.5022112E-02,   0.1014784    ,   0.1087203    
     +,   0.1094813    ,   0.1026549    ,   9.2486136E-02
     +,   7.8939512E-02,   6.6421792E-02,   5.6914650E-02
     +,   4.8628431E-02,   4.2225845E-02,   3.6707889E-02
     +,   3.0968430E-02,   2.5220465E-02,   2.0264752E-02
     +,   1.6490828E-02,   1.3857887E-02,   1.2127064E-02
     +,   1.0877085E-02,   9.6733589E-03,   8.3015338E-03
     +,   6.7987628E-03,   5.3205932E-03,   4.0072426E-03
     +,   2.9292072E-03,   2.0944793E-03,   1.4752242E-03
     +,   1.0302055E-03,   7.1784278E-04,   5.0206977E-04
     +,   3.5415220E-04,   2.5259936E-04,   1.8221069E-04
     +,   1.3273620E-04,   9.7486467E-05,   7.2135626E-05
     +,   5.3834796E-05,   4.0631741E-05,   3.1127216E-05
     +,   2.4290690E-05,   1.9356659E-05,   1.5760279E-05
     +,   1.3091780E-05,   1.1060663E-05,   9.4659417E-06
     +,   8.1718335E-06,   7.0887641E-06,   6.1590540E-06
     +,   5.3463309E-06,   4.6278851E-06,   3.9894162E-06
     +,   3.4216127E-06,   2.9179646E-06,   2.4733006E-06
     +,   2.0830762E-06,   1.7429923E-06,   1.4487955E-06
     +,   1.1962201E-06,   9.8104522E-07,   7.9916236E-07
     +,   6.4661702E-07,   5.1966026E-07,   4.1480848E-07
     +,   3.2887712E-07,   2.5898868E-07,   2.0257474E-07
     +,   1.5737795E-07,   1.2144038E-07,   9.3076437E-08
     +,   7.0854924E-08,   5.3574393E-08,   4.0235161E-08
     +,   3.0013169E-08,   2.2236732E-08,   1.6363916E-08
     +,   1.1960941E-08,   8.6836183E-09,   6.2616512E-09
     +,   4.4847579E-09,   3.1903800E-09,   2.2542783E-09
     +,   1.5820690E-09,   1.1028243E-09,   7.6355300E-10
     +,   5.2509141E-10,   3.5866091E-10,   2.4333038E-10
     +,   1.6396877E-10,   1.0974629E-10,   7.2958820E-11
     +,   4.8174673E-11,   3.1595511E-11,   2.0581932E-11
     +,   1.3317230E-11,   8.5584742E-12,   5.4632158E-12
     +,   3.4638408E-12,   2.1814295E-12,   1.3645334E-12
     +,   8.4782572E-13,   5.2323684E-13,   3.2075761E-13
     +,   1.9531483E-13,   1.1814020E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt102 = Yx/0.40712
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.5327396E-06,   9.5569503E-06
     +,   9.5661198E-06,   9.5602336E-06,   9.5393580E-06
     +,   9.5036239E-06,   9.4532516E-06,   9.3885246E-06
     +,   9.3098088E-06,   9.2175351E-06,   9.1122074E-06
     +,   8.9943942E-06,   8.8647312E-06,   8.7239059E-06
     +,   8.5726715E-06,   8.4118246E-06,   8.2422148E-06
     +,   8.0647324E-06,   7.8803087E-06,   7.6899105E-06
     +,   7.4945301E-06,   7.2951902E-06,   7.0929405E-06
     +,   6.8888307E-06,   6.6839521E-06,   6.4793790E-06
     +,   6.2762133E-06,   6.0755556E-06,   5.8785085E-06
     +,   5.6861782E-06,   5.4996663E-06,   5.3200779E-06
     +,   5.1485099E-06,   4.9860619E-06,   4.8338279E-06
     +,   4.6928990E-06,   4.5643660E-06,   4.4493204E-06
     +,   4.3488499E-06,   4.2640513E-06,   4.1960216E-06
     +,   4.1458661E-06,   4.1147000E-06,   4.1036469E-06
     +,   4.1138451E-06,   4.1464514E-06,   4.2026350E-06
     +,   4.2835886E-06,   4.3905256E-06,   4.5246807E-06
     +,   4.6873142E-06,   4.8797069E-06,   5.1031625E-06
     +,   5.3590238E-06,   5.6486228E-06,   5.9733443E-06
     +,   6.3345715E-06,   6.7337000E-06,   7.1721370E-06
     +,   7.6512852E-06,   8.1725402E-06,   8.7372928E-06
     +,   9.3468670E-06,   1.0002595E-05,   1.0705763E-05
     +,   1.1457523E-05,   1.2259035E-05,   1.3111263E-05
     +,   1.4015161E-05,   1.4971431E-05,   1.5980733E-05
     +,   1.7043421E-05,   1.8159790E-05,   1.9329762E-05
     +,   2.0553112E-05,   2.1829377E-05,   2.3157700E-05
     +,   2.4536925E-05,   2.5965644E-05,   2.7442135E-05
     +,   2.8964156E-05,   3.0529318E-05,   3.2134663E-05
     +,   3.3777083E-05,   3.5452897E-05,   3.7158312E-05
     +,   3.8889000E-05,   4.0640571E-05,   4.2408152E-05
     +,   4.4186843E-05,   4.5971599E-05,   4.7757167E-05
     +,   4.9538248E-05,   5.1309758E-05,   5.3066713E-05
     +,   5.4804168E-05,   5.6517729E-05,   5.8203157E-05
     +,   5.9856939E-05,   6.1475890E-05,   6.3057734E-05
     +,   6.4600696E-05,   6.6104047E-05,   6.7567787E-05
     +,   6.8993038E-05,   7.0381990E-05,   7.1737959E-05
     +,   7.3065501E-05,   7.4370808E-05,   7.5661679E-05
     +,   7.6947719E-05,   7.8241079E-05,   7.9556448E-05
     +,   8.0912119E-05,   8.2330378E-05,   8.3838808E-05
     +,   8.5471052E-05,   8.7268498E-05,   8.9281326E-05
     +,   9.1570422E-05,   9.4208714E-05,   9.7282464E-05
     +,   1.0089237E-04,   1.0515448E-04,   1.1019975E-04
     +,   1.1617234E-04,   1.2322815E-04,   1.3152944E-04
     +,   1.4124079E-04,   1.5251947E-04,   1.6550903E-04
     +,   1.8032563E-04,   1.9705025E-04,   2.1571296E-04
     +,   2.3628544E-04,   2.5867045E-04,   2.8269252E-04
     +,   3.0809673E-04,   3.3455092E-04,   3.6165109E-04
     +,   3.8893102E-04,   4.1588049E-04,   4.4196952E-04
     +,   4.6667072E-04,   4.8948446E-04,   5.0997059E-04
     +,   5.2777195E-04,   5.4263481E-04,   5.5442884E-04
     +,   5.6315743E-04,   5.6896271E-04,   5.7212234E-04
     +,   5.7304499E-04,   5.7225837E-04,   5.7039812E-04
     +,   5.6819606E-04,   5.6647346E-04,   5.6613819E-04
     +,   5.6819041E-04,   5.7374046E-04,   5.8403262E-04
     +,   6.0048973E-04,   6.2476681E-04,   6.5882289E-04
     +,   7.0500170E-04,   7.6609821E-04,   8.4537792E-04
     +,   9.4650500E-04,   1.0733234E-03,   1.2294251E-03
     +,   1.4174958E-03,   1.6385464E-03,   1.8912245E-03
     +,   2.1714601E-03,   2.4727604E-03,   2.7873686E-03
     +,   3.1079601E-03,   3.4293658E-03,   3.7497282E-03
     +,   4.0706117E-03,   4.3963389E-03,   4.7339583E-03
     +,   5.0963988E-03,   5.5116573E-03,   6.0383133E-03
     +,   6.7800297E-03,   7.8798383E-03,   9.4738752E-03
     +,   1.1616790E-02,   1.4237715E-02,   1.7173177E-02
     +,   2.0248758E-02,   2.3365168E-02,   2.6668208E-02
     +,   3.0873096E-02,   3.6675122E-02,   4.3557901E-02
     +,   5.1541012E-02,   6.2389754E-02,   7.6852620E-02
     +,   9.0456225E-02,   9.9505007E-02,   0.1070161    
     +,   0.1170133    ,   0.1205740    ,   0.1070903    
     +,   9.4071500E-02,   8.4430978E-02,   7.5063102E-02
     +,   6.2944569E-02,   4.9334627E-02,   3.9542288E-02
     +,   3.2959633E-02,   2.7891569E-02,   2.3724886E-02
     +,   2.0370837E-02,   1.7531805E-02,   1.4773252E-02
     +,   1.1951394E-02,   9.2354324E-03,   6.8388926E-03
     +,   4.8614247E-03,   3.3120525E-03,   2.1620055E-03
     +,   1.3580759E-03,   8.2714960E-04,   4.9184618E-04
     +,   2.8649197E-04,   1.6341222E-04,   9.1066424E-05
     +,   4.9462269E-05,   2.6134938E-05,   1.3414982E-05
     +,   6.6805078E-06,   3.2228222E-06,   1.5033168E-06
     +,   6.7660153E-07,   2.9322513E-07,   1.2216221E-07
     +,   4.8884093E-08,   1.8805100E-08,   6.9876358E-09
     +,   2.5423119E-09,   9.3609853E-10,   3.7308640E-10
     +,   1.7657133E-10,   1.0403568E-10,   7.2709609E-11
     +,   5.5552056E-11,   4.3975126E-11,   3.5211705E-11
     +,   2.8266146E-11,   2.2680335E-11,   1.8173189E-11
     +,   1.4537435E-11,   1.1608664E-11,   9.2535537E-12
     +,   7.3632290E-12,   5.8486649E-12,   4.6373560E-12
     +,   3.6703991E-12,   2.8999314E-12,   2.2871310E-12
     +,   1.8006084E-12,   1.4150737E-12,   1.1101144E-12
     +,   8.6932170E-13,   6.7955093E-13,   5.3026778E-13
     +,   4.1304357E-13,   3.2115993E-13,   2.4927263E-13
     +,   1.9313461E-13,   1.4937305E-13,   1.1532133E-13
     +,   8.8874498E-14,   6.8370643E-14,   5.2504161E-14
     +,   4.0247662E-14,   3.0797820E-14,   2.3524619E-14
     +,   1.7937261E-14,   1.3652526E-14,   1.0372957E-14
     +,   7.8670929E-15,   5.9560350E-15,   4.5011953E-15
     +,   3.3956433E-15,   2.5570942E-15,   1.9221831E-15
     +,   1.4423624E-15,   1.0803793E-15,   8.0781093E-16
     +,   6.0292816E-16,   4.4921397E-16,   3.3408983E-16
     +,   2.4803004E-16,   1.8380970E-16,   1.3597630E-16
     +,   1.0041096E-16,   7.4016565E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt104 = Yx/0.40684
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4676267E-06,   2.6537714E-06
     +,   2.8504294E-06,   3.0578935E-06,   3.2764410E-06
     +,   3.5063294E-06,   3.7477980E-06,   4.0010636E-06
     +,   4.2663137E-06,   4.5437232E-06,   4.8334264E-06
     +,   5.1355305E-06,   5.4501120E-06,   5.7772145E-06
     +,   6.1168448E-06,   6.4689766E-06,   6.8335430E-06
     +,   7.2104408E-06,   7.5995276E-06,   8.0006230E-06
     +,   8.4135063E-06,   8.8379202E-06,   9.2735581E-06
     +,   9.7201118E-06,   1.0177184E-05,   1.0644395E-05
     +,   1.1121312E-05,   1.1607481E-05,   1.2102424E-05
     +,   1.2605654E-05,   1.3116669E-05,   1.3634965E-05
     +,   1.4160049E-05,   1.4691433E-05,   1.5228660E-05
     +,   1.5771311E-05,   1.6319005E-05,   1.6871425E-05
     +,   1.7428360E-05,   1.7989623E-05,   1.8555211E-05
     +,   1.9125193E-05,   1.9699799E-05,   2.0279420E-05
     +,   2.0864618E-05,   2.1456155E-05,   2.2055001E-05
     +,   2.2662363E-05,   2.3279674E-05,   2.3908628E-05
     +,   2.4551180E-05,   2.5209541E-05,   2.5886191E-05
     +,   2.6583890E-05,   2.7305587E-05,   2.8054534E-05
     +,   2.8834142E-05,   2.9648008E-05,   3.0499861E-05
     +,   3.1393516E-05,   3.2332813E-05,   3.3321587E-05
     +,   3.4363482E-05,   3.5462053E-05,   3.6620579E-05
     +,   3.7841870E-05,   3.9128459E-05,   4.0482151E-05
     +,   4.1904292E-05,   4.3395343E-05,   4.4955137E-05
     +,   4.6582409E-05,   4.8275197E-05,   5.0030292E-05
     +,   5.1843646E-05,   5.3710162E-05,   5.5623561E-05
     +,   5.7576563E-05,   5.9561040E-05,   6.1567960E-05
     +,   6.3587278E-05,   6.5608561E-05,   6.7620495E-05
     +,   6.9611713E-05,   7.1570328E-05,   7.3484705E-05
     +,   7.5343145E-05,   7.7134573E-05,   7.8848308E-05
     +,   8.0474623E-05,   8.2004874E-05,   8.3431500E-05
     +,   8.4748361E-05,   8.5951011E-05,   8.7036693E-05
     +,   8.8004374E-05,   8.8855093E-05,   8.9591755E-05
     +,   9.0219364E-05,   9.0744921E-05,   9.1177433E-05
     +,   9.1527865E-05,   9.1809030E-05,   9.2035574E-05
     +,   9.2223832E-05,   9.2391652E-05,   9.2558425E-05
     +,   9.2744813E-05,   9.2972798E-05,   9.3265393E-05
     +,   9.3646726E-05,   9.4141833E-05,   9.4776638E-05
     +,   9.5577845E-05,   9.6572847E-05,   9.7789765E-05
     +,   9.9256984E-05,   1.0100348E-04,   1.0305803E-04
     +,   1.0544953E-04,   1.0820637E-04,   1.1135599E-04
     +,   1.1492449E-04,   1.1893662E-04,   1.2341511E-04
     +,   1.2838020E-04,   1.3385038E-04,   1.3984172E-04
     +,   1.4636990E-04,   1.5345005E-04,   1.6110044E-04
     +,   1.6934355E-04,   1.7821173E-04,   1.8774909E-04
     +,   1.9801878E-04,   2.0910706E-04,   2.2112732E-04
     +,   2.3422495E-04,   2.4857940E-04,   2.6440405E-04
     +,   2.8193975E-04,   3.0144764E-04,   3.2319664E-04
     +,   3.4744368E-04,   3.7440800E-04,   4.0424871E-04
     +,   4.3703470E-04,   4.7271428E-04,   5.1109376E-04
     +,   5.5182271E-04,   5.9438637E-04,   6.3810893E-04
     +,   6.8217702E-04,   7.2567881E-04,   7.6765171E-04
     +,   8.0713938E-04,   8.4326399E-04,   8.7529892E-04
     +,   9.0273196E-04,   9.2532358E-04,   9.4315573E-04
     +,   9.5665798E-04,   9.6662069E-04,   9.7418728E-04
     +,   9.8082854E-04,   9.8830438E-04,   9.9860551E-04
     +,   1.0138912E-03,   1.0364143E-03,   1.0684452E-03
     +,   1.1121939E-03,   1.1697272E-03,   1.2428970E-03
     +,   1.3332375E-03,   1.4418510E-03,   1.5693111E-03
     +,   1.7155824E-03,   1.8800755E-03,   2.0619424E-03
     +,   2.2607069E-03,   2.4771749E-03,   2.7145178E-03
     +,   2.9793750E-03,   3.2827437E-03,   3.6402771E-03
     +,   4.0711020E-03,   4.5936997E-03,   5.2181380E-03
     +,   5.9378045E-03,   6.7306007E-03,   7.5821201E-03
     +,   8.5279336E-03,   9.6783685E-03,   1.1174189E-02
     +,   1.3097083E-02,   1.5500923E-02,   1.8682675E-02
     +,   2.3347804E-02,   3.0161142E-02,   3.8902290E-02
     +,   4.7553349E-02,   5.5260729E-02,   6.5652452E-02
     +,   7.6961562E-02,   8.7446027E-02,   9.9465065E-02
     +,   0.1090265    ,   0.1146131    ,   0.1175096    
     +,   0.1162416    ,   0.1097052    ,   9.5958896E-02
     +,   8.0174081E-02,   6.7507237E-02,   5.7101887E-02
     +,   4.5749214E-02,   3.3863202E-02,   2.3728926E-02
     +,   1.6772546E-02,   1.2353979E-02,   9.3388455E-03
     +,   7.0264228E-03,   5.1269331E-03,   3.5681094E-03
     +,   2.3479206E-03,   1.4577571E-03,   8.5626740E-04
     +,   4.7799994E-04,   2.5456114E-04,   1.2958259E-04
     +,   6.3073894E-05,   2.9343117E-05,   1.3038249E-05
     +,   5.5295450E-06,   2.2367410E-06,   8.6211350E-07
     +,   3.1621525E-07,   1.1021775E-07,   3.6452150E-08
     +,   1.1423553E-08,   3.3903755E-09,   9.5507824E-10
     +,   2.5821462E-10,   6.9657169E-11,   2.0944677E-11
     +,   8.4832644E-12,   4.9532704E-12,   3.5892981E-12
     +,   2.8050006E-12,   2.2358539E-12,   1.7893425E-12
     +,   1.4322079E-12,   1.1455151E-12,   9.1535254E-13
     +,   7.3069773E-13,   5.8267784E-13,   4.6413925E-13
     +,   3.6930834E-13,   2.9351811E-13,   2.3300798E-13
     +,   1.8475278E-13,   1.4631415E-13,   1.1572998E-13
     +,   9.1423254E-14,   7.2130358E-14,   5.6835230E-14
     +,   4.4724617E-14,   3.5148100E-14,   2.7585500E-14
     +,   2.1620867E-14,   1.6922783E-14,   1.3227413E-14
     +,   1.0324813E-14,   8.0479734E-15,   6.2643855E-15
     +,   4.8692896E-15,   3.7795046E-15,   2.9294834E-15
     +,   2.2673880E-15,   1.7524379E-15,   1.3524890E-15
     +,   1.0423265E-15,   8.0212633E-16,   6.1639255E-16
     +,   4.7297557E-16,   3.6240461E-16,   2.7727759E-16
     +,   2.1183595E-16,   1.6160514E-16,   1.2310367E-16
     +,   9.3638579E-17,   7.1121082E-17,   5.3939571E-17
     +,   4.0848478E-17,   3.0889349E-17,   2.3323790E-17
     +,   1.7585494E-17,   1.3239321E-17,   9.9526859E-18
     +,   7.4708620E-18,   5.5996893E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt106 = Yx/0.403142857142857
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1551176E-07,   2.4207461E-07
     +,   2.7151816E-07,   3.0410322E-07,   3.4010813E-07
     +,   3.7982872E-07,   4.2357914E-07,   4.7169232E-07
     +,   5.2451884E-07,   5.8243086E-07,   6.4581644E-07
     +,   7.1508367E-07,   7.9065921E-07,   8.7298770E-07
     +,   9.6253132E-07,   1.0597689E-06,   1.1651964E-06
     +,   1.2793245E-06,   1.4026770E-06,   1.5357917E-06
     +,   1.6792169E-06,   1.8335105E-06,   1.9992349E-06
     +,   2.1769706E-06,   2.3672812E-06,   2.5707513E-06
     +,   2.7879541E-06,   3.0194619E-06,   3.2658404E-06
     +,   3.5276473E-06,   3.8054293E-06,   4.0997184E-06
     +,   4.4110316E-06,   4.7398635E-06,   5.0866906E-06
     +,   5.4519637E-06,   5.8361052E-06,   6.2395038E-06
     +,   6.6625453E-06,   7.1055329E-06,   7.5687840E-06
     +,   8.0525542E-06,   8.5570646E-06,   9.0825069E-06
     +,   9.6290241E-06,   1.0196730E-05,   1.0785694E-05
     +,   1.1395947E-05,   1.2027486E-05,   1.2680268E-05
     +,   1.3354214E-05,   1.4049206E-05,   1.4765090E-05
     +,   1.5501721E-05,   1.6258835E-05,   1.7036231E-05
     +,   1.7833629E-05,   1.8650726E-05,   1.9487205E-05
     +,   2.0342719E-05,   2.1216896E-05,   2.2109349E-05
     +,   2.3019624E-05,   2.3947297E-05,   2.4891928E-05
     +,   2.5852962E-05,   2.6829934E-05,   2.7822223E-05
     +,   2.8829301E-05,   2.9850467E-05,   3.0885130E-05
     +,   3.1932508E-05,   3.2991913E-05,   3.4062450E-05
     +,   3.5143308E-05,   3.6233585E-05,   3.7332273E-05
     +,   3.8438280E-05,   3.9550538E-05,   4.0667896E-05
     +,   4.1789041E-05,   4.2912750E-05,   4.4037588E-05
     +,   4.5162193E-05,   4.6285033E-05,   4.7404719E-05
     +,   4.8519625E-05,   4.9628328E-05,   5.0729264E-05
     +,   5.1821018E-05,   5.2902247E-05,   5.3971711E-05
     +,   5.5028289E-05,   5.6071207E-05,   5.7099980E-05
     +,   5.8114452E-05,   5.9115166E-05,   6.0103139E-05
     +,   6.1080413E-05,   6.2049934E-05,   6.3016145E-05
     +,   6.3984910E-05,   6.4964195E-05,   6.5964246E-05
     +,   6.6998160E-05,   6.8082423E-05,   6.9237271E-05
     +,   7.0487375E-05,   7.1862552E-05,   7.3398107E-05
     +,   7.5135227E-05,   7.7121789E-05,   7.9411897E-05
     +,   8.2066465E-05,   8.5152249E-05,   8.8741748E-05
     +,   9.2911330E-05,   9.7740412E-05,   1.0330825E-04
     +,   1.0969234E-04,   1.1696483E-04,   1.2518864E-04
     +,   1.3441367E-04,   1.4467392E-04,   1.5598287E-04
     +,   1.6832908E-04,   1.8167582E-04,   1.9595613E-04
     +,   2.1107514E-04,   2.2690750E-04,   2.4330307E-04
     +,   2.6008690E-04,   2.7706887E-04,   2.9404616E-04
     +,   3.1081564E-04,   3.2718087E-04,   3.4296015E-04
     +,   3.5799711E-04,   3.7216968E-04,   3.8539543E-04
     +,   3.9763548E-04,   4.0889785E-04,   4.1923701E-04
     +,   4.2875006E-04,   4.3756975E-04,   4.4585887E-04
     +,   4.5379886E-04,   4.6158044E-04,   4.6939377E-04
     +,   4.7742156E-04,   4.8583161E-04,   4.9477461E-04
     +,   5.0438440E-04,   5.1478419E-04,   5.2609318E-04
     +,   5.3844042E-04,   5.5198016E-04,   5.6691520E-04
     +,   5.8351952E-04,   6.0216535E-04,   6.2335597E-04
     +,   6.4775173E-04,   6.7618961E-04,   7.0968765E-04
     +,   7.4942422E-04,   7.9667172E-04,   8.5268001E-04
     +,   9.1851776E-04,   9.9487079E-04,   1.0818383E-03
     +,   1.1787518E-03,   1.2841229E-03,   1.3957529E-03
     +,   1.5110465E-03,   1.6275486E-03,   1.7436682E-03
     +,   1.8594046E-03,   1.9768865E-03,   2.1004602E-03
     +,   2.2360994E-03,   2.3900361E-03,   2.5667923E-03
     +,   2.7671796E-03,   2.9870910E-03,   3.2179169E-03
     +,   3.4492097E-03,   3.6734294E-03,   3.8915868E-03
     +,   4.1177850E-03,   4.3808138E-03,   4.7221482E-03
     +,   5.1908623E-03,   5.8362111E-03,   6.6989893E-03
     +,   7.8062038E-03,   9.1754477E-03,   1.0820403E-02
     +,   1.2726551E-02,   1.4800272E-02,   1.6897988E-02
     +,   1.9043500E-02,   2.1718649E-02,   2.5817301E-02
     +,   3.2019407E-02,   4.0806830E-02,   5.2453499E-02
     +,   6.3771509E-02,   7.2865270E-02,   8.3356351E-02
     +,   9.8176673E-02,   0.1176366    ,   0.1353121    
     +,   0.1452452    ,   0.1387525    ,   0.1251940    
     +,   0.1019783    ,   7.3576674E-02,   5.6167763E-02
     +,   4.5442194E-02,   3.4993012E-02,   2.4538288E-02
     +,   1.5557762E-02,   9.0227500E-03,   4.7733891E-03
     +,   2.2777349E-03,   9.7818940E-04,   3.8175148E-04
     +,   1.3890780E-04,   5.0387229E-05,   2.1303009E-05
     +,   1.2665239E-05,   1.0350562E-05,   9.7915308E-06
     +,   9.6621561E-06,   9.6174690E-06,   9.5776759E-06
     +,   9.5266232E-06,   9.4616280E-06,   9.3825374E-06
     +,   9.2896498E-06,   9.1833745E-06,   9.0641970E-06
     +,   8.9326541E-06,   8.7893277E-06,   8.6348427E-06
     +,   8.4698768E-06,   8.2951419E-06,   8.1113740E-06
     +,   7.9193296E-06,   7.7198101E-06,   7.5136090E-06
     +,   7.3015299E-06,   7.0843962E-06,   6.8630316E-06
     +,   6.6382399E-06,   6.4108126E-06,   6.1815435E-06
     +,   5.9512067E-06,   5.7205375E-06,   5.4902448E-06
     +,   5.2610239E-06,   5.0335370E-06,   4.8083916E-06
     +,   4.5861639E-06,   4.3674058E-06,   4.1526118E-06
     +,   3.9422303E-06,   3.7366844E-06,   3.5363503E-06
     +,   3.3415488E-06,   3.1525587E-06,   2.9696300E-06
     +,   2.7929680E-06,   2.6227278E-06,   2.4590277E-06
     +,   2.3019620E-06,   2.1515709E-06,   2.0078801E-06
     +,   1.8708655E-06,   1.7404924E-06,   1.6166812E-06
     +,   1.4993437E-06,   1.3883557E-06,   1.2835865E-06
     +,   1.1848737E-06,   1.0920529E-06,   1.0049378E-06
     +,   9.2333028E-07,   8.4703208E-07,   7.7582735E-07
     +,   7.0950472E-07,   6.4784024E-07,   5.9061637E-07
     +,   5.3760778E-07,   4.8859675E-07,   4.4336127E-07
     +,   4.0168933E-07,   3.6336650E-07,   3.2818951E-07
     +,   2.9595574E-07,   2.6647345E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt108 = Yx/0.399857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2789329E-06,   2.4323722E-06
     +,   2.5935235E-06,   2.7626440E-06,   2.9400046E-06
     +,   3.1258912E-06,   3.3206086E-06,   3.5244839E-06
     +,   3.7378661E-06,   3.9611409E-06,   4.1947183E-06
     +,   4.4390449E-06,   4.6946061E-06,   4.9619321E-06
     +,   5.2415935E-06,   5.5342125E-06,   5.8404585E-06
     +,   6.1610544E-06,   6.4967730E-06,   6.8484405E-06
     +,   7.2169332E-06,   7.6031765E-06,   8.0081354E-06
     +,   8.4328376E-06,   8.8782990E-06,   9.3456119E-06
     +,   9.8358505E-06,   1.0350103E-05,   1.0889449E-05
     +,   1.1454943E-05,   1.2047598E-05,   1.2668371E-05
     +,   1.3318143E-05,   1.3997696E-05,   1.4707693E-05
     +,   1.5448666E-05,   1.6220982E-05,   1.7024819E-05
     +,   1.7860209E-05,   1.8726880E-05,   1.9624422E-05
     +,   2.0552123E-05,   2.1509044E-05,   2.2493978E-05
     +,   2.3505470E-05,   2.4541805E-05,   2.5601028E-05
     +,   2.6680960E-05,   2.7779208E-05,   2.8893206E-05
     +,   3.0020230E-05,   3.1157469E-05,   3.2302025E-05
     +,   3.3451051E-05,   3.4601650E-05,   3.5751127E-05
     +,   3.6896898E-05,   3.8036615E-05,   3.9168233E-05
     +,   4.0290062E-05,   4.1400817E-05,   4.2499694E-05
     +,   4.3586348E-05,   4.4661047E-05,   4.5724664E-05
     +,   4.6778532E-05,   4.7824728E-05,   4.8865764E-05
     +,   4.9904851E-05,   5.0945571E-05,   5.1992036E-05
     +,   5.3048614E-05,   5.4120068E-05,   5.5211174E-05
     +,   5.6326859E-05,   5.7471891E-05,   5.8650789E-05
     +,   5.9867645E-05,   6.1126062E-05,   6.2429041E-05
     +,   6.3778592E-05,   6.5175991E-05,   6.6621331E-05
     +,   6.8113724E-05,   6.9650989E-05,   7.1229908E-05
     +,   7.2845891E-05,   7.4493400E-05,   7.6165612E-05
     +,   7.7854893E-05,   7.9552759E-05,   8.1249942E-05
     +,   8.2936756E-05,   8.4603307E-05,   8.6239750E-05
     +,   8.7836255E-05,   8.9383720E-05,   9.0873655E-05
     +,   9.2298695E-05,   9.3652539E-05,   9.4930590E-05
     +,   9.6129697E-05,   9.7248783E-05,   9.8288430E-05
     +,   9.9251578E-05,   1.0014317E-04,   1.0097030E-04
     +,   1.0174212E-04,   1.0246996E-04,   1.0316708E-04
     +,   1.0384861E-04,   1.0453133E-04,   1.0523349E-04
     +,   1.0597482E-04,   1.0677589E-04,   1.0765828E-04
     +,   1.0864402E-04,   1.0975567E-04,   1.1101571E-04
     +,   1.1244648E-04,   1.1407008E-04,   1.1590783E-04
     +,   1.1798021E-04,   1.2030679E-04,   1.2290606E-04
     +,   1.2579492E-04,   1.2898925E-04,   1.3250324E-04
     +,   1.3634987E-04,   1.4054040E-04,   1.4508510E-04
     +,   1.4999240E-04,   1.5527006E-04,   1.6092403E-04
     +,   1.6695954E-04,   1.7338063E-04,   1.8018975E-04
     +,   1.8738802E-04,   1.9497544E-04,   2.0295067E-04
     +,   2.1131031E-04,   2.2004932E-04,   2.2916232E-04
     +,   2.3864362E-04,   2.4848734E-04,   2.5869123E-04
     +,   2.6925810E-04,   2.8019829E-04,   2.9153426E-04
     +,   3.0330516E-04,   3.1557056E-04,   3.2841417E-04
     +,   3.4194702E-04,   3.5631060E-04,   3.7167527E-04
     +,   3.8823555E-04,   4.0620528E-04,   4.2580804E-04
     +,   4.4726400E-04,   4.7077221E-04,   4.9649953E-04
     +,   5.2456587E-04,   5.5503339E-04,   5.8790838E-04
     +,   6.2315632E-04,   6.6073291E-04,   7.0062705E-04
     +,   7.4293686E-04,   7.8795623E-04,   8.3626359E-04
     +,   8.8879839E-04,   9.4690692E-04,   1.0123242E-03
     +,   1.0870658E-03,   1.1732070E-03,   1.2725898E-03
     +,   1.3864539E-03,   1.5150530E-03,   1.6573629E-03
     +,   1.8109567E-03,   1.9721149E-03,   2.1362433E-03
     +,   2.2987574E-03,   2.4564385E-03,   2.6092960E-03
     +,   2.7627784E-03,   2.9297844E-03,   3.1313552E-03
     +,   3.3946082E-03,   3.7468132E-03,   4.2060958E-03
     +,   4.7712792E-03,   5.4155630E-03,   6.0897772E-03
     +,   6.7395386E-03,   7.3364805E-03,   7.9144305E-03
     +,   8.5869655E-03,   9.5177619E-03,   1.0841697E-02
     +,   1.2583776E-02,   1.4632414E-02,   1.6773112E-02
     +,   1.8774504E-02,   2.0558508E-02,   2.2377849E-02
     +,   2.4657698E-02,   2.7707817E-02,   3.2471608E-02
     +,   4.0126666E-02,   4.9713489E-02,   6.3269325E-02
     +,   8.3347596E-02,   0.1030841    ,   0.1227585    
     +,   0.1396928    ,   0.1497284    ,   0.1505635    
     +,   0.1302825    ,   0.1033961    ,   7.0809923E-02
     +,   4.2430904E-02,   2.2590267E-02,   9.7342012E-03
     +,   3.2386545E-03,   8.9330727E-04,   2.7641526E-04
     +,   1.2861704E-04,   7.3257186E-05,   4.1629890E-05
     +,   2.3750834E-05,   1.4928793E-05,   1.1145418E-05
     +,   9.7216762E-06,   9.2427754E-06,   9.0861840E-06
     +,   9.0187496E-06,   8.9657251E-06,   8.9066916E-06
     +,   8.8370225E-06,   8.7560175E-06,   8.6638320E-06
     +,   8.5608162E-06,   8.4473731E-06,   8.3239465E-06
     +,   8.1910193E-06,   8.0491145E-06,   7.8987669E-06
     +,   7.7405439E-06,   7.5750399E-06,   7.4028585E-06
     +,   7.2246144E-06,   7.0409437E-06,   6.8524919E-06
     +,   6.6598918E-06,   6.4637766E-06,   6.2647891E-06
     +,   6.0635657E-06,   5.8607156E-06,   5.6568383E-06
     +,   5.4525262E-06,   5.2483556E-06,   5.0448671E-06
     +,   4.8425773E-06,   4.6419977E-06,   4.4435938E-06
     +,   4.2477996E-06,   4.0550349E-06,   3.8656890E-06
     +,   3.6801036E-06,   3.4985937E-06,   3.3214512E-06
     +,   3.1489362E-06,   2.9812672E-06,   2.8186300E-06
     +,   2.6611967E-06,   2.5090887E-06,   2.3624186E-06
     +,   2.2212516E-06,   2.0856455E-06,   1.9556146E-06
     +,   1.8311667E-06,   1.7122711E-06,   1.5988917E-06
     +,   1.4909584E-06,   1.3883980E-06,   1.2911103E-06
     +,   1.1989820E-06,   1.1118955E-06,   1.0297103E-06
     +,   9.5228796E-07,   8.7947069E-07,   8.1110397E-07
     +,   7.4701836E-07,   6.8705009E-07,   6.3102289E-07
     +,   5.7876736E-07,   5.3010581E-07,   4.8486788E-07
     +,   4.4287779E-07,   4.0396765E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt110 = Yx/0.375714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt111(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3161529E-06,   1.4284032E-06
     +,   1.5483042E-06,   1.6761975E-06,   1.8124235E-06
     +,   1.9573210E-06,   2.1112262E-06,   2.2744698E-06
     +,   2.4473734E-06,   2.6302589E-06,   2.8234299E-06
     +,   3.0271815E-06,   3.2417950E-06,   3.4675359E-06
     +,   3.7046530E-06,   3.9533766E-06,   4.2139150E-06
     +,   4.4864546E-06,   4.7711583E-06,   5.0681606E-06
     +,   5.3775730E-06,   5.6994731E-06,   6.0339057E-06
     +,   6.3809071E-06,   6.7404385E-06,   7.1124718E-06
     +,   7.4969184E-06,   7.8936619E-06,   8.3025525E-06
     +,   8.7234030E-06,   9.1559932E-06,   9.6000667E-06
     +,   1.0055335E-05,   1.0521476E-05,   1.0998135E-05
     +,   1.1484924E-05,   1.1981434E-05,   1.2487214E-05
     +,   1.3001826E-05,   1.3524745E-05,   1.4055492E-05
     +,   1.4593537E-05,   1.5138343E-05,   1.5689366E-05
     +,   1.6246055E-05,   1.6807857E-05,   1.7374223E-05
     +,   1.7944609E-05,   1.8518487E-05,   1.9095340E-05
     +,   1.9674673E-05,   2.0256022E-05,   2.0838932E-05
     +,   2.1423031E-05,   2.2007916E-05,   2.2593300E-05
     +,   2.3178891E-05,   2.3764478E-05,   2.4349889E-05
     +,   2.4935023E-05,   2.5519836E-05,   2.6104355E-05
     +,   2.6688638E-05,   2.7272850E-05,   2.7857246E-05
     +,   2.8442064E-05,   2.9027697E-05,   2.9614534E-05
     +,   3.0203091E-05,   3.0793868E-05,   3.1387510E-05
     +,   3.1984626E-05,   3.2585947E-05,   3.3192176E-05
     +,   3.3804099E-05,   3.4422534E-05,   3.5048281E-05
     +,   3.5682137E-05,   3.6324978E-05,   3.6977639E-05
     +,   3.7640904E-05,   3.8315626E-05,   3.9002545E-05
     +,   3.9702456E-05,   4.0416038E-05,   4.1144034E-05
     +,   4.1887055E-05,   4.2645763E-05,   4.3420714E-05
     +,   4.4212484E-05,   4.5021636E-05,   4.5848694E-05
     +,   4.6694135E-05,   4.7558544E-05,   4.8442511E-05
     +,   4.9346600E-05,   5.0271519E-05,   5.1217987E-05
     +,   5.2186904E-05,   5.3179188E-05,   5.4196040E-05
     +,   5.5238703E-05,   5.6308731E-05,   5.7407768E-05
     +,   5.8537855E-05,   5.9701255E-05,   6.0900464E-05
     +,   6.2138359E-05,   6.3418236E-05,   6.4743828E-05
     +,   6.6119173E-05,   6.7549016E-05,   6.9038520E-05
     +,   7.0593611E-05,   7.2220806E-05,   7.3927600E-05
     +,   7.5722135E-05,   7.7613797E-05,   7.9612786E-05
     +,   8.1730643E-05,   8.3980172E-05,   8.6375279E-05
     +,   8.8931258E-05,   9.1664828E-05,   9.4594092E-05
     +,   9.7738164E-05,   1.0111769E-04,   1.0475411E-04
     +,   1.0867036E-04,   1.1288989E-04,   1.1743783E-04
     +,   1.2233987E-04,   1.2762372E-04,   1.3331859E-04
     +,   1.3945675E-04,   1.4607435E-04,   1.5321211E-04
     +,   1.6091745E-04,   1.6924678E-04,   1.7826723E-04
     +,   1.8805824E-04,   1.9871385E-04,   2.1034549E-04
     +,   2.2308227E-04,   2.3707033E-04,   2.5247413E-04
     +,   2.6947385E-04,   2.8826046E-04,   3.0903172E-04
     +,   3.3198734E-04,   3.5732030E-04,   3.8520686E-04
     +,   4.1579784E-04,   4.4921224E-04,   4.8552547E-04
     +,   5.2476121E-04,   5.6688598E-04,   6.1181036E-04
     +,   6.5939175E-04,   7.0943485E-04,   7.6171930E-04
     +,   8.1601564E-04,   8.7210740E-04,   9.2981849E-04
     +,   9.8903372E-04,   1.0496940E-03,   1.1117694E-03
     +,   1.1752137E-03,   1.2398972E-03,   1.3055283E-03
     +,   1.3716053E-03,   1.4374359E-03,   1.5022712E-03
     +,   1.5655559E-03,   1.6273051E-03,   1.6885630E-03
     +,   1.7517977E-03,   1.8210678E-03,   1.9018145E-03
     +,   2.0001207E-03,   2.1214890E-03,   2.2693730E-03
     +,   2.4439725E-03,   2.6419472E-03,   2.8574984E-03
     +,   3.0849106E-03,   3.3218211E-03,   3.5716007E-03
     +,   3.8428949E-03,   4.1453387E-03,   4.4826572E-03
     +,   4.8467033E-03,   5.2171368E-03,   5.5691684E-03
     +,   5.8863703E-03,   6.1711613E-03,   6.4458046E-03
     +,   6.7434623E-03,   7.0966901E-03,   7.5332648E-03
     +,   8.0829412E-03,   8.7899361E-03,   9.7209765E-03
     +,   1.0961597E-02,   1.2609608E-02,   1.4796313E-02
     +,   1.7712669E-02,   2.1508254E-02,   2.6094140E-02
     +,   3.1245425E-02,   3.7406631E-02,   4.5768108E-02
     +,   5.6355935E-02,   6.9771059E-02,   8.4651813E-02
     +,   0.1007550    ,   0.1254414    ,   0.1483643    
     +,   0.1648101    ,   0.1601044    ,   0.1315238    
     +,   9.2626393E-02,   4.9059778E-02,   1.7657302E-02
     +,   4.1563921E-03,   6.0631998E-04,   5.0876144E-05
     +,   2.3651537E-06,   7.0028342E-08,   1.0029830E-08
     +,   7.8572695E-09,   6.6743993E-09,   5.6667173E-09
     +,   4.8050657E-09,   4.0692165E-09,   3.4415686E-09
     +,   2.9068814E-09,   2.4519984E-09,   2.0655286E-09
     +,   1.7376127E-09,   1.4597458E-09,   1.2246237E-09
     +,   1.0259520E-09,   8.5830842E-10,   7.1704409E-10
     +,   5.9818112E-10,   4.9831350E-10,   4.1452505E-10
     +,   3.4432676E-10,   2.8560410E-10,   2.3655214E-10
     +,   1.9563752E-10,   1.6156269E-10,   1.3322739E-10
     +,   1.0969935E-10,   9.0192048E-11,   7.4043445E-11
     +,   6.0695962E-11,   4.9680184E-11,   4.0602445E-11
     +,   3.3133527E-11,   2.6997989E-11,   2.1965370E-11
     +,   1.7843713E-11,   1.4473560E-11,   1.1722089E-11
     +,   9.4791570E-12,   7.6537023E-12,   6.1703945E-12
     +,   4.9669418E-12,   3.9920554E-12,   3.2035913E-12
     +,   2.5669239E-12,   2.0536201E-12,   1.6404192E-12
     +,   1.3083474E-12,   1.0418811E-12,   8.2840944E-13
     +,   6.5765308E-13,   5.2129075E-13,   4.1255980E-13
     +,   3.2600482E-13,   2.5720753E-13,   2.0261589E-13
     +,   1.5936227E-13,   1.2514843E-13,   9.8127412E-14
     +,   7.6820522E-14,   6.0047013E-14,   4.6862552E-14
     +,   3.6516383E-14,   2.8409865E-14,   2.2068796E-14
     +,   1.7116195E-14,   1.3254438E-14,   1.0247916E-14
     +,   7.9110650E-15,   6.0975327E-15,   4.6924338E-15
     +,   3.6054618E-15,   2.7659789E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt111 = Yx/0.369
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0499317E-06,   4.2861584E-06
     +,   4.5318397E-06,   4.7870558E-06,   5.0518706E-06
     +,   5.3263266E-06,   5.6104468E-06,   5.9042313E-06
     +,   6.2076551E-06,   6.5206827E-06,   6.8432460E-06
     +,   7.1752524E-06,   7.5165899E-06,   7.8671228E-06
     +,   8.2266924E-06,   8.5951133E-06,   8.9721843E-06
     +,   9.3576764E-06,   9.7513421E-06,   1.0152914E-05
     +,   1.0562105E-05,   1.0978610E-05,   1.1402097E-05
     +,   1.1832257E-05,   1.2268708E-05,   1.2711112E-05
     +,   1.3159093E-05,   1.3612276E-05,   1.4070278E-05
     +,   1.4532719E-05,   1.4999218E-05,   1.5469397E-05
     +,   1.5942882E-05,   1.6419312E-05,   1.6898337E-05
     +,   1.7379623E-05,   1.7862849E-05,   1.8347719E-05
     +,   1.8833978E-05,   1.9321344E-05,   1.9809635E-05
     +,   2.0298650E-05,   2.0788240E-05,   2.1278292E-05
     +,   2.1768723E-05,   2.2259499E-05,   2.2750621E-05
     +,   2.3242137E-05,   2.3734126E-05,   2.4226725E-05
     +,   2.4720099E-05,   2.5214460E-05,   2.5710058E-05
     +,   2.6207206E-05,   2.6706197E-05,   2.7207427E-05
     +,   2.7711274E-05,   2.8218174E-05,   2.8728567E-05
     +,   2.9242934E-05,   2.9761761E-05,   3.0285553E-05
     +,   3.0814801E-05,   3.1350046E-05,   3.1891806E-05
     +,   3.2440566E-05,   3.2996861E-05,   3.3561129E-05
     +,   3.4133893E-05,   3.4715536E-05,   3.5306519E-05
     +,   3.5907200E-05,   3.6517969E-05,   3.7139107E-05
     +,   3.7770918E-05,   3.8413677E-05,   3.9067574E-05
     +,   3.9732775E-05,   4.0409464E-05,   4.1097785E-05
     +,   4.1797812E-05,   4.2509702E-05,   4.3233493E-05
     +,   4.3969369E-05,   4.4717421E-05,   4.5477886E-05
     +,   4.6250992E-05,   4.7037123E-05,   4.7836718E-05
     +,   4.8650447E-05,   4.9479149E-05,   5.0323903E-05
     +,   5.1186020E-05,   5.2067280E-05,   5.2969823E-05
     +,   5.3896249E-05,   5.4849810E-05,   5.5834291E-05
     +,   5.6854384E-05,   5.7915484E-05,   5.9024100E-05
     +,   6.0187645E-05,   6.1414888E-05,   6.2715750E-05
     +,   6.4101652E-05,   6.5585540E-05,   6.7181922E-05
     +,   6.8906884E-05,   7.0778435E-05,   7.2816300E-05
     +,   7.5041833E-05,   7.7478260E-05,   8.0150232E-05
     +,   8.3084080E-05,   8.6307053E-05,   8.9847708E-05
     +,   9.3734780E-05,   9.7997574E-05,   1.0266444E-04
     +,   1.0776320E-04,   1.1331996E-04,   1.1935806E-04
     +,   1.2589751E-04,   1.3295456E-04,   1.4054072E-04
     +,   1.4866079E-04,   1.5731415E-04,   1.6649187E-04
     +,   1.7617850E-04,   1.8634934E-04,   1.9697305E-04
     +,   2.0800924E-04,   2.1941193E-04,   2.3112747E-04
     +,   2.4309903E-04,   2.5526696E-04,   2.6757034E-04
     +,   2.7995047E-04,   2.9235403E-04,   3.0473602E-04
     +,   3.1706138E-04,   3.2930941E-04,   3.4147722E-04
     +,   3.5358220E-04,   3.6566312E-04,   3.7778536E-04
     +,   3.9004168E-04,   4.0255429E-04,   4.1547749E-04
     +,   4.2900111E-04,   4.4335259E-04,   4.5879863E-04
     +,   4.7564867E-04,   4.9425958E-04,   5.1503669E-04
     +,   5.3843466E-04,   5.6495791E-04,   5.9516111E-04
     +,   6.2964170E-04,   6.6902337E-04,   7.1394315E-04
     +,   7.6501473E-04,   8.2277961E-04,   8.8764651E-04
     +,   9.5982099E-04,   1.0392158E-03,   1.1253649E-03
     +,   1.2173583E-03,   1.3138268E-03,   1.4129707E-03
     +,   1.5126623E-03,   1.6106534E-03,   1.7048728E-03
     +,   1.7937594E-03,   1.8766333E-03,   1.9540614E-03
     +,   2.0280990E-03,   2.1024051E-03,   2.1821668E-03
     +,   2.2738161E-03,   2.3845385E-03,   2.5216097E-03
     +,   2.6915958E-03,   2.8994705E-03,   3.1476400E-03
     +,   3.4350378E-03,   3.7565634E-03,   4.1033113E-03
     +,   4.4638696E-03,   4.8269606E-03,   5.1852106E-03
     +,   5.5388929E-03,   5.8981869E-03,   6.2819915E-03
     +,   6.7124828E-03,   7.2072418E-03,   7.7736261E-03
     +,   8.4096026E-03,   9.1093099E-03,   9.8682940E-03
     +,   1.0689197E-02,   1.1596404E-02,   1.2655985E-02
     +,   1.3973519E-02,   1.5650412E-02,   1.7718092E-02
     +,   2.0085800E-02,   2.2558659E-02,   2.5063986E-02
     +,   2.8033113E-02,   3.2174829E-02,   3.7575264E-02
     +,   4.3915201E-02,   5.0861850E-02,   5.8541175E-02
     +,   7.0291519E-02,   8.6551778E-02,   0.1079085    
     +,   0.1306551    ,   0.1473699    ,   0.1598131    
     +,   0.1447019    ,   9.2552274E-02,   3.7612442E-02
     +,   8.6005563E-03,   1.0087118E-03,   5.8132133E-05
     +,   1.6114492E-06,   2.1773529E-08,   7.6115536E-10
     +,   5.1929289E-10,   4.2372023E-10,   3.4578590E-10
     +,   2.8202618E-10,   2.2988880E-10,   1.8727532E-10
     +,   1.5246507E-10,   1.2404815E-10,   1.0086634E-10
     +,   8.1967488E-11,   6.6570548E-11,   5.4035790E-11
     +,   4.3838346E-11,   3.5547613E-11,   2.8811146E-11
     +,   2.3341119E-11,   1.8902152E-11,   1.5301703E-11
     +,   1.2382758E-11,   1.0017584E-11,   8.1018707E-12
     +,   6.5507617E-12,   5.2953575E-12,   4.2796352E-12
     +,   3.4580377E-12,   2.7936193E-12,   2.2564435E-12
     +,   1.8222500E-12,   1.4713450E-12,   1.1877912E-12
     +,   9.5870501E-13,   7.7365696E-13,   6.2419612E-13
     +,   5.0349389E-13,   4.0603640E-13,   3.2735660E-13
     +,   2.6384561E-13,   2.1259040E-13,   1.7123510E-13
     +,   1.3787382E-13,   1.1096735E-13,   8.9273620E-14
     +,   7.1788346E-14,   5.7699430E-14,   4.6350981E-14
     +,   3.7214142E-14,   2.9860724E-14,   2.3945687E-14
     +,   1.9189789E-14,   1.5368176E-14,   1.2298832E-14
     +,   9.8353722E-15,   7.8593104E-15,   6.2753829E-15
     +,   5.0065708E-15,   3.9909982E-15,   3.1787150E-15
     +,   2.5295133E-15,   2.0111078E-15,   1.5974713E-15
     +,   1.2677357E-15,   1.0050990E-15,   7.9610975E-16
     +,   6.2995164E-16,   4.9798327E-16,   3.9326136E-16
     +,   3.1024855E-16,   2.4450493E-16,   1.9249485E-16
     +,   1.5138807E-16,   1.1893501E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt112 = Yx/0.359571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt1128(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.0862340E-06,   6.2602153E-06
     +,   6.4319333E-06,   6.6009748E-06,   6.7669289E-06
     +,   6.9293969E-06,   7.0879905E-06,   7.2423381E-06
     +,   7.3920828E-06,   7.5368989E-06,   7.6764791E-06
     +,   7.8105468E-06,   7.9388601E-06,   8.0612126E-06
     +,   8.1774397E-06,   8.2874203E-06,   8.3910845E-06
     +,   8.4884105E-06,   8.5794318E-06,   8.6642467E-06
     +,   8.7430080E-06,   8.8159422E-06,   8.8833376E-06
     +,   8.9455616E-06,   9.0030462E-06,   9.0563099E-06
     +,   9.1059446E-06,   9.1526235E-06,   9.1970969E-06
     +,   9.2402051E-06,   9.2828604E-06,   9.3260642E-06
     +,   9.3708913E-06,   9.4184988E-06,   9.4701118E-06
     +,   9.5270343E-06,   9.5906307E-06,   9.6623262E-06
     +,   9.7436041E-06,   9.8359887E-06,   9.9410436E-06
     +,   1.0060361E-05,   1.0195548E-05,   1.0348217E-05
     +,   1.0519972E-05,   1.0712395E-05,   1.0927030E-05
     +,   1.1165373E-05,   1.1428842E-05,   1.1718775E-05
     +,   1.2036406E-05,   1.2382848E-05,   1.2759069E-05
     +,   1.3165905E-05,   1.3603978E-05,   1.4073762E-05
     +,   1.4575506E-05,   1.5109248E-05,   1.5674790E-05
     +,   1.6271699E-05,   1.6899292E-05,   1.7556644E-05
     +,   1.8242526E-05,   1.8955514E-05,   1.9693927E-05
     +,   2.0455767E-05,   2.1238908E-05,   2.2040884E-05
     +,   2.2859154E-05,   2.3690884E-05,   2.4533192E-05
     +,   2.5382978E-05,   2.6237178E-05,   2.7092558E-05
     +,   2.7945978E-05,   2.8794364E-05,   2.9634666E-05
     +,   3.0464014E-05,   3.1279800E-05,   3.2079686E-05
     +,   3.2861608E-05,   3.3624005E-05,   3.4365676E-05
     +,   3.5086043E-05,   3.5785037E-05,   3.6463320E-05
     +,   3.7122176E-05,   3.7763759E-05,   3.8390903E-05
     +,   3.9007384E-05,   3.9617855E-05,   4.0227813E-05
     +,   4.0843686E-05,   4.1472835E-05,   4.2123567E-05
     +,   4.2804968E-05,   4.3527041E-05,   4.4300501E-05
     +,   4.5136854E-05,   4.6048182E-05,   4.7047128E-05
     +,   4.8146710E-05,   4.9360395E-05,   5.0701656E-05
     +,   5.2184263E-05,   5.3821848E-05,   5.5627908E-05
     +,   5.7615671E-05,   5.9798207E-05,   6.2188323E-05
     +,   6.4798260E-05,   6.7640329E-05,   7.0726295E-05
     +,   7.4068288E-05,   7.7678131E-05,   8.1568418E-05
     +,   8.5751919E-05,   9.0242742E-05,   9.5055613E-05
     +,   1.0020701E-04,   1.0571515E-04,   1.1159953E-04
     +,   1.1788142E-04,   1.2458402E-04,   1.3173193E-04
     +,   1.3934993E-04,   1.4746367E-04,   1.5609703E-04
     +,   1.6527290E-04,   1.7500941E-04,   1.8532129E-04
     +,   1.9621498E-04,   2.0769035E-04,   2.1973620E-04
     +,   2.3233129E-04,   2.4544285E-04,   2.5902520E-04
     +,   2.7302050E-04,   2.8736112E-04,   3.0197052E-04
     +,   3.1676440E-04,   3.3165529E-04,   3.4655738E-04
     +,   3.6138954E-04,   3.7607903E-04,   3.9056773E-04
     +,   4.0481592E-04,   4.1880371E-04,   4.3253516E-04
     +,   4.4604111E-04,   4.5937879E-04,   4.7263192E-04
     +,   4.8591310E-04,   4.9936614E-04,   5.1316962E-04
     +,   5.2754389E-04,   5.4276444E-04,   5.5918016E-04
     +,   5.7723623E-04,   5.9750018E-04,   6.2069460E-04
     +,   6.4772059E-04,   6.7967002E-04,   7.1781705E-04
     +,   7.6358346E-04,   8.1845705E-04,   8.8387332E-04
     +,   9.6106925E-04,   1.0509370E-03,   1.1538866E-03
     +,   1.2697560E-03,   1.3978075E-03,   1.5368066E-03
     +,   1.6851225E-03,   1.8408364E-03,   2.0018590E-03
     +,   2.1659464E-03,   2.3307372E-03,   2.4938828E-03
     +,   2.6533855E-03,   2.8082184E-03,   2.9592167E-03
     +,   3.1101406E-03,   3.2685676E-03,   3.4461385E-03
     +,   3.6576688E-03,   3.9188857E-03,   4.2430116E-03
     +,   4.6373215E-03,   5.1012430E-03,   5.6273541E-03
     +,   6.2046391E-03,   6.8217958E-03,   7.4682184E-03
     +,   8.1322705E-03,   8.8000456E-03,   9.4592962E-03
     +,   1.0112108E-02,   1.0793021E-02,   1.1577744E-02
     +,   1.2560877E-02,   1.3795950E-02,   1.5231925E-02
     +,   1.6720761E-02,   1.8153137E-02,   1.9635756E-02
     +,   2.1487854E-02,   2.3979789E-02,   2.6990471E-02
     +,   3.0130208E-02,   3.3811994E-02,   3.8962383E-02
     +,   4.4331372E-02,   4.8557211E-02,   5.3350482E-02
     +,   5.9197631E-02,   6.8436526E-02,   8.6566500E-02
     +,   0.1126208    ,   0.1366610    ,   0.1456705    
     +,   0.1353382    ,   9.5630519E-02,   4.2223573E-02
     +,   1.0368159E-02,   1.4424897E-03,   1.9740236E-04
     +,   6.0515908E-05,   1.9199671E-05,   4.2102201E-06
     +,   6.2104573E-07,   6.6656625E-08,   1.0105837E-08
     +,   5.6361587E-09,   4.7789657E-09,   4.1620174E-09
     +,   3.6243613E-09,   3.1528999E-09,   2.7398483E-09
     +,   2.3783386E-09,   2.0622637E-09,   1.7862265E-09
     +,   1.5454269E-09,   1.3355963E-09,   1.1529517E-09
     +,   9.9415898E-10,   8.5626800E-10,   7.3666140E-10
     +,   6.3303324E-10,   5.4336030E-10,   4.6585347E-10
     +,   3.9893902E-10,   3.4124048E-10,   2.9155003E-10
     +,   2.4880548E-10,   2.1207966E-10,   1.8056412E-10
     +,   1.5355310E-10,   1.3043010E-10,   1.1065880E-10
     +,   9.3774689E-11,   7.9373987E-11,   6.7105835E-11
     +,   5.6667067E-11,   4.7796107E-11,   4.0266450E-11
     +,   3.3882949E-11,   2.8477843E-11,   2.3906974E-11
     +,   2.0046109E-11,   1.6788853E-11,   1.4044311E-11
     +,   1.1734632E-11,   9.7932357E-12,   8.1633433E-12
     +,   6.7967225E-12,   5.6521784E-12,   4.6948474E-12
     +,   3.8950384E-12,   3.2276876E-12,   2.6714976E-12
     +,   2.2085506E-12,   1.8236612E-12,   1.5040766E-12
     +,   1.2390220E-12,   1.0194779E-12,   8.3784179E-13
     +,   6.8774836E-13,   5.6387875E-13,   4.6176881E-13
     +,   3.7770508E-13,   3.0857763E-13,   2.5180455E-13
     +,   2.0523203E-13,   1.6707691E-13,   1.3585275E-13
     +,   1.1033419E-13,   8.9502068E-14,   7.2517967E-14
     +,   5.8686542E-14,   4.7437386E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt1128 = Yx/0.344895833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0923201E-07,   2.2879262E-07
     +,   2.5000259E-07,   2.7298560E-07,   2.9787387E-07
     +,   3.2480790E-07,   3.5393768E-07,   3.8542242E-07
     +,   4.1943139E-07,   4.5614635E-07,   4.9575800E-07
     +,   5.3847037E-07,   5.8449945E-07,   6.3407413E-07
     +,   6.8743799E-07,   7.4484745E-07,   8.0657566E-07
     +,   8.7290920E-07,   9.4415338E-07,   1.0206278E-06
     +,   1.1026717E-06,   1.1906408E-06,   1.2849083E-06
     +,   1.3858730E-06,   1.4939415E-06,   1.6095526E-06
     +,   1.7331583E-06,   1.8652333E-06,   2.0062730E-06
     +,   2.1567953E-06,   2.3173372E-06,   2.4884600E-06
     +,   2.6707453E-06,   2.8647969E-06,   3.0712390E-06
     +,   3.2907194E-06,   3.5239048E-06,   3.7714810E-06
     +,   4.0341706E-06,   4.3126870E-06,   4.6077953E-06
     +,   4.9202617E-06,   5.2508785E-06,   5.6004565E-06
     +,   5.9698273E-06,   6.3598409E-06,   6.7713686E-06
     +,   7.2052999E-06,   7.6625456E-06,   8.1440376E-06
     +,   8.6507252E-06,   9.1835836E-06,   9.7435986E-06
     +,   1.0331817E-05,   1.0949243E-05,   1.1596973E-05
     +,   1.2276091E-05,   1.2987719E-05,   1.3733006E-05
     +,   1.4513121E-05,   1.5329277E-05,   1.6182716E-05
     +,   1.7074664E-05,   1.8006434E-05,   1.8979374E-05
     +,   1.9994770E-05,   2.1054047E-05,   2.2158529E-05
     +,   2.3309685E-05,   2.4508858E-05,   2.5757547E-05
     +,   2.7057107E-05,   2.8409046E-05,   2.9814692E-05
     +,   3.1275504E-05,   3.2792930E-05,   3.4368313E-05
     +,   3.6002966E-05,   3.7698301E-05,   3.9455714E-05
     +,   4.1276468E-05,   4.3162036E-05,   4.5113720E-05
     +,   4.7133122E-05,   4.9221671E-05,   5.1381216E-05
     +,   5.3613498E-05,   5.5920769E-05,   5.8305268E-05
     +,   6.0769842E-05,   6.3317704E-05,   6.5952467E-05
     +,   6.8678215E-05,   7.1499868E-05,   7.4422976E-05
     +,   7.7453595E-05,   8.0598824E-05,   8.3866136E-05
     +,   8.7264183E-05,   9.0801761E-05,   9.4488787E-05
     +,   9.8335091E-05,   1.0235131E-04,   1.0654758E-04
     +,   1.1093423E-04,   1.1552109E-04,   1.2031686E-04
     +,   1.2532889E-04,   1.3056338E-04,   1.3602432E-04
     +,   1.4171292E-04,   1.4762823E-04,   1.5376555E-04
     +,   1.6011755E-04,   1.6667272E-04,   1.7341693E-04
     +,   1.8033190E-04,   1.8739718E-04,   1.9458897E-04
     +,   2.0188214E-04,   2.0925082E-04,   2.1666863E-04
     +,   2.2411047E-04,   2.3155451E-04,   2.3898300E-04
     +,   2.4638328E-04,   2.5375080E-04,   2.6108886E-04
     +,   2.6841162E-04,   2.7574337E-04,   2.8312104E-04
     +,   2.9059275E-04,   2.9821869E-04,   3.0606927E-04
     +,   3.1422425E-04,   3.2277027E-04,   3.3179697E-04
     +,   3.4139396E-04,   3.5164782E-04,   3.6263699E-04
     +,   3.7442730E-04,   3.8706968E-04,   4.0059804E-04
     +,   4.1502915E-04,   4.3036268E-04,   4.4658853E-04
     +,   4.6369512E-04,   4.8167881E-04,   5.0056347E-04
     +,   5.2042131E-04,   5.4139690E-04,   5.6373223E-04
     +,   5.8779487E-04,   6.1410409E-04,   6.4334203E-04
     +,   6.7635562E-04,   7.1413734E-04,   7.5778336E-04
     +,   8.0842018E-04,   8.6710125E-04,   9.3470444E-04
     +,   1.0118191E-03,   1.0986516E-03,   1.1949980E-03
     +,   1.3003013E-03,   1.4137796E-03,   1.5346523E-03
     +,   1.6624330E-03,   1.7972194E-03,   1.9398886E-03
     +,   2.0920939E-03,   2.2560295E-03,   2.4339180E-03
     +,   2.6272589E-03,   2.8360081E-03,   3.0580359E-03
     +,   3.2889915E-03,   3.5228729E-03,   3.7533788E-03
     +,   3.9758403E-03,   4.1893069E-03,   4.3983078E-03
     +,   4.6136556E-03,   4.8517212E-03,   5.1316991E-03
     +,   5.4710796E-03,   5.8804429E-03,   6.3598203E-03
     +,   6.8991012E-03,   7.4839504E-03,   8.1047826E-03
     +,   8.7624481E-03,   9.4637200E-03,   1.0206962E-02
     +,   1.0969857E-02,   1.1715006E-02,   1.2413839E-02
     +,   1.3065493E-02,   1.3685313E-02,   1.4269042E-02
     +,   1.4775747E-02,   1.5181642E-02,   1.5598241E-02
     +,   1.6323727E-02,   1.7660791E-02,   1.9596728E-02
     +,   2.1784194E-02,   2.4056649E-02,   2.6815873E-02
     +,   3.0393401E-02,   3.4272298E-02,   3.7933238E-02
     +,   4.2101696E-02,   4.7635909E-02,   5.4064263E-02
     +,   6.1379816E-02,   7.0279762E-02,   7.9734959E-02
     +,   8.8048078E-02,   9.6272312E-02,   0.1013336    
     +,   9.2539228E-02,   6.5687858E-02,   3.3520557E-02
     +,   1.1630779E-02,   2.6146991E-03,   3.6550415E-04
     +,   3.0866140E-05,   1.5485464E-06,   4.6169085E-08
     +,   1.2141185E-09,   3.7125131E-10,   3.1003825E-10
     +,   2.6457836E-10,   2.2587034E-10,   1.9284577E-10
     +,   1.6464874E-10,   1.4056055E-10,   1.1997509E-10
     +,   1.0237801E-10,   8.7333127E-11,   7.4470846E-11
     +,   6.3475870E-11,   5.4078481E-11,   4.6048425E-11
     +,   3.9189135E-11,   3.3332427E-11,   2.8333724E-11
     +,   2.4069285E-11,   2.0433389E-11,   1.7334996E-11
     +,   1.4696125E-11,   1.2450109E-11,   1.0539723E-11
     +,   8.9158620E-12,   7.5364480E-12,   6.3655544E-12
     +,   5.3724069E-12,   4.5306172E-12,   3.8176441E-12
     +,   3.2142546E-12,   2.7040245E-12,   2.2728984E-12
     +,   1.9088919E-12,   1.6018352E-12,   1.3430193E-12
     +,   1.1250446E-12,   9.4162612E-13,   7.8742638E-13
     +,   6.5789561E-13,   5.4918038E-13,   4.5802121E-13
     +,   3.8165177E-13,   3.1772734E-13,   2.6426845E-13
     +,   2.1960427E-13,   1.8231994E-13,   1.5122707E-13
     +,   1.2531966E-13,   1.0375465E-13,   8.5819745E-14
     +,   7.0918870E-14,   5.8549736E-14,   4.8292774E-14
     +,   3.9794641E-14,   3.2761130E-14,   2.6945084E-14
     +,   2.2140298E-14,   1.8174999E-14,   1.4905535E-14
     +,   1.2212572E-14,   9.9964279E-15,   8.1746489E-15
     +,   6.6783796E-15,   5.4507570E-15,   4.4444780E-15
     +,   3.6204827E-15,   2.9463732E-15,   2.3954746E-15
     +,   1.9456779E-15,   1.5788150E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt114 = Yx/0.316166666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.3197381E-06,   6.5945092E-06
     +,   6.8759778E-06,   7.1640216E-06,   7.4585068E-06
     +,   7.7592858E-06,   8.0661912E-06,   8.3790483E-06
     +,   8.6976588E-06,   9.0218291E-06,   9.3513372E-06
     +,   9.6859521E-06,   1.0025439E-05,   1.0369550E-05
     +,   1.0718023E-05,   1.1070599E-05,   1.1427001E-05
     +,   1.1786959E-05,   1.2150195E-05,   1.2516425E-05
     +,   1.2885372E-05,   1.3256759E-05,   1.3630306E-05
     +,   1.4005761E-05,   1.4382838E-05,   1.4761312E-05
     +,   1.5140929E-05,   1.5521475E-05,   1.5902742E-05
     +,   1.6284539E-05,   1.6666705E-05,   1.7049102E-05
     +,   1.7431612E-05,   1.7814156E-05,   1.8196686E-05
     +,   1.8579183E-05,   1.8961673E-05,   1.9344212E-05
     +,   1.9726931E-05,   2.0109952E-05,   2.0493490E-05
     +,   2.0877800E-05,   2.1263182E-05,   2.1649981E-05
     +,   2.2038626E-05,   2.2429571E-05,   2.2823353E-05
     +,   2.3220553E-05,   2.3621809E-05,   2.4027826E-05
     +,   2.4439361E-05,   2.4857231E-05,   2.5282288E-05
     +,   2.5715466E-05,   2.6157702E-05,   2.6610034E-05
     +,   2.7073482E-05,   2.7549122E-05,   2.8038057E-05
     +,   2.8541403E-05,   2.9060280E-05,   2.9595813E-05
     +,   3.0149095E-05,   3.0721229E-05,   3.1313284E-05
     +,   3.1926236E-05,   3.2561067E-05,   3.3218614E-05
     +,   3.3899712E-05,   3.4604989E-05,   3.5335092E-05
     +,   3.6090405E-05,   3.6871290E-05,   3.7677830E-05
     +,   3.8510050E-05,   3.9367787E-05,   4.0250634E-05
     +,   4.1157986E-05,   4.2089090E-05,   4.3043005E-05
     +,   4.4018492E-05,   4.5014174E-05,   4.6028432E-05
     +,   4.7059501E-05,   4.8105339E-05,   4.9163817E-05
     +,   5.0232549E-05,   5.1309125E-05,   5.2390860E-05
     +,   5.3475094E-05,   5.4559099E-05,   5.5640023E-05
     +,   5.6715038E-05,   5.7781413E-05,   5.8836478E-05
     +,   5.9877621E-05,   6.0902508E-05,   6.1908933E-05
     +,   6.2895037E-05,   6.3859203E-05,   6.4800297E-05
     +,   6.5717526E-05,   6.6610708E-05,   6.7480076E-05
     +,   6.8326619E-05,   6.9151967E-05,   6.9958507E-05
     +,   7.0749440E-05,   7.1528986E-05,   7.2302362E-05
     +,   7.3075913E-05,   7.3857322E-05,   7.4655662E-05
     +,   7.5481745E-05,   7.6348108E-05,   7.7269586E-05
     +,   7.8263227E-05,   7.9349025E-05,   8.0549966E-05
     +,   8.1892686E-05,   8.3407846E-05,   8.5130552E-05
     +,   8.7100765E-05,   8.9364104E-05,   9.1972142E-05
     +,   9.4982584E-05,   9.8460157E-05,   1.0247618E-04
     +,   1.0710959E-04,   1.1244602E-04,   1.1857876E-04
     +,   1.2560705E-04,   1.3363732E-04,   1.4278032E-04
     +,   1.5315192E-04,   1.6487094E-04,   1.7805635E-04
     +,   1.9282507E-04,   2.0928988E-04,   2.2755474E-04
     +,   2.4770849E-04,   2.6981966E-04,   2.9393251E-04
     +,   3.2005849E-04,   3.4816822E-04,   3.7819127E-04
     +,   4.1001244E-04,   4.4347238E-04,   4.7837864E-04
     +,   5.1452586E-04,   5.5172184E-04,   5.8982446E-04
     +,   6.2879367E-04,   6.6875544E-04,   7.1005867E-04
     +,   7.5333426E-04,   7.9953705E-04,   8.4996095E-04
     +,   9.0620609E-04,   9.7008469E-04,   1.0434849E-03
     +,   1.1281671E-03,   1.2255262E-03,   1.3363527E-03
     +,   1.4606463E-03,   1.5974919E-03,   1.7450391E-03
     +,   1.9006392E-03,   2.0611130E-03,   2.2231021E-03
     +,   2.3834952E-03,   2.5399104E-03,   2.6911737E-03
     +,   2.8377154E-03,   2.9818483E-03,   3.1278122E-03
     +,   3.2813880E-03,   3.4490912E-03,   3.6370480E-03
     +,   3.8499341E-03,   4.0904204E-03,   4.3593817E-03
     +,   4.6567768E-03,   4.9824305E-03,   5.3361226E-03
     +,   5.7172100E-03,   6.1248895E-03,   6.5595880E-03
     +,   7.0245457E-03,   7.5249313E-03,   8.0634076E-03
     +,   8.6340168E-03,   9.2200488E-03,   9.8021319E-03
     +,   1.0380469E-02,   1.1006059E-02,   1.1794046E-02
     +,   1.2876046E-02,   1.4287436E-02,   1.5876954E-02
     +,   1.7358974E-02,   1.8508548E-02,   1.9351983E-02
     +,   2.0216806E-02,   2.1586368E-02,   2.3751285E-02
     +,   2.6486911E-02,   2.9193150E-02,   3.1498980E-02
     +,   3.3704791E-02,   3.6289528E-02,   3.8914803E-02
     +,   4.1227426E-02,   4.4263527E-02,   4.8711509E-02
     +,   5.3759564E-02,   5.8596600E-02,   6.3256331E-02
     +,   6.8874568E-02,   7.4725352E-02,   7.6276705E-02
     +,   6.8706870E-02,   5.0669041E-02,   2.8453104E-02
     +,   1.1527104E-02,   3.2442654E-03,   6.1859871E-04
     +,   7.8704499E-05,   6.6615085E-06,   4.1705655E-07
     +,   6.0551869E-08,   4.2458041E-08,   3.7422019E-08
     +,   3.3194890E-08,   2.9430328E-08,   2.6076126E-08
     +,   2.3089379E-08,   2.0431644E-08,   1.8068295E-08
     +,   1.5968034E-08,   1.4102728E-08,   1.2447225E-08
     +,   1.0978964E-08,   9.6775645E-09,   8.5247889E-09
     +,   7.5043785E-09,   6.6017645E-09,   5.8038516E-09
     +,   5.0989413E-09,   4.4766573E-09,   3.9276635E-09
     +,   3.4436372E-09,   3.0171987E-09,   2.6417637E-09
     +,   2.3114453E-09,   2.0210176E-09,   1.7658444E-09
     +,   1.5418109E-09,   1.3452482E-09,   1.1729038E-09
     +,   1.0219061E-09,   8.8971036E-10,   7.7405354E-10
     +,   6.7293532E-10,   5.8459998E-10,   5.0748472E-10
     +,   4.4021142E-10,   3.8157055E-10,   3.3049299E-10
     +,   2.8603533E-10,   2.4736804E-10,   2.1376358E-10
     +,   1.8458218E-10,   1.5926048E-10,   1.3730413E-10
     +,   1.1828220E-10,   1.0181437E-10,   8.7569792E-11
     +,   7.5257411E-11,   6.4624306E-11,   5.5448340E-11
     +,   4.7536731E-11,   4.0720368E-11,   3.4852850E-11
     +,   2.9805963E-11,   2.5468804E-11,   2.1744540E-11
     +,   1.8549185E-11,   1.5810119E-11,   1.3464010E-11
     +,   1.1456322E-11,   9.7396258E-12,   8.2731053E-12
     +,   7.0212915E-12,   5.9537700E-12,   5.0441274E-12
     +,   4.2697616E-12,   3.6110919E-12,   3.0513560E-12
     +,   2.5760973E-12,   2.1729476E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt115 = Yx/0.289978723404255
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.6164340E-06,   9.9326026E-06
     +,   1.0256702E-05,   1.0588954E-05,   1.0929585E-05
     +,   1.1278828E-05,   1.1636921E-05,   1.2004104E-05
     +,   1.2380608E-05,   1.2766685E-05,   1.3162563E-05
     +,   1.3568465E-05,   1.3984615E-05,   1.4411214E-05
     +,   1.4848458E-05,   1.5296522E-05,   1.5755559E-05
     +,   1.6225704E-05,   1.6707059E-05,   1.7199694E-05
     +,   1.7703656E-05,   1.8218940E-05,   1.8745508E-05
     +,   1.9283303E-05,   1.9832158E-05,   2.0391928E-05
     +,   2.0962381E-05,   2.1543228E-05,   2.2134138E-05
     +,   2.2734708E-05,   2.3344484E-05,   2.3962950E-05
     +,   2.4589533E-05,   2.5223599E-05,   2.5864447E-05
     +,   2.6511319E-05,   2.7163405E-05,   2.7819828E-05
     +,   2.8479692E-05,   2.9141982E-05,   2.9805720E-05
     +,   3.0469835E-05,   3.1133233E-05,   3.1794789E-05
     +,   3.2453354E-05,   3.3107757E-05,   3.3756809E-05
     +,   3.4399345E-05,   3.5034172E-05,   3.5660119E-05
     +,   3.6276047E-05,   3.6880811E-05,   3.7473328E-05
     +,   3.8052585E-05,   3.8617542E-05,   3.9167309E-05
     +,   3.9701015E-05,   4.0217870E-05,   4.0717205E-05
     +,   4.1198411E-05,   4.1660984E-05,   4.2104552E-05
     +,   4.2528849E-05,   4.2933738E-05,   4.3319236E-05
     +,   4.3685439E-05,   4.4032691E-05,   4.4361386E-05
     +,   4.4672175E-05,   4.4965804E-05,   4.5243243E-05
     +,   4.5505618E-05,   4.5754274E-05,   4.5990713E-05
     +,   4.6216694E-05,   4.6434154E-05,   4.6645255E-05
     +,   4.6852387E-05,   4.7058180E-05,   4.7265519E-05
     +,   4.7477497E-05,   4.7697507E-05,   4.7929167E-05
     +,   4.8176393E-05,   4.8443329E-05,   4.8734426E-05
     +,   4.9054375E-05,   4.9408172E-05,   4.9800987E-05
     +,   5.0238341E-05,   5.0725968E-05,   5.1269781E-05
     +,   5.1875893E-05,   5.2550673E-05,   5.3300584E-05
     +,   5.4132175E-05,   5.5052187E-05,   5.6067289E-05
     +,   5.7184279E-05,   5.8409845E-05,   5.9750750E-05
     +,   6.1213592E-05,   6.2805062E-05,   6.4531683E-05
     +,   6.6400127E-05,   6.8417277E-05,   7.0590097E-05
     +,   7.2926057E-05,   7.5433454E-05,   7.8121768E-05
     +,   8.1001657E-05,   8.4086205E-05,   8.7390734E-05
     +,   9.0934423E-05,   9.4740244E-05,   9.8836616E-05
     +,   1.0325763E-04,   1.0804494E-04,   1.1324752E-04
     +,   1.1892368E-04,   1.2514120E-04,   1.3197736E-04
     +,   1.3951921E-04,   1.4786360E-04,   1.5711581E-04
     +,   1.6738665E-04,   1.7879231E-04,   1.9144798E-04
     +,   2.0546706E-04,   2.2095270E-04,   2.3799609E-04
     +,   2.5666683E-04,   2.7701163E-04,   2.9904352E-04
     +,   3.2274253E-04,   3.4805021E-04,   3.7486668E-04
     +,   4.0305272E-04,   4.3243542E-04,   4.6281249E-04
     +,   4.9395999E-04,   5.2564515E-04,   5.5764284E-04
     +,   5.8974937E-04,   6.2179478E-04,   6.5366522E-04
     +,   6.8531354E-04,   7.1677036E-04,   7.4815389E-04
     +,   7.7967742E-04,   8.1164780E-04,   8.4446202E-04
     +,   8.7860064E-04,   9.1461750E-04,   9.5312181E-04
     +,   9.9475076E-04,   1.0401407E-03,   1.0898862E-03
     +,   1.1444875E-03,   1.2042825E-03,   1.2693929E-03
     +,   1.3396601E-03,   1.4146080E-03,   1.4934459E-03
     +,   1.5751532E-03,   1.6586228E-03,   1.7429026E-03
     +,   1.8275201E-03,   1.9128635E-03,   2.0005060E-03
     +,   2.0934427E-03,   2.1961131E-03,   2.3141536E-03
     +,   2.4538469E-03,   2.6213573E-03,   2.8219467E-03
     +,   3.0592845E-03,   3.3350547E-03,   3.6488560E-03
     +,   3.9982870E-03,   4.3789726E-03,   4.7843894E-03
     +,   5.2057393E-03,   5.6320862E-03,   6.0511963E-03
     +,   6.4515648E-03,   6.8260320E-03,   7.1765925E-03
     +,   7.5188573E-03,   7.8835376E-03,   8.3126472E-03
     +,   8.8510020E-03,   9.5387660E-03,   1.0409887E-02
     +,   1.1489171E-02,   1.2768970E-02,   1.4165020E-02
     +,   1.5501716E-02,   1.6595056E-02,   1.7419007E-02
     +,   1.8211102E-02,   1.9352920E-02,   2.1036221E-02
     +,   2.2983266E-02,   2.4560811E-02,   2.5300588E-02
     +,   2.5335586E-02,   2.5252232E-02,   2.5549497E-02
     +,   2.6455384E-02,   2.8262120E-02,   3.1351313E-02
     +,   3.5697799E-02,   4.0813491E-02,   4.6390664E-02
     +,   5.2471716E-02,   5.8659006E-02,   6.3845389E-02
     +,   6.6691875E-02,   6.5598443E-02,   5.9141610E-02
     +,   4.7349475E-02,   3.2458492E-02,   1.8329488E-02
     +,   8.2392180E-03,   2.8769248E-03,   7.6985994E-04
     +,   1.5692227E-04,   2.4275998E-05,   2.8452837E-06
     +,   2.6121518E-07,   2.8572321E-08,   1.1865913E-08
     +,   9.8181516E-09,   8.6263556E-09,   7.5913222E-09
     +,   6.6746062E-09,   5.8630052E-09,   5.1451887E-09
     +,   4.5109192E-09,   3.9510164E-09,   3.4572654E-09
     +,   3.0223026E-09,   2.6395000E-09,   2.3029270E-09
     +,   2.0073139E-09,   1.7479443E-09,   1.5205979E-09
     +,   1.3215176E-09,   1.1473779E-09,   9.9520459E-10
     +,   8.6235813E-10,   7.4650647E-10,   6.4558314E-10
     +,   5.5775118E-10,   4.8138821E-10,   4.1506776E-10
     +,   3.5753039E-10,   3.0766226E-10,   2.6448438E-10
     +,   2.2713960E-10,   1.9487405E-10,   1.6702480E-10
     +,   1.4301142E-10,   1.2232866E-10,   1.0453227E-10
     +,   8.9234786E-11,   7.6099696E-11,   6.4833174E-11
     +,   5.5179139E-11,   4.6915319E-11,   3.9848961E-11
     +,   3.3813102E-11,   2.8662605E-11,   2.4272103E-11
     +,   2.0533538E-11,   1.7353251E-11,   1.4650850E-11
     +,   1.2356775E-11,   1.0411496E-11,   8.7635741E-12
     +,   7.3691131E-12,   6.1902688E-12,   5.1948090E-12
     +,   4.3550224E-12,   3.6473533E-12,   3.0516117E-12
     +,   2.5506012E-12,   2.1297209E-12,   1.7765009E-12
     +,   1.4803912E-12,   1.2323959E-12,   1.0249279E-12
     +,   8.5153277E-13,   7.0677063E-13,   5.8603258E-13
     +,   4.8544030E-13,   4.0171436E-13,   3.3210175E-13
     +,   2.7427932E-13,   2.2630311E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt116 = Yx/0.26868085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0441948E-06,   2.1558767E-06
     +,   2.2719657E-06,   2.3925279E-06,   2.5176246E-06
     +,   2.6473108E-06,   2.7816386E-06,   2.9206512E-06
     +,   3.0643866E-06,   3.2128819E-06,   3.3661649E-06
     +,   3.5242572E-06,   3.6871775E-06,   3.8549392E-06
     +,   4.0275518E-06,   4.2050201E-06,   4.3873479E-06
     +,   4.5745369E-06,   4.7665872E-06,   4.9634991E-06
     +,   5.1652746E-06,   5.3719209E-06,   5.5834430E-06
     +,   5.7998686E-06,   6.0212105E-06,   6.2475156E-06
     +,   6.4788305E-06,   6.7152218E-06,   6.9567745E-06
     +,   7.2035955E-06,   7.4558156E-06,   7.7135946E-06
     +,   7.9771244E-06,   8.2466304E-06,   8.5223764E-06
     +,   8.8046691E-06,   9.0938556E-06,   9.3903363E-06
     +,   9.6945741E-06,   1.0007058E-05,   1.0328368E-05
     +,   1.0659124E-05,   1.1000016E-05,   1.1351799E-05
     +,   1.1715293E-05,   1.2091386E-05,   1.2481029E-05
     +,   1.2885251E-05,   1.3305134E-05,   1.3741829E-05
     +,   1.4196545E-05,   1.4670547E-05,   1.5165144E-05
     +,   1.5681717E-05,   1.6221629E-05,   1.6786333E-05
     +,   1.7377262E-05,   1.7995866E-05,   1.8643601E-05
     +,   1.9321897E-05,   2.0032168E-05,   2.0775804E-05
     +,   2.1554084E-05,   2.2368302E-05,   2.3219678E-05
     +,   2.4109268E-05,   2.5038162E-05,   2.6007237E-05
     +,   2.7017400E-05,   2.8069351E-05,   2.9163832E-05
     +,   3.0301395E-05,   3.1482668E-05,   3.2708125E-05
     +,   3.3978344E-05,   3.5293975E-05,   3.6655660E-05
     +,   3.8064198E-05,   3.9520666E-05,   4.1026433E-05
     +,   4.2583048E-05,   4.4192682E-05,   4.5857789E-05
     +,   4.7581583E-05,   4.9367682E-05,   5.1220642E-05
     +,   5.3145526E-05,   5.5148390E-05,   5.7235833E-05
     +,   5.9415455E-05,   6.1695609E-05,   6.4085172E-05
     +,   6.6593704E-05,   6.9231297E-05,   7.2008464E-05
     +,   7.4935560E-05,   7.8023280E-05,   8.1281571E-05
     +,   8.4720297E-05,   8.8348090E-05,   9.2172995E-05
     +,   9.6201307E-05,   1.0043846E-04,   1.0488769E-04
     +,   1.0955115E-04,   1.1442931E-04,   1.1952097E-04
     +,   1.2482364E-04,   1.3033430E-04,   1.3604957E-04
     +,   1.4196573E-04,   1.4808074E-04,   1.5439333E-04
     +,   1.6090543E-04,   1.6762153E-04,   1.7455070E-04
     +,   1.8170576E-04,   1.8910578E-04,   1.9677410E-04
     +,   2.0474032E-04,   2.1303954E-04,   2.2171129E-04
     +,   2.3079946E-04,   2.4035241E-04,   2.5042132E-04
     +,   2.6105868E-04,   2.7231991E-04,   2.8426023E-04
     +,   2.9693768E-04,   3.1041063E-04,   3.2474118E-04
     +,   3.3999354E-04,   3.5623749E-04,   3.7354638E-04
     +,   3.9199938E-04,   4.1167918E-04,   4.3266686E-04
     +,   4.5503839E-04,   4.7885787E-04,   5.0416676E-04
     +,   5.3097052E-04,   5.5922795E-04,   5.8884145E-04
     +,   6.1964698E-04,   6.5140467E-04,   6.8380951E-04
     +,   7.1649544E-04,   7.4905471E-04,   7.8106817E-04
     +,   8.1214454E-04,   8.4196101E-04,   8.7030779E-04
     +,   8.9713320E-04,   9.2258450E-04,   9.4703294E-04
     +,   9.7108784E-04,   9.9559803E-04,   1.0216422E-03
     +,   1.0505037E-03,   1.0836322E-03,   1.1226062E-03
     +,   1.1690771E-03,   1.2246969E-03,   1.2910248E-03
     +,   1.3694275E-03,   1.4609491E-03,   1.5661949E-03
     +,   1.6852784E-03,   1.8178876E-03,   1.9635155E-03
     +,   2.1219177E-03,   2.2937795E-03,   2.4814657E-03
     +,   2.6895467E-03,   2.9246723E-03,   3.1945521E-03
     +,   3.5056684E-03,   3.8601400E-03,   4.2526918E-03
     +,   4.6692723E-03,   5.0887177E-03,   5.4881568E-03
     +,   5.8509507E-03,   6.1738295E-03,   6.4692595E-03
     +,   6.7608003E-03,   7.0730275E-03,   7.4206647E-03
     +,   7.8019644E-03,   8.1995465E-03,   8.5898731E-03
     +,   8.9608468E-03,   9.3335379E-03,   9.7760288E-03
     +,   1.0392174E-02,   1.1277920E-02,   1.2461558E-02
     +,   1.3865644E-02,   1.5329425E-02,   1.6699774E-02
     +,   1.7932404E-02,   1.9095309E-02,   2.0246414E-02
     +,   2.1325840E-02,   2.2213742E-02,   2.2908363E-02
     +,   2.3634072E-02,   2.4781846E-02,   2.6726209E-02
     +,   2.9528648E-02,   3.2636061E-02,   3.5053067E-02
     +,   3.6235895E-02,   3.6694616E-02,   3.7180599E-02
     +,   3.7888575E-02,   3.9070584E-02,   4.0997665E-02
     +,   4.2708550E-02,   4.2050902E-02,   3.7477709E-02
     +,   2.9521314E-02,   2.0358829E-02,   1.2225178E-02
     +,   6.3409577E-03,   2.8086395E-03,   1.0485897E-03
     +,   3.2572582E-04,   8.3219711E-05,   1.7327666E-05
     +,   2.9214380E-06,   3.9773059E-07,   4.4318796E-08
     +,   4.7402859E-09,   1.1168008E-09,   7.6737688E-10
     +,   6.6400463E-10,   5.8423788E-10,   5.1417826E-10
     +,   4.5222975E-10,   3.9746928E-10,   3.4909475E-10
     +,   3.0639030E-10,   2.6871555E-10,   2.3550017E-10
     +,   2.0623753E-10,   1.8047709E-10,   1.5781487E-10
     +,   1.3789299E-10,   1.2039408E-10,   1.0503472E-10
     +,   9.1563375E-11,   7.9757437E-11,   6.9419560E-11
     +,   6.0373991E-11,   5.2465383E-11,   4.5556513E-11
     +,   3.9526122E-11,   3.4266569E-11,   2.9682944E-11
     +,   2.5691796E-11,   2.2219502E-11,   1.9200979E-11
     +,   1.6579059E-11,   1.4303668E-11,   1.2330539E-11
     +,   1.0620932E-11,   9.1409276E-12,   7.8607919E-12
     +,   6.7544386E-12,   5.7990357E-12,   4.9747194E-12
     +,   4.2641129E-12,   3.6520318E-12,   3.1252381E-12
     +,   2.6722632E-12,   2.2830615E-12,   1.9489612E-12
     +,   1.6623818E-12,   1.4167882E-12,   1.2064819E-12
     +,   1.0265599E-12,   8.7274805E-13,   7.4137783E-13
     +,   6.2926281E-13,   5.3366670E-13,   4.5222308E-13
     +,   3.8289291E-13,   3.2392643E-13,   2.7381507E-13
     +,   2.3126696E-13,   1.9516928E-13,   1.6457143E-13
     +,   1.3865641E-13,   1.1672674E-13,   9.8184007E-14
     +,   8.2519712E-14,   6.9296999E-14,   5.8145695E-14
     +,   4.8748416E-14,   4.0836549E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt118 = Yx/0.22795652173913
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8242885E-07,   4.2756352E-07
     +,   4.7739593E-07,   5.3232998E-07,   5.9279444E-07
     +,   6.5924178E-07,   7.3214943E-07,   8.1201892E-07
     +,   8.9937390E-07,   9.9476642E-07,   1.0987660E-06
     +,   1.2119655E-06,   1.3349778E-06,   1.4684341E-06
     +,   1.6129828E-06,   1.7692849E-06,   1.9380152E-06
     +,   2.1198559E-06,   2.3154957E-06,   2.5256250E-06
     +,   2.7509309E-06,   2.9920975E-06,   3.2497924E-06
     +,   3.5246842E-06,   3.8173921E-06,   4.1285416E-06
     +,   4.4587082E-06,   4.8084353E-06,   5.1782245E-06
     +,   5.5685305E-06,   5.9797508E-06,   6.4122282E-06
     +,   6.8662384E-06,   7.3419842E-06,   7.8395979E-06
     +,   8.3591276E-06,   8.9005389E-06,   9.4636962E-06
     +,   1.0048408E-05,   1.0654327E-05,   1.1281069E-05
     +,   1.1928114E-05,   1.2594853E-05,   1.3280572E-05
     +,   1.3984461E-05,   1.4705608E-05,   1.5443009E-05
     +,   1.6195569E-05,   1.6962094E-05,   1.7741320E-05
     +,   1.8531904E-05,   1.9332427E-05,   2.0141393E-05
     +,   2.0957314E-05,   2.1778558E-05,   2.2603550E-05
     +,   2.3430637E-05,   2.4258168E-05,   2.5084484E-05
     +,   2.5907930E-05,   2.6726879E-05,   2.7539734E-05
     +,   2.8344892E-05,   2.9140858E-05,   2.9926206E-05
     +,   3.0699503E-05,   3.1459484E-05,   3.2204876E-05
     +,   3.2934597E-05,   3.3647575E-05,   3.4342938E-05
     +,   3.5019821E-05,   3.5677582E-05,   3.6315596E-05
     +,   3.6933441E-05,   3.7530834E-05,   3.8107541E-05
     +,   3.8663507E-05,   3.9198840E-05,   3.9713803E-05
     +,   4.0208761E-05,   4.0684328E-05,   4.1141211E-05
     +,   4.1580421E-05,   4.2003136E-05,   4.2410826E-05
     +,   4.2805237E-05,   4.3188516E-05,   4.3563163E-05
     +,   4.3932185E-05,   4.4299148E-05,   4.4668272E-05
     +,   4.5044486E-05,   4.5433666E-05,   4.5842666E-05
     +,   4.6279496E-05,   4.6753510E-05,   4.7275527E-05
     +,   4.7858121E-05,   4.8515598E-05,   4.9264447E-05
     +,   5.0123257E-05,   5.1113089E-05,   5.2257416E-05
     +,   5.3582375E-05,   5.5116787E-05,   5.6892011E-05
     +,   5.8941867E-05,   6.1302664E-05,   6.4012689E-05
     +,   6.7111665E-05,   7.0640723E-05,   7.4640884E-05
     +,   7.9153280E-05,   8.4217041E-05,   8.9869485E-05
     +,   9.6143653E-05,   1.0306847E-04,   1.1066596E-04
     +,   1.1895144E-04,   1.2793191E-04,   1.3760425E-04
     +,   1.4795500E-04,   1.5896057E-04,   1.7058628E-04
     +,   1.8278563E-04,   1.9550347E-04,   2.0867400E-04
     +,   2.2222598E-04,   2.3608090E-04,   2.5015982E-04
     +,   2.6438254E-04,   2.7867427E-04,   2.9296591E-04
     +,   3.0720033E-04,   3.2133452E-04,   3.3534091E-04
     +,   3.4921063E-04,   3.6295544E-04,   3.7660662E-04
     +,   3.9021263E-04,   4.0383753E-04,   4.1755833E-04
     +,   4.3145946E-04,   4.4562671E-04,   4.6014675E-04
     +,   4.7510379E-04,   4.9058173E-04,   5.0667318E-04
     +,   5.2349619E-04,   5.4121995E-04,   5.6009850E-04
     +,   5.8051944E-04,   6.0305902E-04,   6.2853959E-04
     +,   6.5808109E-04,   6.9314195E-04,   7.3553325E-04
     +,   7.8738766E-04,   8.5106510E-04,   9.2900958E-04
     +,   1.0235198E-03,   1.1364471E-03,   1.2688652E-03
     +,   1.4207339E-03,   1.5905948E-03,   1.7753619E-03
     +,   1.9703018E-03,   2.1692512E-03,   2.3650555E-03
     +,   2.5502976E-03,   2.7182903E-03,   2.8642362E-03
     +,   2.9863988E-03,   3.0870775E-03,   3.1731087E-03
     +,   3.2554604E-03,   3.3477049E-03,   3.4633838E-03
     +,   3.6127956E-03,   3.8003954E-03,   4.0241634E-03
     +,   4.2778929E-03,   4.5558270E-03,   4.8575490E-03
     +,   5.1904605E-03,   5.5682696E-03,   6.0056504E-03
     +,   6.5107816E-03,   7.0778183E-03,   7.6820748E-03
     +,   8.2813352E-03,   8.8272505E-03,   9.2868516E-03
     +,   9.6667130E-03,   1.0028441E-02,   1.0487243E-02
     +,   1.1187135E-02,   1.2242838E-02,   1.3648575E-02
     +,   1.5209531E-02,   1.6606977E-02,   1.7623112E-02
     +,   1.8348090E-02,   1.9144911E-02,   2.0345910E-02
     +,   2.1903282E-02,   2.3367638E-02,   2.4348861E-02
     +,   2.4951385E-02,   2.5550889E-02,   2.6309894E-02
     +,   2.7292622E-02,   2.8751029E-02,   3.0672923E-02
     +,   3.2414231E-02,   3.3519257E-02,   3.4210976E-02
     +,   3.4272447E-02,   3.2566734E-02,   2.8362665E-02
     +,   2.2235969E-02,   1.5530654E-02,   9.5462548E-03
     +,   5.0922250E-03,   2.3291791E-03,   9.0594910E-04
     +,   2.9802867E-04,   8.2594939E-05,   1.9220279E-05
     +,   3.7464292E-06,   6.1281980E-07,   8.6902752E-08
     +,   1.3528828E-08,   4.6733515E-09,   3.4096630E-09
     +,   2.9245628E-09,   2.5478819E-09,   2.2208035E-09
     +,   1.9344371E-09,   1.6837460E-09,   1.4644445E-09
     +,   1.2727452E-09,   1.1052907E-09,   9.5911745E-10
     +,   8.3162072E-10,   7.2050327E-10,   6.2372951E-10
     +,   5.3951321E-10,   4.6628662E-10,   4.0266479E-10
     +,   3.4743045E-10,   2.9951919E-10,   2.5799576E-10
     +,   2.2203746E-10,   1.9092403E-10,   1.6402672E-10
     +,   1.4079521E-10,   1.2074650E-10,   1.0345953E-10
     +,   8.8567577E-11,   7.5750864E-11,   6.4729812E-11
     +,   5.5261157E-11,   4.7134355E-11,   4.0165465E-11
     +,   3.4194852E-11,   2.9084537E-11,   2.4714869E-11
     +,   2.0981871E-11,   1.7795754E-11,   1.5079117E-11
     +,   1.2765075E-11,   1.0795823E-11,   9.1215568E-12
     +,   7.6995780E-12,   6.4929698E-12,   5.4701894E-12
     +,   4.6040290E-12,   3.8712831E-12,   3.2519694E-12
     +,   2.7290882E-12,   2.2880317E-12,   1.9163911E-12
     +,   1.6035371E-12,   1.3404493E-12,   1.1194261E-12
     +,   9.3392286E-13,   7.7839905E-13,   6.4813064E-13
     +,   5.3913514E-13,   4.4802457E-13,   3.7194602E-13
     +,   3.0847910E-13,   2.5559066E-13,   2.1155929E-13
     +,   1.7494085E-13,   1.4451671E-13,   1.1926629E-13
     +,   9.8329500E-14,   8.0988215E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt120 = Yx/0.189318181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1214586E-05,   3.2201366E-05
     +,   3.3210268E-05,   3.4240336E-05,   3.5290475E-05
     +,   3.6359437E-05,   3.7445872E-05,   3.8548256E-05
     +,   3.9664978E-05,   4.0794352E-05,   4.1934552E-05
     +,   4.3083706E-05,   4.4239892E-05,   4.5401157E-05
     +,   4.6565550E-05,   4.7731148E-05,   4.8896112E-05
     +,   5.0058654E-05,   5.1217205E-05,   5.2370313E-05
     +,   5.3516807E-05,   5.4655749E-05,   5.5786531E-05
     +,   5.6909012E-05,   5.8023303E-05,   5.9130165E-05
     +,   6.0230803E-05,   6.1327024E-05,   6.2421277E-05
     +,   6.3516622E-05,   6.4616914E-05,   6.5726657E-05
     +,   6.6851193E-05,   6.7996596E-05,   6.9169764E-05
     +,   7.0378323E-05,   7.1630770E-05,   7.2936193E-05
     +,   7.4304538E-05,   7.5746204E-05,   7.7272300E-05
     +,   7.8894329E-05,   8.0624181E-05,   8.2473969E-05
     +,   8.4455889E-05,   8.6582171E-05,   8.8864770E-05
     +,   9.1315283E-05,   9.3944713E-05,   9.6763455E-05
     +,   9.9780846E-05,   1.0300519E-04,   1.0644345E-04
     +,   1.1010138E-04,   1.1398274E-04,   1.1808998E-04
     +,   1.2242346E-04,   1.2698174E-04,   1.3176145E-04
     +,   1.3675712E-04,   1.4196162E-04,   1.4736579E-04
     +,   1.5295856E-04,   1.5872794E-04,   1.6466052E-04
     +,   1.7074183E-04,   1.7695755E-04,   1.8329312E-04
     +,   1.8973577E-04,   1.9627409E-04,   2.0290077E-04
     +,   2.0961225E-04,   2.1641268E-04,   2.2331363E-04
     +,   2.3033876E-04,   2.3752559E-04,   2.4492838E-04
     +,   2.5262230E-04,   2.6070763E-04,   2.6931331E-04
     +,   2.7859997E-04,   2.8876541E-04,   3.0004542E-04
     +,   3.1271845E-04,   3.2710304E-04,   3.4356065E-04
     +,   3.6248859E-04,   3.8431864E-04,   4.0950422E-04
     +,   4.3851312E-04,   4.7181311E-04,   5.0985231E-04
     +,   5.5304240E-04,   6.0174207E-04,   6.5623561E-04
     +,   7.1670808E-04,   7.8324100E-04,   8.5578574E-04
     +,   9.3416945E-04,   1.0180770E-03,   1.1070726E-03
     +,   1.2005916E-03,   1.2979885E-03,   1.3985526E-03
     +,   1.5016021E-03,   1.6065754E-03,   1.7131816E-03
     +,   1.8216104E-03,   1.9327892E-03,   2.0486328E-03
     +,   2.1722589E-03,   2.3081014E-03,   2.4617887E-03
     +,   2.6398499E-03,   2.8491986E-03,   3.0966983E-03
     +,   3.3889397E-03,   3.7325518E-03,   4.1347733E-03
     +,   4.6040514E-03,   5.1498259E-03,   5.7810582E-03
     +,   6.5041068E-03,   7.3208152E-03,   8.2283970E-03
     +,   9.2228157E-03,   1.0307218E-02,   1.1502313E-02
     +,   1.2849983E-02,   1.4392824E-02,   1.6127182E-02
     +,   1.7959930E-02,   1.9725999E-02,   2.1275857E-02
     +,   2.2559924E-02,   2.3634894E-02,   2.4637233E-02
     +,   2.5801769E-02,   2.7446145E-02,   2.9797230E-02
     +,   3.2783728E-02,   3.6015291E-02,   3.8980577E-02
     +,   4.1466076E-02,   4.3998927E-02,   4.7424570E-02
     +,   5.1565293E-02,   5.5217806E-02,   5.7836775E-02
     +,   5.9641674E-02,   6.0203597E-02,   5.8695592E-02
     +,   5.5494394E-02,   5.2479841E-02,   5.1007602E-02
     +,   5.0230004E-02,   4.8316337E-02,   4.4508111E-02
     +,   3.9578296E-02,   3.4902751E-02,   3.1346869E-02
     +,   2.8932411E-02,   2.7208447E-02,   2.5655441E-02
     +,   2.3886018E-02,   2.1760520E-02,   1.9399270E-02
     +,   1.7046005E-02,   1.4902654E-02,   1.3069598E-02
     +,   1.1573488E-02,   1.0402733E-02,   9.5200213E-03
     +,   8.8678049E-03,   8.3799995E-03,   7.9964884E-03
     +,   7.6720705E-03,   7.3767439E-03,   7.0912070E-03
     +,   6.8023987E-03,   6.5015852E-03,   6.1844918E-03
     +,   5.8518918E-03,   5.5092750E-03,   5.1654768E-03
     +,   4.8305127E-03,   4.5134998E-03,   4.2210622E-03
     +,   3.9566592E-03,   3.7206605E-03,   3.5108770E-03
     +,   3.3234775E-03,   3.1539081E-03,   2.9976773E-03
     +,   2.8509086E-03,   2.7106768E-03,   2.5751251E-03
     +,   2.4433797E-03,   2.3153648E-03,   2.1915494E-03
     +,   2.0726915E-03,   1.9595744E-03,   1.8527942E-03
     +,   1.7526413E-03,   1.6590459E-03,   1.5715762E-03
     +,   1.4895131E-03,   1.4119599E-03,   1.3379492E-03
     +,   1.2665470E-03,   1.1969435E-03,   1.1285146E-03
     +,   1.0608473E-03,   9.9373492E-04,   9.2716108E-04
     +,   8.6127268E-04,   7.9633546E-04,   7.3268928E-04
     +,   6.7071279E-04,   6.1079883E-04,   5.5331405E-04
     +,   4.9858703E-04,   4.4689706E-04,   3.9846165E-04
     +,   3.5342970E-04,   3.1188488E-04,   2.7385048E-04
     +,   2.3929132E-04,   2.0811810E-04,   1.8019753E-04
     +,   1.5536282E-04,   1.3341916E-04,   1.1415139E-04
     +,   9.7333563E-05,   8.2737250E-05,   7.0134403E-05
     +,   5.9304442E-05,   5.0038590E-05,   4.2141841E-05
     +,   3.5434558E-05,   2.9754094E-05,   2.4955318E-05
     +,   2.0909771E-05,   1.7504677E-05,   1.4642210E-05
     +,   1.2238325E-05,   1.0221064E-05,   8.5290867E-06
     +,   7.1104928E-06,   5.9216200E-06,   4.9256064E-06
     +,   4.0915088E-06,   3.3934271E-06,   2.8096165E-06
     +,   2.3218042E-06,   1.9146537E-06,   1.5753049E-06
     +,   1.2929304E-06,   1.0583922E-06,   8.6398796E-07
     +,   7.0323028E-07,   5.7063767E-07,   4.6157186E-07
     +,   3.7211939E-07,   2.9898598E-07,   2.3938782E-07
     +,   1.9098385E-07,   1.5181189E-07,   1.2022761E-07
     +,   9.4855757E-08,   7.4551870E-08,   5.8367636E-08
     +,   4.5518810E-08,   3.5358688E-08,   2.7357158E-08
     +,   2.1081959E-08,   1.6180762E-08,   1.2368967E-08
     +,   9.4167110E-09,   7.1400010E-09,   5.3915858E-09
     +,   4.0547015E-09,   3.0367833E-09,   2.2651001E-09
     +,   1.6825608E-09,   1.2447228E-09,   9.1704838E-10
     +,   6.7286665E-10,   4.9169752E-10,   3.5784986E-10
     +,   2.5939356E-10,   1.8727654E-10,   1.3468085E-10
     +,   9.6482627E-11,   6.8859481E-11,   4.8966078E-11
     +,   3.4699424E-11,   2.4508957E-11,   1.7259544E-11
     +,   1.2121993E-11,   8.4949148E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt75 = Yx/0.411714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.7678678E-06,   8.3007981E-06
     +,   8.8594807E-06,   9.4443185E-06,   1.0055676E-05
     +,   1.0693869E-05,   1.1359170E-05,   1.2051809E-05
     +,   1.2771971E-05,   1.3519839E-05,   1.4295533E-05
     +,   1.5099169E-05,   1.5930842E-05,   1.6790646E-05
     +,   1.7678683E-05,   1.8595079E-05,   1.9539981E-05
     +,   2.0513584E-05,   2.1516151E-05,   2.2548009E-05
     +,   2.3609578E-05,   2.4701380E-05,   2.5824051E-05
     +,   2.6978421E-05,   2.8165343E-05,   2.9385985E-05
     +,   3.0641575E-05,   3.1933574E-05,   3.3263626E-05
     +,   3.4633558E-05,   3.6045414E-05,   3.7501432E-05
     +,   3.9004026E-05,   4.0555813E-05,   4.2159594E-05
     +,   4.3818294E-05,   4.5535042E-05,   4.7313009E-05
     +,   4.9155620E-05,   5.1066170E-05,   5.3048221E-05
     +,   5.5105254E-05,   5.7240792E-05,   5.9458351E-05
     +,   6.1761450E-05,   6.4153537E-05,   6.6638029E-05
     +,   6.9218309E-05,   7.1897724E-05,   7.4679592E-05
     +,   7.7567245E-05,   8.0564016E-05,   8.3673294E-05
     +,   8.6898785E-05,   9.0243942E-05,   9.3712857E-05
     +,   9.7309668E-05,   1.0103892E-04,   1.0490546E-04
     +,   1.0891461E-04,   1.1307209E-04,   1.1738416E-04
     +,   1.2185715E-04,   1.2649818E-04,   1.3131466E-04
     +,   1.3631371E-04,   1.4150316E-04,   1.4688996E-04
     +,   1.5248165E-04,   1.5828421E-04,   1.6430370E-04
     +,   1.7054440E-04,   1.7701005E-04,   1.8370189E-04
     +,   1.9062043E-04,   1.9776412E-04,   2.0512955E-04
     +,   2.1271159E-04,   2.2050475E-04,   2.2850305E-04
     +,   2.3670051E-04,   2.4509436E-04,   2.5368467E-04
     +,   2.6247898E-04,   2.7149293E-04,   2.8075610E-04
     +,   2.9031280E-04,   3.0022979E-04,   3.1059704E-04
     +,   3.2153426E-04,   3.3319436E-04,   3.4576425E-04
     +,   3.5946700E-04,   3.7456158E-04,   3.9133808E-04
     +,   4.1010857E-04,   4.3120113E-04,   4.5493894E-04
     +,   4.8162957E-04,   5.1153696E-04,   5.4486789E-04
     +,   5.8174052E-04,   6.2217610E-04,   6.6607381E-04
     +,   7.1321259E-04,   7.6325028E-04,   8.1573438E-04
     +,   8.7013043E-04,   9.2586479E-04,   9.8237081E-04
     +,   1.0391363E-03,   1.0957798E-03,   1.1520885E-03
     +,   1.2080841E-03,   1.2640374E-03,   1.3205031E-03
     +,   1.3782997E-03,   1.4385142E-03,   1.5024751E-03
     +,   1.5717695E-03,   1.6482755E-03,   1.7342446E-03
     +,   1.8324258E-03,   1.9462204E-03,   2.0797960E-03
     +,   2.2381600E-03,   2.4272513E-03,   2.6540824E-03
     +,   2.9272928E-03,   3.2580921E-03,   3.6616630E-03
     +,   4.1579804E-03,   4.7710212E-03,   5.5248137E-03
     +,   6.4369082E-03,   7.5115273E-03,   8.7369857E-03
     +,   1.0091810E-02,   1.1556589E-02,   1.3119031E-02
     +,   1.4764515E-02,   1.6475283E-02,   1.8277220E-02
     +,   2.0305574E-02,   2.2770310E-02,   2.5789497E-02
     +,   2.9312121E-02,   3.3322033E-02,   3.7996743E-02
     +,   4.3310419E-02,   4.8557218E-02,   5.3093020E-02
     +,   5.7437539E-02,   6.2582768E-02,   6.9119446E-02
     +,   7.6253518E-02,   8.0581941E-02,   7.9585522E-02
     +,   7.5369731E-02,   7.1938530E-02,   7.0799924E-02
     +,   6.9366187E-02,   6.4473294E-02,   5.7845172E-02
     +,   5.2179497E-02,   4.6691064E-02,   4.0764157E-02
     +,   3.5352778E-02,   3.1014429E-02,   2.7666802E-02
     +,   2.5196182E-02,   2.3431811E-02,   2.2071950E-02
     +,   2.0852031E-02,   1.9647684E-02,   1.8420929E-02
     +,   1.7146349E-02,   1.5802635E-02,   1.4403644E-02
     +,   1.3011722E-02,   1.1710645E-02,   1.0561432E-02
     +,   9.5788082E-03,   8.7403636E-03,   8.0118766E-03
     +,   7.3667993E-03,   6.7915260E-03,   6.2810336E-03
     +,   5.8326959E-03,   5.4425071E-03,   5.1040836E-03
     +,   4.8093386E-03,   4.5496579E-03,   4.3168287E-03
     +,   4.1036564E-03,   3.9044186E-03,   3.7149061E-03
     +,   3.5322243E-03,   3.3543452E-03,   3.1796801E-03
     +,   3.0067847E-03,   2.8342709E-03,   2.6609385E-03
     +,   2.4860715E-03,   2.3097177E-03,   2.1327944E-03
     +,   1.9570652E-03,   1.7849321E-03,   1.6190798E-03
     +,   1.4620941E-03,   1.3161435E-03,   1.1827582E-03
     +,   1.0627209E-03,   9.5607177E-04,   8.6222577E-04
     +,   7.8013982E-04,   7.0847961E-04,   6.4578332E-04
     +,   5.9060351E-04,   5.4161134E-04,   4.9764459E-04
     +,   4.5774120E-04,   4.2114232E-04,   3.8727239E-04
     +,   3.5571103E-04,   3.2616404E-04,   2.9843469E-04
     +,   2.7239369E-04,   2.4795518E-04,   2.2506078E-04
     +,   2.0366770E-04,   1.8373839E-04,   1.6523406E-04
     +,   1.4811307E-04,   1.3233106E-04,   1.1783764E-04
     +,   1.0457820E-04,   9.2495648E-05,   8.1529863E-05
     +,   7.1617920E-05,   6.2695588E-05,   5.4698459E-05
     +,   4.7561723E-05,   4.1220403E-05,   3.5610417E-05
     +,   3.0669431E-05,   2.6336784E-05,   2.2553812E-05
     +,   1.9264560E-05,   1.6416427E-05,   1.3959789E-05
     +,   1.1848583E-05,   1.0040559E-05,   8.4971198E-06
     +,   7.1832628E-06,   6.0676184E-06,   5.1223556E-06
     +,   4.3228993E-06,   3.6476733E-06,   3.0779267E-06
     +,   2.5975028E-06,   2.1925218E-06,   1.8511104E-06
     +,   1.5631916E-06,   1.3202705E-06,   1.1151670E-06
     +,   9.4185259E-07,   7.9528837E-07,   6.7125501E-07
     +,   5.6621650E-07,   4.7721733E-07,   4.0178884E-07
     +,   3.3786066E-07,   2.8368885E-07,   2.3780602E-07
     +,   1.9897674E-07,   1.6614918E-07,   1.3843484E-07
     +,   1.1507323E-07,   9.5418251E-08,   7.8914816E-08
     +,   6.5090035E-08,   5.3536830E-08,   4.3907811E-08
     +,   3.5904154E-08,   2.9271114E-08,   2.3790227E-08
     +,   1.9275214E-08,   1.5567867E-08,   1.2533360E-08
     +,   1.0057900E-08,   8.0451059E-09,   6.4141235E-09
     +,   5.0969500E-09,   4.0369250E-09,   3.1867378E-09
     +,   2.5072617E-09,   1.9660722E-09,   1.5365635E-09
     +,   1.1968572E-09,   9.2913904E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt80 = Yx/0.44604
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3014457E-05,   1.3578710E-05
     +,   1.4148852E-05,   1.4723708E-05,   1.5302059E-05
     +,   1.5882661E-05,   1.6464221E-05,   1.7045442E-05
     +,   1.7625011E-05,   1.8201636E-05,   1.8774012E-05
     +,   1.9340869E-05,   1.9900972E-05,   2.0453132E-05
     +,   2.0996220E-05,   2.1529189E-05,   2.2051079E-05
     +,   2.2561020E-05,   2.3058266E-05,   2.3542201E-05
     +,   2.4012345E-05,   2.4468389E-05,   2.4910156E-05
     +,   2.5337700E-05,   2.5751220E-05,   2.6151165E-05
     +,   2.6538164E-05,   2.6913098E-05,   2.7277067E-05
     +,   2.7631435E-05,   2.7977798E-05,   2.8318036E-05
     +,   2.8654265E-05,   2.8988898E-05,   2.9324605E-05
     +,   2.9664321E-05,   3.0011275E-05,   3.0368938E-05
     +,   3.0741074E-05,   3.1131669E-05,   3.1544991E-05
     +,   3.1985539E-05,   3.2458011E-05,   3.2967328E-05
     +,   3.3518605E-05,   3.4117122E-05,   3.4768294E-05
     +,   3.5477657E-05,   3.6250862E-05,   3.7093574E-05
     +,   3.8011542E-05,   3.9010469E-05,   4.0096027E-05
     +,   4.1273888E-05,   4.2549495E-05,   4.3928289E-05
     +,   4.5415443E-05,   4.7016012E-05,   4.8734768E-05
     +,   5.0576287E-05,   5.2544856E-05,   5.4644544E-05
     +,   5.6879002E-05,   5.9251768E-05,   6.1766143E-05
     +,   6.4424923E-05,   6.7231049E-05,   7.0186914E-05
     +,   7.3295087E-05,   7.6557815E-05,   7.9977668E-05
     +,   8.3556901E-05,   8.7298453E-05,   9.1205133E-05
     +,   9.5280637E-05,   9.9529258E-05,   1.0395597E-04
     +,   1.0856683E-04,   1.1336949E-04,   1.1837326E-04
     +,   1.2358895E-04,   1.2903023E-04,   1.3471278E-04
     +,   1.4065586E-04,   1.4688133E-04,   1.5341541E-04
     +,   1.6028738E-04,   1.6753131E-04,   1.7518460E-04
     +,   1.8328919E-04,   1.9189104E-04,   2.0103877E-04
     +,   2.1078366E-04,   2.2117948E-04,   2.3228065E-04
     +,   2.4413998E-04,   2.5680941E-04,   2.7033561E-04
     +,   2.8476163E-04,   3.0012146E-04,   3.1644281E-04
     +,   3.3374166E-04,   3.5202620E-04,   3.7129232E-04
     +,   3.9152842E-04,   4.1271481E-04,   4.3482546E-04
     +,   4.5783148E-04,   4.8170699E-04,   5.0643302E-04
     +,   5.3199893E-04,   5.5841747E-04,   5.8572198E-04
     +,   6.1398587E-04,   6.4332294E-04,   6.7391107E-04
     +,   7.0599612E-04,   7.3991815E-04,   7.7611912E-04
     +,   8.1516505E-04,   8.5775286E-04,   9.0471131E-04
     +,   9.5699809E-04,   1.0156896E-03,   1.0819574E-03
     +,   1.1570372E-03,   1.2422223E-03,   1.3388185E-03
     +,   1.4481412E-03,   1.5714534E-03,   1.7099386E-03
     +,   1.8645918E-03,   2.0361743E-03,   2.2251245E-03
     +,   2.4316288E-03,   2.6557983E-03,   2.8980023E-03
     +,   3.1593586E-03,   3.4422502E-03,   3.7507997E-03
     +,   4.0917303E-03,   4.4765207E-03,   4.9256906E-03
     +,   5.4741255E-03,   6.1729574E-03,   7.0810486E-03
     +,   8.2427012E-03,   9.6608410E-03,   1.1285552E-02
     +,   1.3030279E-02,   1.4807302E-02,   1.6578842E-02
     +,   1.8441480E-02,   2.0698205E-02,   2.3734244E-02
     +,   2.7613748E-02,   3.1809136E-02,   3.5741858E-02
     +,   3.9871588E-02,   4.5697901E-02,   5.4241877E-02
     +,   6.4316109E-02,   7.3237091E-02,   8.0384046E-02
     +,   8.5272692E-02,   8.8404812E-02,   9.1186039E-02
     +,   9.0968259E-02,   8.7783560E-02,   8.3481945E-02
     +,   7.7794306E-02,   6.9124751E-02,   5.8528468E-02
     +,   4.9221393E-02,   4.3230575E-02,   4.0271308E-02
     +,   3.8232062E-02,   3.5241269E-02,   3.1163167E-02
     +,   2.6797088E-02,   2.2778096E-02,   1.9504368E-02
     +,   1.7219532E-02,   1.5840787E-02,   1.4974241E-02
     +,   1.4204359E-02,   1.3328772E-02,   1.2361364E-02
     +,   1.1402092E-02,   1.0523778E-02,   9.7349714E-03
     +,   9.0011070E-03,   8.2836226E-03,   7.5665903E-03
     +,   6.8614725E-03,   6.1964248E-03,   5.6014415E-03
     +,   5.0976542E-03,   4.6930690E-03,   4.3834900E-03
     +,   4.1559320E-03,   3.9924979E-03,   3.8736602E-03
     +,   3.7805929E-03,   3.6965576E-03,   3.6076482E-03
     +,   3.5031475E-03,   3.3757007E-03,   3.2213246E-03
     +,   3.0393146E-03,   2.8319727E-03,   2.6041821E-03
     +,   2.3627069E-03,   2.1153435E-03,   1.8700322E-03
     +,   1.6340192E-03,   1.4131949E-03,   1.2116799E-03
     +,   1.0317510E-03,   8.7401143E-04,   7.3769648E-04
     +,   6.2111660E-04,   5.2207976E-04,   4.3823250E-04
     +,   3.6730836E-04,   3.0728351E-04,   2.5644025E-04
     +,   2.1336057E-04,   1.7688591E-04,   1.4607032E-04
     +,   1.2012944E-04,   9.8395896E-05,   8.0287529E-05
     +,   6.5289096E-05,   5.2942072E-05,   4.2835636E-05
     +,   3.4605695E-05,   2.7933393E-05,   2.2542605E-05
     +,   1.8197410E-05,   1.4699494E-05,   1.1884545E-05
     +,   9.6178665E-06,   7.7901177E-06,   6.3134889E-06
     +,   5.1180073E-06,   4.1480789E-06,   3.3595957E-06
     +,   2.7176213E-06,   2.1944782E-06,   1.7680397E-06
     +,   1.4205767E-06,   1.1378062E-06,   9.0811881E-07
     +,   7.2200896E-07,   5.7166665E-07,   4.5065403E-07
     +,   3.5363942E-07,   2.7619691E-07,   2.1466111E-07
     +,   1.6600350E-07,   1.2772374E-07,   9.7763383E-08
     +,   7.4438297E-08,   5.6378294E-08,   4.2471243E-08
     +,   3.1821365E-08,   2.3711948E-08,   1.7572138E-08
     +,   1.2949976E-08,   9.4902601E-09,   6.9157453E-09
     +,   5.0111888E-09,   3.6104590E-09,   2.5863336E-09
     +,   1.8420513E-09,   1.3043391E-09,   9.1822072E-10
     +,   6.4261346E-10,   4.4709136E-10,   3.0921862E-10
     +,   2.1259741E-10,   1.4529603E-10,   9.8708715E-11
     +,   6.6656847E-11,   4.4743154E-11,   2.9853269E-11
     +,   1.9798422E-11,   1.3051277E-11,   8.5516177E-12
     +,   5.5696875E-12,   3.6057515E-12,   2.3204149E-12
     +,   1.4843798E-12,   9.4399423E-13,   5.9684283E-13
     +,   3.7521280E-13,   2.3457107E-13,   1.4586699E-13
     +,   9.0248000E-14,   5.5578419E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt85 = Yx/0.45556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3336105E-06,   7.7692894E-06
     +,   8.2205561E-06,   8.6872042E-06,   9.1689599E-06
     +,   9.6654940E-06,   1.0176420E-05,   1.0701295E-05
     +,   1.1239609E-05,   1.1790831E-05,   1.2354352E-05
     +,   1.2929529E-05,   1.3515681E-05,   1.4112096E-05
     +,   1.4718025E-05,   1.5332715E-05,   1.5955395E-05
     +,   1.6585300E-05,   1.7221666E-05,   1.7863758E-05
     +,   1.8510875E-05,   1.9162368E-05,   1.9817626E-05
     +,   2.0476171E-05,   2.1137532E-05,   2.1801421E-05
     +,   2.2467644E-05,   2.3136146E-05,   2.3807042E-05
     +,   2.4480623E-05,   2.5157369E-05,   2.5838002E-05
     +,   2.6523463E-05,   2.7214954E-05,   2.7913973E-05
     +,   2.8622284E-05,   2.9342034E-05,   3.0075667E-05
     +,   3.0826061E-05,   3.1596421E-05,   3.2390464E-05
     +,   3.3212353E-05,   3.4066743E-05,   3.4958830E-05
     +,   3.5894394E-05,   3.6879857E-05,   3.7922342E-05
     +,   3.9029659E-05,   4.0210449E-05,   4.1474177E-05
     +,   4.2831223E-05,   4.4292938E-05,   4.5871664E-05
     +,   4.7580881E-05,   4.9435013E-05,   5.1449755E-05
     +,   5.3641830E-05,   5.6029035E-05,   5.8630209E-05
     +,   6.1465063E-05,   6.4554115E-05,   6.7918460E-05
     +,   7.1579314E-05,   7.5558157E-05,   7.9876132E-05
     +,   8.4553190E-05,   8.9608577E-05,   9.5059149E-05
     +,   1.0092002E-04,   1.0720270E-04,   1.1391588E-04
     +,   1.2106332E-04,   1.2864497E-04,   1.3665463E-04
     +,   1.4508120E-04,   1.5390771E-04,   1.6311042E-04
     +,   1.7265929E-04,   1.8251869E-04,   1.9264726E-04
     +,   2.0299687E-04,   2.1351600E-04,   2.2414749E-04
     +,   2.3483210E-04,   2.4550728E-04,   2.5611033E-04
     +,   2.6657744E-04,   2.7684742E-04,   2.8686051E-04
     +,   2.9656166E-04,   3.0590108E-04,   3.1483479E-04
     +,   3.2332604E-04,   3.3134755E-04,   3.3888119E-04
     +,   3.4591826E-04,   3.5246185E-04,   3.5852561E-04
     +,   3.6413569E-04,   3.6932959E-04,   3.7415739E-04
     +,   3.7868047E-04,   3.8297271E-04,   3.8711831E-04
     +,   3.9121270E-04,   3.9536026E-04,   3.9967362E-04
     +,   4.0427165E-04,   4.0927788E-04,   4.1481835E-04
     +,   4.2101773E-04,   4.2799767E-04,   4.3587200E-04
     +,   4.4474518E-04,   4.5470634E-04,   4.6582834E-04
     +,   4.7816345E-04,   4.9174344E-04,   5.0657603E-04
     +,   5.2265025E-04,   5.3993938E-04,   5.5840594E-04
     +,   5.7801564E-04,   5.9875241E-04,   6.2063907E-04
     +,   6.4375892E-04,   6.6829164E-04,   6.9453736E-04
     +,   7.2296179E-04,   7.5421843E-04,   7.8918715E-04
     +,   8.2898303E-04,   8.7497476E-04,   9.2876022E-04
     +,   9.9214597E-04,   1.0670905E-03,   1.1556145E-03
     +,   1.2597021E-03,   1.3811738E-03,   1.5215467E-03
     +,   1.6819016E-03,   1.8628465E-03,   2.0646306E-03
     +,   2.2874610E-03,   2.5320461E-03,   2.8003356E-03
     +,   3.0960375E-03,   3.4245462E-03,   3.7919534E-03
     +,   4.2033424E-03,   4.6613957E-03,   5.1671322E-03
     +,   5.7240990E-03,   6.3444357E-03,   7.0520989E-03
     +,   7.8781694E-03,   8.8490667E-03,   9.9755786E-03
     +,   1.1250698E-02,   1.2657437E-02,   1.4197540E-02
     +,   1.5959153E-02,   1.8167889E-02,   2.1069380E-02
     +,   2.4736237E-02,   2.9221077E-02,   3.4769062E-02
     +,   4.1322425E-02,   4.8318449E-02,   5.5690572E-02
     +,   6.4450368E-02,   7.4583270E-02,   8.3158970E-02
     +,   8.8368103E-02,   9.0662099E-02,   9.2434086E-02
     +,   9.3893573E-02,   9.0693429E-02,   8.2683884E-02
     +,   7.5559795E-02,   7.0337974E-02,   6.3023940E-02
     +,   5.4167744E-02,   4.6171326E-02,   3.9738659E-02
     +,   3.4547947E-02,   3.0199083E-02,   2.6569903E-02
     +,   2.3604432E-02,   2.1158645E-02,   1.9048758E-02
     +,   1.7089723E-02,   1.5157236E-02,   1.3270346E-02
     +,   1.1571171E-02,   1.0203688E-02,   9.2146201E-03
     +,   8.5459240E-03,   8.0882749E-03,   7.7371164E-03
     +,   7.4212025E-03,   7.1047503E-03,   6.7765815E-03
     +,   6.4376709E-03,   6.0926741E-03,   5.7455804E-03
     +,   5.3984537E-03,   5.0517553E-03,   4.7052535E-03
     +,   4.3590153E-03,   4.0140017E-03,   3.6721104E-03
     +,   3.3357949E-03,   3.0076045E-03,   2.6900163E-03
     +,   2.3854775E-03,   2.0965089E-03,   1.8256817E-03
     +,   1.5754807E-03,   1.3479977E-03,   1.1445574E-03
     +,   9.6553355E-04,   8.1032503E-04,   6.7748252E-04
     +,   5.6494976E-04,   4.7035466E-04,   3.9126328E-04
     +,   3.2535248E-04,   2.7051769E-04,   2.2492593E-04
     +,   1.8702084E-04,   1.5549737E-04,   1.2926769E-04
     +,   1.0743086E-04,   8.9242567E-05,   7.4084397E-05
     +,   6.1444443E-05,   5.0899758E-05,   4.2099997E-05
     +,   3.4754932E-05,   2.8624616E-05,   2.3510906E-05
     +,   1.9249530E-05,   1.5703683E-05,   1.2759380E-05
     +,   1.0321310E-05,   8.3092355E-06,   6.6551829E-06
     +,   5.3014901E-06,   4.1991980E-06,   3.3064473E-06
     +,   2.5875772E-06,   2.0122900E-06,   1.5548695E-06
     +,   1.1935649E-06,   9.1011680E-07,   6.8930672E-07
     +,   5.1851714E-07,   3.8736201E-07,   2.8737270E-07
     +,   2.1170530E-07,   1.5486805E-07,   1.1249035E-07
     +,   8.1128562E-08,   5.8094372E-08,   4.1302890E-08
     +,   2.9154062E-08,   2.0430845E-08,   1.4214793E-08
     +,   9.8186339E-09,   6.7329853E-09,   4.5836583E-09
     +,   3.0978973E-09,   2.0785742E-09,   1.3845242E-09
     +,   9.1555352E-10,   6.0103994E-10,   3.9171738E-10
     +,   2.5344415E-10,   1.6279685E-10,   1.0381376E-10
     +,   6.5724294E-11,   4.1309529E-11,   2.5777887E-11
     +,   1.5970203E-11,   9.8234155E-12,   5.9994093E-12
     +,   3.6379489E-12,   2.1904934E-12,   1.3097214E-12
     +,   7.7772267E-13,   4.5869358E-13,   2.6876556E-13
     +,   1.5649041E-13,   9.0586643E-14,   5.2162339E-14
     +,   2.9907517E-14,   1.7096289E-14,   9.7630551E-15
     +,   5.5851104E-15,   3.2133247E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt90 = Yx/0.44436
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1342307E-05,   1.1797165E-05
     +,   1.2259677E-05,   1.2729433E-05,   1.3206002E-05
     +,   1.3688943E-05,   1.4177795E-05,   1.4672091E-05
     +,   1.5171347E-05,   1.5675096E-05,   1.6182852E-05
     +,   1.6694128E-05,   1.7208449E-05,   1.7725348E-05
     +,   1.8244369E-05,   1.8765062E-05,   1.9287012E-05
     +,   1.9809819E-05,   2.0333104E-05,   2.0856520E-05
     +,   2.1379759E-05,   2.1902546E-05,   2.2424643E-05
     +,   2.2945886E-05,   2.3466098E-05,   2.3985223E-05
     +,   2.4503226E-05,   2.5020132E-05,   2.5536041E-05
     +,   2.6051119E-05,   2.6565604E-05,   2.7079815E-05
     +,   2.7594157E-05,   2.8109103E-05,   2.8625238E-05
     +,   2.9143246E-05,   2.9663897E-05,   3.0188074E-05
     +,   3.0716801E-05,   3.1251166E-05,   3.1792431E-05
     +,   3.2341970E-05,   3.2901280E-05,   3.3472003E-05
     +,   3.4055924E-05,   3.4654979E-05,   3.5271238E-05
     +,   3.5906924E-05,   3.6564390E-05,   3.7246155E-05
     +,   3.7954844E-05,   3.8693226E-05,   3.9464176E-05
     +,   4.0270701E-05,   4.1115807E-05,   4.2002648E-05
     +,   4.2934364E-05,   4.3914108E-05,   4.4944980E-05
     +,   4.6030043E-05,   4.7172205E-05,   4.8374266E-05
     +,   4.9638700E-05,   5.0967850E-05,   5.2363717E-05
     +,   5.3827785E-05,   5.5361317E-05,   5.6964858E-05
     +,   5.8638634E-05,   6.0382041E-05,   6.2194049E-05
     +,   6.4072716E-05,   6.6015607E-05,   6.8019304E-05
     +,   7.0079783E-05,   7.2192284E-05,   7.4351134E-05
     +,   7.6549870E-05,   7.8781544E-05,   8.1038474E-05
     +,   8.3312232E-05,   8.5594082E-05,   8.7874665E-05
     +,   9.0144618E-05,   9.2394024E-05,   9.4613344E-05
     +,   9.6792835E-05,   9.8923352E-05,   1.0099594E-04
     +,   1.0300260E-04,   1.0493612E-04,   1.0679040E-04
     +,   1.0856050E-04,   1.1024327E-04,   1.1183725E-04
     +,   1.1334283E-04,   1.1476278E-04,   1.1610213E-04
     +,   1.1736868E-04,   1.1857299E-04,   1.1972883E-04
     +,   1.2085301E-04,   1.2196608E-04,   1.2309215E-04
     +,   1.2425936E-04,   1.2550010E-04,   1.2685110E-04
     +,   1.2835408E-04,   1.3005579E-04,   1.3200860E-04
     +,   1.3427059E-04,   1.3690667E-04,   1.3998797E-04
     +,   1.4359322E-04,   1.4780855E-04,   1.5272810E-04
     +,   1.5845367E-04,   1.6509571E-04,   1.7277176E-04
     +,   1.8160781E-04,   1.9173688E-04,   2.0329811E-04
     +,   2.1643608E-04,   2.3130109E-04,   2.4804752E-04
     +,   2.6683087E-04,   2.8781011E-04,   3.1114038E-04
     +,   3.3697695E-04,   3.6546396E-04,   3.9673602E-04
     +,   4.3090450E-04,   4.6805557E-04,   5.0823129E-04
     +,   5.5142440E-04,   5.9756381E-04,   6.4649840E-04
     +,   6.9799263E-04,   7.5172877E-04,   8.0731331E-04
     +,   8.6430041E-04,   9.2224125E-04,   9.8077091E-04
     +,   1.0397140E-03,   1.0992337E-03,   1.1600248E-03
     +,   1.2235014E-03,   1.2919513E-03,   1.3685974E-03
     +,   1.4574742E-03,   1.5630393E-03,   1.6894980E-03
     +,   1.8399151E-03,   2.0153155E-03,   2.2140422E-03
     +,   2.4317091E-03,   2.6620335E-03,   2.8985410E-03
     +,   3.1368637E-03,   3.3771477E-03,   3.6261084E-03
     +,   3.8981461E-03,   4.2156014E-03,   4.6083890E-03
     +,   5.1126685E-03,   5.7664355E-03,   6.5995264E-03
     +,   7.6225335E-03,   8.8349255E-03,   1.0279755E-02
     +,   1.2133822E-02,   1.4726880E-02,   1.8342946E-02
     +,   2.2883777E-02,   2.7817704E-02,   3.2663729E-02
     +,   3.7652552E-02,   4.3749608E-02,   5.1896174E-02
     +,   6.2531732E-02,   7.4387938E-02,   8.4666587E-02
     +,   9.3943857E-02,   0.1029082    ,   0.1063537    
     +,   9.8660015E-02,   8.8755488E-02,   8.3777420E-02
     +,   8.0144458E-02,   7.3656663E-02,   6.4734131E-02
     +,   5.6675758E-02,   4.9840376E-02,   4.2728618E-02
     +,   3.5938818E-02,   3.0823175E-02,   2.7035834E-02
     +,   2.3572518E-02,   2.0401672E-02,   1.7923474E-02
     +,   1.6105324E-02,   1.4619216E-02,   1.3244634E-02
     +,   1.1941123E-02,   1.0732065E-02,   9.6208043E-03
     +,   8.5868966E-03,   7.6182080E-03,   6.7270692E-03
     +,   5.9379763E-03,   5.2679246E-03,   4.7175237E-03
     +,   4.2730398E-03,   3.9119842E-03,   3.6081504E-03
     +,   3.3357656E-03,   3.0732227E-03,   2.8058668E-03
     +,   2.5271629E-03,   2.2380417E-03,   1.9448308E-03
     +,   1.6566891E-03,   1.3831807E-03,   1.1324182E-03
     +,   9.0999558E-04,   7.1869238E-04,   5.5872765E-04
     +,   4.2831420E-04,   3.2434231E-04,   2.4304485E-04
     +,   1.8052335E-04,   1.3310154E-04,   9.7533128E-05
     +,   7.1092727E-05,   5.1577692E-05,   3.7254245E-05
     +,   2.6789352E-05,   1.9174771E-05,   1.3655806E-05
     +,   9.6717340E-06,   6.8083950E-06,   4.7609465E-06
     +,   3.3052754E-06,   2.2769163E-06,   1.5555610E-06
     +,   1.0534935E-06,   7.0697502E-07,   4.6992764E-07
     +,   3.0928067E-07,   2.0148248E-07,   1.2988029E-07
     +,   8.2819682E-08,   5.2226117E-08,   3.2560418E-08
     +,   2.0063824E-08,   1.2216165E-08,   7.3476296E-09
     +,   4.3646575E-09,   2.5599558E-09,   1.4821392E-09
     +,   8.4690743E-10,   4.7752741E-10,   2.6563782E-10
     +,   1.4575788E-10,   7.8882061E-11,   4.2098217E-11
     +,   2.2152806E-11,   1.1493128E-11,   5.8784397E-12
     +,   2.9638592E-12,   1.4729403E-12,   7.2148787E-13
     +,   3.4831860E-13,   1.6573036E-13,   7.7709913E-14
     +,   3.5909562E-14,   1.6351986E-14,   7.3378828E-15
     +,   3.2447897E-15,   1.4139666E-15,   6.0717111E-16
     +,   2.5694774E-16,   1.0716544E-16,   4.4059726E-17
     +,   1.7862267E-17,   7.1460497E-18,   2.8250238E-18
     +,   1.1065807E-18,   4.3184510E-19,   1.6965143E-19
     +,   6.8377431E-20,   2.9143541E-20,   1.3645719E-20
     +,   7.2246964E-21,   4.3245188E-21,   2.8452018E-21
     +,   1.9858888E-21,   1.4309567E-21,   1.0472179E-21
     +,   7.7168025E-22,   5.7016796E-22
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_htt95 = Yx/0.43036
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4444587E-05,   4.4980439E-05
     +,   4.5497363E-05,   4.5995694E-05,   4.6475921E-05
     +,   4.6938691E-05,   4.7384783E-05,   4.7815152E-05
     +,   4.8230911E-05,   4.8633312E-05,   4.9023765E-05
     +,   4.9403836E-05,   4.9775212E-05,   5.0139741E-05
     +,   5.0499384E-05,   5.0856233E-05,   5.1212493E-05
     +,   5.1570471E-05,   5.1932540E-05,   5.2301180E-05
     +,   5.2678934E-05,   5.3068357E-05,   5.3472035E-05
     +,   5.3892629E-05,   5.4332704E-05,   5.4794873E-05
     +,   5.5281667E-05,   5.5795565E-05,   5.6338951E-05
     +,   5.6914130E-05,   5.7523273E-05,   5.8168396E-05
     +,   5.8851394E-05,   5.9573980E-05,   6.0337650E-05
     +,   6.1143757E-05,   6.1993371E-05,   6.2887397E-05
     +,   6.3826570E-05,   6.4811225E-05,   6.5841625E-05
     +,   6.6917768E-05,   6.8039401E-05,   6.9206057E-05
     +,   7.0417133E-05,   7.1671740E-05,   7.2968949E-05
     +,   7.4307602E-05,   7.5686505E-05,   7.7104298E-05
     +,   7.8559671E-05,   8.0051221E-05,   8.1577600E-05
     +,   8.3137631E-05,   8.4730040E-05,   8.6353939E-05
     +,   8.8008484E-05,   8.9693145E-05,   9.1407623E-05
     +,   9.3151953E-05,   9.4926560E-05,   9.6732263E-05
     +,   9.8570141E-05,   1.0044191E-04,   1.0234967E-04
     +,   1.0429580E-04,   1.0628345E-04,   1.0831583E-04
     +,   1.1039691E-04,   1.1253076E-04,   1.1472205E-04
     +,   1.1697544E-04,   1.1929613E-04,   1.2168924E-04
     +,   1.2416008E-04,   1.2671415E-04,   1.2935656E-04
     +,   1.3209229E-04,   1.3492619E-04,   1.3786281E-04
     +,   1.4090593E-04,   1.4405916E-04,   1.4732510E-04
     +,   1.5070608E-04,   1.5420330E-04,   1.5781754E-04
     +,   1.6154841E-04,   1.6539503E-04,   1.6935557E-04
     +,   1.7342743E-04,   1.7760777E-04,   1.8189276E-04
     +,   1.8627822E-04,   1.9076017E-04,   1.9533437E-04
     +,   1.9999639E-04,   2.0474321E-04,   2.0957149E-04
     +,   2.1447991E-04,   2.1946756E-04,   2.2453636E-04
     +,   2.2968894E-04,   2.3493174E-04,   2.4027258E-04
     +,   2.4572326E-04,   2.5129894E-04,   2.5701817E-04
     +,   2.6290322E-04,   2.6898136E-04,   2.7528423E-04
     +,   2.8184764E-04,   2.8871268E-04,   2.9592501E-04
     +,   3.0353558E-04,   3.1159929E-04,   3.2017610E-04
     +,   3.2932928E-04,   3.3912592E-04,   3.4963488E-04
     +,   3.6092667E-04,   3.7307199E-04,   3.8613839E-04
     +,   4.0018978E-04,   4.1528395E-04,   4.3146993E-04
     +,   4.4878252E-04,   4.6724381E-04,   4.8685467E-04
     +,   5.0759630E-04,   5.2942266E-04,   5.5226311E-04
     +,   5.7601370E-04,   6.0054311E-04,   6.2568480E-04
     +,   6.5124477E-04,   6.7699904E-04,   7.0269755E-04
     +,   7.2806922E-04,   7.5283000E-04,   7.7668746E-04
     +,   7.9934910E-04,   8.2053145E-04,   8.3997147E-04
     +,   8.5743400E-04,   8.7271869E-04,   8.8567048E-04
     +,   8.9618703E-04,   9.0421969E-04,   9.0978068E-04
     +,   9.1294240E-04,   9.1383548E-04,   9.1264967E-04
     +,   9.0962369E-04,   9.0504461E-04,   8.9923706E-04
     +,   8.9255895E-04,   8.8539132E-04,   8.7813300E-04
     +,   8.7119563E-04,   8.6499867E-04,   8.5996685E-04
     +,   8.5652893E-04,   8.5511740E-04,   8.5617416E-04
     +,   8.6015015E-04,   8.6751359E-04,   8.7876059E-04
     +,   8.9442922E-04,   9.1512420E-04,   9.4155379E-04
     +,   9.7457314E-04,   1.0152458E-03,   1.0649167E-03
     +,   1.1252816E-03,   1.1984430E-03,   1.2869596E-03
     +,   1.3938387E-03,   1.5224721E-03,   1.6765157E-03
     +,   1.8597005E-03,   2.0755583E-03,   2.3270715E-03
     +,   2.6163149E-03,   2.9441579E-03,   3.3100294E-03
     +,   3.7120311E-03,   4.1477042E-03,   4.6158051E-03
     +,   5.1191063E-03,   5.6677987E-03,   6.2818611E-03
     +,   6.9897315E-03,   7.8216847E-03,   8.8004339E-03
     +,   9.9365832E-03,   1.1237482E-02,   1.2731041E-02
     +,   1.4493028E-02,   1.6655346E-02,   1.9366851E-02
     +,   2.2694465E-02,   2.6515184E-02,   3.0510051E-02
     +,   3.4283314E-02,   3.7470073E-02,   3.9830696E-02
     +,   4.1539770E-02,   4.3443803E-02,   4.6591837E-02
     +,   5.1180571E-02,   5.6083612E-02,   5.9640266E-02
     +,   6.1058111E-02,   6.0869012E-02,   5.9932202E-02
     +,   5.8636121E-02,   5.7181351E-02,   5.5748474E-02
     +,   5.4196801E-02,   5.2087773E-02,   4.9084049E-02
     +,   4.5364272E-02,   4.1617554E-02,   3.8463384E-02
     +,   3.5985921E-02,   3.3870336E-02,   3.1776711E-02
     +,   2.9518973E-02,   2.7056603E-02,   2.4467401E-02
     +,   2.1925049E-02,   1.9629186E-02,   1.7708916E-02
     +,   1.6172186E-02,   1.4932957E-02,   1.3881564E-02
     +,   1.2943670E-02,   1.2098410E-02,   1.1361226E-02
     +,   1.0753026E-02,   1.0274980E-02,   9.8994505E-03
     +,   9.5769996E-03,   9.2525790E-03,   8.8817421E-03
     +,   8.4403781E-03,   7.9260711E-03,   7.3532751E-03
     +,   6.7460239E-03,   6.1309636E-03,   5.5322223E-03
     +,   4.9685519E-03,   4.4522383E-03,   3.9891424E-03
     +,   3.5796110E-03,   3.2199339E-03,   2.9039683E-03
     +,   2.6246333E-03,   2.3751082E-03,   2.1496327E-03
     +,   1.9438587E-03,   1.7548130E-03,   1.5806535E-03
     +,   1.4203253E-03,   1.2732458E-03,   1.1389899E-03
     +,   1.0171273E-03,   9.0713077E-04,   8.0833770E-04
     +,   7.1996328E-04,   6.4115069E-04,   5.7101977E-04
     +,   5.0870079E-04,   4.5336341E-04,   4.0423707E-04
     +,   3.6062481E-04,   3.2189305E-04,   2.8747978E-04
     +,   2.5687928E-04,   2.2964532E-04,   2.0537811E-04
     +,   1.8372717E-04,   1.6438084E-04,   1.4706831E-04
     +,   1.3155153E-04,   1.1762580E-04,   1.0511313E-04
     +,   9.3860108E-05,   8.3735453E-05,   7.4624353E-05
     +,   6.6427914E-05,   5.9058439E-05,   5.2438980E-05
     +,   4.6499950E-05,   4.1179152E-05,   3.6419242E-05
     +,   3.2168275E-05,   2.8377854E-05,   2.5003872E-05
     +,   2.2005213E-05,   1.9344387E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt100 = Yx/0.4235
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4841209E-05,   2.5321857E-05
     +,   2.5797330E-05,   2.6267093E-05,   2.6730626E-05
     +,   2.7187416E-05,   2.7636977E-05,   2.8078850E-05
     +,   2.8512592E-05,   2.8937802E-05,   2.9354091E-05
     +,   2.9761113E-05,   3.0158544E-05,   3.0546093E-05
     +,   3.0923529E-05,   3.1290627E-05,   3.1647207E-05
     +,   3.1993139E-05,   3.2328324E-05,   3.2652708E-05
     +,   3.2966273E-05,   3.3269051E-05,   3.3561097E-05
     +,   3.3842542E-05,   3.4113513E-05,   3.4374218E-05
     +,   3.4624889E-05,   3.4865792E-05,   3.5097259E-05
     +,   3.5319623E-05,   3.5533292E-05,   3.5738707E-05
     +,   3.5936326E-05,   3.6126654E-05,   3.6310252E-05
     +,   3.6487683E-05,   3.6659581E-05,   3.6826586E-05
     +,   3.6989404E-05,   3.7148719E-05,   3.7305326E-05
     +,   3.7459991E-05,   3.7613565E-05,   3.7766895E-05
     +,   3.7920894E-05,   3.8076494E-05,   3.8234695E-05
     +,   3.8396516E-05,   3.8563037E-05,   3.8735383E-05
     +,   3.8914746E-05,   3.9102364E-05,   3.9299553E-05
     +,   3.9507664E-05,   3.9728173E-05,   3.9962604E-05
     +,   4.0212610E-05,   4.0479885E-05,   4.0766281E-05
     +,   4.1073741E-05,   4.1404342E-05,   4.1760311E-05
     +,   4.2143980E-05,   4.2557858E-05,   4.3004668E-05
     +,   4.3487198E-05,   4.4008553E-05,   4.4571905E-05
     +,   4.5180765E-05,   4.5838733E-05,   4.6549725E-05
     +,   4.7317786E-05,   4.8147296E-05,   4.9042788E-05
     +,   5.0009039E-05,   5.1051098E-05,   5.2174186E-05
     +,   5.3383708E-05,   5.4685268E-05,   5.6084755E-05
     +,   5.7588011E-05,   5.9201244E-05,   6.0930466E-05
     +,   6.2781997E-05,   6.4762011E-05,   6.6876790E-05
     +,   6.9132329E-05,   7.1534771E-05,   7.4089825E-05
     +,   7.6803146E-05,   7.9680278E-05,   8.2726088E-05
     +,   8.5945328E-05,   8.9342422E-05,   9.2921560E-05
     +,   9.6686199E-05,   1.0063998E-04,   1.0478566E-04
     +,   1.0912641E-04,   1.1366455E-04,   1.1840310E-04
     +,   1.2334439E-04,   1.2849155E-04,   1.3384734E-04
     +,   1.3941550E-04,   1.4520052E-04,   1.5120707E-04
     +,   1.5744062E-04,   1.6390807E-04,   1.7061718E-04
     +,   1.7757634E-04,   1.8479525E-04,   1.9228415E-04
     +,   2.0005436E-04,   2.0811698E-04,   2.1648429E-04
     +,   2.2516698E-04,   2.3417656E-04,   2.4352224E-04
     +,   2.5321270E-04,   2.6325480E-04,   2.7365226E-04
     +,   2.8440659E-04,   2.9551686E-04,   3.0697981E-04
     +,   3.1878805E-04,   3.3093322E-04,   3.4340375E-04
     +,   3.5618781E-04,   3.6927155E-04,   3.8264270E-04
     +,   3.9628847E-04,   4.1019949E-04,   4.2436708E-04
     +,   4.3878754E-04,   4.5345971E-04,   4.6838497E-04
     +,   4.8356684E-04,   4.9901189E-04,   5.1472575E-04
     +,   5.3071132E-04,   5.4696645E-04,   5.6348229E-04
     +,   5.8023975E-04,   5.9720548E-04,   6.1433145E-04
     +,   6.3155225E-04,   6.4878311E-04,   6.6592061E-04
     +,   6.8284507E-04,   6.9942157E-04,   7.1550335E-04
     +,   7.3093723E-04,   7.4557139E-04,   7.5926079E-04
     +,   7.7187282E-04,   7.8329659E-04,   7.9345016E-04
     +,   8.0228463E-04,   8.0978766E-04,   8.1598910E-04
     +,   8.2095817E-04,   8.2480372E-04,   8.2767027E-04
     +,   8.2973181E-04,   8.3118724E-04,   8.3225087E-04
     +,   8.3314738E-04,   8.3410612E-04,   8.3535723E-04
     +,   8.3713344E-04,   8.3967502E-04,   8.4323960E-04
     +,   8.4812148E-04,   8.5467525E-04,   8.6335099E-04
     +,   8.7473425E-04,   8.8959845E-04,   9.0896274E-04
     +,   9.3416113E-04,   9.6691173E-04,   1.0093803E-03
     +,   1.0642456E-03,   1.1347557E-03,   1.2247798E-03
     +,   1.3388681E-03,   1.4823558E-03,   1.6615414E-03
     +,   1.8838840E-03,   2.1580972E-03,   2.4940262E-03
     +,   2.9018368E-03,   3.3903075E-03,   3.9644437E-03
     +,   4.6232422E-03,   5.3590182E-03,   6.1597629E-03
     +,   7.0149074E-03,   7.9228142E-03,   8.8969916E-03
     +,   9.9682426E-03,   1.1179744E-02,   1.2572676E-02
     +,   1.4165263E-02,   1.5941067E-02,   1.7870018E-02
     +,   1.9960949E-02,   2.2291413E-02,   2.4949186E-02
     +,   2.7916197E-02,   3.1030746E-02,   3.4075275E-02
     +,   3.6851205E-02,   3.9238330E-02,   4.1486945E-02
     +,   4.4374660E-02,   4.8341312E-02,   5.2342407E-02
     +,   5.4441053E-02,   5.4019071E-02,   5.2872527E-02
     +,   5.3221498E-02,   5.4980934E-02,   5.6283154E-02
     +,   5.6024421E-02,   5.4591093E-02,   5.2794266E-02
     +,   5.0892450E-02,   4.8471019E-02,   4.5130558E-02
     +,   4.1194536E-02,   3.7505023E-02,   3.4610629E-02
     +,   3.2411788E-02,   3.0457517E-02,   2.8381485E-02
     +,   2.6121335E-02,   2.3840042E-02,   2.1705445E-02
     +,   1.9773254E-02,   1.8027456E-02,   1.6449004E-02
     +,   1.5031572E-02,   1.3769683E-02,   1.2652262E-02
     +,   1.1660028E-02,   1.0763059E-02,   9.9240718E-03
     +,   9.1102319E-03,   8.3055310E-03,   7.5142537E-03
     +,   6.7547723E-03,   6.0485099E-03,   5.4107853E-03
     +,   4.8467661E-03,   4.3524615E-03,   3.9182296E-03
     +,   3.5326257E-03,   3.1852466E-03,   2.8682116E-03
     +,   2.5764464E-03,   2.3071512E-03,   2.0590054E-03
     +,   1.8314315E-03,   1.6240528E-03,   1.4363367E-03
     +,   1.2674974E-03,   1.1165190E-03,   9.8221167E-04
     +,   8.6328294E-04,   7.5841247E-04,   6.6629826E-04
     +,   5.8566721E-04,   5.1528541E-04,   4.5397220E-04
     +,   4.0061594E-04,   3.5417202E-04,   3.1368918E-04
     +,   2.7830762E-04,   2.4727584E-04,   2.1994306E-04
     +,   1.9576304E-04,   1.7427963E-04,   1.5512196E-04
     +,   1.3798605E-04,   1.2262749E-04,   1.0884526E-04
     +,   9.6473246E-05,   8.5372369E-05,   7.5421383E-05
     +,   6.6514549E-05,   5.8555521E-05,   5.1457479E-05
     +,   4.5139408E-05,   3.9527138E-05,   3.4551238E-05
     +,   3.0148181E-05,   2.6258853E-05,   2.2829578E-05
     +,   1.9810917E-05,   1.7158374E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt102 = Yx/0.40712
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.8034927E-06,   7.9720685E-06
     +,   8.1476264E-06,   8.3306595E-06,   8.5216880E-06
     +,   8.7212529E-06,   8.9299201E-06,   9.1482771E-06
     +,   9.3769395E-06,   9.6165513E-06,   9.8677738E-06
     +,   1.0131303E-05,   1.0407849E-05,   1.0698159E-05
     +,   1.1002997E-05,   1.1323159E-05,   1.1659457E-05
     +,   1.2012737E-05,   1.2383866E-05,   1.2773728E-05
     +,   1.3183230E-05,   1.3613305E-05,   1.4064886E-05
     +,   1.4538965E-05,   1.5036484E-05,   1.5558455E-05
     +,   1.6105862E-05,   1.6679705E-05,   1.7280994E-05
     +,   1.7910716E-05,   1.8569865E-05,   1.9259425E-05
     +,   1.9980353E-05,   2.0733592E-05,   2.1520062E-05
     +,   2.2340642E-05,   2.3196179E-05,   2.4087463E-05
     +,   2.5015306E-05,   2.5980346E-05,   2.6983280E-05
     +,   2.8024695E-05,   2.9105118E-05,   3.0225037E-05
     +,   3.1384850E-05,   3.2584940E-05,   3.3825581E-05
     +,   3.5107041E-05,   3.6429527E-05,   3.7793234E-05
     +,   3.9198316E-05,   4.0644951E-05,   4.2133313E-05
     +,   4.3663724E-05,   4.5236393E-05,   4.6851826E-05
     +,   4.8510567E-05,   5.0213359E-05,   5.1961182E-05
     +,   5.3755291E-05,   5.5597233E-05,   5.7489007E-05
     +,   5.9432827E-05,   6.1431594E-05,   6.3488755E-05
     +,   6.5608037E-05,   6.7794113E-05,   7.0051981E-05
     +,   7.2387629E-05,   7.4807358E-05,   7.7318538E-05
     +,   7.9928810E-05,   8.2646788E-05,   8.5481312E-05
     +,   8.8441979E-05,   9.1538786E-05,   9.4781732E-05
     +,   9.8180913E-05,   1.0174657E-04,   1.0548859E-04
     +,   1.0941594E-04,   1.1353729E-04,   1.1785967E-04
     +,   1.2238923E-04,   1.2712980E-04,   1.3208376E-04
     +,   1.3725061E-04,   1.4262761E-04,   1.4820865E-04
     +,   1.5398474E-04,   1.5994358E-04,   1.6606892E-04
     +,   1.7234063E-04,   1.7873538E-04,   1.8522603E-04
     +,   1.9178131E-04,   1.9836715E-04,   2.0494552E-04
     +,   2.1147641E-04,   2.1791649E-04,   2.2422132E-04
     +,   2.3034438E-04,   2.3623917E-04,   2.4185830E-04
     +,   2.4715578E-04,   2.5208670E-04,   2.5660827E-04
     +,   2.6068024E-04,   2.6426648E-04,   2.6733463E-04
     +,   2.6985712E-04,   2.7181164E-04,   2.7318153E-04
     +,   2.7395619E-04,   2.7413081E-04,   2.7370738E-04
     +,   2.7269387E-04,   2.7110428E-04,   2.6895889E-04
     +,   2.6628308E-04,   2.6310782E-04,   2.5946848E-04
     +,   2.5540494E-04,   2.5096041E-04,   2.4618092E-04
     +,   2.4111541E-04,   2.3581370E-04,   2.3032769E-04
     +,   2.2470910E-04,   2.1901037E-04,   2.1328292E-04
     +,   2.0757808E-04,   2.0194547E-04,   1.9643438E-04
     +,   1.9109178E-04,   1.8596346E-04,   1.8109412E-04
     +,   1.7652703E-04,   1.7230389E-04,   1.6846533E-04
     +,   1.6505145E-04,   1.6210147E-04,   1.5965385E-04
     +,   1.5774666E-04,   1.5641772E-04,   1.5570415E-04
     +,   1.5564254E-04,   1.5626856E-04,   1.5761642E-04
     +,   1.5971877E-04,   1.6260552E-04,   1.6630336E-04
     +,   1.7083476E-04,   1.7621752E-04,   1.8246380E-04
     +,   1.8957898E-04,   1.9756144E-04,   2.0640297E-04
     +,   2.1608835E-04,   2.2659505E-04,   2.3789654E-04
     +,   2.4996258E-04,   2.6276123E-04,   2.7626206E-04
     +,   2.9044095E-04,   3.0528283E-04,   3.2078513E-04
     +,   3.3696258E-04,   3.5385301E-04,   3.7151916E-04
     +,   3.9005143E-04,   4.0956994E-04,   4.3022673E-04
     +,   4.5220435E-04,   4.7570994E-04,   5.0097529E-04
     +,   5.2824931E-04,   5.5778603E-04,   5.8983819E-04
     +,   6.2464818E-04,   6.6243816E-04,   7.0340087E-04
     +,   7.4770139E-04,   7.9549220E-04,   8.4693887E-04
     +,   9.0226432E-04,   9.6182834E-04,   1.0262384E-03
     +,   1.0964791E-03,   1.1740581E-03,   1.2611765E-03
     +,   1.3608688E-03,   1.4770989E-03,   1.6147979E-03
     +,   1.7798071E-03,   1.9786463E-03,   2.2181112E-03
     +,   2.5046798E-03,   2.8438403E-03,   3.2394652E-03
     +,   3.6935601E-03,   4.2066895E-03,   4.7792052E-03
     +,   5.4128980E-03,   6.1126309E-03,   6.8869158E-03
     +,   7.7457903E-03,   8.6946758E-03,   9.7263306E-03
     +,   1.0816831E-02,   1.1935010E-02,   1.3068590E-02
     +,   1.4255163E-02,   1.5592435E-02,   1.7211106E-02
     +,   1.9227849E-02,   2.1723745E-02,   2.4771042E-02
     +,   2.8444722E-02,   3.2682158E-02,   3.7048467E-02
     +,   4.0859122E-02,   4.3800093E-02,   4.6190523E-02
     +,   4.8412871E-02,   5.0547458E-02,   5.2650698E-02
     +,   5.4974061E-02,   5.8090799E-02,   6.2178437E-02
     +,   6.5737590E-02,   6.6889241E-02,   6.5544039E-02
     +,   6.2292077E-02,   5.7327773E-02,   5.1595446E-02
     +,   4.6648920E-02,   4.3356448E-02,   4.1329850E-02
     +,   3.9440762E-02,   3.7027624E-02,   3.4274861E-02
     +,   3.1541776E-02,   2.8924225E-02,   2.6395548E-02
     +,   2.3972524E-02,   2.1703294E-02,   1.9623416E-02
     +,   1.7746579E-02,   1.6065469E-02,   1.4554252E-02
     +,   1.3179107E-02,   1.1911913E-02,   1.0738633E-02
     +,   9.6597308E-03,   8.6832270E-03,   7.8124148E-03
     +,   7.0365444E-03,   6.3314945E-03,   5.6694611E-03
     +,   5.0298786E-03,   4.4051339E-03,   3.7998799E-03
     +,   3.2262763E-03,   2.6982771E-03,   2.2270861E-03
     +,   1.8188766E-03,   1.4744692E-03,   1.1902690E-03
     +,   9.5980265E-04,   7.7528809E-04,   6.2884082E-04
     +,   5.1321177E-04,   4.2214143E-04,   3.5044766E-04
     +,   2.9394944E-04,   2.4930167E-04,   2.1385864E-04
     +,   1.8552638E-04,   1.6266365E-04,   1.4398858E-04
     +,   1.2851518E-04,   1.1549089E-04,   1.0435237E-04
     +,   9.4680727E-05,   8.6170163E-05,   7.8597433E-05
     +,   7.1800474E-05,   6.5661523E-05,   6.0092501E-05
     +,   5.5027078E-05,   5.0412331E-05,   4.6205521E-05
     +,   4.2369647E-05,   3.8872589E-05,   3.5684850E-05
     +,   3.2779746E-05,   3.0132174E-05,   2.7719170E-05
     +,   2.5519083E-05,   2.3512213E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt104 = Yx/0.40684
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.5326404E-06,   9.7850370E-06
     +,   1.0041785E-05,   1.0303000E-05,   1.0568806E-05
     +,   1.0839341E-05,   1.1114747E-05,   1.1395184E-05
     +,   1.1680809E-05,   1.1971805E-05,   1.2268351E-05
     +,   1.2570643E-05,   1.2878878E-05,   1.3193265E-05
     +,   1.3514024E-05,   1.3841378E-05,   1.4175556E-05
     +,   1.4516794E-05,   1.4865332E-05,   1.5221413E-05
     +,   1.5585289E-05,   1.5957203E-05,   1.6337393E-05
     +,   1.6726137E-05,   1.7123652E-05,   1.7530196E-05
     +,   1.7946004E-05,   1.8371309E-05,   1.8806340E-05
     +,   1.9251305E-05,   1.9706424E-05,   2.0171881E-05
     +,   2.0647873E-05,   2.1134561E-05,   2.1632111E-05
     +,   2.2140668E-05,   2.2660355E-05,   2.3191280E-05
     +,   2.3733564E-05,   2.4287259E-05,   2.4852457E-05
     +,   2.5429204E-05,   2.6017538E-05,   2.6617488E-05
     +,   2.7229073E-05,   2.7852304E-05,   2.8487191E-05
     +,   2.9133747E-05,   2.9791969E-05,   3.0461888E-05
     +,   3.1143532E-05,   3.1836942E-05,   3.2542204E-05
     +,   3.3259454E-05,   3.3988803E-05,   3.4730489E-05
     +,   3.5484776E-05,   3.6252004E-05,   3.7032605E-05
     +,   3.7827100E-05,   3.8636128E-05,   3.9460469E-05
     +,   4.0300998E-05,   4.1158812E-05,   4.2035183E-05
     +,   4.2931493E-05,   4.3849464E-05,   4.4790922E-05
     +,   4.5758072E-05,   4.6753270E-05,   4.7779264E-05
     +,   4.8839029E-05,   4.9935927E-05,   5.1073581E-05
     +,   5.2256026E-05,   5.3487704E-05,   5.4773278E-05
     +,   5.6117828E-05,   5.7526860E-05,   5.9006212E-05
     +,   6.0561935E-05,   6.2200575E-05,   6.3928746E-05
     +,   6.5753513E-05,   6.7681882E-05,   6.9721224E-05
     +,   7.1878683E-05,   7.4161660E-05,   7.6577133E-05
     +,   7.9132042E-05,   8.1832979E-05,   8.4685962E-05
     +,   8.7696317E-05,   9.0868809E-05,   9.4207331E-05
     +,   9.7714495E-05,   1.0139207E-04,   1.0524008E-04
     +,   1.0925755E-04,   1.1344138E-04,   1.1778735E-04
     +,   1.2228875E-04,   1.2693761E-04,   1.3172331E-04
     +,   1.3663371E-04,   1.4165459E-04,   1.4676942E-04
     +,   1.5195954E-04,   1.5720486E-04,   1.6248337E-04
     +,   1.6777094E-04,   1.7304247E-04,   1.7827108E-04
     +,   1.8342934E-04,   1.8848843E-04,   1.9341956E-04
     +,   1.9819326E-04,   2.0278056E-04,   2.0715247E-04
     +,   2.1128109E-04,   2.1513963E-04,   2.1870247E-04
     +,   2.2194578E-04,   2.2484770E-04,   2.2738897E-04
     +,   2.2955242E-04,   2.3132387E-04,   2.3269192E-04
     +,   2.3364818E-04,   2.3418760E-04,   2.3430803E-04
     +,   2.3401073E-04,   2.3329999E-04,   2.3218320E-04
     +,   2.3067079E-04,   2.2877600E-04,   2.2651470E-04
     +,   2.2390544E-04,   2.2096884E-04,   2.1772757E-04
     +,   2.1420632E-04,   2.1043140E-04,   2.0643060E-04
     +,   2.0223235E-04,   1.9786699E-04,   1.9336533E-04
     +,   1.8875892E-04,   1.8408042E-04,   1.7936360E-04
     +,   1.7464264E-04,   1.6995301E-04,   1.6533183E-04
     +,   1.6081825E-04,   1.5645310E-04,   1.5228013E-04
     +,   1.4834690E-04,   1.4470478E-04,   1.4140978E-04
     +,   1.3852336E-04,   1.3611330E-04,   1.3425364E-04
     +,   1.3302529E-04,   1.3251620E-04,   1.3282061E-04
     +,   1.3403868E-04,   1.3627522E-04,   1.3963769E-04
     +,   1.4423407E-04,   1.5017025E-04,   1.5754736E-04
     +,   1.6645744E-04,   1.7698068E-04,   1.8918385E-04
     +,   2.0311748E-04,   2.1881427E-04,   2.3629233E-04
     +,   2.5555812E-04,   2.7661081E-04,   2.9945208E-04
     +,   3.2409918E-04,   3.5059909E-04,   3.7904186E-04
     +,   4.0958074E-04,   4.4245177E-04,   4.7798935E-04
     +,   5.1663892E-04,   5.5897003E-04,   6.0568698E-04
     +,   6.5763318E-04,   7.1578461E-04,   7.8126258E-04
     +,   8.5533020E-04,   9.3939685E-04,   1.0350372E-03
     +,   1.1440245E-03,   1.2683602E-03,   1.4102813E-03
     +,   1.5722296E-03,   1.7567285E-03,   1.9660937E-03
     +,   2.2019660E-03,   2.4647731E-03,   2.7532368E-03
     +,   3.0641453E-03,   3.3926021E-03,   3.7330252E-03
     +,   4.0806052E-03,   4.4330619E-03,   4.7922563E-03
     +,   5.1650698E-03,   5.5627758E-03,   5.9982957E-03
     +,   6.4812042E-03,   7.0119137E-03,   7.5788996E-03
     +,   8.1639634E-03,   8.7584499E-03,   9.3870899E-03
     +,   1.0130990E-02,   1.1140997E-02,   1.2629317E-02
     +,   1.4810523E-02,   1.7768251E-02,   2.1315986E-02
     +,   2.5020614E-02,   2.8429013E-02,   3.1276599E-02
     +,   3.3580463E-02,   3.5805847E-02,   3.8848359E-02
     +,   4.3230809E-02,   4.8100248E-02,   5.1893529E-02
     +,   5.4764893E-02,   5.8412932E-02,   6.2389515E-02
     +,   6.4237952E-02,   6.3416563E-02,   6.1807785E-02
     +,   6.1326925E-02,   6.1616257E-02,   6.0662668E-02
     +,   5.8341816E-02,   5.6040108E-02,   5.3684220E-02
     +,   5.0495543E-02,   4.6460334E-02,   4.1692484E-02
     +,   3.6426969E-02,   3.1525917E-02,   2.7822154E-02
     +,   2.5283253E-02,   2.3270130E-02,   2.1299327E-02
     +,   1.9281991E-02,   1.7290952E-02,   1.5382789E-02
     +,   1.3599434E-02,   1.1992980E-02,   1.0601047E-02
     +,   9.4146086E-03,   8.3793122E-03,   7.4266177E-03
     +,   6.5073809E-03,   5.6072646E-03,   4.7410503E-03
     +,   3.9363736E-03,   3.2183316E-03,   2.6009900E-03
     +,   2.0860599E-03,   1.6659610E-03,   1.3281278E-03
     +,   1.0585873E-03,   8.4424252E-04,   6.7392335E-04
     +,   5.3858472E-04,   4.3103792E-04,   3.4562583E-04
     +,   2.7785217E-04,   2.2413456E-04,   1.8158676E-04
     +,   1.4788934E-04,   1.2117233E-04,   9.9943281E-05
     +,   8.3013794E-05,   6.9449939E-05,   5.8520371E-05
     +,   4.9657672E-05,   4.2424417E-05,   3.6482536E-05
     +,   3.1572101E-05,   2.7491311E-05,   2.4083380E-05
     +,   2.1224696E-05,   1.8817447E-05,   1.6782904E-05
     +,   1.5057596E-05,   1.3589492E-05,   1.2336071E-05
     +,   1.1262057E-05,   1.0338388E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt106 = Yx/0.403142857142857
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0164616E-05,   3.1173695E-05
     +,   3.2191121E-05,   3.3215383E-05,   3.4244869E-05
     +,   3.5277921E-05,   3.6312813E-05,   3.7347738E-05
     +,   3.8380829E-05,   3.9410210E-05,   4.0433926E-05
     +,   4.1449981E-05,   4.2456366E-05,   4.3451033E-05
     +,   4.4431938E-05,   4.5397031E-05,   4.6344270E-05
     +,   4.7271613E-05,   4.8177055E-05,   4.9058654E-05
     +,   4.9914463E-05,   5.0742634E-05,   5.1541367E-05
     +,   5.2308995E-05,   5.3043848E-05,   5.3744450E-05
     +,   5.4409396E-05,   5.5037406E-05,   5.5627341E-05
     +,   5.6178218E-05,   5.6689194E-05,   5.7159592E-05
     +,   5.7588943E-05,   5.7976911E-05,   5.8323367E-05
     +,   5.8628415E-05,   5.8892329E-05,   5.9115599E-05
     +,   5.9298975E-05,   5.9443348E-05,   5.9549926E-05
     +,   5.9620106E-05,   5.9655518E-05,   5.9658050E-05
     +,   5.9629794E-05,   5.9573122E-05,   5.9490601E-05
     +,   5.9385071E-05,   5.9259586E-05,   5.9117447E-05
     +,   5.8962152E-05,   5.8797425E-05,   5.8627218E-05
     +,   5.8455644E-05,   5.8287056E-05,   5.8125937E-05
     +,   5.7976962E-05,   5.7844954E-05,   5.7734858E-05
     +,   5.7651738E-05,   5.7600748E-05,   5.7587120E-05
     +,   5.7616173E-05,   5.7693196E-05,   5.7823541E-05
     +,   5.8012491E-05,   5.8265337E-05,   5.8587277E-05
     +,   5.8983431E-05,   5.9458784E-05,   6.0018210E-05
     +,   6.0666389E-05,   6.1407882E-05,   6.2246938E-05
     +,   6.3187734E-05,   6.4234067E-05,   6.5389591E-05
     +,   6.6657609E-05,   6.8041212E-05,   6.9543290E-05
     +,   7.1166251E-05,   7.2912459E-05,   7.4783769E-05
     +,   7.6781973E-05,   7.8908328E-05,   8.1164093E-05
     +,   8.3549945E-05,   8.6066560E-05,   8.8713990E-05
     +,   9.1492257E-05,   9.4401039E-05,   9.7439472E-05
     +,   1.0060635E-04,   1.0390015E-04,   1.0731904E-04
     +,   1.1086028E-04,   1.1452097E-04,   1.1829721E-04
     +,   1.2218489E-04,   1.2617855E-04,   1.3027254E-04
     +,   1.3445967E-04,   1.3873242E-04,   1.4308159E-04
     +,   1.4749741E-04,   1.5196894E-04,   1.5648380E-04
     +,   1.6102851E-04,   1.6558864E-04,   1.7014881E-04
     +,   1.7469197E-04,   1.7920096E-04,   1.8365694E-04
     +,   1.8804111E-04,   1.9233370E-04,   1.9651513E-04
     +,   2.0056515E-04,   2.0446429E-04,   2.0819331E-04
     +,   2.1173360E-04,   2.1506805E-04,   2.1818049E-04
     +,   2.2105641E-04,   2.2368344E-04,   2.2605147E-04
     +,   2.2815235E-04,   2.2998112E-04,   2.3153509E-04
     +,   2.3281491E-04,   2.3382391E-04,   2.3456848E-04
     +,   2.3505809E-04,   2.3530504E-04,   2.3532423E-04
     +,   2.3513347E-04,   2.3475259E-04,   2.3420365E-04
     +,   2.3351045E-04,   2.3269842E-04,   2.3179369E-04
     +,   2.3082360E-04,   2.2981555E-04,   2.2879706E-04
     +,   2.2779546E-04,   2.2683751E-04,   2.2594926E-04
     +,   2.2515545E-04,   2.2448000E-04,   2.2394532E-04
     +,   2.2357283E-04,   2.2338257E-04,   2.2339351E-04
     +,   2.2362407E-04,   2.2409158E-04,   2.2481351E-04
     +,   2.2580754E-04,   2.2709156E-04,   2.2868469E-04
     +,   2.3060793E-04,   2.3288369E-04,   2.3553724E-04
     +,   2.3859699E-04,   2.4209406E-04,   2.4606325E-04
     +,   2.5054329E-04,   2.5557639E-04,   2.6120807E-04
     +,   2.6748673E-04,   2.7446399E-04,   2.8219310E-04
     +,   2.9072762E-04,   3.0012082E-04,   3.1042492E-04
     +,   3.2168895E-04,   3.3395644E-04,   3.4726571E-04
     +,   3.6164816E-04,   3.7712578E-04,   3.9371080E-04
     +,   4.1140782E-04,   4.3021265E-04,   4.5011329E-04
     +,   4.7109244E-04,   4.9313420E-04,   5.1622605E-04
     +,   5.4036488E-04,   5.6556385E-04,   5.9186231E-04
     +,   6.1933079E-04,   6.4807769E-04,   6.7826110E-04
     +,   7.1009214E-04,   7.4384181E-04,   7.7984860E-04
     +,   8.1853167E-04,   8.6040044E-04,   9.0606965E-04
     +,   9.5628400E-04,   1.0119514E-03,   1.0741764E-03
     +,   1.1442958E-03,   1.2239246E-03,   1.3149986E-03
     +,   1.4197958E-03,   1.5409328E-03,   1.6813503E-03
     +,   1.8442352E-03,   2.0328749E-03,   2.2504728E-03
     +,   2.4998970E-03,   2.7833192E-03,   3.1017130E-03
     +,   3.4542629E-03,   3.8377517E-03,   4.2461269E-03
     +,   4.6707070E-03,   5.1017608E-03,   5.5316431E-03
     +,   5.9591979E-03,   6.3944096E-03,   6.8616075E-03
     +,   7.3991586E-03,   8.0541419E-03,   8.8712638E-03
     +,   9.8768817E-03,   1.1061594E-02,   1.2369308E-02
     +,   1.3706347E-02,   1.4985462E-02,   1.6206209E-02
     +,   1.7536666E-02,   1.9318528E-02,   2.1923155E-02
     +,   2.5490284E-02,   2.9740784E-02,   3.4107205E-02
     +,   3.8174640E-02,   4.1960370E-02,   4.5637727E-02
     +,   4.9218420E-02,   5.2687041E-02,   5.6047067E-02
     +,   5.9145164E-02,   6.1754514E-02,   6.3644126E-02
     +,   6.4541094E-02,   6.4913630E-02,   6.6033348E-02
     +,   6.7678966E-02,   6.7520738E-02,   6.4086393E-02
     +,   5.8729604E-02,   5.3653568E-02,   4.9264032E-02
     +,   4.4688493E-02,   3.9840989E-02,   3.5457723E-02
     +,   3.1747825E-02,   2.8285250E-02,   2.4819771E-02
     +,   2.1459730E-02,   1.8332353E-02,   1.5456651E-02
     +,   1.2848285E-02,   1.0565548E-02,   8.6522596E-03
     +,   7.0930226E-03,   5.8273659E-03,   4.7873617E-03
     +,   3.9206059E-03,   3.1930225E-03,   2.5827754E-03
     +,   2.0741823E-03,   1.6541509E-03,   1.3106797E-03
     +,   1.0324615E-03,   8.0896675E-04,   6.3081534E-04
     +,   4.8988877E-04,   3.7936078E-04,   2.9349662E-04
     +,   2.2749012E-04,   1.7727868E-04,   1.3945374E-04
     +,   1.1117827E-04,   9.0144829E-05,   7.4515592E-05
     +,   6.2866064E-05,   5.4119424E-05,   4.7477581E-05
     +,   4.2361407E-05,   3.8355003E-05,   3.5162946E-05
     +,   3.2575063E-05,   3.0441768E-05,   2.8655135E-05
     +,   2.7136635E-05,   2.5827881E-05,   2.4685081E-05
     +,   2.3674618E-05,   2.2770566E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt108 = Yx/0.399857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2132198E-05,   1.2397602E-05
     +,   1.2665485E-05,   1.2935999E-05,   1.3209325E-05
     +,   1.3485673E-05,   1.3765279E-05,   1.4048414E-05
     +,   1.4335383E-05,   1.4626532E-05,   1.4922233E-05
     +,   1.5222899E-05,   1.5528974E-05,   1.5840953E-05
     +,   1.6159354E-05,   1.6484739E-05,   1.6817707E-05
     +,   1.7158887E-05,   1.7508950E-05,   1.7868590E-05
     +,   1.8238532E-05,   1.8619532E-05,   1.9012356E-05
     +,   1.9417826E-05,   1.9836711E-05,   2.0269865E-05
     +,   2.0718078E-05,   2.1182188E-05,   2.1662987E-05
     +,   2.2161270E-05,   2.2677805E-05,   2.3213313E-05
     +,   2.3768496E-05,   2.4343983E-05,   2.4940351E-05
     +,   2.5558122E-05,   2.6197717E-05,   2.6859472E-05
     +,   2.7543683E-05,   2.8250441E-05,   2.8979823E-05
     +,   2.9731729E-05,   3.0505962E-05,   3.1302199E-05
     +,   3.2119948E-05,   3.2958622E-05,   3.3817487E-05
     +,   3.4695662E-05,   3.5592133E-05,   3.6505771E-05
     +,   3.7435322E-05,   3.8379389E-05,   3.9336501E-05
     +,   4.0305109E-05,   4.1283503E-05,   4.2270025E-05
     +,   4.3262891E-05,   4.4260323E-05,   4.5260549E-05
     +,   4.6261797E-05,   4.7262343E-05,   4.8260583E-05
     +,   4.9254919E-05,   5.0243965E-05,   5.1226489E-05
     +,   5.2201358E-05,   5.3167747E-05,   5.4124939E-05
     +,   5.5072607E-05,   5.6010584E-05,   5.6939080E-05
     +,   5.7858524E-05,   5.8769809E-05,   5.9673985E-05
     +,   6.0572551E-05,   6.1467334E-05,   6.2360472E-05
     +,   6.3254352E-05,   6.4151805E-05,   6.5055916E-05
     +,   6.5969922E-05,   6.6897475E-05,   6.7842273E-05
     +,   6.8808302E-05,   6.9799578E-05,   7.0820315E-05
     +,   7.1874609E-05,   7.2966686E-05,   7.4100572E-05
     +,   7.5280266E-05,   7.6509605E-05,   7.7792050E-05
     +,   7.9130841E-05,   8.0528916E-05,   8.1988830E-05
     +,   8.3512568E-05,   8.5101819E-05,   8.6757515E-05
     +,   8.8480272E-05,   9.0269881E-05,   9.2125723E-05
     +,   9.4046358E-05,   9.6029929E-05,   9.8073695E-05
     +,   1.0017445E-04,   1.0232838E-04,   1.0453090E-04
     +,   1.0677692E-04,   1.0906086E-04,   1.1137660E-04
     +,   1.1371749E-04,   1.1607660E-04,   1.1844637E-04
     +,   1.2081934E-04,   1.2318736E-04,   1.2554246E-04
     +,   1.2787626E-04,   1.3018069E-04,   1.3244723E-04
     +,   1.3466782E-04,   1.3683448E-04,   1.3893927E-04
     +,   1.4097466E-04,   1.4293341E-04,   1.4480873E-04
     +,   1.4659418E-04,   1.4828386E-04,   1.4987223E-04
     +,   1.5135463E-04,   1.5272667E-04,   1.5398479E-04
     +,   1.5512599E-04,   1.5614794E-04,   1.5704897E-04
     +,   1.5782815E-04,   1.5848520E-04,   1.5902046E-04
     +,   1.5943511E-04,   1.5973084E-04,   1.5991014E-04
     +,   1.5997603E-04,   1.5993221E-04,   1.5978306E-04
     +,   1.5953336E-04,   1.5918873E-04,   1.5875499E-04
     +,   1.5823873E-04,   1.5764689E-04,   1.5698693E-04
     +,   1.5626664E-04,   1.5549427E-04,   1.5467838E-04
     +,   1.5382789E-04,   1.5295199E-04,   1.5206012E-04
     +,   1.5116205E-04,   1.5026773E-04,   1.4938730E-04
     +,   1.4853118E-04,   1.4770991E-04,   1.4693449E-04
     +,   1.4621588E-04,   1.4556575E-04,   1.4499613E-04
     +,   1.4451965E-04,   1.4414980E-04,   1.4390124E-04
     +,   1.4379011E-04,   1.4383429E-04,   1.4405430E-04
     +,   1.4447364E-04,   1.4511951E-04,   1.4602400E-04
     +,   1.4722486E-04,   1.4876637E-04,   1.5070097E-04
     +,   1.5309005E-04,   1.5600535E-04,   1.5953001E-04
     +,   1.6375980E-04,   1.6880396E-04,   1.7478547E-04
     +,   1.8184117E-04,   1.9012265E-04,   1.9979465E-04
     +,   2.1103419E-04,   2.2402890E-04,   2.3897675E-04
     +,   2.5608367E-04,   2.7556060E-04,   2.9762549E-04
     +,   3.2250263E-04,   3.5042016E-04,   3.8161475E-04
     +,   4.1633449E-04,   4.5484098E-04,   4.9740908E-04
     +,   5.4432848E-04,   5.9590797E-04,   6.5247144E-04
     +,   7.1435032E-04,   7.8188733E-04,   8.5544336E-04
     +,   9.3540532E-04,   1.0221972E-03,   1.1163235E-03
     +,   1.2184009E-03,   1.3291847E-03,   1.4496086E-03
     +,   1.5808115E-03,   1.7241499E-03,   1.8812066E-03
     +,   2.0538706E-03,   2.2444967E-03,   2.4561663E-03
     +,   2.6930394E-03,   2.9606938E-03,   3.2661788E-03
     +,   3.6173642E-03,   4.0214057E-03,   4.4824681E-03
     +,   4.9993219E-03,   5.5639506E-03,   6.1623571E-03
     +,   6.7779617E-03,   7.3969355E-03,   8.0139237E-03
     +,   8.6360024E-03,   9.2827100E-03,   9.9807885E-03
     +,   1.0755401E-02,   1.1622041E-02,   1.2583220E-02
     +,   1.3630052E-02,   1.4746375E-02,   1.5915079E-02
     +,   1.7123284E-02,   1.8355295E-02,   1.9580709E-02
     +,   2.0805914E-02,   2.2230253E-02,   2.4310142E-02
     +,   2.7441708E-02,   3.1497184E-02,   3.5871185E-02
     +,   4.0008444E-02,   4.3728776E-02,   4.7170054E-02
     +,   5.0674736E-02,   5.4598738E-02,   5.8751404E-02
     +,   6.2256198E-02,   6.4325839E-02,   6.5918073E-02
     +,   6.8801574E-02,   7.1103007E-02,   6.9364093E-02
     +,   6.3743137E-02,   5.7166249E-02,   5.1970895E-02
     +,   4.8199974E-02,   4.4813737E-02,   4.1000731E-02
     +,   3.6380336E-02,   3.1150585E-02,   2.5804436E-02
     +,   2.0732891E-02,   1.6155820E-02,   1.2209496E-02
     +,   8.9934291E-03,   6.5362016E-03,   4.7599846E-03
     +,   3.5113490E-03,   2.6300973E-03,   1.9948115E-03
     +,   1.5279429E-03,   1.1812247E-03,   9.2223013E-04
     +,   7.2736869E-04,   5.7925336E-04,   4.6529062E-04
     +,   3.7656384E-04,   3.0675074E-04,   2.5131274E-04
     +,   2.0690160E-04,   1.7101332E-04,   1.4175558E-04
     +,   1.1770726E-04,   9.7809396E-05,   8.1268940E-05
     +,   6.7488814E-05,   5.6004497E-05,   4.6445501E-05
     +,   3.8504233E-05,   3.1921500E-05,   2.6474572E-05
     +,   2.1973248E-05,   1.8254754E-05,   1.5182031E-05
     +,   1.2640026E-05,   1.0533754E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt110 = Yx/0.375714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt111(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.4990080E-06,   7.8234325E-06
     +,   8.1598018E-06,   8.5083311E-06,   8.8692086E-06
     +,   9.2425926E-06,   9.6286067E-06,   1.0027339E-05
     +,   1.0438833E-05,   1.0863105E-05,   1.1300102E-05
     +,   1.1749736E-05,   1.2211855E-05,   1.2686263E-05
     +,   1.3172697E-05,   1.3670836E-05,   1.4180295E-05
     +,   1.4700624E-05,   1.5231312E-05,   1.5771780E-05
     +,   1.6321379E-05,   1.6879401E-05,   1.7445056E-05
     +,   1.8017532E-05,   1.8595887E-05,   1.9179186E-05
     +,   1.9766401E-05,   2.0356463E-05,   2.0948251E-05
     +,   2.1540600E-05,   2.2132315E-05,   2.2722150E-05
     +,   2.3308858E-05,   2.3891154E-05,   2.4467750E-05
     +,   2.5037347E-05,   2.5598665E-05,   2.6150410E-05
     +,   2.6691343E-05,   2.7220212E-05,   2.7735836E-05
     +,   2.8237062E-05,   2.8722790E-05,   2.9191984E-05
     +,   2.9643681E-05,   3.0076984E-05,   3.0491077E-05
     +,   3.0885247E-05,   3.1258853E-05,   3.1611376E-05
     +,   3.1942378E-05,   3.2251544E-05,   3.2538657E-05
     +,   3.2803622E-05,   3.3046446E-05,   3.3267264E-05
     +,   3.3466302E-05,   3.3643915E-05,   3.3800556E-05
     +,   3.3936787E-05,   3.4053282E-05,   3.4150802E-05
     +,   3.4230179E-05,   3.4292389E-05,   3.4338434E-05
     +,   3.4369430E-05,   3.4386514E-05,   3.4390938E-05
     +,   3.4383964E-05,   3.4366913E-05,   3.4341148E-05
     +,   3.4308043E-05,   3.4269007E-05,   3.4225453E-05
     +,   3.4178811E-05,   3.4130499E-05,   3.4081928E-05
     +,   3.4034503E-05,   3.3989585E-05,   3.3948549E-05
     +,   3.3912704E-05,   3.3883349E-05,   3.3861750E-05
     +,   3.3849115E-05,   3.3846645E-05,   3.3855493E-05
     +,   3.3876764E-05,   3.3911565E-05,   3.3960940E-05
     +,   3.4025936E-05,   3.4107579E-05,   3.4206885E-05
     +,   3.4324876E-05,   3.4462588E-05,   3.4621087E-05
     +,   3.4801451E-05,   3.5004843E-05,   3.5232475E-05
     +,   3.5485642E-05,   3.5765748E-05,   3.6074311E-05
     +,   3.6412966E-05,   3.6783542E-05,   3.7187983E-05
     +,   3.7628473E-05,   3.8107384E-05,   3.8627291E-05
     +,   3.9190996E-05,   3.9801551E-05,   4.0462281E-05
     +,   4.1176681E-05,   4.1948588E-05,   4.2781954E-05
     +,   4.3681084E-05,   4.4650351E-05,   4.5694407E-05
     +,   4.6817935E-05,   4.8025831E-05,   4.9322869E-05
     +,   5.0713916E-05,   5.2203759E-05,   5.3796924E-05
     +,   5.5497650E-05,   5.7309935E-05,   5.9237380E-05
     +,   6.1282772E-05,   6.3448577E-05,   6.5736203E-05
     +,   6.8146459E-05,   7.0678951E-05,   7.3332478E-05
     +,   7.6104414E-05,   7.8991245E-05,   8.1987811E-05
     +,   8.5087944E-05,   8.8284083E-05,   9.1567119E-05
     +,   9.4926625E-05,   9.8351025E-05,   1.0182751E-04
     +,   1.0534190E-04,   1.0887901E-04,   1.1242281E-04
     +,   1.1595664E-04,   1.1946282E-04,   1.2292374E-04
     +,   1.2632148E-04,   1.2963799E-04,   1.3285557E-04
     +,   1.3595716E-04,   1.3892655E-04,   1.4174840E-04
     +,   1.4440859E-04,   1.4689476E-04,   1.4919635E-04
     +,   1.5130457E-04,   1.5321290E-04,   1.5491740E-04
     +,   1.5641681E-04,   1.5771229E-04,   1.5880831E-04
     +,   1.5971232E-04,   1.6043500E-04,   1.6099027E-04
     +,   1.6139566E-04,   1.6167211E-04,   1.6184423E-04
     +,   1.6194007E-04,   1.6199163E-04,   1.6203415E-04
     +,   1.6210695E-04,   1.6225262E-04,   1.6251735E-04
     +,   1.6295076E-04,   1.6360577E-04,   1.6453824E-04
     +,   1.6580769E-04,   1.6747594E-04,   1.6960826E-04
     +,   1.7227301E-04,   1.7554256E-04,   1.7949329E-04
     +,   1.8420747E-04,   1.8977452E-04,   1.9629445E-04
     +,   2.0387930E-04,   2.1265769E-04,   2.2277996E-04
     +,   2.3442302E-04,   2.4779473E-04,   2.6314158E-04
     +,   2.8075548E-04,   3.0097747E-04,   3.2420579E-04
     +,   3.5090474E-04,   3.8161001E-04,   4.1693213E-04
     +,   4.5756286E-04,   5.0427607E-04,   5.5791810E-04
     +,   6.1938213E-04,   6.8957213E-04,   7.6934946E-04
     +,   8.5945294E-04,   9.6039922E-04,   1.0724115E-03
     +,   1.1953457E-03,   1.3286538E-03,   1.4714301E-03
     +,   1.6225312E-03,   1.7807364E-03,   1.9449496E-03
     +,   2.1143956E-03,   2.2887732E-03,   2.4682619E-03
     +,   2.6534512E-03,   2.8452321E-03,   3.0447186E-03
     +,   3.2532702E-03,   3.4725962E-03,   3.7049239E-03
     +,   3.9529013E-03,   4.2191590E-03,   4.5055286E-03
     +,   4.8123617E-03,   5.1385118E-03,   5.4827924E-03
     +,   5.8473116E-03,   6.2420415E-03,   6.6887699E-03
     +,   7.2209719E-03,   7.8762015E-03,   8.6798761E-03
     +,   9.6256472E-03,   1.0664574E-02,   1.1716273E-02
     +,   1.2703035E-02,   1.3593097E-02,   1.4435587E-02
     +,   1.5379633E-02,   1.6670182E-02,   1.8577408E-02
     +,   2.1202132E-02,   2.4250338E-02,   2.7118098E-02
     +,   2.9431915E-02,   3.1439815E-02,   3.3642646E-02
     +,   3.6314573E-02,   3.9813388E-02,   4.4695277E-02
     +,   5.0470382E-02,   5.5360712E-02,   5.8684554E-02
     +,   6.1665401E-02,   6.5120220E-02,   6.8653807E-02
     +,   7.1873032E-02,   7.4211232E-02,   7.3711075E-02
     +,   6.8870604E-02,   6.1741423E-02,   5.5210013E-02
     +,   4.9924910E-02,   4.5099884E-02,   3.9803047E-02
     +,   3.3765323E-02,   2.7397910E-02,   2.1261025E-02
     +,   1.5863001E-02,   1.1529345E-02,   8.2773995E-03
     +,   5.9270300E-03,   4.2640292E-03,   3.1053547E-03
     +,   2.3053044E-03,   1.7507594E-03,   1.3582458E-03
     +,   1.0704657E-03,   8.5107941E-04,   6.7833526E-04
     +,   5.3962885E-04,   4.2749129E-04,   3.3710295E-04
     +,   2.6483907E-04,   2.0762540E-04,   1.6270333E-04
     +,   1.2762770E-04,   1.0030702E-04,   7.9014571E-05
     +,   6.2377047E-05,   4.9324914E-05,   3.9042094E-05
     +,   3.0908370E-05,   2.4455157E-05,   1.9325102E-05
     +,   1.5244372E-05,   1.1999588E-05,   9.4231737E-06
     +,   7.3813985E-06,   5.7672087E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt111 = Yx/0.369
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5153769E-05,   2.5802483E-05
     +,   2.6457097E-05,   2.7117103E-05,   2.7781978E-05
     +,   2.8451181E-05,   2.9124141E-05,   2.9800280E-05
     +,   3.0478981E-05,   3.1159663E-05,   3.1841690E-05
     +,   3.2524422E-05,   3.3207212E-05,   3.3889417E-05
     +,   3.4570370E-05,   3.5249410E-05,   3.5925881E-05
     +,   3.6599107E-05,   3.7268430E-05,   3.7933180E-05
     +,   3.8592720E-05,   3.9246392E-05,   3.9893548E-05
     +,   4.0533585E-05,   4.1165851E-05,   4.1789768E-05
     +,   4.2404743E-05,   4.3010208E-05,   4.3605600E-05
     +,   4.4190394E-05,   4.4764074E-05,   4.5326149E-05
     +,   4.5876153E-05,   4.6413636E-05,   4.6938199E-05
     +,   4.7449423E-05,   4.7946964E-05,   4.8430469E-05
     +,   4.8899659E-05,   4.9354232E-05,   4.9793958E-05
     +,   5.0218598E-05,   5.0628005E-05,   5.1021998E-05
     +,   5.1400493E-05,   5.1763389E-05,   5.2110667E-05
     +,   5.2442298E-05,   5.2758314E-05,   5.3058815E-05
     +,   5.3343902E-05,   5.3613716E-05,   5.3868454E-05
     +,   5.4108394E-05,   5.4333792E-05,   5.4544973E-05
     +,   5.4742351E-05,   5.4926335E-05,   5.5097415E-05
     +,   5.5256125E-05,   5.5403052E-05,   5.5538847E-05
     +,   5.5664190E-05,   5.5779838E-05,   5.5886616E-05
     +,   5.5985372E-05,   5.6077057E-05,   5.6162622E-05
     +,   5.6243156E-05,   5.6319699E-05,   5.6393459E-05
     +,   5.6465618E-05,   5.6537450E-05,   5.6610268E-05
     +,   5.6685429E-05,   5.6764366E-05,   5.6848497E-05
     +,   5.6939327E-05,   5.7038378E-05,   5.7147183E-05
     +,   5.7267313E-05,   5.7400353E-05,   5.7547888E-05
     +,   5.7711506E-05,   5.7892776E-05,   5.8093261E-05
     +,   5.8314483E-05,   5.8557940E-05,   5.8825048E-05
     +,   5.9117225E-05,   5.9435759E-05,   5.9781909E-05
     +,   6.0156763E-05,   6.0561419E-05,   6.0996772E-05
     +,   6.1463601E-05,   6.1962615E-05,   6.2494291E-05
     +,   6.3059029E-05,   6.3657004E-05,   6.4288281E-05
     +,   6.4952670E-05,   6.5649911E-05,   6.6379405E-05
     +,   6.7140514E-05,   6.7932349E-05,   6.8753790E-05
     +,   6.9603542E-05,   7.0480157E-05,   7.1382019E-05
     +,   7.2307201E-05,   7.3253803E-05,   7.4219563E-05
     +,   7.5202239E-05,   7.6199300E-05,   7.7208206E-05
     +,   7.8226229E-05,   7.9250603E-05,   8.0278398E-05
     +,   8.1306716E-05,   8.2332619E-05,   8.3353072E-05
     +,   8.4365049E-05,   8.5365587E-05,   8.6351822E-05
     +,   8.7320775E-05,   8.8269742E-05,   8.9196001E-05
     +,   9.0097041E-05,   9.0970389E-05,   9.1813905E-05
     +,   9.2625429E-05,   9.3403221E-05,   9.4145536E-05
     +,   9.4851122E-05,   9.5518815E-05,   9.6147764E-05
     +,   9.6737414E-05,   9.7287571E-05,   9.7798373E-05
     +,   9.8270248E-05,   9.8704018E-05,   9.9101002E-05
     +,   9.9462872E-05,   9.9791723E-05,   1.0009024E-04
     +,   1.0036170E-04,   1.0060982E-04,   1.0083905E-04
     +,   1.0105456E-04,   1.0126233E-04,   1.0146914E-04
     +,   1.0168281E-04,   1.0191214E-04,   1.0216715E-04
     +,   1.0245907E-04,   1.0280058E-04,   1.0320581E-04
     +,   1.0369059E-04,   1.0427235E-04,   1.0497042E-04
     +,   1.0580607E-04,   1.0680254E-04,   1.0798499E-04
     +,   1.0938076E-04,   1.1101930E-04,   1.1293196E-04
     +,   1.1515213E-04,   1.1771539E-04,   1.2065939E-04
     +,   1.2402383E-04,   1.2785061E-04,   1.3218446E-04
     +,   1.3707338E-04,   1.4256877E-04,   1.4872721E-04
     +,   1.5561143E-04,   1.6329132E-04,   1.7184601E-04
     +,   1.8136662E-04,   1.9195776E-04,   2.0373901E-04
     +,   2.1684710E-04,   2.3143794E-04,   2.4768707E-04
     +,   2.6578779E-04,   2.8594973E-04,   3.0839854E-04
     +,   3.3336936E-04,   3.6109981E-04,   3.9182737E-04
     +,   4.2578194E-04,   4.6317524E-04,   5.0419732E-04
     +,   5.4901507E-04,   5.9776515E-04,   6.5054942E-04
     +,   7.0743432E-04,   7.6845370E-04,   8.3360082E-04
     +,   9.0281665E-04,   9.7598450E-04,   1.0529211E-03
     +,   1.1333582E-03,   1.2169272E-03,   1.3031777E-03
     +,   1.3915980E-03,   1.4816746E-03,   1.5730170E-03
     +,   1.6655358E-03,   1.7596736E-03,   1.8566742E-03
     +,   1.9588661E-03,   2.0698761E-03,   2.1946884E-03
     +,   2.3394558E-03,   2.5110343E-03,   2.7162295E-03
     +,   2.9608486E-03,   3.2487311E-03,   3.5810992E-03
     +,   3.9562681E-03,   4.3697720E-03,   4.8148548E-03
     +,   5.2830330E-03,   5.7645664E-03,   6.2490217E-03
     +,   6.7264000E-03,   7.1892622E-03,   7.6357853E-03
     +,   8.0730133E-03,   8.5185859E-03,   8.9981444E-03
     +,   9.5369406E-03,   1.0147113E-02,   1.0817877E-02
     +,   1.1517828E-02,   1.2215876E-02,   1.2916557E-02
     +,   1.3692834E-02,   1.4688039E-02,   1.6060786E-02
     +,   1.7879685E-02,   2.0038040E-02,   2.2274710E-02
     +,   2.4295598E-02,   2.5909692E-02,   2.7149428E-02
     +,   2.8370431E-02,   3.0193865E-02,   3.3189129E-02
     +,   3.7529044E-02,   4.2949114E-02,   4.8862416E-02
     +,   5.4219659E-02,   5.7751976E-02,   5.9450947E-02
     +,   6.1073080E-02,   6.3637882E-02,   6.5909259E-02
     +,   6.6413805E-02,   6.5152876E-02,   6.3033015E-02
     +,   6.0280446E-02,   5.6115676E-02,   5.0131004E-02
     +,   4.2954750E-02,   3.5522941E-02,   2.8443342E-02
     +,   2.2147879E-02,   1.7034432E-02,   1.3220926E-02
     +,   1.0459045E-02,   8.3772521E-03,   6.7067556E-03
     +,   5.3179185E-03,   4.1608466E-03,   3.2130810E-03
     +,   2.4550513E-03,   1.8634392E-03,   1.4113858E-03
     +,   1.0713446E-03,   8.1765791E-04,   6.2843860E-04
     +,   4.8627675E-04,   3.7820908E-04,   2.9502268E-04
     +,   2.3036639E-04,   1.7986716E-04,   1.4041786E-04
     +,   1.0971292E-04,   8.5948202E-05,   6.7668596E-05
     +,   5.3677046E-05,   4.2994121E-05,   3.4826044E-05
     +,   2.8544737E-05,   2.3663271E-05,   1.9814766E-05
     +,   1.6728291E-05,   1.4208663E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt112 = Yx/0.359571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt1128(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7207880E-05,   1.7987335E-05
     +,   1.8785811E-05,   1.9602694E-05,   2.0437312E-05
     +,   2.1288926E-05,   2.2156721E-05,   2.3039833E-05
     +,   2.3937300E-05,   2.4848177E-05,   2.5771393E-05
     +,   2.6705844E-05,   2.7650400E-05,   2.8603870E-05
     +,   2.9565042E-05,   3.0532650E-05,   3.1505442E-05
     +,   3.2482112E-05,   3.3461365E-05,   3.4441906E-05
     +,   3.5422439E-05,   3.6401663E-05,   3.7378315E-05
     +,   3.8351187E-05,   3.9319017E-05,   4.0280695E-05
     +,   4.1235082E-05,   4.2181113E-05,   4.3117820E-05
     +,   4.4044245E-05,   4.4959557E-05,   4.5862984E-05
     +,   4.6753838E-05,   4.7631511E-05,   4.8495545E-05
     +,   4.9345519E-05,   5.0181141E-05,   5.1002222E-05
     +,   5.1808707E-05,   5.2600579E-05,   5.3378033E-05
     +,   5.4141281E-05,   5.4890716E-05,   5.5626831E-05
     +,   5.6350182E-05,   5.7061472E-05,   5.7761539E-05
     +,   5.8451311E-05,   5.9131795E-05,   5.9804159E-05
     +,   6.0469643E-05,   6.1129605E-05,   6.1785497E-05
     +,   6.2438907E-05,   6.3091480E-05,   6.3745021E-05
     +,   6.4401349E-05,   6.5062508E-05,   6.5730543E-05
     +,   6.6407658E-05,   6.7096131E-05,   6.7798355E-05
     +,   6.8516834E-05,   6.9254093E-05,   7.0012953E-05
     +,   7.0796086E-05,   7.1606461E-05,   7.2446986E-05
     +,   7.3320800E-05,   7.4230935E-05,   7.5180717E-05
     +,   7.6173332E-05,   7.7212164E-05,   7.8300494E-05
     +,   7.9441728E-05,   8.0639285E-05,   8.1896440E-05
     +,   8.3216481E-05,   8.4602660E-05,   8.6058120E-05
     +,   8.7585788E-05,   8.9188587E-05,   9.0869042E-05
     +,   9.2629627E-05,   9.4472365E-05,   9.6399148E-05
     +,   9.8411336E-05,   1.0051008E-04,   1.0269591E-04
     +,   1.0496902E-04,   1.0732915E-04,   1.0977535E-04
     +,   1.1230606E-04,   1.1491935E-04,   1.1761257E-04
     +,   1.2038223E-04,   1.2322454E-04,   1.2613458E-04
     +,   1.2910725E-04,   1.3213627E-04,   1.3521516E-04
     +,   1.3833628E-04,   1.4149184E-04,   1.4467296E-04
     +,   1.4787047E-04,   1.5107465E-04,   1.5427505E-04
     +,   1.5746079E-04,   1.6062077E-04,   1.6374349E-04
     +,   1.6681693E-04,   1.6982920E-04,   1.7276798E-04
     +,   1.7562113E-04,   1.7837629E-04,   1.8102149E-04
     +,   1.8354469E-04,   1.8593445E-04,   1.8817943E-04
     +,   1.9026898E-04,   1.9219288E-04,   1.9394177E-04
     +,   1.9550671E-04,   1.9687993E-04,   1.9805448E-04
     +,   1.9902422E-04,   1.9978442E-04,   2.0033123E-04
     +,   2.0066201E-04,   2.0077545E-04,   2.0067154E-04
     +,   2.0035144E-04,   1.9981767E-04,   1.9907423E-04
     +,   1.9812614E-04,   1.9698002E-04,   1.9564363E-04
     +,   1.9412593E-04,   1.9243715E-04,   1.9058837E-04
     +,   1.8859193E-04,   1.8646120E-04,   1.8421009E-04
     +,   1.8185338E-04,   1.7940659E-04,   1.7688566E-04
     +,   1.7430684E-04,   1.7168696E-04,   1.6904305E-04
     +,   1.6639213E-04,   1.6375128E-04,   1.6113785E-04
     +,   1.5856919E-04,   1.5606250E-04,   1.5363499E-04
     +,   1.5130428E-04,   1.4908807E-04,   1.4700441E-04
     +,   1.4507181E-04,   1.4330984E-04,   1.4173891E-04
     +,   1.4038093E-04,   1.3925953E-04,   1.3840059E-04
     +,   1.3783245E-04,   1.3758663E-04,   1.3769828E-04
     +,   1.3820664E-04,   1.3915561E-04,   1.4059449E-04
     +,   1.4257815E-04,   1.4516771E-04,   1.4843119E-04
     +,   1.5244404E-04,   1.5728868E-04,   1.6305601E-04
     +,   1.6984501E-04,   1.7776230E-04,   1.8692248E-04
     +,   1.9744830E-04,   2.0946977E-04,   2.2312214E-04
     +,   2.3854562E-04,   2.5588440E-04,   2.7528370E-04
     +,   2.9688570E-04,   3.2082741E-04,   3.4723728E-04
     +,   3.7623066E-04,   4.0790107E-04,   4.4232071E-04
     +,   4.7953438E-04,   5.1955116E-04,   5.6234607E-04
     +,   6.0786214E-04,   6.5601181E-04,   7.0668245E-04
     +,   7.5974938E-04,   8.1510202E-04,   8.7266444E-04
     +,   9.3242619E-04,   9.9448825E-04,   1.0591223E-03
     +,   1.1268309E-03,   1.1984146E-03,   1.2750636E-03
     +,   1.3584149E-03,   1.4505931E-03,   1.5541931E-03
     +,   1.6721728E-03,   1.8076266E-03,   1.9633975E-03
     +,   2.1416051E-03,   2.3431061E-03,   2.5670216E-03
     +,   2.8104573E-03,   3.0687002E-03,   3.3359749E-03
     +,   3.6067565E-03,   3.8774672E-03,   4.1482244E-03
     +,   4.4238358E-03,   4.7134231E-03,   5.0283433E-03
     +,   5.3784898E-03,   5.7679485E-03,   6.1916769E-03
     +,   6.6352794E-03,   7.0791775E-03,   7.5070760E-03
     +,   7.9159839E-03,   8.3234720E-03,   8.7669790E-03
     +,   9.2932172E-03,   9.9403486E-03,   1.0720273E-02
     +,   1.1610024E-02,   1.2558795E-02,   1.3511813E-02
     +,   1.4442753E-02,   1.5378215E-02,   1.6397594E-02
     +,   1.7606305E-02,   1.9098556E-02,   2.0917894E-02
     +,   2.3002001E-02,   2.5142845E-02,   2.7086997E-02
     +,   2.8801169E-02,   3.0591121E-02,   3.2753576E-02
     +,   3.5139889E-02,   3.7390057E-02,   3.9673857E-02
     +,   4.2823397E-02,   4.7355257E-02,   5.2387897E-02
     +,   5.6109145E-02,   5.7733446E-02,   5.8147538E-02
     +,   5.8053341E-02,   5.7104006E-02,   5.5355702E-02
     +,   5.3604364E-02,   5.2003630E-02,   4.9591184E-02
     +,   4.5395818E-02,   3.9482065E-02,   3.2789327E-02
     +,   2.6353305E-02,   2.0815970E-02,   1.6364856E-02
     +,   1.2878549E-02,   1.0120564E-02,   7.8823389E-03
     +,   6.0334248E-03,   4.5094849E-03,   3.2830043E-03
     +,   2.3346287E-03,   1.6356396E-03,   1.1439355E-03
     +,   8.1087044E-04,   5.9032458E-04,   4.4485184E-04
     +,   3.4727994E-04,   2.7951805E-04,   2.3023256E-04
     +,   1.9263770E-04,   1.6277819E-04,   1.3835169E-04
     +,   1.1798914E-04,   1.0082888E-04,   8.6294291E-05
     +,   7.3969110E-05,   6.3536558E-05,   5.4739165E-05
     +,   4.7359525E-05,   4.1204657E-05,   3.6100737E-05
     +,   3.1888161E-05,   2.8422191E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt1128 = Yx/0.344895833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3849998E-05,   2.4314166E-05
     +,   2.4771824E-05,   2.5222460E-05,   2.5665568E-05
     +,   2.6100688E-05,   2.6527388E-05,   2.6945261E-05
     +,   2.7353932E-05,   2.7753091E-05,   2.8142438E-05
     +,   2.8521727E-05,   2.8890763E-05,   2.9249382E-05
     +,   2.9597479E-05,   2.9935005E-05,   3.0261954E-05
     +,   3.0578361E-05,   3.0884341E-05,   3.1180050E-05
     +,   3.1465694E-05,   3.1741554E-05,   3.2007938E-05
     +,   3.2265260E-05,   3.2513944E-05,   3.2754499E-05
     +,   3.2987486E-05,   3.3213521E-05,   3.3433302E-05
     +,   3.3647539E-05,   3.3857039E-05,   3.4062650E-05
     +,   3.4265282E-05,   3.4465884E-05,   3.4665492E-05
     +,   3.4865145E-05,   3.5065979E-05,   3.5269153E-05
     +,   3.5475892E-05,   3.5687437E-05,   3.5905101E-05
     +,   3.6130237E-05,   3.6364214E-05,   3.6608464E-05
     +,   3.6864429E-05,   3.7133592E-05,   3.7417467E-05
     +,   3.7717571E-05,   3.8035469E-05,   3.8372727E-05
     +,   3.8730923E-05,   3.9111615E-05,   3.9516410E-05
     +,   3.9946892E-05,   4.0404590E-05,   4.0891093E-05
     +,   4.1407922E-05,   4.1956562E-05,   4.2538490E-05
     +,   4.3155127E-05,   4.3807839E-05,   4.4497941E-05
     +,   4.5226661E-05,   4.5995184E-05,   4.6804635E-05
     +,   4.7655951E-05,   4.8550100E-05,   4.9487800E-05
     +,   5.0469815E-05,   5.1496612E-05,   5.2568717E-05
     +,   5.3686341E-05,   5.4849654E-05,   5.6058612E-05
     +,   5.7313100E-05,   5.8612779E-05,   5.9957158E-05
     +,   6.1345476E-05,   6.2776940E-05,   6.4250591E-05
     +,   6.5765103E-05,   6.7319190E-05,   6.8911169E-05
     +,   7.0539376E-05,   7.2201830E-05,   7.3896539E-05
     +,   7.5621079E-05,   7.7373181E-05,   7.9150137E-05
     +,   8.0949314E-05,   8.2767903E-05,   8.4602914E-05
     +,   8.6451160E-05,   8.8309542E-05,   9.0174930E-05
     +,   9.2043832E-05,   9.3913040E-05,   9.5779062E-05
     +,   9.7638607E-05,   9.9488148E-05,   1.0132453E-04
     +,   1.0314422E-04,   1.0494419E-04,   1.0672113E-04
     +,   1.0847210E-04,   1.1019422E-04,   1.1188468E-04
     +,   1.1354088E-04,   1.1516051E-04,   1.1674136E-04
     +,   1.1828154E-04,   1.1977934E-04,   1.2123327E-04
     +,   1.2264235E-04,   1.2400564E-04,   1.2532274E-04
     +,   1.2659337E-04,   1.2781778E-04,   1.2899643E-04
     +,   1.3013025E-04,   1.3122057E-04,   1.3226896E-04
     +,   1.3327741E-04,   1.3424843E-04,   1.3518475E-04
     +,   1.3608951E-04,   1.3696622E-04,   1.3781882E-04
     +,   1.3865154E-04,   1.3946884E-04,   1.4027563E-04
     +,   1.4107702E-04,   1.4187836E-04,   1.4268524E-04
     +,   1.4350341E-04,   1.4433876E-04,   1.4519726E-04
     +,   1.4608493E-04,   1.4700780E-04,   1.4797183E-04
     +,   1.4898292E-04,   1.5004662E-04,   1.5116851E-04
     +,   1.5235385E-04,   1.5360746E-04,   1.5493395E-04
     +,   1.5633758E-04,   1.5782208E-04,   1.5939077E-04
     +,   1.6104670E-04,   1.6279246E-04,   1.6463007E-04
     +,   1.6656131E-04,   1.6858787E-04,   1.7071102E-04
     +,   1.7293198E-04,   1.7525186E-04,   1.7767207E-04
     +,   1.8019440E-04,   1.8282083E-04,   1.8555431E-04
     +,   1.8839863E-04,   1.9135863E-04,   1.9444041E-04
     +,   1.9765210E-04,   2.0100357E-04,   2.0450694E-04
     +,   2.0817660E-04,   2.1203024E-04,   2.1608855E-04
     +,   2.2037559E-04,   2.2491915E-04,   2.2975169E-04
     +,   2.3491048E-04,   2.4043764E-04,   2.4638153E-04
     +,   2.5279800E-04,   2.5975046E-04,   2.6731248E-04
     +,   2.7556979E-04,   2.8462376E-04,   2.9459412E-04
     +,   3.0562410E-04,   3.1788743E-04,   3.3159539E-04
     +,   3.4700378E-04,   3.6442294E-04,   3.8422877E-04
     +,   4.0687071E-04,   4.3287719E-04,   4.6286450E-04
     +,   4.9753499E-04,   5.3766777E-04,   5.8410567E-04
     +,   6.3773623E-04,   6.9945480E-04,   7.7011809E-04
     +,   8.5049361E-04,   9.4120554E-04,   1.0426654E-03
     +,   1.1549949E-03,   1.2779606E-03,   1.4109232E-03
     +,   1.5527868E-03,   1.7019681E-03,   1.8564665E-03
     +,   2.0139690E-03,   2.1720678E-03,   2.3286194E-03
     +,   2.4822245E-03,   2.6327854E-03,   2.7820528E-03
     +,   2.9340817E-03,   3.0953896E-03,   3.2746880E-03
     +,   3.4820696E-03,   3.7277376E-03,   4.0203887E-03
     +,   4.3654740E-03,   4.7637364E-03,   5.2104457E-03
     +,   5.6953616E-03,   6.2035611E-03,   6.7170565E-03
     +,   7.2169392E-03,   7.6859170E-03,   8.1112459E-03
     +,   8.4881578E-03,   8.8227103E-03,   9.1324616E-03
     +,   9.4434973E-03,   9.7840419E-03,   1.0178120E-02
     +,   1.0643909E-02,   1.1198639E-02,   1.1864709E-02
     +,   1.2666214E-02,   1.3611368E-02,   1.4671591E-02
     +,   1.5781999E-02,   1.6876606E-02,   1.7935848E-02
     +,   1.8999482E-02,   2.0130897E-02,   2.1377932E-02
     +,   2.2771165E-02,   2.4325224E-02,   2.5996109E-02
     +,   2.7660651E-02,   2.9215591E-02,   3.0710472E-02
     +,   3.2303527E-02,   3.4068216E-02,   3.5929531E-02
     +,   3.7817888E-02,   3.9795272E-02,   4.1948352E-02
     +,   4.4141024E-02,   4.5931928E-02,   4.7001660E-02
     +,   4.7676958E-02,   4.8357431E-02,   4.8434515E-02
     +,   4.6841957E-02,   4.3520235E-02,   3.9338179E-02
     +,   3.4960419E-02,   3.0489679E-02,   2.5883898E-02
     +,   2.1288740E-02,   1.7015662E-02,   1.3351274E-02
     +,   1.0416647E-02,   8.1591811E-03,   6.4333691E-03
     +,   5.0888774E-03,   4.0162038E-03,   3.1495502E-03
     +,   2.4498643E-03,   1.8900594E-03,   1.4476633E-03
     +,   1.1028619E-03,   8.3790487E-04,   6.3702033E-04
     +,   4.8633126E-04,   3.7403393E-04,   2.9046307E-04
     +,   2.2804881E-04,   1.8108048E-04,   1.4535328E-04
     +,   1.1783041E-04,   9.6329328E-05,   7.9292557E-05
     +,   6.5606502E-05,   5.4478172E-05,   4.5338118E-05
     +,   3.7775088E-05,   3.1484531E-05,   2.6236396E-05
     +,   2.1850336E-05,   1.8182312E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt114 = Yx/0.316166666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0658959E-06,   9.3000335E-06
     +,   9.5379473E-06,   9.7796737E-06,   1.0025260E-05
     +,   1.0274753E-05,   1.0528202E-05,   1.0785662E-05
     +,   1.1047194E-05,   1.1312869E-05,   1.1582752E-05
     +,   1.1856924E-05,   1.2135461E-05,   1.2418453E-05
     +,   1.2705994E-05,   1.2998181E-05,   1.3295123E-05
     +,   1.3596927E-05,   1.3903712E-05,   1.4215601E-05
     +,   1.4532728E-05,   1.4855224E-05,   1.5183229E-05
     +,   1.5516905E-05,   1.5856387E-05,   1.6201851E-05
     +,   1.6553453E-05,   1.6911366E-05,   1.7275765E-05
     +,   1.7646831E-05,   1.8024744E-05,   1.8409703E-05
     +,   1.8801888E-05,   1.9201494E-05,   1.9608731E-05
     +,   2.0023788E-05,   2.0446872E-05,   2.0878184E-05
     +,   2.1317943E-05,   2.1766324E-05,   2.2223565E-05
     +,   2.2689859E-05,   2.3165412E-05,   2.3650431E-05
     +,   2.4145127E-05,   2.4649689E-05,   2.5164340E-05
     +,   2.5689265E-05,   2.6224674E-05,   2.6770769E-05
     +,   2.7327744E-05,   2.7895803E-05,   2.8475137E-05
     +,   2.9065975E-05,   2.9668481E-05,   3.0282892E-05
     +,   3.0909403E-05,   3.1548236E-05,   3.2199612E-05
     +,   3.2863747E-05,   3.3540884E-05,   3.4231274E-05
     +,   3.4935147E-05,   3.5652807E-05,   3.6384547E-05
     +,   3.7130623E-05,   3.7891416E-05,   3.8667229E-05
     +,   3.9458468E-05,   4.0265466E-05,   4.1088715E-05
     +,   4.1928601E-05,   4.2785650E-05,   4.3660340E-05
     +,   4.4553221E-05,   4.5464927E-05,   4.6396039E-05
     +,   4.7347163E-05,   4.8319049E-05,   4.9312468E-05
     +,   5.0328123E-05,   5.1366915E-05,   5.2429619E-05
     +,   5.3517222E-05,   5.4630615E-05,   5.5770892E-05
     +,   5.6938985E-05,   5.8136116E-05,   5.9363301E-05
     +,   6.0621827E-05,   6.1912957E-05,   6.3238018E-05
     +,   6.4598295E-05,   6.5995278E-05,   6.7430570E-05
     +,   6.8905625E-05,   7.0422211E-05,   7.1982016E-05
     +,   7.3586954E-05,   7.5238859E-05,   7.6939905E-05
     +,   7.8692130E-05,   8.0497892E-05,   8.2359453E-05
     +,   8.4279367E-05,   8.6260312E-05,   8.8304914E-05
     +,   9.0415924E-05,   9.2596303E-05,   9.4849114E-05
     +,   9.7177224E-05,   9.9583878E-05,   1.0207193E-04
     +,   1.0464458E-04,   1.0730456E-04,   1.1005489E-04
     +,   1.1289794E-04,   1.1583627E-04,   1.1887167E-04
     +,   1.2200584E-04,   1.2524007E-04,   1.2857473E-04
     +,   1.3200966E-04,   1.3554418E-04,   1.3917674E-04
     +,   1.4290449E-04,   1.4672415E-04,   1.5063095E-04
     +,   1.5461940E-04,   1.5868229E-04,   1.6281198E-04
     +,   1.6699880E-04,   1.7123250E-04,   1.7550113E-04
     +,   1.7979188E-04,   1.8409091E-04,   1.8838300E-04
     +,   1.9265193E-04,   1.9688120E-04,   2.0105338E-04
     +,   2.0515034E-04,   2.0915378E-04,   2.1304535E-04
     +,   2.1680693E-04,   2.2042044E-04,   2.2386861E-04
     +,   2.2713501E-04,   2.3020431E-04,   2.3306224E-04
     +,   2.3569654E-04,   2.3809665E-04,   2.4025406E-04
     +,   2.4216239E-04,   2.4381817E-04,   2.4522035E-04
     +,   2.4637082E-04,   2.4727455E-04,   2.4793993E-04
     +,   2.4837832E-04,   2.4860466E-04,   2.4863778E-04
     +,   2.4850000E-04,   2.4821775E-04,   2.4782150E-04
     +,   2.4734638E-04,   2.4683203E-04,   2.4632382E-04
     +,   2.4587262E-04,   2.4553627E-04,   2.4538016E-04
     +,   2.4547891E-04,   2.4591706E-04,   2.4679149E-04
     +,   2.4821321E-04,   2.5030956E-04,   2.5322687E-04
     +,   2.5713356E-04,   2.6222307E-04,   2.6871625E-04
     +,   2.7686617E-04,   2.8695972E-04,   2.9931945E-04
     +,   3.1430498E-04,   3.3231298E-04,   3.5377339E-04
     +,   3.7914139E-04,   4.0888650E-04,   4.4347835E-04
     +,   4.8336401E-04,   5.2893406E-04,   5.8049825E-04
     +,   6.3824374E-04,   7.0219283E-04,   7.7217130E-04
     +,   8.4778504E-04,   9.2840649E-04,   1.0131742E-03
     +,   1.1010360E-03,   1.1908187E-03,   1.2813205E-03
     +,   1.3714331E-03,   1.4603002E-03,   1.5474850E-03
     +,   1.6331376E-03,   1.7181382E-03,   1.8042396E-03
     +,   1.8941395E-03,   1.9914696E-03,   2.1007026E-03
     +,   2.2269108E-03,   2.3753296E-03,   2.5507435E-03
     +,   2.7566887E-03,   2.9945890E-03,   3.2629450E-03
     +,   3.5567821E-03,   3.8676830E-03,   4.1846116E-03
     +,   4.4955374E-03,   4.7898474E-03,   5.0612944E-03
     +,   5.3106109E-03,   5.5471105E-03,   5.7883691E-03
     +,   6.0573737E-03,   6.3773072E-03,   6.7652096E-03
     +,   7.2267181E-03,   7.7543077E-03,   8.3303303E-03
     +,   8.9338385E-03,   9.5481882E-03,   1.0165110E-02
     +,   1.0783201E-02,   1.1402204E-02,   1.2018029E-02
     +,   1.2623029E-02,   1.3214569E-02,   1.3809792E-02
     +,   1.4458873E-02,   1.5244304E-02,   1.6256094E-02
     +,   1.7546102E-02,   1.9083783E-02,   2.0751718E-02
     +,   2.2410655E-02,   2.3996944E-02,   2.5548149E-02
     +,   2.7118888E-02,   2.8698722E-02,   3.0241948E-02
     +,   3.1763669E-02,   3.3354189E-02,   3.5020571E-02
     +,   3.6585011E-02,   3.7956797E-02,   3.9361406E-02
     +,   4.0899124E-02,   4.2052157E-02,   4.2071823E-02
     +,   4.0771879E-02,   3.8732216E-02,   3.6732223E-02
     +,   3.5045519E-02,   3.3397727E-02,   3.1483088E-02
     +,   2.9185213E-02,   2.6415901E-02,   2.3122482E-02
     +,   1.9462999E-02,   1.5804408E-02,   1.2525053E-02
     +,   9.8391948E-03,   7.7660005E-03,   6.2023504E-03
     +,   5.0104824E-03,   4.0728417E-03,   3.3111363E-03
     +,   2.6814654E-03,   2.1607289E-03,   1.7338804E-03
     +,   1.3872636E-03,   1.1070331E-03,   8.8032772E-04
     +,   6.9641648E-04,   5.4710684E-04,   4.2629498E-04
     +,   3.2930035E-04,   2.5228097E-04,   1.9186214E-04
     +,   1.4502372E-04,   1.0907445E-04,   8.1697683E-05
     +,   6.0960592E-05,   4.5310109E-05,   3.3528046E-05
     +,   2.4680236E-05,   1.8055591E-05,   1.3116297E-05
     +,   9.4533771E-06,   6.7554829E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt115 = Yx/0.289978723404255
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0900436E-06,   8.2291917E-06
     +,   8.3698442E-06,   8.5120373E-06,   8.6558102E-06
     +,   8.8012066E-06,   8.9482683E-06,   9.0970416E-06
     +,   9.2475748E-06,   9.3999197E-06,   9.5541318E-06
     +,   9.7102666E-06,   9.8683850E-06,   1.0028547E-05
     +,   1.0190824E-05,   1.0355286E-05,   1.0522010E-05
     +,   1.0691077E-05,   1.0862579E-05,   1.1036605E-05
     +,   1.1213254E-05,   1.1392636E-05,   1.1574866E-05
     +,   1.1760078E-05,   1.1948393E-05,   1.2139969E-05
     +,   1.2334956E-05,   1.2533528E-05,   1.2735869E-05
     +,   1.2942173E-05,   1.3152665E-05,   1.3367564E-05
     +,   1.3587129E-05,   1.3811627E-05,   1.4041352E-05
     +,   1.4276610E-05,   1.4517746E-05,   1.4765111E-05
     +,   1.5019108E-05,   1.5280129E-05,   1.5548634E-05
     +,   1.5825086E-05,   1.6109994E-05,   1.6403879E-05
     +,   1.6707321E-05,   1.7020902E-05,   1.7345261E-05
     +,   1.7681059E-05,   1.8028990E-05,   1.8389786E-05
     +,   1.8764207E-05,   1.9153043E-05,   1.9557116E-05
     +,   1.9977297E-05,   2.0414442E-05,   2.0869473E-05
     +,   2.1343318E-05,   2.1836924E-05,   2.2351260E-05
     +,   2.2887307E-05,   2.3446068E-05,   2.4028534E-05
     +,   2.4635696E-05,   2.5268568E-05,   2.5928162E-05
     +,   2.6615420E-05,   2.7331353E-05,   2.8076853E-05
     +,   2.8852886E-05,   2.9660296E-05,   3.0499968E-05
     +,   3.1372663E-05,   3.2279197E-05,   3.3220203E-05
     +,   3.4196386E-05,   3.5208366E-05,   3.6256650E-05
     +,   3.7341691E-05,   3.8463921E-05,   3.9623748E-05
     +,   4.0821400E-05,   4.2057152E-05,   4.3331165E-05
     +,   4.4643628E-05,   4.5994555E-05,   4.7384096E-05
     +,   4.8812202E-05,   5.0278988E-05,   5.1784406E-05
     +,   5.3328517E-05,   5.4911456E-05,   5.6533310E-05
     +,   5.8194226E-05,   5.9894541E-05,   6.1634717E-05
     +,   6.3415209E-05,   6.5236891E-05,   6.7100606E-05
     +,   6.9007641E-05,   7.0959417E-05,   7.2957897E-05
     +,   7.5005126E-05,   7.7103934E-05,   7.9257297E-05
     +,   8.1468985E-05,   8.3743347E-05,   8.6085252E-05
     +,   8.8500317E-05,   9.0995061E-05,   9.3576862E-05
     +,   9.6253818E-05,   9.9035213E-05,   1.0193101E-04
     +,   1.0495253E-04,   1.0811175E-04,   1.1142201E-04
     +,   1.1489716E-04,   1.1855237E-04,   1.2240313E-04
     +,   1.2646585E-04,   1.3075734E-04,   1.3529441E-04
     +,   1.4009351E-04,   1.4517106E-04,   1.5054256E-04
     +,   1.5622162E-04,   1.6222082E-04,   1.6854957E-04
     +,   1.7521525E-04,   1.8222084E-04,   1.8956620E-04
     +,   1.9724572E-04,   2.0524958E-04,   2.1356148E-04
     +,   2.2215984E-04,   2.3101692E-04,   2.4009787E-04
     +,   2.4936133E-04,   2.5876024E-04,   2.6824110E-04
     +,   2.7774426E-04,   2.8720495E-04,   2.9655435E-04
     +,   3.0572023E-04,   3.1462710E-04,   3.2319941E-04
     +,   3.3136114E-04,   3.3903783E-04,   3.4615785E-04
     +,   3.5265458E-04,   3.5846751E-04,   3.6354316E-04
     +,   3.6783679E-04,   3.7131427E-04,   3.7395276E-04
     +,   3.7574104E-04,   3.7668098E-04,   3.7678814E-04
     +,   3.7609210E-04,   3.7463591E-04,   3.7247714E-04
     +,   3.6968710E-04,   3.6635023E-04,   3.6256417E-04
     +,   3.5843856E-04,   3.5409420E-04,   3.4966276E-04
     +,   3.4528534E-04,   3.4111144E-04,   3.3729759E-04
     +,   3.3400691E-04,   3.3140744E-04,   3.2967128E-04
     +,   3.2897294E-04,   3.2948938E-04,   3.3139720E-04
     +,   3.3487380E-04,   3.4009400E-04,   3.4723131E-04
     +,   3.5645464E-04,   3.6792946E-04,   3.8181365E-04
     +,   3.9825658E-04,   4.1739712E-04,   4.3936001E-04
     +,   4.6424964E-04,   4.9214571E-04,   5.2309956E-04
     +,   5.5712723E-04,   5.9420150E-04,   6.3425454E-04
     +,   6.7718024E-04,   7.2283880E-04,   7.7107939E-04
     +,   8.2177535E-04,   8.7486912E-04,   9.3042961E-04
     +,   9.8873139E-04,   1.0503406E-03,   1.1161955E-03
     +,   1.1876664E-03,   1.2665931E-03,   1.3552717E-03
     +,   1.4563679E-03,   1.5727406E-03,   1.7072466E-03
     +,   1.8624661E-03,   2.0404297E-03,   2.2424082E-03
     +,   2.4687832E-03,   2.7189553E-03,   2.9912733E-03
     +,   3.2829768E-03,   3.5900390E-03,   3.9069895E-03
     +,   4.2267442E-03,   4.5408099E-03,   4.8399717E-03
     +,   5.1155593E-03,   5.3613060E-03,   5.5754352E-03
     +,   5.7623335E-03,   5.9331441E-03,   6.1047240E-03
     +,   6.2968563E-03,   6.5282914E-03,   6.8130256E-03
     +,   7.1585448E-03,   7.5673386E-03,   8.0413278E-03
     +,   8.5871695E-03,   9.2193605E-03,   9.9583305E-03
     +,   1.0821576E-02,   1.1809162E-02,   1.2888575E-02
     +,   1.3988134E-02,   1.5009047E-02,   1.5860088E-02
     +,   1.6506273E-02,   1.7007284E-02,   1.7513577E-02
     +,   1.8200591E-02,   1.9167872E-02,   2.0371957E-02
     +,   2.1653254E-02,   2.2852635E-02,   2.3943264E-02
     +,   2.5066597E-02,   2.6389735E-02,   2.7865654E-02
     +,   2.9195141E-02,   3.0145656E-02,   3.0829109E-02
     +,   3.1512376E-02,   3.2295927E-02,   3.3169091E-02
     +,   3.4144949E-02,   3.5046235E-02,   3.5359975E-02
     +,   3.4679413E-02,   3.3239335E-02,   3.1680208E-02
     +,   3.0269027E-02,   2.8660536E-02,   2.6459519E-02
     +,   2.3730719E-02,   2.0873412E-02,   1.8205058E-02
     +,   1.5787017E-02,   1.3545590E-02,   1.1431789E-02
     +,   9.4652129E-03,   7.6968786E-03,   6.1674751E-03
     +,   4.8903166E-03,   3.8527730E-03,   3.0261287E-03
     +,   2.3755860E-03,   1.8678089E-03,   1.4740232E-03
     +,   1.1704655E-03,   9.3740399E-04,   7.5844344E-04
     +,   6.2011182E-04,   5.1177101E-04,   4.2539404E-04
     +,   3.5521877E-04,   2.9726827E-04,   2.4883746E-04
     +,   2.0808414E-04,   1.7369821E-04,   1.4470324E-04
     +,   1.2031711E-04,   9.9886711E-05,   8.2841449E-05
     +,   6.8679125E-05,   5.6952449E-05,   4.7268713E-05
     +,   3.9284449E-05,   3.2705640E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt116 = Yx/0.26868085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4044622E-05,   1.4353001E-05
     +,   1.4659965E-05,   1.4965263E-05,   1.5268663E-05
     +,   1.5569949E-05,   1.5868922E-05,   1.6165402E-05
     +,   1.6459229E-05,   1.6750282E-05,   1.7038441E-05
     +,   1.7323628E-05,   1.7605791E-05,   1.7884910E-05
     +,   1.8160992E-05,   1.8434084E-05,   1.8704264E-05
     +,   1.8971654E-05,   1.9236402E-05,   1.9498706E-05
     +,   1.9758801E-05,   2.0016963E-05,   2.0273505E-05
     +,   2.0528798E-05,   2.0783238E-05,   2.1037273E-05
     +,   2.1291402E-05,   2.1546151E-05,   2.1802107E-05
     +,   2.2059887E-05,   2.2320151E-05,   2.2583607E-05
     +,   2.2850996E-05,   2.3123102E-05,   2.3400748E-05
     +,   2.3684783E-05,   2.3976094E-05,   2.4275603E-05
     +,   2.4584260E-05,   2.4903020E-05,   2.5232895E-05
     +,   2.5574889E-05,   2.5930034E-05,   2.6299365E-05
     +,   2.6683943E-05,   2.7084818E-05,   2.7503043E-05
     +,   2.7939677E-05,   2.8395783E-05,   2.8872370E-05
     +,   2.9370487E-05,   2.9891138E-05,   3.0435296E-05
     +,   3.1003947E-05,   3.1597996E-05,   3.2218377E-05
     +,   3.2865941E-05,   3.3541524E-05,   3.4245924E-05
     +,   3.4979887E-05,   3.5744117E-05,   3.6539292E-05
     +,   3.7365986E-05,   3.8224807E-05,   3.9116294E-05
     +,   4.0040861E-05,   4.0998995E-05,   4.1990999E-05
     +,   4.3017273E-05,   4.4078031E-05,   4.5173569E-05
     +,   4.6303994E-05,   4.7469537E-05,   4.8670201E-05
     +,   4.9906055E-05,   5.1177187E-05,   5.2483487E-05
     +,   5.3824828E-05,   5.5201141E-05,   5.6612291E-05
     +,   5.8057954E-05,   5.9537993E-05,   6.1051978E-05
     +,   6.2599654E-05,   6.4180480E-05,   6.5794149E-05
     +,   6.7439978E-05,   6.9117516E-05,   7.0825976E-05
     +,   7.2564711E-05,   7.4333002E-05,   7.6129923E-05
     +,   7.7954479E-05,   7.9805730E-05,   8.1682629E-05
     +,   8.3583916E-05,   8.5508451E-05,   8.7454806E-05
     +,   8.9421650E-05,   9.1407463E-05,   9.3410781E-05
     +,   9.5429918E-05,   9.7463351E-05,   9.9509205E-05
     +,   1.0156586E-04,   1.0363157E-04,   1.0570454E-04
     +,   1.0778289E-04,   1.0986486E-04,   1.1194882E-04
     +,   1.1403282E-04,   1.1611534E-04,   1.1819453E-04
     +,   1.2026890E-04,   1.2233673E-04,   1.2439667E-04
     +,   1.2644712E-04,   1.2848673E-04,   1.3051409E-04
     +,   1.3252783E-04,   1.3452674E-04,   1.3650939E-04
     +,   1.3847442E-04,   1.4042048E-04,   1.4234627E-04
     +,   1.4425005E-04,   1.4613038E-04,   1.4798528E-04
     +,   1.4981303E-04,   1.5161131E-04,   1.5337794E-04
     +,   1.5511028E-04,   1.5680562E-04,   1.5846091E-04
     +,   1.6007293E-04,   1.6163834E-04,   1.6315348E-04
     +,   1.6461470E-04,   1.6601822E-04,   1.6736035E-04
     +,   1.6863746E-04,   1.6984620E-04,   1.7098359E-04
     +,   1.7204724E-04,   1.7303533E-04,   1.7394709E-04
     +,   1.7478284E-04,   1.7554425E-04,   1.7623478E-04
     +,   1.7685957E-04,   1.7742616E-04,   1.7794470E-04
     +,   1.7842808E-04,   1.7889243E-04,   1.7935767E-04
     +,   1.7984770E-04,   1.8039085E-04,   1.8102040E-04
     +,   1.8177505E-04,   1.8269951E-04,   1.8384476E-04
     +,   1.8526913E-04,   1.8703834E-04,   1.8922625E-04
     +,   1.9191568E-04,   1.9519865E-04,   1.9917647E-04
     +,   2.0395998E-04,   2.0966974E-04,   2.1643529E-04
     +,   2.2439334E-04,   2.3368675E-04,   2.4446208E-04
     +,   2.5686674E-04,   2.7104295E-04,   2.8712535E-04
     +,   3.0523448E-04,   3.2546881E-04,   3.4789968E-04
     +,   3.7256561E-04,   3.9946588E-04,   4.2855350E-04
     +,   4.5973356E-04,   4.9286481E-04,   5.2776025E-04
     +,   5.6418951E-04,   6.0189096E-04,   6.4058520E-04
     +,   6.7998935E-04,   7.1982876E-04,   7.5986393E-04
     +,   7.9990312E-04,   8.3981460E-04,   8.7953871E-04
     +,   9.1909943E-04,   9.5859700E-04,   9.9820376E-04
     +,   1.0381542E-03,   1.0787378E-03,   1.1202851E-03
     +,   1.1631575E-03,   1.2077505E-03,   1.2544980E-03
     +,   1.3038841E-03,   1.3564506E-03,   1.4128246E-03
     +,   1.4737390E-03,   1.5400579E-03,   1.6128257E-03
     +,   1.6933535E-03,   1.7833224E-03,   1.8849111E-03
     +,   2.0009358E-03,   2.1349268E-03,   2.2910757E-03
     +,   2.4739737E-03,   2.6881243E-03,   2.9372631E-03
     +,   3.2234988E-03,   3.5464456E-03,   3.9025736E-03
     +,   4.2848303E-03,   4.6827276E-03,   5.0832345E-03
     +,   5.4726023E-03,   5.8392612E-03,   6.1777942E-03
     +,   6.4934329E-03,   6.8058115E-03,   7.1495860E-03
     +,   7.5690988E-03,   8.1051532E-03,   8.7760808E-03
     +,   9.5607862E-03,   1.0396423E-02,   1.1199929E-02
     +,   1.1908061E-02,   1.2514896E-02,   1.3080923E-02
     +,   1.3704304E-02,   1.4469723E-02,   1.5402618E-02
     +,   1.6452258E-02,   1.7513854E-02,   1.8482875E-02
     +,   1.9313874E-02,   2.0051040E-02,   2.0812349E-02
     +,   2.1722466E-02,   2.2809388E-02,   2.3946106E-02
     +,   2.4930434E-02,   2.5641257E-02,   2.6094992E-02
     +,   2.6384620E-02,   2.6639359E-02,   2.7003173E-02
     +,   2.7532587E-02,   2.8104721E-02,   2.8496997E-02
     +,   2.8550021E-02,   2.8211802E-02,   2.7460609E-02
     +,   2.6267793E-02,   2.4650985E-02,   2.2710025E-02
     +,   2.0578807E-02,   1.8357297E-02,   1.6103480E-02
     +,   1.3872880E-02,   1.1745272E-02,   9.8085413E-03
     +,   8.1220372E-03,   6.6970568E-03,   5.5068661E-03
     +,   4.5107682E-03,   3.6723136E-03,   2.9656354E-03
     +,   2.3730681E-03,   1.8813066E-03,   1.4784996E-03
     +,   1.1532449E-03,   8.9426374E-04,   6.9068646E-04
     +,   5.3232082E-04,   4.1005897E-04,   3.1608721E-04
     +,   2.4399787E-04,   1.8872420E-04,   1.4634598E-04
     +,   1.1387765E-04,   8.9037479E-05,   7.0074857E-05
     +,   5.5628974E-05,   4.4639626E-05,   3.6277615E-05
     +,   2.9900340E-05,   2.5012510E-05,   2.1237589E-05
     +,   1.8290999E-05,   1.5960029E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt118 = Yx/0.22795652173913
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1993965E-06,   6.4009832E-06
     +,   6.6076072E-06,   6.8193303E-06,   7.0362048E-06
     +,   7.2582848E-06,   7.4856143E-06,   7.7182358E-06
     +,   7.9561787E-06,   8.1994822E-06,   8.4481626E-06
     +,   8.7022354E-06,   8.9617106E-06,   9.2265900E-06
     +,   9.4968627E-06,   9.7725169E-06,   1.0053528E-05
     +,   1.0339864E-05,   1.0631484E-05,   1.0928338E-05
     +,   1.1230370E-05,   1.1537514E-05,   1.1849688E-05
     +,   1.2166824E-05,   1.2488819E-05,   1.2815584E-05
     +,   1.3147013E-05,   1.3483002E-05,   1.3823435E-05
     +,   1.4168201E-05,   1.4517180E-05,   1.4870257E-05
     +,   1.5227317E-05,   1.5588246E-05,   1.5952946E-05
     +,   1.6321314E-05,   1.6693262E-05,   1.7068718E-05
     +,   1.7447637E-05,   1.7829960E-05,   1.8215695E-05
     +,   1.8604844E-05,   1.8997445E-05,   1.9393587E-05
     +,   1.9793375E-05,   2.0196974E-05,   2.0604575E-05
     +,   2.1016442E-05,   2.1432870E-05,   2.1854234E-05
     +,   2.2280956E-05,   2.2713530E-05,   2.3152506E-05
     +,   2.3598548E-05,   2.4052326E-05,   2.4514651E-05
     +,   2.4986386E-05,   2.5468462E-05,   2.5961919E-05
     +,   2.6467853E-05,   2.6987451E-05,   2.7521988E-05
     +,   2.8072762E-05,   2.8641200E-05,   2.9228795E-05
     +,   2.9837034E-05,   3.0467538E-05,   3.1121879E-05
     +,   3.1801756E-05,   3.2508797E-05,   3.3244727E-05
     +,   3.4011169E-05,   3.4809826E-05,   3.5642261E-05
     +,   3.6510057E-05,   3.7414731E-05,   3.8357652E-05
     +,   3.9340062E-05,   4.0363149E-05,   4.1427953E-05
     +,   4.2535223E-05,   4.3685686E-05,   4.4879660E-05
     +,   4.6117446E-05,   4.7398913E-05,   4.8723807E-05
     +,   5.0091443E-05,   5.1501036E-05,   5.2951287E-05
     +,   5.4440741E-05,   5.5967608E-05,   5.7529705E-05
     +,   5.9124512E-05,   6.0749273E-05,   6.2400984E-05
     +,   6.4076114E-05,   6.5771113E-05,   6.7481946E-05
     +,   6.9204536E-05,   7.0934446E-05,   7.2667193E-05
     +,   7.4398020E-05,   7.6122247E-05,   7.7834957E-05
     +,   7.9531426E-05,   8.1206948E-05,   8.2856859E-05
     +,   8.4476698E-05,   8.6062370E-05,   8.7610068E-05
     +,   8.9116314E-05,   9.0578265E-05,   9.1993446E-05
     +,   9.3360271E-05,   9.4677693E-05,   9.5945652E-05
     +,   9.7164870E-05,   9.8337172E-05,   9.9465418E-05
     +,   1.0055365E-04,   1.0160734E-04,   1.0263300E-04
     +,   1.0363876E-04,   1.0463418E-04,   1.0563041E-04
     +,   1.0663999E-04,   1.0767732E-04,   1.0875816E-04
     +,   1.0990002E-04,   1.1112173E-04,   1.1244384E-04
     +,   1.1388803E-04,   1.1547736E-04,   1.1723570E-04
     +,   1.1918781E-04,   1.2135909E-04,   1.2377489E-04
     +,   1.2646038E-04,   1.2944028E-04,   1.3273819E-04
     +,   1.3637623E-04,   1.4037419E-04,   1.4474952E-04
     +,   1.4951675E-04,   1.5468606E-04,   1.6026401E-04
     +,   1.6625262E-04,   1.7264836E-04,   1.7944230E-04
     +,   1.8662018E-04,   1.9416206E-04,   2.0204169E-04
     +,   2.1022712E-04,   2.1868144E-04,   2.2736275E-04
     +,   2.3622428E-04,   2.4521537E-04,   2.5428340E-04
     +,   2.6337360E-04,   2.7242996E-04,   2.8139760E-04
     +,   2.9022331E-04,   2.9885635E-04,   3.0724995E-04
     +,   3.1536349E-04,   3.2316233E-04,   3.3061879E-04
     +,   3.3771314E-04,   3.4443458E-04,   3.5078108E-04
     +,   3.5675938E-04,   3.6238448E-04,   3.6768056E-04
     +,   3.7267944E-04,   3.7741961E-04,   3.8194651E-04
     +,   3.8631077E-04,   3.9056814E-04,   3.9477868E-04
     +,   3.9900711E-04,   4.0332286E-04,   4.0780113E-04
     +,   4.1252485E-04,   4.1758711E-04,   4.2309551E-04
     +,   4.2917582E-04,   4.3597782E-04,   4.4368306E-04
     +,   4.5251084E-04,   4.6272422E-04,   4.7463857E-04
     +,   4.8862537E-04,   5.0511333E-04,   5.2458659E-04
     +,   5.4757827E-04,   5.7465472E-04,   6.0638908E-04
     +,   6.4333226E-04,   6.8597210E-04,   7.3468918E-04
     +,   7.8970136E-04,   8.5102418E-04,   9.1843941E-04
     +,   9.9148497E-04,   1.0694611E-03,   1.1515075E-03
     +,   1.2366947E-03,   1.3241582E-03,   1.4132765E-03
     +,   1.5038527E-03,   1.5962599E-03,   1.6915209E-03
     +,   1.7912959E-03,   1.8977427E-03,   2.0132447E-03
     +,   2.1400638E-03,   2.2800057E-03,   2.4342125E-03
     +,   2.6031625E-03,   2.7869057E-03,   2.9855811E-03
     +,   3.1999059E-03,   3.4315174E-03,   3.6829223E-03
     +,   3.9570211E-03,   4.2562024E-03,   4.5814253E-03
     +,   4.9315654E-03,   5.3032525E-03,   5.6909136E-03
     +,   6.0867588E-03,   6.4805732E-03,   6.8599544E-03
     +,   7.2125643E-03,   7.5320397E-03,   7.8275036E-03
     +,   8.1319036E-03,   8.5021742E-03,   9.0052262E-03
     +,   9.6920133E-03,   1.0571025E-02,   1.1596471E-02
     +,   1.2680154E-02,   1.3721587E-02,   1.4639219E-02
     +,   1.5386830E-02,   1.5951606E-02,   1.6349008E-02
     +,   1.6631885E-02,   1.6907915E-02,   1.7327184E-02
     +,   1.8007917E-02,   1.8936122E-02,   1.9938929E-02
     +,   2.0791253E-02,   2.1379160E-02,   2.1768421E-02
     +,   2.2116013E-02,   2.2524059E-02,   2.2984451E-02
     +,   2.3434142E-02,   2.3799490E-02,   2.3963630E-02
     +,   2.3751875E-02,   2.3019616E-02,   2.1764381E-02
     +,   2.0130666E-02,   1.8303201E-02,   1.6404746E-02
     +,   1.4486118E-02,   1.2581598E-02,   1.0750025E-02
     +,   9.0665985E-03,   7.5882878E-03,   6.3305800E-03
     +,   5.2707260E-03,   4.3683532E-03,   3.5868785E-03
     +,   2.9037879E-03,   2.3102358E-03,   1.8045183E-03
     +,   1.3856887E-03,   1.0495610E-03,   7.8794203E-04
     +,   5.8964716E-04,   4.4240124E-04,   3.3445435E-04
     +,   2.5567415E-04,   1.9798319E-04,   1.5530064E-04
     +,   1.2325803E-04,   9.8801414E-05,   7.9836114E-05
     +,   6.4924170E-05,   5.3070973E-05,   4.3570199E-05
     +,   3.5907666E-05,   2.9695797E-05,   2.4636638E-05
     +,   2.0496165E-05,   1.7090231E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt120 = Yx/0.189318181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1002788E-05,   9.3433591E-05
     +,   9.5908465E-05,   9.8430464E-05,   1.0100294E-04
     +,   1.0362957E-04,   1.0631449E-04,   1.0906206E-04
     +,   1.1187715E-04,   1.1476509E-04,   1.1773164E-04
     +,   1.2078302E-04,   1.2392603E-04,   1.2716814E-04
     +,   1.3051742E-04,   1.3398287E-04,   1.3757417E-04
     +,   1.4130204E-04,   1.4517840E-04,   1.4921642E-04
     +,   1.5343058E-04,   1.5783701E-04,   1.6245361E-04
     +,   1.6730031E-04,   1.7239887E-04,   1.7777382E-04
     +,   1.8345166E-04,   1.8946161E-04,   1.9583566E-04
     +,   2.0260825E-04,   2.0981637E-04,   2.1749976E-04
     +,   2.2570025E-04,   2.3446159E-04,   2.4382936E-04
     +,   2.5384990E-04,   2.6457058E-04,   2.7603822E-04
     +,   2.8830033E-04,   3.0140110E-04,   3.1538532E-04
     +,   3.3029451E-04,   3.4616882E-04,   3.6304636E-04
     +,   3.8096466E-04,   3.9996210E-04,   4.2007936E-04
     +,   4.4136401E-04,   4.6387315E-04,   4.8768005E-04
     +,   5.1288010E-04,   5.3959782E-04,   5.6799600E-04
     +,   5.9828727E-04,   6.3073565E-04,   6.6567661E-04
     +,   7.0351630E-04,   7.4474112E-04,   7.8992365E-04
     +,   8.3972304E-04,   8.9488388E-04,   9.5623598E-04
     +,   1.0246785E-03,   1.1011810E-03,   1.1867619E-03
     +,   1.2824652E-03,   1.3893546E-03,   1.5084818E-03
     +,   1.6409127E-03,   1.7877260E-03,   1.9501247E-03
     +,   2.1295226E-03,   2.3277707E-03,   2.5473111E-03
     +,   2.7914299E-03,   3.0643691E-03,   3.3713428E-03
     +,   3.7184577E-03,   4.1125156E-03,   4.5606750E-03
     +,   5.0700344E-03,   5.6474428E-03,   6.2993546E-03
     +,   7.0323604E-03,   7.8537120E-03,   8.7718554E-03
     +,   9.7953295E-03,   1.0930472E-02,   1.2178260E-02
     +,   1.3534573E-02,   1.4996536E-02,   1.6574657E-02
     +,   1.8302785E-02,   2.0230806E-02,   2.2390600E-02
     +,   2.4755042E-02,   2.7237253E-02,   2.9756146E-02
     +,   3.2318309E-02,   3.5012353E-02,   3.7903070E-02
     +,   4.0949941E-02,   4.4047236E-02,   4.7066581E-02
     +,   4.9784187E-02,   5.1850367E-02,   5.2968938E-02
     +,   5.3063937E-02,   5.2182708E-02,   5.0357111E-02
     +,   4.7713555E-02,   4.4613339E-02,   4.1493598E-02
     +,   3.8593356E-02,   3.5949610E-02,   3.3593636E-02
     +,   3.1608876E-02,   2.9999366E-02,   2.8612280E-02
     +,   2.7229477E-02,   2.5719091E-02,   2.4107639E-02
     +,   2.2538822E-02,   2.1169292E-02,   2.0073975E-02
     +,   1.9211825E-02,   1.8460033E-02,   1.7683676E-02
     +,   1.6796269E-02,   1.5785150E-02,   1.4699873E-02
     +,   1.3620858E-02,   1.2625519E-02,   1.1765463E-02
     +,   1.1057540E-02,   1.0487380E-02,   1.0019963E-02
     +,   9.6122334E-03,   9.2239818E-03,   8.8255834E-03
     +,   8.4014144E-03,   7.9493374E-03,   7.4775843E-03
     +,   7.0002014E-03,   6.5326854E-03,   6.0884035E-03
     +,   5.6766989E-03,   5.3023631E-03,   4.9660718E-03
     +,   4.6654488E-03,   4.3962649E-03,   4.1535283E-03
     +,   3.9322609E-03,   3.7279597E-03,   3.5369154E-03
     +,   3.3562721E-03,   3.1839877E-03,   3.0187257E-03
     +,   2.8597091E-03,   2.7065885E-03,   2.5592525E-03
     +,   2.4177346E-03,   2.2821324E-03,   2.1525333E-03
     +,   2.0290110E-03,   1.9116283E-03,   1.8004774E-03
     +,   1.6956824E-03,   1.5974218E-03,   1.5059336E-03
     +,   1.4215179E-03,   1.3445073E-03,   1.2752335E-03
     +,   1.2140055E-03,   1.1610801E-03,   1.1166246E-03
     +,   1.0807045E-03,   1.0532762E-03,   1.0341766E-03
     +,   1.0231326E-03,   1.0197693E-03,   1.0236312E-03
     +,   1.0341901E-03,   1.0508709E-03,   1.0730625E-03
     +,   1.1001341E-03,   1.1314467E-03,   1.1663653E-03
     +,   1.2042611E-03,   1.2445188E-03,   1.2865340E-03
     +,   1.3297207E-03,   1.3735022E-03,   1.4173165E-03
     +,   1.4606102E-03,   1.5028415E-03,   1.5434738E-03
     +,   1.5819814E-03,   1.6178509E-03,   1.6505820E-03
     +,   1.6796954E-03,   1.7047370E-03,   1.7252885E-03
     +,   1.7409794E-03,   1.7514884E-03,   1.7565642E-03
     +,   1.7560255E-03,   1.7497770E-03,   1.7378099E-03
     +,   1.7202119E-03,   1.6971623E-03,   1.6689351E-03
     +,   1.6358937E-03,   1.5984765E-03,   1.5571915E-03
     +,   1.5126044E-03,   1.4653177E-03,   1.4159568E-03
     +,   1.3651507E-03,   1.3135216E-03,   1.2616611E-03
     +,   1.2101220E-03,   1.1594046E-03,   1.1099506E-03
     +,   1.0621302E-03,   1.0162434E-03,   9.7251846E-04
     +,   9.3111501E-04,   8.9212216E-04,   8.5556722E-04
     +,   8.2142447E-04,   7.8962103E-04,   7.6004147E-04
     +,   7.3254039E-04,   7.0695119E-04,   6.8309065E-04
     +,   6.6076522E-04,   6.3978240E-04,   6.1995210E-04
     +,   6.0109090E-04,   5.8302731E-04,   5.6560454E-04
     +,   5.4868311E-04,   5.3213921E-04,   5.1586708E-04
     +,   4.9978116E-04,   4.8381349E-04,   4.6791224E-04
     +,   4.5204186E-04,   4.3618336E-04,   4.2032945E-04
     +,   4.0448524E-04,   3.8866646E-04,   3.7289783E-04
     +,   3.5720997E-04,   3.4163854E-04,   3.2622443E-04
     +,   3.1101023E-04,   2.9603890E-04,   2.8135290E-04
     +,   2.6699444E-04,   2.5300300E-04,   2.3941454E-04
     +,   2.2626107E-04,   2.1357165E-04,   2.0136953E-04
     +,   1.8967321E-04,   1.7849720E-04,   1.6785100E-04
     +,   1.5773892E-04,   1.4816072E-04,   1.3911273E-04
     +,   1.3058733E-04,   1.2257304E-04,   1.1505532E-04
     +,   1.0801795E-04,   1.0144154E-04,   9.5305972E-05
     +,   8.9588946E-05,   8.4268220E-05,   7.9320198E-05
     +,   7.4721866E-05,   7.0449692E-05,   6.6481101E-05
     +,   6.2793617E-05,   5.9366026E-05,   5.6177709E-05
     +,   5.3209107E-05,   5.0442137E-05,   4.7859463E-05
     +,   4.5445337E-05,   4.3184900E-05,   4.1064814E-05
     +,   3.9072595E-05,   3.7197187E-05,   3.5428337E-05
     +,   3.3757042E-05,   3.2175016E-05,   3.0675074E-05
     +,   2.9250630E-05,   2.7896009E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt75 = Yx/0.411714285714286
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7267379E-05,   3.8870276E-05
     +,   4.0555100E-05,   4.2326610E-05,   4.4189783E-05
     +,   4.6149722E-05,   4.8211714E-05,   5.0381175E-05
     +,   5.2663629E-05,   5.5064760E-05,   5.7590270E-05
     +,   6.0245853E-05,   6.3037274E-05,   6.5970205E-05
     +,   6.9050220E-05,   7.2282855E-05,   7.5673393E-05
     +,   7.9226898E-05,   8.2948209E-05,   8.6841799E-05
     +,   9.0911773E-05,   9.5161849E-05,   9.9595120E-05
     +,   1.0421457E-04,   1.0902199E-04,   1.1401921E-04
     +,   1.1920714E-04,   1.2458603E-04,   1.3015568E-04
     +,   1.3591508E-04,   1.4186279E-04,   1.4799675E-04
     +,   1.5431442E-04,   1.6081288E-04,   1.6748912E-04
     +,   1.7433980E-04,   1.8136190E-04,   1.8855254E-04
     +,   1.9590998E-04,   2.0343268E-04,   2.1112127E-04
     +,   2.1897774E-04,   2.2700660E-04,   2.3521509E-04
     +,   2.4361417E-04,   2.5221842E-04,   2.6104780E-04
     +,   2.7012697E-04,   2.7948714E-04,   2.8916574E-04
     +,   2.9920702E-04,   3.0966284E-04,   3.2059153E-04
     +,   3.3206024E-04,   3.4414078E-04,   3.5691223E-04
     +,   3.7045818E-04,   3.8486489E-04,   4.0022092E-04
     +,   4.1661339E-04,   4.3412659E-04,   4.5283957E-04
     +,   4.7282191E-04,   4.9413362E-04,   5.1682303E-04
     +,   5.4092240E-04,   5.6645263E-04,   5.9341872E-04
     +,   6.2181579E-04,   6.5162865E-04,   6.8284158E-04
     +,   7.1543863E-04,   7.4941939E-04,   7.8480091E-04
     +,   8.2163647E-04,   8.6002512E-04,   9.0012525E-04
     +,   9.4217149E-04,   9.8649587E-04,   1.0335492E-03
     +,   1.0839150E-03,   1.1383535E-03,   1.1978201E-03
     +,   1.2635150E-03,   1.3369133E-03,   1.4198252E-03
     +,   1.5144121E-03,   1.6232352E-03,   1.7492294E-03
     +,   1.8956776E-03,   2.0661019E-03,   2.2640636E-03
     +,   2.4929144E-03,   2.7554934E-03,   3.0538035E-03
     +,   3.3887518E-03,   3.7602761E-03,   4.1676750E-03
     +,   4.6105697E-03,   5.0898981E-03,   5.6089107E-03
     +,   6.1732605E-03,   6.7904992E-03,   7.4690734E-03
     +,   8.2186181E-03,   9.0519078E-03,   9.9877967E-03
     +,   1.1052796E-02,   1.2278480E-02,   1.3694221E-02
     +,   1.5317737E-02,   1.7146615E-02,   1.9153219E-02
     +,   2.1290347E-02,   2.3511106E-02,   2.5794383E-02
     +,   2.8150516E-02,   3.0604934E-02,   3.3198770E-02
     +,   3.6027845E-02,   3.9229967E-02,   4.2830400E-02
     +,   4.6564776E-02,   4.9920470E-02,   5.2422564E-02
     +,   5.3932350E-02,   5.4734070E-02,   5.5303052E-02
     +,   5.5842202E-02,   5.6002624E-02,   5.5208791E-02
     +,   5.3327873E-02,   5.0901979E-02,   4.8660867E-02
     +,   4.6888754E-02,   4.5272149E-02,   4.3230306E-02
     +,   4.0356807E-02,   3.6679294E-02,   3.2628119E-02
     +,   2.8782751E-02,   2.5589149E-02,   2.3221403E-02
     +,   2.1601567E-02,   2.0498991E-02,   1.9642880E-02
     +,   1.8815136E-02,   1.7901586E-02,   1.6891010E-02
     +,   1.5833894E-02,   1.4791309E-02,   1.3800921E-02
     +,   1.2869447E-02,   1.1983877E-02,   1.1128404E-02
     +,   1.0296080E-02,   9.4914185E-03,   8.7261312E-03
     +,   8.0125583E-03,   7.3584053E-03,   6.7646727E-03
     +,   6.2267175E-03,   5.7369093E-03,   5.2873506E-03
     +,   4.8717619E-03,   4.4862321E-03,   4.1290643E-03
     +,   3.8000084E-03,   3.4995347E-03,   3.2282441E-03
     +,   2.9866109E-03,   2.7748300E-03,   2.5927890E-03
     +,   2.4400987E-03,   2.3160796E-03,   2.2197270E-03
     +,   2.1496883E-03,   2.1042919E-03,   2.0815597E-03
     +,   2.0792761E-03,   2.0950795E-03,   2.1265317E-03
     +,   2.1711842E-03,   2.2266321E-03,   2.2905378E-03
     +,   2.3606191E-03,   2.4346700E-03,   2.5105320E-03
     +,   2.5861077E-03,   2.6593388E-03,   2.7282492E-03
     +,   2.7909603E-03,   2.8457479E-03,   2.8910760E-03
     +,   2.9256782E-03,   2.9486017E-03,   2.9592603E-03
     +,   2.9574523E-03,   2.9434026E-03,   2.9177251E-03
     +,   2.8814056E-03,   2.8357434E-03,   2.7822820E-03
     +,   2.7227174E-03,   2.6588265E-03,   2.5923653E-03
     +,   2.5249911E-03,   2.4582110E-03,   2.3933225E-03
     +,   2.3313803E-03,   2.2731835E-03,   2.2192844E-03
     +,   2.1699923E-03,   2.1253994E-03,   2.0854019E-03
     +,   2.0497399E-03,   2.0180184E-03,   1.9897334E-03
     +,   1.9642990E-03,   1.9410745E-03,   1.9193760E-03
     +,   1.8985011E-03,   1.8777447E-03,   1.8564202E-03
     +,   1.8338700E-03,   1.8094869E-03,   1.7827328E-03
     +,   1.7531519E-03,   1.7203771E-03,   1.6841518E-03
     +,   1.6443257E-03,   1.6008655E-03,   1.5538520E-03
     +,   1.5034659E-03,   1.4499958E-03,   1.3938082E-03
     +,   1.3353393E-03,   1.2750842E-03,   1.2135735E-03
     +,   1.1513502E-03,   1.0889600E-03,   1.0269360E-03
     +,   9.6578448E-04,   9.0596388E-04,   8.4788509E-04
     +,   7.9190527E-04,   7.3832134E-04,   6.8736385E-04
     +,   6.3920149E-04,   5.9394777E-04,   5.5165606E-04
     +,   5.1232829E-04,   4.7592499E-04,   4.4236652E-04
     +,   4.1153916E-04,   3.8330528E-04,   3.5750886E-04
     +,   3.3398185E-04,   3.1254679E-04,   2.9302464E-04
     +,   2.7523932E-04,   2.5901973E-04,   2.4420209E-04
     +,   2.3063323E-04,   2.1817253E-04,   2.0669081E-04
     +,   1.9607179E-04,   1.8621287E-04,   1.7702382E-04
     +,   1.6842535E-04,   1.6034946E-04,   1.5273836E-04
     +,   1.4554305E-04,   1.3872214E-04,   1.3224081E-04
     +,   1.2607063E-04,   1.2018738E-04,   1.1457136E-04
     +,   1.0920574E-04,   1.0407663E-04,   9.9171913E-05
     +,   9.4481511E-05,   8.9995963E-05,   8.5707390E-05
     +,   8.1608021E-05,   7.7691031E-05,   7.3949632E-05
     +,   7.0377304E-05,   6.6967928E-05,   6.3715248E-05
     +,   6.0613373E-05,   5.7656147E-05,   5.4837932E-05
     +,   5.2152718E-05,   4.9595026E-05,   4.7159094E-05
     +,   4.4839657E-05,   4.2631233E-05,   4.0528805E-05
     +,   3.8527236E-05,   3.6621823E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt80 = Yx/0.44604
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7992209E-05,   3.9463674E-05
     +,   4.0975337E-05,   4.2527539E-05,   4.4120527E-05
     +,   4.5754550E-05,   4.7429792E-05,   4.9146420E-05
     +,   5.0904491E-05,   5.2704145E-05,   5.4545366E-05
     +,   5.6428111E-05,   5.8352303E-05,   6.0317790E-05
     +,   6.2324383E-05,   6.4371830E-05,   6.6459805E-05
     +,   6.8587957E-05,   7.0755821E-05,   7.2962946E-05
     +,   7.5208758E-05,   7.7492696E-05,   7.9814054E-05
     +,   8.2172279E-05,   8.4566505E-05,   8.6996122E-05
     +,   8.9460387E-05,   9.1958573E-05,   9.4489973E-05
     +,   9.7054064E-05,   9.9650249E-05,   1.0227827E-04
     +,   1.0493788E-04,   1.0762919E-04,   1.1035258E-04
     +,   1.1310875E-04,   1.1589890E-04,   1.1872478E-04
     +,   1.2158879E-04,   1.2449388E-04,   1.2744412E-04
     +,   1.3044440E-04,   1.3350070E-04,   1.3662026E-04
     +,   1.3981167E-04,   1.4308501E-04,   1.4645192E-04
     +,   1.4992592E-04,   1.5352228E-04,   1.5725831E-04
     +,   1.6115319E-04,   1.6522832E-04,   1.6950704E-04
     +,   1.7401500E-04,   1.7877940E-04,   1.8382970E-04
     +,   1.8919668E-04,   1.9491278E-04,   2.0101138E-04
     +,   2.0752667E-04,   2.1449315E-04,   2.2194517E-04
     +,   2.2991585E-04,   2.3843779E-04,   2.4754138E-04
     +,   2.5725408E-04,   2.6760064E-04,   2.7860139E-04
     +,   2.9027319E-04,   3.0262725E-04,   3.1567068E-04
     +,   3.2940402E-04,   3.4382465E-04,   3.5892308E-04
     +,   3.7468734E-04,   3.9110292E-04,   4.0815270E-04
     +,   4.2582070E-04,   4.4409538E-04,   4.6297166E-04
     +,   4.8245359E-04,   5.0256163E-04,   5.2333297E-04
     +,   5.4483145E-04,   5.6714553E-04,   5.9039862E-04
     +,   6.1474659E-04,   6.4038543E-04,   6.6754478E-04
     +,   6.9649372E-04,   7.2753406E-04,   7.6099404E-04
     +,   7.9722400E-04,   8.3659525E-04,   8.7948807E-04
     +,   9.2629151E-04,   9.7740872E-04,   1.0332550E-03
     +,   1.0942847E-03,   1.1609973E-03,   1.2339862E-03
     +,   1.3139602E-03,   1.4018075E-03,   1.4986229E-03
     +,   1.6057701E-03,   1.7248933E-03,   1.8579062E-03
     +,   2.0069552E-03,   2.1743281E-03,   2.3623409E-03
     +,   2.5731854E-03,   2.8089224E-03,   3.0714546E-03
     +,   3.3627809E-03,   3.6852548E-03,   4.0419768E-03
     +,   4.4369381E-03,   4.8749642E-03,   5.3610415E-03
     +,   5.8995117E-03,   6.4932294E-03,   7.1433708E-03
     +,   7.8507485E-03,   8.6183762E-03,   9.4543817E-03
     +,   1.0372880E-02,   1.1391489E-02,   1.2524611E-02
     +,   1.3777493E-02,   1.5144967E-02,   1.6617371E-02
     +,   1.8186973E-02,   1.9850552E-02,   2.1611376E-02
     +,   2.3489842E-02,   2.5535123E-02,   2.7809855E-02
     +,   3.0339943E-02,   3.3075266E-02,   3.5919316E-02
     +,   3.8805943E-02,   4.1735202E-02,   4.4738933E-02
     +,   4.7832418E-02,   5.0955657E-02,   5.3903040E-02
     +,   5.6380358E-02,   5.8224648E-02,   5.9436861E-02
     +,   5.9888635E-02,   5.9267912E-02,   5.7522200E-02
     +,   5.5059735E-02,   5.2320961E-02,   4.9461432E-02
     +,   4.6542190E-02,   4.3670811E-02,   4.0846612E-02
     +,   3.7900507E-02,   3.4684319E-02,   3.1249456E-02
     +,   2.7821595E-02,   2.4634434E-02,   2.1794379E-02
     +,   1.9270794E-02,   1.6975991E-02,   1.4847010E-02
     +,   1.2874866E-02,   1.1087105E-02,   9.5157037E-03
     +,   8.1764907E-03,   7.0657111E-03,   6.1667869E-03
     +,   5.4582111E-03,   4.9180365E-03,   4.5251939E-03
     +,   4.2598322E-03,   4.1033514E-03,   4.0385122E-03
     +,   4.0495028E-03,   4.1218321E-03,   4.2421594E-03
     +,   4.3980638E-03,   4.5780288E-03,   4.7714878E-03
     +,   4.9689799E-03,   5.1624058E-03,   5.3452277E-03
     +,   5.5126152E-03,   5.6613921E-03,   5.7899551E-03
     +,   5.8979448E-03,   5.9858640E-03,   6.0546314E-03
     +,   6.1052046E-03,   6.1381832E-03,   6.1536748E-03
     +,   6.1511965E-03,   6.1298106E-03,   6.0884040E-03
     +,   6.0260003E-03,   5.9421440E-03,   5.8372505E-03
     +,   5.7127788E-03,   5.5713165E-03,   5.4164031E-03
     +,   5.2522230E-03,   5.0832159E-03,   4.9135392E-03
     +,   4.7466643E-03,   4.5850440E-03,   4.4299643E-03
     +,   4.2815837E-03,   4.1391156E-03,   4.0011392E-03
     +,   3.8660197E-03,   3.7322151E-03,   3.5986023E-03
     +,   3.4646364E-03,   3.3304559E-03,   3.1968085E-03
     +,   3.0649330E-03,   2.9363763E-03,   2.8127921E-03
     +,   2.6957262E-03,   2.5864760E-03,   2.4859612E-03
     +,   2.3946739E-03,   2.3126355E-03,   2.2394552E-03
     +,   2.1743691E-03,   2.1163276E-03,   2.0640783E-03
     +,   2.0162556E-03,   1.9714742E-03,   1.9283966E-03
     +,   1.8857892E-03,   1.8425810E-03,   1.7978883E-03
     +,   1.7510314E-03,   1.7015444E-03,   1.6491772E-03
     +,   1.5938717E-03,   1.5357463E-03,   1.4750698E-03
     +,   1.4122357E-03,   1.3477314E-03,   1.2821007E-03
     +,   1.2159180E-03,   1.1497699E-03,   1.0842150E-03
     +,   1.0197730E-03,   9.5691241E-04,   8.9603488E-04
     +,   8.3746581E-04,   7.8145589E-04,   7.2818593E-04
     +,   6.7776680E-04,   6.3024485E-04,   5.8561214E-04
     +,   5.4381887E-04,   5.0477940E-04,   4.6837906E-04
     +,   4.3448570E-04,   4.0295906E-04,   3.7365148E-04
     +,   3.4641518E-04,   3.2110891E-04,   2.9759671E-04
     +,   2.7575024E-04,   2.5544968E-04,   2.3658572E-04
     +,   2.1905827E-04,   2.0277432E-04,   1.8764813E-04
     +,   1.7360289E-04,   1.6056550E-04,   1.4846998E-04
     +,   1.3725326E-04,   1.2685778E-04,   1.1722799E-04
     +,   1.0831294E-04,   1.0006318E-04,   9.2433103E-05
     +,   8.5378524E-05,   7.8858662E-05,   7.2834278E-05
     +,   6.7268527E-05,   6.2127314E-05,   5.7377962E-05
     +,   5.2990621E-05,   4.8936843E-05,   4.5190824E-05
     +,   4.1728079E-05,   3.8526505E-05,   3.5565317E-05
     +,   3.2825759E-05,   3.0290304E-05,   2.7943204E-05
     +,   2.5769732E-05,   2.3756731E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt85 = Yx/0.45556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.1063202E-05,   5.2975527E-05
     +,   5.4943703E-05,   5.6969111E-05,   5.9053255E-05
     +,   6.1197585E-05,   6.3403648E-05,   6.5672990E-05
     +,   6.8007110E-05,   7.0407659E-05,   7.2876152E-05
     +,   7.5414107E-05,   7.8023033E-05,   8.0704318E-05
     +,   8.3459374E-05,   8.6289503E-05,   8.9195790E-05
     +,   9.2179296E-05,   9.5240859E-05,   9.8381148E-05
     +,   1.0160061E-04,   1.0489949E-04,   1.0827763E-04
     +,   1.1173486E-04,   1.1527028E-04,   1.1888302E-04
     +,   1.2257160E-04,   1.2633421E-04,   1.3016870E-04
     +,   1.3407225E-04,   1.3804181E-04,   1.4207383E-04
     +,   1.4616411E-04,   1.5030814E-04,   1.5450084E-04
     +,   1.5873666E-04,   1.6300962E-04,   1.6731312E-04
     +,   1.7164048E-04,   1.7598405E-04,   1.8033646E-04
     +,   1.8468953E-04,   1.8903498E-04,   1.9336418E-04
     +,   1.9766857E-04,   2.0193929E-04,   2.0616739E-04
     +,   2.1034418E-04,   2.1446103E-04,   2.1850945E-04
     +,   2.2248128E-04,   2.2636892E-04,   2.3016513E-04
     +,   2.3386342E-04,   2.3745785E-04,   2.4094360E-04
     +,   2.4431659E-04,   2.4757383E-04,   2.5071361E-04
     +,   2.5373552E-04,   2.5664046E-04,   2.5943120E-04
     +,   2.6211163E-04,   2.6468813E-04,   2.6716868E-04
     +,   2.6956349E-04,   2.7188487E-04,   2.7414784E-04
     +,   2.7636997E-04,   2.7857180E-04,   2.8077691E-04
     +,   2.8301222E-04,   2.8530875E-04,   2.8770120E-04
     +,   2.9022893E-04,   2.9293631E-04,   2.9587300E-04
     +,   2.9909454E-04,   3.0266281E-04,   3.0664681E-04
     +,   3.1112216E-04,   3.1617293E-04,   3.2189037E-04
     +,   3.2837430E-04,   3.3573105E-04,   3.4407590E-04
     +,   3.5352813E-04,   3.6421372E-04,   3.7626011E-04
     +,   3.8979662E-04,   4.0494979E-04,   4.2183953E-04
     +,   4.4057568E-04,   4.6125468E-04,   4.8395377E-04
     +,   5.0872390E-04,   5.3559069E-04,   5.6454208E-04
     +,   5.9553201E-04,   6.2847120E-04,   6.6323153E-04
     +,   6.9963728E-04,   7.3747785E-04,   7.7650085E-04
     +,   8.1642752E-04,   8.5695955E-04,   8.9779007E-04
     +,   9.3862298E-04,   9.7919710E-04,   1.0193076E-03
     +,   1.0588334E-03,   1.0977763E-03,   1.1362839E-03
     +,   1.1746974E-03,   1.2135667E-03,   1.2536927E-03
     +,   1.2961304E-03,   1.3422018E-03,   1.3934788E-03
     +,   1.4517579E-03,   1.5190124E-03,   1.5973181E-03
     +,   1.6887763E-03,   1.7954321E-03,   1.9191750E-03
     +,   2.0616492E-03,   2.2242065E-03,   2.4078526E-03
     +,   2.6133140E-03,   2.8410638E-03,   3.0915390E-03
     +,   3.3652931E-03,   3.6633282E-03,   3.9873016E-03
     +,   4.3398794E-03,   4.7250125E-03,   5.1481538E-03
     +,   5.6163850E-03,   6.1383448E-03,   6.7236107E-03
     +,   7.3814397E-03,   8.1190271E-03,   8.9393873E-03
     +,   9.8392321E-03,   1.0807611E-02,   1.1826644E-02
     +,   1.2874782E-02,   1.3933593E-02,   1.4997925E-02
     +,   1.6087521E-02,   1.7257998E-02,   1.8606491E-02
     +,   2.0263672E-02,   2.2359308E-02,   2.4957126E-02
     +,   2.7988307E-02,   3.1239672E-02,   3.4426700E-02
     +,   3.7304539E-02,   3.9739005E-02,   4.1721463E-02
     +,   4.3364182E-02,   4.4859596E-02,   4.6344452E-02
     +,   4.7722988E-02,   4.8633233E-02,   4.8625838E-02
     +,   4.7395594E-02,   4.4891573E-02,   4.1309826E-02
     +,   3.7051301E-02,   3.2643702E-02,   2.8601069E-02
     +,   2.5272440E-02,   2.2775548E-02,   2.1038372E-02
     +,   1.9895339E-02,   1.9179085E-02,   1.8785691E-02
     +,   1.8701917E-02,   1.8982748E-02,   1.9684389E-02
     +,   2.0784505E-02,   2.2136413E-02,   2.3491737E-02
     +,   2.4585214E-02,   2.5234511E-02,   2.5393991E-02
     +,   2.5133496E-02,   2.4565458E-02,   2.3775861E-02
     +,   2.2802638E-02,   2.1662761E-02,   2.0392107E-02
     +,   1.9060746E-02,   1.7755026E-02,   1.6546370E-02
     +,   1.5471569E-02,   1.4534694E-02,   1.3721543E-02
     +,   1.3012524E-02,   1.2387904E-02,   1.1828019E-02
     +,   1.1313461E-02,   1.0827182E-02,   1.0356345E-02
     +,   9.8928874E-03,   9.4320960E-03,   8.9709871E-03
     +,   8.5078329E-03,   8.0429409E-03,   7.5798333E-03
     +,   7.1257087E-03,   6.6906605E-03,   6.2858523E-03
     +,   5.9213466E-03,   5.6040962E-03,   5.3368532E-03
     +,   5.1180222E-03,   4.9424204E-03,   4.8024273E-03
     +,   4.6894299E-03,   4.5950138E-03,   4.5118039E-03
     +,   4.4338694E-03,   4.3567903E-03,   4.2774868E-03
     +,   4.1939127E-03,   4.1047968E-03,   4.0094126E-03
     +,   3.9074849E-03,   3.7991083E-03,   3.6847203E-03
     +,   3.5650884E-03,   3.4412614E-03,   3.3144848E-03
     +,   3.1860857E-03,   3.0573811E-03,   2.9295469E-03
     +,   2.8035301E-03,   2.6799957E-03,   2.5593198E-03
     +,   2.4416086E-03,   2.3267334E-03,   2.2144173E-03
     +,   2.1043022E-03,   1.9960427E-03,   1.8893335E-03
     +,   1.7839841E-03,   1.6799499E-03,   1.5773186E-03
     +,   1.4763183E-03,   1.3772983E-03,   1.2806929E-03
     +,   1.1869791E-03,   1.0966497E-03,   1.0101778E-03
     +,   9.2798634E-04,   8.5041899E-04,   7.7772804E-04
     +,   7.1007595E-04,   6.4752431E-04,   5.9003773E-04
     +,   5.3749711E-04,   4.8971671E-04,   4.4644889E-04
     +,   4.0740301E-04,   3.7226378E-04,   3.4069989E-04
     +,   3.1237499E-04,   2.8695908E-04,   2.6413775E-04
     +,   2.4361598E-04,   2.2512022E-04,   2.0840271E-04
     +,   1.9324331E-04,   1.7944576E-04,   1.6684039E-04
     +,   1.5527876E-04,   1.4463502E-04,   1.3480075E-04
     +,   1.2568515E-04,   1.1721051E-04,   1.0931246E-04
     +,   1.0193581E-04,   9.5034869E-05,   8.8570239E-05
     +,   8.2508443E-05,   7.6821219E-05,   7.1483271E-05
     +,   6.6473076E-05,   6.1770959E-05,   5.7359732E-05
     +,   5.3223172E-05,   4.9346854E-05,   4.5716846E-05
     +,   4.2320524E-05,   3.9145485E-05,   3.6180263E-05
     +,   3.3413529E-05,   3.0834763E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt90 = Yx/0.44436
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1188472E-05,   3.2278058E-05
     +,   3.3386077E-05,   3.4511959E-05,   3.5655085E-05
     +,   3.6814814E-05,   3.7990500E-05,   3.9181476E-05
     +,   4.0387029E-05,   4.1606501E-05,   4.2839187E-05
     +,   4.4084369E-05,   4.5341349E-05,   4.6609439E-05
     +,   4.7887945E-05,   4.9176197E-05,   5.0473536E-05
     +,   5.1779331E-05,   5.3092954E-05,   5.4413824E-05
     +,   5.5741388E-05,   5.7075107E-05,   5.8414462E-05
     +,   5.9759084E-05,   6.1108418E-05,   6.2462175E-05
     +,   6.3819964E-05,   6.5181492E-05,   6.6546476E-05
     +,   6.7914669E-05,   6.9285852E-05,   7.0659902E-05
     +,   7.2036637E-05,   7.3415940E-05,   7.4797746E-05
     +,   7.6181990E-05,   7.7568598E-05,   7.8957528E-05
     +,   8.0348873E-05,   8.1742466E-05,   8.3138446E-05
     +,   8.4536769E-05,   8.5937456E-05,   8.7340544E-05
     +,   8.8746063E-05,   9.0154062E-05,   9.1564609E-05
     +,   9.2977789E-05,   9.4393668E-05,   9.5812444E-05
     +,   9.7234304E-05,   9.8659548E-05,   1.0008848E-04
     +,   1.0152169E-04,   1.0295964E-04,   1.0440316E-04
     +,   1.0585319E-04,   1.0731095E-04,   1.0877786E-04
     +,   1.1025568E-04,   1.1174648E-04,   1.1325285E-04
     +,   1.1477763E-04,   1.1632435E-04,   1.1789708E-04
     +,   1.1950031E-04,   1.2113946E-04,   1.2282052E-04
     +,   1.2455038E-04,   1.2633661E-04,   1.2818805E-04
     +,   1.3011403E-04,   1.3212541E-04,   1.3423368E-04
     +,   1.3645181E-04,   1.3879382E-04,   1.4127503E-04
     +,   1.4391173E-04,   1.4672191E-04,   1.4972471E-04
     +,   1.5294032E-04,   1.5639079E-04,   1.6009877E-04
     +,   1.6408869E-04,   1.6838570E-04,   1.7301664E-04
     +,   1.7800856E-04,   1.8339005E-04,   1.8918973E-04
     +,   1.9543705E-04,   2.0216181E-04,   2.0939345E-04
     +,   2.1716057E-04,   2.2549181E-04,   2.3441466E-04
     +,   2.4395410E-04,   2.5413459E-04,   2.6497641E-04
     +,   2.7649914E-04,   2.8871710E-04,   3.0164304E-04
     +,   3.1528421E-04,   3.2964614E-04,   3.4472829E-04
     +,   3.6052847E-04,   3.7704117E-04,   3.9425772E-04
     +,   4.1216789E-04,   4.3076157E-04,   4.5003128E-04
     +,   4.6996976E-04,   4.9057760E-04,   5.1186042E-04
     +,   5.3383649E-04,   5.5653439E-04,   5.8000116E-04
     +,   6.0429994E-04,   6.2951923E-04,   6.5576937E-04
     +,   6.8319088E-04,   7.1195455E-04,   7.4226112E-04
     +,   7.7434437E-04,   8.0847001E-04,   8.4493327E-04
     +,   8.8405045E-04,   9.2615816E-04,   9.7159651E-04
     +,   1.0207033E-03,   1.0737926E-03,   1.1311485E-03
     +,   1.1929980E-03,   1.2595123E-03,   1.3307756E-03
     +,   1.4068016E-03,   1.4875201E-03,   1.5727864E-03
     +,   1.6623987E-03,   1.7561225E-03,   1.8537184E-03
     +,   1.9549581E-03,   2.0596643E-03,   2.1677387E-03
     +,   2.2791859E-03,   2.3941265E-03,   2.5128573E-03
     +,   2.6358773E-03,   2.7639193E-03,   2.8980032E-03
     +,   3.0394725E-03,   3.1899833E-03,   3.3514726E-03
     +,   3.5261186E-03,   3.7163419E-03,   3.9248653E-03
     +,   4.1548349E-03,   4.4100177E-03,   4.6948665E-03
     +,   5.0140969E-03,   5.3715617E-03,   5.7683359E-03
     +,   6.2001110E-03,   6.6545778E-03,   7.1100597E-03
     +,   7.5363251E-03,   7.8983083E-03,   8.1625432E-03
     +,   8.3050048E-03,   8.3182631E-03,   8.2157608E-03
     +,   8.0319354E-03,   7.8179725E-03,   7.6346714E-03
     +,   7.5445632E-03,   7.6052723E-03,   7.8650145E-03
     +,   8.3597600E-03,   9.1113150E-03,   1.0128638E-02
     +,   1.1418139E-02,   1.3006741E-02,   1.4967285E-02
     +,   1.7417118E-02,   2.0464350E-02,   2.4123810E-02
     +,   2.8283238E-02,   3.2762460E-02,   3.7352242E-02
     +,   4.1716158E-02,   4.5387663E-02,   4.8172180E-02
     +,   5.0521266E-02,   5.3097643E-02,   5.5894502E-02
     +,   5.8187116E-02,   5.9384014E-02,   5.9379641E-02
     +,   5.8091130E-02,   5.5434890E-02,   5.1837862E-02
     +,   4.8162110E-02,   4.5068175E-02,   4.2650901E-02
     +,   4.0569995E-02,   3.8402926E-02,   3.5951566E-02
     +,   3.3325147E-02,   3.0758386E-02,   2.8382346E-02
     +,   2.6187971E-02,   2.4142135E-02,   2.2267615E-02
     +,   2.0621726E-02,   1.9235786E-02,   1.8081663E-02
     +,   1.7083075E-02,   1.6152004E-02,   1.5222034E-02
     +,   1.4261189E-02,   1.3267095E-02,   1.2256434E-02
     +,   1.1257845E-02,   1.0307050E-02,   9.4400635E-03
     +,   8.6843027E-03,   8.0515286E-03,   7.5361365E-03
     +,   7.1193376E-03,   6.7762844E-03,   6.4827804E-03
     +,   6.2191929E-03,   5.9714117E-03,   5.7300040E-03
     +,   5.4888534E-03,   5.2440795E-03,   4.9935291E-03
     +,   4.7366736E-03,   4.4746338E-03,   4.2100097E-03
     +,   3.9465115E-03,   3.6884139E-03,   3.4399875E-03
     +,   3.2049606E-03,   2.9861694E-03,   2.7854345E-03
     +,   2.6035747E-03,   2.4405373E-03,   2.2955730E-03
     +,   2.1674361E-03,   2.0545586E-03,   1.9551460E-03
     +,   1.8672880E-03,   1.7890264E-03,   1.7184060E-03
     +,   1.6535305E-03,   1.5926124E-03,   1.5340415E-03
     +,   1.4764194E-03,   1.4186007E-03,   1.3597179E-03
     +,   1.2991958E-03,   1.2367390E-03,   1.1723123E-03
     +,   1.1061075E-03,   1.0385113E-03,   9.7004900E-04
     +,   9.0134260E-04,   8.3306804E-04,   7.6591107E-04
     +,   7.0052454E-04,   6.3750363E-04,   5.7736551E-04
     +,   5.2053086E-04,   4.6731203E-04,   4.1791561E-04
     +,   3.7245112E-04,   3.3092833E-04,   2.9328166E-04
     +,   2.5937217E-04,   2.2901277E-04,   2.0197325E-04
     +,   1.7800201E-04,   1.5683091E-04,   1.3819194E-04
     +,   1.2181991E-04,   1.0746359E-04,   9.4886520E-05
     +,   8.3871550E-05,   7.4223135E-05,   6.5765511E-05
     +,   5.8344365E-05,   5.1823856E-05,   4.6086821E-05
     +,   4.1031399E-05,   3.6570571E-05,   3.2629257E-05
     +,   2.9143528E-05,   2.6058120E-05,   2.3325932E-05
     +,   2.0905940E-05,   1.8762878E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_htt95 = Yx/0.43036
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5539165E-06,   3.8744774E-06
     +,   4.2181023E-06,   4.5858474E-06,   4.9787523E-06
     +,   5.3978424E-06,   5.8441133E-06,   6.3185230E-06
     +,   6.8219824E-06,   7.3553679E-06,   7.9194715E-06
     +,   8.5150205E-06,   9.1426582E-06,   9.8029304E-06
     +,   1.0496285E-05,   1.1223051E-05,   1.1983434E-05
     +,   1.2777503E-05,   1.3605183E-05,   1.4466243E-05
     +,   1.5360289E-05,   1.6286753E-05,   1.7244871E-05
     +,   1.8233768E-05,   1.9252244E-05,   2.0299040E-05
     +,   2.1372616E-05,   2.2471264E-05,   2.3593062E-05
     +,   2.4735906E-05,   2.5897489E-05,   2.7075317E-05
     +,   2.8266726E-05,   2.9468873E-05,   3.0678755E-05
     +,   3.1893233E-05,   3.3109016E-05,   3.4322715E-05
     +,   3.5530909E-05,   3.6729940E-05,   3.7916270E-05
     +,   3.9086251E-05,   4.0236220E-05,   4.1362564E-05
     +,   4.2461717E-05,   4.3530137E-05,   4.4564458E-05
     +,   4.5561381E-05,   4.6517755E-05,   4.7430643E-05
     +,   4.8297275E-05,   4.9115111E-05,   4.9881852E-05
     +,   5.0595485E-05,   5.1254225E-05,   5.1856634E-05
     +,   5.2401530E-05,   5.2888103E-05,   5.3315816E-05
     +,   5.3684485E-05,   5.3994248E-05,   5.4245578E-05
     +,   5.4439235E-05,   5.4576332E-05,   5.4658271E-05
     +,   5.4686738E-05,   5.4663691E-05,   5.4591343E-05
     +,   5.4472133E-05,   5.4308730E-05,   5.4103948E-05
     +,   5.3860811E-05,   5.3582437E-05,   5.3272066E-05
     +,   5.2933010E-05,   5.2568619E-05,   5.2182284E-05
     +,   5.1777410E-05,   5.1357300E-05,   5.0925246E-05
     +,   5.0484494E-05,   5.0038132E-05,   4.9589180E-05
     +,   4.9140464E-05,   4.8694743E-05,   4.8254544E-05
     +,   4.7822290E-05,   4.7400194E-05,   4.6990328E-05
     +,   4.6594567E-05,   4.6214631E-05,   4.5852095E-05
     +,   4.5508405E-05,   4.5184828E-05,   4.4882512E-05
     +,   4.4602544E-05,   4.4345899E-05,   4.4113465E-05
     +,   4.3906115E-05,   4.3724682E-05,   4.3569962E-05
     +,   4.3442808E-05,   4.3344025E-05,   4.3274526E-05
     +,   4.3235221E-05,   4.3227108E-05,   4.3251213E-05
     +,   4.3308664E-05,   4.3400611E-05,   4.3528285E-05
     +,   4.3692944E-05,   4.3895889E-05,   4.4138407E-05
     +,   4.4421806E-05,   4.4747329E-05,   4.5116205E-05
     +,   4.5529512E-05,   4.5988319E-05,   4.6493496E-05
     +,   4.7045800E-05,   4.7645874E-05,   4.8294176E-05
     +,   4.8991024E-05,   4.9736653E-05,   5.0531256E-05
     +,   5.1374889E-05,   5.2267766E-05,   5.3210089E-05
     +,   5.4202388E-05,   5.5245353E-05,   5.6340221E-05
     +,   5.7488560E-05,   5.8692713E-05,   5.9955542E-05
     +,   6.1280771E-05,   6.2672894E-05,   6.4137057E-05
     +,   6.5679065E-05,   6.7305344E-05,   6.9022615E-05
     +,   7.0837472E-05,   7.2756076E-05,   7.4783806E-05
     +,   7.6924545E-05,   7.9179852E-05,   8.1548664E-05
     +,   8.4026404E-05,   8.6604065E-05,   8.9267800E-05
     +,   9.1998481E-05,   9.4771269E-05,   9.7555247E-05
     +,   1.0031380E-04,   1.0300542E-04,   1.0558455E-04
     +,   1.0800310E-04,   1.1021300E-04,   1.1216968E-04
     +,   1.1383603E-04,   1.1518765E-04,   1.1621967E-04
     +,   1.1695410E-04,   1.1744811E-04,   1.1780273E-04
     +,   1.1817077E-04,   1.1876286E-04,   1.1985051E-04
     +,   1.2176442E-04,   1.2488724E-04,   1.2964036E-04
     +,   1.3646517E-04,   1.4580227E-04,   1.5807481E-04
     +,   1.7368168E-04,   1.9301065E-04,   2.1648906E-04
     +,   2.4467267E-04,   2.7837834E-04,   3.1885400E-04
     +,   3.6795603E-04,   4.2827870E-04,   5.0316926E-04
     +,   5.9657247E-04,   7.1265921E-04,   8.5522479E-04
     +,   1.0269285E-03,   1.2285229E-03,   1.4582259E-03
     +,   1.7113504E-03,   1.9802691E-03,   2.2548221E-03
     +,   2.5229282E-03,   2.7714011E-03,   2.9869019E-03
     +,   3.1569656E-03,   3.2710431E-03,   3.3215762E-03
     +,   3.3049730E-03,   3.2222550E-03,   3.0791813E-03
     +,   2.8857337E-03,   2.6549543E-03,   2.4013210E-03
     +,   2.1390431E-03,   1.8806042E-03,   1.6357077E-03
     +,   1.4108913E-03,   1.2096687E-03,   1.0330130E-03
     +,   8.8003103E-04,   7.4867322E-04,   6.3633115E-04
     +,   5.4026628E-04,   4.5789636E-04,   3.8696273E-04
     +,   3.2559922E-04,   2.7232603E-04,   2.2600511E-04
     +,   1.8578079E-04,   1.5100962E-04,   1.2118217E-04
     +,   9.5867879E-05,   7.4670410E-05,   5.7196670E-05
     +,   4.3042590E-05,   3.1793905E-05,   2.3034385E-05
     +,   1.6357271E-05,   1.1378635E-05,   7.7498107E-06
     +,   5.1657307E-06,   3.3686777E-06,   2.1484982E-06
     +,   1.3398105E-06,   8.1679644E-07,   4.8672393E-07
     +,   2.8347597E-07,   1.6137534E-07,   8.9810641E-08
     +,   4.8881688E-08,   2.6037421E-08,   1.3591211E-08
     +,   6.9683899E-09,   3.5232453E-09,   1.7686009E-09
     +,   8.9135876E-10,   4.5880277E-10,   2.4672420E-10
     +,   1.4194015E-10,   8.8697667E-11,   6.0129096E-11
     +,   4.3528833E-11,   3.2957824E-11,   2.5637433E-11
     +,   2.0239853E-11,   1.6097809E-11,   1.2846815E-11
     +,   1.0265250E-11,   8.2037649E-12,   6.5536682E-12
     +,   5.2319464E-12,   4.1733730E-12,   3.3259253E-12
     +,   2.6479418E-12,   2.1060118E-12,   1.6732012E-12
     +,   1.3278507E-12,   1.0525785E-12,   8.3339634E-13
     +,   6.5905961E-13,   5.2054536E-13,   4.1062504E-13
     +,   3.2350251E-13,   2.5453199E-13,   1.9999903E-13
     +,   1.5693993E-13,   1.2298257E-13,   9.6240771E-14
     +,   7.5208530E-14,   5.8690601E-14,   4.5735405E-14
     +,   3.5589475E-14,   2.7654365E-14,   2.1457671E-14
     +,   1.6625237E-14,   1.2862505E-14,   9.9368374E-15
     +,   7.6653043E-15,   5.9044088E-15,   4.5412846E-15
     +,   3.4877308E-15,   2.6746107E-15,   2.0480374E-15
     +,   1.5659104E-15,   1.1955129E-15,   9.1136468E-16
     +,   6.9372549E-16,   5.2726996E-16,   4.0016160E-16
     +,   3.0324095E-16,   2.2945501E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt100 = Yx/0.01725
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0236981E-05,   1.0829631E-05
     +,   1.1441543E-05,   1.2072189E-05,   1.2720941E-05
     +,   1.3387067E-05,   1.4069749E-05,   1.4768057E-05
     +,   1.5480957E-05,   1.6207352E-05,   1.6946024E-05
     +,   1.7695666E-05,   1.8454892E-05,   1.9222240E-05
     +,   1.9996158E-05,   2.0775040E-05,   2.1557214E-05
     +,   2.2340966E-05,   2.3124519E-05,   2.3906074E-05
     +,   2.4683821E-05,   2.5455909E-05,   2.6220505E-05
     +,   2.6975807E-05,   2.7719972E-05,   2.8451264E-05
     +,   2.9167950E-05,   2.9868366E-05,   3.0550924E-05
     +,   3.1214113E-05,   3.1856529E-05,   3.2476863E-05
     +,   3.3073924E-05,   3.3646658E-05,   3.4194145E-05
     +,   3.4715606E-05,   3.5210425E-05,   3.5678135E-05
     +,   3.6118468E-05,   3.6531288E-05,   3.6916645E-05
     +,   3.7274789E-05,   3.7606147E-05,   3.7911283E-05
     +,   3.8191003E-05,   3.8446229E-05,   3.8678092E-05
     +,   3.8887880E-05,   3.9077029E-05,   3.9247137E-05
     +,   3.9399936E-05,   3.9537314E-05,   3.9661223E-05
     +,   3.9773786E-05,   3.9877177E-05,   3.9973664E-05
     +,   4.0065588E-05,   4.0155322E-05,   4.0245293E-05
     +,   4.0337927E-05,   4.0435669E-05,   4.0540937E-05
     +,   4.0656119E-05,   4.0783580E-05,   4.0925599E-05
     +,   4.1084390E-05,   4.1262098E-05,   4.1460735E-05
     +,   4.1682237E-05,   4.1928401E-05,   4.2200933E-05
     +,   4.2501339E-05,   4.2831070E-05,   4.3191394E-05
     +,   4.3583455E-05,   4.4008277E-05,   4.4466731E-05
     +,   4.4959568E-05,   4.5487457E-05,   4.6050965E-05
     +,   4.6650512E-05,   4.7286543E-05,   4.7959344E-05
     +,   4.8669281E-05,   4.9416576E-05,   5.0201590E-05
     +,   5.1024588E-05,   5.1885967E-05,   5.2786123E-05
     +,   5.3725602E-05,   5.4705037E-05,   5.5725133E-05
     +,   5.6786714E-05,   5.7890797E-05,   5.9038550E-05
     +,   6.0231141E-05,   6.1470048E-05,   6.2756655E-05
     +,   6.4092616E-05,   6.5479471E-05,   6.6918961E-05
     +,   6.8412599E-05,   6.9962029E-05,   7.1568531E-05
     +,   7.3233350E-05,   7.4957439E-05,   7.6741278E-05
     +,   7.8584897E-05,   8.0487909E-05,   8.2449318E-05
     +,   8.4467225E-05,   8.6539178E-05,   8.8661611E-05
     +,   9.0830232E-05,   9.3039489E-05,   9.5283052E-05
     +,   9.7553129E-05,   9.9841120E-05,   1.0213703E-04
     +,   1.0442986E-04,   1.0670759E-04,   1.0895696E-04
     +,   1.1116378E-04,   1.1331312E-04,   1.1538930E-04
     +,   1.1737589E-04,   1.1925626E-04,   1.2101330E-04
     +,   1.2263007E-04,   1.2408964E-04,   1.2537562E-04
     +,   1.2647209E-04,   1.2736420E-04,   1.2803791E-04
     +,   1.2848072E-04,   1.2868154E-04,   1.2863093E-04
     +,   1.2832142E-04,   1.2774749E-04,   1.2690577E-04
     +,   1.2579514E-04,   1.2441677E-04,   1.2277410E-04
     +,   1.2087281E-04,   1.1872106E-04,   1.1632896E-04
     +,   1.1370876E-04,   1.1087480E-04,   1.0784336E-04
     +,   1.0463221E-04,   1.0126088E-04,   9.7750686E-05
     +,   9.4124662E-05,   9.0407397E-05,   8.6625594E-05
     +,   8.2808743E-05,   7.8989513E-05,   7.5204385E-05
     +,   7.1494920E-05,   6.7909386E-05,   6.4503423E-05
     +,   6.1341947E-05,   5.8500806E-05,   5.6068006E-05
     +,   5.4144981E-05,   5.2848136E-05,   5.2310155E-05
     +,   5.2681193E-05,   5.4130705E-05,   5.6850262E-05
     +,   6.1057290E-05,   6.7001354E-05,   7.4974247E-05
     +,   8.5323634E-05,   9.8470009E-05,   1.1493119E-04
     +,   1.3534611E-04,   1.6049606E-04,   1.9132046E-04
     +,   2.2892073E-04,   2.7454167E-04,   3.2952835E-04
     +,   3.9526817E-04,   4.7312534E-04,   5.6436652E-04
     +,   6.7009375E-04,   7.9119945E-04,   9.2833332E-04
     +,   1.0818392E-03,   1.2516314E-03,   1.4370391E-03
     +,   1.6365282E-03,   1.8473510E-03,   2.0652357E-03
     +,   2.2841955E-03,   2.4965361E-03,   2.6931923E-03
     +,   2.8644577E-03,   3.0009905E-03,   3.0949221E-03
     +,   3.1408789E-03,   3.1366979E-03,   3.0836295E-03
     +,   2.9860074E-03,   2.8504971E-03,   2.6850684E-03
     +,   2.4979855E-03,   2.2970098E-03,   2.0889130E-03
     +,   1.8793005E-03,   1.6727251E-03,   1.4729095E-03
     +,   1.2829358E-03,   1.1053451E-03,   9.4215968E-04
     +,   7.9483050E-04,   6.6414225E-04,   5.5017113E-04
     +,   4.5233243E-04,   3.6950110E-04,   3.0016107E-04
     +,   2.4260393E-04,   1.9510380E-04,   1.5604369E-04
     +,   1.2399540E-04,   9.7755183E-05,   7.6338656E-05
     +,   5.8948423E-05,   4.4934492E-05,   3.3757857E-05
     +,   2.4960103E-05,   1.8141302E-05,   1.2947608E-05
     +,   9.0663962E-06,   6.2246195E-06,   4.1876979E-06
     +,   2.7594415E-06,   1.7803299E-06,   1.1243375E-06
     +,   6.9487487E-07,   4.2019079E-07,   2.4857900E-07
     +,   1.4385439E-07,   8.1429668E-08,   4.5082917E-08
     +,   2.4412232E-08,   1.2929357E-08,   6.6976948E-09
     +,   3.3937104E-09,   1.6823107E-09,   8.1606000E-10
     +,   3.8753276E-10,   1.8031222E-10,   8.2320782E-11
     +,   3.6972491E-11,   1.6411917E-11,   7.2609510E-12
     +,   3.2479050E-12,   1.5021242E-12,   7.3979879E-13
     +,   3.9906116E-13,   2.3866063E-13,   1.5654586E-13
     +,   1.0984829E-13,   8.0422316E-14,   6.0335458E-14
     +,   4.5888491E-14,   3.5176414E-14,   2.7097485E-14
     +,   2.0945039E-14,   1.6231657E-14,   1.2605966E-14
     +,   9.8081536E-15,   7.6432696E-15,   5.9641394E-15
     +,   4.6591153E-15,   3.6428990E-15,   2.8503281E-15
     +,   2.2312970E-15,   1.7472741E-15,   1.3684392E-15
     +,   1.0717389E-15,   8.3923611E-16,   6.5699274E-16
     +,   5.1411342E-16,   4.0210838E-16,   3.1431693E-16
     +,   2.4552481E-16,   1.9164597E-16,   1.4946761E-16
     +,   1.1647141E-16,   9.0675592E-17,   7.0525670E-17
     +,   5.4798456E-17,   4.2534934E-17,   3.2980889E-17
     +,   2.5545548E-17,   1.9764592E-17,   1.5274972E-17
     +,   1.1791772E-17,   9.0925769E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt102 = Yx/0.0185
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2660612E-05,   2.2980372E-05
     +,   2.3300550E-05,   2.3620894E-05,   2.3941138E-05
     +,   2.4261006E-05,   2.4580202E-05,   2.4898423E-05
     +,   2.5215353E-05,   2.5530668E-05,   2.5844030E-05
     +,   2.6155094E-05,   2.6463493E-05,   2.6768868E-05
     +,   2.7070850E-05,   2.7369048E-05,   2.7663078E-05
     +,   2.7952547E-05,   2.8237062E-05,   2.8516219E-05
     +,   2.8789613E-05,   2.9056841E-05,   2.9317494E-05
     +,   2.9571185E-05,   2.9817489E-05,   3.0056028E-05
     +,   3.0286397E-05,   3.0508212E-05,   3.0721090E-05
     +,   3.0924657E-05,   3.1118550E-05,   3.1302410E-05
     +,   3.1475898E-05,   3.1638687E-05,   3.1790456E-05
     +,   3.1930904E-05,   3.2059743E-05,   3.2176697E-05
     +,   3.2281525E-05,   3.2373984E-05,   3.2453867E-05
     +,   3.2520973E-05,   3.2575124E-05,   3.2616175E-05
     +,   3.2643984E-05,   3.2658449E-05,   3.2659475E-05
     +,   3.2647000E-05,   3.2620985E-05,   3.2581400E-05
     +,   3.2528267E-05,   3.2461598E-05,   3.2381446E-05
     +,   3.2287891E-05,   3.2181018E-05,   3.2060954E-05
     +,   3.1927833E-05,   3.1781823E-05,   3.1623094E-05
     +,   3.1451858E-05,   3.1268337E-05,   3.1072759E-05
     +,   3.0865398E-05,   3.0646530E-05,   3.0416428E-05
     +,   3.0175419E-05,   2.9923807E-05,   2.9661947E-05
     +,   2.9390163E-05,   2.9108840E-05,   2.8818318E-05
     +,   2.8518998E-05,   2.8211249E-05,   2.7895485E-05
     +,   2.7572087E-05,   2.7241456E-05,   2.6904005E-05
     +,   2.6560154E-05,   2.6210304E-05,   2.5854859E-05
     +,   2.5494252E-05,   2.5128867E-05,   2.4759143E-05
     +,   2.4385454E-05,   2.4008235E-05,   2.3627848E-05
     +,   2.3244722E-05,   2.2859207E-05,   2.2471717E-05
     +,   2.2082611E-05,   2.1692245E-05,   2.1300988E-05
     +,   2.0909212E-05,   2.0517251E-05,   2.0125432E-05
     +,   1.9734116E-05,   1.9343614E-05,   1.8954275E-05
     +,   1.8566407E-05,   1.8180363E-05,   1.7796447E-05
     +,   1.7415030E-05,   1.7036440E-05,   1.6661070E-05
     +,   1.6289299E-05,   1.5921540E-05,   1.5558267E-05
     +,   1.5200004E-05,   1.4847310E-05,   1.4500819E-05
     +,   1.4161293E-05,   1.3829552E-05,   1.3506588E-05
     +,   1.3193505E-05,   1.2891623E-05,   1.2602426E-05
     +,   1.2327672E-05,   1.2069356E-05,   1.1829815E-05
     +,   1.1611706E-05,   1.1418084E-05,   1.1252452E-05
     +,   1.1118787E-05,   1.1021591E-05,   1.0965940E-05
     +,   1.0957527E-05,   1.1002702E-05,   1.1108502E-05
     +,   1.1282677E-05,   1.1533685E-05,   1.1870732E-05
     +,   1.2303680E-05,   1.2843087E-05,   1.3500028E-05
     +,   1.4286113E-05,   1.5213304E-05,   1.6293696E-05
     +,   1.7539329E-05,   1.8962066E-05,   2.0573261E-05
     +,   2.2383343E-05,   2.4401565E-05,   2.6635840E-05
     +,   2.9092300E-05,   3.1774693E-05,   3.4684625E-05
     +,   3.7821024E-05,   4.1179745E-05,   4.4753637E-05
     +,   4.8532675E-05,   5.2503812E-05,   5.6650737E-05
     +,   6.0954280E-05,   6.5392873E-05,   6.9942500E-05
     +,   7.4576572E-05,   7.9266363E-05,   8.3981460E-05
     +,   8.8689434E-05,   9.3355375E-05,   9.7942546E-05
     +,   1.0241194E-04,   1.0672147E-04,   1.1082642E-04
     +,   1.1467962E-04,   1.1823136E-04,   1.2143014E-04
     +,   1.2422392E-04,   1.2656282E-04,   1.2840171E-04
     +,   1.2970455E-04,   1.3045078E-04,   1.3064327E-04
     +,   1.3031822E-04,   1.2955832E-04,   1.2850846E-04
     +,   1.2739413E-04,   1.2654295E-04,   1.2640761E-04
     +,   1.2759014E-04,   1.3086436E-04,   1.3719434E-04
     +,   1.4774608E-04,   1.6388918E-04,   1.8718388E-04
     +,   2.1934780E-04,   2.6220348E-04,   3.1760725E-04
     +,   3.8734823E-04,   4.7301862E-04,   5.7588361E-04
     +,   6.9671910E-04,   8.3563704E-04,   9.9192909E-04
     +,   1.1639385E-03,   1.3489502E-03,   1.5431338E-03
     +,   1.7415939E-03,   1.9385145E-03,   2.1273848E-03
     +,   2.3013197E-03,   2.4534939E-03,   2.5776087E-03
     +,   2.6683456E-03,   2.7217716E-03,   2.7356732E-03
     +,   2.7097133E-03,   2.6454513E-03,   2.5461942E-03
     +,   2.4166880E-03,   2.2627236E-03,   2.0906895E-03
     +,   1.9071100E-03,   1.7182120E-03,   1.5296089E-03
     +,   1.3460797E-03,   1.1714348E-03,   1.0084764E-03
     +,   8.5906457E-04,   7.2423730E-04,   6.0431904E-04
     +,   4.9908453E-04,   4.0790541E-04,   3.2986753E-04
     +,   2.6387043E-04,   2.0871860E-04,   1.6318615E-04
     +,   1.2605978E-04,   9.6171185E-05,   7.2425246E-05
     +,   5.3817639E-05,   3.9442977E-05,   2.8500195E-05
     +,   2.0295251E-05,   1.4238833E-05,   9.8391347E-06
     +,   6.6946732E-06,   4.4845242E-06,   2.9571570E-06
     +,   1.9195161E-06,   1.2266454E-06,   7.7199388E-07
     +,   4.7883145E-07,   2.9305781E-07,   1.7734826E-07
     +,   1.0649057E-07,   6.3799355E-08,   3.8461174E-08
     +,   2.3615632E-08,   1.4999754E-08,   1.0016743E-08
     +,   7.1177020E-09,   5.3971911E-09,   4.3360577E-09
     +,   3.6422292E-09,   3.1543361E-09,   2.7846017E-09
     +,   2.4858142E-09,   2.2326709E-09,   2.0115161E-09
     +,   1.8147776E-09,   1.6380135E-09,   1.4783768E-09
     +,   1.3338632E-09,   1.2029282E-09,   1.0842790E-09
     +,   9.7678310E-10,   8.7944052E-10,   7.9134077E-10
     +,   7.1164957E-10,   6.3960731E-10,   5.7452004E-10
     +,   5.1575455E-10,   4.6272824E-10,   4.1490822E-10
     +,   3.7181253E-10,   3.3299632E-10,   2.9805819E-10
     +,   2.6662775E-10,   2.3837260E-10,   2.1298538E-10
     +,   1.9019082E-10,   1.6973532E-10,   1.5139151E-10
     +,   1.3495016E-10,   1.2022408E-10,   1.0704198E-10
     +,   9.5248809E-11,   8.4705444E-11,   7.5284563E-11
     +,   6.6872251E-11,   5.9364888E-11,   5.2669483E-11
     +,   4.6701597E-11,   4.1385732E-11,   3.6653212E-11
     +,   3.2442920E-11,   2.8699234E-11,   2.5372735E-11
     +,   2.2418463E-11,   1.9796650E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt104 = Yx/0.0155555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0443793E-10,   5.0759208E-10
     +,   6.3557587E-10,   7.9398077E-10,   9.8956210E-10
     +,   1.2304588E-09,   1.5264485E-09,   1.8892485E-09
     +,   2.3328524E-09,   2.8739553E-09,   3.5323644E-09
     +,   4.3315751E-09,   5.2993250E-09,   6.4683001E-09
     +,   7.8769125E-09,   9.5701411E-09,   1.1600531E-08
     +,   1.4029280E-08,   1.6927451E-08,   2.0377318E-08
     +,   2.4473865E-08,   2.9326438E-08,   3.5060364E-08
     +,   4.1819501E-08,   4.9767088E-08,   5.9089629E-08
     +,   6.9997995E-08,   8.2730665E-08,   9.7556160E-08
     +,   1.1477609E-07,   1.3472781E-07,   1.5778799E-07
     +,   1.8437514E-07,   2.1495295E-07,   2.5003376E-07
     +,   2.9018111E-07,   3.3601299E-07,   3.8820403E-07
     +,   4.4749189E-07,   5.1467003E-07,   5.9060289E-07
     +,   6.7621642E-07,   7.7250445E-07,   8.8052695E-07
     +,   1.0014112E-06,   1.1363494E-06,   1.2865978E-06
     +,   1.4534718E-06,   1.6383441E-06,   1.8426396E-06
     +,   2.0678258E-06,   2.3154084E-06,   2.5869176E-06
     +,   2.8839197E-06,   3.2079556E-06,   3.5605908E-06
     +,   3.9433548E-06,   4.3577443E-06,   4.8052034E-06
     +,   5.2871078E-06,   5.8047440E-06,   6.3593002E-06
     +,   6.9517964E-06,   7.5831572E-06,   8.2541374E-06
     +,   8.9652385E-06,   9.7168449E-06,   1.0509011E-05
     +,   1.1341650E-05,   1.2214298E-05,   1.3126333E-05
     +,   1.4076704E-05,   1.5064186E-05,   1.6087108E-05
     +,   1.7143566E-05,   1.8231331E-05,   1.9347783E-05
     +,   2.0489953E-05,   2.1654641E-05,   2.2838325E-05
     +,   2.4037063E-05,   2.5246791E-05,   2.6463009E-05
     +,   2.7681155E-05,   2.8896266E-05,   3.0103367E-05
     +,   3.1297168E-05,   3.2472421E-05,   3.3623637E-05
     +,   3.4745412E-05,   3.5832330E-05,   3.6878948E-05
     +,   3.7879927E-05,   3.8830109E-05,   3.9724524E-05
     +,   4.0558316E-05,   4.1327025E-05,   4.2026360E-05
     +,   4.2652475E-05,   4.3201824E-05,   4.3671309E-05
     +,   4.4058255E-05,   4.4360448E-05,   4.4576162E-05
     +,   4.4704164E-05,   4.4743760E-05,   4.4694760E-05
     +,   4.4557528E-05,   4.4332970E-05,   4.4022516E-05
     +,   4.3628184E-05,   4.3152490E-05,   4.2598542E-05
     +,   4.1969950E-05,   4.1270956E-05,   4.0506278E-05
     +,   3.9681319E-05,   3.8802002E-05,   3.7875012E-05
     +,   3.6907655E-05,   3.5908030E-05,   3.4885139E-05
     +,   3.3848966E-05,   3.2810512E-05,   3.1782005E-05
     +,   3.0777144E-05,   2.9811034E-05,   2.8900604E-05
     +,   2.8064536E-05,   2.7323629E-05,   2.6700718E-05
     +,   2.6220936E-05,   2.5911577E-05,   2.5802161E-05
     +,   2.5924195E-05,   2.6310960E-05,   2.6997070E-05
     +,   2.8017885E-05,   2.9408891E-05,   3.1204803E-05
     +,   3.3438402E-05,   3.6139332E-05,   3.9333023E-05
     +,   4.3039174E-05,   4.7269805E-05,   5.2028525E-05
     +,   5.7308847E-05,   6.3092462E-05,   6.9348491E-05
     +,   7.6033110E-05,   8.3088809E-05,   9.0443944E-05
     +,   9.8013501E-05,   1.0570078E-04,   1.1339830E-04
     +,   1.2098944E-04,   1.2835131E-04,   1.3535832E-04
     +,   1.4188478E-04,   1.4780776E-04,   1.5301202E-04
     +,   1.5739263E-04,   1.6085802E-04,   1.6333345E-04
     +,   1.6476332E-04,   1.6511294E-04,   1.6436953E-04
     +,   1.6254309E-04,   1.5966562E-04,   1.5579017E-04
     +,   1.5098944E-04,   1.4535344E-04,   1.3898630E-04
     +,   1.3200386E-04,   1.2453187E-04,   1.1670288E-04
     +,   1.0865660E-04,   1.0054273E-04,   9.2526250E-05
     +,   8.4798201E-05,   7.7593970E-05,   7.1219511E-05
     +,   6.6084147E-05,   6.2739942E-05,   6.1923609E-05
     +,   6.4591448E-05,   7.1936673E-05,   8.5377338E-05
     +,   1.0650048E-04,   1.3694979E-04,   1.7826658E-04
     +,   2.3168551E-04,   2.9791289E-04,   3.7694108E-04
     +,   4.6794754E-04,   5.6931132E-04,   6.7877473E-04
     +,   7.9375657E-04,   9.1174716E-04,   1.0306622E-03
     +,   1.1490519E-03,   1.2660727E-03,   1.3811718E-03
     +,   1.4935110E-03,   1.6012992E-03,   1.7012828E-03
     +,   1.7885340E-03,   1.8567459E-03,   1.8990162E-03
     +,   1.9089971E-03,   1.8821103E-03,   1.8165736E-03
     +,   1.7139597E-03,   1.5791431E-03,   1.4196887E-03
     +,   1.2448428E-03,   1.0643248E-03,   8.8718598E-04
     +,   7.2095433E-04,   5.7113561E-04,   4.4103403E-04
     +,   3.3192409E-04,   2.4341163E-04,   1.7387701E-04
     +,   1.2093558E-04,   8.1856706E-05,   5.3889471E-05
     +,   3.4486489E-05,   2.1439557E-05,   1.2939887E-05
     +,   7.5777803E-06,   4.3034406E-06,   2.3687526E-06
     +,   1.2631090E-06,   6.5225203E-07,   3.2604248E-07
     +,   1.5771290E-07,   7.3804742E-08,   3.3406781E-08
     +,   1.4622521E-08,   6.1881753E-09,   2.5316891E-09
     +,   1.0012338E-09,   3.8273457E-10,   1.4140912E-10
     +,   5.0503289E-11,   1.7440082E-11,   5.8266725E-12
     +,   1.8860987E-12,   5.9367219E-13,   1.8323727E-13
     +,   5.6565734E-14,   1.8233472E-14,   6.6156221E-15
     +,   2.9214581E-15,   1.5863080E-15,   9.9247592E-16
     +,   6.6646193E-16,   4.6084188E-16,   3.2215331E-16
     +,   2.2601205E-16,   1.5867765E-16,   1.1134678E-16
     +,   7.8045715E-17,   5.4624384E-17,   3.8166557E-17
     +,   2.6616861E-17,   1.8525122E-17,   1.2866445E-17
     +,   8.9169417E-18,   6.1659875E-18,   4.2541370E-18
     +,   2.9284224E-18,   2.0111987E-18,   1.3780489E-18
     +,   9.4203774E-19,   6.4246953E-19,   4.3714371E-19
     +,   2.9673820E-19,   2.0095810E-19,   1.3577341E-19
     +,   9.1518139E-20,   6.1542108E-20,   4.1287631E-20
     +,   2.7633859E-20,   1.8452141E-20,   1.2292137E-20
     +,   8.1692697E-21,   5.4165063E-21,   3.5828508E-21
     +,   2.3643942E-21,   1.5566267E-21,   1.0224234E-21
     +,   6.6995970E-22,   4.3797563E-22,   2.8564247E-22
     +,   1.8585698E-22,   1.2064425E-22,   7.8129649E-23
     +,   5.0477556E-23,   3.2535861E-23
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt106 = Yx/0.0102083333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.2406204E-06,   8.7132976E-06
     +,   9.2028749E-06,   9.7092043E-06,   1.0232079E-05
     +,   1.0771225E-05,   1.1326308E-05,   1.1896920E-05
     +,   1.2482583E-05,   1.3082775E-05,   1.3696880E-05
     +,   1.4324218E-05,   1.4964049E-05,   1.5615560E-05
     +,   1.6277874E-05,   1.6950053E-05,   1.7631090E-05
     +,   1.8319930E-05,   1.9015453E-05,   1.9716495E-05
     +,   2.0421841E-05,   2.1130234E-05,   2.1840366E-05
     +,   2.2550947E-05,   2.3260574E-05,   2.3967912E-05
     +,   2.4671557E-05,   2.5370111E-05,   2.6062187E-05
     +,   2.6746393E-05,   2.7421354E-05,   2.8085718E-05
     +,   2.8738157E-05,   2.9377388E-05,   3.0002169E-05
     +,   3.0611303E-05,   3.1203654E-05,   3.1778141E-05
     +,   3.2333792E-05,   3.2869662E-05,   3.3384909E-05
     +,   3.3878801E-05,   3.4350662E-05,   3.4799938E-05
     +,   3.5226174E-05,   3.5629000E-05,   3.6008172E-05
     +,   3.6363555E-05,   3.6695114E-05,   3.7002923E-05
     +,   3.7287173E-05,   3.7548161E-05,   3.7786285E-05
     +,   3.8002068E-05,   3.8196096E-05,   3.8369089E-05
     +,   3.8521855E-05,   3.8655264E-05,   3.8770304E-05
     +,   3.8868002E-05,   3.8949489E-05,   3.9015940E-05
     +,   3.9068589E-05,   3.9108720E-05,   3.9137634E-05
     +,   3.9156705E-05,   3.9167291E-05,   3.9170784E-05
     +,   3.9168572E-05,   3.9162031E-05,   3.9152546E-05
     +,   3.9141461E-05,   3.9130096E-05,   3.9119743E-05
     +,   3.9111637E-05,   3.9106955E-05,   3.9106828E-05
     +,   3.9112318E-05,   3.9124410E-05,   3.9144019E-05
     +,   3.9171962E-05,   3.9208990E-05,   3.9255734E-05
     +,   3.9312774E-05,   3.9380553E-05,   3.9459435E-05
     +,   3.9549694E-05,   3.9651477E-05,   3.9764851E-05
     +,   3.9889790E-05,   4.0026160E-05,   4.0173727E-05
     +,   4.0332172E-05,   4.0501087E-05,   4.0679985E-05
     +,   4.0868268E-05,   4.1065297E-05,   4.1270327E-05
     +,   4.1482581E-05,   4.1701169E-05,   4.1925196E-05
     +,   4.2153686E-05,   4.2385625E-05,   4.2619955E-05
     +,   4.2855583E-05,   4.3091415E-05,   4.3326298E-05
     +,   4.3559070E-05,   4.3788590E-05,   4.4013694E-05
     +,   4.4233195E-05,   4.4445969E-05,   4.4650849E-05
     +,   4.4846718E-05,   4.5032470E-05,   4.5207024E-05
     +,   4.5369332E-05,   4.5518384E-05,   4.5653193E-05
     +,   4.5772824E-05,   4.5876386E-05,   4.5963028E-05
     +,   4.6031932E-05,   4.6082350E-05,   4.6113579E-05
     +,   4.6124966E-05,   4.6115903E-05,   4.6085846E-05
     +,   4.6034289E-05,   4.5960809E-05,   4.5864999E-05
     +,   4.5746539E-05,   4.5605131E-05,   4.5440567E-05
     +,   4.5252658E-05,   4.5041277E-05,   4.4806362E-05
     +,   4.4547902E-05,   4.4265922E-05,   4.3960485E-05
     +,   4.3631735E-05,   4.3279866E-05,   4.2905096E-05
     +,   4.2507680E-05,   4.2087973E-05,   4.1646326E-05
     +,   4.1183135E-05,   4.0698877E-05,   4.0194085E-05
     +,   3.9669296E-05,   3.9125098E-05,   3.8562182E-05
     +,   3.7981306E-05,   3.7383285E-05,   3.6769041E-05
     +,   3.6139700E-05,   3.5496618E-05,   3.4841436E-05
     +,   3.4176246E-05,   3.3503849E-05,   3.2827866E-05
     +,   3.2153152E-05,   3.1486194E-05,   3.0835577E-05
     +,   3.0212490E-05,   2.9631336E-05,   2.9110377E-05
     +,   2.8672199E-05,   2.8344008E-05,   2.8157756E-05
     +,   2.8149809E-05,   2.8360009E-05,   2.8830216E-05
     +,   2.9602132E-05,   3.0714353E-05,   3.2199147E-05
     +,   3.4078927E-05,   3.6362759E-05,   3.9044156E-05
     +,   4.2100633E-05,   4.5496061E-05,   4.9186616E-05
     +,   5.3132804E-05,   5.7317702E-05,   6.1772567E-05
     +,   6.6610031E-05,   7.2065654E-05,   7.8545178E-05
     +,   8.6674059E-05,   9.7343152E-05,   1.1174698E-04
     +,   1.3140151E-04,   1.5813425E-04,   1.9404361E-04
     +,   2.4142841E-04,   3.0268641E-04,   3.8019256E-04
     +,   4.7618090E-04,   5.9264147E-04,   7.3121465E-04
     +,   8.9306803E-04,   1.0787511E-03,   1.2879752E-03
     +,   1.5192704E-03,   1.7695248E-03,   2.0335594E-03
     +,   2.3037291E-03,   2.5697646E-03,   2.8190669E-03
     +,   3.0374934E-03,   3.2106233E-03,   3.3253685E-03
     +,   3.3717181E-03,   3.3442220E-03,   3.2429018E-03
     +,   3.0734339E-03,   2.8465099E-03,   2.5764941E-03
     +,   2.2796784E-03,   1.9724811E-03,   1.6697660E-03
     +,   1.3836946E-03,   1.1231146E-03,   8.9343183E-04
     +,   6.9691287E-04,   5.3329009E-04,   4.0046379E-04
     +,   2.9516779E-04,   2.1355323E-04,   1.5165145E-04
     +,   1.0568911E-04,   7.2272880E-05,   4.8483245E-05
     +,   3.1902586E-05,   2.0593467E-05,   1.3046600E-05
     +,   8.1207345E-06,   4.9767887E-06,   3.0143708E-06
     +,   1.8157009E-06,   1.0982977E-06,   6.7651786E-07
     +,   4.3176047E-07,   2.9041536E-07,   2.0811765E-07
     +,   1.5888743E-07,   1.2793099E-07,   1.0704986E-07
     +,   9.1814002E-08,   7.9878561E-08,   7.0015155E-08
     +,   6.1578284E-08,   5.4218731E-08,   4.7734261E-08
     +,   4.1994848E-08,   3.6907142E-08,   3.2397367E-08
     +,   2.8403074E-08,   2.4869161E-08,   2.1746494E-08
     +,   1.8991011E-08,   1.6563000E-08,   1.4426409E-08
     +,   1.2548852E-08,   1.0901337E-08,   9.4576400E-09
     +,   8.1942826E-09,   7.0903243E-09,   6.1270287E-09
     +,   5.2876130E-09,   4.5571507E-09,   3.9224086E-09
     +,   3.3716290E-09,   2.8943530E-09,   2.4813396E-09
     +,   2.1244548E-09,   1.8164827E-09,   1.5511041E-09
     +,   1.3227338E-09,   1.1264955E-09,   9.5809460E-10
     +,   8.1379048E-10,   6.9029882E-10,   5.8477267E-10
     +,   4.9471760E-10,   4.1797724E-10,   3.5267117E-10
     +,   2.9717168E-10,   2.5007402E-10,   2.1015993E-10
     +,   1.7638220E-10,   1.4783549E-10,   1.2374467E-10
     +,   1.0344111E-10,   8.6354132E-11,   7.1993217E-11
     +,   5.9940927E-11,   4.9839490E-11,   4.1385378E-11
     +,   3.4319249E-11,   2.8421805E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt108 = Yx/0.0155555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   3.5516414E-38
     +,   1.1871444E-37,   3.9301256E-37,   1.2887656E-36
     +,   4.1853134E-36,   1.3461214E-35,   4.2881756E-35
     +,   1.3529436E-34,   4.2277476E-34,   1.3084505E-33
     +,   4.0108007E-33,   1.2176493E-32,   3.6613167E-32
     +,   1.0903638E-31,   3.2160881E-31,   9.3951480E-31
     +,   2.7183271E-30,   7.7897599E-30,   2.2108403E-29
     +,   6.2147930E-29,   1.7302295E-28,   4.7710080E-28
     +,   1.3029800E-27,   3.5244117E-27,   9.4418816E-27
     +,   2.5052358E-26,   6.5836273E-26,   1.7136024E-25
     +,   4.4173494E-25,   1.1278126E-24,   2.8519862E-24
     +,   7.1427994E-24,   1.7718354E-23,   4.3530048E-23
     +,   1.0592353E-22,   2.5527223E-22,   6.0933020E-22
     +,   1.4405002E-21,   3.3729430E-21,   7.8219806E-21
     +,   1.7965946E-20,   4.0871214E-20,   9.2090076E-20
     +,   2.0550370E-19,   4.5420648E-19,   9.9431504E-19
     +,   2.1558072E-18,   4.6294966E-18,   9.8463113E-18
     +,   2.0742075E-17,   4.3276075E-17,   8.9430063E-17
     +,   1.8303630E-16,   3.7104977E-16,   7.4498618E-16
     +,   1.4814778E-15,   2.9179849E-15,   5.6925383E-15
     +,   1.0998960E-14,   2.1049089E-14,   3.9898786E-14
     +,   7.4905597E-14,   1.3928865E-13,   2.5653571E-13
     +,   4.6798232E-13,   8.4556190E-13,   1.5132578E-12
     +,   2.6823658E-12,   4.7095357E-12,   8.1899123E-12
     +,   1.4106912E-11,   2.4068287E-11,   4.0673683E-11
     +,   6.8082054E-11,   1.1287889E-10,   1.8538024E-10
     +,   3.0155953E-10,   4.8591353E-10,   7.7555296E-10
     +,   1.2261571E-09,   1.9202375E-09,   2.9788880E-09
     +,   4.5775814E-09,   6.9681310E-09,   1.0507248E-08
     +,   1.5695118E-08,   2.3224951E-08,   3.4045410E-08
     +,   4.9439890E-08,   7.1125129E-08,   1.0136944E-07
     +,   1.4312870E-07,   2.0021646E-07,   2.7747490E-07
     +,   3.8099282E-07,   5.1829653E-07,   6.9859675E-07
     +,   9.3295819E-07,   1.2345358E-06,   1.6186513E-06
     +,   2.1029355E-06,   2.7072990E-06,   3.4537609E-06
     +,   4.3661876E-06,   5.4699417E-06,   6.7912388E-06
     +,   8.3562381E-06,   1.0190112E-05,   1.2316010E-05
     +,   1.4753681E-05,   1.7517781E-05,   2.0616888E-05
     +,   2.4051888E-05,   2.7814396E-05,   3.1885829E-05
     +,   3.6236877E-05,   4.0826875E-05,   4.5603498E-05
     +,   5.0503590E-05,   5.5454639E-05,   6.0376162E-05
     +,   6.5181579E-05,   6.9781272E-05,   7.4085983E-05
     +,   7.8009813E-05,   8.1473394E-05,   8.4407991E-05
     +,   8.6758315E-05,   8.8485118E-05,   8.9567686E-05
     +,   9.0005306E-05,   8.9817753E-05,   8.9045068E-05
     +,   8.7746579E-05,   8.5998610E-05,   8.3891820E-05
     +,   8.1527905E-05,   7.9015801E-05,   7.6467608E-05
     +,   7.3995077E-05,   7.1706774E-05,   6.9705100E-05
     +,   6.8085326E-05,   6.6935390E-05,   6.6336623E-05
     +,   6.6365508E-05,   6.7096204E-05,   6.8602800E-05
     +,   7.0960850E-05,   7.4247910E-05,   7.8541641E-05
     +,   8.3915322E-05,   9.0431560E-05,   9.8135031E-05
     +,   1.0704432E-04,   1.1714445E-04,   1.2838411E-04
     +,   1.4067203E-04,   1.5387137E-04,   1.6778985E-04
     +,   1.8215927E-04,   1.9660163E-04,   2.1058935E-04
     +,   2.2341961E-04,   2.3422894E-04,   2.4209109E-04
     +,   2.4625822E-04,   2.4661570E-04,   2.4438329E-04
     +,   2.4296985E-04,   2.4861307E-04,   2.7013506E-04
     +,   3.1726735E-04,   3.9812623E-04,   5.1862956E-04
     +,   6.8788300E-04,   9.2934055E-04,   1.2858820E-03
     +,   1.7984380E-03,   2.4546003E-03,   3.1470689E-03
     +,   3.7019397E-03,   3.9797095E-03,   3.9610574E-03
     +,   3.7289036E-03,   3.3723395E-03,   2.9240204E-03
     +,   2.3873814E-03,   1.7957618E-03,   1.2242245E-03
     +,   7.4974261E-04,   4.1094056E-04,   2.0124168E-04
     +,   8.7880559E-05,   3.4116125E-05,   1.1726122E-05
     +,   3.5533087E-06,   9.4582845E-07,   2.2069122E-07
     +,   4.5234895E-08,   8.2785112E-09,   1.4478184E-09
     +,   2.9965896E-10,   9.8185224E-11,   4.7184787E-11
     +,   2.5745375E-11,   1.4312804E-11,   7.9120087E-12
     +,   4.3301777E-12,   2.3444452E-12,   1.2554337E-12
     +,   6.6486546E-13,   3.4820711E-13,   1.8033390E-13
     +,   9.2348187E-14,   4.6762781E-14,   2.3414068E-14
     +,   1.1591526E-14,   5.6741488E-15,   2.7463957E-15
     +,   1.3143681E-15,   6.2194331E-16,   2.9098758E-16
     +,   1.3461627E-16,   6.1575993E-17,   2.7848455E-17
     +,   1.2453163E-17,   5.5062746E-18,   2.4072794E-18
     +,   1.0405662E-18,   4.4474984E-19,   1.8795288E-19
     +,   7.8534136E-20,   3.2445723E-20,   1.3254275E-20
     +,   5.3535574E-21,   2.1379951E-21,   8.4422642E-22
     +,   3.2961905E-22,   1.2724874E-22,   4.8570324E-23
     +,   1.8331147E-23,   6.8404227E-24,   2.5239396E-24
     +,   9.2076693E-25,   3.3214153E-25,   1.1845988E-25
     +,   4.1775553E-26,   1.4566192E-26,   5.0219536E-27
     +,   1.7118827E-27,   5.7700519E-28,   1.9229665E-28
     +,   6.3363366E-29,   2.0644810E-29,   6.6504595E-30
     +,   2.1183616E-30,   6.6714439E-31,   2.0775222E-31
     +,   6.3964819E-32,   1.9473447E-32,   5.8616386E-33
     +,   1.7445958E-33,   5.1338926E-34,   1.4938307E-34
     +,   4.2976315E-35,   1.2225400E-35
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt110 = Yx/0.01092
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt111(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.4058909E-27,   1.4900566E-26
     +,   2.9832137E-26,   5.9432719E-26,   1.1782108E-25
     +,   2.3242436E-25,   4.5624328E-25,   8.9119125E-25
     +,   1.7322007E-24,   3.3503360E-24,   6.4481932E-24
     +,   1.2349393E-23,   2.3534834E-23,   4.4630945E-23
     +,   8.4220406E-23,   1.5814597E-22,   2.9550063E-22
     +,   5.4943332E-22,   1.0165555E-21,   1.8715656E-21
     +,   3.4287715E-21,   6.2507187E-21,   1.1338988E-20
     +,   2.0468518E-20,   3.6766149E-20,   6.5716249E-20
     +,   1.1688405E-19,   2.0686986E-19,   3.6433188E-19
     +,   6.3849001E-19,   1.1134476E-18,   1.9321684E-18
     +,   3.3363995E-18,   5.7328406E-18,   9.8021093E-18
     +,   1.6677352E-17,   2.8235367E-17,   4.7568027E-17
     +,   7.9744618E-17,   1.3302695E-16,   2.2082120E-16
     +,   3.6475306E-16,   5.9953680E-16,   9.8059533E-16
     +,   1.5959650E-15,   2.5847274E-15,   4.1654857E-15
     +,   6.6799695E-15,   1.0659606E-14,   1.6926478E-14
     +,   2.6745446E-14,   4.2052502E-14,   6.5794456E-14
     +,   1.0243548E-13,   1.5869542E-13,   2.4464729E-13
     +,   3.7529634E-13,   5.7288327E-13,   8.7019682E-13
     +,   1.3153031E-12,   1.9783040E-12,   2.9608833E-12
     +,   4.4096380E-12,   6.5349531E-12,   9.6370941E-12
     +,   1.4141718E-11,   2.0650112E-11,   3.0005162E-11
     +,   4.3384275E-11,   6.2419757E-11,   8.9366833E-11
     +,   1.2731591E-10,   1.8048998E-10,   2.5461055E-10
     +,   3.5740322E-10,   4.9923360E-10,   6.9391609E-10
     +,   9.5976371E-10,   1.3209306E-09,   1.8090829E-09
     +,   2.4654190E-09,   3.3433811E-09,   4.5116471E-09
     +,   6.0582455E-09,   8.0949230E-09,   1.0763199E-08
     +,   1.4240461E-08,   1.8748622E-08,   2.4562281E-08
     +,   3.2020406E-08,   4.1538140E-08,   5.3619814E-08
     +,   6.8874520E-08,   8.8033964E-08,   1.1197049E-07
     +,   1.4171381E-07,   1.7847697E-07,   2.2366983E-07
     +,   2.7892938E-07,   3.4612759E-07,   4.2740498E-07
     +,   5.2516816E-07,   6.4212338E-07,   7.8125737E-07
     +,   9.4586267E-07,   1.1395234E-06,   1.3660816E-06
     +,   1.6296181E-06,   1.9344320E-06,   2.2849767E-06
     +,   2.6857540E-06,   3.1413133E-06,   3.6560534E-06
     +,   4.2342285E-06,   4.8796910E-06,   5.5959099E-06
     +,   6.3856564E-06,   7.2510470E-06,   8.1931785E-06
     +,   9.2121845E-06,   1.0307015E-05,   1.1475236E-05
     +,   1.2712980E-05,   1.4014959E-05,   1.5374339E-05
     +,   1.6782576E-05,   1.8229775E-05,   1.9704368E-05
     +,   2.1193609E-05,   2.2683353E-05,   2.4158649E-05
     +,   2.5603595E-05,   2.7002001E-05,   2.8337367E-05
     +,   2.9593524E-05,   3.0754887E-05,   3.1806798E-05
     +,   3.2735981E-05,   3.3531032E-05,   3.4182747E-05
     +,   3.4684446E-05,   3.5032441E-05,   3.5226381E-05
     +,   3.5269491E-05,   3.5168920E-05,   3.4935911E-05
     +,   3.4586003E-05,   3.4139164E-05,   3.3619810E-05
     +,   3.3056727E-05,   3.2482934E-05,   3.1935422E-05
     +,   3.1454692E-05,   3.1084110E-05,   3.0869160E-05
     +,   3.0856445E-05,   3.1092419E-05,   3.1621996E-05
     +,   3.2486932E-05,   3.3723933E-05,   3.5362915E-05
     +,   3.7425041E-05,   3.9920655E-05,   4.2847620E-05
     +,   4.6190129E-05,   4.9917522E-05,   5.3983546E-05
     +,   5.8326670E-05,   6.2871361E-05,   6.7529618E-05
     +,   7.2203205E-05,   7.6787503E-05,   8.1176084E-05
     +,   8.5265325E-05,   8.8959401E-05,   9.2176757E-05
     +,   9.4855037E-05,   9.6955810E-05,   9.8468743E-05
     +,   9.9413934E-05,   9.9842000E-05,   9.9832017E-05
     +,   9.9486875E-05,   9.8925775E-05,   9.8274708E-05
     +,   9.7655626E-05,   9.7176147E-05,   9.6922282E-05
     +,   9.6958196E-05,   9.7337543E-05,   9.8131270E-05
     +,   9.9475459E-05,   1.0163758E-04,   1.0509109E-04
     +,   1.1057754E-04,   1.1912321E-04,   1.3197405E-04
     +,   1.5042741E-04,   1.7557062E-04,   2.0798395E-04
     +,   2.4752092E-04,   2.9330657E-04,   3.4403126E-04
     +,   3.9845458E-04,   4.5586604E-04,   5.1626231E-04
     +,   5.8032124E-04,   6.4997253E-04,   7.3063769E-04
     +,   8.3512138E-04,   9.8648889E-04,   1.2150352E-03
     +,   1.5460065E-03,   1.9814731E-03,   2.4872033E-03
     +,   2.9956296E-03,   3.4254782E-03,   3.7053321E-03
     +,   3.7870037E-03,   3.6479884E-03,   3.2938025E-03
     +,   2.7651910E-03,   2.1397774E-03,   1.5150124E-03
     +,   9.7647624E-04,   5.7146733E-04,   3.0355356E-04
     +,   1.4650737E-04,   6.4356529E-05,   2.5769221E-05
     +,   9.4134311E-06,   3.1363347E-06,   9.5171231E-07
     +,   2.6244149E-07,   6.5615708E-08,   1.4850249E-08
     +,   3.0468876E-09,   5.7340438E-10,   1.0349183E-10
     +,   2.0456647E-11,   5.5573315E-12,   2.2057419E-12
     +,   1.0679357E-12,   5.4899851E-13,   2.8600196E-13
     +,   1.4922293E-13,   7.7723039E-14,   4.0347354E-14
     +,   2.0849550E-14,   1.0714317E-14,   5.4705123E-15
     +,   2.7730940E-15,   1.3948762E-15,   6.9591724E-16
     +,   3.4425089E-16,   1.6880071E-16,   8.2033070E-17
     +,   3.9508009E-17,   1.8854960E-17,   8.9164553E-18
     +,   4.1783668E-18,   1.9404481E-18,   8.9311652E-19
     +,   4.0744557E-19,   1.8428434E-19,   8.2651674E-20
     +,   3.6768698E-20,   1.6231180E-20,   7.1136184E-21
     +,   3.0971074E-21,   1.3405229E-21,   5.7740281E-22
     +,   2.4779883E-22,   1.0610772E-22,   4.5409311E-23
     +,   1.9460735E-23,   8.3692754E-24,   3.6200472E-24
     +,   1.5781419E-24,   6.9473328E-25,   3.0925810E-25
     +,   1.3931974E-25,   6.3516208E-26,   2.9286865E-26
     +,   1.3639878E-26,   6.4060944E-27,   3.0283305E-27
     +,   1.4381671E-27,   6.8495617E-28,   3.2663006E-28
     +,   1.5574871E-28,   7.4175922E-29,   3.5253859E-29
     +,   1.6708264E-29,   7.8925121E-30,   3.7141341E-30
     +,   1.7407917E-30,   8.1238001E-31,   3.7743106E-31
     +,   1.7454333E-31,   8.0341871E-32
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt111 = Yx/0.0110833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0245798E-05,   1.0115860E-05
     +,   9.9828685E-06,   9.8470855E-06,   9.7087759E-06
     +,   9.5682090E-06,   9.4256620E-06,   9.2814143E-06
     +,   9.1357497E-06,   8.9889481E-06,   8.8413008E-06
     +,   8.6930968E-06,   8.5446291E-06,   8.3961895E-06
     +,   8.2480701E-06,   8.1005646E-06,   7.9539677E-06
     +,   7.8085677E-06,   7.6646602E-06,   7.5225325E-06
     +,   7.3824717E-06,   7.2447629E-06,   7.1096906E-06
     +,   6.9775256E-06,   6.8485524E-06,   6.7230353E-06
     +,   6.6012412E-06,   6.4834335E-06,   6.3698667E-06
     +,   6.2607892E-06,   6.1564474E-06,   6.0570787E-06
     +,   5.9629110E-06,   5.8741698E-06,   5.7910693E-06
     +,   5.7138182E-06,   5.6426147E-06,   5.5776504E-06
     +,   5.5191049E-06,   5.4671518E-06,   5.4219536E-06
     +,   5.3836616E-06,   5.3524182E-06,   5.3283547E-06
     +,   5.3115923E-06,   5.3022395E-06,   5.3003951E-06
     +,   5.3061431E-06,   5.3195604E-06,   5.3407102E-06
     +,   5.3696413E-06,   5.4063903E-06,   5.4509856E-06
     +,   5.5034411E-06,   5.5637556E-06,   5.6319204E-06
     +,   5.7079124E-06,   5.7916964E-06,   5.8832252E-06
     +,   5.9824415E-06,   6.0892771E-06,   6.2036520E-06
     +,   6.3254734E-06,   6.4546425E-06,   6.5910590E-06
     +,   6.7345964E-06,   6.8851400E-06,   7.0425476E-06
     +,   7.2066978E-06,   7.3774354E-06,   7.5546286E-06
     +,   7.7381201E-06,   7.9277715E-06,   8.1234257E-06
     +,   8.3249397E-06,   8.5321772E-06,   8.7449926E-06
     +,   8.9632449E-06,   9.1868105E-06,   9.4155794E-06
     +,   9.6494286E-06,   9.8882756E-06,   1.0132019E-05
     +,   1.0380603E-05,   1.0633956E-05,   1.0892058E-05
     +,   1.1154868E-05,   1.1422407E-05,   1.1694673E-05
     +,   1.1971717E-05,   1.2253613E-05,   1.2540437E-05
     +,   1.2832291E-05,   1.3129323E-05,   1.3431702E-05
     +,   1.3739600E-05,   1.4053250E-05,   1.4372873E-05
     +,   1.4698760E-05,   1.5031185E-05,   1.5370493E-05
     +,   1.5717014E-05,   1.6071150E-05,   1.6433280E-05
     +,   1.6803850E-05,   1.7183324E-05,   1.7572174E-05
     +,   1.7970891E-05,   1.8380017E-05,   1.8800107E-05
     +,   1.9231702E-05,   1.9675415E-05,   2.0131807E-05
     +,   2.0601514E-05,   2.1085112E-05,   2.1583241E-05
     +,   2.2096476E-05,   2.2625440E-05,   2.3170673E-05
     +,   2.3732729E-05,   2.4312145E-05,   2.4909359E-05
     +,   2.5524751E-05,   2.6158679E-05,   2.6811396E-05
     +,   2.7483018E-05,   2.8173616E-05,   2.8883049E-05
     +,   2.9611125E-05,   3.0357382E-05,   3.1121286E-05
     +,   3.1902015E-05,   3.2698623E-05,   3.3509852E-05
     +,   3.4334273E-05,   3.5170237E-05,   3.6015761E-05
     +,   3.6868638E-05,   3.7726448E-05,   3.8586542E-05
     +,   3.9445975E-05,   4.0301624E-05,   4.1150230E-05
     +,   4.1988413E-05,   4.2812640E-05,   4.3619431E-05
     +,   4.4405395E-05,   4.5167209E-05,   4.5901837E-05
     +,   4.6606634E-05,   4.7279464E-05,   4.7918744E-05
     +,   4.8523667E-05,   4.9094353E-05,   4.9631923E-05
     +,   5.0138606E-05,   5.0617862E-05,   5.1074450E-05
     +,   5.1514446E-05,   5.1945139E-05,   5.2375039E-05
     +,   5.2813648E-05,   5.3271237E-05,   5.3758467E-05
     +,   5.4286113E-05,   5.4864471E-05,   5.5502867E-05
     +,   5.6209032E-05,   5.6988585E-05,   5.7844394E-05
     +,   5.8775975E-05,   5.9779122E-05,   6.0845581E-05
     +,   6.1962950E-05,   6.3114683E-05,   6.4280743E-05
     +,   6.5438260E-05,   6.6562759E-05,   6.7629982E-05
     +,   6.8618210E-05,   6.9511123E-05,   7.0301430E-05
     +,   7.0995156E-05,   7.1616851E-05,   7.2215276E-05
     +,   7.2869720E-05,   7.3697054E-05,   7.4858806E-05
     +,   7.6568249E-05,   7.9096637E-05,   8.2778919E-05
     +,   8.8017274E-05,   9.5282128E-05,   1.0511004E-04
     +,   1.1809898E-04,   1.3489816E-04,   1.5619212E-04
     +,   1.8268125E-04,   2.1505910E-04,   2.5398162E-04
     +,   3.0002923E-04,   3.5366899E-04,   4.1521544E-04
     +,   4.8478268E-04,   5.6222914E-04,   6.4712571E-04
     +,   7.3870789E-04,   8.3583570E-04,   9.3697832E-04
     +,   1.0402192E-03,   1.1432712E-03,   1.2435190E-03
     +,   1.3381066E-03,   1.4240528E-03,   1.4983835E-03
     +,   1.5582839E-03,   1.6012760E-03,   1.6253821E-03
     +,   1.6292665E-03,   1.6123495E-03,   1.5748733E-03
     +,   1.5179107E-03,   1.4433223E-03,   1.3536509E-03
     +,   1.2519630E-03,   1.1416652E-03,   1.0263093E-03
     +,   9.0938329E-04,   7.9411693E-04,   6.8333716E-04
     +,   5.7936483E-04,   4.8394341E-04,   3.9821837E-04
     +,   3.2277036E-04,   2.5768354E-04,   2.0261406E-04
     +,   1.5689692E-04,   1.1964749E-04,   8.9851143E-05
     +,   6.6444140E-05,   4.8382492E-05,   3.4691020E-05
     +,   2.4493380E-05,   1.7028911E-05,   1.1658554E-05
     +,   7.8607018E-06,   5.2203359E-06,   3.4153843E-06
     +,   2.2019967E-06,   1.3997688E-06,   8.7797878E-07
     +,   5.4400607E-07,   3.3358785E-07,   2.0300962E-07
     +,   1.2312199E-07,   7.4873498E-08,   4.6049507E-08
     +,   2.8961248E-08,   1.8857431E-08,   1.2855342E-08
     +,   9.2362322E-09,   6.9917370E-09,   5.5393006E-09
     +,   4.5469415E-09,   3.8275161E-09,   3.2759695E-09
     +,   2.8332678E-09,   2.4657876E-09,   2.1537965E-09
     +,   1.8851176E-09,   1.6517507E-09,   1.4480601E-09
     +,   1.2697826E-09,   1.1135025E-09,   9.7638697E-10
     +,   8.5604318E-10,   7.5039369E-10,   6.5764183E-10
     +,   5.7621102E-10,   5.0472876E-10,   4.4198131E-10
     +,   3.8691347E-10,   3.3859054E-10,   2.9619698E-10
     +,   2.5901192E-10,   2.2640503E-10,   1.9782011E-10
     +,   1.7276752E-10,   1.5081934E-10,   1.3159664E-10
     +,   1.1476792E-10,   1.0004014E-10,   8.7157080E-11
     +,   7.5891980E-11,   6.6046765E-11,   5.7445920E-11
     +,   4.9936465E-11,   4.3382863E-11,   3.7666800E-11
     +,   3.2683682E-11,   2.8342250E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt112 = Yx/0.00991666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt1128(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.2370149E-07,   4.7234451E-07
     +,   5.2586739E-07,   5.8467225E-07,   6.4918436E-07
     +,   7.1985210E-07,   7.9714789E-07,   8.8156645E-07
     +,   9.7362499E-07,   1.0738672E-06,   1.1828552E-06
     +,   1.3011728E-06,   1.4294247E-06,   1.5682341E-06
     +,   1.7182419E-06,   1.8801043E-06,   2.0544908E-06
     +,   2.2420816E-06,   2.4435662E-06,   2.6596399E-06
     +,   2.8909990E-06,   3.1383386E-06,   3.4023451E-06
     +,   3.6837125E-06,   3.9830893E-06,   4.3011405E-06
     +,   4.6384857E-06,   4.9957239E-06,   5.3734184E-06
     +,   5.7720936E-06,   6.1922315E-06,   6.6342614E-06
     +,   7.0985589E-06,   7.5854368E-06,   8.0951386E-06
     +,   8.6278387E-06,   9.1836309E-06,   9.7625161E-06
     +,   1.0364448E-05,   1.0989212E-05,   1.1636575E-05
     +,   1.2306155E-05,   1.2997481E-05,   1.3709971E-05
     +,   1.4442938E-05,   1.5195578E-05,   1.5966985E-05
     +,   1.6756134E-05,   1.7561892E-05,   1.8383016E-05
     +,   1.9218163E-05,   2.0065880E-05,   2.0924605E-05
     +,   2.1792734E-05,   2.2668488E-05,   2.3550092E-05
     +,   2.4435647E-05,   2.5323216E-05,   2.6210782E-05
     +,   2.7096305E-05,   2.7977696E-05,   2.8852861E-05
     +,   2.9719640E-05,   3.0575924E-05,   3.1419640E-05
     +,   3.2248634E-05,   3.3060907E-05,   3.3854398E-05
     +,   3.4627192E-05,   3.5377368E-05,   3.6103167E-05
     +,   3.6802823E-05,   3.7474776E-05,   3.8117469E-05
     +,   3.8729548E-05,   3.9309762E-05,   3.9856954E-05
     +,   4.0370138E-05,   4.0848452E-05,   4.1291216E-05
     +,   4.1697833E-05,   4.2067935E-05,   4.2401214E-05
     +,   4.2697586E-05,   4.2957079E-05,   4.3179880E-05
     +,   4.3366308E-05,   4.3516862E-05,   4.3632135E-05
     +,   4.3712909E-05,   4.3760079E-05,   4.3774689E-05
     +,   4.3757933E-05,   4.3711148E-05,   4.3635824E-05
     +,   4.3533590E-05,   4.3406260E-05,   4.3255841E-05
     +,   4.3084467E-05,   4.2894571E-05,   4.2688738E-05
     +,   4.2469845E-05,   4.2241001E-05,   4.2005657E-05
     +,   4.1767551E-05,   4.1530799E-05,   4.1299922E-05
     +,   4.1079835E-05,   4.0875897E-05,   4.0693943E-05
     +,   4.0540315E-05,   4.0421866E-05,   4.0345967E-05
     +,   4.0320509E-05,   4.0353923E-05,   4.0455103E-05
     +,   4.0633426E-05,   4.0898667E-05,   4.1260952E-05
     +,   4.1730629E-05,   4.2318236E-05,   4.3034306E-05
     +,   4.3889173E-05,   4.4892946E-05,   4.6055262E-05
     +,   4.7384918E-05,   4.8889968E-05,   5.0577110E-05
     +,   5.2451847E-05,   5.4517805E-05,   5.6776978E-05
     +,   5.9228922E-05,   6.1871164E-05,   6.4698383E-05
     +,   6.7702764E-05,   7.0873655E-05,   7.4197313E-05
     +,   7.7656958E-05,   8.1233156E-05,   8.4903601E-05
     +,   8.8643057E-05,   9.2423848E-05,   9.6216361E-05
     +,   9.9989295E-05,   1.0370958E-04,   1.0734384E-04
     +,   1.1085844E-04,   1.1422001E-04,   1.1739634E-04
     +,   1.2035731E-04,   1.2307541E-04,   1.2552626E-04
     +,   1.2768955E-04,   1.2954981E-04,   1.3109679E-04
     +,   1.3232589E-04,   1.3323860E-04,   1.3384275E-04
     +,   1.3415242E-04,   1.3418774E-04,   1.3397464E-04
     +,   1.3354403E-04,   1.3293121E-04,   1.3217471E-04
     +,   1.3131506E-04,   1.3039347E-04,   1.2945032E-04
     +,   1.2852378E-04,   1.2764809E-04,   1.2685219E-04
     +,   1.2615870E-04,   1.2558278E-04,   1.2513134E-04
     +,   1.2480318E-04,   1.2458890E-04,   1.2447179E-04
     +,   1.2442895E-04,   1.2443308E-04,   1.2445450E-04
     +,   1.2446348E-04,   1.2443302E-04,   1.2434104E-04
     +,   1.2417331E-04,   1.2392522E-04,   1.2360372E-04
     +,   1.2322873E-04,   1.2283397E-04,   1.2246800E-04
     +,   1.2219483E-04,   1.2209557E-04,   1.2227069E-04
     +,   1.2284434E-04,   1.2397047E-04,   1.2584170E-04
     +,   1.2870124E-04,   1.3285720E-04,   1.3869829E-04
     +,   1.4670975E-04,   1.5748803E-04,   1.7174911E-04
     +,   1.9032646E-04,   2.1415704E-04,   2.4425137E-04
     +,   2.8164036E-04,   3.2729612E-04,   3.8204330E-04
     +,   4.4644388E-04,   5.2066986E-04,   6.0438609E-04
     +,   6.9665309E-04,   7.9585274E-04,   8.9965604E-04
     +,   1.0050661E-03,   1.1085292E-03,   1.2060986E-03
     +,   1.2936582E-03,   1.3672027E-03,   1.4231310E-03
     +,   1.4585189E-03,   1.4713564E-03,   1.4607254E-03
     +,   1.4268771E-03,   1.3712255E-03,   1.2962347E-03
     +,   1.2052205E-03,   1.1020949E-03,   9.9108380E-04
     +,   8.7642652E-04,   7.6209503E-04,   6.5158086E-04
     +,   5.4774270E-04,   4.5271017E-04,   3.6785947E-04
     +,   2.9386306E-04,   2.3078253E-04,   1.7817272E-04
     +,   1.3522118E-04,   1.0088041E-04,   7.3981297E-05
     +,   5.3330652E-05,   3.7788308E-05,   2.6318401E-05
     +,   1.8016901E-05,   1.2122893E-05,   8.0172185E-06
     +,   5.2111177E-06,   3.3290967E-06,   2.0902448E-06
     +,   1.2898220E-06,   7.8222405E-07,   4.6621767E-07
     +,   2.7307982E-07,   1.5719421E-07,   8.8927301E-08
     +,   4.9439816E-08,   2.7011945E-08,   1.4504057E-08
     +,   7.6542834E-09,   3.9703396E-09,   2.0244675E-09
     +,   1.0150176E-09,   5.0063448E-10,   2.4310096E-10
     +,   1.1637745E-10,   5.5063887E-11,   2.5862441E-11
     +,   1.2149060E-11,   5.7796992E-12,   2.8375145E-12
     +,   1.4727307E-12,   8.2695168E-13,   5.0805730E-13
     +,   3.3921040E-13,   2.4129039E-13,   1.7886204E-13
     +,   1.3577837E-13,   1.0435787E-13,   8.0673098E-14
     +,   6.2497621E-14,   4.8430179E-14,   3.7502926E-14
     +,   2.9007545E-14,   2.2404980E-14,   1.7279274E-14
     +,   1.3305244E-14,   1.0228969E-14,   7.8513678E-15
     +,   6.0166334E-15,   4.6032514E-15,   3.5161631E-15
     +,   2.6814812E-15,   2.0416080E-15,   1.5519214E-15
     +,   1.1777662E-15,   8.9237420E-16,   6.7503655E-16
     +,   5.0980695E-16,   3.8439316E-16,   2.8936448E-16
     +,   2.1747248E-16,   1.6317818E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt1128 = Yx/0.009625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0618584E-06,   4.3635073E-06
     +,   4.6830041E-06,   5.0210333E-06,   5.3782769E-06
     +,   5.7554162E-06,   6.1531186E-06,   6.5720487E-06
     +,   7.0128435E-06,   7.4761515E-06,   7.9625725E-06
     +,   8.4726953E-06,   9.0070780E-06,   9.5662490E-06
     +,   1.0150698E-05,   1.0760879E-05,   1.1397203E-05
     +,   1.2060025E-05,   1.2749655E-05,   1.3466343E-05
     +,   1.4210278E-05,   1.4981585E-05,   1.5780302E-05
     +,   1.6606449E-05,   1.7459866E-05,   1.8340421E-05
     +,   1.9247826E-05,   2.0181720E-05,   2.1141657E-05
     +,   2.2127086E-05,   2.3137369E-05,   2.4171755E-05
     +,   2.5229396E-05,   2.6309348E-05,   2.7410557E-05
     +,   2.8531873E-05,   2.9672039E-05,   3.0829680E-05
     +,   3.2003401E-05,   3.3191583E-05,   3.4392640E-05
     +,   3.5604837E-05,   3.6826383E-05,   3.8055383E-05
     +,   3.9289909E-05,   4.0527964E-05,   4.1767489E-05
     +,   4.3006399E-05,   4.4242588E-05,   4.5473902E-05
     +,   4.6698187E-05,   4.7913312E-05,   4.9117109E-05
     +,   5.0307546E-05,   5.1482461E-05,   5.2639887E-05
     +,   5.3777865E-05,   5.4894492E-05,   5.5987966E-05
     +,   5.7056579E-05,   5.8098711E-05,   5.9112906E-05
     +,   6.0097718E-05,   6.1051949E-05,   6.1974511E-05
     +,   6.2864383E-05,   6.3720763E-05,   6.4542932E-05
     +,   6.5330387E-05,   6.6082684E-05,   6.6799628E-05
     +,   6.7481014E-05,   6.8126945E-05,   6.8737492E-05
     +,   6.9312940E-05,   6.9853697E-05,   7.0360213E-05
     +,   7.0833012E-05,   7.1272763E-05,   7.1680195E-05
     +,   7.2056027E-05,   7.2401061E-05,   7.2716102E-05
     +,   7.3002011E-05,   7.3259573E-05,   7.3489631E-05
     +,   7.3692936E-05,   7.3870229E-05,   7.4022209E-05
     +,   7.4149473E-05,   7.4252581E-05,   7.4332012E-05
     +,   7.4388117E-05,   7.4421238E-05,   7.4431540E-05
     +,   7.4419149E-05,   7.4384086E-05,   7.4326264E-05
     +,   7.4245545E-05,   7.4141688E-05,   7.4014395E-05
     +,   7.3863310E-05,   7.3688025E-05,   7.3488103E-05
     +,   7.3263080E-05,   7.3012496E-05,   7.2735915E-05
     +,   7.2432915E-05,   7.2103139E-05,   7.1746283E-05
     +,   7.1362163E-05,   7.0950649E-05,   7.0511815E-05
     +,   7.0045775E-05,   6.9552931E-05,   6.9033718E-05
     +,   6.8488895E-05,   6.7919304E-05,   6.7326080E-05
     +,   6.6710520E-05,   6.6074157E-05,   6.5418739E-05
     +,   6.4746266E-05,   6.4058884E-05,   6.3358922E-05
     +,   6.2648985E-05,   6.1931736E-05,   6.1210056E-05
     +,   6.0486840E-05,   5.9765200E-05,   5.9048161E-05
     +,   5.8338846E-05,   5.7640300E-05,   5.6955563E-05
     +,   5.6287488E-05,   5.5638815E-05,   5.5012122E-05
     +,   5.4409760E-05,   5.3833784E-05,   5.3285989E-05
     +,   5.2767875E-05,   5.2280666E-05,   5.1825209E-05
     +,   5.1402068E-05,   5.1011571E-05,   5.0653765E-05
     +,   5.0328530E-05,   5.0035629E-05,   4.9774826E-05
     +,   4.9545924E-05,   4.9348953E-05,   4.9184273E-05
     +,   4.9052716E-05,   4.8955739E-05,   4.8895607E-05
     +,   4.8875503E-05,   4.8899739E-05,   4.8973820E-05
     +,   4.9104623E-05,   4.9300430E-05,   4.9571030E-05
     +,   4.9927654E-05,   5.0383009E-05,   5.0951050E-05
     +,   5.1646919E-05,   5.2486714E-05,   5.3487121E-05
     +,   5.4665059E-05,   5.6037439E-05,   5.7620586E-05
     +,   5.9429865E-05,   6.1479164E-05,   6.3780753E-05
     +,   6.6344932E-05,   6.9179463E-05,   7.2290190E-05
     +,   7.5680990E-05,   7.9353907E-05,   8.3310159E-05
     +,   8.7551496E-05,   9.2081340E-05,   9.6906326E-05
     +,   1.0203879E-04,   1.0749939E-04,   1.1331987E-04
     +,   1.1954539E-04,   1.2623795E-04,   1.3347965E-04
     +,   1.4137500E-04,   1.5005180E-04,   1.5966379E-04
     +,   1.7039005E-04,   1.8243231E-04,   1.9601219E-04
     +,   2.1136680E-04,   2.2874042E-04,   2.4837346E-04
     +,   2.7049147E-04,   2.9529247E-04,   3.2293116E-04
     +,   3.5350060E-04,   3.8701715E-04,   4.2340779E-04
     +,   4.6249540E-04,   5.0398329E-04,   5.4745784E-04
     +,   5.9238274E-04,   6.3810078E-04,   6.8384723E-04
     +,   7.2877092E-04,   7.7195285E-04,   8.1243337E-04
     +,   8.4924791E-04,   8.8146428E-04,   9.0821629E-04
     +,   9.2873967E-04,   9.4240467E-04,   9.4874727E-04
     +,   9.4748702E-04,   9.3854236E-04,   9.2203537E-04
     +,   8.9828653E-04,   8.6780498E-04,   8.3126553E-04
     +,   7.8948052E-04,   7.4336625E-04,   6.9391105E-04
     +,   6.4213603E-04,   5.8905309E-04,   5.3563609E-04
     +,   4.8279203E-04,   4.3133448E-04,   3.8196082E-04
     +,   3.3524411E-04,   2.9163159E-04,   2.5143605E-04
     +,   2.1484670E-04,   1.8194142E-04,   1.5269697E-04
     +,   1.2700332E-04,   1.0468282E-04,   8.5507971E-05
     +,   6.9215792E-05,   5.5521537E-05,   4.4133238E-05
     +,   3.4762841E-05,   2.7133603E-05,   2.0986177E-05
     +,   1.6083608E-05,   1.2214069E-05,   9.1908350E-06
     +,   6.8526460E-06,   5.0625517E-06,   3.7058560E-06
     +,   2.6878606E-06,   1.9315928E-06,   1.3753564E-06
     +,   9.7030329E-07,   6.7824084E-07,   4.6971684E-07
     +,   3.2230469E-07,   2.1911843E-07,   1.4759298E-07
     +,   9.8496443E-08,   6.5126009E-08,   4.2664166E-08
     +,   2.7691291E-08,   1.7807595E-08,   1.1346540E-08
     +,   7.1634654E-09,   4.4812025E-09,   2.7778524E-09
     +,   1.7065104E-09,   1.0390524E-09,   6.2713251E-10
     +,   3.7531087E-10,   2.2277338E-10,   1.3121965E-10
     +,   7.6750030E-11,   4.4621095E-11,   2.5820559E-11
     +,   1.4900805E-11,   8.5983694E-12,   4.9792453E-12
     +,   2.9070988E-12,   1.7210638E-12,   1.0397917E-12
     +,   6.4512984E-13,   4.1316654E-13,   2.7386611E-13
     +,   1.8781996E-13,   1.3284251E-13,   9.6413037E-14
     +,   7.1391521E-14,   5.3645544E-14,   4.0720597E-14
     +,   3.1114451E-14,   2.3869470E-14,   1.8351304E-14
     +,   1.4121454E-14,   1.0867261E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt114 = Yx/0.00882608695652174
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5056556E-06,   6.4110136E-06
     +,   6.3181574E-06,   6.2273630E-06,   6.1389192E-06
     +,   6.0531374E-06,   5.9703443E-06,   5.8908918E-06
     +,   5.8151513E-06,   5.7435177E-06,   5.6764134E-06
     +,   5.6142835E-06,   5.5576033E-06,   5.5068745E-06
     +,   5.4626298E-06,   5.4254315E-06,   5.3958761E-06
     +,   5.3745903E-06,   5.3622343E-06,   5.3595040E-06
     +,   5.3671297E-06,   5.3858730E-06,   5.4165362E-06
     +,   5.4599523E-06,   5.5169867E-06,   5.5885434E-06
     +,   5.6755562E-06,   5.7789875E-06,   5.8998326E-06
     +,   6.0391098E-06,   6.1978640E-06,   6.3771649E-06
     +,   6.5780914E-06,   6.8017430E-06,   7.0492265E-06
     +,   7.3216547E-06,   7.6201372E-06,   7.9457741E-06
     +,   8.2996721E-06,   8.6828804E-06,   9.0964641E-06
     +,   9.5414225E-06,   1.0018728E-05,   1.0529296E-05
     +,   1.1073985E-05,   1.1653579E-05,   1.2268791E-05
     +,   1.2920246E-05,   1.3608465E-05,   1.4333871E-05
     +,   1.5096767E-05,   1.5897333E-05,   1.6735594E-05
     +,   1.7611497E-05,   1.8524734E-05,   1.9474937E-05
     +,   2.0461521E-05,   2.1483733E-05,   2.2540647E-05
     +,   2.3631150E-05,   2.4753954E-05,   2.5907584E-05
     +,   2.7090306E-05,   2.8300299E-05,   2.9535542E-05
     +,   3.0793712E-05,   3.2072468E-05,   3.3369135E-05
     +,   3.4681027E-05,   3.6005131E-05,   3.7338465E-05
     +,   3.8677739E-05,   4.0019706E-05,   4.1360850E-05
     +,   4.2697688E-05,   4.4026692E-05,   4.5344172E-05
     +,   4.6646419E-05,   4.7929811E-05,   4.9190745E-05
     +,   5.0425529E-05,   5.1630712E-05,   5.2802774E-05
     +,   5.3938467E-05,   5.5034547E-05,   5.6088084E-05
     +,   5.7096204E-05,   5.8056397E-05,   5.8966249E-05
     +,   5.9823757E-05,   6.0627139E-05,   6.1374936E-05
     +,   6.2065992E-05,   6.2699546E-05,   6.3275205E-05
     +,   6.3792890E-05,   6.4252999E-05,   6.4656211E-05
     +,   6.5003747E-05,   6.5297099E-05,   6.5538254E-05
     +,   6.5729546E-05,   6.5873763E-05,   6.5974025E-05
     +,   6.6033870E-05,   6.6057211E-05,   6.6048284E-05
     +,   6.6011649E-05,   6.5952234E-05,   6.5875211E-05
     +,   6.5786036E-05,   6.5690401E-05,   6.5594206E-05
     +,   6.5503526E-05,   6.5424567E-05,   6.5363674E-05
     +,   6.5327207E-05,   6.5321598E-05,   6.5353248E-05
     +,   6.5428481E-05,   6.5553526E-05,   6.5734435E-05
     +,   6.5977081E-05,   6.6287044E-05,   6.6669607E-05
     +,   6.7129615E-05,   6.7671586E-05,   6.8299443E-05
     +,   6.9016627E-05,   6.9825910E-05,   7.0729446E-05
     +,   7.1728587E-05,   7.2823968E-05,   7.4015370E-05
     +,   7.5301679E-05,   7.6680939E-05,   7.8150115E-05
     +,   7.9705285E-05,   8.1341517E-05,   8.3052968E-05
     +,   8.4832711E-05,   8.6672895E-05,   8.8564833E-05
     +,   9.0499045E-05,   9.2465103E-05,   9.4452109E-05
     +,   9.6448617E-05,   9.8442659E-05,   1.0042202E-04
     +,   1.0237448E-04,   1.0428799E-04,   1.0615062E-04
     +,   1.0795095E-04,   1.0967840E-04,   1.1132336E-04
     +,   1.1287718E-04,   1.1433269E-04,   1.1568426E-04
     +,   1.1692820E-04,   1.1806250E-04,   1.1908745E-04
     +,   1.2000562E-04,   1.2082176E-04,   1.2154323E-04
     +,   1.2217980E-04,   1.2274380E-04,   1.2325001E-04
     +,   1.2371561E-04,   1.2416021E-04,   1.2460565E-04
     +,   1.2507571E-04,   1.2559608E-04,   1.2619425E-04
     +,   1.2689900E-04,   1.2774028E-04,   1.2874896E-04
     +,   1.2995652E-04,   1.3139461E-04,   1.3309471E-04
     +,   1.3508815E-04,   1.3740528E-04,   1.4007530E-04
     +,   1.4312574E-04,   1.4658236E-04,   1.5046870E-04
     +,   1.5480505E-04,   1.5960862E-04,   1.6489312E-04
     +,   1.7066806E-04,   1.7693799E-04,   1.8370269E-04
     +,   1.9095665E-04,   1.9868782E-04,   2.0687780E-04
     +,   2.1550184E-04,   2.2452847E-04,   2.3391808E-04
     +,   2.4362390E-04,   2.5359230E-04,   2.6376234E-04
     +,   2.7406536E-04,   2.8442606E-04,   2.9476357E-04
     +,   3.0499167E-04,   3.1501861E-04,   3.2474988E-04
     +,   3.3408860E-04,   3.4293631E-04,   3.5119467E-04
     +,   3.5876781E-04,   3.6556300E-04,   3.7149203E-04
     +,   3.7647306E-04,   3.8043282E-04,   3.8330693E-04
     +,   3.8504144E-04,   3.8559444E-04,   3.8493655E-04
     +,   3.8305161E-04,   3.7993738E-04,   3.7560545E-04
     +,   3.7008122E-04,   3.6340373E-04,   3.5562532E-04
     +,   3.4680968E-04,   3.3703158E-04,   3.2637597E-04
     +,   3.1493625E-04,   3.0281162E-04,   2.9010634E-04
     +,   2.7692885E-04,   2.6338900E-04,   2.4959570E-04
     +,   2.3565610E-04,   2.2167547E-04,   2.0775289E-04
     +,   1.9398164E-04,   1.8044886E-04,   1.6723385E-04
     +,   1.5440649E-04,   1.4202775E-04,   1.3015016E-04
     +,   1.1881692E-04,   1.0806118E-04,   9.7907257E-05
     +,   8.8371613E-05,   7.9462559E-05,   7.1180468E-05
     +,   6.3519081E-05,   5.6466921E-05,   5.0006620E-05
     +,   4.4116499E-05,   3.8771741E-05,   3.3944623E-05
     +,   2.9605008E-05,   2.5721423E-05,   2.2261858E-05
     +,   1.9194014E-05,   1.6485628E-05,   1.4105141E-05
     +,   1.2022184E-05,   1.0207630E-05,   8.6337504E-06
     +,   7.2745183E-06,   6.1058140E-06,   5.1052216E-06
     +,   4.2522088E-06,   3.5281398E-06,   2.9161538E-06
     +,   2.4010756E-06,   1.9693778E-06,   1.6090971E-06
     +,   1.3096902E-06,   1.0619033E-06,   8.5768556E-07
     +,   6.9008718E-07,   5.5310346E-07,   4.4161251E-07
     +,   3.5123875E-07,   2.7828909E-07,   2.1964213E-07
     +,   1.7269026E-07,   1.3525253E-07,   1.0552507E-07
     +,   8.2014573E-08,   6.3497851E-08,   4.8972893E-08
     +,   3.7625089E-08,   2.8795967E-08,   2.1953849E-08
     +,   1.6673313E-08,   1.2614148E-08,   9.5066186E-09
     +,   7.1370470E-09,   5.3375695E-09,   3.9764205E-09
     +,   2.9510312E-09,   2.1816182E-09,   1.6066312E-09
     +,   1.1786295E-09,   8.6133184E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt115 = Yx/0.00666666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1704868E-34,   9.7551438E-34
     +,   2.2694544E-33,   5.2510986E-33,   1.2084341E-32
     +,   2.7659220E-32,   6.2964791E-32,   1.4256015E-31
     +,   3.2102290E-31,   7.1898759E-31,   1.6015825E-30
     +,   3.5482950E-30,   7.8186654E-30,   1.7135155E-29
     +,   3.7349602E-29,   8.0970428E-29,   1.7458601E-28
     +,   3.7439917E-28,   7.9855141E-28,   1.6939871E-27
     +,   3.5740707E-27,   7.4999548E-27,   1.5652789E-26
     +,   3.2492059E-26,   6.7080356E-26,   1.3774029E-25
     +,   2.8129848E-25,   5.7137082E-25,   1.1542755E-24
     +,   2.3192373E-24,   4.6347176E-24,   9.2117544E-24
     +,   1.8209743E-23,   3.5802320E-23,   7.0009619E-23
     +,   1.3615915E-22,   2.6337832E-22,   5.0669987E-22
     +,   9.6955110E-22,   1.8451279E-21,   3.4924466E-21
     +,   6.5746694E-21,   1.2310119E-20,   2.2923965E-20
     +,   4.2458350E-20,   7.8212706E-20,   1.4329653E-19
     +,   2.6111585E-19,   4.7323473E-19,   8.5302329E-19
     +,   1.5292822E-18,   2.7268280E-18,   4.8357578E-18
     +,   8.5295043E-18,   1.4962925E-17,   2.6106981E-17
     +,   4.5304116E-17,   7.8191947E-17,   1.3422385E-16
     +,   2.2915971E-16,   3.8912590E-16,   6.5718523E-16
     +,   1.1038789E-15,   1.8441519E-15,   3.0642404E-15
     +,   5.0638666E-15,   8.3232591E-15,   1.3606260E-14
     +,   2.2122449E-14,   3.5773745E-14,   5.7536678E-14
     +,   9.2036337E-14,   1.4642818E-13,   2.3169951E-13
     +,   3.6464383E-13,   5.7076972E-13,   8.8857795E-13
     +,   1.3758338E-12,   2.1187505E-12,   3.2452034E-12
     +,   4.9435616E-12,   7.4900771E-12,   1.1286771E-11
     +,   1.6916147E-11,   2.5215614E-11,   3.7384051E-11
     +,   5.5123836E-11,   8.0842770E-11,   1.1791780E-10
     +,   1.7106469E-10,   2.4682489E-10,   3.5420963E-10
     +,   5.0555521E-10,   7.1766154E-10,   1.0132539E-09
     +,   1.4228332E-09,   1.9871818E-09,   2.7603158E-09
     +,   3.8135282E-09,   5.2400235E-09,   7.1612045E-09
     +,   9.7336867E-09,   1.3158782E-08,   1.7692605E-08
     +,   2.3659775E-08,   3.1468495E-08,   4.1627835E-08
     +,   5.4768442E-08,   7.1667003E-08,   9.3272725E-08
     +,   1.2073383E-07,   1.5543522E-07,   1.9902566E-07
     +,   2.5346313E-07,   3.2104074E-07,   4.0443734E-07
     +,   5.0673646E-07,   6.3147962E-07,   7.8266601E-07
     +,   9.6479903E-07,   1.1828886E-06,   1.4424293E-06
     +,   1.7493893E-06,   2.1101969E-06,   2.5316699E-06
     +,   3.0208844E-06,   3.5851708E-06,   4.2318520E-06
     +,   4.9682276E-06,   5.8012283E-06,   6.7373876E-06
     +,   7.7824143E-06,   8.9411751E-06,   1.0217187E-05
     +,   1.1612618E-05,   1.3127946E-05,   1.4761644E-05
     +,   1.6510054E-05,   1.8367380E-05,   2.0325497E-05
     +,   2.2373790E-05,   2.4499308E-05,   2.6687048E-05
     +,   2.8920047E-05,   3.1179428E-05,   3.3445274E-05
     +,   3.5696808E-05,   3.7912836E-05,   4.0072438E-05
     +,   4.2155731E-05,   4.4144355E-05,   4.6021938E-05
     +,   4.7774822E-05,   4.9392664E-05,   5.0868690E-05
     +,   5.2199914E-05,   5.3387364E-05,   5.4436165E-05
     +,   5.5355216E-05,   5.6156761E-05,   5.6856061E-05
     +,   5.7470599E-05,   5.8019206E-05,   5.8521284E-05
     +,   5.8995756E-05,   5.9460090E-05,   5.9929320E-05
     +,   6.0415099E-05,   6.0925071E-05,   6.1462109E-05
     +,   6.2023952E-05,   6.2603067E-05,   6.3186701E-05
     +,   6.3757245E-05,   6.4292799E-05,   6.4768130E-05
     +,   6.5155851E-05,   6.5427761E-05,   6.5556749E-05
     +,   6.5518776E-05,   6.5295484E-05,   6.4877175E-05
     +,   6.4266431E-05,   6.3482214E-05,   6.2564417E-05
     +,   6.1578692E-05,   6.0620532E-05,   5.9817870E-05
     +,   5.9331145E-05,   5.9349186E-05,   6.0079728E-05
     +,   6.1734616E-05,   6.4509753E-05,   6.8562862E-05
     +,   7.3993346E-05,   8.0828984E-05,   8.9024696E-05
     +,   9.8478493E-05,   1.0906519E-04,   1.2068252E-04
     +,   1.3330347E-04,   1.4702888E-04,   1.6213230E-04
     +,   1.7909445E-04,   1.9862945E-04,   2.2171381E-04
     +,   2.4960691E-04,   2.8385301E-04,   3.2624134E-04
     +,   3.7868426E-04,   4.4296766E-04,   5.2034837E-04
     +,   6.1101740E-04,   7.1349111E-04,   8.2404283E-04
     +,   9.3637418E-04,   1.0417624E-03,   1.1298353E-03
     +,   1.1899740E-03,   1.2131706E-03,   1.1939354E-03
     +,   1.1316873E-03,   1.0312138E-03,   9.0197101E-04
     +,   7.5636030E-04,   6.0748227E-04,   4.6695845E-04
     +,   3.4332788E-04,   2.4133692E-04,   1.6213061E-04
     +,   1.0406979E-04,   6.3815743E-05,   3.7377577E-05
     +,   2.0908819E-05,   1.1170692E-05,   5.6997133E-06
     +,   2.7774956E-06,   1.2927995E-06,   5.7487944E-07
     +,   2.4430221E-07,   9.9277180E-08,   3.8627572E-08
     +,   1.4426766E-08,   5.1982574E-09,   1.8257794E-09
     +,   6.3804217E-10,   2.3015073E-10,   9.0305936E-11
     +,   4.0377767E-11,   2.0695275E-11,   1.1722222E-11
     +,   7.0099850E-12,   4.2872906E-12,   2.6372199E-12
     +,   1.6192447E-12,   9.8926325E-13,   6.0065782E-13
     +,   3.6229944E-13,   2.1704920E-13,   1.2914228E-13
     +,   7.6312566E-14,   4.4786650E-14,   2.6104600E-14
     +,   1.5111019E-14,   8.6874740E-15,   4.9603118E-15
     +,   2.8127535E-15,   1.5840572E-15,   8.8599863E-16
     +,   4.9216516E-16,   2.7151578E-16,   1.4876325E-16
     +,   8.0950621E-17,   4.3748296E-17,   2.3480514E-17
     +,   1.2516380E-17,   6.6260745E-18,   3.4838498E-18
     +,   1.8191484E-18,   9.4341231E-19,   4.8589375E-19
     +,   2.4854544E-19,   1.2626318E-19,   6.3704811E-20
     +,   3.1920835E-20,   1.5885500E-20,   7.8513423E-21
     +,   3.8538082E-21,   1.8787293E-21,   9.0958464E-22
     +,   4.3736943E-22,   2.0886076E-22,   9.9058848E-23
     +,   4.6658718E-23,   2.1827316E-23,   1.0140772E-23
     +,   4.6791813E-24,   2.1442401E-24,   9.7589559E-25
     +,   4.4109946E-25,   1.9801486E-25
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt116 = Yx/0.00505555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1410644E-05,   1.1382304E-05
     +,   1.1353292E-05,   1.1323930E-05,   1.1294565E-05
     +,   1.1265560E-05,   1.1237302E-05,   1.1210200E-05
     +,   1.1184678E-05,   1.1161194E-05,   1.1140218E-05
     +,   1.1122247E-05,   1.1107802E-05,   1.1097425E-05
     +,   1.1091684E-05,   1.1091168E-05,   1.1096493E-05
     +,   1.1108295E-05,   1.1127238E-05,   1.1154007E-05
     +,   1.1189309E-05,   1.1233879E-05,   1.1288474E-05
     +,   1.1353871E-05,   1.1430871E-05,   1.1520297E-05
     +,   1.1622995E-05,   1.1739826E-05,   1.1871681E-05
     +,   1.2019459E-05,   1.2184083E-05,   1.2366494E-05
     +,   1.2567642E-05,   1.2788499E-05,   1.3030044E-05
     +,   1.3293266E-05,   1.3579170E-05,   1.3888753E-05
     +,   1.4223046E-05,   1.4583036E-05,   1.4969757E-05
     +,   1.5384208E-05,   1.5827389E-05,   1.6300288E-05
     +,   1.6803882E-05,   1.7339120E-05,   1.7906932E-05
     +,   1.8508221E-05,   1.9143848E-05,   1.9814643E-05
     +,   2.0521378E-05,   2.1264781E-05,   2.2045502E-05
     +,   2.2864177E-05,   2.3721270E-05,   2.4617268E-05
     +,   2.5552505E-05,   2.6527223E-05,   2.7541559E-05
     +,   2.8595541E-05,   2.9689067E-05,   3.0821906E-05
     +,   3.1993626E-05,   3.3203716E-05,   3.4451525E-05
     +,   3.5736099E-05,   3.7056467E-05,   3.8411315E-05
     +,   3.9799292E-05,   4.1218686E-05,   4.2667754E-05
     +,   4.4144352E-05,   4.5646320E-05,   4.7171103E-05
     +,   4.8716040E-05,   5.0278290E-05,   5.1854688E-05
     +,   5.3441854E-05,   5.5036282E-05,   5.6634337E-05
     +,   5.8231963E-05,   5.9825179E-05,   6.1409613E-05
     +,   6.2980966E-05,   6.4534579E-05,   6.6065892E-05
     +,   6.7570050E-05,   6.9042304E-05,   7.0477705E-05
     +,   7.1871364E-05,   7.3218427E-05,   7.4513977E-05
     +,   7.5753138E-05,   7.6931239E-05,   7.8043719E-05
     +,   7.9086014E-05,   8.0053927E-05,   8.0943326E-05
     +,   8.1750426E-05,   8.2471663E-05,   8.3103805E-05
     +,   8.3643921E-05,   8.4089486E-05,   8.4438318E-05
     +,   8.4688669E-05,   8.4839230E-05,   8.4889136E-05
     +,   8.4838000E-05,   8.4685911E-05,   8.4433465E-05
     +,   8.4081781E-05,   8.3632454E-05,   8.3087682E-05
     +,   8.2450046E-05,   8.1722785E-05,   8.0909544E-05
     +,   8.0014535E-05,   7.9042373E-05,   7.7998244E-05
     +,   7.6887707E-05,   7.5716671E-05,   7.4491618E-05
     +,   7.3219293E-05,   7.1906747E-05,   7.0561335E-05
     +,   6.9190726E-05,   6.7802692E-05,   6.6405300E-05
     +,   6.5006585E-05,   6.3614847E-05,   6.2238185E-05
     +,   6.0884882E-05,   5.9562972E-05,   5.8280504E-05
     +,   5.7045236E-05,   5.5864690E-05,   5.4746142E-05
     +,   5.3696589E-05,   5.2722527E-05,   5.1830059E-05
     +,   5.1024814E-05,   5.0311985E-05,   4.9696086E-05
     +,   4.9181079E-05,   4.8770391E-05,   4.8466736E-05
     +,   4.8272199E-05,   4.8188227E-05,   4.8215610E-05
     +,   4.8354515E-05,   4.8604456E-05,   4.8964350E-05
     +,   4.9432583E-05,   5.0007031E-05,   5.0685139E-05
     +,   5.1463991E-05,   5.2340351E-05,   5.3310850E-05
     +,   5.4372093E-05,   5.5520621E-05,   5.6753255E-05
     +,   5.8067184E-05,   5.9459941E-05,   6.0929757E-05
     +,   6.2475694E-05,   6.4097789E-05,   6.5797081E-05
     +,   6.7575864E-05,   6.9437956E-05,   7.1388713E-05
     +,   7.3435018E-05,   7.5585456E-05,   7.7850549E-05
     +,   8.0242673E-05,   8.2775798E-05,   8.5465828E-05
     +,   8.8330409E-05,   9.1388523E-05,   9.4660441E-05
     +,   9.8167700E-05,   1.0193265E-04,   1.0597777E-04
     +,   1.1032546E-04,   1.1499789E-04,   1.2001622E-04
     +,   1.2539969E-04,   1.3116526E-04,   1.3732736E-04
     +,   1.4389699E-04,   1.5088041E-04,   1.5827962E-04
     +,   1.6609134E-04,   1.7430582E-04,   1.8290679E-04
     +,   1.9187163E-04,   2.0117055E-04,   2.1076579E-04
     +,   2.2061200E-04,   2.3065699E-04,   2.4084149E-04
     +,   2.5109845E-04,   2.6135467E-04,   2.7153178E-04
     +,   2.8154670E-04,   2.9131141E-04,   3.0073628E-04
     +,   3.0973009E-04,   3.1820076E-04,   3.2605772E-04
     +,   3.3321348E-04,   3.3958475E-04,   3.4509326E-04
     +,   3.4966791E-04,   3.5324620E-04,   3.5577489E-04
     +,   3.5721104E-04,   3.5752318E-04,   3.5669189E-04
     +,   3.5470998E-04,   3.5158309E-04,   3.4732930E-04
     +,   3.4197906E-04,   3.3557479E-04,   3.2817031E-04
     +,   3.1982939E-04,   3.1062475E-04,   3.0063774E-04
     +,   2.8995640E-04,   2.7867340E-04,   2.6688492E-04
     +,   2.5469015E-04,   2.4218910E-04,   2.2948008E-04
     +,   2.1665922E-04,   2.0382057E-04,   1.9105228E-04
     +,   1.7843687E-04,   1.6605125E-04,   1.5396510E-04
     +,   1.4223969E-04,   1.3092827E-04,   1.2007653E-04
     +,   1.0972197E-04,   9.9893245E-05,   9.0611218E-05
     +,   8.1889862E-05,   7.3736090E-05,   6.6149805E-05
     +,   5.9125116E-05,   5.2651660E-05,   4.6713823E-05
     +,   4.1292275E-05,   3.6364920E-05,   3.1907093E-05
     +,   2.7892012E-05,   2.4291659E-05,   2.1077542E-05
     +,   1.8220884E-05,   1.5692871E-05,   1.3465296E-05
     +,   1.1510946E-05,   9.8036880E-06,   8.3185569E-06
     +,   7.0320775E-06,   5.9224358E-06,   4.9692994E-06
     +,   4.1539843E-06,   3.4594841E-06,   2.8703621E-06
     +,   2.3726727E-06,   1.9539409E-06,   1.6030967E-06
     +,   1.3103428E-06,   1.0670481E-06,   8.6567229E-07
     +,   6.9967922E-07,   5.6339633E-07,   4.5196438E-07
     +,   3.6121287E-07,   2.8760525E-07,   2.2813838E-07
     +,   1.8029094E-07,   1.4194391E-07,   1.1133539E-07
     +,   8.6999378E-08,   6.7728621E-08,   5.2528851E-08
     +,   4.0587192E-08,   3.1243005E-08,   2.3959698E-08
     +,   1.8305537E-08,   1.3933106E-08,   1.0565388E-08
     +,   7.9815425E-09,   6.0070371E-09,   4.5039883E-09
     +,   3.3643874E-09,   2.5036764E-09,   1.8561883E-09
     +,   1.3709747E-09,   1.0088089E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt118 = Yx/0.00595
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5281741E-05,   2.5744017E-05
     +,   2.6218488E-05,   2.6705766E-05,   2.7206466E-05
     +,   2.7721222E-05,   2.8250672E-05,   2.8795475E-05
     +,   2.9356288E-05,   2.9933813E-05,   3.0528739E-05
     +,   3.1141764E-05,   3.1773616E-05,   3.2425032E-05
     +,   3.3096749E-05,   3.3789522E-05,   3.4504119E-05
     +,   3.5241301E-05,   3.6001824E-05,   3.6786463E-05
     +,   3.7595961E-05,   3.8431052E-05,   3.9292434E-05
     +,   4.0180843E-05,   4.1096853E-05,   4.2041109E-05
     +,   4.3014115E-05,   4.4016357E-05,   4.5048189E-05
     +,   4.6109904E-05,   4.7201665E-05,   4.8323531E-05
     +,   4.9475384E-05,   5.0656992E-05,   5.1867937E-05
     +,   5.3107615E-05,   5.4375239E-05,   5.5669778E-05
     +,   5.6990069E-05,   5.8334590E-05,   5.9701695E-05
     +,   6.1089413E-05,   6.2495565E-05,   6.3917687E-05
     +,   6.5353073E-05,   6.6798770E-05,   6.8251531E-05
     +,   6.9707945E-05,   7.1164301E-05,   7.2616698E-05
     +,   7.4061041E-05,   7.5493059E-05,   7.6908284E-05
     +,   7.8302262E-05,   7.9670215E-05,   8.1007529E-05
     +,   8.2309438E-05,   8.3571227E-05,   8.4788233E-05
     +,   8.5955886E-05,   8.7069755E-05,   8.8125627E-05
     +,   8.9119421E-05,   9.0047426E-05,   9.0906287E-05
     +,   9.1692797E-05,   9.2404414E-05,   9.3038812E-05
     +,   9.3594259E-05,   9.4069481E-05,   9.4463729E-05
     +,   9.4776777E-05,   9.5009047E-05,   9.5161442E-05
     +,   9.5235489E-05,   9.5233299E-05,   9.5157549E-05
     +,   9.5011477E-05,   9.4798874E-05,   9.4524024E-05
     +,   9.4191731E-05,   9.3807212E-05,   9.3376126E-05
     +,   9.2904447E-05,   9.2398499E-05,   9.1864793E-05
     +,   9.1310103E-05,   9.0741196E-05,   9.0165071E-05
     +,   8.9588524E-05,   8.9018351E-05,   8.8461202E-05
     +,   8.7923487E-05,   8.7411303E-05,   8.6930362E-05
     +,   8.6486034E-05,   8.6083099E-05,   8.5725900E-05
     +,   8.5418113E-05,   8.5162814E-05,   8.4962427E-05
     +,   8.4818690E-05,   8.4732579E-05,   8.4704370E-05
     +,   8.4733612E-05,   8.4819134E-05,   8.4959021E-05
     +,   8.5150677E-05,   8.5390813E-05,   8.5675565E-05
     +,   8.6000466E-05,   8.6360509E-05,   8.6750202E-05
     +,   8.7163709E-05,   8.7594810E-05,   8.8037050E-05
     +,   8.8483772E-05,   8.8928347E-05,   8.9363966E-05
     +,   8.9784095E-05,   9.0182213E-05,   9.0552181E-05
     +,   9.0888083E-05,   9.1184549E-05,   9.1436639E-05
     +,   9.1639995E-05,   9.1790898E-05,   9.1886366E-05
     +,   9.1924085E-05,   9.1902606E-05,   9.1821261E-05
     +,   9.1680246E-05,   9.1480601E-05,   9.1224305E-05
     +,   9.0914109E-05,   9.0553629E-05,   9.0147376E-05
     +,   8.9700603E-05,   8.9219298E-05,   8.8710163E-05
     +,   8.8180568E-05,   8.7638451E-05,   8.7092216E-05
     +,   8.6550710E-05,   8.6023167E-05,   8.5519016E-05
     +,   8.5047861E-05,   8.4619474E-05,   8.4243482E-05
     +,   8.3929495E-05,   8.3686886E-05,   8.3524727E-05
     +,   8.3451778E-05,   8.3476240E-05,   8.3605832E-05
     +,   8.3847561E-05,   8.4207852E-05,   8.4692219E-05
     +,   8.5305452E-05,   8.6051310E-05,   8.6932676E-05
     +,   8.7951463E-05,   8.9108449E-05,   9.0403286E-05
     +,   9.1834663E-05,   9.3400035E-05,   9.5095733E-05
     +,   9.6916869E-05,   9.8857483E-05,   1.0091056E-04
     +,   1.0306778E-04,   1.0531978E-04,   1.0765624E-04
     +,   1.1006590E-04,   1.1253630E-04,   1.1505435E-04
     +,   1.1760616E-04,   1.2017700E-04,   1.2275153E-04
     +,   1.2531405E-04,   1.2784843E-04,   1.3033822E-04
     +,   1.3276673E-04,   1.3511740E-04,   1.3737389E-04
     +,   1.3951991E-04,   1.4153948E-04,   1.4341748E-04
     +,   1.4513927E-04,   1.4669096E-04,   1.4805973E-04
     +,   1.4923372E-04,   1.5020222E-04,   1.5095575E-04
     +,   1.5148630E-04,   1.5178716E-04,   1.5185314E-04
     +,   1.5168059E-04,   1.5126745E-04,   1.5061306E-04
     +,   1.4971856E-04,   1.4858648E-04,   1.4722097E-04
     +,   1.4562745E-04,   1.4381303E-04,   1.4178587E-04
     +,   1.3955536E-04,   1.3713219E-04,   1.3452799E-04
     +,   1.3175518E-04,   1.2882687E-04,   1.2575700E-04
     +,   1.2255996E-04,   1.1925033E-04,   1.1584289E-04
     +,   1.1235269E-04,   1.0879477E-04,   1.0518375E-04
     +,   1.0153399E-04,   9.7859804E-05,   9.4174669E-05
     +,   9.0491492E-05,   8.6822780E-05,   8.3180341E-05
     +,   7.9574973E-05,   7.6016673E-05,   7.2514857E-05
     +,   6.9078080E-05,   6.5713808E-05,   6.2428648E-05
     +,   5.9228591E-05,   5.6118781E-05,   5.3103329E-05
     +,   5.0185608E-05,   4.7368507E-05,   4.4653938E-05
     +,   4.2043164E-05,   3.9537033E-05,   3.7135756E-05
     +,   3.4838929E-05,   3.2645661E-05,   3.0554798E-05
     +,   2.8564813E-05,   2.6673701E-05,   2.4879198E-05
     +,   2.3178927E-05,   2.1570297E-05,   2.0050433E-05
     +,   1.8616365E-05,   1.7265151E-05,   1.5993643E-05
     +,   1.4798658E-05,   1.3677071E-05,   1.2625748E-05
     +,   1.1641503E-05,   1.0721184E-05,   9.8617538E-06
     +,   9.0602198E-06,   8.3135965E-06,   7.6189822E-06
     +,   6.9736016E-06,   6.3747543E-06,   5.8197897E-06
     +,   5.3061513E-06,   4.8314273E-06,   4.3932423E-06
     +,   3.9893284E-06,   3.6175306E-06,   3.2757896E-06
     +,   2.9621133E-06,   2.6746063E-06,   2.4114818E-06
     +,   2.1710396E-06,   1.9516501E-06,   1.7517723E-06
     +,   1.5699671E-06,   1.4048509E-06,   1.2551418E-06
     +,   1.1196142E-06,   9.9713429E-07,   8.8662267E-07
     +,   7.8708433E-07,   6.9757613E-07,   6.1723068E-07
     +,   5.4523036E-07,   4.8082546E-07,   4.2331465E-07
     +,   3.7204941E-07,   3.2643629E-07,   2.8592285E-07
     +,   2.5000671E-07,   2.1822213E-07,   1.9014743E-07
     +,   1.6539383E-07,   1.4361035E-07,   1.2447521E-07
     +,   1.0769894E-07,   9.3017512E-08,   8.0194376E-08
     +,   6.9014845E-08,   5.9287345E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt120 = Yx/0.00515789473684211
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2861334E-05,   1.3795327E-05
     +,   1.4801743E-05,   1.5888312E-05,   1.7063545E-05
     +,   1.8336712E-05,   1.9717821E-05,   2.1217596E-05
     +,   2.2847355E-05,   2.4619047E-05,   2.6544943E-05
     +,   2.8637654E-05,   3.0909880E-05,   3.3374268E-05
     +,   3.6043166E-05,   3.8928425E-05,   4.2041156E-05
     +,   4.5391498E-05,   4.8988397E-05,   5.2839368E-05
     +,   5.6950314E-05,   6.1325336E-05,   6.5966582E-05
     +,   7.0874521E-05,   7.6046985E-05,   8.1480452E-05
     +,   8.7169079E-05,   9.3105373E-05,   9.9280202E-05
     +,   1.0568306E-04,   1.1230230E-04,   1.1912540E-04
     +,   1.2613928E-04,   1.3333042E-04,   1.4068524E-04
     +,   1.4819013E-04,   1.5583154E-04,   1.6359592E-04
     +,   1.7147016E-04,   1.7944023E-04,   1.8749233E-04
     +,   1.9561163E-04,   2.0378218E-04,   2.1198674E-04
     +,   2.2020607E-04,   2.2841913E-04,   2.3660249E-04
     +,   2.4473082E-04,   2.5277658E-04,   2.6071092E-04
     +,   2.6850417E-04,   2.7612658E-04,   2.8354969E-04
     +,   2.9074785E-04,   2.9769854E-04,   3.0438558E-04
     +,   3.1079893E-04,   3.1693702E-04,   3.2280723E-04
     +,   3.2842695E-04,   3.3382358E-04,   3.3903486E-04
     +,   3.4410696E-04,   3.4909445E-04,   3.5405747E-04
     +,   3.5905949E-04,   3.6416476E-04,   3.6943404E-04
     +,   3.7492276E-04,   3.8067595E-04,   3.8672672E-04
     +,   3.9309188E-04,   3.9977103E-04,   4.0674437E-04
     +,   4.1397268E-04,   4.2139803E-04,   4.2894468E-04
     +,   4.3652233E-04,   4.4402995E-04,   4.5136060E-04
     +,   4.5840495E-04,   4.6505861E-04,   4.7122606E-04
     +,   4.7682630E-04,   4.8179700E-04,   4.8609811E-04
     +,   4.8971386E-04,   4.9265492E-04,   4.9495732E-04
     +,   4.9668312E-04,   4.9791753E-04,   4.9876707E-04
     +,   4.9935817E-04,   4.9983372E-04,   5.0035107E-04
     +,   5.0107972E-04,   5.0219911E-04,   5.0389615E-04
     +,   5.0636183E-04,   5.0978694E-04,   5.1435747E-04
     +,   5.2024663E-04,   5.2760716E-04,   5.3656165E-04
     +,   5.4719188E-04,   5.5952900E-04,   5.7354354E-04
     +,   5.8913772E-04,   6.0614262E-04,   6.2431680E-04
     +,   6.4334879E-04,   6.6287006E-04,   6.8246364E-04
     +,   7.0168689E-04,   7.2008779E-04,   7.3723187E-04
     +,   7.5272087E-04,   7.6621812E-04,   7.7746232E-04
     +,   7.8628631E-04,   7.9261977E-04,   7.9649186E-04
     +,   7.9802715E-04,   7.9743064E-04,   7.9497031E-04
     +,   7.9095445E-04,   7.8570721E-04,   7.7954121E-04
     +,   7.7273551E-04,   7.6551485E-04,   7.5803453E-04
     +,   7.5037481E-04,   7.4253994E-04,   7.3446683E-04
     +,   7.2603929E-04,   7.1710773E-04,   7.0751255E-04
     +,   6.9710723E-04,   6.8577885E-04,   6.7346566E-04
     +,   6.6017092E-04,   6.4596510E-04,   6.3098408E-04
     +,   6.1541976E-04,   5.9950812E-04,   5.8350631E-04
     +,   5.6767539E-04,   5.5225997E-04,   5.3747033E-04
     +,   5.2346621E-04,   5.1035004E-04,   4.9816235E-04
     +,   4.8688304E-04,   4.7643637E-04,   4.6670198E-04
     +,   4.5752837E-04,   4.4874521E-04,   4.4017824E-04
     +,   4.3166173E-04,   4.2305046E-04,   4.1422699E-04
     +,   4.0510733E-04,   3.9564463E-04,   3.8582791E-04
     +,   3.7567920E-04,   3.6524935E-04,   3.5461373E-04
     +,   3.4386394E-04,   3.3310140E-04,   3.2243147E-04
     +,   3.1195776E-04,   3.0177709E-04,   2.9197463E-04
     +,   2.8262124E-04,   2.7377324E-04,   2.6546916E-04
     +,   2.5773060E-04,   2.5056358E-04,   2.4395909E-04
     +,   2.3789429E-04,   2.3233503E-04,   2.2723802E-04
     +,   2.2255286E-04,   2.1822365E-04,   2.1419144E-04
     +,   2.1039632E-04,   2.0677895E-04,   2.0328139E-04
     +,   1.9984927E-04,   1.9643252E-04,   1.9298584E-04
     +,   1.8946971E-04,   1.8585070E-04,   1.8210185E-04
     +,   1.7820220E-04,   1.7413702E-04,   1.6989779E-04
     +,   1.6548175E-04,   1.6089102E-04,   1.5613252E-04
     +,   1.5121754E-04,   1.4616111E-04,   1.4098079E-04
     +,   1.3569659E-04,   1.3033087E-04,   1.2490657E-04
     +,   1.1944734E-04,   1.1397742E-04,   1.0852068E-04
     +,   1.0310004E-04,   9.7737277E-05,   9.2453323E-05
     +,   8.7267494E-05,   8.2197061E-05,   7.7257471E-05
     +,   7.2462542E-05,   6.7824112E-05,   6.3351814E-05
     +,   5.9053338E-05,   5.4935001E-05,   5.1000923E-05
     +,   4.7253645E-05,   4.3694450E-05,   4.0323219E-05
     +,   3.7138379E-05,   3.4137316E-05,   3.1316649E-05
     +,   2.8672159E-05,   2.6198761E-05,   2.3890821E-05
     +,   2.1742413E-05,   1.9747218E-05,   1.7898521E-05
     +,   1.6189446E-05,   1.4613170E-05,   1.3162658E-05
     +,   1.1830894E-05,   1.0611019E-05,   9.4962634E-06
     +,   8.4799130E-06,   7.5554403E-06,   6.7165693E-06
     +,   5.9572321E-06,   5.2715363E-06,   4.6538476E-06
     +,   4.0988252E-06,   3.6013846E-06,   3.1566733E-06
     +,   2.7601141E-06,   2.4074377E-06,   2.0946045E-06
     +,   1.8178422E-06,   1.5736581E-06,   1.3588076E-06
     +,   1.1702763E-06,   1.0052920E-06,   8.6131809E-07
     +,   7.3603445E-07,   6.2731687E-07,   5.3323890E-07
     +,   4.5206312E-07,   3.8222245E-07,   3.2230383E-07
     +,   2.7104440E-07,   2.2732183E-07,   1.9013500E-07
     +,   1.5859762E-07,   1.3193021E-07,   1.0944712E-07
     +,   9.0546600E-08,   7.4703692E-08,   6.1463147E-08
     +,   5.0430256E-08,   4.1263540E-08,   3.3669490E-08
     +,   2.7397157E-08,   2.2231379E-08,   1.7989695E-08
     +,   1.4516801E-08,   1.1681889E-08,   9.3743910E-09
     +,   7.5018258E-09,   5.9865672E-09,   4.7641087E-09
     +,   3.7806931E-09,   2.9919414E-09,   2.3611524E-09
     +,   1.8581473E-09,   1.4582368E-09,   1.1411972E-09
     +,   8.9060653E-10,   6.9309980E-10,   5.3789495E-10
     +,   4.1627854E-10,   3.2126485E-10,   2.4724475E-10
     +,   1.8975070E-10,   1.4521949E-10,   1.1083045E-10
     +,   8.4348771E-11,   6.4016424E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt75 = Yx/0.018
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5084771E-08,   5.7313041E-08
     +,   7.2582090E-08,   9.1571700E-08,   1.1509415E-07
     +,   1.4411495E-07,   1.7977652E-07,   2.2342390E-07
     +,   2.7663214E-07,   3.4123977E-07,   4.1937753E-07
     +,   5.1350457E-07,   6.2644608E-07,   7.6142919E-07
     +,   9.2212309E-07,   1.1126762E-06,   1.3377562E-06
     +,   1.6025874E-06,   1.9129839E-06,   2.2753861E-06
     +,   2.6968844E-06,   3.1852469E-06,   3.7489260E-06
     +,   4.3971181E-06,   5.1396532E-06,   5.9871418E-06
     +,   6.9508278E-06,   8.0426316E-06,   9.2750834E-06
     +,   1.0661293E-05,   1.2214859E-05,   1.3949824E-05
     +,   1.5880558E-05,   1.8021668E-05,   2.0387892E-05
     +,   2.2993949E-05,   2.5854406E-05,   2.8983459E-05
     +,   3.2395066E-05,   3.6102108E-05,   4.0117025E-05
     +,   4.4450942E-05,   4.9113751E-05,   5.4113814E-05
     +,   5.9457700E-05,   6.5149950E-05,   7.1192764E-05
     +,   7.7585770E-05,   8.4325715E-05,   9.1406182E-05
     +,   9.8817334E-05,   1.0654563E-04,   1.1457353E-04
     +,   1.2287988E-04,   1.3143838E-04,   1.4021933E-04
     +,   1.4918816E-04,   1.5830618E-04,   1.6753073E-04
     +,   1.7681533E-04,   1.8611019E-04,   1.9536304E-04
     +,   2.0451883E-04,   2.1352198E-04,   2.2231659E-04
     +,   2.3084659E-04,   2.3905857E-04,   2.4690115E-04
     +,   2.5432734E-04,   2.6129451E-04,   2.6776662E-04
     +,   2.7371329E-04,   2.7911234E-04,   2.8394835E-04
     +,   2.8821439E-04,   2.9191098E-04,   2.9504596E-04
     +,   2.9763387E-04,   2.9969550E-04,   3.0125669E-04
     +,   3.0234703E-04,   3.0299905E-04,   3.0324719E-04
     +,   3.0312658E-04,   3.0267233E-04,   3.0191909E-04
     +,   3.0090057E-04,   2.9964972E-04,   2.9819921E-04
     +,   2.9658162E-04,   2.9483074E-04,   2.9298267E-04
     +,   2.9107663E-04,   2.8915604E-04,   2.8726965E-04
     +,   2.8547205E-04,   2.8382349E-04,   2.8239007E-04
     +,   2.8124225E-04,   2.8045365E-04,   2.8009835E-04
     +,   2.8024885E-04,   2.8097222E-04,   2.8232718E-04
     +,   2.8436023E-04,   2.8710262E-04,   2.9056732E-04
     +,   2.9474674E-04,   2.9961174E-04,   3.0511137E-04
     +,   3.1117338E-04,   3.1770769E-04,   3.2460919E-04
     +,   3.3176364E-04,   3.3905276E-04,   3.4636262E-04
     +,   3.5358919E-04,   3.6064824E-04,   3.6748027E-04
     +,   3.7405893E-04,   3.8039580E-04,   3.8654372E-04
     +,   3.9259903E-04,   3.9870266E-04,   4.0503725E-04
     +,   4.1182266E-04,   4.1931184E-04,   4.2778239E-04
     +,   4.3753057E-04,   4.4886119E-04,   4.6208213E-04
     +,   4.7749432E-04,   4.9538753E-04,   5.1602896E-04
     +,   5.3966022E-04,   5.6648592E-04,   5.9666077E-04
     +,   6.3027476E-04,   6.6733855E-04,   7.0775719E-04
     +,   7.5130543E-04,   7.9760252E-04,   8.4609631E-04
     +,   8.9604378E-04,   9.4650220E-04,   9.9634985E-04
     +,   1.0443078E-03,   1.0889824E-03,   1.1289306E-03
     +,   1.1627396E-03,   1.1891057E-03,   1.2069201E-03
     +,   1.2153513E-03,   1.2139068E-03,   1.2024792E-03
     +,   1.1813642E-03,   1.1512524E-03,   1.1131907E-03
     +,   1.0685230E-03,   1.0188149E-03,   9.6575514E-04
     +,   9.1106514E-04,   8.5641193E-04,   8.0332474E-04
     +,   7.5312890E-04,   7.0690649E-04,   6.6547602E-04
     +,   6.2938698E-04,   5.9893279E-04,   5.7418324E-04
     +,   5.5502122E-04,   5.4118095E-04,   5.3228688E-04
     +,   5.2788918E-04,   5.2749115E-04,   5.3056731E-04
     +,   5.3657650E-04,   5.4496597E-04,   5.5517250E-04
     +,   5.6662317E-04,   5.7873357E-04,   5.9090980E-04
     +,   6.0255412E-04,   6.1307626E-04,   6.2190549E-04
     +,   6.2850723E-04,   6.3240348E-04,   6.3319091E-04
     +,   6.3055771E-04,   6.2429981E-04,   6.1432883E-04
     +,   6.0067704E-04,   5.8349740E-04,   5.6305551E-04
     +,   5.3971511E-04,   5.1392143E-04,   4.8618211E-04
     +,   4.5704315E-04,   4.2706207E-04,   3.9678760E-04
     +,   3.6674039E-04,   3.3739299E-04,   3.0915462E-04
     +,   2.8236274E-04,   2.5728080E-04,   2.3409176E-04
     +,   2.1290347E-04,   1.9375594E-04,   1.7662747E-04
     +,   1.6144358E-04,   1.4808908E-04,   1.3641929E-04
     +,   1.2626935E-04,   1.1746296E-04,   1.0982146E-04
     +,   1.0317100E-04,   9.7347001E-05,   9.2198141E-05
     +,   8.7588982E-05,   8.3402003E-05,   7.9536985E-05
     +,   7.5911194E-05,   7.2458526E-05,   6.9127913E-05
     +,   6.5881461E-05,   6.2692860E-05,   5.9545819E-05
     +,   5.6432003E-05,   5.3349213E-05,   5.0300139E-05
     +,   4.7291127E-05,   4.4330882E-05,   4.1429292E-05
     +,   3.8596834E-05,   3.5844190E-05,   3.3181193E-05
     +,   3.0616804E-05,   2.8158940E-05,   2.5814184E-05
     +,   2.3587543E-05,   2.1482609E-05,   1.9501689E-05
     +,   1.7645738E-05,   1.5914336E-05,   1.4305961E-05
     +,   1.2818169E-05,   1.1447657E-05,   1.0190280E-05
     +,   9.0412959E-06,   7.9956098E-06,   7.0476476E-06
     +,   6.1916062E-06,   5.4215916E-06,   4.7316485E-06
     +,   4.1157937E-06,   3.5681519E-06,   3.0830347E-06
     +,   2.6549453E-06,   2.2785946E-06,   1.9489698E-06
     +,   1.6613687E-06,   1.4113883E-06,   1.1949187E-06
     +,   1.0081698E-06,   8.4767925E-07,   7.1027148E-07
     +,   5.9306763E-07,   4.9347852E-07,   4.0918007E-07
     +,   3.3809246E-07,   2.7837112E-07,   2.2839082E-07
     +,   1.8672307E-07,   1.5211627E-07,   1.2348232E-07
     +,   9.9882229E-08,   8.0503845E-08,   6.4653690E-08
     +,   5.1737974E-08,   4.1254236E-08,   3.2776470E-08
     +,   2.5947442E-08,   2.0467150E-08,   1.6086265E-08
     +,   1.2597378E-08,   9.8296331E-09,   7.6422593E-09
     +,   5.9200964E-09,   4.5694608E-09,   3.5141610E-09
     +,   2.6928075E-09,   2.0559281E-09,   1.5639990E-09
     +,   1.1854482E-09,   8.9526903E-10,   6.7365974E-10
     +,   5.0507043E-10,   3.7729314E-10,   2.8082114E-10
     +,   2.0825498E-10,   1.5388066E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt80 = Yx/0.0185862068965517
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2651426E-05,   1.3171226E-05
     +,   1.3702687E-05,   1.4245624E-05,   1.4799844E-05
     +,   1.5365165E-05,   1.5941408E-05,   1.6528413E-05
     +,   1.7126031E-05,   1.7734183E-05,   1.8352797E-05
     +,   1.8981867E-05,   1.9621441E-05,   2.0271656E-05
     +,   2.0932728E-05,   2.1604967E-05,   2.2288801E-05
     +,   2.2984776E-05,   2.3693567E-05,   2.4416007E-05
     +,   2.5153082E-05,   2.5905940E-05,   2.6675903E-05
     +,   2.7464510E-05,   2.8273420E-05,   2.9104556E-05
     +,   2.9959991E-05,   3.0842006E-05,   3.1753058E-05
     +,   3.2695785E-05,   3.3672983E-05,   3.4687611E-05
     +,   3.5742716E-05,   3.6841491E-05,   3.7987153E-05
     +,   3.9182978E-05,   4.0432224E-05,   4.1738072E-05
     +,   4.3103697E-05,   4.4531964E-05,   4.6025674E-05
     +,   4.7587280E-05,   4.9218936E-05,   5.0922434E-05
     +,   5.2699099E-05,   5.4549804E-05,   5.6474881E-05
     +,   5.8474074E-05,   6.0546561E-05,   6.2690902E-05
     +,   6.4905056E-05,   6.7186338E-05,   6.9531525E-05
     +,   7.1936985E-05,   7.4398384E-05,   7.6911303E-05
     +,   7.9470956E-05,   8.2072474E-05,   8.4711035E-05
     +,   8.7382046E-05,   9.0081317E-05,   9.2805254E-05
     +,   9.5550888E-05,   9.8316421E-05,   1.0110119E-04
     +,   1.0390551E-04,   1.0673152E-04,   1.0958240E-04
     +,   1.1246333E-04,   1.1538051E-04,   1.1834205E-04
     +,   1.2135694E-04,   1.2443565E-04,   1.2758910E-04
     +,   1.3082896E-04,   1.3416704E-04,   1.3761452E-04
     +,   1.4118165E-04,   1.4487767E-04,   1.4870963E-04
     +,   1.5268184E-04,   1.5679614E-04,   1.6105021E-04
     +,   1.6543841E-04,   1.6995032E-04,   1.7457153E-04
     +,   1.7928242E-04,   1.8405945E-04,   1.8887391E-04
     +,   1.9369338E-04,   1.9848184E-04,   2.0319955E-04
     +,   2.0780443E-04,   2.1225301E-04,   2.1650085E-04
     +,   2.2050343E-04,   2.2421776E-04,   2.2760262E-04
     +,   2.3062027E-04,   2.3323683E-04,   2.3542375E-04
     +,   2.3715802E-04,   2.3842354E-04,   2.3921102E-04
     +,   2.3951891E-04,   2.3935350E-04,   2.3872906E-04
     +,   2.3766786E-04,   2.3619983E-04,   2.3436223E-04
     +,   2.3219940E-04,   2.2976172E-04,   2.2710515E-04
     +,   2.2428995E-04,   2.2138015E-04,   2.1844177E-04
     +,   2.1554237E-04,   2.1274884E-04,   2.1012696E-04
     +,   2.0773949E-04,   2.0564510E-04,   2.0389765E-04
     +,   2.0254534E-04,   2.0163045E-04,   2.0119002E-04
     +,   2.0125763E-04,   2.0186596E-04,   2.0305047E-04
     +,   2.0485559E-04,   2.0734030E-04,   2.1058712E-04
     +,   2.1470903E-04,   2.1985856E-04,   2.2623359E-04
     +,   2.3408284E-04,   2.4370647E-04,   2.5545195E-04
     +,   2.6970488E-04,   2.8687564E-04,   3.0737786E-04
     +,   3.3160165E-04,   3.5988548E-04,   3.9248870E-04
     +,   4.2956078E-04,   4.7111299E-04,   5.1700749E-04
     +,   5.6694302E-04,   6.2045187E-04,   6.7691103E-04
     +,   7.3556526E-04,   7.9555064E-04,   8.5592089E-04
     +,   9.1568800E-04,   9.7386254E-04,   1.0294826E-03
     +,   1.0816407E-03,   1.1295137E-03,   1.1723826E-03
     +,   1.2096390E-03,   1.2407895E-03,   1.2654605E-03
     +,   1.2833913E-03,   1.2944291E-03,   1.2985331E-03
     +,   1.2957749E-03,   1.2863466E-03,   1.2705749E-03
     +,   1.2489385E-03,   1.2220740E-03,   1.1907808E-03
     +,   1.1560123E-03,   1.1188433E-03,   1.0804168E-03
     +,   1.0418777E-03,   1.0042978E-03,   9.6858788E-04
     +,   9.3542685E-04,   9.0521143E-04,   8.7802822E-04
     +,   8.5365941E-04,   8.3162257E-04,   8.1124017E-04
     +,   7.9172233E-04,   7.7225658E-04,   7.5209880E-04
     +,   7.3064375E-04,   7.0747832E-04,   6.8240153E-04
     +,   6.5542577E-04,   6.2675640E-04,   5.9674593E-04
     +,   5.6584843E-04,   5.3456950E-04,   5.0341629E-04
     +,   4.7285625E-04,   4.4328949E-04,   4.1503322E-04
     +,   3.8831276E-04,   3.6326153E-04,   3.3993213E-04
     +,   3.1831057E-04,   2.9832972E-04,   2.7988295E-04
     +,   2.6284100E-04,   2.4706419E-04,   2.3241021E-04
     +,   2.1874267E-04,   2.0593737E-04,   1.9388422E-04
     +,   1.8248818E-04,   1.7167041E-04,   1.6136839E-04
     +,   1.5153359E-04,   1.4212955E-04,   1.3313035E-04
     +,   1.2451944E-04,   1.1628693E-04,   1.0842731E-04
     +,   1.0093841E-04,   9.3820563E-05,   8.7073946E-05
     +,   8.0698410E-05,   7.4692995E-05,   6.9054964E-05
     +,   6.3779160E-05,   5.8858153E-05,   5.4282631E-05
     +,   5.0041053E-05,   4.6119640E-05,   4.2502994E-05
     +,   3.9174611E-05,   3.6116991E-05,   3.3311764E-05
     +,   3.0740353E-05,   2.8384442E-05,   2.6225833E-05
     +,   2.4246947E-05,   2.2431135E-05,   2.0762745E-05
     +,   1.9227105E-05,   1.7810755E-05,   1.6501575E-05
     +,   1.5288675E-05,   1.4162305E-05,   1.3113902E-05
     +,   1.2136075E-05,   1.1222443E-05,   1.0367479E-05
     +,   9.5664782E-06,   8.8155348E-06,   8.1112630E-06
     +,   7.4507893E-06,   6.8317054E-06,   6.2519230E-06
     +,   5.7095758E-06,   5.2029886E-06,   4.7306617E-06
     +,   4.2911838E-06,   3.8831690E-06,   3.5052681E-06
     +,   3.1561694E-06,   2.8345587E-06,   2.5390909E-06
     +,   2.2684171E-06,   2.0212058E-06,   1.7960959E-06
     +,   1.5917311E-06,   1.4067784E-06,   1.2399199E-06
     +,   1.0898505E-06,   9.5529992E-07,   8.3504705E-07
     +,   7.2791329E-07,   6.3276423E-07,   5.4852245E-07
     +,   4.7417552E-07,   4.0876290E-07,   3.5139408E-07
     +,   3.0123337E-07,   2.5751442E-07,   2.1952530E-07
     +,   1.8661932E-07,   1.5820230E-07,   1.3373879E-07
     +,   1.1274197E-07,   9.4776894E-08,   7.9452015E-08
     +,   6.6418778E-08,   5.5368773E-08,   4.6027999E-08
     +,   3.8156415E-08,   3.1542484E-08,   2.6002349E-08
     +,   2.1375314E-08,   1.7522673E-08,   1.4324225E-08
     +,   1.1676967E-08,   9.4923109E-09,   7.6948901E-09
     +,   6.2203513E-09,   5.0143729E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt85 = Yx/0.017
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.8367069E-06,   9.5318137E-06
     +,   1.0263790E-05,   1.1032853E-05,   1.1839034E-05
     +,   1.2682174E-05,   1.3561914E-05,   1.4477669E-05
     +,   1.5428617E-05,   1.6413747E-05,   1.7431757E-05
     +,   1.8481112E-05,   1.9560019E-05,   2.0666437E-05
     +,   2.1798069E-05,   2.2952359E-05,   2.4126515E-05
     +,   2.5317488E-05,   2.6522013E-05,   2.7736607E-05
     +,   2.8957571E-05,   3.0181027E-05,   3.1402898E-05
     +,   3.2619071E-05,   3.3825138E-05,   3.5016754E-05
     +,   3.6189420E-05,   3.7338614E-05,   3.8459817E-05
     +,   3.9548522E-05,   4.0600295E-05,   4.1610791E-05
     +,   4.2575775E-05,   4.3491218E-05,   4.4353252E-05
     +,   4.5158260E-05,   4.5902911E-05,   4.6584169E-05
     +,   4.7199399E-05,   4.7746282E-05,   4.8223006E-05
     +,   4.8628179E-05,   4.8960945E-05,   4.9221020E-05
     +,   4.9408711E-05,   4.9524981E-05,   4.9571496E-05
     +,   4.9550690E-05,   4.9465798E-05,   4.9320937E-05
     +,   4.9121150E-05,   4.8872509E-05,   4.8582122E-05
     +,   4.8258200E-05,   4.7910249E-05,   4.7548936E-05
     +,   4.7186288E-05,   4.6835707E-05,   4.6511981E-05
     +,   4.6231344E-05,   4.6011475E-05,   4.5871442E-05
     +,   4.5831697E-05,   4.5913992E-05,   4.6141260E-05
     +,   4.6537392E-05,   4.7127181E-05,   4.7935868E-05
     +,   4.8989026E-05,   5.0312017E-05,   5.1929794E-05
     +,   5.3866119E-05,   5.6143486E-05,   5.8782054E-05
     +,   6.1799554E-05,   6.5210486E-05,   6.9025322E-05
     +,   7.3249998E-05,   7.7885641E-05,   8.2927902E-05
     +,   8.8365858E-05,   9.4182775E-05,   1.0035450E-04
     +,   1.0685068E-04,   1.1363318E-04,   1.2065782E-04
     +,   1.2787298E-04,   1.3522165E-04,   1.4264032E-04
     +,   1.5006123E-04,   1.5741269E-04,   1.6461953E-04
     +,   1.7160474E-04,   1.7829119E-04,   1.8460245E-04
     +,   1.9046353E-04,   1.9580367E-04,   2.0055614E-04
     +,   2.0466083E-04,   2.0806417E-04,   2.1072139E-04
     +,   2.1259629E-04,   2.1366283E-04,   2.1390489E-04
     +,   2.1331730E-04,   2.1190512E-04,   2.0968437E-04
     +,   2.0668117E-04,   2.0293141E-04,   1.9847990E-04
     +,   1.9338049E-04,   1.8769392E-04,   1.8148859E-04
     +,   1.7483803E-04,   1.6782194E-04,   1.6052379E-04
     +,   1.5303223E-04,   1.4543896E-04,   1.3784063E-04
     +,   1.3033740E-04,   1.2303428E-04,   1.1604239E-04
     +,   1.0947944E-04,   1.0347057E-04,   9.8150267E-05
     +,   9.3664064E-05,   9.0168687E-05,   8.7834094E-05
     +,   8.6843029E-05,   8.7391389E-05,   8.9687041E-05
     +,   9.3947303E-05,   1.0039654E-04,   1.0926025E-04
     +,   1.2076063E-04,   1.3510928E-04,   1.5249809E-04
     +,   1.7309120E-04,   1.9701786E-04,   2.2436335E-04
     +,   2.5515925E-04,   2.8937880E-04,   3.2693427E-04
     +,   3.6767192E-04,   4.1136509E-04,   4.5771923E-04
     +,   5.0636649E-04,   5.5685837E-04,   6.0866470E-04
     +,   6.6117547E-04,   7.1370002E-04,   7.6547544E-04
     +,   8.1569667E-04,   8.6356665E-04,   9.0836006E-04
     +,   9.4950898E-04,   9.8670274E-04,   1.0199838E-03
     +,   1.0498125E-03,   1.0770820E-03,   1.1030781E-03
     +,   1.1293539E-03,   1.1575428E-03,   1.1891293E-03
     +,   1.2252225E-03,   1.2663777E-03,   1.3125020E-03
     +,   1.3628894E-03,   1.4163770E-03,   1.4715847E-03
     +,   1.5271871E-03,   1.5821506E-03,   1.6358661E-03
     +,   1.6881143E-03,   1.7388735E-03,   1.7880105E-03
     +,   1.8349153E-03,   1.8781979E-03,   1.9155375E-03
     +,   1.9437682E-03,   1.9591968E-03,   1.9581260E-03
     +,   1.9374820E-03,   1.8954071E-03,   1.8316866E-03
     +,   1.7479301E-03,   1.6474369E-03,   1.5347926E-03
     +,   1.4152812E-03,   1.2942483E-03,   1.1764793E-03
     +,   1.0657633E-03,   9.6465932E-04,   8.7445672E-04
     +,   7.9531036E-04,   7.2650705E-04,   6.6677417E-04
     +,   6.1457028E-04,   5.6832988E-04,   5.2664388E-04
     +,   4.8836536E-04,   4.5264576E-04,   4.1892286E-04
     +,   3.8688196E-04,   3.5640009E-04,   3.2747677E-04
     +,   3.0017848E-04,   2.7459220E-04,   2.5078660E-04
     +,   2.2878889E-04,   2.0857633E-04,   1.9007798E-04
     +,   1.7318100E-04,   1.5774262E-04,   1.4360550E-04
     +,   1.3061239E-04,   1.1861647E-04,   1.0748871E-04
     +,   9.7123739E-05,   8.7441847E-05,   7.8385900E-05
     +,   6.9918955E-05,   6.2020430E-05,   5.4680560E-05
     +,   4.7895308E-05,   4.1662723E-05,   3.5979985E-05
     +,   3.0840525E-05,   2.6232265E-05,   2.2137374E-05
     +,   1.8532590E-05,   1.5389396E-05,   1.2674886E-05
     +,   1.0353165E-05,   8.3867453E-06,   6.7373217E-06
     +,   5.3671133E-06,   4.2398424E-06,   3.3213430E-06
     +,   2.5800489E-06,   1.9874110E-06,   1.5180931E-06
     +,   1.1499155E-06,   8.6375326E-07,   6.4338190E-07
     +,   4.7523775E-07,   3.4811620E-07,   2.5287673E-07
     +,   1.8216454E-07,   1.3013744E-07,   9.2198299E-08
     +,   6.4777574E-08,   4.5135170E-08,   3.1189053E-08
     +,   2.1373911E-08,   1.4526363E-08,   9.7910267E-09
     +,   6.5449424E-09,   4.3389519E-09,   2.8527345E-09
     +,   1.8601219E-09,   1.2029057E-09,   7.7148399E-10
     +,   4.9070531E-10,   3.0954686E-10,   1.9365844E-10
     +,   1.2015572E-10,   7.3936010E-11,   4.5120876E-11
     +,   2.7308730E-11,   1.6391544E-11,   9.7575047E-12
     +,   5.7605600E-12,   3.3727849E-12,   1.9584035E-12
     +,   1.1277672E-12,   6.4405626E-13,   3.6477922E-13
     +,   2.0488960E-13,   1.1413262E-13,   6.3049433E-14
     +,   3.4542214E-14,   1.8767165E-14,   1.0112143E-14
     +,   5.4033600E-15,   2.8633779E-15,   1.5047967E-15
     +,   7.8424208E-16,   4.0533507E-16,   2.0775459E-16
     +,   1.0560310E-16,   5.3232030E-17,   2.6610821E-17
     +,   1.3192040E-17,   6.4856684E-18,   3.1620143E-18
     +,   1.5288313E-18,   7.3303076E-19,   3.4855481E-19
     +,   1.6435559E-19,   7.6857138E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt90 = Yx/0.0202758620689655
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1936912E-05,   1.1883204E-05
     +,   1.1824245E-05,   1.1760449E-05,   1.1692257E-05
     +,   1.1620118E-05,   1.1544509E-05,   1.1465915E-05
     +,   1.1384836E-05,   1.1301780E-05,   1.1217270E-05
     +,   1.1131830E-05,   1.1045998E-05,   1.0960304E-05
     +,   1.0875286E-05,   1.0791477E-05,   1.0709407E-05
     +,   1.0629604E-05,   1.0552579E-05,   1.0478841E-05
     +,   1.0408882E-05,   1.0343182E-05,   1.0282205E-05
     +,   1.0226393E-05,   1.0176179E-05,   1.0131963E-05
     +,   1.0094131E-05,   1.0063043E-05,   1.0039040E-05
     +,   1.0022435E-05,   1.0013518E-05,   1.0012563E-05
     +,   1.0019814E-05,   1.0035499E-05,   1.0059827E-05
     +,   1.0092995E-05,   1.0135178E-05,   1.0186552E-05
     +,   1.0247286E-05,   1.0317548E-05,   1.0397516E-05
     +,   1.0487381E-05,   1.0587351E-05,   1.0697675E-05
     +,   1.0818628E-05,   1.0950539E-05,   1.1093802E-05
     +,   1.1248873E-05,   1.1416296E-05,   1.1596705E-05
     +,   1.1790848E-05,   1.1999585E-05,   1.2223912E-05
     +,   1.2464981E-05,   1.2724077E-05,   1.3002678E-05
     +,   1.3302428E-05,   1.3625157E-05,   1.3972899E-05
     +,   1.4347878E-05,   1.4752516E-05,   1.5189451E-05
     +,   1.5661484E-05,   1.6171638E-05,   1.6723114E-05
     +,   1.7319224E-05,   1.7963484E-05,   1.8659446E-05
     +,   1.9410820E-05,   2.0221278E-05,   2.1094585E-05
     +,   2.2034350E-05,   2.3044207E-05,   2.4127510E-05
     +,   2.5287491E-05,   2.6527143E-05,   2.7849006E-05
     +,   2.9255239E-05,   3.0747608E-05,   3.2327363E-05
     +,   3.3995009E-05,   3.5750611E-05,   3.7593316E-05
     +,   3.9521765E-05,   4.1533571E-05,   4.3625820E-05
     +,   4.5794499E-05,   4.8035068E-05,   5.0341885E-05
     +,   5.2708765E-05,   5.5128799E-05,   5.7594243E-05
     +,   6.0096736E-05,   6.2627543E-05,   6.5177563E-05
     +,   6.7737070E-05,   7.0296526E-05,   7.2845956E-05
     +,   7.5375807E-05,   7.7876364E-05,   8.0338585E-05
     +,   8.2753540E-05,   8.5113214E-05,   8.7409971E-05
     +,   8.9637120E-05,   9.1788912E-05,   9.3860304E-05
     +,   9.5847266E-05,   9.7746874E-05,   9.9557212E-05
     +,   1.0127710E-04,   1.0290665E-04,   1.0444655E-04
     +,   1.0589858E-04,   1.0726512E-04,   1.0854944E-04
     +,   1.0975522E-04,   1.1088687E-04,   1.1194909E-04
     +,   1.1294716E-04,   1.1388656E-04,   1.1477294E-04
     +,   1.1561220E-04,   1.1641036E-04,   1.1717354E-04
     +,   1.1790794E-04,   1.1862008E-04,   1.1931686E-04
     +,   1.2000621E-04,   1.2069742E-04,   1.2140247E-04
     +,   1.2213692E-04,   1.2292205E-04,   1.2378673E-04
     +,   1.2477010E-04,   1.2592472E-04,   1.2731912E-04
     +,   1.2904110E-04,   1.3120014E-04,   1.3392852E-04
     +,   1.3738147E-04,   1.4173474E-04,   1.4718075E-04
     +,   1.5392146E-04,   1.6215844E-04,   1.7208315E-04
     +,   1.8386544E-04,   1.9764176E-04,   2.1350868E-04
     +,   2.3152136E-04,   2.5169703E-04,   2.7402479E-04
     +,   2.9848481E-04,   3.2507302E-04,   3.5382295E-04
     +,   3.8482097E-04,   4.1821378E-04,   4.5419662E-04
     +,   4.9297774E-04,   5.3471536E-04,   5.7945307E-04
     +,   6.2703935E-04,   6.7706103E-04,   7.2882051E-04
     +,   7.8136829E-04,   8.3360384E-04,   8.8445074E-04
     +,   9.3310873E-04,   9.7933854E-04,   1.0237233E-03
     +,   1.0678577E-03,   1.1143853E-03,   1.1668263E-03
     +,   1.2291702E-03,   1.3052437E-03,   1.3979633E-03
     +,   1.5085734E-03,   1.6360286E-03,   1.7767040E-03
     +,   1.9245191E-03,   2.0714882E-03,   2.2086150E-03
     +,   2.3270347E-03,   2.4191374E-03,   2.4794594E-03
     +,   2.5052202E-03,   2.4964151E-03,   2.4554806E-03
     +,   2.3866508E-03,   2.2951839E-03,   2.1865955E-03
     +,   2.0660707E-03,   1.9380946E-03,   1.8062986E-03
     +,   1.6734689E-03,   1.5416689E-03,   1.4124044E-03
     +,   1.2867620E-03,   1.1655235E-03,   1.0492897E-03
     +,   9.3857228E-04,   8.3386229E-04,   7.3566887E-04
     +,   6.4453622E-04,   5.6102133E-04,   4.8561208E-04
     +,   4.1865834E-04,   3.6029849E-04,   3.1040391E-04
     +,   2.6856147E-04,   2.3410360E-04,   2.0616621E-04
     +,   1.8376343E-04,   1.6586830E-04,   1.5149037E-04
     +,   1.3973471E-04,   1.2983842E-04,   1.2118845E-04
     +,   1.1332242E-04,   1.0591668E-04,   9.8764227E-05
     +,   9.1751383E-05,   8.4833926E-05,   7.8015008E-05
     +,   7.1326234E-05,   6.4813976E-05,   5.8529520E-05
     +,   5.2521566E-05,   4.6831730E-05,   4.1492800E-05
     +,   3.6528309E-05,   3.1952331E-05,   2.7770006E-05
     +,   2.3978875E-05,   2.0570409E-05,   1.7530348E-05
     +,   1.4840282E-05,   1.2478787E-05,   1.0422138E-05
     +,   8.6450555E-06,   7.1216268E-06,   5.8260393E-06
     +,   4.7329936E-06,   3.8181170E-06,   3.0584317E-06
     +,   2.4326416E-06,   1.9212519E-06,   1.5066377E-06
     +,   1.1731267E-06,   9.0697949E-07,   6.9624355E-07
     +,   5.3067788E-07,   4.0161473E-07,   3.0178657E-07
     +,   2.2516230E-07,   1.6679786E-07,   1.2268332E-07
     +,   8.9594401E-08,   6.4963260E-08,   4.6766637E-08
     +,   3.3425934E-08,   2.3719632E-08,   1.6710791E-08
     +,   1.1687919E-08,   8.1157632E-09,   5.5944809E-09
     +,   3.8283616E-09,   2.6006624E-09,   1.7537607E-09
     +,   1.1739653E-09,   7.8005258E-10,   5.1448423E-10
     +,   3.3681991E-10,   2.1887002E-10,   1.4116382E-10
     +,   9.0368144E-11,   5.7417304E-11,   3.6208807E-11
     +,   2.2662830E-11,   1.4078442E-11,   8.6801157E-12
     +,   5.3118512E-12,   3.2263775E-12,   1.9452155E-12
     +,   1.1641763E-12,   6.9172115E-13,   4.0810023E-13
     +,   2.3912350E-13,   1.3920661E-13,   8.0553992E-14
     +,   4.6369616E-14,   2.6579594E-14,   1.5195163E-14
     +,   8.6822004E-15,   4.9733226E-15,   2.8675244E-15
     +,   1.6730569E-15,   9.9401826E-16,   6.0558165E-16
     +,   3.8074086E-16,   2.4818920E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_htt95 = Yx/0.0193103448275862
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7123595E-05,   2.7722439E-05
     +,   2.8324213E-05,   2.8928956E-05,   2.9536748E-05
     +,   3.0147708E-05,   3.0762036E-05,   3.1379990E-05
     +,   3.2001881E-05,   3.2628137E-05,   3.3259206E-05
     +,   3.3895707E-05,   3.4538280E-05,   3.5187702E-05
     +,   3.5844874E-05,   3.6510788E-05,   3.7186579E-05
     +,   3.7873506E-05,   3.8572969E-05,   3.9286504E-05
     +,   4.0015828E-05,   4.0762770E-05,   4.1529325E-05
     +,   4.2317726E-05,   4.3130254E-05,   4.3969445E-05
     +,   4.4837961E-05,   4.5738641E-05,   4.6674490E-05
     +,   4.7648646E-05,   4.8664398E-05,   4.9725193E-05
     +,   5.0834555E-05,   5.1996169E-05,   5.3213760E-05
     +,   5.4491127E-05,   5.5832126E-05,   5.7240617E-05
     +,   5.8720478E-05,   6.0275430E-05,   6.1909232E-05
     +,   6.3625470E-05,   6.5427565E-05,   6.7318710E-05
     +,   6.9301881E-05,   7.1379756E-05,   7.3554678E-05
     +,   7.5828582E-05,   7.8202997E-05,   8.0678983E-05
     +,   8.3257066E-05,   8.5937252E-05,   8.8718894E-05
     +,   9.1600945E-05,   9.4581344E-05,   9.7657750E-05
     +,   1.0082690E-04,   1.0408505E-04,   1.0742755E-04
     +,   1.1084936E-04,   1.1434459E-04,   1.1790688E-04
     +,   1.2152907E-04,   1.2520379E-04,   1.2892319E-04
     +,   1.3267862E-04,   1.3646173E-04,   1.4026334E-04
     +,   1.4407471E-04,   1.4788650E-04,   1.5169002E-04
     +,   1.5547624E-04,   1.5923689E-04,   1.6296368E-04
     +,   1.6664923E-04,   1.7028679E-04,   1.7387011E-04
     +,   1.7739378E-04,   1.8085366E-04,   1.8424672E-04
     +,   1.8757052E-04,   1.9082434E-04,   1.9400824E-04
     +,   1.9712409E-04,   2.0017449E-04,   2.0316368E-04
     +,   2.0609691E-04,   2.0898091E-04,   2.1182318E-04
     +,   2.1463250E-04,   2.1741872E-04,   2.2019216E-04
     +,   2.2296383E-04,   2.2574567E-04,   2.2854972E-04
     +,   2.3138800E-04,   2.3427271E-04,   2.3721572E-04
     +,   2.4022847E-04,   2.4332172E-04,   2.4650566E-04
     +,   2.4978881E-04,   2.5317920E-04,   2.5668272E-04
     +,   2.6030440E-04,   2.6404721E-04,   2.6791234E-04
     +,   2.7189893E-04,   2.7600452E-04,   2.8022463E-04
     +,   2.8455255E-04,   2.8897994E-04,   2.9349638E-04
     +,   2.9809013E-04,   3.0274724E-04,   3.0745345E-04
     +,   3.1219207E-04,   3.1694685E-04,   3.2169983E-04
     +,   3.2643377E-04,   3.3113145E-04,   3.3577575E-04
     +,   3.4035102E-04,   3.4484282E-04,   3.4923945E-04
     +,   3.5353060E-04,   3.5771000E-04,   3.6177435E-04
     +,   3.6572479E-04,   3.6956661E-04,   3.7331111E-04
     +,   3.7697423E-04,   3.8057877E-04,   3.8415351E-04
     +,   3.8773436E-04,   3.9136468E-04,   3.9509425E-04
     +,   3.9898115E-04,   4.0309053E-04,   4.0749475E-04
     +,   4.1227334E-04,   4.1751197E-04,   4.2330308E-04
     +,   4.2974390E-04,   4.3693624E-04,   4.4498485E-04
     +,   4.5399755E-04,   4.6408249E-04,   4.7534710E-04
     +,   4.8789798E-04,   5.0183793E-04,   5.1726453E-04
     +,   5.3426839E-04,   5.5293302E-04,   5.7333242E-04
     +,   5.9552782E-04,   6.1956741E-04,   6.4548611E-04
     +,   6.7330402E-04,   7.0302282E-04,   7.3463324E-04
     +,   7.6811347E-04,   8.0343481E-04,   8.4056839E-04
     +,   8.7950128E-04,   9.2024624E-04,   9.6285489E-04
     +,   1.0074363E-03,   1.0541760E-03,   1.1033405E-03
     +,   1.1552832E-03,   1.2104411E-03,   1.2693271E-03
     +,   1.3325138E-03,   1.4005983E-03,   1.4741994E-03
     +,   1.5539327E-03,   1.6404085E-03,   1.7342517E-03
     +,   1.8361438E-03,   1.9468756E-03,   2.0674008E-03
     +,   2.1988924E-03,   2.3427724E-03,   2.5006575E-03
     +,   2.6742460E-03,   2.8651645E-03,   3.0748642E-03
     +,   3.3046014E-03,   3.5556571E-03,   3.8298776E-03
     +,   4.1303248E-03,   4.4618505E-03,   4.8315027E-03
     +,   5.2486476E-03,   5.7248101E-03,   6.2731411E-03
     +,   6.9068712E-03,   7.6356796E-03,   8.4595205E-03
     +,   9.3614906E-03,   1.0304132E-02,   1.1233611E-02
     +,   1.2093368E-02,   1.2842578E-02,   1.3470044E-02
     +,   1.3995219E-02,   1.4456986E-02,   1.4899240E-02
     +,   1.5361138E-02,   1.5872495E-02,   1.6448990E-02
     +,   1.7084211E-02,   1.7741820E-02,   1.8352509E-02
     +,   1.8820079E-02,   1.9038767E-02,   1.8922744E-02
     +,   1.8438030E-02,   1.7621100E-02,   1.6572023E-02
     +,   1.5425781E-02,   1.4316426E-02,   1.3345754E-02
     +,   1.2563161E-02,   1.1960050E-02,   1.1481566E-02
     +,   1.1053186E-02,   1.0611163E-02,   1.0122402E-02
     +,   9.5864851E-03,   9.0235015E-03,   8.4583145E-03
     +,   7.9100095E-03,   7.3889419E-03,   6.8986816E-03
     +,   6.4393650E-03,   6.0101696E-03,   5.6104232E-03
     +,   5.2398746E-03,   4.8986715E-03,   4.5871623E-03
     +,   4.3055587E-03,   4.0535275E-03,   3.8299311E-03
     +,   3.6327140E-03,   3.4590110E-03,   3.3054110E-03
     +,   3.1683291E-03,   3.0443328E-03,   2.9303140E-03
     +,   2.8235882E-03,   2.7218887E-03,   2.6232842E-03
     +,   2.5261354E-03,   2.4290672E-03,   2.3310042E-03
     +,   2.2312161E-03,   2.1293473E-03,   2.0254564E-03
     +,   1.9199877E-03,   1.8136977E-03,   1.7075536E-03
     +,   1.6026178E-03,   1.4999510E-03,   1.4005004E-03
     +,   1.3050489E-03,   1.2141917E-03,   1.1283221E-03
     +,   1.0476464E-03,   9.7221532E-04,   9.0196443E-04
     +,   8.3674054E-04,   7.7632541E-04,   7.2046259E-04
     +,   6.6887971E-04,   6.2128692E-04,   5.7739689E-04
     +,   5.3691887E-04,   4.9957301E-04,   4.6508361E-04
     +,   4.3319177E-04,   4.0364967E-04,   3.7623153E-04
     +,   3.5072755E-04,   3.2695328E-04,   3.0474388E-04
     +,   2.8395673E-04,   2.6447227E-04,   2.4618770E-04
     +,   2.2901989E-04,   2.1289752E-04,   1.9776345E-04
     +,   1.8356775E-04,   1.7026872E-04,   1.5782764E-04
     +,   1.4620998E-04,   1.3538095E-04,   1.2530747E-04
     +,   1.1595474E-04,   1.0728842E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt100 = Yx/0.172772727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9064777E-05,   2.9973835E-05
     +,   3.0891610E-05,   3.1817286E-05,   3.2750038E-05
     +,   3.3689015E-05,   3.4633318E-05,   3.5582059E-05
     +,   3.6534286E-05,   3.7489106E-05,   3.8445534E-05
     +,   3.9402610E-05,   4.0359373E-05,   4.1314837E-05
     +,   4.2268028E-05,   4.3217980E-05,   4.4163724E-05
     +,   4.5104302E-05,   4.6038789E-05,   4.6966255E-05
     +,   4.7885831E-05,   4.8796639E-05,   4.9697854E-05
     +,   5.0588758E-05,   5.1468538E-05,   5.2336578E-05
     +,   5.3192245E-05,   5.4035012E-05,   5.4864402E-05
     +,   5.5680033E-05,   5.6481626E-05,   5.7268968E-05
     +,   5.8041984E-05,   5.8800691E-05,   5.9545262E-05
     +,   6.0275954E-05,   6.0993210E-05,   6.1697552E-05
     +,   6.2389765E-05,   6.3070656E-05,   6.3741347E-05
     +,   6.4403022E-05,   6.5057095E-05,   6.5705171E-05
     +,   6.6349014E-05,   6.6990615E-05,   6.7632129E-05
     +,   6.8275913E-05,   6.8924535E-05,   6.9580718E-05
     +,   7.0247406E-05,   7.0927701E-05,   7.1624832E-05
     +,   7.2342256E-05,   7.3083487E-05,   7.3852229E-05
     +,   7.4652191E-05,   7.5487253E-05,   7.6361255E-05
     +,   7.7278128E-05,   7.8241690E-05,   7.9255828E-05
     +,   8.0324149E-05,   8.1450300E-05,   8.2637729E-05
     +,   8.3889528E-05,   8.5208703E-05,   8.6597771E-05
     +,   8.8059060E-05,   8.9594330E-05,   9.1205067E-05
     +,   9.2892049E-05,   9.4655821E-05,   9.6496049E-05
     +,   9.8412005E-05,   1.0040240E-04,   1.0246513E-04
     +,   1.0459749E-04,   1.0679620E-04,   1.0905739E-04
     +,   1.1137634E-04,   1.1374805E-04,   1.1616660E-04
     +,   1.1862589E-04,   1.2111912E-04,   1.2363936E-04
     +,   1.2617906E-04,   1.2873086E-04,   1.3128696E-04
     +,   1.3383990E-04,   1.3638235E-04,   1.3890715E-04
     +,   1.4140770E-04,   1.4387823E-04,   1.4631379E-04
     +,   1.4871021E-04,   1.5106496E-04,   1.5337663E-04
     +,   1.5564571E-04,   1.5787431E-04,   1.6006691E-04
     +,   1.6222986E-04,   1.6437231E-04,   1.6650574E-04
     +,   1.6864453E-04,   1.7080594E-04,   1.7300998E-04
     +,   1.7527975E-04,   1.7764143E-04,   1.8012412E-04
     +,   1.8275941E-04,   1.8558209E-04,   1.8862876E-04
     +,   1.9193852E-04,   1.9555181E-04,   1.9951070E-04
     +,   2.0385739E-04,   2.0863453E-04,   2.1388363E-04
     +,   2.1964515E-04,   2.2595718E-04,   2.3285454E-04
     +,   2.4036744E-04,   2.4852186E-04,   2.5733776E-04
     +,   2.6682712E-04,   2.7699550E-04,   2.8783834E-04
     +,   2.9934317E-04,   3.1148596E-04,   3.2423355E-04
     +,   3.3754023E-04,   3.5135122E-04,   3.6559856E-04
     +,   3.8020517E-04,   3.9508415E-04,   4.1013790E-04
     +,   4.2526098E-04,   4.4034244E-04,   4.5526630E-04
     +,   4.6991263E-04,   4.8416189E-04,   4.9789686E-04
     +,   5.1100604E-04,   5.2338449E-04,   5.3494074E-04
     +,   5.4559723E-04,   5.5529451E-04,   5.6399510E-04
     +,   5.7168683E-04,   5.7838549E-04,   5.8413751E-04
     +,   5.8902247E-04,   5.9315632E-04,   5.9669168E-04
     +,   5.9981924E-04,   6.0276809E-04,   6.0580490E-04
     +,   6.0923252E-04,   6.1338668E-04,   6.1863160E-04
     +,   6.2535563E-04,   6.3396170E-04,   6.4485747E-04
     +,   6.5844599E-04,   6.7511114E-04,   6.9520215E-04
     +,   7.1901805E-04,   7.4679387E-04,   7.7868672E-04
     +,   8.1476115E-04,   8.5498614E-04,   8.9923409E-04
     +,   9.4729097E-04,   9.9886511E-04,   1.0536285E-03
     +,   1.1112468E-03,   1.1714342E-03,   1.2340144E-03
     +,   1.2990069E-03,   1.3667068E-03,   1.4377548E-03
     +,   1.5132200E-03,   1.5946270E-03,   1.6839221E-03
     +,   1.7833561E-03,   1.8952715E-03,   2.0218126E-03
     +,   2.1645976E-03,   2.3244335E-03,   2.5012589E-03
     +,   2.6943111E-03,   2.9026389E-03,   3.1258441E-03
     +,   3.3648773E-03,   3.6224448E-03,   3.9027645E-03
     +,   4.2105168E-03,   4.5492570E-03,   4.9200114E-03
     +,   5.3211735E-03,   5.7507232E-03,   6.2106219E-03
     +,   6.7115780E-03,   7.2747623E-03,   7.9271002E-03
     +,   8.6887395E-03,   9.5566073E-03,   1.0492608E-02
     +,   1.1426391E-02,   1.2276807E-02,   1.2985189E-02
     +,   1.3542957E-02,   1.3995021E-02,   1.4414894E-02
     +,   1.4867849E-02,   1.5386024E-02,   1.5965635E-02
     +,   1.6577132E-02,   1.7175533E-02,   1.7713021E-02
     +,   1.8158225E-02,   1.8510865E-02,   1.8790115E-02
     +,   1.8998101E-02,   1.9095823E-02,   1.9022899E-02
     +,   1.8746747E-02,   1.8292120E-02,   1.7723575E-02
     +,   1.7102584E-02,   1.6459100E-02,   1.5794123E-02
     +,   1.5099774E-02,   1.4376143E-02,   1.3634615E-02
     +,   1.2890590E-02,   1.2154509E-02,   1.1427939E-02
     +,   1.0706107E-02,   9.9835219E-03,   9.2586298E-03
     +,   8.5362019E-03,   7.8275483E-03,   7.1491408E-03
     +,   6.5196357E-03,   5.9557073E-03,   5.4684267E-03
     +,   5.0611999E-03,   4.7296421E-03,   4.4628326E-03
     +,   4.2455676E-03,   4.0608179E-03,   3.8920918E-03
     +,   3.7254994E-03,   3.5512466E-03,   3.3643302E-03
     +,   3.1643198E-03,   2.9543794E-03,   2.7398814E-03
     +,   2.5269329E-03,   2.3211557E-03,   2.1268656E-03
     +,   1.9467493E-03,   1.7819261E-03,   1.6321855E-03
     +,   1.4964208E-03,   1.3730315E-03,   1.2602574E-03
     +,   1.1564244E-03,   1.0601010E-03,   9.7017479E-04
     +,   8.8585110E-04,   8.0660882E-04,   7.3215296E-04
     +,   6.6235149E-04,   5.9715944E-04,   5.3657976E-04
     +,   4.8060768E-04,   4.2921529E-04,   3.8232133E-04
     +,   3.3979735E-04,   3.0145681E-04,   2.6707310E-04
     +,   2.3637951E-04,   2.0909002E-04,   1.8490388E-04
     +,   1.6351948E-04,   1.4464499E-04,   1.2800090E-04
     +,   1.1332974E-04,   1.0039480E-04,   8.8985369E-05
     +,   7.8913203E-05,   7.0014627E-05,   6.2146086E-05
     +,   5.5184337E-05,   4.9022041E-05,   4.3567288E-05
     +,   3.8739789E-05,   3.4470257E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt102 = Yx/0.183590909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1252126E-05,   3.2374312E-05
     +,   3.3523203E-05,   3.4698463E-05,   3.5899680E-05
     +,   3.7126360E-05,   3.8377933E-05,   3.9653725E-05
     +,   4.0952960E-05,   4.2274842E-05,   4.3618420E-05
     +,   4.4982698E-05,   4.6366597E-05,   4.7768925E-05
     +,   4.9188471E-05,   5.0623941E-05,   5.2073970E-05
     +,   5.3537140E-05,   5.5012042E-05,   5.6497156E-05
     +,   5.7991012E-05,   5.9492082E-05,   6.0998820E-05
     +,   6.2509855E-05,   6.4023581E-05,   6.5538639E-05
     +,   6.7053676E-05,   6.8567359E-05,   7.0078466E-05
     +,   7.1585906E-05,   7.3088668E-05,   7.4585914E-05
     +,   7.6076860E-05,   7.7560937E-05,   7.9037796E-05
     +,   8.0507132E-05,   8.1968967E-05,   8.3423431E-05
     +,   8.4870975E-05,   8.6312088E-05,   8.7747670E-05
     +,   8.9178728E-05,   9.0606562E-05,   9.2032649E-05
     +,   9.3458766E-05,   9.4886840E-05,   9.6319061E-05
     +,   9.7757875E-05,   9.9205834E-05,   1.0066578E-04
     +,   1.0214069E-04,   1.0363375E-04,   1.0514823E-04
     +,   1.0668765E-04,   1.0825550E-04,   1.0985545E-04
     +,   1.1149120E-04,   1.1316656E-04,   1.1488522E-04
     +,   1.1665097E-04,   1.1846746E-04,   1.2033833E-04
     +,   1.2226692E-04,   1.2425669E-04,   1.2631073E-04
     +,   1.2843181E-04,   1.3062268E-04,   1.3288543E-04
     +,   1.3522217E-04,   1.3763427E-04,   1.4012298E-04
     +,   1.4268870E-04,   1.4533172E-04,   1.4805142E-04
     +,   1.5084687E-04,   1.5371649E-04,   1.5665792E-04
     +,   1.5966814E-04,   1.6274370E-04,   1.6588040E-04
     +,   1.6907309E-04,   1.7231637E-04,   1.7560377E-04
     +,   1.7892865E-04,   1.8228318E-04,   1.8565958E-04
     +,   1.8904899E-04,   1.9244250E-04,   1.9583061E-04
     +,   1.9920355E-04,   2.0255138E-04,   2.0586392E-04
     +,   2.0913084E-04,   2.1234211E-04,   2.1548782E-04
     +,   2.1855817E-04,   2.2154415E-04,   2.2443675E-04
     +,   2.2722813E-04,   2.2991085E-04,   2.3247863E-04
     +,   2.3492599E-04,   2.3724890E-04,   2.3944389E-04
     +,   2.4150952E-04,   2.4344554E-04,   2.4525274E-04
     +,   2.4693404E-04,   2.4849339E-04,   2.4993691E-04
     +,   2.5127170E-04,   2.5250696E-04,   2.5365318E-04
     +,   2.5472252E-04,   2.5572872E-04,   2.5668676E-04
     +,   2.5761302E-04,   2.5852519E-04,   2.5944182E-04
     +,   2.6038275E-04,   2.6136814E-04,   2.6241911E-04
     +,   2.6355681E-04,   2.6480271E-04,   2.6617810E-04
     +,   2.6770370E-04,   2.6939958E-04,   2.7128484E-04
     +,   2.7337708E-04,   2.7569235E-04,   2.7824438E-04
     +,   2.8104463E-04,   2.8410178E-04,   2.8742154E-04
     +,   2.9100594E-04,   2.9485364E-04,   2.9895935E-04
     +,   3.0331343E-04,   3.0790246E-04,   3.1270896E-04
     +,   3.1771130E-04,   3.2288360E-04,   3.2819732E-04
     +,   3.3362029E-04,   3.3911821E-04,   3.4465521E-04
     +,   3.5019484E-04,   3.5570047E-04,   3.6113724E-04
     +,   3.6647308E-04,   3.7168025E-04,   3.7673613E-04
     +,   3.8162508E-04,   3.8634104E-04,   3.9088706E-04
     +,   3.9527789E-04,   3.9954099E-04,   4.0371864E-04
     +,   4.0786841E-04,   4.1206428E-04,   4.1639825E-04
     +,   4.2098094E-04,   4.2594265E-04,   4.3143381E-04
     +,   4.3762728E-04,   4.4471724E-04,   4.5292065E-04
     +,   4.6247605E-04,   4.7364586E-04,   4.8671290E-04
     +,   5.0197775E-04,   5.1975646E-04,   5.4037501E-04
     +,   5.6416227E-04,   5.9143675E-04,   6.2249962E-04
     +,   6.5761863E-04,   6.9700874E-04,   7.4081717E-04
     +,   7.8910764E-04,   8.4184203E-04,   8.9886296E-04
     +,   9.5988717E-04,   1.0245040E-03,   1.0921846E-03
     +,   1.1622898E-03,   1.2341125E-03,   1.3069229E-03
     +,   1.3800309E-03,   1.4528452E-03,   1.5249645E-03
     +,   1.5962389E-03,   1.6668200E-03,   1.7371899E-03
     +,   1.8081568E-03,   1.8808214E-03,   1.9565136E-03
     +,   2.0367608E-03,   2.1233193E-03,   2.2182579E-03
     +,   2.3241541E-03,   2.4443429E-03,   2.5831780E-03
     +,   2.7461383E-03,   2.9397223E-03,   3.1711301E-03
     +,   3.4477427E-03,   3.7765554E-03,   4.1637798E-03
     +,   4.6147294E-03,   5.1338375E-03,   5.7246774E-03
     +,   6.3899104E-03,   7.1309768E-03,   7.9472205E-03
     +,   8.8344477E-03,   9.7832149E-03,   1.0778245E-02
     +,   1.1800592E-02,   1.2833459E-02,   1.3868291E-02
     +,   1.4904018E-02,   1.5936300E-02,   1.6943919E-02
     +,   1.7886212E-02,   1.8720606E-02,   1.9431181E-02
     +,   2.0043038E-02,   2.0601552E-02,   2.1123130E-02
     +,   2.1557156E-02,   2.1802321E-02,   2.1776954E-02
     +,   2.1487767E-02,   2.1033641E-02,   2.0537384E-02
     +,   2.0061888E-02,   1.9576719E-02,   1.8993890E-02
     +,   1.8238680E-02,   1.7301086E-02,   1.6237665E-02
     +,   1.5135028E-02,   1.4068967E-02,   1.3084496E-02
     +,   1.2198022E-02,   1.1408200E-02,   1.0704067E-02
     +,   1.0067854E-02,   9.4759194E-03,   8.9018913E-03
     +,   8.3227642E-03,   7.7251904E-03,   7.1090921E-03
     +,   6.4865816E-03,   5.8771609E-03,   5.3011295E-03
     +,   4.7739386E-03,   4.3032449E-03,   3.8889113E-03
     +,   3.5250713E-03,   3.2029483E-03,   2.9134431E-03
     +,   2.6489554E-03,   2.4042332E-03,   2.1763584E-03
     +,   1.9642739E-03,   1.7680766E-03,   1.5882986E-03
     +,   1.4253458E-03,   1.2792012E-03,   1.1493170E-03
     +,   1.0346542E-03,   9.3381264E-04,   8.4520591E-04
     +,   7.6722528E-04,   6.9833436E-04,   6.3716579E-04
     +,   5.8253674E-04,   5.3347147E-04,   4.8917130E-04
     +,   4.4900191E-04,   4.1245169E-04,   3.7911467E-04
     +,   3.4865478E-04,   3.2079467E-04,   2.9529337E-04
     +,   2.7193845E-04,   2.5054146E-04,   2.3092811E-04
     +,   2.1294145E-04,   1.9643587E-04,   1.8128038E-04
     +,   1.6735424E-04,   1.5455003E-04,   1.4276910E-04
     +,   1.3192413E-04,   1.2193497E-04,   1.1273067E-04
     +,   1.0424563E-04,   9.6421427E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt104 = Yx/0.187727272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.7464236E-05,   6.8931644E-05
     +,   7.0388931E-05,   7.1835428E-05,   7.3270581E-05
     +,   7.4693977E-05,   7.6105272E-05,   7.7504272E-05
     +,   7.8890800E-05,   8.0264923E-05,   8.1626669E-05
     +,   8.2976250E-05,   8.4313848E-05,   8.5639840E-05
     +,   8.6954569E-05,   8.8258457E-05,   8.9551999E-05
     +,   9.0835667E-05,   9.2109971E-05,   9.3375420E-05
     +,   9.4632516E-05,   9.5881755E-05,   9.7123528E-05
     +,   9.8358323E-05,   9.9586410E-05,   1.0080813E-04
     +,   1.0202367E-04,   1.0323317E-04,   1.0443668E-04
     +,   1.0563414E-04,   1.0682542E-04,   1.0801032E-04
     +,   1.0918847E-04,   1.1035948E-04,   1.1152287E-04
     +,   1.1267803E-04,   1.1382432E-04,   1.1496103E-04
     +,   1.1608744E-04,   1.1720263E-04,   1.1830600E-04
     +,   1.1939657E-04,   1.2047365E-04,   1.2153642E-04
     +,   1.2258424E-04,   1.2361653E-04,   1.2463272E-04
     +,   1.2563252E-04,   1.2661566E-04,   1.2758213E-04
     +,   1.2853208E-04,   1.2946595E-04,   1.3038429E-04
     +,   1.3128808E-04,   1.3217848E-04,   1.3305695E-04
     +,   1.3392535E-04,   1.3478573E-04,   1.3564060E-04
     +,   1.3649279E-04,   1.3734543E-04,   1.3820203E-04
     +,   1.3906647E-04,   1.3994287E-04,   1.4083592E-04
     +,   1.4175028E-04,   1.4269125E-04,   1.4366403E-04
     +,   1.4467440E-04,   1.4572819E-04,   1.4683146E-04
     +,   1.4799030E-04,   1.4921100E-04,   1.5049982E-04
     +,   1.5186303E-04,   1.5330693E-04,   1.5483750E-04
     +,   1.5646050E-04,   1.5818162E-04,   1.6000609E-04
     +,   1.6193870E-04,   1.6398396E-04,   1.6614534E-04
     +,   1.6842636E-04,   1.7082917E-04,   1.7335557E-04
     +,   1.7600629E-04,   1.7878125E-04,   1.8167924E-04
     +,   1.8469820E-04,   1.8783504E-04,   1.9108530E-04
     +,   1.9444324E-04,   1.9790242E-04,   2.0145500E-04
     +,   2.0509158E-04,   2.0880229E-04,   2.1257527E-04
     +,   2.1639840E-04,   2.2025775E-04,   2.2413919E-04
     +,   2.2802690E-04,   2.3190500E-04,   2.3575642E-04
     +,   2.3956386E-04,   2.4330970E-04,   2.4697592E-04
     +,   2.5054457E-04,   2.5399768E-04,   2.5731811E-04
     +,   2.6048857E-04,   2.6349319E-04,   2.6631643E-04
     +,   2.6894442E-04,   2.7136423E-04,   2.7356474E-04
     +,   2.7553621E-04,   2.7727112E-04,   2.7876356E-04
     +,   2.8001014E-04,   2.8100942E-04,   2.8176236E-04
     +,   2.8227232E-04,   2.8254508E-04,   2.8258868E-04
     +,   2.8241365E-04,   2.8203282E-04,   2.8146122E-04
     +,   2.8071593E-04,   2.7981590E-04,   2.7878210E-04
     +,   2.7763669E-04,   2.7640359E-04,   2.7510733E-04
     +,   2.7377365E-04,   2.7242859E-04,   2.7109869E-04
     +,   2.6980997E-04,   2.6858869E-04,   2.6746019E-04
     +,   2.6644909E-04,   2.6557859E-04,   2.6487067E-04
     +,   2.6434619E-04,   2.6402349E-04,   2.6391976E-04
     +,   2.6404983E-04,   2.6442687E-04,   2.6506212E-04
     +,   2.6596492E-04,   2.6714313E-04,   2.6860315E-04
     +,   2.7035040E-04,   2.7238924E-04,   2.7472433E-04
     +,   2.7736055E-04,   2.8030315E-04,   2.8355993E-04
     +,   2.8714072E-04,   2.9105859E-04,   2.9533164E-04
     +,   2.9998305E-04,   3.0504263E-04,   3.1054817E-04
     +,   3.1654703E-04,   3.2309684E-04,   3.3026742E-04
     +,   3.3814137E-04,   3.4681658E-04,   3.5640743E-04
     +,   3.6704435E-04,   3.7887710E-04,   3.9207502E-04
     +,   4.0682897E-04,   4.2335002E-04,   4.4187199E-04
     +,   4.6265204E-04,   4.8596607E-04,   5.1210891E-04
     +,   5.4139155E-04,   5.7413313E-04,   6.1065122E-04
     +,   6.5124908E-04,   6.9620629E-04,   7.4575772E-04
     +,   8.0007251E-04,   8.5923495E-04,   9.2323235E-04
     +,   9.9193701E-04,   1.0650911E-03,   1.1423203E-03
     +,   1.2231424E-03,   1.3069941E-03,   1.3932858E-03
     +,   1.4814854E-03,   1.5712070E-03,   1.6623319E-03
     +,   1.7551414E-03,   1.8504552E-03,   1.9497263E-03
     +,   2.0550792E-03,   2.1692822E-03,   2.2955919E-03
     +,   2.4374763E-03,   2.5982466E-03,   2.7807162E-03
     +,   2.9869243E-03,   3.2180792E-03,   3.4748251E-03
     +,   3.7577366E-03,   4.0678550E-03,   4.4069020E-03
     +,   4.7770650E-03,   5.1801996E-03,   5.6167771E-03
     +,   6.0851327E-03,   6.5816985E-03,   7.1023726E-03
     +,   7.6447129E-03,   8.2101692E-03,   8.8056279E-03
     +,   9.4430307E-03,   1.0136497E-02,   1.0897090E-02
     +,   1.1726791E-02,   1.2615159E-02,   1.3542362E-02
     +,   1.4488976E-02,   1.5447583E-02,   1.6426550E-02
     +,   1.7440325E-02,   1.8490523E-02,   1.9552447E-02
     +,   2.0579383E-02,   2.1521326E-02,   2.2339385E-02
     +,   2.3002572E-02,   2.3478694E-02,   2.3741964E-02
     +,   2.3795208E-02,   2.3679918E-02,   2.3453083E-02
     +,   2.3146881E-02,   2.2745650E-02,   2.2199206E-02
     +,   2.1459054E-02,   2.0509347E-02,   1.9374378E-02
     +,   1.8105922E-02,   1.6767148E-02,   1.5422245E-02
     +,   1.4129784E-02,   1.2933829E-02,   1.1854553E-02
     +,   1.0886360E-02,   1.0006514E-02,   9.1887964E-03
     +,   8.4140543E-03,   7.6735625E-03,   6.9666835E-03
     +,   6.2966673E-03,   5.6672655E-03,   5.0811879E-03
     +,   4.5398199E-03,   4.0433821E-03,   3.5910492E-03
     +,   3.1812675E-03,   2.8120549E-03,   2.4812338E-03
     +,   2.1865719E-03,   1.9258168E-03,   1.6966452E-03
     +,   1.4965648E-03,   1.3228743E-03,   1.1727262E-03
     +,   1.0432291E-03,   9.3152869E-04,   8.3494704E-04
     +,   7.5103919E-04,   6.7767093E-04,   6.1301683E-04
     +,   5.5557844E-04,   5.0414068E-04,   4.5775194E-04
     +,   4.1566687E-04,   3.7731646E-04,   3.4225872E-04
     +,   3.1015088E-04,   2.8072539E-04,   2.5376258E-04
     +,   2.2908313E-04,   2.0653037E-04,   1.8596878E-04
     +,   1.6727218E-04,   1.5032513E-04,   1.3501533E-04
     +,   1.2123569E-04,   1.0887950E-04,   9.7843149E-05
     +,   8.8022898E-05,   7.9317972E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt106 = Yx/0.201755555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.2216830E-05,   6.4013562E-05
     +,   6.5797278E-05,   6.7564455E-05,   6.9311631E-05
     +,   7.1035356E-05,   7.2732240E-05,   7.4399017E-05
     +,   7.6032433E-05,   7.7629520E-05,   7.9187310E-05
     +,   8.0703008E-05,   8.2174061E-05,   8.3598046E-05
     +,   8.4972795E-05,   8.6296306E-05,   8.7566870E-05
     +,   8.8782988E-05,   8.9943453E-05,   9.1047252E-05
     +,   9.2093716E-05,   9.3082417E-05,   9.4013194E-05
     +,   9.4886207E-05,   9.5701842E-05,   9.6460826E-05
     +,   9.7164098E-05,   9.7812881E-05,   9.8408673E-05
     +,   9.8953198E-05,   9.9448436E-05,   9.9896555E-05
     +,   1.0029997E-04,   1.0066131E-04,   1.0098328E-04
     +,   1.0126887E-04,   1.0152115E-04,   1.0174333E-04
     +,   1.0193868E-04,   1.0211060E-04,   1.0226257E-04
     +,   1.0239801E-04,   1.0252050E-04,   1.0263350E-04
     +,   1.0274059E-04,   1.0284518E-04,   1.0295067E-04
     +,   1.0306045E-04,   1.0317776E-04,   1.0330580E-04
     +,   1.0344759E-04,   1.0360608E-04,   1.0378408E-04
     +,   1.0398426E-04,   1.0420914E-04,   1.0446112E-04
     +,   1.0474242E-04,   1.0505515E-04,   1.0540124E-04
     +,   1.0578246E-04,   1.0620054E-04,   1.0665699E-04
     +,   1.0715324E-04,   1.0769062E-04,   1.0827037E-04
     +,   1.0889363E-04,   1.0956149E-04,   1.1027502E-04
     +,   1.1103523E-04,   1.1184313E-04,   1.1269971E-04
     +,   1.1360602E-04,   1.1456316E-04,   1.1557215E-04
     +,   1.1663425E-04,   1.1775072E-04,   1.1892289E-04
     +,   1.2015217E-04,   1.2144004E-04,   1.2278829E-04
     +,   1.2419838E-04,   1.2567230E-04,   1.2721174E-04
     +,   1.2881872E-04,   1.3049510E-04,   1.3224286E-04
     +,   1.3406380E-04,   1.3595994E-04,   1.3793285E-04
     +,   1.3998417E-04,   1.4211543E-04,   1.4432770E-04
     +,   1.4662182E-04,   1.4899843E-04,   1.5145779E-04
     +,   1.5399938E-04,   1.5662270E-04,   1.5932626E-04
     +,   1.6210838E-04,   1.6496633E-04,   1.6789719E-04
     +,   1.7089692E-04,   1.7396121E-04,   1.7708467E-04
     +,   1.8026140E-04,   1.8348491E-04,   1.8674771E-04
     +,   1.9004183E-04,   1.9335868E-04,   1.9668938E-04
     +,   2.0002383E-04,   2.0335249E-04,   2.0666461E-04
     +,   2.0994968E-04,   2.1319688E-04,   2.1639551E-04
     +,   2.1953450E-04,   2.2260372E-04,   2.2559246E-04
     +,   2.2849110E-04,   2.3129028E-04,   2.3398123E-04
     +,   2.3655605E-04,   2.3900763E-04,   2.4132976E-04
     +,   2.4351724E-04,   2.4556616E-04,   2.4747330E-04
     +,   2.4923732E-04,   2.5085712E-04,   2.5233391E-04
     +,   2.5366931E-04,   2.5486658E-04,   2.5593009E-04
     +,   2.5686529E-04,   2.5767897E-04,   2.5837877E-04
     +,   2.5897339E-04,   2.5947258E-04,   2.5988679E-04
     +,   2.6022739E-04,   2.6050638E-04,   2.6073627E-04
     +,   2.6093033E-04,   2.6110187E-04,   2.6126500E-04
     +,   2.6143371E-04,   2.6162245E-04,   2.6184565E-04
     +,   2.6211794E-04,   2.6245398E-04,   2.6286833E-04
     +,   2.6337587E-04,   2.6399101E-04,   2.6472914E-04
     +,   2.6560505E-04,   2.6663419E-04,   2.6783271E-04
     +,   2.6921733E-04,   2.7080576E-04,   2.7261727E-04
     +,   2.7467316E-04,   2.7699638E-04,   2.7961325E-04
     +,   2.8255378E-04,   2.8585151E-04,   2.8954545E-04
     +,   2.9367974E-04,   2.9830512E-04,   3.0347964E-04
     +,   3.0926868E-04,   3.1574606E-04,   3.2299451E-04
     +,   3.3110598E-04,   3.4018085E-04,   3.5032904E-04
     +,   3.6166969E-04,   3.7432951E-04,   3.8844268E-04
     +,   4.0415133E-04,   4.2160455E-04,   4.4095624E-04
     +,   4.6236630E-04,   4.8600169E-04,   5.1203562E-04
     +,   5.4064603E-04,   5.7201757E-04,   6.0634292E-04
     +,   6.4382155E-04,   6.8465347E-04,   7.2904368E-04
     +,   7.7719626E-04,   8.2930637E-04,   8.8556000E-04
     +,   9.4613625E-04,   1.0112061E-03,   1.0809387E-03
     +,   1.1555189E-03,   1.2351746E-03,   1.3202036E-03
     +,   1.4109907E-03,   1.5080381E-03,   1.6119778E-03
     +,   1.7235528E-03,   1.8435584E-03,   1.9728008E-03
     +,   2.1119902E-03,   2.2616342E-03,   2.4219423E-03
     +,   2.5927548E-03,   2.7734919E-03,   2.9631320E-03
     +,   3.1602825E-03,   3.3633369E-03,   3.5707040E-03
     +,   3.7811880E-03,   3.9945045E-03,   4.2119231E-03
     +,   4.4368752E-03,   4.6754251E-03,   4.9366262E-03
     +,   5.2324543E-03,   5.5773519E-03,   5.9872763E-03
     +,   6.4778533E-03,   7.0614493E-03,   7.7433423E-03
     +,   8.5181668E-03,   9.3684234E-03,   1.0266918E-02
     +,   1.1183308E-02,   1.2092721E-02,   1.2981202E-02
     +,   1.3844664E-02,   1.4682750E-02,   1.5495188E-02
     +,   1.6285419E-02,   1.7066590E-02,   1.7859254E-02
     +,   1.8677317E-02,   1.9517258E-02,   2.0365903E-02
     +,   2.1216292E-02,   2.2063324E-02,   2.2871168E-02
     +,   2.3547813E-02,   2.3967732E-02,   2.4035649E-02
     +,   2.3737855E-02,   2.3140205E-02,   2.2344273E-02
     +,   2.1445476E-02,   2.0515315E-02,   1.9601326E-02
     +,   1.8729270E-02,   1.7903013E-02,   1.7103625E-02
     +,   1.6293315E-02,   1.5428650E-02,   1.4479565E-02
     +,   1.3443002E-02,   1.2340312E-02,   1.1201672E-02
     +,   1.0051338E-02,   8.9041917E-03,   7.7723586E-03
     +,   6.6733863E-03,   5.6323069E-03,   4.6768296E-03
     +,   3.8299933E-03,   3.1047873E-03,   2.5025974E-03
     +,   2.0149369E-03,   1.6270314E-03,   1.3216523E-03
     +,   1.0820572E-03,   8.9362240E-04,   7.4450724E-04
     +,   6.2551134E-04,   5.2967999E-04,   4.5177547E-04
     +,   3.8786835E-04,   3.3498011E-04,   2.9085408E-04
     +,   2.5375868E-04,   2.2236524E-04,   1.9563711E-04
     +,   1.7275875E-04,   1.5308177E-04,   1.3607992E-04
     +,   1.2132633E-04,   1.0846894E-04,   9.7220181E-05
     +,   8.7342421E-05,   7.8642151E-05,   7.0959803E-05
     +,   6.4165433E-05,   5.8150908E-05,   5.2826654E-05
     +,   4.8116046E-05,   4.3953329E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt108 = Yx/0.195377777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6176465E-05,   2.6928336E-05
     +,   2.7690419E-05,   2.8462551E-05,   2.9244587E-05
     +,   3.0036377E-05,   3.0837782E-05,   3.1648651E-05
     +,   3.2468841E-05,   3.3298220E-05,   3.4136650E-05
     +,   3.4983997E-05,   3.5840116E-05,   3.6704885E-05
     +,   3.7578171E-05,   3.8459850E-05,   3.9349779E-05
     +,   4.0247844E-05,   4.1153911E-05,   4.2067844E-05
     +,   4.2989497E-05,   4.3918750E-05,   4.4855431E-05
     +,   4.5799432E-05,   4.6750531E-05,   4.7708607E-05
     +,   4.8673450E-05,   4.9644885E-05,   5.0622701E-05
     +,   5.1606665E-05,   5.2596533E-05,   5.3592066E-05
     +,   5.4592943E-05,   5.5598895E-05,   5.6609599E-05
     +,   5.7624689E-05,   5.8643811E-05,   5.9666538E-05
     +,   6.0692484E-05,   6.1721134E-05,   6.2752079E-05
     +,   6.3784762E-05,   6.4818654E-05,   6.5853223E-05
     +,   6.6887813E-05,   6.7921865E-05,   6.8954738E-05
     +,   6.9985705E-05,   7.1014118E-05,   7.2039256E-05
     +,   7.3060393E-05,   7.4076772E-05,   7.5087628E-05
     +,   7.6092241E-05,   7.7089753E-05,   7.8079422E-05
     +,   7.9060483E-05,   8.0032114E-05,   8.0993552E-05
     +,   8.1944054E-05,   8.2882856E-05,   8.3809202E-05
     +,   8.4722407E-05,   8.5621781E-05,   8.6506712E-05
     +,   8.7376538E-05,   8.8230699E-05,   8.9068708E-05
     +,   8.9890083E-05,   9.0694361E-05,   9.1481226E-05
     +,   9.2250346E-05,   9.3001538E-05,   9.3734605E-05
     +,   9.4449453E-05,   9.5146104E-05,   9.5824631E-05
     +,   9.6485172E-05,   9.7127951E-05,   9.7753371E-05
     +,   9.8361801E-05,   9.8953788E-05,   9.9529927E-05
     +,   1.0009102E-04,   1.0063774E-04,   1.0117119E-04
     +,   1.0169224E-04,   1.0220210E-04,   1.0270200E-04
     +,   1.0319326E-04,   1.0367738E-04,   1.0415589E-04
     +,   1.0463046E-04,   1.0510280E-04,   1.0557490E-04
     +,   1.0604865E-04,   1.0652620E-04,   1.0700963E-04
     +,   1.0750132E-04,   1.0800356E-04,   1.0851881E-04
     +,   1.0904962E-04,   1.0959855E-04,   1.1016825E-04
     +,   1.1076147E-04,   1.1138098E-04,   1.1202947E-04
     +,   1.1270979E-04,   1.1342474E-04,   1.1417706E-04
     +,   1.1496954E-04,   1.1580484E-04,   1.1668550E-04
     +,   1.1761412E-04,   1.1859297E-04,   1.1962439E-04
     +,   1.2071032E-04,   1.2185267E-04,   1.2305295E-04
     +,   1.2431254E-04,   1.2563250E-04,   1.2701358E-04
     +,   1.2845607E-04,   1.2995994E-04,   1.3152494E-04
     +,   1.3315008E-04,   1.3483423E-04,   1.3657557E-04
     +,   1.3837204E-04,   1.4022083E-04,   1.4211894E-04
     +,   1.4406262E-04,   1.4604800E-04,   1.4807035E-04
     +,   1.5012483E-04,   1.5220628E-04,   1.5430890E-04
     +,   1.5642661E-04,   1.5855346E-04,   1.6068296E-04
     +,   1.6280872E-04,   1.6492420E-04,   1.6702308E-04
     +,   1.6909937E-04,   1.7114714E-04,   1.7316113E-04
     +,   1.7513674E-04,   1.7706993E-04,   1.7895781E-04
     +,   1.8079857E-04,   1.8259186E-04,   1.8433871E-04
     +,   1.8604191E-04,   1.8770654E-04,   1.8933971E-04
     +,   1.9095125E-04,   1.9255352E-04,   1.9416230E-04
     +,   1.9579670E-04,   1.9747940E-04,   1.9923730E-04
     +,   2.0110165E-04,   2.0310846E-04,   2.0529873E-04
     +,   2.0771916E-04,   2.1042257E-04,   2.1346772E-04
     +,   2.1692060E-04,   2.2085443E-04,   2.2535073E-04
     +,   2.3049883E-04,   2.3639694E-04,   2.4315274E-04
     +,   2.5088346E-04,   2.5971467E-04,   2.6978157E-04
     +,   2.8122729E-04,   2.9420081E-04,   3.0885474E-04
     +,   3.2534340E-04,   3.4381813E-04,   3.6442024E-04
     +,   3.8727658E-04,   4.1249357E-04,   4.4014867E-04
     +,   4.7028094E-04,   5.0288544E-04,   5.3790817E-04
     +,   5.7524128E-04,   6.1471545E-04,   6.5610942E-04
     +,   6.9915154E-04,   7.4352603E-04,   7.8888831E-04
     +,   8.3488942E-04,   8.8119169E-04,   9.2749344E-04
     +,   9.7355794E-04,   1.0192388E-03,   1.0645026E-03
     +,   1.1094414E-03,   1.1542798E-03,   1.1993807E-03
     +,   1.2452222E-03,   1.2923700E-03,   1.3414515E-03
     +,   1.3931195E-03,   1.4480178E-03,   1.5067775E-03
     +,   1.5700377E-03,   1.6384990E-03,   1.7130137E-03
     +,   1.7947120E-03,   1.8851274E-03,   1.9862978E-03
     +,   2.1007750E-03,   2.2315339E-03,   2.3817604E-03
     +,   2.5544947E-03,   2.7521793E-03,   2.9763007E-03
     +,   3.2271324E-03,   3.5037326E-03,   3.8043277E-03
     +,   4.1269856E-03,   4.4703521E-03,   4.8341248E-03
     +,   5.2189757E-03,   5.6256801E-03,   6.0535041E-03
     +,   6.4986879E-03,   6.9543431E-03,   7.4131484E-03
     +,   7.8733349E-03,   8.3463462E-03,   8.8622635E-03
     +,   9.4674155E-03,   1.0210714E-02,   1.1120661E-02
     +,   1.2182299E-02,   1.3328358E-02,   1.4457326E-02
     +,   1.5477496E-02,   1.6355516E-02,   1.7134856E-02
     +,   1.7903335E-02,   1.8727347E-02,   1.9609522E-02
     +,   2.0521197E-02,   2.1492705E-02,   2.2656495E-02
     +,   2.4148442E-02,   2.5934873E-02,   2.7758684E-02
     +,   2.9280165E-02,   3.0259181E-02,   3.0603321E-02
     +,   3.0294912E-02,   2.9325515E-02,   2.7716577E-02
     +,   2.5588080E-02,   2.3176359E-02,   2.0749118E-02
     +,   1.8481512E-02,   1.6403114E-02,   1.4449556E-02
     +,   1.2555327E-02,   1.0710709E-02,   8.9621460E-03
     +,   7.3800492E-03,   6.0229665E-03,   4.9151266E-03
     +,   4.0427134E-03,   3.3655923E-03,   2.8351776E-03
     +,   2.4089266E-03,   2.0567749E-03,   1.7607163E-03
     +,   1.5106708E-03,   1.3004125E-03,   1.1248505E-03
     +,   9.7903318E-04,   8.5803197E-04,   7.5725082E-04
     +,   6.7263911E-04,   6.0082279E-04,   5.3908338E-04
     +,   4.8530108E-04,   4.3787446E-04,   3.9561876E-04
     +,   3.5769190E-04,   3.2349993E-04,   2.9263133E-04
     +,   2.6478464E-04,   2.3972610E-04,   2.1724803E-04
     +,   1.9715507E-04,   1.7924914E-04,   1.6333329E-04
     +,   1.4920997E-04,   1.3669011E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt110 = Yx/0.199577777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt111(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9299588E-05,   2.9777397E-05
     +,   3.0242383E-05,   3.0693966E-05,   3.1131607E-05
     +,   3.1554835E-05,   3.1963242E-05,   3.2356482E-05
     +,   3.2734282E-05,   3.3096450E-05,   3.3442862E-05
     +,   3.3773485E-05,   3.4088389E-05,   3.4387682E-05
     +,   3.4671615E-05,   3.4940527E-05,   3.5194800E-05
     +,   3.5434994E-05,   3.5661709E-05,   3.5875670E-05
     +,   3.6077687E-05,   3.6268688E-05,   3.6449688E-05
     +,   3.6621797E-05,   3.6786227E-05,   3.6944301E-05
     +,   3.7097401E-05,   3.7247009E-05,   3.7394708E-05
     +,   3.7542133E-05,   3.7691007E-05,   3.7843136E-05
     +,   3.8000358E-05,   3.8164584E-05,   3.8337763E-05
     +,   3.8521899E-05,   3.8719012E-05,   3.8931143E-05
     +,   3.9160353E-05,   3.9408689E-05,   3.9678212E-05
     +,   3.9970946E-05,   4.0288876E-05,   4.0633964E-05
     +,   4.1008108E-05,   4.1413125E-05,   4.1850755E-05
     +,   4.2322685E-05,   4.2830434E-05,   4.3375450E-05
     +,   4.3959044E-05,   4.4582372E-05,   4.5246466E-05
     +,   4.5952183E-05,   4.6700188E-05,   4.7491001E-05
     +,   4.8324957E-05,   4.9202150E-05,   5.0122526E-05
     +,   5.1085775E-05,   5.2091404E-05,   5.3138723E-05
     +,   5.4226737E-05,   5.5354336E-05,   5.6520181E-05
     +,   5.7722649E-05,   5.8959984E-05,   6.0230122E-05
     +,   6.1530969E-05,   6.2860017E-05,   6.4214837E-05
     +,   6.5592554E-05,   6.6990411E-05,   6.8405265E-05
     +,   6.9833994E-05,   7.1273418E-05,   7.2720082E-05
     +,   7.4170537E-05,   7.5621363E-05,   7.7069089E-05
     +,   7.8510129E-05,   7.9941092E-05,   8.1358412E-05
     +,   8.2758845E-05,   8.4139021E-05,   8.5495871E-05
     +,   8.6826316E-05,   8.8127621E-05,   8.9397159E-05
     +,   9.0632522E-05,   9.1831767E-05,   9.2992996E-05
     +,   9.4114788E-05,   9.5196068E-05,   9.6236217E-05
     +,   9.7234923E-05,   9.8192475E-05,   9.9109551E-05
     +,   9.9987439E-05,   1.0082791E-04,   1.0163345E-04
     +,   1.0240703E-04,   1.0315237E-04,   1.0387380E-04
     +,   1.0457646E-04,   1.0526612E-04,   1.0594926E-04
     +,   1.0663320E-04,   1.0732594E-04,   1.0803626E-04
     +,   1.0877368E-04,   1.0954843E-04,   1.1037137E-04
     +,   1.1125410E-04,   1.1220867E-04,   1.1324778E-04
     +,   1.1438439E-04,   1.1563198E-04,   1.1700399E-04
     +,   1.1851408E-04,   1.2017589E-04,   1.2200268E-04
     +,   1.2400719E-04,   1.2620178E-04,   1.2859792E-04
     +,   1.3120584E-04,   1.3403487E-04,   1.3709247E-04
     +,   1.4038492E-04,   1.4391608E-04,   1.4768817E-04
     +,   1.5170082E-04,   1.5595177E-04,   1.6043555E-04
     +,   1.6514480E-04,   1.7006930E-04,   1.7519591E-04
     +,   1.8050901E-04,   1.8599085E-04,   1.9162116E-04
     +,   1.9737745E-04,   2.0323513E-04,   2.0916856E-04
     +,   2.1515084E-04,   2.2115375E-04,   2.2714939E-04
     +,   2.3310982E-04,   2.3900747E-04,   2.4481595E-04
     +,   2.5051075E-04,   2.5606982E-04,   2.6147324E-04
     +,   2.6670416E-04,   2.7175000E-04,   2.7660182E-04
     +,   2.8125473E-04,   2.8570829E-04,   2.8996708E-04
     +,   2.9404051E-04,   2.9794200E-04,   3.0169002E-04
     +,   3.0530765E-04,   3.0882127E-04,   3.1226111E-04
     +,   3.1566073E-04,   3.1905621E-04,   3.2248526E-04
     +,   3.2598700E-04,   3.2960167E-04,   3.3336933E-04
     +,   3.3732990E-04,   3.4152286E-04,   3.4598727E-04
     +,   3.5076207E-04,   3.5588554E-04,   3.6139763E-04
     +,   3.6733985E-04,   3.7375710E-04,   3.8069906E-04
     +,   3.8822246E-04,   3.9639315E-04,   4.0528731E-04
     +,   4.1499367E-04,   4.2561657E-04,   4.3727615E-04
     +,   4.5010977E-04,   4.6427225E-04,   4.7993800E-04
     +,   4.9729989E-04,   5.1656633E-04,   5.3796440E-04
     +,   5.6173536E-04,   5.8813131E-04,   6.1741244E-04
     +,   6.4984377E-04,   6.8568799E-04,   7.2519470E-04
     +,   7.6859083E-04,   8.1607449E-04,   8.6779764E-04
     +,   9.2385220E-04,   9.8425860E-04,   1.0489644E-03
     +,   1.1178355E-03,   1.1906526E-03,   1.2671353E-03
     +,   1.3469483E-03,   1.4297265E-03,   1.5151028E-03
     +,   1.6027469E-03,   1.6923981E-03,   1.7838860E-03
     +,   1.8771735E-03,   1.9723859E-03,   2.0698241E-03
     +,   2.1699662E-03,   2.2734762E-03,   2.3812028E-03
     +,   2.4941796E-03,   2.6136620E-03,   2.7412674E-03
     +,   2.8792126E-03,   3.0306356E-03,   3.2000009E-03
     +,   3.3933572E-03,   3.6182082E-03,   3.8826792E-03
     +,   4.1938461E-03,   4.5553455E-03,   4.9648606E-03
     +,   5.4127816E-03,   5.8836415E-03,   6.3612685E-03
     +,   6.8369447E-03,   7.3175277E-03,   7.8286510E-03
     +,   8.4085055E-03,   9.0917442E-03,   9.8896036E-03
     +,   1.0776595E-02,   1.1693307E-02,   1.2566097E-02
     +,   1.3333875E-02,   1.3967943E-02,   1.4479015E-02
     +,   1.4918005E-02,   1.5375989E-02,   1.5974686E-02
     +,   1.6831487E-02,   1.8004771E-02,   1.9462347E-02
     +,   2.1114489E-02,   2.2883045E-02,   2.4718842E-02
     +,   2.6543597E-02,   2.8209973E-02,   2.9544994E-02
     +,   3.0409753E-02,   3.0712778E-02,   3.0409664E-02
     +,   2.9512221E-02,   2.8080933E-02,   2.6214756E-02
     +,   2.4056675E-02,   2.1774139E-02,   1.9499389E-02
     +,   1.7291417E-02,   1.5160915E-02,   1.3119974E-02
     +,   1.1203084E-02,   9.4536440E-03,   7.9029603E-03
     +,   6.5608732E-03,   5.4185241E-03,   4.4565378E-03
     +,   3.6525882E-03,   2.9856551E-03,   2.4374109E-03
     +,   1.9912312E-03,   1.6313834E-03,   1.3427663E-03
     +,   1.1116146E-03,   9.2610484E-04,   7.7671011E-04
     +,   6.5597607E-04,   5.5813795E-04,   4.7865097E-04
     +,   4.1387422E-04,   3.6086378E-04,   3.1722870E-04
     +,   2.8105298E-04,   2.5080692E-04,   2.2528712E-04
     +,   2.0354644E-04,   1.8484735E-04,   1.6861253E-04
     +,   1.5439397E-04,   1.4184086E-04,   1.3068078E-04
     +,   1.2069869E-04,   1.1172587E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt111 = Yx/0.199888888888889
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4427332E-05,   4.5519693E-05
     +,   4.6615503E-05,   4.7713733E-05,   4.8813334E-05
     +,   4.9913262E-05,   5.1012426E-05,   5.2109775E-05
     +,   5.3204196E-05,   5.4294618E-05,   5.5379965E-05
     +,   5.6459114E-05,   5.7531019E-05,   5.8594560E-05
     +,   5.9648726E-05,   6.0692440E-05,   6.1724655E-05
     +,   6.2744388E-05,   6.3750624E-05,   6.4742395E-05
     +,   6.5718799E-05,   6.6678891E-05,   6.7621804E-05
     +,   6.8546753E-05,   6.9452879E-05,   7.0339483E-05
     +,   7.1205846E-05,   7.2051327E-05,   7.2875300E-05
     +,   7.3677249E-05,   7.4456657E-05,   7.5213116E-05
     +,   7.5946264E-05,   7.6655822E-05,   7.7341523E-05
     +,   7.8003235E-05,   7.8640893E-05,   7.9254496E-05
     +,   7.9844140E-05,   8.0409955E-05,   8.0952239E-05
     +,   8.1471328E-05,   8.1967642E-05,   8.2441758E-05
     +,   8.2894287E-05,   8.3325976E-05,   8.3737672E-05
     +,   8.4130326E-05,   8.4505002E-05,   8.4862892E-05
     +,   8.5205262E-05,   8.5533524E-05,   8.5849235E-05
     +,   8.6154010E-05,   8.6449618E-05,   8.6737979E-05
     +,   8.7021072E-05,   8.7301043E-05,   8.7580178E-05
     +,   8.7860797E-05,   8.8145411E-05,   8.8436638E-05
     +,   8.8737150E-05,   8.9049798E-05,   8.9377470E-05
     +,   8.9723188E-05,   9.0090041E-05,   9.0481175E-05
     +,   9.0899804E-05,   9.1349219E-05,   9.1832720E-05
     +,   9.2353614E-05,   9.2915281E-05,   9.3520983E-05
     +,   9.4174058E-05,   9.4877767E-05,   9.5635231E-05
     +,   9.6449541E-05,   9.7323624E-05,   9.8260360E-05
     +,   9.9262317E-05,   1.0033198E-04,   1.0147149E-04
     +,   1.0268293E-04,   1.0396784E-04,   1.0532772E-04
     +,   1.0676353E-04,   1.0827598E-04,   1.0986535E-04
     +,   1.1153147E-04,   1.1327393E-04,   1.1509159E-04
     +,   1.1698293E-04,   1.1894597E-04,   1.2097837E-04
     +,   1.2307693E-04,   1.2523828E-04,   1.2745819E-04
     +,   1.2973229E-04,   1.3205523E-04,   1.3442167E-04
     +,   1.3682526E-04,   1.3925954E-04,   1.4171746E-04
     +,   1.4419157E-04,   1.4667405E-04,   1.4915665E-04
     +,   1.5163081E-04,   1.5408783E-04,   1.5651880E-04
     +,   1.5891444E-04,   1.6126574E-04,   1.6356318E-04
     +,   1.6579777E-04,   1.6796029E-04,   1.7004192E-04
     +,   1.7203383E-04,   1.7392779E-04,   1.7571570E-04
     +,   1.7739016E-04,   1.7894420E-04,   1.8037143E-04
     +,   1.8166620E-04,   1.8282358E-04,   1.8383961E-04
     +,   1.8471101E-04,   1.8543562E-04,   1.8601205E-04
     +,   1.8644026E-04,   1.8672121E-04,   1.8685698E-04
     +,   1.8685084E-04,   1.8670750E-04,   1.8643272E-04
     +,   1.8603366E-04,   1.8551887E-04,   1.8489819E-04
     +,   1.8418294E-04,   1.8338567E-04,   1.8252038E-04
     +,   1.8160239E-04,   1.8064852E-04,   1.7967680E-04
     +,   1.7870648E-04,   1.7775831E-04,   1.7685414E-04
     +,   1.7601677E-04,   1.7527034E-04,   1.7463983E-04
     +,   1.7415115E-04,   1.7383098E-04,   1.7370649E-04
     +,   1.7380560E-04,   1.7415632E-04,   1.7478713E-04
     +,   1.7572648E-04,   1.7700267E-04,   1.7864385E-04
     +,   1.8067782E-04,   1.8313171E-04,   1.8603228E-04
     +,   1.8940562E-04,   1.9327686E-04,   1.9767039E-04
     +,   2.0261024E-04,   2.0811956E-04,   2.1422116E-04
     +,   2.2093693E-04,   2.2828962E-04,   2.3630212E-04
     +,   2.4499744E-04,   2.5439999E-04,   2.6453633E-04
     +,   2.7543560E-04,   2.8712922E-04,   2.9965368E-04
     +,   3.1305020E-04,   3.2736565E-04,   3.4265290E-04
     +,   3.5897357E-04,   3.7639783E-04,   3.9500304E-04
     +,   4.1487513E-04,   4.3610987E-04,   4.5881039E-04
     +,   4.8308421E-04,   5.0904200E-04,   5.3679739E-04
     +,   5.6646031E-04,   5.9813255E-04,   6.3190766E-04
     +,   6.6786591E-04,   7.0606906E-04,   7.4656145E-04
     +,   7.8937435E-04,   8.3452644E-04,   8.8202918E-04
     +,   9.3189819E-04,   9.8416663E-04,   1.0389044E-03
     +,   1.0962179E-03,   1.1562741E-03,   1.2193128E-03
     +,   1.2856434E-03,   1.3556397E-03,   1.4297373E-03
     +,   1.5084088E-03,   1.5921282E-03,   1.6813420E-03
     +,   1.7764367E-03,   1.8777044E-03,   1.9853006E-03
     +,   2.0992367E-03,   2.2193792E-03,   2.3454474E-03
     +,   2.4770149E-03,   2.6135296E-03,   2.7543276E-03
     +,   2.8986484E-03,   3.0456488E-03,   3.1944984E-03
     +,   3.3445258E-03,   3.4954525E-03,   3.6477677E-03
     +,   3.8032064E-03,   3.9652162E-03,   4.1392832E-03
     +,   4.3330048E-03,   4.5556691E-03,   4.8172721E-03
     +,   5.1271222E-03,   5.4922933E-03,   5.9162481E-03
     +,   6.3975770E-03,   6.9287606E-03,   7.4947719E-03
     +,   8.0718249E-03,   8.6276988E-03,   9.1260597E-03
     +,   9.5361695E-03,   9.8465150E-03,   1.0077606E-02
     +,   1.0287274E-02,   1.0563003E-02,   1.1000847E-02
     +,   1.1675631E-02,   1.2612389E-02,   1.3772161E-02
     +,   1.5062169E-02,   1.6371313E-02,   1.7618071E-02
     +,   1.8787393E-02,   1.9935127E-02,   2.1148426E-02
     +,   2.2475142E-02,   2.3867397E-02,   2.5191773E-02
     +,   2.6307028E-02,   2.7132925E-02,   2.7641572E-02
     +,   2.7795007E-02,   2.7519312E-02,   2.6752189E-02
     +,   2.5510682E-02,   2.3907861E-02,   2.2107482E-02
     +,   2.0261711E-02,   1.8473359E-02,   1.6788416E-02
     +,   1.5205833E-02,   1.3695628E-02,   1.2223799E-02
     +,   1.0774889E-02,   9.3601076E-03,   8.0086375E-03
     +,   6.7520821E-03,   5.6133252E-03,   4.6044430E-03
     +,   3.7288119E-03,   2.9841808E-03,   2.3639880E-03
     +,   1.8582838E-03,   1.4543053E-03,   1.1376973E-03
     +,   8.9363300E-04,   7.0801825E-04,   5.6823128E-04
     +,   4.6357140E-04,   3.8534956E-04,   3.2672516E-04
     +,   2.8247052E-04,   2.4866158E-04,   2.2241235E-04
     +,   2.0162383E-04,   1.8479282E-04,   1.7084756E-04
     +,   1.5903100E-04,   1.4880548E-04,   1.3978979E-04
     +,   1.3170870E-04,   1.2436333E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt112 = Yx/0.199733333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt1128(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4686196E-05,   3.5657158E-05
     +,   3.6635680E-05,   3.7620717E-05,   3.8611171E-05
     +,   3.9605940E-05,   4.0603838E-05,   4.1603675E-05
     +,   4.2604202E-05,   4.3604192E-05,   4.4602351E-05
     +,   4.5597375E-05,   4.6587935E-05,   4.7572721E-05
     +,   4.8550377E-05,   4.9519593E-05,   5.0479019E-05
     +,   5.1427345E-05,   5.2363255E-05,   5.3285476E-05
     +,   5.4192744E-05,   5.5083827E-05,   5.5957553E-05
     +,   5.6812780E-05,   5.7648391E-05,   5.8463382E-05
     +,   5.9256741E-05,   6.0027585E-05,   6.0775052E-05
     +,   6.1498402E-05,   6.2196938E-05,   6.2870073E-05
     +,   6.3517313E-05,   6.4138243E-05,   6.4732558E-05
     +,   6.5300075E-05,   6.5840672E-05,   6.6354420E-05
     +,   6.6841407E-05,   6.7301902E-05,   6.7736299E-05
     +,   6.8145047E-05,   6.8528832E-05,   6.8888345E-05
     +,   6.9224479E-05,   6.9538233E-05,   6.9830712E-05
     +,   7.0103211E-05,   7.0357055E-05,   7.0593793E-05
     +,   7.0815011E-05,   7.1022521E-05,   7.1218099E-05
     +,   7.1403796E-05,   7.1581686E-05,   7.1753937E-05
     +,   7.1922877E-05,   7.2090887E-05,   7.2260431E-05
     +,   7.2434101E-05,   7.2614508E-05,   7.2804352E-05
     +,   7.3006362E-05,   7.3223382E-05,   7.3458177E-05
     +,   7.3713636E-05,   7.3992596E-05,   7.4297917E-05
     +,   7.4632400E-05,   7.4998832E-05,   7.5399985E-05
     +,   7.5838492E-05,   7.6316974E-05,   7.6837867E-05
     +,   7.7403594E-05,   7.8016361E-05,   7.8678248E-05
     +,   7.9391117E-05,   8.0156722E-05,   8.0976599E-05
     +,   8.1851984E-05,   8.2783961E-05,   8.3773302E-05
     +,   8.4820596E-05,   8.5926054E-05,   8.7089691E-05
     +,   8.8311106E-05,   8.9589827E-05,   9.0924761E-05
     +,   9.2314767E-05,   9.3758339E-05,   9.5253599E-05
     +,   9.6798372E-05,   9.8390228E-05,   1.0002660E-04
     +,   1.0170438E-04,   1.0342043E-04,   1.0517127E-04
     +,   1.0695338E-04,   1.0876279E-04,   1.1059568E-04
     +,   1.1244789E-04,   1.1431544E-04,   1.1619389E-04
     +,   1.1807913E-04,   1.1996710E-04,   1.2185355E-04
     +,   1.2373445E-04,   1.2560599E-04,   1.2746452E-04
     +,   1.2930647E-04,   1.3112884E-04,   1.3292853E-04
     +,   1.3470318E-04,   1.3645046E-04,   1.3816875E-04
     +,   1.3985670E-04,   1.4151350E-04,   1.4313882E-04
     +,   1.4473290E-04,   1.4629662E-04,   1.4783129E-04
     +,   1.4933894E-04,   1.5082228E-04,   1.5228466E-04
     +,   1.5373009E-04,   1.5516340E-04,   1.5659006E-04
     +,   1.5801640E-04,   1.5944951E-04,   1.6089743E-04
     +,   1.6236883E-04,   1.6387360E-04,   1.6542207E-04
     +,   1.6702604E-04,   1.6869801E-04,   1.7045139E-04
     +,   1.7230053E-04,   1.7426087E-04,   1.7634888E-04
     +,   1.7858151E-04,   1.8097668E-04,   1.8355319E-04
     +,   1.8633025E-04,   1.8932713E-04,   1.9256382E-04
     +,   1.9606005E-04,   1.9983489E-04,   2.0390686E-04
     +,   2.0829357E-04,   2.1301110E-04,   2.1807336E-04
     +,   2.2349204E-04,   2.2927609E-04,   2.3543127E-04
     +,   2.4195932E-04,   2.4885769E-04,   2.5612005E-04
     +,   2.6373516E-04,   2.7168618E-04,   2.7995266E-04
     +,   2.8850895E-04,   2.9732482E-04,   3.0636575E-04
     +,   3.1559513E-04,   3.2497366E-04,   3.3446058E-04
     +,   3.4401510E-04,   3.5359888E-04,   3.6317680E-04
     +,   3.7271826E-04,   3.8220003E-04,   3.9160784E-04
     +,   4.0093888E-04,   4.1020161E-04,   4.1942034E-04
     +,   4.2863551E-04,   4.3790357E-04,   4.4730012E-04
     +,   4.5692001E-04,   4.6687768E-04,   4.7730666E-04
     +,   4.8835832E-04,   5.0020323E-04,   5.1302719E-04
     +,   5.2702974E-04,   5.4242066E-04,   5.5941741E-04
     +,   5.7824107E-04,   5.9910945E-04,   6.2223419E-04
     +,   6.4781657E-04,   6.7603850E-04,   7.0706051E-04
     +,   7.4102078E-04,   7.7803188E-04,   8.1817777E-04
     +,   8.6152047E-04,   9.0810732E-04,   9.5797994E-04
     +,   1.0111800E-03,   1.0677723E-03,   1.1278652E-03
     +,   1.1916345E-03,   1.2593428E-03,   1.3313794E-03
     +,   1.4082853E-03,   1.4907635E-03,   1.5796840E-03
     +,   1.6760650E-03,   1.7810077E-03,   1.8955918E-03
     +,   2.0207381E-03,   2.1570825E-03,   2.3048345E-03
     +,   2.4637019E-03,   2.6329204E-03,   2.8113972E-03
     +,   2.9978992E-03,   3.1912436E-03,   3.3904349E-03
     +,   3.5945468E-03,   3.8024348E-03,   4.0123439E-03
     +,   4.2217234E-03,   4.4275490E-03,   4.6274560E-03
     +,   4.8218053E-03,   5.0162752E-03,   5.2242307E-03
     +,   5.4677734E-03,   5.7762386E-03,   6.1812303E-03
     +,   6.7081763E-03,   7.3660072E-03,   8.1387032E-03
     +,   8.9829117E-03,   9.8349927E-03,   1.0627423E-02
     +,   1.1309719E-02,   1.1865331E-02,   1.2316371E-02
     +,   1.2711736E-02,   1.3103353E-02,   1.3524373E-02
     +,   1.3986032E-02,   1.4498810E-02,   1.5102569E-02
     +,   1.5873425E-02,   1.6882759E-02,   1.8125493E-02
     +,   1.9482743E-02,   2.0780711E-02,   2.1919262E-02
     +,   2.2949660E-02,   2.4011632E-02,   2.5183978E-02
     +,   2.6394181E-02,   2.7455933E-02,   2.8172825E-02
     +,   2.8417259E-02,   2.8159585E-02,   2.7462129E-02
     +,   2.6442902E-02,   2.5217753E-02,   2.3852069E-02
     +,   2.2351395E-02,   2.0687776E-02,   1.8841432E-02
     +,   1.6835587E-02,   1.4744837E-02,   1.2672141E-02
     +,   1.0712377E-02,   8.9285336E-03,   7.3503787E-03
     +,   5.9859599E-03,   4.8319972E-03,   3.8786235E-03
     +,   3.1094227E-03,   2.5020293E-03,   2.0300681E-03
     +,   1.6665625E-03,   1.3867251E-03,   1.1697862E-03
     +,   9.9937618E-04,   8.6319097E-04,   7.5218908E-04
     +,   6.5983663E-04,   5.8147608E-04,   5.1382818E-04
     +,   4.5465704E-04,   4.0246820E-04,   3.5629270E-04
     +,   3.1548264E-04,   2.7957628E-04,   2.4818542E-04
     +,   2.2094195E-04,   1.9746083E-04,   1.7734160E-04
     +,   1.6017025E-04,   1.4553830E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt1128 = Yx/0.210466666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6603375E-05,   3.7436312E-05
     +,   3.8270551E-05,   3.9105329E-05,   3.9939892E-05
     +,   4.0773477E-05,   4.1605301E-05,   4.2434604E-05
     +,   4.3260592E-05,   4.4082521E-05,   4.4899622E-05
     +,   4.5711105E-05,   4.6516263E-05,   4.7314319E-05
     +,   4.8104554E-05,   4.8886261E-05,   4.9658749E-05
     +,   5.0421331E-05,   5.1173371E-05,   5.1914212E-05
     +,   5.2643260E-05,   5.3359938E-05,   5.4063690E-05
     +,   5.4754040E-05,   5.5430428E-05,   5.6092475E-05
     +,   5.6739707E-05,   5.7371792E-05,   5.7988349E-05
     +,   5.8589121E-05,   5.9173824E-05,   5.9742251E-05
     +,   6.0294238E-05,   6.0829647E-05,   6.1348401E-05
     +,   6.1850464E-05,   6.2335886E-05,   6.2804698E-05
     +,   6.3257074E-05,   6.3693144E-05,   6.4113177E-05
     +,   6.4517451E-05,   6.4906366E-05,   6.5280321E-05
     +,   6.5639819E-05,   6.5985427E-05,   6.6317785E-05
     +,   6.6637629E-05,   6.6945788E-05,   6.7243127E-05
     +,   6.7530695E-05,   6.7809604E-05,   6.8081041E-05
     +,   6.8346359E-05,   6.8607034E-05,   6.8864669E-05
     +,   6.9120986E-05,   6.9377915E-05,   6.9637499E-05
     +,   6.9901951E-05,   7.0173701E-05,   7.0455324E-05
     +,   7.0749593E-05,   7.1059490E-05,   7.1388247E-05
     +,   7.1739181E-05,   7.2115967E-05,   7.2522387E-05
     +,   7.2962524E-05,   7.3440548E-05,   7.3960953E-05
     +,   7.4528347E-05,   7.5147575E-05,   7.5823547E-05
     +,   7.6561446E-05,   7.7366509E-05,   7.8244047E-05
     +,   7.9199403E-05,   8.0238031E-05,   8.1365317E-05
     +,   8.2586528E-05,   8.3906925E-05,   8.5331492E-05
     +,   8.6865090E-05,   8.8512163E-05,   9.0276983E-05
     +,   9.2163238E-05,   9.4174342E-05,   9.6312928E-05
     +,   9.8581288E-05,   1.0098102E-04,   1.0351291E-04
     +,   1.0617693E-04,   1.0897245E-04,   1.1189807E-04
     +,   1.1495116E-04,   1.1812863E-04,   1.2142611E-04
     +,   1.2483877E-04,   1.2836039E-04,   1.3198449E-04
     +,   1.3570319E-04,   1.3950832E-04,   1.4339063E-04
     +,   1.4734060E-04,   1.5134811E-04,   1.5540239E-04
     +,   1.5949232E-04,   1.6360686E-04,   1.6773492E-04
     +,   1.7186493E-04,   1.7598624E-04,   1.8008774E-04
     +,   1.8415943E-04,   1.8819129E-04,   1.9217459E-04
     +,   1.9610079E-04,   1.9996286E-04,   2.0375410E-04
     +,   2.0746941E-04,   2.1110475E-04,   2.1465695E-04
     +,   2.1812409E-04,   2.2150572E-04,   2.2480250E-04
     +,   2.2801590E-04,   2.3114870E-04,   2.3420478E-04
     +,   2.3718900E-04,   2.4010667E-04,   2.4296422E-04
     +,   2.4576843E-04,   2.4852675E-04,   2.5124659E-04
     +,   2.5393619E-04,   2.5660332E-04,   2.5925596E-04
     +,   2.6190170E-04,   2.6454814E-04,   2.6720253E-04
     +,   2.6987138E-04,   2.7256086E-04,   2.7527683E-04
     +,   2.7802450E-04,   2.8080831E-04,   2.8363269E-04
     +,   2.8650145E-04,   2.8941804E-04,   2.9238564E-04
     +,   2.9540760E-04,   2.9848728E-04,   3.0162843E-04
     +,   3.0483483E-04,   3.0811148E-04,   3.1146425E-04
     +,   3.1490013E-04,   3.1842699E-04,   3.2205536E-04
     +,   3.2579756E-04,   3.2966750E-04,   3.3368272E-04
     +,   3.3786337E-04,   3.4223346E-04,   3.4682074E-04
     +,   3.5165859E-04,   3.5678604E-04,   3.6224915E-04
     +,   3.6810181E-04,   3.7440879E-04,   3.8124670E-04
     +,   3.8870570E-04,   3.9689269E-04,   4.0593406E-04
     +,   4.1597741E-04,   4.2719365E-04,   4.3977992E-04
     +,   4.5396009E-04,   4.6998402E-04,   4.8812633E-04
     +,   5.0868542E-04,   5.3197780E-04,   5.5832899E-04
     +,   5.8806688E-04,   6.2151422E-04,   6.5897516E-04
     +,   7.0072059E-04,   7.4697786E-04,   7.9792179E-04
     +,   8.5366203E-04,   9.1422768E-04,   9.7956799E-04
     +,   1.0495434E-03,   1.1239112E-03,   1.2023269E-03
     +,   1.2843420E-03,   1.3693975E-03,   1.4568138E-03
     +,   1.5457931E-03,   1.6354342E-03,   1.7247378E-03
     +,   1.8126221E-03,   1.8979746E-03,   1.9797126E-03
     +,   2.0568524E-03,   2.1285985E-03,   2.1944810E-03
     +,   2.2544481E-03,   2.3090101E-03,   2.3593337E-03
     +,   2.4073396E-03,   2.4557170E-03,   2.5079064E-03
     +,   2.5679823E-03,   2.6404674E-03,   2.7300692E-03
     +,   2.8413441E-03,   2.9783484E-03,   3.1443189E-03
     +,   3.3413845E-03,   3.5704034E-03,   3.8309698E-03
     +,   4.1216486E-03,   4.4403961E-03,   4.7852150E-03
     +,   5.1548588E-03,   5.5491859E-03,   5.9688976E-03
     +,   6.4146202E-03,   6.8856068E-03,   7.3788534E-03
     +,   7.8897635E-03,   8.4147332E-03,   8.9548230E-03
     +,   9.5180953E-03,   1.0117819E-02,   1.0765480E-02
     +,   1.1459945E-02,   1.2178142E-02,   1.2874126E-02
     +,   1.3491021E-02,   1.3983620E-02,   1.4342227E-02
     +,   1.4603185E-02,   1.4835894E-02,   1.5109589E-02
     +,   1.5460542E-02,   1.5882913E-02,   1.6349575E-02
     +,   1.6843496E-02,   1.7373495E-02,   1.7965380E-02
     +,   1.8639743E-02,   1.9393483E-02,   2.0192685E-02
     +,   2.0981282E-02,   2.1704974E-02,   2.2336442E-02
     +,   2.2876117E-02,   2.3321137E-02,   2.3633679E-02
     +,   2.3749676E-02,   2.3624292E-02,   2.3265710E-02
     +,   2.2720968E-02,   2.2028662E-02,   2.1182280E-02
     +,   2.0134304E-02,   1.8836426E-02,   1.7286364E-02
     +,   1.5549071E-02,   1.3738948E-02,   1.1976171E-02
     +,   1.0345958E-02,   8.8830218E-03,   7.5833392E-03
     +,   6.4279120E-03,   5.4014111E-03,   4.4986764E-03
     +,   3.7205147E-03,   3.0667426E-03,   2.5311951E-03
     +,   2.1012167E-03,   1.7598554E-03,   1.4892471E-03
     +,   1.2731659E-03,   1.0984773E-03,   9.5532334E-04
     +,   8.3665212E-04,   7.3746394E-04,   6.5407297E-04
     +,   5.8361178E-04,   5.2370405E-04,   4.7233884E-04
     +,   4.2780611E-04,   3.8869638E-04,   3.5388028E-04
     +,   3.2249693E-04,   2.9391079E-04,   2.6767777E-04
     +,   2.4349357E-04,   2.2115973E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt114 = Yx/0.217311111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.6390007E-05,   5.7170728E-05
     +,   5.7924244E-05,   5.8649926E-05,   5.9347265E-05
     +,   6.0015886E-05,   6.0655508E-05,   6.1266015E-05
     +,   6.1847393E-05,   6.2399798E-05,   6.2923478E-05
     +,   6.3418855E-05,   6.3886459E-05,   6.4326981E-05
     +,   6.4741238E-05,   6.5130160E-05,   6.5494845E-05
     +,   6.5836495E-05,   6.6156477E-05,   6.6456225E-05
     +,   6.6737317E-05,   6.7001456E-05,   6.7250417E-05
     +,   6.7486151E-05,   6.7710607E-05,   6.7925917E-05
     +,   6.8134250E-05,   6.8337846E-05,   6.8539033E-05
     +,   6.8740199E-05,   6.8943787E-05,   6.9152295E-05
     +,   6.9368274E-05,   6.9594280E-05,   6.9832902E-05
     +,   7.0086753E-05,   7.0358503E-05,   7.0650771E-05
     +,   7.0966220E-05,   7.1307506E-05,   7.1677248E-05
     +,   7.2078074E-05,   7.2512637E-05,   7.2983508E-05
     +,   7.3493276E-05,   7.4044518E-05,   7.4639742E-05
     +,   7.5281510E-05,   7.5972319E-05,   7.6714663E-05
     +,   7.7510951E-05,   7.8363744E-05,   7.9275436E-05
     +,   8.0248516E-05,   8.1285412E-05,   8.2388709E-05
     +,   8.3560823E-05,   8.4804349E-05,   8.6121858E-05
     +,   8.7515997E-05,   8.8989502E-05,   9.0545131E-05
     +,   9.2185735E-05,   9.3914292E-05,   9.5733936E-05
     +,   9.7647709E-05,   9.9659061E-05,   1.0177123E-04
     +,   1.0398794E-04,   1.0631263E-04,   1.0874926E-04
     +,   1.1130152E-04,   1.1397357E-04,   1.1676926E-04
     +,   1.1969268E-04,   1.2274813E-04,   1.2593951E-04
     +,   1.2927077E-04,   1.3274586E-04,   1.3636876E-04
     +,   1.4014264E-04,   1.4407095E-04,   1.4815635E-04
     +,   1.5240145E-04,   1.5680784E-04,   1.6137704E-04
     +,   1.6610928E-04,   1.7100456E-04,   1.7606144E-04
     +,   1.8127785E-04,   1.8665075E-04,   1.9217546E-04
     +,   1.9784641E-04,   2.0365669E-04,   2.0959822E-04
     +,   2.1566106E-04,   2.2183450E-04,   2.2810559E-04
     +,   2.3446104E-04,   2.4088506E-04,   2.4736160E-04
     +,   2.5387242E-04,   2.6039907E-04,   2.6692110E-04
     +,   2.7341800E-04,   2.7986837E-04,   2.8625000E-04
     +,   2.9254021E-04,   2.9871683E-04,   3.0475750E-04
     +,   3.1063994E-04,   3.1634301E-04,   3.2184567E-04
     +,   3.2712880E-04,   3.3217363E-04,   3.3696397E-04
     +,   3.4148429E-04,   3.4572210E-04,   3.4966596E-04
     +,   3.5330738E-04,   3.5663982E-04,   3.5965952E-04
     +,   3.6236478E-04,   3.6475700E-04,   3.6683943E-04
     +,   3.6861823E-04,   3.7010195E-04,   3.7130111E-04
     +,   3.7222879E-04,   3.7289973E-04,   3.7333101E-04
     +,   3.7354094E-04,   3.7354958E-04,   3.7337837E-04
     +,   3.7305005E-04,   3.7258799E-04,   3.7201692E-04
     +,   3.7136223E-04,   3.7065006E-04,   3.6990709E-04
     +,   3.6916113E-04,   3.6844029E-04,   3.6777393E-04
     +,   3.6719223E-04,   3.6672680E-04,   3.6641030E-04
     +,   3.6627761E-04,   3.6636525E-04,   3.6671254E-04
     +,   3.6736100E-04,   3.6835542E-04,   3.6974388E-04
     +,   3.7157765E-04,   3.7391204E-04,   3.7680590E-04
     +,   3.8032202E-04,   3.8452604E-04,   3.8948740E-04
     +,   3.9527845E-04,   4.0197233E-04,   4.0964474E-04
     +,   4.1837100E-04,   4.2822494E-04,   4.3927817E-04
     +,   4.5159835E-04,   4.6524825E-04,   4.8028282E-04
     +,   4.9674796E-04,   5.1468029E-04,   5.3410535E-04
     +,   5.5503484E-04,   5.7746633E-04,   6.0138461E-04
     +,   6.2676048E-04,   6.5354706E-04,   6.8168639E-04
     +,   7.1110768E-04,   7.4172567E-04,   7.7344436E-04
     +,   8.0616184E-04,   8.3977194E-04,   8.7416364E-04
     +,   9.0922794E-04,   9.4486802E-04,   9.8100118E-04
     +,   1.0175651E-03,   1.0545331E-03,   1.0919221E-03
     +,   1.1298056E-03,   1.1683201E-03,   1.2076846E-03
     +,   1.2482069E-03,   1.2902820E-03,   1.3344021E-03
     +,   1.3811492E-03,   1.4311854E-03,   1.4852309E-03
     +,   1.5440417E-03,   1.6083838E-03,   1.6789994E-03
     +,   1.7565596E-03,   1.8416308E-03,   1.9346382E-03
     +,   2.0358185E-03,   2.1451660E-03,   2.2624189E-03
     +,   2.3870263E-03,   2.5181614E-03,   2.6547781E-03
     +,   2.7957771E-03,   2.9402287E-03,   3.0876836E-03
     +,   3.2385702E-03,   3.3945795E-03,   3.5589007E-03
     +,   3.7362117E-03,   3.9323173E-03,   4.1533820E-03
     +,   4.4048238E-03,   4.6900152E-03,   5.0092139E-03
     +,   5.3588911E-03,   5.7316795E-03,   6.1172144E-03
     +,   6.5036900E-03,   6.8798852E-03,   7.2374768E-03
     +,   7.5731864E-03,   7.8901928E-03,   8.1979018E-03
     +,   8.5098390E-03,   8.8394573E-03,   9.1949562E-03
     +,   9.5749404E-03,   9.9670924E-03,   1.0351339E-02
     +,   1.0706841E-02,   1.1020481E-02,   1.1293425E-02
     +,   1.1542898E-02,   1.1798665E-02,   1.2096559E-02
     +,   1.2471151E-02,   1.2948615E-02,   1.3538979E-02
     +,   1.4228392E-02,   1.4976088E-02,   1.5722722E-02
     +,   1.6411671E-02,   1.7015129E-02,   1.7550226E-02
     +,   1.8073339E-02,   1.8655930E-02,   1.9356737E-02
     +,   2.0203499E-02,   2.1186106E-02,   2.2253640E-02
     +,   2.3314260E-02,   2.4246680E-02,   2.4927767E-02
     +,   2.5265088E-02,   2.5213173E-02,   2.4768211E-02
     +,   2.3954779E-02,   2.2819372E-02,   2.1427799E-02
     +,   1.9856447E-02,   1.8175088E-02,   1.6434608E-02
     +,   1.4669184E-02,   1.2909753E-02,   1.1194979E-02
     +,   9.5712142E-03,   8.0831833E-03,   6.7638210E-03
     +,   5.6290138E-03,   4.6778717E-03,   3.8972730E-03
     +,   3.2665771E-03,   2.7619482E-03,   2.3591416E-03
     +,   2.0356800E-03,   1.7721393E-03,   1.5529619E-03
     +,   1.3664825E-03,   1.2045500E-03,   1.0617413E-03
     +,   9.3458209E-04,   8.2085584E-04,   7.1906601E-04
     +,   6.2813028E-04,   5.4715679E-04,   4.7536331E-04
     +,   4.1200148E-04,   3.5635571E-04,   3.0771739E-04
     +,   2.6540217E-04,   2.2874375E-04,   1.9711265E-04
     +,   1.6991371E-04,   1.4660074E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt115 = Yx/0.22095652173913
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1767137E-05,   1.2226345E-05
     +,   1.2705568E-05,   1.3205501E-05,   1.3726834E-05
     +,   1.4270235E-05,   1.4836359E-05,   1.5425836E-05
     +,   1.6039261E-05,   1.6677224E-05,   1.7340250E-05
     +,   1.8028826E-05,   1.8743403E-05,   1.9484376E-05
     +,   2.0252086E-05,   2.1046804E-05,   2.1868738E-05
     +,   2.2718037E-05,   2.3594766E-05,   2.4498902E-05
     +,   2.5430367E-05,   2.6388971E-05,   2.7374424E-05
     +,   2.8386414E-05,   2.9424427E-05,   3.0487963E-05
     +,   3.1576357E-05,   3.2688873E-05,   3.3824683E-05
     +,   3.4982852E-05,   3.6162372E-05,   3.7362126E-05
     +,   3.8580944E-05,   3.9817547E-05,   4.1070594E-05
     +,   4.2338703E-05,   4.3620388E-05,   4.4914126E-05
     +,   4.6218425E-05,   4.7531605E-05,   4.8852129E-05
     +,   5.0178362E-05,   5.1508709E-05,   5.2841544E-05
     +,   5.4175314E-05,   5.5508495E-05,   5.6839635E-05
     +,   5.8167305E-05,   5.9490201E-05,   6.0807102E-05
     +,   6.2116917E-05,   6.3418607E-05,   6.4711348E-05
     +,   6.5994500E-05,   6.7267407E-05,   6.8529785E-05
     +,   6.9781388E-05,   7.1022238E-05,   7.2252449E-05
     +,   7.3472467E-05,   7.4682837E-05,   7.5884331E-05
     +,   7.7077908E-05,   7.8264748E-05,   7.9446298E-05
     +,   8.0623999E-05,   8.1799728E-05,   8.2975268E-05
     +,   8.4152794E-05,   8.5334468E-05,   8.6522668E-05
     +,   8.7719876E-05,   8.8928668E-05,   9.0151610E-05
     +,   9.1391492E-05,   9.2651033E-05,   9.3932969E-05
     +,   9.5239971E-05,   9.6574775E-05,   9.7940028E-05
     +,   9.9338184E-05,   1.0077173E-04,   1.0224283E-04
     +,   1.0375371E-04,   1.0530616E-04,   1.0690197E-04
     +,   1.0854249E-04,   1.1022904E-04,   1.1196240E-04
     +,   1.1374323E-04,   1.1557195E-04,   1.1744845E-04
     +,   1.1937233E-04,   1.2134297E-04,   1.2335935E-04
     +,   1.2542000E-04,   1.2752328E-04,   1.2966692E-04
     +,   1.3184863E-04,   1.3406559E-04,   1.3631464E-04
     +,   1.3859235E-04,   1.4089514E-04,   1.4321886E-04
     +,   1.4555933E-04,   1.4791217E-04,   1.5027270E-04
     +,   1.5263591E-04,   1.5499706E-04,   1.5735117E-04
     +,   1.5969294E-04,   1.6201749E-04,   1.6431957E-04
     +,   1.6659446E-04,   1.6883704E-04,   1.7104295E-04
     +,   1.7320745E-04,   1.7532676E-04,   1.7739677E-04
     +,   1.7941411E-04,   1.8137600E-04,   1.8327973E-04
     +,   1.8512334E-04,   1.8690540E-04,   1.8862527E-04
     +,   1.9028272E-04,   1.9187832E-04,   1.9341336E-04
     +,   1.9488987E-04,   1.9631066E-04,   1.9767928E-04
     +,   1.9900007E-04,   2.0027824E-04,   2.0151965E-04
     +,   2.0273100E-04,   2.0391986E-04,   2.0509433E-04
     +,   2.0626334E-04,   2.0743649E-04,   2.0862422E-04
     +,   2.0983732E-04,   2.1108746E-04,   2.1238696E-04
     +,   2.1374894E-04,   2.1518685E-04,   2.1671556E-04
     +,   2.1835060E-04,   2.2010865E-04,   2.2200757E-04
     +,   2.2406744E-04,   2.2631008E-04,   2.2875992E-04
     +,   2.3144425E-04,   2.3439452E-04,   2.3764663E-04
     +,   2.4124168E-04,   2.4522690E-04,   2.4965714E-04
     +,   2.5459533E-04,   2.6011359E-04,   2.6629408E-04
     +,   2.7322982E-04,   2.8102516E-04,   2.8979513E-04
     +,   2.9966701E-04,   3.1077792E-04,   3.2327374E-04
     +,   3.3730606E-04,   3.5303086E-04,   3.7060387E-04
     +,   3.9017401E-04,   4.1187857E-04,   4.3583781E-04
     +,   4.6214700E-04,   4.9086625E-04,   5.2201608E-04
     +,   5.5557024E-04,   5.9144496E-04,   6.2949630E-04
     +,   6.6951994E-04,   7.1124797E-04,   7.5434928E-04
     +,   7.9843745E-04,   8.4308529E-04,   8.8783359E-04
     +,   9.3220692E-04,   9.7573682E-04,   1.0179841E-03
     +,   1.0585614E-03,   1.0971510E-03,   1.1335304E-03
     +,   1.1675899E-03,   1.1993441E-03,   1.2289429E-03
     +,   1.2566836E-03,   1.2830171E-03,   1.3085472E-03
     +,   1.3340442E-03,   1.3604505E-03,   1.3888896E-03
     +,   1.4206759E-03,   1.4573142E-03,   1.5005041E-03
     +,   1.5521112E-03,   1.6141183E-03,   1.6885616E-03
     +,   1.7774197E-03,   1.8824753E-03,   2.0051796E-03
     +,   2.1465337E-03,   2.3070164E-03,   2.4865968E-03
     +,   2.6848915E-03,   2.9014463E-03,   3.1360653E-03
     +,   3.3890849E-03,   3.6614847E-03,   3.9546550E-03
     +,   4.2697275E-03,   4.6065608E-03,   4.9628457E-03
     +,   5.3335330E-03,   5.7112440E-03,   6.0877255E-03
     +,   6.4560464E-03,   6.8125678E-03,   7.1577993E-03
     +,   7.4956110E-03,   7.8313556E-03,   8.1699332E-03
     +,   8.5152304E-03,   8.8712936E-03,   9.2443125E-03
     +,   9.6441042E-03,   1.0084002E-02,   1.0579526E-02
     +,   1.1145812E-02,   1.1793600E-02,   1.2524450E-02
     +,   1.3326974E-02,   1.4177905E-02,   1.5047953E-02
     +,   1.5907047E-02,   1.6722566E-02,   1.7453672E-02
     +,   1.8054929E-02,   1.8497407E-02,   1.8795030E-02
     +,   1.9008843E-02,   1.9213034E-02,   1.9438555E-02
     +,   1.9638931E-02,   1.9717671E-02,   1.9614147E-02
     +,   1.9385759E-02,   1.9207709E-02,   1.9274607E-02
     +,   1.9675106E-02,   2.0338288E-02,   2.1083005E-02
     +,   2.1717940E-02,   2.2114992E-02,   2.2220343E-02
     +,   2.2021865E-02,   2.1511734E-02,   2.0672679E-02
     +,   1.9492075E-02,   1.7990217E-02,   1.6240234E-02
     +,   1.4363703E-02,   1.2499996E-02,   1.0765965E-02
     +,   9.2286980E-03,   7.9041868E-03,   6.7762560E-03
     +,   5.8186925E-03,   5.0078994E-03,   4.3252399E-03
     +,   3.7538679E-03,   3.2766145E-03,   2.8760645E-03
     +,   2.5363972E-03,   2.2447470E-03,   1.9916990E-03
     +,   1.7706550E-03,   1.5769623E-03,   1.4070080E-03
     +,   1.2577242E-03,   1.1263744E-03,   1.0104856E-03
     +,   9.0791174E-04,   8.1682514E-04,   7.3572388E-04
     +,   6.6336396E-04,   5.9871975E-04,   5.4091291E-04
     +,   4.8918463E-04,   4.4285538E-04,   4.0132212E-04
     +,   3.6404093E-04,   3.3053380E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt116 = Yx/0.218555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.9260441E-05,   5.0485283E-05
     +,   5.1718685E-05,   5.2960157E-05,   5.4209198E-05
     +,   5.5465393E-05,   5.6728368E-05,   5.7997826E-05
     +,   5.9273527E-05,   6.0555329E-05,   6.1843180E-05
     +,   6.3137057E-05,   6.4437088E-05,   6.5743516E-05
     +,   6.7056666E-05,   6.8376954E-05,   6.9704933E-05
     +,   7.1041315E-05,   7.2386865E-05,   7.3742522E-05
     +,   7.5109354E-05,   7.6488490E-05,   7.7881319E-05
     +,   7.9289246E-05,   8.0713784E-05,   8.2156723E-05
     +,   8.3619860E-05,   8.5105094E-05,   8.6614469E-05
     +,   8.8150155E-05,   8.9714384E-05,   9.1309514E-05
     +,   9.2937938E-05,   9.4602139E-05,   9.6304699E-05
     +,   9.8048149E-05,   9.9835168E-05,   1.0166834E-04
     +,   1.0355040E-04,   1.0548387E-04,   1.0747142E-04
     +,   1.0951563E-04,   1.1161895E-04,   1.1378387E-04
     +,   1.1601266E-04,   1.1830757E-04,   1.2067067E-04
     +,   1.2310394E-04,   1.2560912E-04,   1.2818789E-04
     +,   1.3084162E-04,   1.3357155E-04,   1.3637866E-04
     +,   1.3926381E-04,   1.4222742E-04,   1.4526983E-04
     +,   1.4839116E-04,   1.5159111E-04,   1.5486924E-04
     +,   1.5822488E-04,   1.6165694E-04,   1.6516427E-04
     +,   1.6874523E-04,   1.7239804E-04,   1.7612096E-04
     +,   1.7991147E-04,   1.8376728E-04,   1.8768552E-04
     +,   1.9166348E-04,   1.9569782E-04,   1.9978544E-04
     +,   2.0392257E-04,   2.0810583E-04,   2.1233101E-04
     +,   2.1659427E-04,   2.2089152E-04,   2.2521825E-04
     +,   2.2956970E-04,   2.3394142E-04,   2.3832850E-04
     +,   2.4272574E-04,   2.4712799E-04,   2.5152968E-04
     +,   2.5592529E-04,   2.6030856E-04,   2.6467387E-04
     +,   2.6901430E-04,   2.7332376E-04,   2.7759507E-04
     +,   2.8182124E-04,   2.8599508E-04,   2.9010896E-04
     +,   2.9415483E-04,   2.9812520E-04,   3.0201185E-04
     +,   3.0580643E-04,   3.0950090E-04,   3.1308690E-04
     +,   3.1655634E-04,   3.1990127E-04,   3.2311404E-04
     +,   3.2618694E-04,   3.2911333E-04,   3.3188678E-04
     +,   3.3450132E-04,   3.3695245E-04,   3.3923605E-04
     +,   3.4134887E-04,   3.4328946E-04,   3.4505691E-04
     +,   3.4665209E-04,   3.4807710E-04,   3.4933543E-04
     +,   3.5043265E-04,   3.5137503E-04,   3.5217093E-04
     +,   3.5283042E-04,   3.5336486E-04,   3.5378686E-04
     +,   3.5411102E-04,   3.5435276E-04,   3.5452878E-04
     +,   3.5465678E-04,   3.5475532E-04,   3.5484374E-04
     +,   3.5494147E-04,   3.5506868E-04,   3.5524496E-04
     +,   3.5549034E-04,   3.5582378E-04,   3.5626395E-04
     +,   3.5682879E-04,   3.5753468E-04,   3.5839708E-04
     +,   3.5942986E-04,   3.6064532E-04,   3.6205430E-04
     +,   3.6366543E-04,   3.6548564E-04,   3.6752009E-04
     +,   3.6977153E-04,   3.7224157E-04,   3.7492890E-04
     +,   3.7783146E-04,   3.8094484E-04,   3.8426337E-04
     +,   3.8777967E-04,   3.9148561E-04,   3.9537117E-04
     +,   3.9942630E-04,   4.0364033E-04,   4.0800142E-04
     +,   4.1249808E-04,   4.1711936E-04,   4.2185400E-04
     +,   4.2669167E-04,   4.3162302E-04,   4.3663985E-04
     +,   4.4173608E-04,   4.4690620E-04,   4.5214826E-04
     +,   4.5746253E-04,   4.6285152E-04,   4.6832164E-04
     +,   4.7388329E-04,   4.7955057E-04,   4.8534261E-04
     +,   4.9128383E-04,   4.9740530E-04,   5.0374458E-04
     +,   5.1034725E-04,   5.1726738E-04,   5.2456971E-04
     +,   5.3233118E-04,   5.4063945E-04,   5.4959912E-04
     +,   5.5933057E-04,   5.6997105E-04,   5.8167713E-04
     +,   5.9462700E-04,   6.0901878E-04,   6.2507065E-04
     +,   6.4301956E-04,   6.6312082E-04,   6.8564026E-04
     +,   7.1084918E-04,   7.3901727E-04,   7.7040237E-04
     +,   8.0524141E-04,   8.4373233E-04,   8.8602758E-04
     +,   9.3222264E-04,   9.8233845E-04,   1.0363183E-03
     +,   1.0940274E-03,   1.1552505E-03,   1.2196969E-03
     +,   1.2870113E-03,   1.3568057E-03,   1.4286776E-03
     +,   1.5022379E-03,   1.5771571E-03,   1.6532111E-03
     +,   1.7303214E-03,   1.8085904E-03,   1.8883590E-03
     +,   1.9702341E-03,   2.0551076E-03,   2.1441793E-03
     +,   2.2389435E-03,   2.3411647E-03,   2.4527989E-03
     +,   2.5758913E-03,   2.7124146E-03,   2.8640542E-03
     +,   3.0319428E-03,   3.2164340E-03,   3.4169385E-03
     +,   3.6319257E-03,   3.8591383E-03,   4.0961490E-03
     +,   4.3411804E-03,   4.5939777E-03,   4.8567257E-03
     +,   5.1345634E-03,   5.4355236E-03,   5.7696537E-03
     +,   6.1475202E-03,   6.5782638E-03,   7.0677972E-03
     +,   7.6176934E-03,   8.2252445E-03,   8.8845640E-03
     +,   9.5877619E-03,   1.0325254E-02,   1.1084597E-02
     +,   1.1848252E-02,   1.2592208E-02,   1.3288565E-02
     +,   1.3913038E-02,   1.4455300E-02,   1.4926998E-02
     +,   1.5361511E-02,   1.5804244E-02,   1.6299007E-02
     +,   1.6880369E-02,   1.7576942E-02,   1.8419307E-02
     +,   1.9438343E-02,   2.0645177E-02,   2.1999851E-02
     +,   2.3389649E-02,   2.4636561E-02,   2.5540588E-02
     +,   2.5944602E-02,   2.5793808E-02,   2.5160752E-02
     +,   2.4219994E-02,   2.3182491E-02,   2.2222718E-02
     +,   2.1430632E-02,   2.0802569E-02,   2.0263655E-02
     +,   1.9705340E-02,   1.9023290E-02,   1.8147338E-02
     +,   1.7056908E-02,   1.5779706E-02,   1.4375419E-02
     +,   1.2913660E-02,   1.1456298E-02,   1.0050075E-02
     +,   8.7274835E-03,   7.5107561E-03,   6.4149573E-03
     +,   5.4485225E-03,   4.6126442E-03,   3.9018497E-03
     +,   3.3052934E-03,   2.8090458E-03,   2.3979966E-03
     +,   2.0574627E-03,   1.7740537E-03,   1.5362817E-03
     +,   1.3346983E-03,   1.1619413E-03,   1.0124793E-03
     +,   8.8231108E-04,   7.6860387E-04,   6.6930440E-04
     +,   5.8286980E-04,   5.0802110E-04,   4.4362622E-04
     +,   3.8860316E-04,   3.4191035E-04,   3.0252873E-04
     +,   2.6948733E-04,   2.4186667E-04,   2.1882198E-04
     +,   1.9958433E-04,   1.8347229E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt118 = Yx/0.222444444444444
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5214610E-05,   1.5689811E-05
     +,   1.6179403E-05,   1.6683882E-05,   1.7203767E-05
     +,   1.7739596E-05,   1.8291916E-05,   1.8861283E-05
     +,   1.9448275E-05,   2.0053496E-05,   2.0677533E-05
     +,   2.1321001E-05,   2.1984519E-05,   2.2668706E-05
     +,   2.3374192E-05,   2.4101608E-05,   2.4851586E-05
     +,   2.5624744E-05,   2.6421720E-05,   2.7243119E-05
     +,   2.8089553E-05,   2.8961615E-05,   2.9859857E-05
     +,   3.0784904E-05,   3.1737218E-05,   3.2717373E-05
     +,   3.3725846E-05,   3.4763110E-05,   3.5829595E-05
     +,   3.6925729E-05,   3.8051869E-05,   3.9208382E-05
     +,   4.0395575E-05,   4.1613745E-05,   4.2863150E-05
     +,   4.4144013E-05,   4.5456531E-05,   4.6800884E-05
     +,   4.8177273E-05,   4.9585778E-05,   5.1026585E-05
     +,   5.2499799E-05,   5.4005573E-05,   5.5544053E-05
     +,   5.7115394E-05,   5.8719768E-05,   6.0357434E-05
     +,   6.2028652E-05,   6.3733758E-05,   6.5473156E-05
     +,   6.7247347E-05,   6.9056907E-05,   7.0902446E-05
     +,   7.2784911E-05,   7.4705065E-05,   7.6664037E-05
     +,   7.8663033E-05,   8.0703423E-05,   8.2786704E-05
     +,   8.4914507E-05,   8.7088716E-05,   8.9311354E-05
     +,   9.1584472E-05,   9.3910436E-05,   9.6291835E-05
     +,   9.8731056E-05,   1.0123099E-04,   1.0379427E-04
     +,   1.0642393E-04,   1.0912269E-04,   1.1189366E-04
     +,   1.1473955E-04,   1.1766334E-04,   1.2066757E-04
     +,   1.2375480E-04,   1.2692754E-04,   1.3018769E-04
     +,   1.3353677E-04,   1.3697636E-04,   1.4050736E-04
     +,   1.4412991E-04,   1.4784410E-04,   1.5164883E-04
     +,   1.5554283E-04,   1.5952364E-04,   1.6358843E-04
     +,   1.6773319E-04,   1.7195346E-04,   1.7624334E-04
     +,   1.8059646E-04,   1.8500556E-04,   1.8946221E-04
     +,   1.9395695E-04,   1.9847971E-04,   2.0301971E-04
     +,   2.0756478E-04,   2.1210256E-04,   2.1661950E-04
     +,   2.2110192E-04,   2.2553503E-04,   2.2990414E-04
     +,   2.3419381E-04,   2.3838894E-04,   2.4247350E-04
     +,   2.4643220E-04,   2.5024998E-04,   2.5391154E-04
     +,   2.5740228E-04,   2.6070868E-04,   2.6381732E-04
     +,   2.6671620E-04,   2.6939431E-04,   2.7184142E-04
     +,   2.7404923E-04,   2.7601060E-04,   2.7772033E-04
     +,   2.7917436E-04,   2.8037120E-04,   2.8131079E-04
     +,   2.8199548E-04,   2.8242962E-04,   2.8261967E-04
     +,   2.8257462E-04,   2.8230587E-04,   2.8182700E-04
     +,   2.8115421E-04,   2.8030609E-04,   2.7930396E-04
     +,   2.7817144E-04,   2.7693476E-04,   2.7562238E-04
     +,   2.7426553E-04,   2.7289728E-04,   2.7155355E-04
     +,   2.7027179E-04,   2.6909160E-04,   2.6805449E-04
     +,   2.6720320E-04,   2.6658189E-04,   2.6623564E-04
     +,   2.6621009E-04,   2.6655145E-04,   2.6730521E-04
     +,   2.6851712E-04,   2.7023125E-04,   2.7249067E-04
     +,   2.7533650E-04,   2.7880716E-04,   2.8293859E-04
     +,   2.8776328E-04,   2.9331038E-04,   2.9960458E-04
     +,   3.0666564E-04,   3.1450932E-04,   3.2314647E-04
     +,   3.3258155E-04,   3.4281393E-04,   3.5383762E-04
     +,   3.6564097E-04,   3.7820530E-04,   3.9150740E-04
     +,   4.0551773E-04,   4.2020102E-04,   4.3551539E-04
     +,   4.5141482E-04,   4.6784850E-04,   4.8475960E-04
     +,   5.0208694E-04,   5.1976694E-04,   5.3773320E-04
     +,   5.5591611E-04,   5.7424611E-04,   5.9265440E-04
     +,   6.1107532E-04,   6.2944472E-04,   6.4770691E-04
     +,   6.6581403E-04,   6.8372674E-04,   7.0141995E-04
     +,   7.1888301E-04,   7.3612324E-04,   7.5316499E-04
     +,   7.7005278E-04,   7.8685384E-04,   8.0365653E-04
     +,   8.2056929E-04,   8.3772134E-04,   8.5526227E-04
     +,   8.7335997E-04,   8.9219870E-04,   9.1198029E-04
     +,   9.3292462E-04,   9.5527206E-04,   9.7928511E-04
     +,   1.0052589E-03,   1.0335292E-03,   1.0644800E-03
     +,   1.0985587E-03,   1.1362941E-03,   1.1783106E-03
     +,   1.2253396E-03,   1.2782419E-03,   1.3380144E-03
     +,   1.4057970E-03,   1.4828474E-03,   1.5705321E-03
     +,   1.6702600E-03,   1.7833927E-03,   1.9111470E-03
     +,   2.0544729E-03,   2.2139240E-03,   2.3895332E-03
     +,   2.5807687E-03,   2.7865577E-03,   3.0053856E-03
     +,   3.2354663E-03,   3.4749939E-03,   3.7223734E-03
     +,   3.9763493E-03,   4.2359047E-03,   4.5001116E-03
     +,   4.7676740E-03,   5.0366321E-03,   5.3042900E-03
     +,   5.5677132E-03,   5.8246865E-03,   6.0750498E-03
     +,   6.3218139E-03,   6.5714563E-03,   6.8329540E-03
     +,   7.1157645E-03,   7.4276486E-03,   7.7733328E-03
     +,   8.1546996E-03,   8.5721621E-03,   9.0262312E-03
     +,   9.5172469E-03,   1.0042937E-02,   1.0594215E-02
     +,   1.1151579E-02,   1.1685275E-02,   1.2161613E-02
     +,   1.2555676E-02,   1.2865536E-02,   1.3120334E-02
     +,   1.3376337E-02,   1.3701938E-02,   1.4159546E-02
     +,   1.4791144E-02,   1.5606500E-02,   1.6570503E-02
     +,   1.7594250E-02,   1.8548204E-02,   1.9310011E-02
     +,   1.9829163E-02,   2.0166000E-02,   2.0469377E-02
     +,   2.0897703E-02,   2.1525700E-02,   2.2288058E-02
     +,   2.2991851E-02,   2.3396216E-02,   2.3322621E-02
     +,   2.2735821E-02,   2.1748580E-02,   2.0550482E-02
     +,   1.9313173E-02,   1.8131211E-02,   1.7021019E-02
     +,   1.5956076E-02,   1.4903530E-02,   1.3842695E-02
     +,   1.2766378E-02,   1.1675554E-02,   1.0575782E-02
     +,   9.4772903E-03,   8.3961729E-03,   7.3543815E-03
     +,   6.3761561E-03,   5.4830667E-03,   4.6892590E-03
     +,   3.9996970E-03,   3.4108213E-03,   2.9132925E-03
     +,   2.4947973E-03,   2.1425737E-03,   1.8448564E-03
     +,   1.5916714E-03,   1.3750436E-03,   1.1887894E-03
     +,   1.0282467E-03,   8.8985125E-04,   7.7082613E-04
     +,   6.6886120E-04,   5.8194640E-04,   5.0822779E-04
     +,   4.4597866E-04,   3.9357063E-04,   3.4950196E-04
     +,   3.1240375E-04,   2.8106672E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt120 = Yx/0.214977777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0560091E-05,   5.2223080E-05
     +,   5.3929682E-05,   5.5682554E-05,   5.7484755E-05
     +,   5.9339836E-05,   6.1251907E-05,   6.3225678E-05
     +,   6.5266475E-05,   6.7380483E-05,   6.9574518E-05
     +,   7.1856412E-05,   7.4234958E-05,   7.6720004E-05
     +,   7.9322599E-05,   8.2055165E-05,   8.4931453E-05
     +,   8.7966895E-05,   9.1178605E-05,   9.4585630E-05
     +,   9.8209093E-05,   1.0207239E-04,   1.0620135E-04
     +,   1.1062472E-04,   1.1537380E-04,   1.2048346E-04
     +,   1.2599181E-04,   1.3194060E-04,   1.3837557E-04
     +,   1.4534657E-04,   1.5290789E-04,   1.6111827E-04
     +,   1.7004109E-04,   1.7974450E-04,   1.9030107E-04
     +,   2.0178789E-04,   2.1428577E-04,   2.2787893E-04
     +,   2.4265473E-04,   2.5870028E-04,   2.7610431E-04
     +,   2.9495318E-04,   3.1532941E-04,   3.3731028E-04
     +,   3.6096553E-04,   3.8635501E-04,   4.1352780E-04
     +,   4.4252066E-04,   4.7335887E-04,   5.0605630E-04
     +,   5.4061867E-04,   5.7704770E-04,   6.1534648E-04
     +,   6.5553084E-04,   6.9763104E-04,   7.4171170E-04
     +,   7.8787631E-04,   8.3628233E-04,   8.8715105E-04
     +,   9.4078016E-04,   9.9755183E-04,   1.0579429E-03
     +,   1.1225295E-03,   1.1920017E-03,   1.2671656E-03
     +,   1.3489443E-03,   1.4383987E-03,   1.5367109E-03
     +,   1.6452076E-03,   1.7653261E-03,   1.8986198E-03
     +,   2.0466878E-03,   2.2111386E-03,   2.3934653E-03
     +,   2.5949543E-03,   2.8165514E-03,   3.0587127E-03
     +,   3.3213531E-03,   3.6038556E-03,   3.9051611E-03
     +,   4.2239302E-03,   4.5589078E-03,   4.9091605E-03
     +,   5.2744462E-03,   5.6553436E-03,   6.0533821E-03
     +,   6.4707748E-03,   6.9101760E-03,   7.3740361E-03
     +,   7.8641251E-03,   8.3810631E-03,   8.9243157E-03
     +,   9.4927093E-03,   1.0085313E-02,   1.0702116E-02
     +,   1.1343433E-02,   1.2007853E-02,   1.2688199E-02
     +,   1.3367190E-02,   1.4014661E-02,   1.4588629E-02
     +,   1.5041141E-02,   1.5328161E-02,   1.5420276E-02
     +,   1.5310788E-02,   1.5017748E-02,   1.4579643E-02
     +,   1.4045834E-02,   1.3465167E-02,   1.2876557E-02
     +,   1.2304009E-02,   1.1756617E-02,   1.1232909E-02
     +,   1.0726754E-02,   1.0233057E-02,   9.7509408E-03
     +,   9.2843873E-03,   8.8401726E-03,   8.4250392E-03
     +,   8.0429874E-03,   7.6937950E-03,   7.3733237E-03
     +,   7.0748082E-03,   6.7908689E-03,   6.5153562E-03
     +,   6.2445574E-03,   5.9775491E-03,   5.7159499E-03
     +,   5.4631378E-03,   5.2233692E-03,   5.0008106E-03
     +,   4.7988761E-03,   4.6196538E-03,   4.4637048E-03
     +,   4.3300367E-03,   4.2163283E-03,   4.1193059E-03
     +,   4.0351977E-03,   3.9602020E-03,   3.8909141E-03
     +,   3.8246468E-03,   3.7596133E-03,   3.6949629E-03
     +,   3.6306952E-03,   3.5674956E-03,   3.5064742E-03
     +,   3.4488984E-03,   3.3959518E-03,   3.3485007E-03
     +,   3.3069372E-03,   3.2710929E-03,   3.2402363E-03
     +,   3.2131148E-03,   3.1880829E-03,   3.1632390E-03
     +,   3.1366218E-03,   3.1063606E-03,   3.0708571E-03
     +,   3.0288841E-03,   2.9796816E-03,   2.9229806E-03
     +,   2.8589943E-03,   2.7883649E-03,   2.7120691E-03
     +,   2.6313304E-03,   2.5474944E-03,   2.4619440E-03
     +,   2.3760002E-03,   2.2908463E-03,   2.2074983E-03
     +,   2.1267827E-03,   2.0493257E-03,   1.9755764E-03
     +,   1.9058315E-03,   1.8402738E-03,   1.7789993E-03
     +,   1.7220451E-03,   1.6694242E-03,   1.6211272E-03
     +,   1.5771391E-03,   1.5374373E-03,   1.5019886E-03
     +,   1.4707370E-03,   1.4435954E-03,   1.4204358E-03
     +,   1.4010826E-03,   1.3853053E-03,   1.3728176E-03
     +,   1.3632800E-03,   1.3563051E-03,   1.3514685E-03
     +,   1.3483199E-03,   1.3463967E-03,   1.3452409E-03
     +,   1.3444081E-03,   1.3434889E-03,   1.3421151E-03
     +,   1.3399716E-03,   1.3368073E-03,   1.3324321E-03
     +,   1.3267252E-03,   1.3196352E-03,   1.3111703E-03
     +,   1.3013959E-03,   1.2904302E-03,   1.2784293E-03
     +,   1.2655850E-03,   1.2521081E-03,   1.2382244E-03
     +,   1.2241629E-03,   1.2101453E-03,   1.1963837E-03
     +,   1.1830709E-03,   1.1703757E-03,   1.1584394E-03
     +,   1.1473750E-03,   1.1372616E-03,   1.1281498E-03
     +,   1.1200570E-03,   1.1129711E-03,   1.1068523E-03
     +,   1.1016354E-03,   1.0972315E-03,   1.0935315E-03
     +,   1.0904098E-03,   1.0877259E-03,   1.0853282E-03
     +,   1.0830585E-03,   1.0807522E-03,   1.0782429E-03
     +,   1.0753652E-03,   1.0719572E-03,   1.0678625E-03
     +,   1.0629329E-03,   1.0570309E-03,   1.0500327E-03
     +,   1.0418268E-03,   1.0323194E-03,   1.0214339E-03
     +,   1.0091126E-03,   9.9531468E-04,   9.8002353E-04
     +,   9.6324133E-04,   9.4498915E-04,   9.2530850E-04
     +,   9.0426102E-04,   8.8192592E-04,   8.5839821E-04
     +,   8.3378761E-04,   8.0821844E-04,   7.8182406E-04
     +,   7.5474544E-04,   7.2713220E-04,   6.9913699E-04
     +,   6.7091075E-04,   6.4260419E-04,   6.1436510E-04
     +,   5.8633630E-04,   5.5864977E-04,   5.3142878E-04
     +,   5.0478714E-04,   4.7882655E-04,   4.5363422E-04
     +,   4.2928394E-04,   4.0583868E-04,   3.8334532E-04
     +,   3.6183829E-04,   3.4134035E-04,   3.2186290E-04
     +,   3.0340510E-04,   2.8595651E-04,   2.6949949E-04
     +,   2.5400866E-04,   2.3945161E-04,   2.2579082E-04
     +,   2.1298643E-04,   2.0099398E-04,   1.8976873E-04
     +,   1.7926366E-04,   1.6943295E-04,   1.6023016E-04
     +,   1.5161109E-04,   1.4353206E-04,   1.3595250E-04
     +,   1.2883311E-04,   1.2213807E-04,   1.1583333E-04
     +,   1.0988766E-04,   1.0427289E-04,   9.8962781E-05
     +,   9.3934235E-05,   8.9165776E-05,   8.4638814E-05
     +,   8.0336198E-05,   7.6243115E-05,   7.2345938E-05
     +,   6.8633024E-05,   6.5093693E-05,   6.1718747E-05
     +,   5.8499554E-05,   5.5428965E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt75 = Yx/0.184863636363636
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8397974E-05,   7.1119299E-05
     +,   7.3937437E-05,   7.6855664E-05,   7.9877420E-05
     +,   8.3006344E-05,   8.6246226E-05,   8.9601046E-05
     +,   9.3074887E-05,   9.6672244E-05,   1.0039755E-04
     +,   1.0425547E-04,   1.0825084E-04,   1.1238860E-04
     +,   1.1667381E-04,   1.2111155E-04,   1.2570695E-04
     +,   1.3046515E-04,   1.3539127E-04,   1.4049020E-04
     +,   1.4576678E-04,   1.5122563E-04,   1.5687101E-04
     +,   1.6270726E-04,   1.6873771E-04,   1.7496587E-04
     +,   1.8139473E-04,   1.8802671E-04,   1.9486391E-04
     +,   2.0190804E-04,   2.0916044E-04,   2.1662228E-04
     +,   2.2429450E-04,   2.3217796E-04,   2.4027374E-04
     +,   2.4858303E-04,   2.5710784E-04,   2.6585028E-04
     +,   2.7481426E-04,   2.8400379E-04,   2.9342523E-04
     +,   3.0308633E-04,   3.1299627E-04,   3.2316693E-04
     +,   3.3361177E-04,   3.4434715E-04,   3.5539138E-04
     +,   3.6676548E-04,   3.7849255E-04,   3.9059817E-04
     +,   4.0311011E-04,   4.1605753E-04,   4.2947163E-04
     +,   4.4338586E-04,   4.5783276E-04,   4.7284775E-04
     +,   4.8846565E-04,   5.0472171E-04,   5.2165124E-04
     +,   5.3928926E-04,   5.5767020E-04,   5.7682791E-04
     +,   5.9679395E-04,   6.1760040E-04,   6.3927745E-04
     +,   6.6185195E-04,   6.8535068E-04,   7.0979551E-04
     +,   7.3520874E-04,   7.6160592E-04,   7.8900397E-04
     +,   8.1741274E-04,   8.4684259E-04,   8.7729958E-04
     +,   9.0878870E-04,   9.4131572E-04,   9.7488373E-04
     +,   1.0094953E-03,   1.0451586E-03,   1.0818853E-03
     +,   1.1196899E-03,   1.1586043E-03,   1.1986715E-03
     +,   1.2399722E-03,   1.2826249E-03,   1.3268216E-03
     +,   1.3728446E-03,   1.4211122E-03,   1.4722062E-03
     +,   1.5269268E-03,   1.5863394E-03,   1.6518037E-03
     +,   1.7250190E-03,   1.8080327E-03,   1.9032329E-03
     +,   2.0132754E-03,   2.1409991E-03,   2.2892235E-03
     +,   2.4605517E-03,   2.6570242E-03,   2.8798473E-03
     +,   3.1290241E-03,   3.4031225E-03,   3.6991057E-03
     +,   4.0123942E-03,   4.3371310E-03,   4.6666693E-03
     +,   4.9943696E-03,   5.3145834E-03,   5.6237243E-03
     +,   5.9211892E-03,   6.2101539E-03,   6.4975922E-03
     +,   6.7936978E-03,   7.1101454E-03,   7.4577187E-03
     +,   7.8432905E-03,   8.2670311E-03,   8.7205600E-03
     +,   9.1869105E-03,   9.6424678E-03,   1.0060791E-02
     +,   1.0417448E-02,   1.0694683E-02,   1.0884290E-02
     +,   1.0988231E-02,   1.1016656E-02,   1.0983887E-02
     +,   1.0904023E-02,   1.0787194E-02,   1.0637640E-02
     +,   1.0454112E-02,   1.0232114E-02,   9.9670626E-03
     +,   9.6574929E-03,   9.3070371E-03,   8.9250486E-03
     +,   8.5256100E-03,   8.1254160E-03,   7.7412087E-03
     +,   7.3873140E-03,   7.0736189E-03,   6.8044350E-03
     +,   6.5783774E-03,   6.3891807E-03,   6.2271291E-03
     +,   6.0810396E-03,   5.9402590E-03,   5.7963096E-03
     +,   5.6438874E-03,   5.4811756E-03,   5.3094192E-03
     +,   5.1320256E-03,   4.9534044E-03,   4.7779470E-03
     +,   4.6092244E-03,   4.4495221E-03,   4.2997641E-03
     +,   4.1596945E-03,   4.0282812E-03,   3.9040635E-03
     +,   3.7855650E-03,   3.6715621E-03,   3.5612222E-03
     +,   3.4541527E-03,   3.3503419E-03,   3.2500655E-03
     +,   3.1537367E-03,   3.0617774E-03,   2.9745083E-03
     +,   2.8920993E-03,   2.8145097E-03,   2.7415070E-03
     +,   2.6726983E-03,   2.6076047E-03,   2.5456899E-03
     +,   2.4864459E-03,   2.4294418E-03,   2.3743487E-03
     +,   2.3209667E-03,   2.2692229E-03,   2.2191687E-03
     +,   2.1709537E-03,   2.1248008E-03,   2.0809809E-03
     +,   2.0397832E-03,   2.0014984E-03,   1.9663884E-03
     +,   1.9346680E-03,   1.9065076E-03,   1.8820044E-03
     +,   1.8611907E-03,   1.8440227E-03,   1.8303860E-03
     +,   1.8200936E-03,   1.8128912E-03,   1.8084636E-03
     +,   1.8064461E-03,   1.8064320E-03,   1.8079844E-03
     +,   1.8106533E-03,   1.8139839E-03,   1.8175367E-03
     +,   1.8208979E-03,   1.8236923E-03,   1.8255934E-03
     +,   1.8263324E-03,   1.8257031E-03,   1.8235650E-03
     +,   1.8198407E-03,   1.8145135E-03,   1.8076147E-03
     +,   1.7992238E-03,   1.7894465E-03,   1.7784036E-03
     +,   1.7662308E-03,   1.7530512E-03,   1.7389725E-03
     +,   1.7240803E-03,   1.7084335E-03,   1.6920593E-03
     +,   1.6749549E-03,   1.6570959E-03,   1.6384369E-03
     +,   1.6189192E-03,   1.5984786E-03,   1.5770578E-03
     +,   1.5546074E-03,   1.5310940E-03,   1.5065040E-03
     +,   1.4808485E-03,   1.4541629E-03,   1.4265011E-03
     +,   1.3979379E-03,   1.3685649E-03,   1.3384823E-03
     +,   1.3077960E-03,   1.2766119E-03,   1.2450354E-03
     +,   1.2131601E-03,   1.1810707E-03,   1.1488398E-03
     +,   1.1165303E-03,   1.0841888E-03,   1.0518531E-03
     +,   1.0195541E-03,   9.8731485E-04,   9.5515570E-04
     +,   9.2309271E-04,   8.9114992E-04,   8.5934915E-04
     +,   8.2771765E-04,   7.9629157E-04,   7.6511153E-04
     +,   7.3422346E-04,   7.0367835E-04,   6.7353249E-04
     +,   6.4384629E-04,   6.1467866E-04,   5.8608869E-04
     +,   5.5813626E-04,   5.3087645E-04,   5.0435937E-04
     +,   4.7862920E-04,   4.5372674E-04,   4.2968293E-04
     +,   4.0652262E-04,   3.8426465E-04,   3.6292119E-04
     +,   3.4249647E-04,   3.2298893E-04,   3.0439280E-04
     +,   2.8669738E-04,   2.6988683E-04,   2.5394163E-04
     +,   2.3884070E-04,   2.2455896E-04,   2.1107076E-04
     +,   1.9834760E-04,   1.8636115E-04,   1.7508102E-04
     +,   1.6447771E-04,   1.5452006E-04,   1.4517826E-04
     +,   1.3642127E-04,   1.2821966E-04,   1.2054361E-04
     +,   1.1336384E-04,   1.0665247E-04,   1.0038158E-04
     +,   9.4524774E-05,   8.9055960E-05,   8.3950719E-05
     +,   7.9184916E-05,   7.4736236E-05,   7.0582784E-05
     +,   6.6704408E-05,   6.3081519E-05,   5.9696144E-05
     +,   5.6530997E-05,   5.3570238E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt80 = Yx/0.159697674418605
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5389919E-05,   6.7424255E-05
     +,   6.9487280E-05,   7.1578761E-05,   7.3698524E-05
     +,   7.5846525E-05,   7.8022756E-05,   8.0227335E-05
     +,   8.2460479E-05,   8.4722597E-05,   8.7014072E-05
     +,   8.9335525E-05,   9.1687652E-05,   9.4071278E-05
     +,   9.6487391E-05,   9.8937075E-05,   1.0142159E-04
     +,   1.0394229E-04,   1.0650061E-04,   1.0909817E-04
     +,   1.1173670E-04,   1.1441791E-04,   1.1714366E-04
     +,   1.1991603E-04,   1.2273680E-04,   1.2560813E-04
     +,   1.2853196E-04,   1.3151031E-04,   1.3454509E-04
     +,   1.3763818E-04,   1.4079138E-04,   1.4400638E-04
     +,   1.4728463E-04,   1.5062751E-04,   1.5403614E-04
     +,   1.5751146E-04,   1.6105406E-04,   1.6466432E-04
     +,   1.6834254E-04,   1.7208827E-04,   1.7590124E-04
     +,   1.7978060E-04,   1.8372531E-04,   1.8773405E-04
     +,   1.9180521E-04,   1.9593714E-04,   2.0012775E-04
     +,   2.0437510E-04,   2.0867704E-04,   2.1303160E-04
     +,   2.1743683E-04,   2.2189089E-04,   2.2639251E-04
     +,   2.3094093E-04,   2.3553544E-04,   2.4017676E-04
     +,   2.4486607E-04,   2.4960568E-04,   2.5439900E-04
     +,   2.5925104E-04,   2.6416813E-04,   2.6915863E-04
     +,   2.7423221E-04,   2.7940155E-04,   2.8468095E-04
     +,   2.9008742E-04,   2.9564081E-04,   3.0136359E-04
     +,   3.0728182E-04,   3.1342398E-04,   3.1982307E-04
     +,   3.2651436E-04,   3.3353784E-04,   3.4093598E-04
     +,   3.4875568E-04,   3.5704681E-04,   3.6586187E-04
     +,   3.7525606E-04,   3.8528646E-04,   3.9601204E-04
     +,   4.0749102E-04,   4.1978198E-04,   4.3294075E-04
     +,   4.4702220E-04,   4.6207654E-04,   4.7815146E-04
     +,   4.9528916E-04,   5.1353039E-04,   5.3291232E-04
     +,   5.5347366E-04,   5.7525706E-04,   5.9831189E-04
     +,   6.2270177E-04,   6.4851134E-04,   6.7585357E-04
     +,   7.0487411E-04,   7.3576474E-04,   7.6876243E-04
     +,   8.0416061E-04,   8.4230147E-04,   8.8358315E-04
     +,   9.2844042E-04,   9.7734423E-04,   1.0307698E-03
     +,   1.0891864E-03,   1.1530260E-03,   1.2226538E-03
     +,   1.2983432E-03,   1.3802596E-03,   1.4684378E-03
     +,   1.5627573E-03,   1.6629610E-03,   1.7686334E-03
     +,   1.8792318E-03,   1.9940780E-03,   2.1124189E-03
     +,   2.2334387E-03,   2.3563525E-03,   2.4804638E-03
     +,   2.6052974E-03,   2.7307242E-03,   2.8570984E-03
     +,   2.9853850E-03,   3.1173024E-03,   3.2553405E-03
     +,   3.4027542E-03,   3.5634553E-03,   3.7417759E-03
     +,   3.9422018E-03,   4.1689412E-03,   4.4255690E-03
     +,   4.7145016E-03,   5.0366987E-03,   5.3912476E-03
     +,   5.7752342E-03,   6.1837323E-03,   6.6099479E-03
     +,   7.0455736E-03,   7.4813324E-03,   7.9075033E-03
     +,   8.3145136E-03,   8.6938292E-03,   9.0390611E-03
     +,   9.3471929E-03,   9.6196905E-03,   9.8628318E-03
     +,   1.0086498E-02,   1.0301289E-02,   1.0514586E-02
     +,   1.0726742E-02,   1.0929214E-02,   1.1105332E-02
     +,   1.1234064E-02,   1.1295100E-02,   1.1273480E-02
     +,   1.1162298E-02,   1.0962775E-02,   1.0682561E-02
     +,   1.0333088E-02,   9.9275317E-03,   9.4793951E-03
     +,   9.0019833E-03,   8.5081179E-03,   8.0097346E-03
     +,   7.5173723E-03,   7.0397276E-03,   6.5834713E-03
     +,   6.1534015E-03,   5.7528261E-03,   5.3842021E-03
     +,   5.0496524E-03,   4.7512082E-03,   4.4908649E-03
     +,   4.2703324E-03,   4.0906393E-03,   3.9515803E-03
     +,   3.8512845E-03,   3.7859238E-03,   3.7497254E-03
     +,   3.7352559E-03,   3.7340347E-03,   3.7373202E-03
     +,   3.7369346E-03,   3.7260246E-03,   3.6996012E-03
     +,   3.6548164E-03,   3.5909328E-03,   3.5090742E-03
     +,   3.4117834E-03,   3.3025197E-03,   3.1851355E-03
     +,   3.0634443E-03,   2.9409218E-03,   2.8204904E-03
     +,   2.7044343E-03,   2.5944398E-03,   2.4916644E-03
     +,   2.3968390E-03,   2.3103678E-03,   2.2324298E-03
     +,   2.1630574E-03,   2.1021659E-03,   2.0495688E-03
     +,   2.0049962E-03,   1.9680879E-03,   1.9383809E-03
     +,   1.9153138E-03,   1.8982337E-03,   1.8864163E-03
     +,   1.8790854E-03,   1.8754508E-03,   1.8747482E-03
     +,   1.8762758E-03,   1.8794321E-03,   1.8837415E-03
     +,   1.8888898E-03,   1.8947151E-03,   1.9012184E-03
     +,   1.9085403E-03,   1.9169308E-03,   1.9267071E-03
     +,   1.9382092E-03,   1.9517341E-03,   1.9674932E-03
     +,   1.9855550E-03,   2.0058120E-03,   2.0279500E-03
     +,   2.0514335E-03,   2.0755287E-03,   2.0993161E-03
     +,   2.1217421E-03,   2.1416703E-03,   2.1579498E-03
     +,   2.1694819E-03,   2.1752804E-03,   2.1745353E-03
     +,   2.1666610E-03,   2.1513158E-03,   2.1284202E-03
     +,   2.0981545E-03,   2.0609319E-03,   2.0173646E-03
     +,   1.9682248E-03,   1.9143824E-03,   1.8567623E-03
     +,   1.7962946E-03,   1.7338693E-03,   1.6702949E-03
     +,   1.6062829E-03,   1.5424328E-03,   1.4792188E-03
     +,   1.4169965E-03,   1.3560198E-03,   1.2964514E-03
     +,   1.2383761E-03,   1.1818261E-03,   1.1267992E-03
     +,   1.0732749E-03,   1.0212208E-03,   9.7061123E-04
     +,   9.2143065E-04,   8.7367889E-04,   8.2736608E-04
     +,   7.8251702E-04,   7.3917012E-04,   6.9736585E-04
     +,   6.5714709E-04,   6.1855896E-04,   5.8163935E-04
     +,   5.4641603E-04,   5.1290687E-04,   4.8111950E-04
     +,   4.5104904E-04,   4.2267627E-04,   3.9597019E-04
     +,   3.7089185E-04,   3.4738932E-04,   3.2540626E-04
     +,   3.0487662E-04,   2.8573276E-04,   2.6790114E-04
     +,   2.5130817E-04,   2.3587787E-04,   2.2153600E-04
     +,   2.0820773E-04,   1.9582150E-04,   1.8430706E-04
     +,   1.7359687E-04,   1.6362757E-04,   1.5433801E-04
     +,   1.4567176E-04,   1.3757503E-04,   1.2999904E-04
     +,   1.2289787E-04,   1.1623019E-04,   1.0995784E-04
     +,   1.0404703E-04,   9.8466764E-05,   9.3190050E-05
     +,   8.8192413E-05,   8.3452986E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt85 = Yx/0.155139534883721
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.8968119E-05,   6.1315361E-05
     +,   6.3704370E-05,   6.6132838E-05,   6.8598230E-05
     +,   7.1097958E-05,   7.3629293E-05,   7.6189368E-05
     +,   7.8775214E-05,   8.1383936E-05,   8.4012332E-05
     +,   8.6657325E-05,   8.9315712E-05,   9.1984279E-05
     +,   9.4659874E-05,   9.7339282E-05,   1.0001938E-04
     +,   1.0269700E-04,   1.0536923E-04,   1.0803311E-04
     +,   1.1068576E-04,   1.1332467E-04,   1.1594717E-04
     +,   1.1855117E-04,   1.2113433E-04,   1.2369502E-04
     +,   1.2623148E-04,   1.2874251E-04,   1.3122703E-04
     +,   1.3368446E-04,   1.3611438E-04,   1.3851693E-04
     +,   1.4089260E-04,   1.4324226E-04,   1.4556719E-04
     +,   1.4786921E-04,   1.5015060E-04,   1.5241405E-04
     +,   1.5466289E-04,   1.5690061E-04,   1.5913158E-04
     +,   1.6136038E-04,   1.6359221E-04,   1.6583253E-04
     +,   1.6808744E-04,   1.7036326E-04,   1.7266678E-04
     +,   1.7500500E-04,   1.7738524E-04,   1.7981502E-04
     +,   1.8230194E-04,   1.8485374E-04,   1.8747797E-04
     +,   1.9018246E-04,   1.9297433E-04,   1.9586092E-04
     +,   1.9884894E-04,   2.0194479E-04,   2.0515415E-04
     +,   2.0848238E-04,   2.1193389E-04,   2.1551244E-04
     +,   2.1922091E-04,   2.2306138E-04,   2.2703523E-04
     +,   2.3114242E-04,   2.3538271E-04,   2.3975412E-04
     +,   2.4425474E-04,   2.4888120E-04,   2.5363010E-04
     +,   2.5849688E-04,   2.6347718E-04,   2.6856607E-04
     +,   2.7375884E-04,   2.7905125E-04,   2.8443930E-04
     +,   2.8991961E-04,   2.9549035E-04,   3.0115110E-04
     +,   3.0690251E-04,   3.1274807E-04,   3.1869279E-04
     +,   3.2474493E-04,   3.3091471E-04,   3.3721616E-04
     +,   3.4366574E-04,   3.5028381E-04,   3.5709323E-04
     +,   3.6412044E-04,   3.7139532E-04,   3.7894992E-04
     +,   3.8681866E-04,   3.9503886E-04,   4.0364941E-04
     +,   4.1268935E-04,   4.2219961E-04,   4.3221924E-04
     +,   4.4278792E-04,   4.5394216E-04,   4.6571784E-04
     +,   4.7814619E-04,   4.9125665E-04,   5.0507387E-04
     +,   5.1961996E-04,   5.3491502E-04,   5.5097602E-04
     +,   5.6781992E-04,   5.8546884E-04,   6.0394901E-04
     +,   6.2329660E-04,   6.4356514E-04,   6.6482736E-04
     +,   6.8718567E-04,   7.1077497E-04,   7.3577429E-04
     +,   7.6240697E-04,   7.9095241E-04,   8.2174141E-04
     +,   8.5516274E-04,   8.9166005E-04,   9.3171746E-04
     +,   9.7585504E-04,   1.0246143E-03,   1.0785355E-03
     +,   1.1381313E-03,   1.2038746E-03,   1.2761611E-03
     +,   1.3553014E-03,   1.4414894E-03,   1.5348054E-03
     +,   1.6351886E-03,   1.7424610E-03,   1.8562975E-03
     +,   1.9762623E-03,   2.1017937E-03,   2.2322212E-03
     +,   2.3667740E-03,   2.5046109E-03,   2.6448448E-03
     +,   2.7865530E-03,   2.9288323E-03,   3.0708543E-03
     +,   3.2119162E-03,   3.3515671E-03,   3.4898026E-03
     +,   3.6274036E-03,   3.7663728E-03,   3.9105099E-03
     +,   4.0659453E-03,   4.2414311E-03,   4.4480888E-03
     +,   4.6983645E-03,   5.0041685E-03,   5.3743231E-03
     +,   5.8119083E-03,   6.3124201E-03,   6.8633738E-03
     +,   7.4456763E-03,   8.0365017E-03,   8.6129513E-03
     +,   9.1550322E-03,   9.6470620E-03,   1.0077459E-02
     +,   1.0437030E-02,   1.0717184E-02,   1.0909144E-02
     +,   1.1004873E-02,   1.0999566E-02,   1.0894430E-02
     +,   1.0698633E-02,   1.0429285E-02,   1.0109508E-02
     +,   9.7650858E-03,   9.4210058E-03,   9.0982495E-03
     +,   8.8117616E-03,   8.5693840E-03,   8.3719827E-03
     +,   8.2147513E-03,   8.0895554E-03,   7.9877935E-03
     +,   7.9030506E-03,   7.8325942E-03,   7.7773626E-03
     +,   7.7404217E-03,   7.7244062E-03,   7.7289748E-03
     +,   7.7490793E-03,   7.7746464E-03,   7.7917594E-03
     +,   7.7851289E-03,   7.7411197E-03,   7.6505714E-03
     +,   7.5106742E-03,   7.3253950E-03,   7.1043745E-03
     +,   6.8606525E-03,   6.6077914E-03,   6.3572931E-03
     +,   6.1168303E-03,   5.8896164E-03,   5.6748716E-03
     +,   5.4691108E-03,   5.2677654E-03,   5.0666309E-03
     +,   4.8629283E-03,   4.6558101E-03,   4.4462779E-03
     +,   4.2367121E-03,   4.0302961E-03,   3.8303856E-03
     +,   3.6400219E-03,   3.4616268E-03,   3.2969227E-03
     +,   3.1469453E-03,   3.0121303E-03,   2.8923934E-03
     +,   2.7872215E-03,   2.6957206E-03,   2.6166425E-03
     +,   2.5484352E-03,   2.4893279E-03,   2.4374230E-03
     +,   2.3908205E-03,   2.3477566E-03,   2.3067174E-03
     +,   2.2665286E-03,   2.2263853E-03,   2.1858583E-03
     +,   2.1448454E-03,   2.1034938E-03,   2.0621025E-03
     +,   2.0210338E-03,   1.9806297E-03,   1.9411366E-03
     +,   1.9026690E-03,   1.8651970E-03,   1.8285468E-03
     +,   1.7924255E-03,   1.7564589E-03,   1.7202372E-03
     +,   1.6833520E-03,   1.6454359E-03,   1.6061921E-03
     +,   1.5654169E-03,   1.5230057E-03,   1.4789520E-03
     +,   1.4333426E-03,   1.3863456E-03,   1.3381903E-03
     +,   1.2891464E-03,   1.2395133E-03,   1.1895987E-03
     +,   1.1396988E-03,   1.0900928E-03,   1.0410359E-03
     +,   9.9274819E-04,   9.4541343E-04,   8.9917833E-04
     +,   8.5415790E-04,   8.1043545E-04,   7.6806365E-04
     +,   7.2707259E-04,   6.8747666E-04,   6.4927293E-04
     +,   6.1244919E-04,   5.7698903E-04,   5.4287241E-04
     +,   5.1007699E-04,   4.7858118E-04,   4.4836727E-04
     +,   4.1941996E-04,   3.9172411E-04,   3.6526722E-04
     +,   3.4004092E-04,   3.1603355E-04,   2.9323695E-04
     +,   2.7163900E-04,   2.5122837E-04,   2.3198857E-04
     +,   2.1390289E-04,   1.9694850E-04,   1.8110167E-04
     +,   1.6633222E-04,   1.5260905E-04,   1.3989577E-04
     +,   1.2815319E-04,   1.1734054E-04,   1.0741326E-04
     +,   9.8326462E-05,   9.0032794E-05,   8.2485160E-05
     +,   7.5635253E-05,   6.9435810E-05,   6.3839449E-05
     +,   5.8800477E-05,   5.4273878E-05,   5.0216862E-05
     +,   4.6588015E-05,   4.3348380E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt90 = Yx/0.157418604651163
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1714371E-05,   4.3173186E-05
     +,   4.4710312E-05,   4.6330548E-05,   4.8038746E-05
     +,   4.9839717E-05,   5.1738272E-05,   5.3739088E-05
     +,   5.5846696E-05,   5.8065525E-05,   6.0399638E-05
     +,   6.2852836E-05,   6.5428525E-05,   6.8129688E-05
     +,   7.0958784E-05,   7.3917741E-05,   7.7007819E-05
     +,   8.0229627E-05,   8.3582978E-05,   8.7066932E-05
     +,   9.0679663E-05,   9.4418472E-05,   9.8279699E-05
     +,   1.0225891E-04,   1.0635034E-04,   1.1054764E-04
     +,   1.1484329E-04,   1.1922883E-04,   1.2369487E-04
     +,   1.2823129E-04,   1.3282691E-04,   1.3747001E-04
     +,   1.4214808E-04,   1.4684814E-04,   1.5155670E-04
     +,   1.5625994E-04,   1.6094383E-04,   1.6559428E-04
     +,   1.7019764E-04,   1.7473970E-04,   1.7920762E-04
     +,   1.8358859E-04,   1.8787076E-04,   1.9204311E-04
     +,   1.9609589E-04,   2.0002050E-04,   2.0380982E-04
     +,   2.0745829E-04,   2.1096205E-04,   2.1431902E-04
     +,   2.1752925E-04,   2.2059446E-04,   2.2351867E-04
     +,   2.2630820E-04,   2.2897098E-04,   2.3151758E-04
     +,   2.3396054E-04,   2.3631439E-04,   2.3859547E-04
     +,   2.4082235E-04,   2.4301506E-04,   2.4519558E-04
     +,   2.4738681E-04,   2.4961319E-04,   2.5190052E-04
     +,   2.5427487E-04,   2.5676316E-04,   2.5939257E-04
     +,   2.6219053E-04,   2.6518412E-04,   2.6840001E-04
     +,   2.7186424E-04,   2.7560163E-04,   2.7963618E-04
     +,   2.8398982E-04,   2.8868331E-04,   2.9373480E-04
     +,   2.9916019E-04,   3.0497304E-04,   3.1118415E-04
     +,   3.1780064E-04,   3.2482733E-04,   3.3226429E-04
     +,   3.4010902E-04,   3.4835414E-04,   3.5698886E-04
     +,   3.6599726E-04,   3.7536010E-04,   3.8505247E-04
     +,   3.9504585E-04,   4.0530702E-04,   4.1579793E-04
     +,   4.2647583E-04,   4.3729460E-04,   4.4820434E-04
     +,   4.5915061E-04,   4.7007715E-04,   4.8092403E-04
     +,   4.9163064E-04,   5.0213397E-04,   5.1237224E-04
     +,   5.2228291E-04,   5.3180574E-04,   5.4088247E-04
     +,   5.4945896E-04,   5.5748574E-04,   5.6491862E-04
     +,   5.7171972E-04,   5.7785958E-04,   5.8331713E-04
     +,   5.8807968E-04,   5.9214537E-04,   5.9552240E-04
     +,   5.9822958E-04,   6.0029706E-04,   6.0176593E-04
     +,   6.0268794E-04,   6.0312549E-04,   6.0315087E-04
     +,   6.0284586E-04,   6.0230069E-04,   6.0161337E-04
     +,   6.0088839E-04,   6.0023589E-04,   5.9977052E-04
     +,   5.9961143E-04,   5.9988070E-04,   6.0070324E-04
     +,   6.0220697E-04,   6.0452300E-04,   6.0778682E-04
     +,   6.1213865E-04,   6.1772653E-04,   6.2470615E-04
     +,   6.3324597E-04,   6.4352673E-04,   6.5574510E-04
     +,   6.7011395E-04,   6.8686623E-04,   7.0625549E-04
     +,   7.2855351E-04,   7.5405295E-04,   7.8306731E-04
     +,   8.1592979E-04,   8.5298886E-04,   8.9461461E-04
     +,   9.4119186E-04,   9.9311420E-04,   1.0507801E-03
     +,   1.1145882E-03,   1.1849221E-03,   1.2621267E-03
     +,   1.3464938E-03,   1.4382430E-03,   1.5374975E-03
     +,   1.6442493E-03,   1.7583473E-03,   1.8794840E-03
     +,   2.0071599E-03,   2.1406617E-03,   2.2790604E-03
     +,   2.4211959E-03,   2.5656736E-03,   2.7109229E-03
     +,   2.8552832E-03,   2.9971271E-03,   3.1350113E-03
     +,   3.2678565E-03,   3.3951241E-03,   3.5169451E-03
     +,   3.6342440E-03,   3.7489429E-03,   3.8642203E-03
     +,   3.9848485E-03,   4.1175135E-03,   4.2709522E-03
     +,   4.4556996E-03,   4.6832995E-03,   4.9651009E-03
     +,   5.3108898E-03,   5.7275980E-03,   6.2182667E-03
     +,   6.7814710E-03,   7.4111931E-03,   8.0971858E-03
     +,   8.8261543E-03,   9.5835524E-03,   1.0355325E-02
     +,   1.1128239E-02,   1.1888452E-02,   1.2618413E-02
     +,   1.3293695E-02,   1.3881794E-02,   1.4344569E-02
     +,   1.4644686E-02,   1.4754551E-02,   1.4665476E-02
     +,   1.4394036E-02,   1.3981960E-02,   1.3488919E-02
     +,   1.2978971E-02,   1.2504830E-02,   1.2095871E-02
     +,   1.1754243E-02,   1.1460042E-02,   1.1182579E-02
     +,   1.0892512E-02,   1.0570246E-02,   1.0208698E-02
     +,   9.8115606E-03,   9.3897143E-03,   8.9574726E-03
     +,   8.5294144E-03,   8.1178481E-03,   7.7307029E-03
     +,   7.3703271E-03,   7.0336736E-03,   6.7139887E-03
     +,   6.4035500E-03,   6.0963496E-03,   5.7898001E-03
     +,   5.4850932E-03,   5.1863776E-03,   4.8991130E-03
     +,   4.6283812E-03,   4.3776417E-03,   4.1481783E-03
     +,   3.9391755E-03,   3.7482630E-03,   3.5723411E-03
     +,   3.4083098E-03,   3.2535994E-03,   3.1064104E-03
     +,   2.9657271E-03,   2.8311743E-03,   2.7027398E-03
     +,   2.5805510E-03,   2.4647212E-03,   2.3552366E-03
     +,   2.2519331E-03,   2.1545328E-03,   2.0627070E-03
     +,   1.9761235E-03,   1.8944802E-03,   1.8175365E-03
     +,   1.7451062E-03,   1.6770451E-03,   1.6132127E-03
     +,   1.5534614E-03,   1.4976154E-03,   1.4454484E-03
     +,   1.3966870E-03,   1.3510119E-03,   1.3080608E-03
     +,   1.2674343E-03,   1.2287133E-03,   1.1914688E-03
     +,   1.1552748E-03,   1.1197194E-03,   1.0844170E-03
     +,   1.0490251E-03,   1.0132524E-03,   9.7686623E-04
     +,   9.3970209E-04,   9.0166903E-04,   8.6274766E-04
     +,   8.2298700E-04,   7.8250468E-04,   7.4147416E-04
     +,   7.0011307E-04,   6.5867289E-04,   6.1742892E-04
     +,   5.7666691E-04,   5.3666602E-04,   4.9769192E-04
     +,   4.5999212E-04,   4.2377907E-04,   3.8923571E-04
     +,   3.5650242E-04,   3.2568557E-04,   2.9684871E-04
     +,   2.7002359E-04,   2.4520498E-04,   2.2236221E-04
     +,   2.0143617E-04,   1.8235126E-04,   1.6501357E-04
     +,   1.4931886E-04,   1.3515679E-04,   1.2241173E-04
     +,   1.1096923E-04,   1.0071509E-04,   9.1540402E-05
     +,   8.3340463E-05,   7.6017932E-05,   6.9481459E-05
     +,   6.3647931E-05,   5.8440652E-05,   5.3790915E-05
     +,   4.9636088E-05,   4.5920642E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_htt95 = Yx/0.159046511627907
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8816771E-06,   3.1222944E-06
     +,   3.3756028E-06,   3.6414781E-06,   3.9197012E-06
     +,   4.2099518E-06,   4.5118054E-06,   4.8247230E-06
     +,   5.1480547E-06,   5.4810444E-06,   5.8228102E-06
     +,   6.1723572E-06,   6.5285790E-06,   6.8902573E-06
     +,   7.2560715E-06,   7.6246019E-06,   7.9943329E-06
     +,   8.3636714E-06,   8.7309500E-06,   9.0944404E-06
     +,   9.4523666E-06,   9.8029250E-06,   1.0144278E-05
     +,   1.0474618E-05,   1.0792107E-05,   1.1094974E-05
     +,   1.1381482E-05,   1.1649960E-05,   1.1898819E-05
     +,   1.2126568E-05,   1.2331838E-05,   1.2513380E-05
     +,   1.2670097E-05,   1.2801043E-05,   1.2905444E-05
     +,   1.2982701E-05,   1.3032400E-05,   1.3054320E-05
     +,   1.3048440E-05,   1.3014932E-05,   1.2954165E-05
     +,   1.2866709E-05,   1.2753321E-05,   1.2614952E-05
     +,   1.2452731E-05,   1.2267953E-05,   1.2062076E-05
     +,   1.1836705E-05,   1.1593585E-05,   1.1334568E-05
     +,   1.1061625E-05,   1.0776806E-05,   1.0482243E-05
     +,   1.0180112E-05,   9.8726496E-06,   9.5620944E-06
     +,   9.2507071E-06,   8.9407413E-06,   8.6344289E-06
     +,   8.3339683E-06,   8.0415120E-06,   7.7591558E-06
     +,   7.4889454E-06,   7.2328316E-06,   6.9926896E-06
     +,   6.7703345E-06,   6.5674712E-06,   6.3857428E-06
     +,   6.2266913E-06,   6.0918005E-06,   5.9824706E-06
     +,   5.9000527E-06,   5.8458490E-06,   5.8211294E-06
     +,   5.8271526E-06,   5.8651931E-06,   5.9365548E-06
     +,   6.0426005E-06,   6.1847950E-06,   6.3647299E-06
     +,   6.5841509E-06,   6.8450272E-06,   7.1495397E-06
     +,   7.5001981E-06,   7.8997964E-06,   8.3515497E-06
     +,   8.8590405E-06,   9.4263669E-06,   1.0058055E-05
     +,   1.0759215E-05,   1.1535526E-05,   1.2393197E-05
     +,   1.3339029E-05,   1.4380464E-05,   1.5525557E-05
     +,   1.6782806E-05,   1.8161409E-05,   1.9670861E-05
     +,   2.1321270E-05,   2.3122848E-05,   2.5086279E-05
     +,   2.7222070E-05,   2.9540977E-05,   3.2053234E-05
     +,   3.4768920E-05,   3.7697515E-05,   4.0847503E-05
     +,   4.4226228E-05,   4.7839927E-05,   5.1693205E-05
     +,   5.5788380E-05,   6.0126014E-05,   6.4703629E-05
     +,   6.9516427E-05,   7.4555952E-05,   7.9810976E-05
     +,   8.5266111E-05,   9.0902991E-05,   9.6698925E-05
     +,   1.0262818E-04,   1.0866178E-04,   1.1476751E-04
     +,   1.2091087E-04,   1.2705626E-04,   1.3316763E-04
     +,   1.3920895E-04,   1.4514691E-04,   1.5095064E-04
     +,   1.5659485E-04,   1.6205941E-04,   1.6733217E-04
     +,   1.7240843E-04,   1.7729292E-04,   1.8199858E-04
     +,   1.8654746E-04,   1.9096941E-04,   1.9530029E-04
     +,   1.9958065E-04,   2.0385394E-04,   2.0816391E-04
     +,   2.1255227E-04,   2.1705737E-04,   2.2171339E-04
     +,   2.2655001E-04,   2.3159312E-04,   2.3686867E-04
     +,   2.4240620E-04,   2.4824470E-04,   2.5443995E-04
     +,   2.6107344E-04,   2.6826077E-04,   2.7615950E-04
     +,   2.8497641E-04,   2.9497163E-04,   3.0645877E-04
     +,   3.1979673E-04,   3.3537741E-04,   3.5360572E-04
     +,   3.7486968E-04,   3.9950290E-04,   4.2775087E-04
     +,   4.5973351E-04,   4.9541926E-04,   5.3462351E-04
     +,   5.7704060E-04,   6.2231341E-04,   6.7014783E-04
     +,   7.2048150E-04,   7.7368849E-04,   8.3078735E-04
     +,   8.9361827E-04,   9.6493092E-04,   1.0483020E-03
     +,   1.1477892E-03,   1.2672852E-03,   1.4097110E-03
     +,   1.5764051E-03,   1.7674984E-03,   1.9842186E-03
     +,   2.2331416E-03,   2.5303809E-03,   2.9029394E-03
     +,   3.3878938E-03,   4.0339902E-03,   4.9023610E-03
     +,   6.0484339E-03,   7.4881325E-03,   9.2185242E-03
     +,   1.1353246E-02,   1.4212684E-02,   1.7971085E-02
     +,   2.2101602E-02,   2.6173711E-02,   3.0713754E-02
     +,   3.5098169E-02,   3.8288206E-02,   4.0521145E-02
     +,   4.1357957E-02,   4.2121094E-02,   4.2245742E-02
     +,   3.8620424E-02,   3.2361209E-02,   2.6891597E-02
     +,   2.2589928E-02,   1.8363729E-02,   1.4697899E-02
     +,   1.2175530E-02,   1.0250548E-02,   8.3781080E-03
     +,   6.5873205E-03,   5.0888183E-03,   3.9764619E-03
     +,   3.2082556E-03,   2.6809564E-03,   2.2927395E-03
     +,   1.9718627E-03,   1.6805890E-03,   1.4067569E-03
     +,   1.1521771E-03,   9.2322903E-04,   7.2527508E-04
     +,   5.6049839E-04,   4.2783417E-04,   3.2388014E-04
     +,   2.4405381E-04,   1.8357240E-04,   1.3808120E-04
     +,   1.0394346E-04,   7.8295408E-05,   5.8968988E-05
     +,   4.4358396E-05,   3.3282893E-05,   2.4873292E-05
     +,   1.8486766E-05,   1.3644363E-05,   9.9850222E-06
     +,   7.2344956E-06,   5.1825118E-06,   3.6661802E-06
     +,   2.5583438E-06,   1.7594682E-06,   1.1917175E-06
     +,   7.9450763E-07,   5.2115877E-07,   3.3624406E-07
     +,   2.1333948E-07,   1.3309834E-07,   8.1643513E-08
     +,   4.9237709E-08,   2.9195261E-08,   1.7020099E-08
     +,   9.7554187E-09,   5.4976774E-09,   3.0463319E-09
     +,   1.6597271E-09,   8.8909979E-10,   4.6830240E-10
     +,   2.4253211E-10,   1.2349920E-10,   6.1828702E-11
     +,   3.0433087E-11,   1.4727424E-11,   7.0066067E-12
     +,   3.2768877E-12,   1.5065811E-12,   6.8088466E-13
     +,   3.0246866E-13,   1.3207266E-13,   5.6686508E-14
     +,   2.3915577E-14,   9.9182654E-15,   4.0442397E-15
     +,   1.6220236E-15,   6.4032938E-16,   2.4915884E-16
     +,   9.5826194E-17,   3.6613955E-17,   1.4032831E-17
     +,   5.4857344E-18,   2.2455319E-18,   9.9466887E-19
     +,   4.8984561E-19,   2.6937948E-19,   1.6207628E-19
     +,   1.0348339E-19,   6.8322094E-20,   4.5863132E-20
     +,   3.1007460E-20,   2.1012065E-20,   1.4237003E-20
     +,   9.6346613E-21,   6.5085212E-21,   4.3879726E-21
     +,   2.9520479E-21,   1.9817642E-21,   1.3274789E-21
     +,   8.8728177E-22,   5.9175105E-22,   3.9379411E-22
     +,   2.6148215E-22,   1.7324829E-22
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz100 = Yx/0.152209302325581
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2505709E-07,   2.5777442E-07
     +,   2.9457431E-07,   3.3586008E-07,   3.8205900E-07
     +,   4.3362232E-07,   4.9102334E-07,   5.5475675E-07
     +,   6.2533502E-07,   7.0329054E-07,   7.8916565E-07
     +,   8.8351533E-07,   9.8689952E-07,   1.0998801E-06
     +,   1.2230174E-06,   1.3568610E-06,   1.5019475E-06
     +,   1.6587921E-06,   1.8278818E-06,   2.0096695E-06
     +,   2.2045663E-06,   2.4129322E-06,   2.6350676E-06
     +,   2.8712236E-06,   3.1215507E-06,   3.3861502E-06
     +,   3.6650204E-06,   3.9580723E-06,   4.2651213E-06
     +,   4.5858806E-06,   4.9199584E-06,   5.2668570E-06
     +,   5.6259732E-06,   5.9965905E-06,   6.3778925E-06
     +,   6.7689598E-06,   7.1687746E-06,   7.5762209E-06
     +,   7.9901311E-06,   8.4092153E-06,   8.8321740E-06
     +,   9.2576274E-06,   9.6841741E-06,   1.0110394E-05
     +,   1.0534864E-05,   1.0956173E-05,   1.1372956E-05
     +,   1.1783887E-05,   1.2187719E-05,   1.2583293E-05
     +,   1.2969550E-05,   1.3345562E-05,   1.3710537E-05
     +,   1.4063848E-05,   1.4405007E-05,   1.4733735E-05
     +,   1.5049921E-05,   1.5353655E-05,   1.5645224E-05
     +,   1.5925110E-05,   1.6194002E-05,   1.6452785E-05
     +,   1.6702512E-05,   1.6944448E-05,   1.7180022E-05
     +,   1.7410795E-05,   1.7638502E-05,   1.7864973E-05
     +,   1.8092180E-05,   1.8322138E-05,   1.8556964E-05
     +,   1.8798790E-05,   1.9049790E-05,   1.9312121E-05
     +,   1.9587927E-05,   1.9879315E-05,   2.0188307E-05
     +,   2.0516842E-05,   2.0866777E-05,   2.1239861E-05
     +,   2.1637659E-05,   2.2061658E-05,   2.2513117E-05
     +,   2.2993212E-05,   2.3502860E-05,   2.4042893E-05
     +,   2.4613866E-05,   2.5216244E-05,   2.5850233E-05
     +,   2.6515896E-05,   2.7213142E-05,   2.7941653E-05
     +,   2.8700932E-05,   2.9490364E-05,   3.0309178E-05
     +,   3.1156393E-05,   3.2030963E-05,   3.2931635E-05
     +,   3.3857141E-05,   3.4806006E-05,   3.5776800E-05
     +,   3.6767946E-05,   3.7777965E-05,   3.8805305E-05
     +,   3.9848575E-05,   4.0906554E-05,   4.1978150E-05
     +,   4.3062591E-05,   4.4159584E-05,   4.5269353E-05
     +,   4.6392663E-05,   4.7531237E-05,   4.8687598E-05
     +,   4.9865605E-05,   5.1070299E-05,   5.2308442E-05
     +,   5.3588417E-05,   5.4920816E-05,   5.6318309E-05
     +,   5.7796209E-05,   5.9372487E-05,   6.1067971E-05
     +,   6.2906496E-05,   6.4915148E-05,   6.7124274E-05
     +,   6.9567082E-05,   7.2280032E-05,   7.5301919E-05
     +,   7.8674144E-05,   8.2439350E-05,   8.6641521E-05
     +,   9.1324087E-05,   9.6530035E-05,   1.0229940E-04
     +,   1.0866916E-04,   1.1567155E-04,   1.2333212E-04
     +,   1.3166889E-04,   1.4069171E-04,   1.5040084E-04
     +,   1.6078554E-04,   1.7182433E-04,   1.8348530E-04
     +,   1.9572616E-04,   2.0849325E-04,   2.2172536E-04
     +,   2.3535379E-04,   2.4930300E-04,   2.6349389E-04
     +,   2.7784612E-04,   2.9227976E-04,   3.0671578E-04
     +,   3.2107867E-04,   3.3529769E-04,   3.4930604E-04
     +,   3.6303911E-04,   3.7643357E-04,   3.8942538E-04
     +,   4.0194613E-04,   4.1391910E-04,   4.2525996E-04
     +,   4.3587649E-04,   4.4567129E-04,   4.5455279E-04
     +,   4.6245052E-04,   4.6933957E-04,   4.7527251E-04
     +,   4.8042371E-04,   4.8514118E-04,   4.9000524E-04
     +,   4.9588666E-04,   5.0399941E-04,   5.1593367E-04
     +,   5.3366157E-04,   5.5950717E-04,   5.9611199E-04
     +,   6.4641942E-04,   7.1372528E-04,   8.0180704E-04
     +,   9.1505860E-04,   1.0584847E-03,   1.2374992E-03
     +,   1.4578030E-03,   1.7258278E-03,   2.0500275E-03
     +,   2.4431329E-03,   2.9267124E-03,   3.5405825E-03
     +,   4.3519912E-03,   5.4400349E-03,   6.8330332E-03
     +,   8.4523577E-03,   1.0212505E-02,   1.2281751E-02
     +,   1.5154951E-02,   1.9228144E-02,   2.3967346E-02
     +,   2.8358243E-02,   3.3485543E-02,   4.0727675E-02
     +,   4.7942918E-02,   5.2063428E-02,   4.8425898E-02
     +,   4.0404458E-02,   3.4487698E-02,   2.8906774E-02
     +,   2.3299279E-02,   1.9024869E-02,   1.5497983E-02
     +,   1.2275921E-02,   9.7034685E-03,   7.8262975E-03
     +,   6.4839758E-03,   5.5615092E-03,   4.9115568E-03
     +,   4.3704775E-03,   3.8444069E-03,   3.3200609E-03
     +,   2.8183560E-03,   2.3566517E-03,   1.9399731E-03
     +,   1.5676309E-03,   1.2393541E-03,   9.5626351E-04
     +,   7.1912172E-04,   5.2680523E-04,   3.7594367E-04
     +,   2.6141806E-04,   1.7719495E-04,   1.1712699E-04
     +,   7.5533353E-05,   4.7537578E-05,   2.9201174E-05
     +,   1.7505781E-05,   1.0239031E-05,   5.8398750E-06
     +,   3.2457494E-06,   1.7565335E-06,   9.2482003E-07
     +,   4.7327092E-07,   2.3518081E-07,   1.1338412E-07
     +,   5.2991343E-08,   2.3989367E-08,   1.0512177E-08
     +,   4.4565565E-09,   1.8271348E-09,   7.2425166E-10
     +,   2.7755662E-10,   1.0289602E-10,   3.6953482E-11
     +,   1.2902406E-11,   4.4167725E-12,   1.5105325E-12
     +,   5.3631595E-13,   2.1065475E-13,   9.7734809E-14
     +,   5.4284437E-14,   3.4354775E-14,   2.3297055E-14
     +,   1.6268830E-14,   1.1478126E-14,   8.1173336E-15
     +,   5.7368961E-15,   4.0476685E-15,   2.8499368E-15
     +,   2.0022328E-15,   1.4035795E-15,   9.8176963E-16
     +,   6.8522398E-16,   4.7720687E-16,   3.3162237E-16
     +,   2.2996164E-16,   1.5912643E-16,   1.0987660E-16
     +,   7.5711411E-17,   5.2060045E-17,   3.5723304E-17
     +,   2.4462262E-17,   1.6716826E-17,   1.1400398E-17
     +,   7.7590120E-18,   5.2699747E-18,   3.5722250E-18
     +,   2.4165213E-18,   1.6314655E-18,   1.0992492E-18
     +,   7.3916617E-19,   4.9605458E-19,   3.3223642E-19
     +,   2.2207900E-19,   1.4814922E-19,   9.8636015E-20
     +,   6.5539329E-20,   4.3462322E-20,   2.8764146E-20
     +,   1.8999009E-20,   1.2523851E-20,   8.2391196E-21
     +,   5.4093735E-21,   3.5444293E-21
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz102 = Yx/0.146348837209302
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.6400672E-18,   7.9434229E-18
     +,   1.3535345E-17,   2.2956664E-17,   3.8754530E-17
     +,   6.5118894E-17,   1.0890861E-16,   1.8129397E-16
     +,   3.0037636E-16,   4.9535101E-16,   8.1305734E-16
     +,   1.3282713E-15,   2.1597707E-15,   3.4952789E-15
     +,   5.6299891E-15,   9.0257417E-15,   1.4401457E-14
     +,   2.2870489E-14,   3.6148385E-14,   5.6865001E-14
     +,   8.9031213E-14,   1.3873271E-13,   2.1515489E-13
     +,   3.3209839E-13,   5.1016629E-13,   7.7999846E-13
     +,   1.1868870E-12,   1.7974508E-12,   2.7091643E-12
     +,   4.0639163E-12,   6.0671086E-12,   9.0146102E-12
     +,   1.3330282E-11,   1.9618102E-11,   2.8734235E-11
     +,   4.1885710E-11,   6.0765178E-11,   8.7732918E-11
     +,   1.2606530E-10,   1.8027829E-10,   2.5657296E-10
     +,   3.6340864E-10,   5.1226512E-10,   7.1863515E-10
     +,   1.0033075E-09,   1.3940248E-09,   1.9275948E-09
     +,   2.6525788E-09,   3.6326708E-09,   4.9509326E-09
     +,   6.7150538E-09,   9.0638110E-09,   1.2174942E-08
     +,   1.6275020E-08,   2.1650303E-08,   2.8661438E-08
     +,   3.7758848E-08,   4.9502106E-08,   6.4581769E-08
     +,   8.3844505E-08,   1.0832153E-07,   1.3926102E-07
     +,   1.7816006E-07,   2.2680794E-07,   2.8732498E-07
     +,   3.6219797E-07,   4.5433907E-07,   5.6710837E-07
     +,   7.0438097E-07,   8.7055474E-07,   1.0706190E-06
     +,   1.3101345E-06,   1.5953005E-06,   1.9328913E-06
     +,   2.3303000E-06,   2.7954832E-06,   3.3368667E-06
     +,   3.9632796E-06,   4.6838950E-06,   5.5080568E-06
     +,   6.4450305E-06,   7.5040016E-06,   8.6936088E-06
     +,   1.0021985E-05,   1.1496186E-05,   1.3122274E-05
     +,   1.4904650E-05,   1.6846243E-05,   1.8947758E-05
     +,   2.1207930E-05,   2.3623139E-05,   2.6187141E-05
     +,   2.8891112E-05,   3.1723852E-05,   3.4671699E-05
     +,   3.7718382E-05,   4.0845975E-05,   4.4034368E-05
     +,   4.7262558E-05,   5.0508232E-05,   5.3749151E-05
     +,   5.6962926E-05,   6.0128368E-05,   6.3225321E-05
     +,   6.6235902E-05,   6.9144786E-05,   7.1939423E-05
     +,   7.4610703E-05,   7.7153352E-05,   7.9565929E-05
     +,   8.1850638E-05,   8.4013838E-05,   8.6065120E-05
     +,   8.8017652E-05,   8.9887093E-05,   9.1691589E-05
     +,   9.3450712E-05,   9.5185082E-05,   9.6915370E-05
     +,   9.8661963E-05,   1.0044411E-04,   1.0227934E-04
     +,   1.0418296E-04,   1.0616806E-04,   1.0824515E-04
     +,   1.1042217E-04,   1.1270511E-04,   1.1509805E-04
     +,   1.1760485E-04,   1.2022916E-04,   1.2297691E-04
     +,   1.2585697E-04,   1.2888381E-04,   1.3207874E-04
     +,   1.3547258E-04,   1.3910768E-04,   1.4303920E-04
     +,   1.4733720E-04,   1.5208717E-04,   1.5739031E-04
     +,   1.6336179E-04,   1.7012806E-04,   1.7782334E-04
     +,   1.8658317E-04,   1.9653565E-04,   2.0779400E-04
     +,   2.2044581E-04,   2.3454166E-04,   2.5008607E-04
     +,   2.6703125E-04,   2.8527158E-04,   3.0464173E-04
     +,   3.2492200E-04,   3.4585001E-04,   3.6713321E-04
     +,   3.8846571E-04,   4.0955018E-04,   4.3011876E-04
     +,   4.4994874E-04,   4.6887214E-04,   4.8678360E-04
     +,   5.0363457E-04,   5.1942025E-04,   5.3416175E-04
     +,   5.4788630E-04,   5.6060532E-04,   5.7229929E-04
     +,   5.8291486E-04,   5.9237302E-04,   6.0059206E-04
     +,   6.0752215E-04,   6.1319035E-04,   6.1774830E-04
     +,   6.2152155E-04,   6.2506029E-04,   6.2920386E-04
     +,   6.3517538E-04,   6.4473838E-04,   6.6043308E-04
     +,   6.8590965E-04,   7.2631700E-04,   7.8866316E-04
     +,   8.8201097E-04,   1.0173188E-03,   1.2066759E-03
     +,   1.4617138E-03,   1.7912545E-03,   2.1986845E-03
     +,   2.6796430E-03,   3.2199712E-03,   3.7939227E-03
     +,   4.3656537E-03,   4.9030287E-03,   5.4090950E-03
     +,   5.9514265E-03,   6.6429581E-03,   7.5830272E-03
     +,   8.9075845E-03,   1.0972713E-02,   1.4348207E-02
     +,   1.9753581E-02,   2.7682029E-02,   3.6196187E-02
     +,   4.1457903E-02,   4.2895623E-02,   4.2206608E-02
     +,   4.0692933E-02,   3.9166145E-02,   3.6347590E-02
     +,   3.0539319E-02,   2.3707200E-02,   1.7974025E-02
     +,   1.3733643E-02,   1.0848220E-02,   8.8357003E-03
     +,   7.1806181E-03,   5.6989621E-03,   4.4311974E-03
     +,   3.4273954E-03,   2.6693600E-03,   2.0981785E-03
     +,   1.6564345E-03,   1.3045224E-03,   1.0187891E-03
     +,   7.8548386E-04,   5.9602468E-04,   4.4423010E-04
     +,   3.2493626E-04,   2.3339632E-04,   1.6507521E-04
     +,   1.1562775E-04,   8.0982565E-05,   5.7477399E-05
     +,   4.1985171E-05,   3.1984364E-05,   2.5559237E-05
     +,   2.1344958E-05,   1.8430683E-05,   1.6248065E-05
     +,   1.4466920E-05,   1.2910205E-05,   1.1491834E-05
     +,   1.0175407E-05,   8.9490877E-06,   7.8116727E-06
     +,   6.7653896E-06,   5.8123937E-06,   4.9533214E-06
     +,   4.1869853E-06,   3.5105020E-06,   2.9194091E-06
     +,   2.4081044E-06,   1.9702095E-06,   1.5988554E-06
     +,   1.2869540E-06,   1.0274728E-06,   8.1364379E-07
     +,   6.3908459E-07,   4.9789674E-07,   3.8474545E-07
     +,   2.9489271E-07,   2.2418952E-07,   1.6905334E-07
     +,   1.2643994E-07,   9.3800772E-08,   6.9021596E-08
     +,   5.0375125E-08,   3.6467302E-08,   2.6185001E-08
     +,   1.8649128E-08,   1.3173962E-08,   9.2306145E-09
     +,   6.4151546E-09,   4.4222186E-09,   3.0236016E-09
     +,   2.0505551E-09,   1.3793350E-09,   9.2030056E-10
     +,   6.0903321E-10,   3.9977463E-10,   2.6027924E-10
     +,   1.6808434E-10,   1.0766275E-10,   6.8401659E-11
     +,   4.3104031E-11,   2.6942192E-11,   1.6703377E-11
     +,   1.0271317E-11,   6.2648597E-12,   3.7900611E-12
     +,   2.2742871E-12,   1.3536117E-12,   7.9910855E-13
     +,   4.6791607E-13,   2.7176530E-13,   1.5655600E-13
     +,   8.9455936E-14,   5.0698774E-14,   2.8500419E-14
     +,   1.5891065E-14,   8.7885936E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz104 = Yx/0.134333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2583029E-07,   3.6430600E-07
     +,   4.0662709E-07,   4.5308775E-07,   5.0399365E-07
     +,   5.5966200E-07,   6.2041863E-07,   6.8659966E-07
     +,   7.5854683E-07,   8.3661104E-07,   9.2114402E-07
     +,   1.0125017E-06,   1.1110394E-06,   1.2171105E-06
     +,   1.3310635E-06,   1.4532409E-06,   1.5839736E-06
     +,   1.7235806E-06,   1.8723651E-06,   2.0306111E-06
     +,   2.1985793E-06,   2.3765085E-06,   2.5646009E-06
     +,   2.7630447E-06,   2.9719683E-06,   3.1914863E-06
     +,   3.4216600E-06,   3.6625115E-06,   3.9140200E-06
     +,   4.1761150E-06,   4.4486796E-06,   4.7315489E-06
     +,   5.0245071E-06,   5.3272906E-06,   5.6395843E-06
     +,   5.9610256E-06,   6.2912090E-06,   6.6296761E-06
     +,   6.9759535E-06,   7.3294900E-06,   7.6897459E-06
     +,   8.0561267E-06,   8.4280318E-06,   8.8048509E-06
     +,   9.1859611E-06,   9.5707546E-06,   9.9586359E-06
     +,   1.0349046E-05,   1.0741455E-05,   1.1135402E-05
     +,   1.1530477E-05,   1.1926375E-05,   1.2322869E-05
     +,   1.2719884E-05,   1.3117430E-05,   1.3515716E-05
     +,   1.3915099E-05,   1.4316126E-05,   1.4719555E-05
     +,   1.5126374E-05,   1.5537800E-05,   1.5955320E-05
     +,   1.6380671E-05,   1.6815882E-05,   1.7263294E-05
     +,   1.7725481E-05,   1.8205374E-05,   1.8706123E-05
     +,   1.9231222E-05,   1.9784347E-05,   2.0369493E-05
     +,   2.0990770E-05,   2.1652540E-05,   2.2359201E-05
     +,   2.3115286E-05,   2.3925331E-05,   2.4793786E-05
     +,   2.5724947E-05,   2.6722986E-05,   2.7791788E-05
     +,   2.8934797E-05,   3.0155152E-05,   3.1455344E-05
     +,   3.2837463E-05,   3.4302771E-05,   3.5852081E-05
     +,   3.7485257E-05,   3.9201695E-05,   4.0999803E-05
     +,   4.2877473E-05,   4.4831955E-05,   4.6859754E-05
     +,   4.8956859E-05,   5.1118994E-05,   5.3341551E-05
     +,   5.5619585E-05,   5.7948389E-05,   6.0323102E-05
     +,   6.2739418E-05,   6.5193140E-05,   6.7680943E-05
     +,   7.0199836E-05,   7.2747847E-05,   7.5323522E-05
     +,   7.7926474E-05,   8.0557045E-05,   8.3216255E-05
     +,   8.5905711E-05,   8.8627712E-05,   9.1384893E-05
     +,   9.4179763E-05,   9.7015072E-05,   9.9892874E-05
     +,   1.0281493E-04,   1.0578179E-04,   1.0879331E-04
     +,   1.1184746E-04,   1.1494123E-04,   1.1806941E-04
     +,   1.2122535E-04,   1.2440048E-04,   1.2758428E-04
     +,   1.3076443E-04,   1.3392710E-04,   1.3705710E-04
     +,   1.4013764E-04,   1.4315134E-04,   1.4607981E-04
     +,   1.4890467E-04,   1.5160709E-04,   1.5416894E-04
     +,   1.5657235E-04,   1.5880069E-04,   1.6083819E-04
     +,   1.6267075E-04,   1.6428594E-04,   1.6567307E-04
     +,   1.6682368E-04,   1.6773162E-04,   1.6839329E-04
     +,   1.6880801E-04,   1.6897831E-04,   1.6891029E-04
     +,   1.6861445E-04,   1.6810610E-04,   1.6740632E-04
     +,   1.6654286E-04,   1.6555144E-04,   1.6447686E-04
     +,   1.6337440E-04,   1.6231138E-04,   1.6136859E-04
     +,   1.6064204E-04,   1.6024412E-04,   1.6030566E-04
     +,   1.6097771E-04,   1.6243389E-04,   1.6487425E-04
     +,   1.6852973E-04,   1.7366956E-04,   1.8061037E-04
     +,   1.8972835E-04,   2.0147022E-04,   2.1636396E-04
     +,   2.3502429E-04,   2.5814414E-04,   2.8646711E-04
     +,   3.2073472E-04,   3.6160980E-04,   4.0956604E-04
     +,   4.6475668E-04,   5.2688445E-04,   5.9509528E-04
     +,   6.6791009E-04,   7.4322551E-04,   8.1842672E-04
     +,   8.9057739E-04,   9.5669768E-04,   1.0141156E-03
     +,   1.0608484E-03,   1.0959656E-03,   1.1199181E-03
     +,   1.1347960E-03,   1.1444665E-03,   1.1545408E-03
     +,   1.1721294E-03,   1.2053909E-03,   1.2630263E-03
     +,   1.3540261E-03,   1.4879523E-03,   1.6756430E-03
     +,   1.9293505E-03,   2.2611164E-03,   2.6797717E-03
     +,   3.1895007E-03,   3.7932040E-03,   4.4998862E-03
     +,   5.3308262E-03,   6.3182986E-03,   7.4923486E-03
     +,   8.8627497E-03,   1.0455060E-02,   1.2495285E-02
     +,   1.5547124E-02,   1.9934496E-02,   2.4860999E-02
     +,   2.9487185E-02,   3.4205217E-02,   3.9044470E-02
     +,   4.4002242E-02,   4.8596784E-02,   4.8908941E-02
     +,   4.2374395E-02,   3.2320011E-02,   2.3344979E-02
     +,   1.6940314E-02,   1.2534929E-02,   9.5675522E-03
     +,   7.6470156E-03,   6.2713688E-03,   5.0800722E-03
     +,   3.9694021E-03,   2.9622554E-03,   2.0987082E-03
     +,   1.4031425E-03,   8.8107970E-04,   5.1889429E-04
     +,   2.8726607E-04,   1.5023857E-04,   7.4695257E-05
     +,   3.5531048E-05,   1.6260617E-05,   7.1864529E-06
     +,   3.0711942E-06,   1.2673960E-06,   5.0306289E-07
     +,   1.9100909E-07,   6.8973044E-08,   2.3564693E-08
     +,   7.5896098E-09,   2.3025077E-09,   6.6137618E-10
     +,   1.8345481E-10,   5.1936254E-11,   1.6875319E-11
     +,   7.1714774E-12,   3.9637022E-12,   2.5266746E-12
     +,   1.6951574E-12,   1.1526979E-12,   7.8509145E-13
     +,   5.3385329E-13,   3.6214963E-13,   2.4505254E-13
     +,   1.6539775E-13,   1.1135423E-13,   7.4784586E-14
     +,   5.0104157E-14,   3.3489199E-14,   2.2331907E-14
     +,   1.4858300E-14,   9.8644161E-15,   6.5352819E-15
     +,   4.3209874E-15,   2.8515925E-15,   1.8785704E-15
     +,   1.2355461E-15,   8.1144586E-16,   5.3225068E-16
     +,   3.4874956E-16,   2.2832146E-16,   1.4939317E-16
     +,   9.7722423E-17,   6.3923466E-17,   4.1827645E-17
     +,   2.7387991E-17,   1.7951032E-17,   1.1781877E-17
     +,   7.7459476E-18,   5.1030095E-18,   3.3697258E-18
     +,   2.2310573E-18,   1.4813833E-18,   9.8663322E-19
     +,   6.5920618E-19,   4.4187823E-19,   2.9716350E-19
     +,   2.0047863E-19,   1.3566830E-19,   9.2074870E-20
     +,   6.2656883E-20,   4.2740868E-20,   2.9218191E-20
     +,   2.0010569E-20,   1.3725794E-20,   9.4264420E-21
     +,   6.4799350E-21,   4.4573338E-21,   3.0672701E-21
     +,   2.1109635E-21,   1.4527005E-21
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz106 = Yx/0.1345
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6819019E-06,   3.9085908E-06
     +,   4.1450116E-06,   4.3912728E-06,   4.6474588E-06
     +,   4.9136324E-06,   5.1898305E-06,   5.4760658E-06
     +,   5.7723182E-06,   6.0785546E-06,   6.3946959E-06
     +,   6.7206420E-06,   7.0562551E-06,   7.4013706E-06
     +,   7.7557897E-06,   8.1192802E-06,   8.4915764E-06
     +,   8.8723755E-06,   9.2613463E-06,   9.6581198E-06
     +,   1.0062293E-05,   1.0473429E-05,   1.0891054E-05
     +,   1.1314683E-05,   1.1743757E-05,   1.2177729E-05
     +,   1.2615997E-05,   1.3057938E-05,   1.3502899E-05
     +,   1.3950206E-05,   1.4399153E-05,   1.4849019E-05
     +,   1.5299056E-05,   1.5748505E-05,   1.6196580E-05
     +,   1.6642500E-05,   1.7085447E-05,   1.7524619E-05
     +,   1.7959201E-05,   1.8388359E-05,   1.8811284E-05
     +,   1.9227167E-05,   1.9635198E-05,   2.0034578E-05
     +,   2.0424539E-05,   2.0804329E-05,   2.1173235E-05
     +,   2.1530561E-05,   2.1875676E-05,   2.2207987E-05
     +,   2.2526994E-05,   2.2832250E-05,   2.3123419E-05
     +,   2.3400278E-05,   2.3662727E-05,   2.3910852E-05
     +,   2.4144920E-05,   2.4365427E-05,   2.4573139E-05
     +,   2.4769155E-05,   2.4954938E-05,   2.5132402E-05
     +,   2.5303962E-05,   2.5472635E-05,   2.5642144E-05
     +,   2.5816953E-05,   2.6002455E-05,   2.6205033E-05
     +,   2.6432210E-05,   2.6692735E-05,   2.6996750E-05
     +,   2.7355869E-05,   2.7783311E-05,   2.8293955E-05
     +,   2.8904447E-05,   2.9633242E-05,   3.0500518E-05
     +,   3.1528169E-05,   3.2739721E-05,   3.4160177E-05
     +,   3.5815512E-05,   3.7732712E-05,   3.9938910E-05
     +,   4.2461314E-05,   4.5326015E-05,   4.8557973E-05
     +,   5.2179417E-05,   5.6209901E-05,   6.0664403E-05
     +,   6.5553329E-05,   7.0881259E-05,   7.6645731E-05
     +,   8.2836639E-05,   8.9436202E-05,   9.6417913E-05
     +,   1.0374565E-04,   1.1137518E-04,   1.1925235E-04
     +,   1.2731565E-04,   1.3549488E-04,   1.4371410E-04
     +,   1.5189110E-04,   1.5994089E-04,   1.6777527E-04
     +,   1.7530679E-04,   1.8244974E-04,   1.8912194E-04
     +,   1.9524705E-04,   2.0075697E-04,   2.0559315E-04
     +,   2.0970752E-04,   2.1306472E-04,   2.1564189E-04
     +,   2.1743009E-04,   2.1843346E-04,   2.1866964E-04
     +,   2.1816851E-04,   2.1697137E-04,   2.1512975E-04
     +,   2.1270342E-04,   2.0975897E-04,   2.0636780E-04
     +,   2.0260441E-04,   1.9854422E-04,   1.9426181E-04
     +,   1.8983007E-04,   1.8531762E-04,   1.8078872E-04
     +,   1.7630159E-04,   1.7190860E-04,   1.6765502E-04
     +,   1.6358003E-04,   1.5971571E-04,   1.5608872E-04
     +,   1.5271979E-04,   1.4962518E-04,   1.4681726E-04
     +,   1.4430565E-04,   1.4209768E-04,   1.4019976E-04
     +,   1.3861818E-04,   1.3735995E-04,   1.3643313E-04
     +,   1.3584769E-04,   1.3561605E-04,   1.3575295E-04
     +,   1.3627578E-04,   1.3720429E-04,   1.3856046E-04
     +,   1.4036795E-04,   1.4265170E-04,   1.4543683E-04
     +,   1.4874818E-04,   1.5260931E-04,   1.5704178E-04
     +,   1.6206347E-04,   1.6768812E-04,   1.7392475E-04
     +,   1.8077651E-04,   1.8823914E-04,   1.9630170E-04
     +,   2.0494536E-04,   2.1414259E-04,   2.2385713E-04
     +,   2.3404462E-04,   2.4465210E-04,   2.5561743E-04
     +,   2.6687051E-04,   2.7833416E-04,   2.8992476E-04
     +,   3.0155235E-04,   3.1312328E-04,   3.2454255E-04
     +,   3.3571565E-04,   3.4655025E-04,   3.5696212E-04
     +,   3.6687744E-04,   3.7623735E-04,   3.8500363E-04
     +,   3.9316737E-04,   4.0075768E-04,   4.0785605E-04
     +,   4.1461701E-04,   4.2129756E-04,   4.2829575E-04
     +,   4.3620606E-04,   4.4589594E-04,   4.5861871E-04
     +,   4.7617097E-04,   5.0109468E-04,   5.3688471E-04
     +,   5.8807241E-04,   6.5999874E-04,   7.5816328E-04
     +,   8.8739558E-04,   1.0517240E-03,   1.2562467E-03
     +,   1.5114228E-03,   1.8376845E-03,   2.2668755E-03
     +,   2.8412878E-03,   3.6175996E-03,   4.6739168E-03
     +,   6.0917893E-03,   7.9025803E-03,   1.0091070E-02
     +,   1.2751717E-02,   1.6217001E-02,   2.0780649E-02
     +,   2.6140627E-02,   3.1735089E-02,   3.7587404E-02
     +,   4.3200534E-02,   4.7005624E-02,   4.7730379E-02
     +,   4.4562817E-02,   3.8076766E-02,   3.0616393E-02
     +,   2.3739779E-02,   1.7497841E-02,   1.2006240E-02
     +,   7.7058882E-03,   4.7125169E-03,   2.7781196E-03
     +,   1.5882340E-03,   8.9382916E-04,   5.1302894E-04
     +,   3.1513383E-04,   2.1337660E-04,   1.5821410E-04
     +,   1.2562804E-04,   1.0492689E-04,   9.0919115E-05
     +,   8.0577323E-05,   7.2036615E-05,   6.4277752E-05
     +,   5.6883891E-05,   4.9796094E-05,   4.3117125E-05
     +,   3.6987676E-05,   3.1523959E-05,   2.6793992E-05
     +,   2.2814278E-05,   1.9556950E-05,   1.6961534E-05
     +,   1.4947193E-05,   1.3423493E-05,   1.2299325E-05
     +,   1.1489511E-05,   1.0918897E-05,   1.0524099E-05
     +,   1.0253938E-05,   1.0068618E-05,   9.9382314E-06
     +,   9.8410392E-06,   9.7617421E-06,   9.6899184E-06
     +,   9.6186977E-06,   9.5437108E-06,   9.4623028E-06
     +,   9.3729659E-06,   9.2749406E-06,   9.1679321E-06
     +,   9.0519343E-06,   8.9271525E-06,   8.7938843E-06
     +,   8.6525060E-06,   8.5034553E-06,   8.3471969E-06
     +,   8.1842163E-06,   8.0150130E-06,   7.8401126E-06
     +,   7.6600481E-06,   7.4753502E-06,   7.2865528E-06
     +,   7.0942069E-06,   6.8988393E-06,   6.7009978E-06
     +,   6.5011955E-06,   6.2999670E-06,   6.0978073E-06
     +,   5.8952246E-06,   5.6926879E-06,   5.4906745E-06
     +,   5.2896185E-06,   5.0899594E-06,   4.8920979E-06
     +,   4.6964124E-06,   4.5032766E-06,   4.3130181E-06
     +,   4.1259636E-06,   3.9423908E-06,   3.7625771E-06
     +,   3.5867513E-06,   3.4151408E-06,   3.2479259E-06
     +,   3.0852839E-06,   2.9273472E-06,   2.7742456E-06
     +,   2.6260657E-06,   2.4828923E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz108 = Yx/0.126
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7645458E-06,   2.9390476E-06
     +,   3.1202098E-06,   3.3079227E-06,   3.5020432E-06
     +,   3.7023920E-06,   3.9087513E-06,   4.1208687E-06
     +,   4.3384471E-06,   4.5611637E-06,   4.7886460E-06
     +,   5.0204862E-06,   5.2562409E-06,   5.4954276E-06
     +,   5.7375300E-06,   5.9819990E-06,   6.2282516E-06
     +,   6.4756755E-06,   6.7236324E-06,   6.9714615E-06
     +,   7.2184794E-06,   7.4639861E-06,   7.7072682E-06
     +,   7.9476149E-06,   8.1842863E-06,   8.4165731E-06
     +,   8.6437531E-06,   8.8651204E-06,   9.0799886E-06
     +,   9.2876908E-06,   9.4875904E-06,   9.6790855E-06
     +,   9.8616119E-06,   1.0034651E-05,   1.0197738E-05
     +,   1.0350464E-05,   1.0492480E-05,   1.0623505E-05
     +,   1.0743336E-05,   1.0851839E-05,   1.0948966E-05
     +,   1.1034752E-05,   1.1109321E-05,   1.1172891E-05
     +,   1.1225776E-05,   1.1268386E-05,   1.1301232E-05
     +,   1.1324927E-05,   1.1340193E-05,   1.1347860E-05
     +,   1.1348870E-05,   1.1344274E-05,   1.1335253E-05
     +,   1.1323105E-05,   1.1309268E-05,   1.1295320E-05
     +,   1.1282995E-05,   1.1274198E-05,   1.1271023E-05
     +,   1.1275778E-05,   1.1291007E-05,   1.1319537E-05
     +,   1.1364499E-05,   1.1429382E-05,   1.1518085E-05
     +,   1.1634966E-05,   1.1784914E-05,   1.1973397E-05
     +,   1.2206561E-05,   1.2491255E-05,   1.2835164E-05
     +,   1.3246796E-05,   1.3735639E-05,   1.4312085E-05
     +,   1.4987586E-05,   1.5774616E-05,   1.6686601E-05
     +,   1.7737912E-05,   1.8943831E-05,   2.0320398E-05
     +,   2.1884092E-05,   2.3651884E-05,   2.5640597E-05
     +,   2.7866996E-05,   3.0346901E-05,   3.3095315E-05
     +,   3.6125301E-05,   3.9448205E-05,   4.3072287E-05
     +,   4.7002970E-05,   5.1242001E-05,   5.5786662E-05
     +,   6.0629554E-05,   6.5758504E-05,   7.1156166E-05
     +,   7.6799166E-05,   8.2659339E-05,   8.8702349E-05
     +,   9.4889554E-05,   1.0117678E-04,   1.0751652E-04
     +,   1.1385702E-04,   1.2014469E-04,   1.2632369E-04
     +,   1.3233807E-04,   1.3813241E-04,   1.4365268E-04
     +,   1.4884761E-04,   1.5367016E-04,   1.5807812E-04
     +,   1.6203453E-04,   1.6550944E-04,   1.6847950E-04
     +,   1.7092911E-04,   1.7284993E-04,   1.7424159E-04
     +,   1.7511068E-04,   1.7547116E-04,   1.7534340E-04
     +,   1.7475362E-04,   1.7373309E-04,   1.7231736E-04
     +,   1.7054552E-04,   1.6845895E-04,   1.6610064E-04
     +,   1.6351452E-04,   1.6074422E-04,   1.5783295E-04
     +,   1.5482221E-04,   1.5175191E-04,   1.4865918E-04
     +,   1.4557899E-04,   1.4254278E-04,   1.3957931E-04
     +,   1.3671383E-04,   1.3396828E-04,   1.3136151E-04
     +,   1.2890919E-04,   1.2662375E-04,   1.2451471E-04
     +,   1.2258894E-04,   1.2085079E-04,   1.1930219E-04
     +,   1.1794311E-04,   1.1677192E-04,   1.1578557E-04
     +,   1.1498009E-04,   1.1435111E-04,   1.1389433E-04
     +,   1.1360602E-04,   1.1348373E-04,   1.1352714E-04
     +,   1.1373850E-04,   1.1412385E-04,   1.1469360E-04
     +,   1.1546360E-04,   1.1645605E-04,   1.1770030E-04
     +,   1.1923388E-04,   1.2110266E-04,   1.2336187E-04
     +,   1.2607573E-04,   1.2931688E-04,   1.3316552E-04
     +,   1.3770789E-04,   1.4303345E-04,   1.4923140E-04
     +,   1.5638644E-04,   1.6457483E-04,   1.7385914E-04
     +,   1.8428279E-04,   1.9586665E-04,   2.0860783E-04
     +,   2.2247923E-04,   2.3743164E-04,   2.5340449E-04
     +,   2.7033730E-04,   2.8818613E-04,   3.0694788E-04
     +,   3.2668913E-04,   3.4757561E-04,   3.6990186E-04
     +,   3.9412067E-04,   4.2086546E-04,   4.5095873E-04
     +,   4.8540634E-04,   5.2538211E-04,   5.7220587E-04
     +,   6.2730687E-04,   6.9217180E-04,   7.6828414E-04
     +,   8.5701165E-04,   9.5945841E-04,   1.0763669E-03
     +,   1.2081998E-03,   1.3555504E-03,   1.5199265E-03
     +,   1.7046438E-03,   1.9151336E-03,   2.1579610E-03
     +,   2.4386118E-03,   2.7594736E-03,   3.1202328E-03
     +,   3.5227502E-03,   3.9807735E-03,   4.5327619E-03
     +,   5.2629891E-03,   6.3508153E-03,   8.1033744E-03
     +,   1.0788028E-02,   1.4291292E-02,   1.8120859E-02
     +,   2.1969946E-02,   2.6275277E-02,   3.1934980E-02
     +,   3.9057426E-02,   4.5609158E-02,   4.8219722E-02
     +,   4.5315973E-02,   3.8021151E-02,   2.8847702E-02
     +,   1.9921953E-02,   1.2200041E-02,   6.3224132E-03
     +,   2.7070257E-03,   9.9815521E-04,   3.7958613E-04
     +,   2.0257641E-04,   1.5590645E-04,   1.3564405E-04
     +,   1.1747256E-04,   9.9172219E-05,   8.2425395E-05
     +,   6.8383160E-05,   5.7152480E-05,   4.8233040E-05
     +,   4.1006577E-05,   3.5005014E-05,   2.9961382E-05
     +,   2.5747860E-05,   2.2294977E-05,   1.9537381E-05
     +,   1.7392342E-05,   1.5760646E-05,   1.4537016E-05
     +,   1.3621104E-05,   1.2925189E-05,   1.2378030E-05
     +,   1.1925442E-05,   1.1528626E-05,   1.1161325E-05
     +,   1.0806864E-05,   1.0455416E-05,   1.0101770E-05
     +,   9.7436332E-06,   9.3805147E-06,   9.0129734E-06
     +,   8.6421169E-06,   8.2693159E-06,   7.8960338E-06
     +,   7.5237708E-06,   7.1539976E-06,   6.7880842E-06
     +,   6.4273158E-06,   6.0729194E-06,   5.7259831E-06
     +,   5.3874878E-06,   5.0583276E-06,   4.7392878E-06
     +,   4.4310209E-06,   4.1340727E-06,   3.8489002E-06
     +,   3.5758644E-06,   3.3152003E-06,   3.0670574E-06
     +,   2.8315201E-06,   2.6085595E-06,   2.3981008E-06
     +,   2.1999738E-06,   2.0139714E-06,   1.8398068E-06
     +,   1.6771698E-06,   1.5256848E-06,   1.3849644E-06
     +,   1.2545717E-06,   1.1340655E-06,   1.0229759E-06
     +,   9.2082189E-07,   8.2712643E-07,   7.4139740E-07
     +,   6.6315681E-07,   5.9192189E-07,   5.2722805E-07
     +,   4.6861445E-07,   4.1564141E-07,   3.6787878E-07
     +,   3.2492036E-07,   2.8637282E-07,   2.5186796E-07
     +,   2.2105320E-07,   1.9360063E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz110 = Yx/0.11319512195122
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz111(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2811165E-06,   5.4901957E-06
     +,   5.7033931E-06,   5.9206941E-06,   6.1421065E-06
     +,   6.3676507E-06,   6.5973718E-06,   6.8313357E-06
     +,   7.0696296E-06,   7.3123824E-06,   7.5597413E-06
     +,   7.8118883E-06,   8.0690397E-06,   8.3314526E-06
     +,   8.5994161E-06,   8.8732631E-06,   9.1533611E-06
     +,   9.4401212E-06,   9.7339944E-06,   1.0035471E-05
     +,   1.0345079E-05,   1.0663384E-05,   1.0990982E-05
     +,   1.1328522E-05,   1.1676645E-05,   1.2036053E-05
     +,   1.2407447E-05,   1.2791554E-05,   1.3189107E-05
     +,   1.3600843E-05,   1.4027498E-05,   1.4469803E-05
     +,   1.4928467E-05,   1.5404177E-05,   1.5897594E-05
     +,   1.6409336E-05,   1.6939974E-05,   1.7490029E-05
     +,   1.8059985E-05,   1.8650207E-05,   1.9261051E-05
     +,   1.9892759E-05,   2.0545507E-05,   2.1219392E-05
     +,   2.1914415E-05,   2.2630511E-05,   2.3367520E-05
     +,   2.4125204E-05,   2.4903266E-05,   2.5701314E-05
     +,   2.6518916E-05,   2.7355572E-05,   2.8210725E-05
     +,   2.9083854E-05,   2.9974306E-05,   3.0881518E-05
     +,   3.1804888E-05,   3.2743839E-05,   3.3697837E-05
     +,   3.4666380E-05,   3.5649042E-05,   3.6645491E-05
     +,   3.7655391E-05,   3.8678598E-05,   3.9715058E-05
     +,   4.0764742E-05,   4.1827810E-05,   4.2904430E-05
     +,   4.3994987E-05,   4.5099812E-05,   4.6219448E-05
     +,   4.7354340E-05,   4.8505139E-05,   4.9672319E-05
     +,   5.0856488E-05,   5.2058174E-05,   5.3277799E-05
     +,   5.4515622E-05,   5.5771889E-05,   5.7046640E-05
     +,   5.8339640E-05,   5.9650571E-05,   6.0978691E-05
     +,   6.2323248E-05,   6.3682986E-05,   6.5056629E-05
     +,   6.6442451E-05,   6.7838744E-05,   6.9243426E-05
     +,   7.0654452E-05,   7.2069728E-05,   7.3487157E-05
     +,   7.4904718E-05,   7.6320772E-05,   7.7734054E-05
     +,   7.9143683E-05,   8.0549609E-05,   8.1952385E-05
     +,   8.3353720E-05,   8.4756211E-05,   8.6163862E-05
     +,   8.7581815E-05,   8.9016874E-05,   9.0477079E-05
     +,   9.1972215E-05,   9.3513503E-05,   9.5113581E-05
     +,   9.6786382E-05,   9.8547134E-05,   1.0041200E-04
     +,   1.0239755E-04,   1.0452096E-04,   1.0679897E-04
     +,   1.0924802E-04,   1.1188319E-04,   1.1471828E-04
     +,   1.1776454E-04,   1.2103098E-04,   1.2452286E-04
     +,   1.2824226E-04,   1.3218705E-04,   1.3635046E-04
     +,   1.4072098E-04,   1.4528265E-04,   1.5001469E-04
     +,   1.5489126E-04,   1.5988275E-04,   1.6495510E-04
     +,   1.7007145E-04,   1.7519176E-04,   1.8027476E-04
     +,   1.8527765E-04,   1.9015840E-04,   1.9487531E-04
     +,   1.9938929E-04,   2.0366420E-04,   2.0766770E-04
     +,   2.1137208E-04,   2.1475554E-04,   2.1780205E-04
     +,   2.2050201E-04,   2.2285254E-04,   2.2485763E-04
     +,   2.2652805E-04,   2.2788080E-04,   2.2893942E-04
     +,   2.2973314E-04,   2.3029640E-04,   2.3066856E-04
     +,   2.3089346E-04,   2.3101857E-04,   2.3109492E-04
     +,   2.3117659E-04,   2.3132050E-04,   2.3158579E-04
     +,   2.3203432E-04,   2.3272967E-04,   2.3373755E-04
     +,   2.3512547E-04,   2.3696257E-04,   2.3931950E-04
     +,   2.4226858E-04,   2.4588374E-04,   2.5024064E-04
     +,   2.5541769E-04,   2.6149675E-04,   2.6856319E-04
     +,   2.7670781E-04,   2.8602785E-04,   2.9662694E-04
     +,   3.0861481E-04,   3.2210530E-04,   3.3721508E-04
     +,   3.5405852E-04,   3.7274000E-04,   3.9335151E-04
     +,   4.1596391E-04,   4.4062189E-04,   4.6734328E-04
     +,   4.9612526E-04,   5.2695291E-04,   5.5981625E-04
     +,   5.9473969E-04,   6.3182227E-04,   6.7128142E-04
     +,   7.1350159E-04,   7.5909286E-04,   8.0894266E-04
     +,   8.6425984E-04,   9.2659425E-04,   9.9786406E-04
     +,   1.0803608E-03,   1.1767599E-03,   1.2901453E-03
     +,   1.4240240E-03,   1.5822231E-03,   1.7685795E-03
     +,   1.9863129E-03,   2.2370194E-03,   2.5193184E-03
     +,   2.8277871E-03,   3.1538445E-03,   3.4905956E-03
     +,   3.8413543E-03,   4.2256527E-03,   4.6737515E-03
     +,   5.2142800E-03,   5.8896081E-03,   6.8240147E-03
     +,   8.2522091E-03,   1.0341067E-02,   1.2962294E-02
     +,   1.5917685E-02,   1.9484427E-02,   2.4356114E-02
     +,   3.0774083E-02,   3.8148712E-02,   4.5785040E-02
     +,   5.2420124E-02,   5.4762196E-02,   4.9574289E-02
     +,   3.7641093E-02,   2.3617972E-02,   1.2218050E-02
     +,   5.3191120E-03,   2.1557538E-03,   1.0620541E-03
     +,   7.6067972E-04,   6.5560458E-04,   5.7314982E-04
     +,   4.8975908E-04,   4.1161425E-04,   3.4394662E-04
     +,   2.8748997E-04,   2.4036184E-04,   2.0015791E-04
     +,   1.6507723E-04,   1.3413813E-04,   1.0695213E-04
     +,   8.3420418E-05,   6.3507097E-05,   4.7110658E-05
     +,   3.4011842E-05,   2.3875808E-05,   1.6286320E-05
     +,   1.0790728E-05,   6.9429843E-06,   4.3377008E-06
     +,   2.6313633E-06,   1.5500580E-06,   8.8673295E-07
     +,   4.9266743E-07,   2.6588057E-07,   1.3939477E-07
     +,   7.1001246E-08,   3.5137582E-08,   1.6896800E-08
     +,   7.8959070E-09,   3.5857464E-09,   1.5825434E-09
     +,   6.7887240E-10,   2.8312508E-10,   1.1484286E-10
     +,   4.5349439E-11,   1.7472577E-11,   6.6010344E-12
     +,   2.4730099E-12,   9.4158297E-13,   3.8191249E-13
     +,   1.7660600E-13,   9.7980651E-14,   6.4378394E-14
     +,   4.7192647E-14,   3.6532971E-14,   2.8940924E-14
     +,   2.3127135E-14,   1.8533433E-14,   1.4860448E-14
     +,   1.1911608E-14,   9.5418753E-15,   7.6375733E-15
     +,   6.1081968E-15,   4.8807101E-15,   3.8963456E-15
     +,   3.1075612E-15,   2.4761039E-15,   1.9710198E-15
     +,   1.5673869E-15,   1.2451608E-15,   9.8815128E-16
     +,   7.8338440E-16,   6.2039266E-16,   4.9079593E-16
     +,   3.8785366E-16,   3.0617369E-16,   2.4143181E-16
     +,   1.9017293E-16,   1.4963172E-16,   1.1760372E-16
     +,   9.2327683E-17,   7.2404171E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz111 = Yx/0.124333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7289475E-09,   3.1825031E-09
     +,   3.7066348E-09,   4.3115542E-09,   5.0088897E-09
     +,   5.8118066E-09,   6.7352572E-09,   7.7961779E-09
     +,   9.0137746E-09,   1.0409879E-08,   1.2009166E-08
     +,   1.3839682E-08,   1.5933246E-08,   1.8326022E-08
     +,   2.1059080E-08,   2.4179203E-08,   2.7739665E-08
     +,   3.1801221E-08,   3.6433239E-08,   4.1715023E-08
     +,   4.7737334E-08,   5.4604204E-08,   6.2434808E-08
     +,   7.1366500E-08,   8.1556152E-08,   9.3185115E-08
     +,   1.0646148E-07,   1.2162459E-07,   1.3894984E-07
     +,   1.5875388E-07,   1.8140037E-07,   2.0730693E-07
     +,   2.3695210E-07,   2.7088390E-07,   3.0972845E-07
     +,   3.5419927E-07,   4.0510821E-07,   4.6337539E-07
     +,   5.3004584E-07,   6.0628952E-07,   6.9343031E-07
     +,   7.9294472E-07,   9.0648109E-07,   1.0358696E-06
     +,   1.1831335E-06,   1.3505007E-06,   1.5404082E-06
     +,   1.7555117E-06,   1.9986878E-06,   2.2730342E-06
     +,   2.5818638E-06,   2.9286982E-06,   3.3172469E-06
     +,   3.7514219E-06,   4.2352358E-06,   4.7728663E-06
     +,   5.3685440E-06,   6.0265338E-06,   6.7510809E-06
     +,   7.5463463E-06,   8.4163439E-06,   9.3648741E-06
     +,   1.0395377E-05,   1.1510987E-05,   1.2714380E-05
     +,   1.4007559E-05,   1.5392066E-05,   1.6868538E-05
     +,   1.8437024E-05,   2.0096517E-05,   2.1845319E-05
     +,   2.3680566E-05,   2.5598667E-05,   2.7594817E-05
     +,   2.9663452E-05,   3.1798136E-05,   3.3991437E-05
     +,   3.6235182E-05,   3.8520746E-05,   4.0839015E-05
     +,   4.3180371E-05,   4.5535366E-05,   4.7894369E-05
     +,   5.0248371E-05,   5.2588617E-05,   5.4907465E-05
     +,   5.7198002E-05,   5.9454873E-05,   6.1673876E-05
     +,   6.3852720E-05,   6.5990847E-05,   6.8089510E-05
     +,   7.0151902E-05,   7.2183313E-05,   7.4190953E-05
     +,   7.6183605E-05,   7.8171935E-05,   8.0167694E-05
     +,   8.2183942E-05,   8.4234132E-05,   8.6332228E-05
     +,   8.8491666E-05,   9.0725487E-05,   9.3045142E-05
     +,   9.5460520E-05,   9.7979260E-05,   1.0060603E-04
     +,   1.0334226E-04,   1.0618603E-04,   1.0913150E-04
     +,   1.1216852E-04,   1.1528313E-04,   1.1845697E-04
     +,   1.2166812E-04,   1.2489062E-04,   1.2809579E-04
     +,   1.3125211E-04,   1.3432639E-04,   1.3728424E-04
     +,   1.4009136E-04,   1.4271447E-04,   1.4512212E-04
     +,   1.4728612E-04,   1.4918261E-04,   1.5079348E-04
     +,   1.5210676E-04,   1.5311851E-04,   1.5383311E-04
     +,   1.5426466E-04,   1.5443693E-04,   1.5438438E-04
     +,   1.5415206E-04,   1.5379547E-04,   1.5338004E-04
     +,   1.5298063E-04,   1.5267993E-04,   1.5256704E-04
     +,   1.5273535E-04,   1.5327999E-04,   1.5429509E-04
     +,   1.5587082E-04,   1.5808955E-04,   1.6102314E-04
     +,   1.6472940E-04,   1.6924855E-04,   1.7460168E-04
     +,   1.8078850E-04,   1.8778608E-04,   1.9554931E-04
     +,   2.0401260E-04,   2.1309279E-04,   2.2269180E-04
     +,   2.3270272E-04,   2.4301642E-04,   2.5352807E-04
     +,   2.6414293E-04,   2.7478396E-04,   2.8539894E-04
     +,   2.9596349E-04,   3.0648359E-04,   3.1699700E-04
     +,   3.2757057E-04,   3.3829344E-04,   3.4927035E-04
     +,   3.6061101E-04,   3.7241768E-04,   3.8477071E-04
     +,   3.9771592E-04,   4.1125374E-04,   4.2532902E-04
     +,   4.3982401E-04,   4.5455870E-04,   4.6929531E-04
     +,   4.8374804E-04,   4.9759628E-04,   5.1050825E-04
     +,   5.2216463E-04,   5.3228450E-04,   5.4065889E-04
     +,   5.4718193E-04,   5.5188575E-04,   5.5497407E-04
     +,   5.5686012E-04,   5.5820169E-04,   5.5993383E-04
     +,   5.6329253E-04,   5.6982844E-04,   5.8140268E-04
     +,   6.0017174E-04,   6.2856503E-04,   6.6928135E-04
     +,   7.2530744E-04,   7.9995894E-04,   8.9691940E-04
     +,   1.0202084E-03,   1.1739618E-03,   1.3618903E-03
     +,   1.5863124E-03,   1.8466859E-03,   2.1377483E-03
     +,   2.4478382E-03,   2.7585686E-03,   3.0474183E-03
     +,   3.2947394E-03,   3.4960124E-03,   3.6778208E-03
     +,   3.9111362E-03,   4.3116868E-03,   5.0209649E-03
     +,   6.1719059E-03,   7.8365309E-03,   9.9425828E-03
     +,   1.2255888E-02,   1.4635165E-02,   1.7325556E-02
     +,   2.0828476E-02,   2.5890609E-02,   3.3301130E-02
     +,   4.2308670E-02,   4.9852546E-02,   5.1939614E-02
     +,   4.5829527E-02,   3.2758184E-02,   1.8240018E-02
     +,   7.7385171E-03,   2.5726969E-03,   8.0087228E-04
     +,   3.4175784E-04,   2.1705432E-04,   1.5490640E-04
     +,   1.0768318E-04,   7.0796617E-05,   4.3602206E-05
     +,   2.4826426E-05,   1.2878078E-05,   6.0173561E-06
     +,   2.5163490E-06,   9.3957789E-07,   3.1372983E-07
     +,   9.4512167E-08,   2.6521061E-08,   7.6857427E-09
     +,   2.8865323E-09,   1.6396950E-09,   1.2119779E-09
     +,   9.7529340E-10,   7.9904439E-10,   6.5584410E-10
     +,   5.3759641E-10,   4.3985596E-10,   3.5918979E-10
     +,   2.9274538E-10,   2.3812707E-10,   1.9332272E-10
     +,   1.5664232E-10,   1.2667319E-10,   1.0223795E-10
     +,   8.2355803E-11,   6.6210523E-11,   5.3126149E-11
     +,   4.2544177E-11,   3.4003730E-11,   2.7124645E-11
     +,   2.1594776E-11,   1.7158835E-11,   1.3607504E-11
     +,   1.0770013E-11,   8.5075575E-12,   6.7073079E-12
     +,   5.2776754E-12,   4.1446273E-12,   3.2484759E-12
     +,   2.5411420E-12,   1.9839486E-12,   1.5458939E-12
     +,   1.2022235E-12,   9.3312500E-13,   7.2285369E-13
     +,   5.5887077E-13,   4.3124979E-13,   3.3212072E-13
     +,   2.5528294E-13,   1.9583803E-13,   1.4994497E-13
     +,   1.1458258E-13,   8.7390476E-14,   6.6522058E-14
     +,   5.0538285E-14,   3.8320983E-14,   2.9000606E-14
     +,   2.1904792E-14,   1.6513031E-14,   1.2424456E-14
     +,   9.3300899E-15,   6.9929206E-15,   5.2310544E-15
     +,   3.9055910E-15,   2.9103506E-15,   2.1645713E-15
     +,   1.6067906E-15,   1.1904717E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz112 = Yx/0.109951219512195
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz1128(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.4147134E-07,   1.0260300E-06
     +,   1.1168208E-06,   1.2141652E-06,   1.3183875E-06
     +,   1.4298153E-06,   1.5487766E-06,   1.6755976E-06
     +,   1.8106017E-06,   1.9541137E-06,   2.1064461E-06
     +,   2.2679064E-06,   2.4387919E-06,   2.6193868E-06
     +,   2.8099637E-06,   3.0107772E-06,   3.2220639E-06
     +,   3.4440413E-06,   3.6769018E-06,   3.9208148E-06
     +,   4.1759222E-06,   4.4423391E-06,   4.7201402E-06
     +,   5.0093945E-06,   5.3100985E-06,   5.6222461E-06
     +,   5.9457820E-06,   6.2806143E-06,   6.6266157E-06
     +,   6.9836219E-06,   7.3514311E-06,   7.7298046E-06
     +,   8.1184708E-06,   8.5171205E-06,   8.9254181E-06
     +,   9.3429935E-06,   9.7694538E-06,   1.0204374E-05
     +,   1.0647338E-05,   1.1097864E-05,   1.1555512E-05
     +,   1.2019805E-05,   1.2490272E-05,   1.2966453E-05
     +,   1.3447890E-05,   1.3934147E-05,   1.4424811E-05
     +,   1.4919494E-05,   1.5417849E-05,   1.5919564E-05
     +,   1.6424379E-05,   1.6932074E-05,   1.7442489E-05
     +,   1.7955552E-05,   1.8471195E-05,   1.8989480E-05
     +,   1.9510493E-05,   2.0034406E-05,   2.0561461E-05
     +,   2.1091959E-05,   2.1626274E-05,   2.2164850E-05
     +,   2.2708149E-05,   2.3256738E-05,   2.3811219E-05
     +,   2.4372197E-05,   2.4940366E-05,   2.5516369E-05
     +,   2.6100948E-05,   2.6694775E-05,   2.7298587E-05
     +,   2.7913029E-05,   2.8538816E-05,   2.9176548E-05
     +,   2.9826844E-05,   3.0490293E-05,   3.1167387E-05
     +,   3.1858573E-05,   3.2564298E-05,   3.3284956E-05
     +,   3.4020824E-05,   3.4772256E-05,   3.5539459E-05
     +,   3.6322734E-05,   3.7122256E-05,   3.7938349E-05
     +,   3.8771232E-05,   3.9621300E-05,   4.0488914E-05
     +,   4.1374606E-05,   4.2279051E-05,   4.3203036E-05
     +,   4.4147506E-05,   4.5113735E-05,   4.6103254E-05
     +,   4.7117795E-05,   4.8159582E-05,   4.9231076E-05
     +,   5.0335355E-05,   5.1475803E-05,   5.2656527E-05
     +,   5.3882039E-05,   5.5157674E-05,   5.6489269E-05
     +,   5.7883564E-05,   5.9348047E-05,   6.0890947E-05
     +,   6.2521329E-05,   6.4249165E-05,   6.6085355E-05
     +,   6.8041365E-05,   7.0129659E-05,   7.2363102E-05
     +,   7.4755328E-05,   7.7320066E-05,   8.0071397E-05
     +,   8.3022962E-05,   8.6188295E-05,   8.9579655E-05
     +,   9.3208357E-05,   9.7084019E-05,   1.0121387E-04
     +,   1.0560232E-04,   1.1025092E-04,   1.1515752E-04
     +,   1.2031532E-04,   1.2571366E-04,   1.3133626E-04
     +,   1.3716250E-04,   1.4316574E-04,   1.4931499E-04
     +,   1.5557343E-04,   1.6190049E-04,   1.6825060E-04
     +,   1.7457544E-04,   1.8082427E-04,   1.8694425E-04
     +,   1.9288227E-04,   1.9858663E-04,   2.0400761E-04
     +,   2.0909880E-04,   2.1381865E-04,   2.1813207E-04
     +,   2.2201134E-04,   2.2543668E-04,   2.2839809E-04
     +,   2.3089565E-04,   2.3293996E-04,   2.3455294E-04
     +,   2.3576827E-04,   2.3663147E-04,   2.3720055E-04
     +,   2.3754625E-04,   2.3775280E-04,   2.3791872E-04
     +,   2.3815785E-04,   2.3860064E-04,   2.3939522E-04
     +,   2.4070904E-04,   2.4272909E-04,   2.4566258E-04
     +,   2.4973560E-04,   2.5518981E-04,   2.6227755E-04
     +,   2.7125480E-04,   2.8237031E-04,   2.9585121E-04
     +,   3.1188791E-04,   3.3061786E-04,   3.5210734E-04
     +,   3.7633392E-04,   4.0317504E-04,   4.3240402E-04
     +,   4.6368991E-04,   4.9660646E-04,   5.3066033E-04
     +,   5.6531985E-04,   6.0005405E-04,   6.3438015E-04
     +,   6.6791294E-04,   7.0040789E-04,   7.3179539E-04
     +,   7.6221075E-04,   7.9200993E-04,   8.2176767E-04
     +,   8.5226196E-04,   8.8445033E-04,   9.1944291E-04
     +,   9.5848652E-04,   1.0029759E-03,   1.0545354E-03
     +,   1.1151567E-03,   1.1873797E-03,   1.2744532E-03
     +,   1.3803520E-03,   1.5094932E-03,   1.6660708E-03
     +,   1.8531298E-03,   2.0716456E-03,   2.3198808E-03
     +,   2.5930500E-03,   2.8830366E-03,   3.1782100E-03
     +,   3.4647598E-03,   3.7321744E-03,   3.9834618E-03
     +,   4.2440188E-03,   4.5595788E-03,   4.9835299E-03
     +,   5.5717924E-03,   6.3987970E-03,   7.5779068E-03
     +,   9.2619052E-03,   1.1599008E-02,   1.4630275E-02
     +,   1.8323880E-02,   2.2921896E-02,   2.8902555E-02
     +,   3.5936747E-02,   4.2100959E-02,   4.4552039E-02
     +,   4.0848602E-02,   3.0874675E-02,   1.8464897E-02
     +,   8.8108601E-03,   3.8541632E-03,   2.0723988E-03
     +,   1.4607898E-03,   1.0851078E-03,   7.7336427E-04
     +,   5.4839422E-04,   4.1183524E-04,   3.3576851E-04
     +,   2.9099049E-04,   2.5940951E-04,   2.3302085E-04
     +,   2.0935244E-04,   1.8802121E-04,   1.6906802E-04
     +,   1.5243121E-04,   1.3789877E-04,   1.2517541E-04
     +,   1.1394118E-04,   1.0388818E-04,   9.4745737E-05
     +,   8.6296292E-05,   7.8381687E-05,   7.0901107E-05
     +,   6.3803069E-05,   5.7073579E-05,   5.0721468E-05
     +,   4.4767337E-05,   3.9234623E-05,   3.4142715E-05
     +,   2.9502922E-05,   2.5317227E-05,   2.1578446E-05
     +,   1.8270819E-05,   1.5371377E-05,   1.2851970E-05
     +,   1.0681189E-05,   8.8257375E-06,   7.2517546E-06
     +,   5.9261106E-06,   4.8173329E-06,   3.8959520E-06
     +,   3.1350291E-06,   2.5103791E-06,   2.0005332E-06
     +,   1.5866640E-06,   1.2524797E-06,   9.8404485E-07
     +,   7.6952165E-07,   5.9893108E-07,   4.6394237E-07
     +,   3.5765788E-07,   2.7438065E-07,   2.0945822E-07
     +,   1.5909485E-07,   1.2022635E-07,   9.0381661E-08
     +,   6.7587351E-08,   5.0269623E-08,   3.7185060E-08
     +,   2.7353025E-08,   2.0007194E-08,   1.4550213E-08
     +,   1.0519975E-08,   7.5613169E-09,   5.4022897E-09
     +,   3.8365031E-09,   2.7079059E-09,   1.8995767E-09
     +,   1.3242609E-09,   9.1742824E-10,   6.3157385E-10
     +,   4.3203841E-10,   2.9365801E-10,   1.9832573E-10
     +,   1.3307959E-10,   8.8723563E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz1128 = Yx/0.10185
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6437685E-06,   2.8822794E-06
     +,   3.1377799E-06,   3.4109910E-06,   3.7026134E-06
     +,   4.0133259E-06,   4.3437744E-06,   4.6945693E-06
     +,   5.0662698E-06,   5.4594066E-06,   5.8744322E-06
     +,   6.3117459E-06,   6.7716801E-06,   7.2544831E-06
     +,   7.7603308E-06,   8.2893121E-06,   8.8414208E-06
     +,   9.4165580E-06,   1.0014526E-05,   1.0635019E-05
     +,   1.1277631E-05,   1.1941848E-05,   1.2627036E-05
     +,   1.3332504E-05,   1.4057367E-05,   1.4800724E-05
     +,   1.5561527E-05,   1.6338645E-05,   1.7130853E-05
     +,   1.7936845E-05,   1.8755252E-05,   1.9584619E-05
     +,   2.0423449E-05,   2.1270189E-05,   2.2123268E-05
     +,   2.2981074E-05,   2.3842003E-05,   2.4704415E-05
     +,   2.5566771E-05,   2.6427442E-05,   2.7284954E-05
     +,   2.8137825E-05,   2.8984647E-05,   2.9824110E-05
     +,   3.0654966E-05,   3.1476102E-05,   3.2286487E-05
     +,   3.3085216E-05,   3.3871493E-05,   3.4644690E-05
     +,   3.5404264E-05,   3.6149839E-05,   3.6881116E-05
     +,   3.7598038E-05,   3.8300543E-05,   3.8988775E-05
     +,   3.9662988E-05,   4.0323517E-05,   4.0970815E-05
     +,   4.1605417E-05,   4.2227941E-05,   4.2839067E-05
     +,   4.3439519E-05,   4.4030072E-05,   4.4611559E-05
     +,   4.5184741E-05,   4.5750498E-05,   4.6309571E-05
     +,   4.6862795E-05,   4.7410897E-05,   4.7954622E-05
     +,   4.8494625E-05,   4.9031569E-05,   4.9565992E-05
     +,   5.0098475E-05,   5.0629536E-05,   5.1159626E-05
     +,   5.1689171E-05,   5.2218656E-05,   5.2748546E-05
     +,   5.3279320E-05,   5.3811578E-05,   5.4345910E-05
     +,   5.4883159E-05,   5.5424218E-05,   5.5970264E-05
     +,   5.6522673E-05,   5.7083136E-05,   5.7653651E-05
     +,   5.8236659E-05,   5.8835005E-05,   5.9452021E-05
     +,   6.0091574E-05,   6.0758113E-05,   6.1456791E-05
     +,   6.2193285E-05,   6.2974083E-05,   6.3806307E-05
     +,   6.4697851E-05,   6.5657245E-05,   6.6693821E-05
     +,   6.7817433E-05,   6.9038659E-05,   7.0368398E-05
     +,   7.1818125E-05,   7.3399533E-05,   7.5124379E-05
     +,   7.7004283E-05,   7.9050733E-05,   8.1274724E-05
     +,   8.3686275E-05,   8.6294647E-05,   8.9107576E-05
     +,   9.2131464E-05,   9.5370553E-05,   9.8827324E-05
     +,   1.0250145E-04,   1.0639046E-04,   1.1048863E-04
     +,   1.1478757E-04,   1.1927601E-04,   1.2393919E-04
     +,   1.2875930E-04,   1.3371596E-04,   1.3878607E-04
     +,   1.4394349E-04,   1.4916067E-04,   1.5440764E-04
     +,   1.5965394E-04,   1.6486792E-04,   1.7001848E-04
     +,   1.7507465E-04,   1.8000760E-04,   1.8478997E-04
     +,   1.8939778E-04,   1.9381092E-04,   1.9801315E-04
     +,   2.0199337E-04,   2.0574649E-04,   2.0927333E-04
     +,   2.1258120E-04,   2.1568414E-04,   2.1860338E-04
     +,   2.2136685E-04,   2.2400932E-04,   2.2657201E-04
     +,   2.2910204E-04,   2.3165143E-04,   2.3427671E-04
     +,   2.3703782E-04,   2.3999669E-04,   2.4321587E-04
     +,   2.4675729E-04,   2.5068075E-04,   2.5504272E-04
     +,   2.5989403E-04,   2.6527917E-04,   2.7123545E-04
     +,   2.7779248E-04,   2.8497103E-04,   2.9278515E-04
     +,   3.0124353E-04,   3.1035126E-04,   3.2011460E-04
     +,   3.3054661E-04,   3.4167283E-04,   3.5353744E-04
     +,   3.6621114E-04,   3.7979890E-04,   3.9444416E-04
     +,   4.1033092E-04,   4.2768350E-04,   4.4676173E-04
     +,   4.6785016E-04,   4.9123971E-04,   5.1721174E-04
     +,   5.4601417E-04,   5.7783566E-04,   6.1278627E-04
     +,   6.5088394E-04,   6.9204438E-04,   7.3608308E-04
     +,   7.8273757E-04,   8.3171070E-04,   8.8273035E-04
     +,   9.3563227E-04,   9.9045993E-04,   1.0475662E-03
     +,   1.1076876E-03,   1.1719867E-03,   1.2420944E-03
     +,   1.3201257E-03,   1.4087000E-03,   1.5109071E-03
     +,   1.6301047E-03,   1.7694603E-03,   1.9314556E-03
     +,   2.1180210E-03,   2.3321048E-03,   2.5806625E-03
     +,   2.8770163E-03,   3.2386358E-03,   3.6771544E-03
     +,   4.1831662E-03,   4.7172522E-03,   5.2238572E-03
     +,   5.6763836E-03,   6.1350209E-03,   6.7626010E-03
     +,   7.7431286E-03,   9.1349436E-03,   1.0811018E-02
     +,   1.2598039E-02,   1.4480384E-02,   1.6620662E-02
     +,   1.9163378E-02,   2.2028780E-02,   2.4944359E-02
     +,   2.7648762E-02,   2.9727146E-02,   3.0155085E-02
     +,   2.7697673E-02,   2.2229260E-02,   1.5278840E-02
     +,   8.9828074E-03,   4.6450133E-03,   2.2882805E-03
     +,   1.2274761E-03,   7.8628358E-04,   5.8187830E-04
     +,   4.6261406E-04,   3.7942492E-04,   3.1497891E-04
     +,   2.6139247E-04,   2.1514724E-04,   1.7508359E-04
     +,   1.4095461E-04,   1.1260450E-04,   8.9676840E-05
     +,   7.1594281E-05,   5.7635421E-05,   4.7031011E-05
     +,   3.9048686E-05,   3.3051540E-05,   2.8524255E-05
     +,   2.5070582E-05,   2.2394399E-05,   2.0276761E-05
     +,   1.8555953E-05,   1.7112659E-05,   1.5859450E-05
     +,   1.4733931E-05,   1.3693470E-05,   1.2710654E-05
     +,   1.1769386E-05,   1.0861617E-05,   9.9846902E-06
     +,   9.1391748E-06,   8.3273017E-06,   7.5519629E-06
     +,   6.8161062E-06,   6.1222813E-06,   5.4723923E-06
     +,   4.8676511E-06,   4.3086397E-06,   3.7952113E-06
     +,   3.3266256E-06,   2.9016528E-06,   2.5186184E-06
     +,   2.1754681E-06,   1.8698826E-06,   1.5993709E-06
     +,   1.3613179E-06,   1.1530371E-06,   9.7184716E-07
     +,   8.1513286E-07,   6.8034552E-07,   5.6507565E-07
     +,   4.6704025E-07,   3.8412981E-07,   3.1439254E-07
     +,   2.5606045E-07,   2.0753116E-07,   1.6737877E-07
     +,   1.3433450E-07,   1.0728804E-07,   8.5268425E-08
     +,   6.7436567E-08,   5.3073684E-08,   4.1565468E-08
     +,   3.2393888E-08,   2.5122516E-08,   1.9388327E-08
     +,   1.4889724E-08,   1.1379170E-08,   8.6537355E-09
     +,   6.5489867E-09,   4.9318927E-09,   3.6959915E-09
     +,   2.7562390E-09,   2.0454112E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz114 = Yx/0.093975
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0399653E-06,   9.1054644E-06
     +,   9.1767088E-06,   9.2540276E-06,   9.3377384E-06
     +,   9.4281513E-06,   9.5255555E-06,   9.6302329E-06
     +,   9.7424409E-06,   9.8624305E-06,   9.9904300E-06
     +,   1.0126648E-05,   1.0271278E-05,   1.0424496E-05
     +,   1.0586456E-05,   1.0757302E-05,   1.0937151E-05
     +,   1.1126112E-05,   1.1324278E-05,   1.1531723E-05
     +,   1.1748523E-05,   1.1974736E-05,   1.2210410E-05
     +,   1.2455607E-05,   1.2710373E-05,   1.2974768E-05
     +,   1.3248859E-05,   1.3532731E-05,   1.3826485E-05
     +,   1.4130243E-05,   1.4444162E-05,   1.4768443E-05
     +,   1.5103316E-05,   1.5449074E-05,   1.5806054E-05
     +,   1.6174670E-05,   1.6555410E-05,   1.6948819E-05
     +,   1.7355569E-05,   1.7776378E-05,   1.8212106E-05
     +,   1.8663695E-05,   1.9132218E-05,   1.9618850E-05
     +,   2.0124911E-05,   2.0651833E-05,   2.1201195E-05
     +,   2.1774704E-05,   2.2374195E-05,   2.3001645E-05
     +,   2.3659171E-05,   2.4349003E-05,   2.5073483E-05
     +,   2.5835119E-05,   2.6636411E-05,   2.7480075E-05
     +,   2.8368795E-05,   2.9305358E-05,   3.0292556E-05
     +,   3.1333195E-05,   3.2430045E-05,   3.3585846E-05
     +,   3.4803164E-05,   3.6084541E-05,   3.7432364E-05
     +,   3.8848681E-05,   4.0335482E-05,   4.1894280E-05
     +,   4.3526474E-05,   4.5232890E-05,   4.7014171E-05
     +,   4.8870297E-05,   5.0801031E-05,   5.2805375E-05
     +,   5.4882032E-05,   5.7029196E-05,   5.9244328E-05
     +,   6.1524435E-05,   6.3866086E-05,   6.6265413E-05
     +,   6.8717789E-05,   7.1218528E-05,   7.3762239E-05
     +,   7.6343531E-05,   7.8956487E-05,   8.1595375E-05
     +,   8.4254083E-05,   8.6926928E-05,   8.9608002E-05
     +,   9.2291979E-05,   9.4973962E-05,   9.7649390E-05
     +,   1.0031430E-04,   1.0296575E-04,   1.0560155E-04
     +,   1.0822028E-04,   1.1082182E-04,   1.1340679E-04
     +,   1.1597723E-04,   1.1853592E-04,   1.2108709E-04
     +,   1.2363569E-04,   1.2618782E-04,   1.2875012E-04
     +,   1.3133015E-04,   1.3393593E-04,   1.3657566E-04
     +,   1.3925749E-04,   1.4198957E-04,   1.4477959E-04
     +,   1.4763421E-04,   1.5055956E-04,   1.5355993E-04
     +,   1.5663868E-04,   1.5979691E-04,   1.6303440E-04
     +,   1.6634847E-04,   1.6973483E-04,   1.7318664E-04
     +,   1.7669560E-04,   1.8025146E-04,   1.8384245E-04
     +,   1.8745540E-04,   1.9107664E-04,   1.9469234E-04
     +,   1.9828847E-04,   2.0185228E-04,   2.0537218E-04
     +,   2.0883924E-04,   2.1224687E-04,   2.1559220E-04
     +,   2.1887614E-04,   2.2210453E-04,   2.2528775E-04
     +,   2.2844147E-04,   2.3158680E-04,   2.3474978E-04
     +,   2.3796133E-04,   2.4125712E-04,   2.4467651E-04
     +,   2.4826164E-04,   2.5205617E-04,   2.5610492E-04
     +,   2.6045163E-04,   2.6513738E-04,   2.7019999E-04
     +,   2.7567198E-04,   2.8157909E-04,   2.8793977E-04
     +,   2.9476444E-04,   3.0205568E-04,   3.0980774E-04
     +,   3.1800848E-04,   3.2664178E-04,   3.3568987E-04
     +,   3.4513645E-04,   3.5497147E-04,   3.6519638E-04
     +,   3.7582856E-04,   3.8690551E-04,   3.9849064E-04
     +,   4.1067548E-04,   4.2358096E-04,   4.3735566E-04
     +,   4.5217518E-04,   4.6823270E-04,   4.8572911E-04
     +,   5.0485949E-04,   5.2579877E-04,   5.4868427E-04
     +,   5.7359674E-04,   6.0054864E-04,   6.2948029E-04
     +,   6.6026190E-04,   6.9270865E-04,   7.2662032E-04
     +,   7.6182879E-04,   7.9826184E-04,   8.3601213E-04
     +,   8.7540853E-04,   9.1705128E-04,   9.6180732E-04
     +,   1.0107466E-03,   1.0650037E-03,   1.1255640E-03
     +,   1.1930086E-03,   1.2672766E-03,   1.3475325E-03
     +,   1.4322079E-03,   1.5192913E-03,   1.6069259E-03
     +,   1.6941762E-03,   1.7818481E-03,   1.8731303E-03
     +,   1.9738248E-03,   2.0920467E-03,   2.2374294E-03
     +,   2.4200466E-03,   2.6492216E-03,   2.9323320E-03
     +,   3.2738324E-03,   3.6750906E-03,   4.1358694E-03
     +,   4.6573989E-03,   5.2449596E-03,   5.9058317E-03
     +,   6.6388650E-03,   7.4196202E-03,   8.1978552E-03
     +,   8.9297378E-03,   9.6441926E-03,   1.0488725E-02
     +,   1.1675983E-02,   1.3333036E-02,   1.5386268E-02
     +,   1.7602274E-02,   1.9709857E-02,   2.1421069E-02
     +,   2.2350149E-02,   2.2043480E-02,   2.0222794E-02
     +,   1.7043348E-02,   1.3101101E-02,   9.1657629E-03
     +,   5.8537466E-03,   3.4511390E-03,   1.9317840E-03
     +,   1.0883091E-03,   6.7218422E-04,   4.8163874E-04
     +,   3.8894595E-04,   3.2929613E-04,   2.7734487E-04
     +,   2.2710362E-04,   1.7967728E-04,   1.3741598E-04
     +,   1.0184409E-04,   7.3337076E-05,   5.1415998E-05
     +,   3.5143647E-05,   2.3435619E-05,   1.5249752E-05
     +,   9.6797767E-06,   5.9886943E-06,   3.6069230E-06
     +,   2.1117305E-06,   1.1998493E-06,   6.6049301E-07
     +,   3.5170061E-07,   1.8090897E-07,   8.9788841E-08
     +,   4.2958849E-08,   1.9799748E-08,   8.7868717E-09
     +,   3.7532906E-09,   1.5427066E-09,   6.1011701E-10
     +,   2.3218573E-10,   8.5049509E-11,   3.0012798E-11
     +,   1.0229039E-11,   3.3897312E-12,   1.1116340E-12
     +,   3.7702236E-13,   1.4467393E-13,   7.0012050E-14
     +,   4.3590731E-14,   3.1948575E-14,   2.5166621E-14
     +,   2.0333736E-14,   1.6553418E-14,   1.3497821E-14
     +,   1.1003919E-14,   8.9639777E-15,   7.2954372E-15
     +,   5.9318158E-15,   4.8183520E-15,   3.9100976E-15
     +,   3.1699166E-15,   2.5673518E-15,   2.0772769E-15
     +,   1.6791084E-15,   1.3559188E-15,   1.0938678E-15
     +,   8.8158654E-16,   7.0980916E-16,   5.7094076E-16
     +,   4.5878454E-16,   3.6830017E-16,   2.9536857E-16
     +,   2.3664788E-16,   1.8941267E-16,   1.5145754E-16
     +,   1.2098771E-16,   9.6553266E-17,   7.6977150E-17
     +,   6.1309787E-17,   4.8782970E-17,   3.8777562E-17
     +,   3.0793635E-17,   2.4429661E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz115 = Yx/0.0838205128205128
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1157464E-06,   1.1903622E-06
     +,   1.2690577E-06,   1.3519912E-06,   1.4393225E-06
     +,   1.5312133E-06,   1.6278276E-06,   1.7293298E-06
     +,   1.8358850E-06,   1.9476640E-06,   2.0648329E-06
     +,   2.1875612E-06,   2.3160189E-06,   2.4503756E-06
     +,   2.5908016E-06,   2.7374695E-06,   2.8905495E-06
     +,   3.0502140E-06,   3.2166361E-06,   3.3899878E-06
     +,   3.5704438E-06,   3.7581797E-06,   3.9533697E-06
     +,   4.1562043E-06,   4.3668497E-06,   4.5855031E-06
     +,   4.8123516E-06,   5.0475910E-06,   5.2914211E-06
     +,   5.5440519E-06,   5.8057017E-06,   6.0765956E-06
     +,   6.3569746E-06,   6.6470893E-06,   6.9472057E-06
     +,   7.2576095E-06,   7.5785988E-06,   7.9104875E-06
     +,   8.2536399E-06,   8.6083965E-06,   8.9751666E-06
     +,   9.3543667E-06,   9.7464463E-06,   1.0151886E-05
     +,   1.0571204E-05,   1.1004949E-05,   1.1453705E-05
     +,   1.1918107E-05,   1.2398816E-05,   1.2896547E-05
     +,   1.3412054E-05,   1.3946134E-05,   1.4499634E-05
     +,   1.5073468E-05,   1.5668560E-05,   1.6285938E-05
     +,   1.6926653E-05,   1.7591825E-05,   1.8282635E-05
     +,   1.9000336E-05,   1.9746250E-05,   2.0521782E-05
     +,   2.1328384E-05,   2.2167642E-05,   2.3041266E-05
     +,   2.3950977E-05,   2.4898729E-05,   2.5886508E-05
     +,   2.6916541E-05,   2.7991116E-05,   2.9112845E-05
     +,   3.0284373E-05,   3.1508738E-05,   3.2789078E-05
     +,   3.4128901E-05,   3.5532052E-05,   3.7002599E-05
     +,   3.8544971E-05,   4.0164086E-05,   4.1865293E-05
     +,   4.3654207E-05,   4.5537148E-05,   4.7520680E-05
     +,   4.9612150E-05,   5.1819105E-05,   5.4149932E-05
     +,   5.6613189E-05,   5.9218237E-05,   6.1974519E-05
     +,   6.4892120E-05,   6.7981462E-05,   7.1252893E-05
     +,   7.4716896E-05,   7.8384015E-05,   8.2264633E-05
     +,   8.6368193E-05,   9.0704074E-05,   9.5280062E-05
     +,   1.0010332E-04,   1.0517882E-04,   1.1051034E-04
     +,   1.1609871E-04,   1.2194297E-04,   1.2803834E-04
     +,   1.3437755E-04,   1.4094952E-04,   1.4773899E-04
     +,   1.5472645E-04,   1.6188844E-04,   1.6919702E-04
     +,   1.7661904E-04,   1.8411754E-04,   1.9165040E-04
     +,   1.9917219E-04,   2.0663271E-04,   2.1397954E-04
     +,   2.2115657E-04,   2.2810684E-04,   2.3477129E-04
     +,   2.4109184E-04,   2.4701105E-04,   2.5247375E-04
     +,   2.5742795E-04,   2.6182667E-04,   2.6562883E-04
     +,   2.6879981E-04,   2.7131342E-04,   2.7315199E-04
     +,   2.7430782E-04,   2.7478303E-04,   2.7459048E-04
     +,   2.7375348E-04,   2.7230571E-04,   2.7029112E-04
     +,   2.6776307E-04,   2.6478351E-04,   2.6142251E-04
     +,   2.5775708E-04,   2.5386986E-04,   2.4984824E-04
     +,   2.4578426E-04,   2.4177320E-04,   2.3791303E-04
     +,   2.3430465E-04,   2.3105231E-04,   2.2826342E-04
     +,   2.2604965E-04,   2.2452779E-04,   2.2382084E-04
     +,   2.2405805E-04,   2.2537632E-04,   2.2791927E-04
     +,   2.3183579E-04,   2.3727809E-04,   2.4439799E-04
     +,   2.5334029E-04,   2.6423615E-04,   2.7719571E-04
     +,   2.9229809E-04,   3.0958079E-04,   3.2903437E-04
     +,   3.5059566E-04,   3.7414534E-04,   3.9951314E-04
     +,   4.2649198E-04,   4.5485736E-04,   4.8439490E-04
     +,   5.1493902E-04,   5.4641732E-04,   5.7889294E-04
     +,   6.1260053E-04,   6.4797612E-04,   6.8566570E-04
     +,   7.2650751E-04,   7.7147729E-04,   8.2161650E-04
     +,   8.7791990E-04,   9.4120379E-04,   1.0119800E-03
     +,   1.0903509E-03,   1.1759424E-03,   1.2679076E-03
     +,   1.3650230E-03,   1.4658630E-03,   1.5690022E-03
     +,   1.6731826E-03,   1.7774036E-03,   1.8808623E-03
     +,   1.9827576E-03,   2.0820736E-03,   2.1775533E-03
     +,   2.2679926E-03,   2.3529874E-03,   2.4340386E-03
     +,   2.5156385E-03,   2.6057535E-03,   2.7151965E-03
     +,   2.8558294E-03,   3.0381673E-03,   3.2694228E-03
     +,   3.5525979E-03,   3.8862317E-03,   4.2639473E-03
     +,   4.6743359E-03,   5.1041720E-03,   5.5476576E-03
     +,   6.0184365E-03,   6.5548709E-03,   7.2108507E-03
     +,   8.0356495E-03,   9.0547726E-03,   1.0257938E-02
     +,   1.1591226E-02,   1.2957556E-02,   1.4247302E-02
     +,   1.5403329E-02,   1.6460612E-02,   1.7466743E-02
     +,   1.8295806E-02,   1.8547799E-02,   1.7727356E-02
     +,   1.5616908E-02,   1.2509648E-02,   9.0796445E-03
     +,   6.0158982E-03,   3.7217548E-03,   2.2483722E-03
     +,   1.4152779E-03,   9.7813504E-04,   7.4055576E-04
     +,   5.8715185E-04,   4.6708979E-04,   3.6485039E-04
     +,   2.7836848E-04,   2.0815396E-04,   1.5370174E-04
     +,   1.1319065E-04,   8.4099425E-05,   6.3810272E-05
     +,   4.9974176E-05,   4.0661747E-05,   3.4380893E-05
     +,   3.0033423E-05,   2.6851116E-05,   2.4327584E-05
     +,   2.2152548E-05,   2.0153280E-05,   1.8246681E-05
     +,   1.6403410E-05,   1.4623127E-05,   1.2918353E-05
     +,   1.1305416E-05,   9.7996626E-06,   8.4130234E-06
     +,   7.1530981E-06,   6.0232319E-06,   5.0229451E-06
     +,   4.1484195E-06,   3.3931226E-06,   2.7485639E-06
     +,   2.2049785E-06,   1.7518566E-06,   1.3784312E-06
     +,   1.0741396E-06,   8.2895752E-07,   6.3357237E-07
     +,   4.7956621E-07,   3.5949535E-07,   2.6689142E-07
     +,   1.9623134E-07,   1.4288615E-07,   1.0303960E-07
     +,   7.3589426E-08,   5.2049799E-08,   3.6459429E-08
     +,   2.5292907E-08,   1.7376998E-08,   1.1823572E-08
     +,   7.9672704E-09,   5.3170242E-09,   3.5141057E-09
     +,   2.3001712E-09,   1.4910509E-09,   9.5724828E-10
     +,   6.0861671E-10,   3.8323422E-10,   2.3899019E-10
     +,   1.4759979E-10,   9.0280984E-11,   5.4689139E-11
     +,   3.2810810E-11,   1.9495542E-11,   1.1473072E-11
     +,   6.6872419E-12,   3.8607368E-12,   2.2078157E-12
     +,   1.2507867E-12,   7.0207105E-13,   3.9055068E-13
     +,   2.1538411E-13,   1.1783092E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz116 = Yx/0.080051282051282
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3923146E-06,   4.6824284E-06
     +,   4.9861796E-06,   5.3038016E-06,   5.6355043E-06
     +,   5.9814756E-06,   6.3418788E-06,   6.7168544E-06
     +,   7.1065106E-06,   7.5109524E-06,   7.9302417E-06
     +,   8.3644200E-06,   8.8135112E-06,   9.2775126E-06
     +,   9.7564052E-06,   1.0250146E-05,   1.0758682E-05
     +,   1.1281941E-05,   1.1819835E-05,   1.2372274E-05
     +,   1.2939156E-05,   1.3520374E-05,   1.4115810E-05
     +,   1.4725389E-05,   1.5348967E-05,   1.5986483E-05
     +,   1.6637840E-05,   1.7302969E-05,   1.7981818E-05
     +,   1.8674349E-05,   1.9380557E-05,   2.0100450E-05
     +,   2.0834063E-05,   2.1581478E-05,   2.2342787E-05
     +,   2.3118128E-05,   2.3907673E-05,   2.4711626E-05
     +,   2.5530273E-05,   2.6363869E-05,   2.7212798E-05
     +,   2.8077451E-05,   2.8958295E-05,   2.9855848E-05
     +,   3.0770731E-05,   3.1703610E-05,   3.2655284E-05
     +,   3.3626638E-05,   3.4618675E-05,   3.5632554E-05
     +,   3.6669593E-05,   3.7731275E-05,   3.8819293E-05
     +,   3.9935632E-05,   4.1082410E-05,   4.2262163E-05
     +,   4.3477674E-05,   4.4732078E-05,   4.6028908E-05
     +,   4.7372079E-05,   4.8765927E-05,   5.0215262E-05
     +,   5.1725234E-05,   5.3301581E-05,   5.4950440E-05
     +,   5.6678273E-05,   5.8492082E-05,   6.0399034E-05
     +,   6.2406718E-05,   6.4522712E-05,   6.6754910E-05
     +,   6.9110843E-05,   7.1598144E-05,   7.4223753E-05
     +,   7.6994285E-05,   7.9915611E-05,   8.2992403E-05
     +,   8.6228138E-05,   8.9625049E-05,   9.3183713E-05
     +,   9.6902433E-05,   1.0077790E-04,   1.0480402E-04
     +,   1.0897273E-04,   1.1327281E-04,   1.1769096E-04
     +,   1.2221053E-04,   1.2681277E-04,   1.3147571E-04
     +,   1.3617525E-04,   1.4088512E-04,   1.4557666E-04
     +,   1.5021949E-04,   1.5478232E-04,   1.5923299E-04
     +,   1.6353857E-04,   1.6766705E-04,   1.7158646E-04
     +,   1.7526702E-04,   1.7868032E-04,   1.8180108E-04
     +,   1.8460683E-04,   1.8707917E-04,   1.8920365E-04
     +,   1.9097059E-04,   1.9237536E-04,   1.9341857E-04
     +,   1.9410602E-04,   1.9444930E-04,   1.9446529E-04
     +,   1.9417622E-04,   1.9360938E-04,   1.9279674E-04
     +,   1.9177461E-04,   1.9058317E-04,   1.8926566E-04
     +,   1.8786808E-04,   1.8643825E-04,   1.8502529E-04
     +,   1.8367889E-04,   1.8244865E-04,   1.8138341E-04
     +,   1.8053071E-04,   1.7993609E-04,   1.7964296E-04
     +,   1.7969192E-04,   1.8012073E-04,   1.8096383E-04
     +,   1.8225297E-04,   1.8401627E-04,   1.8627934E-04
     +,   1.8906454E-04,   1.9239233E-04,   1.9628021E-04
     +,   2.0074430E-04,   2.0579883E-04,   2.1145624E-04
     +,   2.1772718E-04,   2.2462096E-04,   2.3214487E-04
     +,   2.4030321E-04,   2.4909689E-04,   2.5852333E-04
     +,   2.6857501E-04,   2.7923749E-04,   2.9049002E-04
     +,   3.0230419E-04,   3.1464201E-04,   3.2745651E-04
     +,   3.4069218E-04,   3.5428494E-04,   3.6816238E-04
     +,   3.8224587E-04,   3.9645444E-04,   4.1070711E-04
     +,   4.2492501E-04,   4.3903748E-04,   4.5298680E-04
     +,   4.6673312E-04,   4.8025660E-04,   4.9356435E-04
     +,   5.0669123E-04,   5.1969988E-04,   5.3268066E-04
     +,   5.4574991E-04,   5.5904349E-04,   5.7271094E-04
     +,   5.8691157E-04,   6.0181238E-04,   6.1758881E-04
     +,   6.3443172E-04,   6.5256126E-04,   6.7225186E-04
     +,   6.9385429E-04,   7.1782159E-04,   7.4473082E-04
     +,   7.7528949E-04,   8.1032346E-04,   8.5075345E-04
     +,   8.9756527E-04,   9.5178251E-04,   1.0144706E-03
     +,   1.0867800E-03,   1.1700290E-03,   1.2657782E-03
     +,   1.3758388E-03,   1.5021544E-03,   1.6465287E-03
     +,   1.8101624E-03,   1.9931260E-03,   2.1939657E-03
     +,   2.4094905E-03,   2.6348890E-03,   2.8641711E-03
     +,   3.0908771E-03,   3.3089446E-03,   3.5138261E-03
     +,   3.7038899E-03,   3.8820156E-03,   4.0569887E-03
     +,   4.2441981E-03,   4.4647316E-03,   4.7421139E-03
     +,   5.0962442E-03,   5.5355332E-03,   6.0502971E-03
     +,   6.6116829E-03,   7.1797841E-03,   7.7203480E-03
     +,   8.2232412E-03,   8.7120179E-03,   9.2362901E-03
     +,   9.8472517E-03,   1.0566659E-02,   1.1364693E-02
     +,   1.2156815E-02,   1.2818950E-02,   1.3211247E-02
     +,   1.3203000E-02,   1.2699616E-02,   1.1672799E-02
     +,   1.0185591E-02,   8.3950227E-03,   6.5196645E-03
     +,   4.7802227E-03,   3.3395768E-03,   2.2691640E-03
     +,   1.5524369E-03,   1.1161786E-03,   8.6933473E-04
     +,   7.3201541E-04,   6.4833130E-04,   5.8616139E-04
     +,   5.3054193E-04,   4.7631661E-04,   4.2276978E-04
     +,   3.7066764E-04,   3.2100637E-04,   2.7463684E-04
     +,   2.3221273E-04,   1.9419687E-04,   1.6084935E-04
     +,   1.3220654E-04,   1.0808340E-04,   8.8112101E-05
     +,   7.1802497E-05,   5.8607489E-05,   4.7981972E-05
     +,   3.9427017E-05,   3.2514265E-05,   2.6892172E-05
     +,   2.2283442E-05,   1.8475326E-05,   1.5306849E-05
     +,   1.2656659E-05,   1.0432879E-05,   8.5649453E-06
     +,   6.9972534E-06,   5.6847298E-06,   4.5900083E-06
     +,   3.6814772E-06,   2.9318951E-06,   2.3175085E-06
     +,   1.8175576E-06,   1.4139134E-06,   1.0906961E-06
     +,   8.3410896E-07,   6.3225468E-07,   4.7493782E-07
     +,   3.5349589E-07,   2.6065950E-07,   1.9039717E-07
     +,   1.3775571E-07,   9.8715262E-08,   7.0057304E-08
     +,   4.9238608E-08,   3.4270077E-08,   2.3619922E-08
     +,   1.6120394E-08,   1.0894563E-08,   7.2906192E-09
     +,   4.8310973E-09,   3.1698586E-09,   2.0594706E-09
     +,   1.3248879E-09,   8.4396146E-10,   5.3232646E-10
     +,   3.3245906E-10,   2.0559679E-10,   1.2589209E-10
     +,   7.6330393E-11,   4.5824768E-11,   2.7240819E-11
     +,   1.6034063E-11,   9.3451037E-12,   5.3929600E-12
     +,   3.0816868E-12,   1.7436207E-12,   9.7686323E-13
     +,   5.4189747E-13,   2.9765895E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz118 = Yx/0.0720263157894737
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6810212E-06,   2.8206045E-06
     +,   2.9662524E-06,   3.1181896E-06,   3.2766529E-06
     +,   3.4418854E-06,   3.6141419E-06,   3.7936861E-06
     +,   3.9807915E-06,   4.1757512E-06,   4.3788577E-06
     +,   4.5904249E-06,   4.8107740E-06,   5.0402418E-06
     +,   5.2791756E-06,   5.5279393E-06,   5.7869106E-06
     +,   6.0564780E-06,   6.3370480E-06,   6.6290409E-06
     +,   6.9328885E-06,   7.2490425E-06,   7.5779599E-06
     +,   7.9201363E-06,   8.2760434E-06,   8.6462069E-06
     +,   9.0311432E-06,   9.4313928E-06,   9.8475039E-06
     +,   1.0280043E-05,   1.0729593E-05,   1.1196745E-05
     +,   1.1682107E-05,   1.2186304E-05,   1.2709966E-05
     +,   1.3253745E-05,   1.3818303E-05,   1.4404304E-05
     +,   1.5012474E-05,   1.5643471E-05,   1.6298052E-05
     +,   1.6976943E-05,   1.7680901E-05,   1.8410690E-05
     +,   1.9167112E-05,   1.9950976E-05,   2.0763118E-05
     +,   2.1604399E-05,   2.2475700E-05,   2.3377936E-05
     +,   2.4312048E-05,   2.5279000E-05,   2.6279784E-05
     +,   2.7315469E-05,   2.8387054E-05,   2.9495686E-05
     +,   3.0642455E-05,   3.1828520E-05,   3.3055032E-05
     +,   3.4323188E-05,   3.5634162E-05,   3.6989175E-05
     +,   3.8389331E-05,   3.9835850E-05,   4.1329880E-05
     +,   4.2872387E-05,   4.4464461E-05,   4.6106878E-05
     +,   4.7800517E-05,   4.9545873E-05,   5.1343501E-05
     +,   5.3193486E-05,   5.5095952E-05,   5.7050464E-05
     +,   5.9056489E-05,   6.1113147E-05,   6.3219064E-05
     +,   6.5372456E-05,   6.7571251E-05,   6.9812966E-05
     +,   7.2094444E-05,   7.4412361E-05,   7.6762677E-05
     +,   7.9141231E-05,   8.1543214E-05,   8.3963758E-05
     +,   8.6397522E-05,   8.8839275E-05,   9.1283538E-05
     +,   9.3725153E-05,   9.6159332E-05,   9.8581673E-05
     +,   1.0098849E-04,   1.0337740E-04,   1.0574723E-04
     +,   1.0809835E-04,   1.1043331E-04,   1.1275676E-04
     +,   1.1507628E-04,   1.1740215E-04,   1.1974833E-04
     +,   1.2213195E-04,   1.2457439E-04,   1.2710052E-04
     +,   1.2973956E-04,   1.3252463E-04,   1.3549242E-04
     +,   1.3868304E-04,   1.4213960E-04,   1.4590769E-04
     +,   1.5003372E-04,   1.5456529E-04,   1.5954858E-04
     +,   1.6502863E-04,   1.7104647E-04,   1.7763936E-04
     +,   1.8483777E-04,   1.9266606E-04,   2.0113915E-04
     +,   2.1026346E-04,   2.2003577E-04,   2.3044180E-04
     +,   2.4145680E-04,   2.5304675E-04,   2.6516832E-04
     +,   2.7776838E-04,   2.9078827E-04,   3.0416236E-04
     +,   3.1782250E-04,   3.3169656E-04,   3.4571358E-04
     +,   3.5980192E-04,   3.7389426E-04,   3.8792440E-04
     +,   4.0183158E-04,   4.1555922E-04,   4.2905382E-04
     +,   4.4226527E-04,   4.5514686E-04,   4.6765307E-04
     +,   4.7973837E-04,   4.9135613E-04,   5.0245877E-04
     +,   5.1299727E-04,   5.2291894E-04,   5.3217035E-04
     +,   5.4069789E-04,   5.4844836E-04,   5.5537169E-04
     +,   5.6142465E-04,   5.6657137E-04,   5.7078816E-04
     +,   5.7406584E-04,   5.7641207E-04,   5.7785498E-04
     +,   5.7844428E-04,   5.7825632E-04,   5.7739584E-04
     +,   5.7600089E-04,   5.7424791E-04,   5.7235855E-04
     +,   5.7060708E-04,   5.6932983E-04,   5.6893297E-04
     +,   5.6990056E-04,   5.7279604E-04,   5.7826069E-04
     +,   5.8699911E-04,   5.9975678E-04,   6.1728148E-04
     +,   6.4026943E-04,   6.6930358E-04,   7.0478593E-04
     +,   7.4687024E-04,   7.9540320E-04,   8.4990263E-04
     +,   9.0955826E-04,   9.7327039E-04,   1.0397334E-03
     +,   1.1075553E-03,   1.1753840E-03,   1.2420377E-03
     +,   1.3066313E-03,   1.3686706E-03,   1.4281070E-03
     +,   1.4853551E-03,   1.5413059E-03,   1.5973520E-03
     +,   1.6554474E-03,   1.7182372E-03,   1.7892142E-03
     +,   1.8727687E-03,   1.9739445E-03,   2.0977308E-03
     +,   2.2478458E-03,   2.4252452E-03,   2.6268754E-03
     +,   2.8453439E-03,   3.0700476E-03,   3.2897484E-03
     +,   3.4963712E-03,   3.6891005E-03,   3.8775103E-03
     +,   4.0819435E-03,   4.3295077E-03,   4.6455231E-03
     +,   5.0429199E-03,   5.5148266E-03,   6.0356245E-03
     +,   6.5714847E-03,   7.0948326E-03,   7.5937058E-03
     +,   8.0692330E-03,   8.5217198E-03,   8.9335544E-03
     +,   9.2598815E-03,   9.4338302E-03,   9.3850633E-03
     +,   9.0636127E-03,   8.4584551E-03,   7.6034828E-03
     +,   6.5702270E-03,   5.4515651E-03,   4.3425732E-03
     +,   3.3238982E-03,   2.4510461E-03,   1.7504410E-03
     +,   1.2217703E-03,   8.4506947E-04,   5.8989599E-04
     +,   4.2377171E-04,   3.1804913E-04,   2.5071035E-04
     +,   2.0662555E-04,   1.7631819E-04,   1.5426084E-04
     +,   1.3736825E-04,   1.2392053E-04,   1.1291124E-04
     +,   1.0370262E-04,   9.5860261E-05,   8.9074609E-05
     +,   8.3118779E-05,   7.7822326E-05,   7.3053983E-05
     +,   6.8710324E-05,   6.4708576E-05,   6.0982951E-05
     +,   5.7482979E-05,   5.4172178E-05,   5.1025403E-05
     +,   4.8026726E-05,   4.5166955E-05,   4.2440832E-05
     +,   3.9844796E-05,   3.7375587E-05,   3.5029556E-05
     +,   3.2802054E-05,   3.0687414E-05,   2.8679307E-05
     +,   2.6771315E-05,   2.4957160E-05,   2.3230928E-05
     +,   2.1587435E-05,   2.0022511E-05,   1.8532681E-05
     +,   1.7115302E-05,   1.5768517E-05,   1.4491004E-05
     +,   1.3281739E-05,   1.2139923E-05,   1.1064901E-05
     +,   1.0055958E-05,   9.1121583E-06,   8.2323595E-06
     +,   7.4152395E-06,   6.6590883E-06,   5.9620211E-06
     +,   5.3217968E-06,   4.7360331E-06,   4.2020711E-06
     +,   3.7171753E-06,   3.2784330E-06,   2.8829265E-06
     +,   2.5276590E-06,   2.2096933E-06,   1.9261049E-06
     +,   1.6740469E-06,   1.4507954E-06,   1.2537138E-06
     +,   1.0803267E-06,   9.2827884E-07,   7.9538694E-07
     +,   6.7960445E-07,   5.7905669E-07,   4.9200861E-07
     +,   4.1688841E-07,   3.5225816E-07,   2.9682752E-07
     +,   2.4942869E-07,   2.0902336E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz120 = Yx/0.0579444444444445
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9551948E-05,   1.9734780E-05
     +,   1.9907457E-05,   2.0069705E-05,   2.0221254E-05
     +,   2.0361855E-05,   2.0491272E-05,   2.0609292E-05
     +,   2.0715715E-05,   2.0810361E-05,   2.0893072E-05
     +,   2.0963704E-05,   2.1022133E-05,   2.1068263E-05
     +,   2.1102007E-05,   2.1123307E-05,   2.1132120E-05
     +,   2.1128431E-05,   2.1112237E-05,   2.1083564E-05
     +,   2.1042453E-05,   2.0988975E-05,   2.0923209E-05
     +,   2.0845262E-05,   2.0755269E-05,   2.0653371E-05
     +,   2.0539739E-05,   2.0414562E-05,   2.0278056E-05
     +,   2.0130445E-05,   1.9971978E-05,   1.9802934E-05
     +,   1.9623601E-05,   1.9434296E-05,   1.9235353E-05
     +,   1.9027129E-05,   1.8810009E-05,   1.8584402E-05
     +,   1.8350733E-05,   1.8109484E-05,   1.7861134E-05
     +,   1.7606226E-05,   1.7345328E-05,   1.7079063E-05
     +,   1.6808093E-05,   1.6533149E-05,   1.6255026E-05
     +,   1.5974585E-05,   1.5692785E-05,   1.5410684E-05
     +,   1.5129437E-05,   1.4850350E-05,   1.4574868E-05
     +,   1.4304591E-05,   1.4041342E-05,   1.3787129E-05
     +,   1.3544227E-05,   1.3315184E-05,   1.3102863E-05
     +,   1.2910469E-05,   1.2741606E-05,   1.2600300E-05
     +,   1.2491051E-05,   1.2418865E-05,   1.2389291E-05
     +,   1.2408462E-05,   1.2483109E-05,   1.2620572E-05
     +,   1.2828823E-05,   1.3116401E-05,   1.3492437E-05
     +,   1.3966518E-05,   1.4548709E-05,   1.5249336E-05
     +,   1.6079002E-05,   1.7048475E-05,   1.8168528E-05
     +,   1.9450015E-05,   2.0904055E-05,   2.2542292E-05
     +,   2.4377205E-05,   2.6423373E-05,   2.8698210E-05
     +,   3.1224288E-05,   3.4031065E-05,   3.7158559E-05
     +,   4.0660369E-05,   4.4608998E-05,   4.9100217E-05
     +,   5.4259941E-05,   6.0250502E-05,   6.7277433E-05
     +,   7.5597010E-05,   8.5524596E-05,   9.7442040E-05
     +,   1.1180453E-04,   1.2915286E-04,   1.5012159E-04
     +,   1.7546052E-04,   2.0605313E-04,   2.4295607E-04
     +,   2.8743199E-04,   3.4100175E-04,   4.0546260E-04
     +,   4.8288994E-04,   5.7555019E-04,   6.8569928E-04
     +,   8.1526453E-04,   9.6546655E-04,   1.1365119E-03
     +,   1.3276327E-03,   1.5378167E-03,   1.7671479E-03
     +,   2.0185688E-03,   2.2990622E-03,   2.6197308E-03
     +,   2.9947665E-03,   3.4411934E-03,   3.9807619E-03
     +,   4.6428125E-03,   5.4609808E-03,   6.4566922E-03
     +,   7.6151909E-03,   8.8777663E-03,   1.0171487E-02
     +,   1.1460045E-02,   1.2760276E-02,   1.4086126E-02
     +,   1.5365043E-02,   1.6421365E-02,   1.7067494E-02
     +,   1.7232714E-02,   1.7024711E-02,   1.6672306E-02
     +,   1.6377972E-02,   1.6182041E-02,   1.5953155E-02
     +,   1.5517092E-02,   1.4808081E-02,   1.3917082E-02
     +,   1.3015855E-02,   1.2238448E-02,   1.1623593E-02
     +,   1.1144165E-02,   1.0759204E-02,   1.0431133E-02
     +,   1.0119376E-02,   9.7836703E-03,   9.3983030E-03
     +,   8.9594610E-03,   8.4790988E-03,   7.9726847E-03
     +,   7.4509387E-03,   6.9194306E-03,   6.3830996E-03
     +,   5.8498592E-03,   5.3305570E-03,   4.8368997E-03
     +,   4.3793302E-03,   3.9654267E-03,   3.5984255E-03
     +,   3.2766503E-03,   2.9942582E-03,   2.7432514E-03
     +,   2.5158816E-03,   2.3063431E-03,   2.1112936E-03
     +,   1.9294497E-03,   1.7608701E-03,   1.6063583E-03
     +,   1.4670817E-03,   1.3442951E-03,   1.2390713E-03
     +,   1.1520281E-03,   1.0830746E-03,   1.0312422E-03
     +,   9.9470746E-04,   9.7095955E-04,   9.5707172E-04
     +,   9.5001212E-04,   9.4693253E-04,   9.4537868E-04
     +,   9.4341667E-04,   9.3967206E-04,   9.3330437E-04
     +,   9.2393346E-04,   9.1154425E-04,   8.9638488E-04
     +,   8.7886956E-04,   8.5949904E-04,   8.3878997E-04
     +,   8.1722543E-04,   7.9522363E-04,   7.7311578E-04
     +,   7.5113581E-04,   7.2942540E-04,   7.0804270E-04
     +,   6.8697688E-04,   6.6616322E-04,   6.4550468E-04
     +,   6.2489207E-04,   6.0421816E-04,   5.8339059E-04
     +,   5.6234491E-04,   5.4105057E-04,   5.1951123E-04
     +,   4.9776508E-04,   4.7588203E-04,   4.5395707E-04
     +,   4.3210067E-04,   4.1043275E-04,   3.8907593E-04
     +,   3.6814684E-04,   3.4774953E-04,   3.2797194E-04
     +,   3.0888489E-04,   2.9053877E-04,   2.7296349E-04
     +,   2.5617142E-04,   2.4016012E-04,   2.2491340E-04
     +,   2.1040534E-04,   1.9660489E-04,   1.8347779E-04
     +,   1.7098796E-04,   1.5910115E-04,   1.4778662E-04
     +,   1.3701756E-04,   1.2677089E-04,   1.1702774E-04
     +,   1.0777405E-04,   9.8999000E-05,   9.0693706E-05
     +,   8.2851169E-05,   7.5465963E-05,   6.8532114E-05
     +,   6.2043058E-05,   5.5991615E-05,   5.0369155E-05
     +,   4.5164885E-05,   4.0366325E-05,   3.5959500E-05
     +,   3.1928776E-05,   2.8256733E-05,   2.4924799E-05
     +,   2.1913700E-05,   1.9203471E-05,   1.6773602E-05
     +,   1.4603563E-05,   1.2673215E-05,   1.0962610E-05
     +,   9.4524439E-06,   8.1242833E-06,   6.9605694E-06
     +,   5.9446579E-06,   5.0609792E-06,   4.2951197E-06
     +,   3.6337667E-06,   3.0646640E-06,   2.5766483E-06
     +,   2.1596400E-06,   1.8045502E-06,   1.5032130E-06
     +,   1.2483547E-06,   1.0335500E-06,   8.5310472E-07
     +,   7.0202452E-07,   5.7595366E-07,   4.7110169E-07
     +,   3.8417897E-07,   3.1235186E-07,   2.5319255E-07
     +,   2.0462487E-07,   1.6487857E-07,   1.3245405E-07
     +,   1.0608806E-07,   8.4714948E-08,   6.7445029E-08
     +,   5.3533537E-08,   4.2363357E-08,   3.3421930E-08
     +,   2.6287562E-08,   2.0612612E-08,   1.6113098E-08
     +,   1.2556645E-08,   9.7547064E-09,   7.5542061E-09
     +,   5.8315459E-09,   4.4874100E-09,   3.4419678E-09
     +,   2.6315630E-09,   2.0053870E-09,   1.5231951E-09
     +,   1.1531032E-09,   8.7002505E-10,   6.5422567E-10
     +,   4.9028975E-10,   3.6617440E-10,   2.7254063E-10
     +,   2.0214516E-10,   1.4941121E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz75 = Yx/0.125666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2964210E-06,   3.5091268E-06
     +,   3.7316470E-06,   3.9641400E-06,   4.2067445E-06
     +,   4.4595799E-06,   4.7227431E-06,   4.9963073E-06
     +,   5.2803157E-06,   5.5748010E-06,   5.8797518E-06
     +,   6.1951364E-06,   6.5208897E-06,   6.8569193E-06
     +,   7.2030948E-06,   7.5592648E-06,   7.9252341E-06
     +,   8.3007781E-06,   8.6856389E-06,   9.0795238E-06
     +,   9.4821062E-06,   9.8930232E-06,   1.0311877E-05
     +,   1.0738264E-05,   1.1171694E-05,   1.1611702E-05
     +,   1.2057763E-05,   1.2509334E-05,   1.2965844E-05
     +,   1.3426704E-05,   1.3891302E-05,   1.4359010E-05
     +,   1.4829192E-05,   1.5301199E-05,   1.5774387E-05
     +,   1.6248103E-05,   1.6721711E-05,   1.7194576E-05
     +,   1.7666121E-05,   1.8135743E-05,   1.8602928E-05
     +,   1.9067174E-05,   1.9528052E-05,   1.9985182E-05
     +,   2.0438276E-05,   2.0887117E-05,   2.1331589E-05
     +,   2.1771682E-05,   2.2207501E-05,   2.2639280E-05
     +,   2.3067389E-05,   2.3492343E-05,   2.3914798E-05
     +,   2.4335610E-05,   2.4755749E-05,   2.5176401E-05
     +,   2.5598896E-05,   2.6024749E-05,   2.6455629E-05
     +,   2.6893380E-05,   2.7339986E-05,   2.7797576E-05
     +,   2.8268376E-05,   2.8754734E-05,   2.9259067E-05
     +,   2.9783798E-05,   3.0331417E-05,   3.0904303E-05
     +,   3.1504842E-05,   3.2135231E-05,   3.2797587E-05
     +,   3.3493729E-05,   3.4225337E-05,   3.4993693E-05
     +,   3.5799832E-05,   3.6644480E-05,   3.7527934E-05
     +,   3.8450165E-05,   3.9410897E-05,   4.0409621E-05
     +,   4.1445634E-05,   4.2518353E-05,   4.3627329E-05
     +,   4.4772773E-05,   4.5955643E-05,   4.7178390E-05
     +,   4.8445225E-05,   4.9763075E-05,   5.1142080E-05
     +,   5.2596806E-05,   5.4147142E-05,   5.5819448E-05
     +,   5.7647896E-05,   5.9676062E-05,   6.1958497E-05
     +,   6.4562068E-05,   6.7568406E-05,   7.1075097E-05
     +,   7.5198506E-05,   8.0074889E-05,   8.5863612E-05
     +,   9.2747876E-05,   1.0093799E-04,   1.1067126E-04
     +,   1.2221458E-04,   1.3586401E-04,   1.5194257E-04
     +,   1.7079784E-04,   1.9279821E-04,   2.1832476E-04
     +,   2.4775736E-04,   2.8146783E-04,   3.1979778E-04
     +,   3.6305329E-04,   4.1148631E-04,   4.6530974E-04
     +,   5.2470894E-04,   5.8991375E-04,   6.6128001E-04
     +,   7.3944248E-04,   8.2546531E-04,   9.2097564E-04
     +,   1.0282281E-03,   1.1500434E-03,   1.2895984E-03
     +,   1.4501429E-03,   1.6348762E-03,   1.8470360E-03
     +,   2.0903717E-03,   2.3694695E-03,   2.6898442E-03
     +,   3.0583218E-03,   3.4865420E-03,   3.9987871E-03
     +,   4.6389662E-03,   5.4642977E-03,   6.5226192E-03
     +,   7.8354282E-03,   9.4123101E-03,   1.1273147E-02
     +,   1.3415276E-02,   1.5754271E-02,   1.8163873E-02
     +,   2.0530276E-02,   2.2627328E-02,   2.4145206E-02
     +,   2.5072528E-02,   2.5697868E-02,   2.6201213E-02
     +,   2.6591491E-02,   2.6709210E-02,   2.6283449E-02
     +,   2.5327755E-02,   2.4049094E-02,   2.2508763E-02
     +,   2.0780100E-02,   1.9047581E-02,   1.7440539E-02
     +,   1.5981710E-02,   1.4664145E-02,   1.3495129E-02
     +,   1.2465609E-02,   1.1511483E-02,   1.0546044E-02
     +,   9.5355082E-03,   8.5161682E-03,   7.5387713E-03
     +,   6.6251722E-03,   5.7820175E-03,   5.0293896E-03
     +,   4.4004722E-03,   3.9193388E-03,   3.5849966E-03
     +,   3.3728599E-03,   3.2467507E-03,   3.1710225E-03
     +,   3.1177565E-03,   3.0686972E-03,   3.0138383E-03
     +,   2.9487282E-03,   2.8719809E-03,   2.7836382E-03
     +,   2.6843823E-03,   2.5752753E-03,   2.4576997E-03
     +,   2.3332902E-03,   2.2037935E-03,   2.0709080E-03
     +,   1.9362057E-03,   1.8011412E-03,   1.6670836E-03
     +,   1.5354009E-03,   1.4075168E-03,   1.2848809E-03
     +,   1.1688924E-03,   1.0607977E-03,   9.6158509E-04
     +,   8.7188481E-04,   7.9191837E-04,   7.2151003E-04
     +,   6.6013937E-04,   6.0700864E-04,   5.6113629E-04
     +,   5.2145164E-04,   4.8688002E-04,   4.5639937E-04
     +,   4.2909337E-04,   4.0417883E-04,   3.8101673E-04
     +,   3.5910853E-04,   3.3808866E-04,   3.1770836E-04
     +,   2.9781571E-04,   2.7833434E-04,   2.5924697E-04
     +,   2.4058003E-04,   2.2238815E-04,   2.0474155E-04
     +,   1.8771819E-04,   1.7139749E-04,   1.5585174E-04
     +,   1.4114327E-04,   1.2732281E-04,   1.1442656E-04
     +,   1.0247473E-04,   9.1472626E-05,   8.1412210E-05
     +,   7.2272429E-05,   6.4020576E-05,   5.6614830E-05
     +,   5.0006707E-05,   4.4142453E-05,   3.8964616E-05
     +,   3.4414250E-05,   3.0432760E-05,   2.6962263E-05
     +,   2.3947141E-05,   2.1334939E-05,   1.9076675E-05
     +,   1.7127082E-05,   1.5444984E-05,   1.3993430E-05
     +,   1.2739453E-05,   1.1653859E-05,   1.0711102E-05
     +,   9.8890705E-06,   9.1686916E-06,   8.5336114E-06
     +,   7.9699448E-06,   7.4660261E-06,   7.0120295E-06
     +,   6.5997674E-06,   6.2224931E-06,   5.8746514E-06
     +,   5.5516748E-06,   5.2498535E-06,   4.9662099E-06
     +,   4.6983487E-06,   4.4443454E-06,   4.2026741E-06
     +,   3.9721440E-06,   3.7518223E-06,   3.5409687E-06
     +,   3.3390031E-06,   3.1454942E-06,   2.9600847E-06
     +,   2.7824919E-06,   2.6124956E-06,   2.4499136E-06
     +,   2.2945762E-06,   2.1463293E-06,   2.0050370E-06
     +,   1.8705646E-06,   1.7427644E-06,   1.6214875E-06
     +,   1.5065872E-06,   1.3978969E-06,   1.2952536E-06
     +,   1.1984741E-06,   1.1073806E-06,   1.0217760E-06
     +,   9.4146895E-07,   8.6625238E-07,   7.9592621E-07
     +,   7.3027746E-07,   6.6910087E-07,   6.1218464E-07
     +,   5.5931815E-07,   5.1029718E-07,   4.6491405E-07
     +,   4.2297009E-07,   3.8426569E-07,   3.4861097E-07
     +,   3.1581658E-07,   2.8570409E-07,   2.5809683E-07
     +,   2.3282844E-07,   2.0973650E-07,   1.8866847E-07
     +,   1.6947645E-07,   1.5202201E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz80 = Yx/0.159046511627907
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6421018E-06,   3.8911335E-06
     +,   4.1511307E-06,   4.4220687E-06,   4.7038789E-06
     +,   4.9964456E-06,   5.2996047E-06,   5.6131407E-06
     +,   5.9367853E-06,   6.2702306E-06,   6.6131024E-06
     +,   6.9649800E-06,   7.3253868E-06,   7.6938013E-06
     +,   8.0696445E-06,   8.4522944E-06,   8.8410734E-06
     +,   9.2352675E-06,   9.6341137E-06,   1.0036812E-05
     +,   1.0442527E-05,   1.0850385E-05,   1.1259481E-05
     +,   1.1668907E-05,   1.2077694E-05,   1.2484898E-05
     +,   1.2889542E-05,   1.3290645E-05,   1.3687233E-05
     +,   1.4078330E-05,   1.4462983E-05,   1.4840246E-05
     +,   1.5209206E-05,   1.5568976E-05,   1.5918722E-05
     +,   1.6257640E-05,   1.6584994E-05,   1.6900110E-05
     +,   1.7202399E-05,   1.7491333E-05,   1.7766513E-05
     +,   1.8027629E-05,   1.8274503E-05,   1.8507095E-05
     +,   1.8725526E-05,   1.8930084E-05,   1.9121258E-05
     +,   1.9299756E-05,   1.9466521E-05,   1.9622761E-05
     +,   1.9769977E-05,   1.9909989E-05,   2.0044949E-05
     +,   2.0177402E-05,   2.0310270E-05,   2.0446907E-05
     +,   2.0591104E-05,   2.0747111E-05,   2.0919651E-05
     +,   2.1113903E-05,   2.1335532E-05,   2.1590637E-05
     +,   2.1885729E-05,   2.2227705E-05,   2.2623799E-05
     +,   2.3081420E-05,   2.3608205E-05,   2.4211733E-05
     +,   2.4899577E-05,   2.5678983E-05,   2.6556861E-05
     +,   2.7539452E-05,   2.8632337E-05,   2.9839992E-05
     +,   3.1165848E-05,   3.2611977E-05,   3.4178862E-05
     +,   3.5865265E-05,   3.7668229E-05,   3.9582887E-05
     +,   4.1602190E-05,   4.3717373E-05,   4.5917437E-05
     +,   4.8189861E-05,   5.0520190E-05,   5.2892898E-05
     +,   5.5291152E-05,   5.7697860E-05,   6.0095561E-05
     +,   6.2467567E-05,   6.4798442E-05,   6.7074558E-05
     +,   6.9285059E-05,   7.1422844E-05,   7.3485193E-05
     +,   7.5474432E-05,   7.7399061E-05,   7.9273894E-05
     +,   8.1121034E-05,   8.2969542E-05,   8.4856045E-05
     +,   8.6823908E-05,   8.8923094E-05,   9.1208844E-05
     +,   9.3740848E-05,   9.6581767E-05,   9.9795434E-05
     +,   1.0344556E-04,   1.0759483E-04,   1.1230390E-04
     +,   1.1763097E-04,   1.2363377E-04,   1.3037045E-04
     +,   1.3790454E-04,   1.4630807E-04,   1.5566933E-04
     +,   1.6609751E-04,   1.7773196E-04,   1.9074547E-04
     +,   2.0535159E-04,   2.2180539E-04,   2.4040035E-04
     +,   2.6146267E-04,   2.8534187E-04,   3.1239481E-04
     +,   3.4296571E-04,   3.7737598E-04,   4.1590512E-04
     +,   4.5879616E-04,   5.0625467E-04,   5.5847806E-04
     +,   6.1566790E-04,   6.7806232E-04,   7.4592140E-04
     +,   8.1950892E-04,   8.9902047E-04,   9.8448980E-04
     +,   1.0757350E-03,   1.1724301E-03,   1.2744297E-03
     +,   1.3825180E-03,   1.4997396E-03,   1.6332852E-03
     +,   1.7966237E-03,   2.0111415E-03,   2.3064751E-03
     +,   2.7198703E-03,   3.2981036E-03,   4.1067568E-03
     +,   5.2449903E-03,   6.8506259E-03,   9.0651242E-03
     +,   1.1921634E-02,   1.5191441E-02,   1.8425807E-02
     +,   2.1461781E-02,   2.4828099E-02,   2.8709058E-02
     +,   3.1978369E-02,   3.4260038E-02,   3.6497928E-02
     +,   3.8707960E-02,   4.0521439E-02,   4.0792663E-02
     +,   3.8469836E-02,   3.5098668E-02,   3.1947255E-02
     +,   2.8713666E-02,   2.5114888E-02,   2.1457624E-02
     +,   1.8437212E-02,   1.6294446E-02,   1.4624476E-02
     +,   1.3029372E-02,   1.1446645E-02,   9.9897319E-03
     +,   8.7522026E-03,   7.7546327E-03,   6.9681262E-03
     +,   6.3347686E-03,   5.7820599E-03,   5.2466569E-03
     +,   4.6959096E-03,   4.1331369E-03,   3.5874047E-03
     +,   3.0962273E-03,   2.6892747E-03,   2.3787655E-03
     +,   2.1585536E-03,   2.0098852E-03,   1.9095911E-03
     +,   1.8368716E-03,   1.7766420E-03,   1.7197240E-03
     +,   1.6613135E-03,   1.5991485E-03,   1.5321957E-03
     +,   1.4600124E-03,   1.3825947E-03,   1.3004424E-03
     +,   1.2146037E-03,   1.1266151E-03,   1.0383277E-03
     +,   9.5168746E-04,   8.6852419E-04,   7.9034985E-04
     +,   7.1825739E-04,   6.5287907E-04,   5.9439981E-04
     +,   5.4261362E-04,   4.9701746E-04,   4.5691043E-04
     +,   4.2148511E-04,   3.8991080E-04,   3.6140063E-04
     +,   3.3526114E-04,   3.1091724E-04,   2.8792169E-04
     +,   2.6595395E-04,   2.4481097E-04,   2.2438404E-04
     +,   2.0464088E-04,   1.8560622E-04,   1.6734094E-04
     +,   1.4992406E-04,   1.3344013E-04,   1.1796928E-04
     +,   1.0357821E-04,   9.0313930E-05,   7.8202189E-05
     +,   6.7247274E-05,   5.7432037E-05,   4.8719161E-05
     +,   4.1055209E-05,   3.4374490E-05,   2.8601224E-05
     +,   2.3653914E-05,   1.9448893E-05,   1.5902659E-05
     +,   1.2934081E-05,   1.0466508E-05,   8.4291323E-06
     +,   6.7575629E-06,   5.3941399E-06,   4.2881447E-06
     +,   3.3956019E-06,   2.6787736E-06,   2.1056067E-06
     +,   1.6492006E-06,   1.2872169E-06,   1.0011764E-06
     +,   7.7594791E-07,   5.9922769E-07,   4.6105066E-07
     +,   3.5338223E-07,   2.6978111E-07,   2.0510758E-07
     +,   1.5526813E-07,   1.1701198E-07,   8.7769074E-08
     +,   6.5514989E-08,   4.8658073E-08,   3.5950620E-08
     +,   2.6419256E-08,   1.9308171E-08,   1.4031495E-08
     +,   1.0137907E-08,   7.2816366E-09,   5.1988276E-09
     +,   3.6892045E-09,   2.6017750E-09,   1.8234277E-09
     +,   1.2698914E-09,   8.7876784E-10,   6.0420419E-10
     +,   4.1275103E-10,   2.8012956E-10,   1.8888333E-10
     +,   1.2652265E-10,   8.4194728E-11,   5.5657236E-11
     +,   3.6549694E-11,   2.3842489E-11,   1.5450153E-11
     +,   9.9451090E-12,   6.3590279E-12,   4.0389315E-12
     +,   2.5481633E-12,   1.5969262E-12,   9.9408524E-13
     +,   6.1468815E-13,   3.7754077E-13,   2.3033661E-13
     +,   1.3958480E-13,   8.4023879E-14,   5.0239069E-14
     +,   2.9838020E-14,   1.7602420E-14,   1.0314870E-14
     +,   6.0038466E-15,   3.4712543E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz85 = Yx/0.178022727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.8449709E-08,   9.0309733E-08
     +,   1.0376529E-07,   1.1899935E-07,   1.3621157E-07
     +,   1.5561852E-07,   1.7745495E-07,   2.0197417E-07
     +,   2.2944856E-07,   2.6017159E-07,   2.9445596E-07
     +,   3.3263572E-07,   3.7506564E-07,   4.2212176E-07
     +,   4.7420076E-07,   5.3172050E-07,   5.9511842E-07
     +,   6.6485217E-07,   7.4139689E-07,   8.2524633E-07
     +,   9.1690976E-07,   1.0169109E-06,   1.1257840E-06
     +,   1.2440818E-06,   1.3723504E-06,   1.5111575E-06
     +,   1.6610632E-06,   1.8226315E-06,   1.9964218E-06
     +,   2.1829865E-06,   2.3828702E-06,   2.5966024E-06
     +,   2.8246950E-06,   3.0676435E-06,   3.3259155E-06
     +,   3.5999535E-06,   3.8901708E-06,   4.1969415E-06
     +,   4.5206234E-06,   4.8615025E-06,   5.2198602E-06
     +,   5.5959149E-06,   5.9898471E-06,   6.4017909E-06
     +,   6.8318409E-06,   7.2800403E-06,   7.7463947E-06
     +,   8.2308625E-06,   8.7333601E-06,   9.2537639E-06
     +,   9.7919146E-06,   1.0347610E-05,   1.0920617E-05
     +,   1.1510695E-05,   1.2117518E-05,   1.2740807E-05
     +,   1.3380211E-05,   1.4035382E-05,   1.4705946E-05
     +,   1.5391523E-05,   1.6091715E-05,   1.6806134E-05
     +,   1.7534328E-05,   1.8275903E-05,   1.9030453E-05
     +,   1.9797486E-05,   2.0576615E-05,   2.1367325E-05
     +,   2.2169192E-05,   2.2981676E-05,   2.3804314E-05
     +,   2.4636525E-05,   2.5477786E-05,   2.6327451E-05
     +,   2.7184908E-05,   2.8049504E-05,   2.8920485E-05
     +,   2.9797035E-05,   3.0678359E-05,   3.1563581E-05
     +,   3.2451699E-05,   3.3341748E-05,   3.4232602E-05
     +,   3.5123168E-05,   3.6012210E-05,   3.6898531E-05
     +,   3.7780763E-05,   3.8657639E-05,   3.9527738E-05
     +,   4.0389685E-05,   4.1242129E-05,   4.2083655E-05
     +,   4.2912889E-05,   4.3728556E-05,   4.4529479E-05
     +,   4.5314486E-05,   4.6082660E-05,   4.6833149E-05
     +,   4.7565423E-05,   4.8279078E-05,   4.8974121E-05
     +,   4.9650804E-05,   5.0309816E-05,   5.0952214E-05
     +,   5.1579591E-05,   5.2194006E-05,   5.2798128E-05
     +,   5.3395248E-05,   5.3989424E-05,   5.4585664E-05
     +,   5.5190019E-05,   5.5810120E-05,   5.6455508E-05
     +,   5.7138626E-05,   5.7875735E-05,   5.8688744E-05
     +,   5.9607166E-05,   6.0671362E-05,   6.1936051E-05
     +,   6.3475440E-05,   6.5388936E-05,   6.7807807E-05
     +,   7.0902490E-05,   7.4890260E-05,   8.0041580E-05
     +,   8.6683809E-05,   9.5202748E-05,   1.0603566E-04
     +,   1.1966028E-04,   1.3656964E-04,   1.5724311E-04
     +,   1.8209983E-04,   2.1145536E-04,   2.4546438E-04
     +,   2.8408100E-04,   3.2702624E-04,   3.7377811E-04
     +,   4.2360145E-04,   4.7561910E-04,   5.2891596E-04
     +,   5.8267580E-04,   6.3634512E-04,   6.8979495E-04
     +,   7.4345066E-04,   7.9837127E-04,   8.5627142E-04
     +,   9.1943430E-04,   9.9051394E-04,   1.0722266E-03
     +,   1.1669584E-03,   1.2763957E-03,   1.4014350E-03
     +,   1.5427689E-03,   1.7024212E-03,   1.8860272E-03
     +,   2.1049222E-03,   2.3770307E-03,   2.7270729E-03
     +,   3.1892234E-03,   3.8148127E-03,   4.6782917E-03
     +,   5.8591254E-03,   7.3883752E-03,   9.2152413E-03
     +,   1.1273268E-02,   1.3557083E-02,   1.6047848E-02
     +,   1.8771285E-02,   2.2225568E-02,   2.7120939E-02
     +,   3.3183075E-02,   3.9147526E-02,   4.3500703E-02
     +,   4.4786267E-02,   4.3170795E-02,   4.0545709E-02
     +,   3.6938768E-02,   3.2883793E-02,   3.0560035E-02
     +,   2.9624689E-02,   2.7884850E-02,   2.4083206E-02
     +,   1.9143494E-02,   1.4985648E-02,   1.2337177E-02
     +,   1.0663180E-02,   9.4241248E-03,   8.4488615E-03
     +,   7.6767043E-03,   7.0169126E-03,   6.3729542E-03
     +,   5.6994124E-03,   5.0199139E-03,   4.3953611E-03
     +,   3.8782610E-03,   3.4881190E-03,   3.2123004E-03
     +,   3.0190751E-03,   2.8714493E-03,   2.7372846E-03
     +,   2.5949359E-03,   2.4347918E-03,   2.2576055E-03
     +,   2.0709587E-03,   1.8852575E-03,   1.7103025E-03
     +,   1.5531759E-03,   1.4174266E-03,   1.3032695E-03
     +,   1.2083680E-03,   1.1288314E-03,   1.0601330E-03
     +,   9.9784147E-04,   9.3813962E-04,   8.7814475E-04
     +,   8.1605284E-04,   7.5111969E-04,   6.8352424E-04
     +,   6.1415852E-04,   5.4438337E-04,   4.7575982E-04
     +,   4.0983350E-04,   3.4796531E-04,   2.9121386E-04
     +,   2.4027900E-04,   1.9550425E-04,   1.5691474E-04
     +,   1.2427254E-04,   9.7144424E-05,   7.4973985E-05
     +,   5.7143614E-05,   4.3022133E-05,   3.2001248E-05
     +,   2.3521510E-05,   1.7087001E-05,   1.2269593E-05
     +,   8.7099734E-06,   6.1135570E-06,   4.2435586E-06
     +,   2.9132927E-06,   1.9783874E-06,   1.3291516E-06
     +,   8.8354500E-07,   5.8117473E-07,   3.7829147E-07
     +,   2.4366912E-07,   1.5531842E-07,   9.7961383E-08
     +,   6.1127558E-08,   3.7732171E-08,   2.3034843E-08
     +,   1.3904308E-08,   8.2966274E-09,   4.8925211E-09
     +,   2.8504781E-09,   1.6403323E-09,   9.3211439E-10
     +,   5.2291826E-10,   2.8954897E-10,   1.5821330E-10
     +,   8.5298116E-11,   4.5370742E-11,   2.3808205E-11
     +,   1.2325533E-11,   6.2966980E-12,   3.1754781E-12
     +,   1.5819427E-12,   7.7946612E-13,   3.8064213E-13
     +,   1.8482873E-13,   8.9704204E-14,   4.3864303E-14
     +,   2.1857335E-14,   1.1259905E-14,   6.0892301E-15
     +,   3.4975202E-15,   2.1407032E-15,   1.3875965E-15
     +,   9.4072305E-16,   6.5797392E-16,   4.6931719E-16
     +,   3.3854933E-16,   2.4563746E-16,   1.7866692E-16
     +,   1.3001940E-16,   9.4559906E-17,   6.8685716E-17
     +,   4.9812194E-17,   3.6061326E-17,   2.6057524E-17
     +,   1.8793075E-17,   1.3527429E-17,   9.7182621E-18
     +,   6.9679511E-18,   4.9862472E-18,   3.5610928E-18
     +,   2.5382953E-18,   1.8056879E-18,   1.2820150E-18
     +,   9.0841285E-19,   6.4242703E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz90 = Yx/0.177227272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7189047E-11,   2.2582580E-11
     +,   2.9589803E-11,   3.8668565E-11,   5.0398845E-11
     +,   6.5513588E-11,   8.4935593E-11,   1.0982389E-10
     +,   1.4162867E-10,   1.8216144E-10,   2.3367455E-10
     +,   2.9896238E-10,   3.8148079E-10,   4.8549015E-10
     +,   6.1622507E-10,   7.8010076E-10,   9.8495045E-10
     +,   1.2403144E-09,   1.5577678E-09,   1.9513167E-09
     +,   2.4378561E-09,   3.0376919E-09,   3.7751442E-09
     +,   4.6793307E-09,   5.7847900E-09,   7.1326576E-09
     +,   8.7714964E-09,   1.0758580E-08,   1.3161229E-08
     +,   1.6058253E-08,   1.9541686E-08,   2.3718515E-08
     +,   2.8712829E-08,   3.4667956E-08,   4.1748905E-08
     +,   5.0144951E-08,   6.0072502E-08,   7.1777755E-08
     +,   8.5541124E-08,   1.0167781E-07,   1.2054491E-07
     +,   1.4254196E-07,   1.6811580E-07,   1.9776418E-07
     +,   2.3203899E-07,   2.7154994E-07,   3.1696780E-07
     +,   3.6902725E-07,   4.2852969E-07,   4.9634531E-07
     +,   5.7341487E-07,   6.6074995E-07,   7.5943251E-07
     +,   8.7062193E-07,   9.9553370E-07,   1.1354630E-06
     +,   1.2917583E-06,   1.4658267E-06,   1.6591251E-06
     +,   1.8731491E-06,   2.1094272E-06,   2.3695100E-06
     +,   2.6549360E-06,   2.9672558E-06,   3.3079975E-06
     +,   3.6786137E-06,   4.0805376E-06,   4.5150691E-06
     +,   4.9834621E-06,   5.4867787E-06,   6.0260027E-06
     +,   6.6018711E-06,   7.2150037E-06,   7.8657267E-06
     +,   8.5541897E-06,   9.2802875E-06,   1.0043601E-05
     +,   1.0843416E-05,   1.1678770E-05,   1.2548389E-05
     +,   1.3450612E-05,   1.4383566E-05,   1.5344949E-05
     +,   1.6332280E-05,   1.7342654E-05,   1.8373030E-05
     +,   1.9419973E-05,   2.0479985E-05,   2.1549222E-05
     +,   2.2623810E-05,   2.3699795E-05,   2.4773088E-05
     +,   2.5839636E-05,   2.6895526E-05,   2.7937014E-05
     +,   2.8960467E-05,   2.9962728E-05,   3.0940901E-05
     +,   3.1892730E-05,   3.2816468E-05,   3.3711214E-05
     +,   3.4576831E-05,   3.5414287E-05,   3.6225643E-05
     +,   3.7014364E-05,   3.7785463E-05,   3.8545630E-05
     +,   3.9303522E-05,   4.0070056E-05,   4.0858566E-05
     +,   4.1684994E-05,   4.2568263E-05,   4.3530272E-05
     +,   4.4596258E-05,   4.5794619E-05,   4.7157173E-05
     +,   4.8718695E-05,   5.0516963E-05,   5.2591924E-05
     +,   5.4985438E-05,   5.7740330E-05,   6.0899238E-05
     +,   6.4503576E-05,   6.8592686E-05,   7.3202478E-05
     +,   7.8363933E-05,   8.4103391E-05,   9.0440975E-05
     +,   9.7392367E-05,   1.0496825E-04,   1.1317832E-04
     +,   1.2203217E-04,   1.3154569E-04,   1.4174338E-04
     +,   1.5266569E-04,   1.6437277E-04,   1.7694729E-04
     +,   1.9049586E-04,   2.0514741E-04,   2.2104493E-04
     +,   2.3833168E-04,   2.5713307E-04,   2.7753593E-04
     +,   2.9956223E-04,   3.2314422E-04,   3.4811284E-04
     +,   3.7419359E-04,   4.0102212E-04,   4.2818754E-04
     +,   4.5530373E-04,   4.8209983E-04,   5.0852599E-04
     +,   5.3485885E-04,   5.6177547E-04,   5.9036509E-04
     +,   6.2204787E-04,   6.5839675E-04,   7.0087257E-04
     +,   7.5053796E-04,   8.0786046E-04,   8.7277615E-04
     +,   9.4512844E-04,   1.0255834E-03,   1.1170022E-03
     +,   1.2260762E-03,   1.3647549E-03,   1.5508060E-03
     +,   1.8067763E-03,   2.1567340E-03,   2.6199911E-03
     +,   3.2014805E-03,   3.8834380E-03,   4.6340139E-03
     +,   5.4539302E-03,   6.4527825E-03,   7.8712581E-03
     +,   9.9522173E-03,   1.2756696E-02,   1.6119128E-02
     +,   1.9718748E-02,   2.3148531E-02,   2.6099397E-02
     +,   2.9505476E-02,   3.4477625E-02,   3.9439622E-02
     +,   4.2714734E-02,   4.3090694E-02,   4.1149732E-02
     +,   3.8946118E-02,   3.5142642E-02,   2.9673552E-02
     +,   2.5259199E-02,   2.1393685E-02,   1.7192366E-02
     +,   1.4061507E-02,   1.2164953E-02,   1.0443647E-02
     +,   8.5576568E-03,   6.8241134E-03,   5.4674293E-03
     +,   4.4746296E-03,   3.7694317E-03,   3.2959424E-03
     +,   3.0050415E-03,   2.8375657E-03,   2.7303617E-03
     +,   2.6319670E-03,   2.5127712E-03,   2.3647661E-03
     +,   2.1942309E-03,   2.0129243E-03,   1.8315468E-03
     +,   1.6566484E-03,   1.4904799E-03,   1.3325516E-03
     +,   1.1815499E-03,   1.0367379E-03,   8.9852198E-04
     +,   7.6831010E-04,   6.4797828E-04,   5.3923833E-04
     +,   4.4321819E-04,   3.6028467E-04,   2.9007444E-04
     +,   2.3166579E-04,   1.8380232E-04,   1.4508949E-04
     +,   1.1413289E-04,   8.9623230E-05,   7.0383510E-05
     +,   5.5385750E-05,   4.3751039E-05,   3.4743596E-05
     +,   2.7762024E-05,   2.2326754E-05,   1.8063316E-05
     +,   1.4686426E-05,   1.1983132E-05,   9.7965276E-06
     +,   8.0117879E-06,   6.5448976E-06,   5.3338217E-06
     +,   4.3318037E-06,   3.5026753E-06,   2.8177762E-06
     +,   2.2538443E-06,   1.7915603E-06,   1.4146073E-06
     +,   1.1091010E-06,   8.6318607E-07,   6.6667110E-07
     +,   5.1083981E-07,   3.8827514E-07,   2.9268810E-07
     +,   2.1878331E-07,   1.6214780E-07,   1.1913991E-07
     +,   8.6780553E-08,   6.2657804E-08,   4.4842380E-08
     +,   3.1809019E-08,   2.2364144E-08,   1.5584018E-08
     +,   1.0762647E-08,   7.3667539E-09,   4.9973630E-09
     +,   3.3597314E-09,   2.2385702E-09,   1.4782340E-09
     +,   9.6742170E-10,   6.2745309E-10,   4.0331524E-10
     +,   2.5692851E-10,   1.6221002E-10,   1.0149252E-10
     +,   6.2935310E-11,   3.8676323E-11,   2.3555926E-11
     +,   1.4218219E-11,   8.5054012E-12,   5.0423598E-12
     +,   2.9626310E-12,   1.7250871E-12,   9.9551910E-13
     +,   5.6934660E-13,   3.2270741E-13,   1.8127538E-13
     +,   1.0091535E-13,   5.5677729E-14,   3.0443486E-14
     +,   1.6497278E-14,   8.8596953E-15,   4.7155557E-15
     +,   2.4873322E-15,   1.3002913E-15,   6.7365271E-16
     +,   3.4588948E-16,   1.7600556E-16,   8.8761013E-17
     +,   4.4361362E-17,   2.1973340E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ttz95 = Yx/0.155953488372093
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0485346E-05,   1.0738769E-05
     +,   1.0996509E-05,   1.1258778E-05,   1.1525803E-05
     +,   1.1797830E-05,   1.2075129E-05,   1.2357970E-05
     +,   1.2646657E-05,   1.2941512E-05,   1.3242862E-05
     +,   1.3551053E-05,   1.3866445E-05,   1.4189417E-05
     +,   1.4520355E-05,   1.4859659E-05,   1.5207736E-05
     +,   1.5565010E-05,   1.5931908E-05,   1.6308857E-05
     +,   1.6696302E-05,   1.7094679E-05,   1.7504426E-05
     +,   1.7926011E-05,   1.8359846E-05,   1.8806390E-05
     +,   1.9266083E-05,   1.9739353E-05,   2.0226635E-05
     +,   2.0728357E-05,   2.1244938E-05,   2.1776797E-05
     +,   2.2324355E-05,   2.2888025E-05,   2.3468221E-05
     +,   2.4065359E-05,   2.4679863E-05,   2.5312158E-05
     +,   2.5962716E-05,   2.6631958E-05,   2.7320397E-05
     +,   2.8028539E-05,   2.8756924E-05,   2.9506144E-05
     +,   3.0276829E-05,   3.1069678E-05,   3.1885429E-05
     +,   3.2724922E-05,   3.3589047E-05,   3.4478799E-05
     +,   3.5395242E-05,   3.6339585E-05,   3.7313082E-05
     +,   3.8317175E-05,   3.9353323E-05,   4.0423209E-05
     +,   4.1528554E-05,   4.2671250E-05,   4.3853255E-05
     +,   4.5076675E-05,   4.6343688E-05,   4.7656620E-05
     +,   4.9017734E-05,   5.0429491E-05,   5.1894382E-05
     +,   5.3414766E-05,   5.4993186E-05,   5.6631892E-05
     +,   5.8333320E-05,   6.0099512E-05,   6.1932573E-05
     +,   6.3834195E-05,   6.5806031E-05,   6.7849178E-05
     +,   6.9964583E-05,   7.2152805E-05,   7.4413794E-05
     +,   7.6747056E-05,   7.9151658E-05,   8.1626145E-05
     +,   8.4168227E-05,   8.6775348E-05,   8.9443907E-05
     +,   9.2170092E-05,   9.4949151E-05,   9.7775934E-05
     +,   1.0064451E-04,   1.0354873E-04,   1.0648158E-04
     +,   1.0943601E-04,   1.1240462E-04,   1.1537968E-04
     +,   1.1835334E-04,   1.2131811E-04,   1.2426672E-04
     +,   1.2719193E-04,   1.3008759E-04,   1.3294781E-04
     +,   1.3576823E-04,   1.3854516E-04,   1.4127676E-04
     +,   1.4396240E-04,   1.4660374E-04,   1.4920400E-04
     +,   1.5176907E-04,   1.5430720E-04,   1.5682931E-04
     +,   1.5934900E-04,   1.6188316E-04,   1.6445188E-04
     +,   1.6707838E-04,   1.6978943E-04,   1.7261530E-04
     +,   1.7558962E-04,   1.7874960E-04,   1.8213598E-04
     +,   1.8579223E-04,   1.8976546E-04,   1.9410481E-04
     +,   1.9886170E-04,   2.0408959E-04,   2.0984192E-04
     +,   2.1617230E-04,   2.2313342E-04,   2.3077569E-04
     +,   2.3914487E-04,   2.4828222E-04,   2.5822115E-04
     +,   2.6898715E-04,   2.8059361E-04,   2.9304289E-04
     +,   3.0632102E-04,   3.2039994E-04,   3.3523195E-04
     +,   3.5075212E-04,   3.6687593E-04,   3.8349853E-04
     +,   4.0049572E-04,   4.1772623E-04,   4.3503250E-04
     +,   4.5224215E-04,   4.6917252E-04,   4.8563592E-04
     +,   5.0144270E-04,   5.1640579E-04,   5.3034909E-04
     +,   5.4311141E-04,   5.5455283E-04,   5.6455977E-04
     +,   5.7305366E-04,   5.7999184E-04,   5.8537419E-04
     +,   5.8924517E-04,   5.9169770E-04,   5.9287279E-04
     +,   5.9296028E-04,   5.9219892E-04,   5.9087342E-04
     +,   5.8931275E-04,   5.8788795E-04,   5.8700674E-04
     +,   5.8711233E-04,   5.8867678E-04,   5.9219700E-04
     +,   5.9818814E-04,   6.0717657E-04,   6.1968720E-04
     +,   6.3623115E-04,   6.5728807E-04,   6.8328588E-04
     +,   7.1457168E-04,   7.5138686E-04,   7.9384079E-04
     +,   8.4188627E-04,   8.9529657E-04,   9.5367141E-04
     +,   1.0164469E-03,   1.0829285E-03,   1.1523616E-03
     +,   1.2240293E-03,   1.2973723E-03,   1.3721288E-03
     +,   1.4484775E-03,   1.5271686E-03,   1.6095556E-03
     +,   1.6975192E-03,   1.7932319E-03,   1.8987646E-03
     +,   2.0155723E-03,   2.1440689E-03,   2.2835403E-03
     +,   2.4326781E-03,   2.5909788E-03,   2.7610867E-03
     +,   2.9519123E-03,   3.1819225E-03,   3.4816049E-03
     +,   3.8935011E-03,   4.4676973E-03,   5.2509559E-03
     +,   6.2701367E-03,   7.5153797E-03,   8.9326734E-03
     +,   1.0432847E-02,   1.1914282E-02,   1.3287144E-02
     +,   1.4487727E-02,   1.5488288E-02,   1.6315512E-02
     +,   1.7072920E-02,   1.7925352E-02,   1.8997204E-02
     +,   2.0222796E-02,   2.1310011E-02,   2.1930575E-02
     +,   2.1993373E-02,   2.1712083E-02,   2.1388544E-02
     +,   2.1142054E-02,   2.0834930E-02,   2.0216091E-02
     +,   1.9128714E-02,   1.7626438E-02,   1.5936844E-02
     +,   1.4322252E-02,   1.2952172E-02,   1.1863737E-02
     +,   1.0999656E-02,   1.0268875E-02,   9.5902160E-03
     +,   8.9121172E-03,   8.2172649E-03,   7.5171958E-03
     +,   6.8374821E-03,   6.1993762E-03,   5.6084604E-03
     +,   5.0566173E-03,   4.5324424E-03,   4.0307338E-03
     +,   3.5552047E-03,   3.1149343E-03,   2.7187918E-03
     +,   2.3714548E-03,   2.0724500E-03,   1.8174418E-03
     +,   1.6002840E-03,   1.4147067E-03,   1.2552588E-03
     +,   1.1175899E-03,   9.9832180E-04,   8.9474680E-04
     +,   8.0459821E-04,   7.2590075E-04,   6.5689289E-04
     +,   5.9600966E-04,   5.4189685E-04,   4.9342308E-04
     +,   4.4967310E-04,   4.0993289E-04,   3.7366676E-04
     +,   3.4048664E-04,   3.1011386E-04,   2.8234263E-04
     +,   2.5701302E-04,   2.3398983E-04,   2.1314039E-04
     +,   1.9432773E-04,   1.7740742E-04,   1.6222573E-04
     +,   1.4862177E-04,   1.3643291E-04,   1.2550033E-04
     +,   1.1567243E-04,   1.0680797E-04,   9.8779419E-05
     +,   9.1475005E-05,   8.4797241E-05,   7.8664481E-05
     +,   7.3007875E-05,   6.7771478E-05,   6.2908970E-05
     +,   5.8383281E-05,   5.4163542E-05,   5.0224866E-05
     +,   4.6545872E-05,   4.3108768E-05,   3.9897623E-05
     +,   3.6898167E-05,   3.4097680E-05,   3.1483978E-05
     +,   2.9046010E-05,   2.6773010E-05,   2.4655128E-05
     +,   2.2682749E-05,   2.0847074E-05,   1.9139545E-05
     +,   1.7552349E-05,   1.6077942E-05,   1.4709432E-05
     +,   1.3440188E-05,   1.2264160E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz100 = Yx/0.152209302325581
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1141942E-05,   1.1315987E-05
     +,   1.1486693E-05,   1.1653908E-05,   1.1817481E-05
     +,   1.1977279E-05,   1.2133181E-05,   1.2285088E-05
     +,   1.2432911E-05,   1.2576586E-05,   1.2716064E-05
     +,   1.2851321E-05,   1.2982350E-05,   1.3109167E-05
     +,   1.3231821E-05,   1.3350374E-05,   1.3464922E-05
     +,   1.3575583E-05,   1.3682506E-05,   1.3785867E-05
     +,   1.3885875E-05,   1.3982764E-05,   1.4076807E-05
     +,   1.4168304E-05,   1.4257582E-05,   1.4345015E-05
     +,   1.4431002E-05,   1.4515978E-05,   1.4600419E-05
     +,   1.4684825E-05,   1.4769750E-05,   1.4855776E-05
     +,   1.4943530E-05,   1.5033676E-05,   1.5126924E-05
     +,   1.5224022E-05,   1.5325772E-05,   1.5433021E-05
     +,   1.5546666E-05,   1.5667651E-05,   1.5796988E-05
     +,   1.5935741E-05,   1.6085034E-05,   1.6246062E-05
     +,   1.6420086E-05,   1.6608446E-05,   1.6812553E-05
     +,   1.7033914E-05,   1.7274111E-05,   1.7534816E-05
     +,   1.7817805E-05,   1.8124960E-05,   1.8458244E-05
     +,   1.8819759E-05,   1.9211675E-05,   1.9636311E-05
     +,   2.0096069E-05,   2.0593470E-05,   2.1131134E-05
     +,   2.1711798E-05,   2.2338267E-05,   2.3013468E-05
     +,   2.3740336E-05,   2.4521940E-05,   2.5361394E-05
     +,   2.6261752E-05,   2.7226202E-05,   2.8257782E-05
     +,   2.9359619E-05,   3.0534644E-05,   3.1785836E-05
     +,   3.3115884E-05,   3.4527489E-05,   3.6022986E-05
     +,   3.7604645E-05,   3.9274473E-05,   4.1034120E-05
     +,   4.2884913E-05,   4.4827993E-05,   4.6864170E-05
     +,   4.8993730E-05,   5.1216859E-05,   5.3533149E-05
     +,   5.5942171E-05,   5.8442849E-05,   6.1034199E-05
     +,   6.3714659E-05,   6.6482848E-05,   6.9336922E-05
     +,   7.2275237E-05,   7.5296215E-05,   7.8398218E-05
     +,   8.1579790E-05,   8.4839994E-05,   8.8178240E-05
     +,   9.1594135E-05,   9.5088275E-05,   9.8661381E-05
     +,   1.0231534E-04,   1.0605227E-04,   1.0987541E-04
     +,   1.1378829E-04,   1.1779549E-04,   1.2190168E-04
     +,   1.2611222E-04,   1.3043291E-04,   1.3486913E-04
     +,   1.3942615E-04,   1.4410904E-04,   1.4892207E-04
     +,   1.5386791E-04,   1.5894836E-04,   1.6416275E-04
     +,   1.6950876E-04,   1.7498086E-04,   1.8057130E-04
     +,   1.8626841E-04,   1.9205782E-04,   1.9792067E-04
     +,   2.0383520E-04,   2.0977580E-04,   2.1571304E-04
     +,   2.2161404E-04,   2.2744351E-04,   2.3316345E-04
     +,   2.3873356E-04,   2.4411290E-04,   2.4925952E-04
     +,   2.5413267E-04,   2.5869213E-04,   2.6290101E-04
     +,   2.6672502E-04,   2.7013491E-04,   2.7310627E-04
     +,   2.7562131E-04,   2.7766917E-04,   2.7924651E-04
     +,   2.8035813E-04,   2.8101733E-04,   2.8124597E-04
     +,   2.8107420E-04,   2.8054038E-04,   2.7969037E-04
     +,   2.7857683E-04,   2.7725819E-04,   2.7579782E-04
     +,   2.7426222E-04,   2.7272030E-04,   2.7124147E-04
     +,   2.6989428E-04,   2.6874521E-04,   2.6785707E-04
     +,   2.6728763E-04,   2.6708902E-04,   2.6730652E-04
     +,   2.6797788E-04,   2.6913348E-04,   2.7079580E-04
     +,   2.7297999E-04,   2.7569459E-04,   2.7894205E-04
     +,   2.8272069E-04,   2.8702500E-04,   2.9184809E-04
     +,   2.9718375E-04,   3.0302763E-04,   3.0937957E-04
     +,   3.1624569E-04,   3.2364138E-04,   3.3159298E-04
     +,   3.4014083E-04,   3.4934204E-04,   3.5927579E-04
     +,   3.7004703E-04,   3.8179144E-04,   3.9468455E-04
     +,   4.0894843E-04,   4.2486054E-04,   4.4276254E-04
     +,   4.6307017E-04,   4.8627891E-04,   5.1296409E-04
     +,   5.4378010E-04,   5.7945697E-04,   6.2078825E-04
     +,   6.6861429E-04,   7.2381203E-04,   7.8728417E-04
     +,   8.5994462E-04,   9.4269554E-04,   1.0364291E-03
     +,   1.1420178E-03,   1.2603272E-03,   1.3922917E-03
     +,   1.5390679E-03,   1.7022213E-03,   1.8838941E-03
     +,   2.0868643E-03,   2.3143953E-03,   2.5699025E-03
     +,   2.8567347E-03,   3.1784782E-03,   3.5399257E-03
     +,   3.9484086E-03,   4.4150399E-03,   4.9554971E-03
     +,   5.5892253E-03,   6.3345511E-03,   7.1964855E-03
     +,   8.1491126E-03,   9.1275927E-03,   1.0051523E-02
     +,   1.0881177E-02,   1.1666369E-02,   1.2533153E-02
     +,   1.3602536E-02,   1.4903333E-02,   1.6355773E-02
     +,   1.7844411E-02,   1.9306686E-02,   2.0725138E-02
     +,   2.2011980E-02,   2.2935992E-02,   2.3223439E-02
     +,   2.2756342E-02,   2.1676503E-02,   2.0310432E-02
     +,   1.8987836E-02,   1.7878264E-02,   1.6942311E-02
     +,   1.6023144E-02,   1.4999841E-02,   1.3871563E-02
     +,   1.2725476E-02,   1.1651031E-02,   1.0682316E-02
     +,   9.7974269E-03,   8.9543350E-03,   8.1284977E-03
     +,   7.3272143E-03,   6.5788743E-03,   5.9118187E-03
     +,   5.3396220E-03,   4.8591676E-03,   4.4570025E-03
     +,   4.1164951E-03,   3.8218061E-03,   3.5590429E-03
     +,   3.3164499E-03,   3.0848160E-03,   2.8579899E-03
     +,   2.6331858E-03,   2.4106198E-03,   2.1925492E-03
     +,   1.9821015E-03,   1.7822675E-03,   1.5952700E-03
     +,   1.4223135E-03,   1.2636631E-03,   1.1189209E-03
     +,   9.8733651E-04,   8.6804276E-04,   7.6019671E-04
     +,   6.6304859E-04,   5.7594350E-04,   4.9826509E-04
     +,   4.2940679E-04,   3.6874827E-04,   3.1563980E-04
     +,   2.6940534E-04,   2.2936219E-04,   1.9484143E-04
     +,   1.6520105E-04,   1.3983795E-04,   1.1819886E-04
     +,   9.9785568E-05,   8.4150721E-05,   7.0900744E-05
     +,   5.9688457E-05,   5.0212628E-05,   4.2210908E-05
     +,   3.5458237E-05,   2.9760902E-05,   2.4954605E-05
     +,   2.0899472E-05,   1.7478031E-05,   1.4591204E-05
     +,   1.2155965E-05,   1.0102965E-05,   8.3737941E-06
     +,   6.9195771E-06,   5.6988874E-06,   4.6767827E-06
     +,   3.8233798E-06,   3.1132436E-06,   2.5244613E-06
     +,   2.0382770E-06,   1.6384921E-06,   1.3112366E-06
     +,   1.0445675E-06,   8.2830815E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz102 = Yx/0.146348837209302
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.9206958E-06,   7.1620198E-06
     +,   7.4091718E-06,   7.6621700E-06,   7.9210322E-06
     +,   8.1857661E-06,   8.4563753E-06,   8.7328626E-06
     +,   9.0152189E-06,   9.3034405E-06,   9.5975165E-06
     +,   9.8974260E-06,   1.0203150E-05,   1.0514671E-05
     +,   1.0831961E-05,   1.1154993E-05,   1.1483747E-05
     +,   1.1818189E-05,   1.2158299E-05,   1.2504051E-05
     +,   1.2855423E-05,   1.3212397E-05,   1.3574953E-05
     +,   1.3943099E-05,   1.4316809E-05,   1.4696107E-05
     +,   1.5080993E-05,   1.5471496E-05,   1.5867645E-05
     +,   1.6269480E-05,   1.6677057E-05,   1.7090439E-05
     +,   1.7509712E-05,   1.7934972E-05,   1.8366321E-05
     +,   1.8803888E-05,   1.9247807E-05,   1.9698238E-05
     +,   2.0155367E-05,   2.0619360E-05,   2.1090440E-05
     +,   2.1568829E-05,   2.2054759E-05,   2.2548486E-05
     +,   2.3050288E-05,   2.3560455E-05,   2.4079282E-05
     +,   2.4607096E-05,   2.5144225E-05,   2.5691033E-05
     +,   2.6247875E-05,   2.6815143E-05,   2.7393227E-05
     +,   2.7982573E-05,   2.8583594E-05,   2.9196774E-05
     +,   2.9822599E-05,   3.0461597E-05,   3.1114323E-05
     +,   3.1781376E-05,   3.2463413E-05,   3.3161145E-05
     +,   3.3875327E-05,   3.4606841E-05,   3.5356654E-05
     +,   3.6125773E-05,   3.6915448E-05,   3.7726950E-05
     +,   3.8561844E-05,   3.9421728E-05,   4.0308561E-05
     +,   4.1224434E-05,   4.2171756E-05,   4.3153170E-05
     +,   4.4171687E-05,   4.5230667E-05,   4.6333753E-05
     +,   4.7485002E-05,   4.8688922E-05,   4.9950460E-05
     +,   5.1274867E-05,   5.2667987E-05,   5.4135988E-05
     +,   5.5685563E-05,   5.7323668E-05,   5.9057846E-05
     +,   6.0895709E-05,   6.2845415E-05,   6.4915112E-05
     +,   6.7113186E-05,   6.9448142E-05,   7.1928283E-05
     +,   7.4561576E-05,   7.7355937E-05,   8.0318765E-05
     +,   8.3456558E-05,   8.6775406E-05,   9.0280017E-05
     +,   9.3974377E-05,   9.7860779E-05,   1.0194047E-04
     +,   1.0621268E-04,   1.1067538E-04,   1.1532420E-04
     +,   1.2015321E-04,   1.2515461E-04,   1.3031818E-04
     +,   1.3563177E-04,   1.4108155E-04,   1.4665192E-04
     +,   1.5232491E-04,   1.5808179E-04,   1.6390157E-04
     +,   1.6976304E-04,   1.7564323E-04,   1.8151943E-04
     +,   1.8736791E-04,   1.9316563E-04,   1.9888944E-04
     +,   2.0451717E-04,   2.1002798E-04,   2.1540190E-04
     +,   2.2062073E-04,   2.2566848E-04,   2.3053132E-04
     +,   2.3519732E-04,   2.3965762E-04,   2.4390534E-04
     +,   2.4793684E-04,   2.5175049E-04,   2.5534802E-04
     +,   2.5873291E-04,   2.6191180E-04,   2.6489288E-04
     +,   2.6768717E-04,   2.7030744E-04,   2.7276823E-04
     +,   2.7508562E-04,   2.7727766E-04,   2.7936371E-04
     +,   2.8136428E-04,   2.8330111E-04,   2.8519749E-04
     +,   2.8707797E-04,   2.8896774E-04,   2.9089383E-04
     +,   2.9288462E-04,   2.9496916E-04,   2.9717831E-04
     +,   2.9954413E-04,   3.0209988E-04,   3.0487980E-04
     +,   3.0791917E-04,   3.1125380E-04,   3.1492033E-04
     +,   3.1895484E-04,   3.2339324E-04,   3.2827060E-04
     +,   3.3362099E-04,   3.3947601E-04,   3.4586547E-04
     +,   3.5281677E-04,   3.6035388E-04,   3.6849739E-04
     +,   3.7726533E-04,   3.8667256E-04,   3.9673035E-04
     +,   4.0744734E-04,   4.1883095E-04,   4.3088791E-04
     +,   4.4362401E-04,   4.5704650E-04,   4.7116651E-04
     +,   4.8600038E-04,   5.0156889E-04,   5.1790260E-04
     +,   5.3504179E-04,   5.5303529E-04,   5.7194184E-04
     +,   5.9183122E-04,   6.1278109E-04,   6.3487585E-04
     +,   6.5820897E-04,   6.8288902E-04,   7.0905179E-04
     +,   7.3687988E-04,   7.6663931E-04,   7.9873059E-04
     +,   8.3374948E-04,   8.7254937E-04,   9.1630506E-04
     +,   9.6654159E-04,   1.0250987E-03,   1.0940207E-03
     +,   1.1753509E-03,   1.2708105E-03,   1.3814127E-03
     +,   1.5070889E-03,   1.6464168E-03,   1.7965516E-03
     +,   1.9534603E-03,   2.1125157E-03,   2.2694205E-03
     +,   2.4212415E-03,   2.5674065E-03,   2.7104199E-03
     +,   2.8560443E-03,   3.0129033E-03,   3.1916127E-03
     +,   3.4035661E-03,   3.6594756E-03,   3.9678598E-03
     +,   4.3338509E-03,   4.7588171E-03,   5.2412511E-03
     +,   5.7783751E-03,   6.3667558E-03,   7.0000123E-03
     +,   7.6645683E-03,   8.3392160E-03,   9.0061761E-03
     +,   9.6730599E-03,   1.0389961E-02,   1.1236660E-02
     +,   1.2270173E-02,   1.3463232E-02,   1.4688492E-02
     +,   1.5773756E-02,   1.6586628E-02,   1.7084448E-02
     +,   1.7310383E-02,   1.7362708E-02,   1.7358044E-02
     +,   1.7391184E-02,   1.7503297E-02,   1.7675508E-02
     +,   1.7838446E-02,   1.7875595E-02,   1.7630544E-02
     +,   1.6953340E-02,   1.5783893E-02,   1.4212285E-02
     +,   1.2455601E-02,   1.0760848E-02,   9.3037393E-03
     +,   8.1455978E-03,   7.2548511E-03,   6.5578748E-03
     +,   5.9814607E-03,   5.4721162E-03,   4.9973624E-03
     +,   4.5401934E-03,   4.0938067E-03,   3.6585042E-03
     +,   3.2397090E-03,   2.8458077E-03,   2.4854948E-03
     +,   2.1652812E-03,   1.8879682E-03,   1.6524760E-03
     +,   1.4546834E-03,   1.2887400E-03,   1.1483734E-03
     +,   1.0278625E-03,   9.2255033E-04,   8.2893833E-04
     +,   7.4456871E-04,   6.6779746E-04,   5.9754879E-04
     +,   5.3311599E-04,   4.7402896E-04,   4.1996044E-04
     +,   3.7066118E-04,   3.2591546E-04,   2.8551783E-04
     +,   2.4925923E-04,   2.1690791E-04,   1.8821629E-04
     +,   1.6291392E-04,   1.4072069E-04,   1.2134734E-04
     +,   1.0450913E-04,   8.9927889E-05,   7.7342047E-05
     +,   6.6506938E-05,   5.7200421E-05,   4.9221304E-05
     +,   4.2390144E-05,   3.6548892E-05,   3.1557851E-05
     +,   2.7295519E-05,   2.3655521E-05,   2.0546026E-05
     +,   1.7887256E-05,   1.5610840E-05,   1.3657848E-05
     +,   1.1978230E-05,   1.0529249E-05,   9.2749733E-06
     +,   8.1850203E-06,   7.2341090E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz104 = Yx/0.134333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0721545E-05,   2.1173691E-05
     +,   2.1626141E-05,   2.2078464E-05,   2.2530241E-05
     +,   2.2981054E-05,   2.3430501E-05,   2.3878183E-05
     +,   2.4323726E-05,   2.4766792E-05,   2.5207035E-05
     +,   2.5644165E-05,   2.6077912E-05,   2.6508038E-05
     +,   2.6934355E-05,   2.7356704E-05,   2.7774990E-05
     +,   2.8189157E-05,   2.8599197E-05,   2.9005185E-05
     +,   2.9407231E-05,   2.9805522E-05,   3.0200299E-05
     +,   3.0591902E-05,   3.0980696E-05,   3.1367163E-05
     +,   3.1751828E-05,   3.2135315E-05,   3.2518306E-05
     +,   3.2901564E-05,   3.3285920E-05,   3.3672281E-05
     +,   3.4061632E-05,   3.4455006E-05,   3.4853518E-05
     +,   3.5258319E-05,   3.5670637E-05,   3.6091722E-05
     +,   3.6522895E-05,   3.6965455E-05,   3.7420788E-05
     +,   3.7890244E-05,   3.8375201E-05,   3.8877028E-05
     +,   3.9397051E-05,   3.9936593E-05,   4.0496943E-05
     +,   4.1079300E-05,   4.1684809E-05,   4.2314554E-05
     +,   4.2969506E-05,   4.3650529E-05,   4.4358381E-05
     +,   4.5093722E-05,   4.5856985E-05,   4.6648562E-05
     +,   4.7468628E-05,   4.8317204E-05,   4.9194157E-05
     +,   5.0099163E-05,   5.1031737E-05,   5.1991254E-05
     +,   5.2976826E-05,   5.3987489E-05,   5.5022145E-05
     +,   5.6079429E-05,   5.7157988E-05,   5.8256199E-05
     +,   5.9372502E-05,   6.0505092E-05,   6.1652303E-05
     +,   6.2812214E-05,   6.3983134E-05,   6.5163222E-05
     +,   6.6350811E-05,   6.7544337E-05,   6.8742316E-05
     +,   6.9943380E-05,   7.1146525E-05,   7.2350944E-05
     +,   7.3556002E-05,   7.4761512E-05,   7.5967560E-05
     +,   7.7174656E-05,   7.8383680E-05,   7.9595964E-05
     +,   8.0813232E-05,   8.2037746E-05,   8.3272120E-05
     +,   8.4519532E-05,   8.5783569E-05,   8.7068212E-05
     +,   8.8377805E-05,   8.9717141E-05,   9.1091388E-05
     +,   9.2505790E-05,   9.3965966E-05,   9.5477502E-05
     +,   9.7046213E-05,   9.8677629E-05,   1.0037742E-04
     +,   1.0215071E-04,   1.0400257E-04,   1.0593729E-04
     +,   1.0795882E-04,   1.1007041E-04,   1.1227439E-04
     +,   1.1457212E-04,   1.1696414E-04,   1.1944991E-04
     +,   1.2202738E-04,   1.2469373E-04,   1.2744439E-04
     +,   1.3027382E-04,   1.3317484E-04,   1.3613915E-04
     +,   1.3915687E-04,   1.4221724E-04,   1.4530781E-04
     +,   1.4841535E-04,   1.5152567E-04,   1.5462343E-04
     +,   1.5769257E-04,   1.6071679E-04,   1.6367929E-04
     +,   1.6656294E-04,   1.6935091E-04,   1.7202632E-04
     +,   1.7457313E-04,   1.7697556E-04,   1.7921913E-04
     +,   1.8129020E-04,   1.8317650E-04,   1.8486725E-04
     +,   1.8635325E-04,   1.8762721E-04,   1.8868347E-04
     +,   1.8951869E-04,   1.9013131E-04,   1.9052210E-04
     +,   1.9069384E-04,   1.9065161E-04,   1.9040256E-04
     +,   1.8995602E-04,   1.8932341E-04,   1.8851826E-04
     +,   1.8755617E-04,   1.8645464E-04,   1.8523324E-04
     +,   1.8391355E-04,   1.8251882E-04,   1.8107468E-04
     +,   1.7960853E-04,   1.7815008E-04,   1.7673094E-04
     +,   1.7538515E-04,   1.7414965E-04,   1.7306335E-04
     +,   1.7216837E-04,   1.7150973E-04,   1.7113559E-04
     +,   1.7109743E-04,   1.7145011E-04,   1.7225189E-04
     +,   1.7356439E-04,   1.7545262E-04,   1.7798423E-04
     +,   1.8122951E-04,   1.8526065E-04,   1.9015097E-04
     +,   1.9597364E-04,   2.0280022E-04,   2.1069986E-04
     +,   2.1973730E-04,   2.2996949E-04,   2.4144512E-04
     +,   2.5420153E-04,   2.6826086E-04,   2.8362783E-04
     +,   3.0028838E-04,   3.1820647E-04,   3.3732035E-04
     +,   3.5754271E-04,   3.7876208E-04,   4.0084266E-04
     +,   4.2362668E-04,   4.4694071E-04,   4.7060614E-04
     +,   4.9444888E-04,   5.1830977E-04,   5.4206763E-04
     +,   5.6565413E-04,   5.8907177E-04,   6.1241590E-04
     +,   6.3589471E-04,   6.5984257E-04,   6.8473100E-04
     +,   7.1117672E-04,   7.3994632E-04,   7.7195140E-04
     +,   8.0824521E-04,   8.5002073E-04,   8.9861790E-04
     +,   9.5553842E-04,   1.0224680E-03,   1.1013263E-03
     +,   1.1943141E-03,   1.3039429E-03,   1.4330507E-03
     +,   1.5847565E-03,   1.7622990E-03,   1.9687086E-03
     +,   2.2063314E-03,   2.4762219E-03,   2.7774863E-03
     +,   3.1068234E-03,   3.4585304E-03,   3.8251046E-03
     +,   4.1983207E-03,   4.5707501E-03,   4.9378173E-03
     +,   5.3004408E-03,   5.6684320E-03,   6.0636196E-03
     +,   6.5199365E-03,   7.0774672E-03,   7.7693998E-03
     +,   8.6053964E-03,   9.5584206E-03,   1.0561831E-02
     +,   1.1521998E-02,   1.2348481E-02,   1.2997316E-02
     +,   1.3509857E-02,   1.4018673E-02,   1.4698561E-02
     +,   1.5673123E-02,   1.6924892E-02,   1.8268289E-02
     +,   1.9415207E-02,   2.0107416E-02,   2.0243274E-02
     +,   1.9923031E-02,   1.9381465E-02,   1.8845795E-02
     +,   1.8403077E-02,   1.7959705E-02,   1.7319037E-02
     +,   1.6323082E-02,   1.4958587E-02,   1.3359684E-02
     +,   1.1722108E-02,   1.0202733E-02,   8.8692363E-03
     +,   7.7123055E-03,   6.6892221E-03,   5.7625519E-03
     +,   4.9170307E-03,   4.1573071E-03,   3.4965912E-03
     +,   2.9450969E-03,   2.5030740E-03,   2.1596947E-03
     +,   1.8962522E-03,   1.6910768E-03,   1.5239718E-03
     +,   1.3791097E-03,   1.2460350E-03,   1.1192042E-03
     +,   9.9673611E-04,   8.7898155E-04,   7.6730445E-04
     +,   6.6322455E-04,   5.6793803E-04,   4.8214273E-04
     +,   4.0604454E-04,   3.3942497E-04,   2.8177982E-04
     +,   2.3241126E-04,   1.9053310E-04,   1.5532144E-04
     +,   1.2596886E-04,   1.0170094E-04,   8.1799059E-05
     +,   6.5602093E-05,   5.2515647E-05,   4.2009804E-05
     +,   3.3620789E-05,   2.6949669E-05,   2.1657421E-05
     +,   1.7462202E-05,   1.4132452E-05,   1.1481852E-05
     +,   9.3620283E-06,   7.6569486E-06,   6.2764730E-06
     +,   5.1515281E-06,   4.2291749E-06,   3.4691268E-06
     +,   2.8404243E-06,   2.3192417E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz106 = Yx/0.1345
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0260753E-05,   1.0395082E-05
     +,   1.0530964E-05,   1.0668573E-05,   1.0808104E-05
     +,   1.0949771E-05,   1.1093822E-05,   1.1240530E-05
     +,   1.1390204E-05,   1.1543202E-05,   1.1699915E-05
     +,   1.1860788E-05,   1.2026337E-05,   1.2197127E-05
     +,   1.2373806E-05,   1.2557101E-05,   1.2747843E-05
     +,   1.2946958E-05,   1.3155492E-05,   1.3374627E-05
     +,   1.3605680E-05,   1.3850134E-05,   1.4109638E-05
     +,   1.4386059E-05,   1.4681433E-05,   1.4998050E-05
     +,   1.5338441E-05,   1.5705389E-05,   1.6101962E-05
     +,   1.6531523E-05,   1.6997750E-05,   1.7504630E-05
     +,   1.8056506E-05,   1.8658060E-05,   1.9314322E-05
     +,   2.0030682E-05,   2.0812866E-05,   2.1666938E-05
     +,   2.2599354E-05,   2.3616756E-05,   2.4726185E-05
     +,   2.5934847E-05,   2.7250167E-05,   2.8679717E-05
     +,   3.0231127E-05,   3.1912052E-05,   3.3730044E-05
     +,   3.5692497E-05,   3.7806534E-05,   4.0078881E-05
     +,   4.2515763E-05,   4.5122790E-05,   4.7904759E-05
     +,   5.0865769E-05,   5.4008553E-05,   5.7335044E-05
     +,   6.0845694E-05,   6.4539592E-05,   6.8414280E-05
     +,   7.2465700E-05,   7.6688033E-05,   8.1073806E-05
     +,   8.5613327E-05,   9.0295405E-05,   9.5107040E-05
     +,   1.0003279E-04,   1.0505605E-04,   1.1015782E-04
     +,   1.1531813E-04,   1.2051481E-04,   1.2572498E-04
     +,   1.3092395E-04,   1.3608676E-04,   1.4118711E-04
     +,   1.4619864E-04,   1.5109494E-04,   1.5584935E-04
     +,   1.6043571E-04,   1.6482885E-04,   1.6900465E-04
     +,   1.7293992E-04,   1.7661371E-04,   1.8000641E-04
     +,   1.8310100E-04,   1.8588263E-04,   1.8833918E-04
     +,   1.9046113E-04,   1.9224209E-04,   1.9367838E-04
     +,   1.9476954E-04,   1.9551802E-04,   1.9592934E-04
     +,   1.9601188E-04,   1.9577687E-04,   1.9523803E-04
     +,   1.9441171E-04,   1.9331639E-04,   1.9197246E-04
     +,   1.9040212E-04,   1.8862891E-04,   1.8667732E-04
     +,   1.8457287E-04,   1.8234122E-04,   1.8000853E-04
     +,   1.7760039E-04,   1.7514202E-04,   1.7265805E-04
     +,   1.7017200E-04,   1.6770599E-04,   1.6528062E-04
     +,   1.6291514E-04,   1.6062653E-04,   1.5843016E-04
     +,   1.5633917E-04,   1.5436474E-04,   1.5251567E-04
     +,   1.5079888E-04,   1.4921899E-04,   1.4777874E-04
     +,   1.4647875E-04,   1.4531781E-04,   1.4429305E-04
     +,   1.4339996E-04,   1.4263253E-04,   1.4198350E-04
     +,   1.4144456E-04,   1.4100637E-04,   1.4065897E-04
     +,   1.4039170E-04,   1.4019353E-04,   1.4005334E-04
     +,   1.3995980E-04,   1.3990172E-04,   1.3986815E-04
     +,   1.3984856E-04,   1.3983290E-04,   1.3981166E-04
     +,   1.3977615E-04,   1.3971831E-04,   1.3963107E-04
     +,   1.3950806E-04,   1.3934408E-04,   1.3913483E-04
     +,   1.3887686E-04,   1.3856775E-04,   1.3820616E-04
     +,   1.3779162E-04,   1.3732466E-04,   1.3680679E-04
     +,   1.3624025E-04,   1.3562836E-04,   1.3497518E-04
     +,   1.3428577E-04,   1.3356586E-04,   1.3282200E-04
     +,   1.3206172E-04,   1.3129335E-04,   1.3052604E-04
     +,   1.2976993E-04,   1.2903629E-04,   1.2833728E-04
     +,   1.2768641E-04,   1.2709860E-04,   1.2659018E-04
     +,   1.2617926E-04,   1.2588582E-04,   1.2573198E-04
     +,   1.2574212E-04,   1.2594330E-04,   1.2636534E-04
     +,   1.2704091E-04,   1.2800591E-04,   1.2929949E-04
     +,   1.3096399E-04,   1.3304486E-04,   1.3559057E-04
     +,   1.3865237E-04,   1.4228334E-04,   1.4653808E-04
     +,   1.5147186E-04,   1.5713961E-04,   1.6359444E-04
     +,   1.7088593E-04,   1.7906001E-04,   1.8815635E-04
     +,   1.9820673E-04,   2.0923390E-04,   2.2125132E-04
     +,   2.3426184E-04,   2.4825608E-04,   2.6321528E-04
     +,   2.7911121E-04,   2.9590743E-04,   3.1356225E-04
     +,   3.3203498E-04,   3.5128806E-04,   3.7129177E-04
     +,   3.9203133E-04,   4.1351377E-04,   4.3577311E-04
     +,   4.5887468E-04,   4.8292239E-04,   5.0806685E-04
     +,   5.3451036E-04,   5.6251086E-04,   5.9239706E-04
     +,   6.2457263E-04,   6.5952260E-04,   6.9781928E-04
     +,   7.4012578E-04,   7.8718405E-04,   8.3979912E-04
     +,   8.9881942E-04,   9.6511573E-04,   1.0395632E-03
     +,   1.1230300E-03,   1.2163862E-03,   1.3205423E-03
     +,   1.4364728E-03,   1.5652393E-03,   1.7080227E-03
     +,   1.8660866E-03,   2.0407189E-03,   2.2331669E-03
     +,   2.4446088E-03,   2.6761547E-03,   2.9289324E-03
     +,   3.2043429E-03,   3.5046178E-03,   3.8340064E-03
     +,   4.2010690E-03,   4.6222424E-03,   5.1254798E-03
     +,   5.7503739E-03,   6.5396358E-03,   7.5189029E-03
     +,   8.6697638E-03,   9.9132136E-03,   1.1125156E-02
     +,   1.2189100E-02,   1.3059488E-02,   1.3790260E-02
     +,   1.4501384E-02,   1.5303144E-02,   1.6230110E-02
     +,   1.7226823E-02,   1.8188307E-02,   1.9024890E-02
     +,   1.9702939E-02,   2.0227447E-02,   2.0581217E-02
     +,   2.0685727E-02,   2.0432275E-02,   1.9757643E-02
     +,   1.8692279E-02,   1.7342987E-02,   1.5836820E-02
     +,   1.4272735E-02,   1.2706824E-02,   1.1166095E-02
     +,   9.6714403E-03,   8.2518309E-03,   6.9429828E-03
     +,   5.7762195E-03,   4.7680624E-03,   3.9174906E-03
     +,   3.2108275E-03,   2.6287020E-03,   2.1510613E-03
     +,   1.7594986E-03,   1.4380527E-03,   1.1734671E-03
     +,   9.5521891E-04,   7.7528163E-04,   6.2758598E-04
     +,   5.0732843E-04,   4.1034090E-04,   3.3278659E-04
     +,   2.7106144E-04,   2.2190016E-04,   1.8248706E-04
     +,   1.5055003E-04,   1.2435534E-04,   1.0265247E-04
     +,   8.4565007E-05,   6.9485533E-05,   5.6973749E-05
     +,   4.6686171E-05,   3.8330130E-05,   3.1636871E-05
     +,   2.6354477E-05,   2.2245626E-05,   1.9092544E-05
     +,   1.6699965E-05,   1.4898874E-05,   1.3546894E-05
     +,   1.2528039E-05,   1.1750204E-05,   1.1142452E-05
     +,   1.0651435E-05,   1.0238197E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz108 = Yx/0.126
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8606812E-05,   1.8975630E-05
     +,   1.9347824E-05,   1.9723442E-05,   2.0102556E-05
     +,   2.0485233E-05,   2.0871574E-05,   2.1261680E-05
     +,   2.1655669E-05,   2.2053689E-05,   2.2455888E-05
     +,   2.2862439E-05,   2.3273535E-05,   2.3689379E-05
     +,   2.4110208E-05,   2.4536264E-05,   2.4967820E-05
     +,   2.5405165E-05,   2.5848609E-05,   2.6298487E-05
     +,   2.6755151E-05,   2.7218975E-05,   2.7690357E-05
     +,   2.8169730E-05,   2.8657503E-05,   2.9154169E-05
     +,   2.9660194E-05,   3.0176088E-05,   3.0702369E-05
     +,   3.1239564E-05,   3.1788251E-05,   3.2348984E-05
     +,   3.2922362E-05,   3.3508983E-05,   3.4109449E-05
     +,   3.4724388E-05,   3.5354431E-05,   3.6000201E-05
     +,   3.6662361E-05,   3.7341521E-05,   3.8038328E-05
     +,   3.8753424E-05,   3.9487426E-05,   4.0240950E-05
     +,   4.1014588E-05,   4.1808937E-05,   4.2624553E-05
     +,   4.3461969E-05,   4.4321714E-05,   4.5204251E-05
     +,   4.6110043E-05,   4.7039466E-05,   4.7992908E-05
     +,   4.8970713E-05,   4.9973103E-05,   5.1000330E-05
     +,   5.2052535E-05,   5.3129825E-05,   5.4232241E-05
     +,   5.5359727E-05,   5.6512206E-05,   5.7689511E-05
     +,   5.8891310E-05,   6.0117334E-05,   6.1367187E-05
     +,   6.2640313E-05,   6.3936161E-05,   6.5254018E-05
     +,   6.6593173E-05,   6.7952686E-05,   6.9331712E-05
     +,   7.0729075E-05,   7.2143768E-05,   7.3574447E-05
     +,   7.5019823E-05,   7.6478529E-05,   7.7948986E-05
     +,   7.9429577E-05,   8.0918646E-05,   8.2414437E-05
     +,   8.3914987E-05,   8.5418469E-05,   8.6922744E-05
     +,   8.8425782E-05,   8.9925350E-05,   9.1419286E-05
     +,   9.2905182E-05,   9.4380819E-05,   9.5843629E-05
     +,   9.7291246E-05,   9.8721233E-05,   1.0013100E-04
     +,   1.0151796E-04,   1.0287960E-04,   1.0421344E-04
     +,   1.0551680E-04,   1.0678721E-04,   1.0802205E-04
     +,   1.0921893E-04,   1.1037530E-04,   1.1148884E-04
     +,   1.1255711E-04,   1.1357796E-04,   1.1454908E-04
     +,   1.1546846E-04,   1.1633408E-04,   1.1714413E-04
     +,   1.1789677E-04,   1.1859044E-04,   1.1922375E-04
     +,   1.1979535E-04,   1.2030414E-04,   1.2074916E-04
     +,   1.2112969E-04,   1.2144518E-04,   1.2169526E-04
     +,   1.2187984E-04,   1.2199896E-04,   1.2205294E-04
     +,   1.2204239E-04,   1.2196798E-04,   1.2183082E-04
     +,   1.2163209E-04,   1.2137337E-04,   1.2105633E-04
     +,   1.2068292E-04,   1.2025534E-04,   1.1977609E-04
     +,   1.1924774E-04,   1.1867323E-04,   1.1805562E-04
     +,   1.1739823E-04,   1.1670456E-04,   1.1597830E-04
     +,   1.1522337E-04,   1.1444378E-04,   1.1364377E-04
     +,   1.1282782E-04,   1.1200043E-04,   1.1116624E-04
     +,   1.1033022E-04,   1.0949726E-04,   1.0867250E-04
     +,   1.0786115E-04,   1.0706860E-04,   1.0630032E-04
     +,   1.0556188E-04,   1.0485899E-04,   1.0419750E-04
     +,   1.0358328E-04,   1.0302236E-04,   1.0252092E-04
     +,   1.0208519E-04,   1.0172149E-04,   1.0143627E-04
     +,   1.0123603E-04,   1.0112741E-04,   1.0111708E-04
     +,   1.0121179E-04,   1.0141835E-04,   1.0174362E-04
     +,   1.0219447E-04,   1.0277779E-04,   1.0350046E-04
     +,   1.0436935E-04,   1.0539140E-04,   1.0657340E-04
     +,   1.0792209E-04,   1.0944434E-04,   1.1114698E-04
     +,   1.1303678E-04,   1.1512060E-04,   1.1740557E-04
     +,   1.1989901E-04,   1.2260834E-04,   1.2554174E-04
     +,   1.2870807E-04,   1.3211668E-04,   1.3577791E-04
     +,   1.3970355E-04,   1.4390687E-04,   1.4840248E-04
     +,   1.5320697E-04,   1.5833917E-04,   1.6382044E-04
     +,   1.6967427E-04,   1.7592672E-04,   1.8260702E-04
     +,   1.8974746E-04,   1.9738251E-04,   2.0555071E-04
     +,   2.1429377E-04,   2.2365668E-04,   2.3368903E-04
     +,   2.4444584E-04,   2.5598903E-04,   2.6838834E-04
     +,   2.8172432E-04,   2.9609291E-04,   3.1160880E-04
     +,   3.2840896E-04,   3.4665994E-04,   3.6656504E-04
     +,   3.8837024E-04,   4.1236909E-04,   4.3891190E-04
     +,   4.6840866E-04,   5.0132745E-04,   5.3819228E-04
     +,   5.7957636E-04,   6.2608375E-04,   6.7832100E-04
     +,   7.3686900E-04,   8.0225331E-04,   8.7490783E-04
     +,   9.5514662E-04,   1.0431567E-03,   1.1390168E-03
     +,   1.2427233E-03,   1.3542160E-03,   1.4734401E-03
     +,   1.6003343E-03,   1.7347827E-03,   1.8765194E-03
     +,   2.0250001E-03,   2.1792569E-03,   2.3378157E-03
     +,   2.4987611E-03,   2.6599397E-03,   2.8192729E-03
     +,   2.9751251E-03,   3.1267107E-03,   3.2744613E-03
     +,   3.4204100E-03,   3.5685746E-03,   3.7254079E-03
     +,   3.9002246E-03,   4.1056182E-03,   4.3579312E-03
     +,   4.6777120E-03,   5.0895941E-03,   5.6206314E-03
     +,   6.2956964E-03,   7.1294070E-03,   8.1161456E-03
     +,   9.2226081E-03,   1.0388887E-02,   1.1541704E-02
     +,   1.2617168E-02,   1.3583155E-02,   1.4448427E-02
     +,   1.5251586E-02,   1.6035790E-02,   1.6819479E-02
     +,   1.7570371E-02,   1.8192306E-02,   1.8544093E-02
     +,   1.8498272E-02,   1.8011188E-02,   1.7153354E-02
     +,   1.6076759E-02,   1.4943388E-02,   1.3861507E-02
     +,   1.2858178E-02,   1.1890538E-02,   1.0884305E-02
     +,   9.7809713E-03,   8.5712420E-03,   7.2991787E-03
     +,   6.0398970E-03,   4.8685651E-03,   3.8383494E-03
     +,   2.9737365E-03,   2.2752844E-03,   1.7283248E-03
     +,   1.3105606E-03,   9.9719013E-04,   7.6439860E-04
     +,   5.9136015E-04,   4.6133823E-04,   3.6178442E-04
     +,   2.8388578E-04,   2.2174190E-04,   1.7154899E-04
     +,   1.3086318E-04,   9.8066041E-05,   7.1976545E-05
     +,   5.1622257E-05,   3.6119312E-05,   2.4625318E-05
     +,   1.6347243E-05,   1.0561330E-05,   6.6392527E-06
     +,   4.0607811E-06,   2.4167789E-06,   1.3998190E-06
     +,   7.8936671E-07,   4.3359748E-07,   2.3223764E-07
     +,   1.2149077E-07,   6.2272903E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz110 = Yx/0.11319512195122
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz111(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7505554E-05,   1.8295588E-05
     +,   1.9116467E-05,   1.9968282E-05,   2.0851016E-05
     +,   2.1764548E-05,   2.2708649E-05,   2.3682964E-05
     +,   2.4686993E-05,   2.5720174E-05,   2.6781760E-05
     +,   2.7870896E-05,   2.8986582E-05,   3.0127701E-05
     +,   3.1292999E-05,   3.2481090E-05,   3.3690474E-05
     +,   3.4919514E-05,   3.6166457E-05,   3.7429450E-05
     +,   3.8706537E-05,   3.9995630E-05,   4.1294585E-05
     +,   4.2601238E-05,   4.3913195E-05,   4.5228189E-05
     +,   4.6543802E-05,   4.7857618E-05,   4.9167225E-05
     +,   5.0470175E-05,   5.1764087E-05,   5.3046591E-05
     +,   5.4315362E-05,   5.5568151E-05,   5.6802808E-05
     +,   5.8017267E-05,   5.9209597E-05,   6.0377981E-05
     +,   6.1520826E-05,   6.2636580E-05,   6.3724023E-05
     +,   6.4781998E-05,   6.5809683E-05,   6.6806337E-05
     +,   6.7771587E-05,   6.8705194E-05,   6.9607246E-05
     +,   7.0478025E-05,   7.1318078E-05,   7.2128249E-05
     +,   7.2909577E-05,   7.3663410E-05,   7.4391275E-05
     +,   7.5095013E-05,   7.5776625E-05,   7.6438388E-05
     +,   7.7082768E-05,   7.7712371E-05,   7.8330042E-05
     +,   7.8938698E-05,   7.9541489E-05,   8.0141566E-05
     +,   8.0742189E-05,   8.1346683E-05,   8.1958431E-05
     +,   8.2580707E-05,   8.3216895E-05,   8.3870145E-05
     +,   8.4543659E-05,   8.5240397E-05,   8.5963315E-05
     +,   8.6714950E-05,   8.7497901E-05,   8.8314329E-05
     +,   8.9166184E-05,   9.0055175E-05,   9.0982634E-05
     +,   9.1949587E-05,   9.2956718E-05,   9.4004376E-05
     +,   9.5092451E-05,   9.6220596E-05,   9.7387929E-05
     +,   9.8593307E-05,   9.9835102E-05,   1.0111142E-04
     +,   1.0241985E-04,   1.0375783E-04,   1.0512227E-04
     +,   1.0650984E-04,   1.0791703E-04,   1.0933990E-04
     +,   1.1077432E-04,   1.1221596E-04,   1.1366041E-04
     +,   1.1510297E-04,   1.1653901E-04,   1.1796373E-04
     +,   1.1937229E-04,   1.2076002E-04,   1.2212218E-04
     +,   1.2345416E-04,   1.2475159E-04,   1.2601013E-04
     +,   1.2722577E-04,   1.2839478E-04,   1.2951357E-04
     +,   1.3057895E-04,   1.3158807E-04,   1.3253855E-04
     +,   1.3342818E-04,   1.3425536E-04,   1.3501875E-04
     +,   1.3571756E-04,   1.3635130E-04,   1.3692008E-04
     +,   1.3742436E-04,   1.3786499E-04,   1.3824328E-04
     +,   1.3856104E-04,   1.3882037E-04,   1.3902374E-04
     +,   1.3917412E-04,   1.3927471E-04,   1.3932906E-04
     +,   1.3934101E-04,   1.3931472E-04,   1.3925455E-04
     +,   1.3916506E-04,   1.3905109E-04,   1.3891752E-04
     +,   1.3876955E-04,   1.3861223E-04,   1.3845094E-04
     +,   1.3829091E-04,   1.3813762E-04,   1.3799635E-04
     +,   1.3787257E-04,   1.3777157E-04,   1.3769871E-04
     +,   1.3765920E-04,   1.3765841E-04,   1.3770143E-04
     +,   1.3779342E-04,   1.3793954E-04,   1.3814491E-04
     +,   1.3841454E-04,   1.3875363E-04,   1.3916734E-04
     +,   1.3966103E-04,   1.4024008E-04,   1.4091014E-04
     +,   1.4167713E-04,   1.4254705E-04,   1.4352666E-04
     +,   1.4462265E-04,   1.4584257E-04,   1.4719421E-04
     +,   1.4868623E-04,   1.5032751E-04,   1.5212786E-04
     +,   1.5409772E-04,   1.5624808E-04,   1.5859058E-04
     +,   1.6113768E-04,   1.6390231E-04,   1.6689784E-04
     +,   1.7013814E-04,   1.7363724E-04,   1.7740970E-04
     +,   1.8146956E-04,   1.8583082E-04,   1.9050711E-04
     +,   1.9551138E-04,   2.0085541E-04,   2.0655004E-04
     +,   2.1260482E-04,   2.1902729E-04,   2.2582320E-04
     +,   2.3299684E-04,   2.4055061E-04,   2.4848469E-04
     +,   2.5679756E-04,   2.6548706E-04,   2.7455037E-04
     +,   2.8398415E-04,   2.9378588E-04,   3.0395575E-04
     +,   3.1449768E-04,   3.2541930E-04,   3.3673627E-04
     +,   3.4847343E-04,   3.6066584E-04,   3.7336277E-04
     +,   3.8663117E-04,   4.0055771E-04,   4.1525144E-04
     +,   4.3084781E-04,   4.4751298E-04,   4.6544592E-04
     +,   4.8488032E-04,   5.0608790E-04,   5.2938086E-04
     +,   5.5511465E-04,   5.8368378E-04,   6.1553036E-04
     +,   6.5114175E-04,   6.9104705E-04,   7.3581940E-04
     +,   7.8606931E-04,   8.4243173E-04,   9.0553629E-04
     +,   9.7596989E-04,   1.0542246E-03,   1.1406160E-03
     +,   1.2351854E-03,   1.3376059E-03,   1.4470959E-03
     +,   1.5623460E-03,   1.6814894E-03,   1.8021694E-03
     +,   1.9216537E-03,   2.0370407E-03,   2.1455600E-03
     +,   2.2449149E-03,   2.3336515E-03,   2.4114796E-03
     +,   2.4795672E-03,   2.5406939E-03,   2.5992482E-03
     +,   2.6610265E-03,   2.7328341E-03,   2.8218874E-03
     +,   2.9350775E-03,   3.0781871E-03,   3.2552599E-03
     +,   3.4681999E-03,   3.7167207E-03,   3.9987122E-03
     +,   4.3109432E-03,   4.6498864E-03,   5.0125271E-03
     +,   5.3970776E-03,   5.8035743E-03,   6.2347045E-03
     +,   6.6974275E-03,   7.2055408E-03,   7.7820006E-03
     +,   8.4583489E-03,   9.2689060E-03,   1.0240629E-02
     +,   1.1382252E-02,   1.2677120E-02,   1.4082976E-02
     +,   1.5539645E-02,   1.6984204E-02,   1.8367404E-02
     +,   1.9654445E-02,   2.0798067E-02,   2.1701749E-02
     +,   2.2217484E-02,   2.2202708E-02,   2.1599362E-02
     +,   2.0467201E-02,   1.8944845E-02,   1.7179655E-02
     +,   1.5285141E-02,   1.3340722E-02,   1.1408690E-02
     +,   9.5447619E-03,   7.7999071E-03,   6.2188022E-03
     +,   4.8367511E-03,   3.6751777E-03,   2.7378185E-03
     +,   2.0106169E-03,   1.4657394E-03,   1.0685227E-03
     +,   7.8382751E-04,   5.8073847E-04,   4.3471437E-04
     +,   3.2790779E-04,   2.4815783E-04,   1.8755226E-04
     +,   1.4098769E-04,   1.0509123E-04,   7.7494435E-05
     +,   5.6428427E-05,   4.0510098E-05,   2.8627772E-05
     +,   1.9884359E-05,   1.3553944E-05,   9.0537960E-06
     +,   5.9185772E-06,   3.7820571E-06,   2.3600192E-06
     +,   1.4369199E-06,   8.5304868E-07,   4.9354156E-07
     +,   2.7815656E-07,   1.5266943E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz111 = Yx/0.124333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5920913E-06,   6.7953006E-06
     +,   7.0074275E-06,   7.2290854E-06,   7.4609334E-06
     +,   7.7036784E-06,   7.9580768E-06,   8.2249417E-06
     +,   8.5051342E-06,   8.7995923E-06,   9.1092979E-06
     +,   9.4353018E-06,   9.7787215E-06,   1.0140745E-05
     +,   1.0522626E-05,   1.0925696E-05,   1.1351356E-05
     +,   1.1801083E-05,   1.2276432E-05,   1.2779031E-05
     +,   1.3310587E-05,   1.3872884E-05,   1.4467762E-05
     +,   1.5097187E-05,   1.5763113E-05,   1.6467631E-05
     +,   1.7212860E-05,   1.8000981E-05,   1.8834222E-05
     +,   1.9714855E-05,   2.0645173E-05,   2.1627517E-05
     +,   2.2664197E-05,   2.3757548E-05,   2.4909878E-05
     +,   2.6123447E-05,   2.7400478E-05,   2.8743087E-05
     +,   3.0153386E-05,   3.1633201E-05,   3.3184402E-05
     +,   3.4808567E-05,   3.6507125E-05,   3.8281276E-05
     +,   4.0131963E-05,   4.2059884E-05,   4.4065378E-05
     +,   4.6148507E-05,   4.8308913E-05,   5.0545899E-05
     +,   5.2858319E-05,   5.5244604E-05,   5.7702688E-05
     +,   6.0230206E-05,   6.2823921E-05,   6.5480519E-05
     +,   6.8195899E-05,   7.0965514E-05,   7.3784337E-05
     +,   7.6646786E-05,   7.9546851E-05,   8.2478029E-05
     +,   8.5433254E-05,   8.8405213E-05,   9.1386348E-05
     +,   9.4368421E-05,   9.7343313E-05,   1.0030241E-04
     +,   1.0323729E-04,   1.0613921E-04,   1.0899972E-04
     +,   1.1181036E-04,   1.1456299E-04,   1.1724978E-04
     +,   1.1986341E-04,   1.2239722E-04,   1.2484503E-04
     +,   1.2720148E-04,   1.2946231E-04,   1.3162426E-04
     +,   1.3368500E-04,   1.3564371E-04,   1.3750061E-04
     +,   1.3925771E-04,   1.4091817E-04,   1.4248697E-04
     +,   1.4397051E-04,   1.4537710E-04,   1.4671643E-04
     +,   1.4800004E-04,   1.4924117E-04,   1.5045451E-04
     +,   1.5165619E-04,   1.5286404E-04,   1.5409695E-04
     +,   1.5537502E-04,   1.5671934E-04,   1.5815160E-04
     +,   1.5969414E-04,   1.6136940E-04,   1.6319992E-04
     +,   1.6520754E-04,   1.6741383E-04,   1.6983878E-04
     +,   1.7250136E-04,   1.7541874E-04,   1.7860549E-04
     +,   1.8207393E-04,   1.8583344E-04,   1.8989040E-04
     +,   1.9424698E-04,   1.9890243E-04,   2.0385088E-04
     +,   2.0908324E-04,   2.1458510E-04,   2.2033842E-04
     +,   2.2631987E-04,   2.3250237E-04,   2.3885412E-04
     +,   2.4533947E-04,   2.5191912E-04,   2.5855014E-04
     +,   2.6518627E-04,   2.7177951E-04,   2.7827994E-04
     +,   2.8463546E-04,   2.9079456E-04,   2.9670465E-04
     +,   3.0231502E-04,   3.0757551E-04,   3.1243902E-04
     +,   3.1686065E-04,   3.2079977E-04,   3.2421926E-04
     +,   3.2708712E-04,   3.2937698E-04,   3.3106728E-04
     +,   3.3214281E-04,   3.3259456E-04,   3.3241964E-04
     +,   3.3162153E-04,   3.3020967E-04,   3.2819994E-04
     +,   3.2561354E-04,   3.2247705E-04,   3.1882233E-04
     +,   3.1468508E-04,   3.1010533E-04,   3.0512662E-04
     +,   2.9979454E-04,   2.9415690E-04,   2.8826325E-04
     +,   2.8216394E-04,   2.7590903E-04,   2.6954865E-04
     +,   2.6313201E-04,   2.5670746E-04,   2.5032111E-04
     +,   2.4401695E-04,   2.3783751E-04,   2.3182240E-04
     +,   2.2600824E-04,   2.2042976E-04,   2.1511884E-04
     +,   2.1010425E-04,   2.0541254E-04,   2.0106777E-04
     +,   1.9709175E-04,   1.9350390E-04,   1.9032140E-04
     +,   1.8755993E-04,   1.8523324E-04,   1.8335322E-04
     +,   1.8193026E-04,   1.8097337E-04,   1.8048985E-04
     +,   1.8048564E-04,   1.8096523E-04,   1.8193159E-04
     +,   1.8338629E-04,   1.8532941E-04,   1.8775977E-04
     +,   1.9067485E-04,   1.9407159E-04,   1.9794644E-04
     +,   2.0229601E-04,   2.0711772E-04,   2.1241157E-04
     +,   2.1818110E-04,   2.2443439E-04,   2.3118683E-04
     +,   2.3846336E-04,   2.4629943E-04,   2.5474414E-04
     +,   2.6386348E-04,   2.7374117E-04,   2.8448045E-04
     +,   2.9620537E-04,   3.0906158E-04,   3.2321509E-04
     +,   3.3884897E-04,   3.5615967E-04,   3.7535292E-04
     +,   3.9663489E-04,   4.2020163E-04,   4.4623230E-04
     +,   4.7487626E-04,   5.0624122E-04,   5.4038496E-04
     +,   5.7731074E-04,   6.1696250E-04,   6.5922469E-04
     +,   7.0393138E-04,   7.5088383E-04,   7.9986727E-04
     +,   8.5067161E-04,   9.0312166E-04,   9.5710671E-04
     +,   1.0125979E-03,   1.0696570E-03,   1.1284458E-03
     +,   1.1892054E-03,   1.2522199E-03,   1.3177739E-03
     +,   1.3861026E-03,   1.4573416E-03,   1.5315019E-03
     +,   1.6084962E-03,   1.6882461E-03,   1.7708449E-03
     +,   1.8567999E-03,   1.9472990E-03,   2.0444340E-03
     +,   2.1512466E-03,   2.2715463E-03,   2.4095075E-03
     +,   2.5690855E-03,   2.7534468E-03,   2.9647211E-03
     +,   3.2040975E-03,   3.4722425E-03,   3.7698345E-03
     +,   4.0980526E-03,   4.4589699E-03,   4.8560412E-03
     +,   5.2947849E-03,   5.7833693E-03,   6.3320911E-03
     +,   6.9506518E-03,   7.6434226E-03,   8.4053911E-03
     +,   9.2224851E-03,   1.0079311E-02,   1.0971913E-02
     +,   1.1916610E-02,   1.2944759E-02,   1.4081380E-02
     +,   1.5317855E-02,   1.6595451E-02,   1.7810777E-02
     +,   1.8839199E-02,   1.9561950E-02,   1.9884109E-02
     +,   1.9741753E-02,   1.9105868E-02,   1.7988026E-02
     +,   1.6446721E-02,   1.4587278E-02,   1.2550402E-02
     +,   1.0489200E-02,   8.5423198E-03,   6.8116849E-03
     +,   5.3512645E-03,   4.1694264E-03,   3.2411201E-03
     +,   2.5236921E-03,   1.9705894E-03,   1.5406823E-03
     +,   1.2020934E-03,   9.3242305E-04,   7.1666518E-04
     +,   5.4473907E-04,   4.0928603E-04,   3.0433171E-04
     +,   2.2457354E-04,   1.6520052E-04,   1.2188828E-04
     +,   9.0879432E-05,   6.9027854E-05,   5.3788510E-05
     +,   4.3179396E-05,   3.5708257E-05,   3.0295552E-05
     +,   2.6190948E-05,   2.2898354E-05,   2.0107294E-05
     +,   1.7637407E-05,   1.5393212E-05,   1.3331571E-05
     +,   1.1437798E-05,   9.7108823E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz112 = Yx/0.109951219512195
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz1128(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2399261E-05,   2.3023522E-05
     +,   2.3656454E-05,   2.4297686E-05,   2.4946812E-05
     +,   2.5603413E-05,   2.6267046E-05,   2.6937263E-05
     +,   2.7613598E-05,   2.8295603E-05,   2.8982791E-05
     +,   2.9674689E-05,   3.0370838E-05,   3.1070762E-05
     +,   3.1774041E-05,   3.2480224E-05,   3.3188931E-05
     +,   3.3899792E-05,   3.4612483E-05,   3.5326731E-05
     +,   3.6042326E-05,   3.6759113E-05,   3.7477024E-05
     +,   3.8196093E-05,   3.8916409E-05,   3.9638231E-05
     +,   4.0361901E-05,   4.1087904E-05,   4.1816886E-05
     +,   4.2549644E-05,   4.3287146E-05,   4.4030570E-05
     +,   4.4781267E-05,   4.5540834E-05,   4.6311066E-05
     +,   4.7094025E-05,   4.7892005E-05,   4.8707563E-05
     +,   4.9543567E-05,   5.0403069E-05,   5.1289513E-05
     +,   5.2206567E-05,   5.3158205E-05,   5.4148681E-05
     +,   5.5182525E-05,   5.6264587E-05,   5.7399931E-05
     +,   5.8593898E-05,   5.9852046E-05,   6.1180195E-05
     +,   6.2584259E-05,   6.4070380E-05,   6.5644781E-05
     +,   6.7313835E-05,   6.9083770E-05,   7.0961018E-05
     +,   7.2951814E-05,   7.5062249E-05,   7.7298311E-05
     +,   7.9665624E-05,   8.2169565E-05,   8.4815125E-05
     +,   8.7606662E-05,   9.0548187E-05,   9.3643081E-05
     +,   9.6893782E-05,   1.0030228E-04,   1.0386934E-04
     +,   1.0759525E-04,   1.1147877E-04,   1.1551819E-04
     +,   1.1971011E-04,   1.2405045E-04,   1.2853349E-04
     +,   1.3315259E-04,   1.3789987E-04,   1.4276589E-04
     +,   1.4773989E-04,   1.5281014E-04,   1.5796370E-04
     +,   1.6318593E-04,   1.6846161E-04,   1.7377379E-04
     +,   1.7910523E-04,   1.8443697E-04,   1.8974996E-04
     +,   1.9502379E-04,   2.0023808E-04,   2.0537141E-04
     +,   2.1040261E-04,   2.1531018E-04,   2.2007250E-04
     +,   2.2466833E-04,   2.2907677E-04,   2.3327765E-04
     +,   2.3725134E-04,   2.4097928E-04,   2.4444380E-04
     +,   2.4762884E-04,   2.5051937E-04,   2.5310216E-04
     +,   2.5536565E-04,   2.5730007E-04,   2.5889740E-04
     +,   2.6015186E-04,   2.6105961E-04,   2.6161884E-04
     +,   2.6183005E-04,   2.6169582E-04,   2.6122059E-04
     +,   2.6041133E-04,   2.5927657E-04,   2.5782723E-04
     +,   2.5607558E-04,   2.5403625E-04,   2.5172476E-04
     +,   2.4915868E-04,   2.4635668E-04,   2.4333854E-04
     +,   2.4012504E-04,   2.3673754E-04,   2.3319833E-04
     +,   2.2953027E-04,   2.2575598E-04,   2.2189808E-04
     +,   2.1797964E-04,   2.1402282E-04,   2.1004988E-04
     +,   2.0608185E-04,   2.0213950E-04,   1.9824220E-04
     +,   1.9440893E-04,   1.9065678E-04,   1.8700234E-04
     +,   1.8346045E-04,   1.8004443E-04,   1.7676680E-04
     +,   1.7363823E-04,   1.7066784E-04,   1.6786349E-04
     +,   1.6523154E-04,   1.6277691E-04,   1.6050316E-04
     +,   1.5841228E-04,   1.5650543E-04,   1.5478198E-04
     +,   1.5324056E-04,   1.5187857E-04,   1.5069256E-04
     +,   1.4967787E-04,   1.4882942E-04,   1.4814112E-04
     +,   1.4760649E-04,   1.4721839E-04,   1.4696935E-04
     +,   1.4685155E-04,   1.4685695E-04,   1.4697739E-04
     +,   1.4720470E-04,   1.4753077E-04,   1.4794756E-04
     +,   1.4844730E-04,   1.4902269E-04,   1.4966662E-04
     +,   1.5037277E-04,   1.5113514E-04,   1.5194876E-04
     +,   1.5280924E-04,   1.5371334E-04,   1.5465904E-04
     +,   1.5564542E-04,   1.5667311E-04,   1.5774441E-04
     +,   1.5886359E-04,   1.6003693E-04,   1.6127319E-04
     +,   1.6258385E-04,   1.6398328E-04,   1.6548915E-04
     +,   1.6712306E-04,   1.6891053E-04,   1.7088138E-04
     +,   1.7307044E-04,   1.7551781E-04,   1.7826942E-04
     +,   1.8137698E-04,   1.8489869E-04,   1.8890000E-04
     +,   1.9345339E-04,   1.9863837E-04,   2.0454249E-04
     +,   2.1126097E-04,   2.1889596E-04,   2.2755632E-04
     +,   2.3735804E-04,   2.4842253E-04,   2.6087448E-04
     +,   2.7484095E-04,   2.9045026E-04,   3.0782921E-04
     +,   3.2709917E-04,   3.4837346E-04,   3.7175693E-04
     +,   3.9734130E-04,   4.2519943E-04,   4.5538752E-04
     +,   4.8794135E-04,   5.2287243E-04,   5.6016882E-04
     +,   5.9979985E-04,   6.4171670E-04,   6.8585511E-04
     +,   7.3214388E-04,   7.8051660E-04,   8.3091954E-04
     +,   8.8331627E-04,   9.3769369E-04,   9.9406904E-04
     +,   1.0524776E-03,   1.1129528E-03,   1.1755119E-03
     +,   1.2401300E-03,   1.3067065E-03,   1.3750609E-03
     +,   1.4449438E-03,   1.5160701E-03,   1.5881815E-03
     +,   1.6611444E-03,   1.7350628E-03,   1.8103702E-03
     +,   1.8878808E-03,   1.9687810E-03,   2.0545400E-03
     +,   2.1467172E-03,   2.2467293E-03,   2.3556510E-03
     +,   2.4740843E-03,   2.6022047E-03,   2.7400330E-03
     +,   2.8879389E-03,   3.0472726E-03,   3.2210257E-03
     +,   3.4143659E-03,   3.6348777E-03,   3.8922715E-03
     +,   4.1975202E-03,   4.5614680E-03,   4.9932431E-03
     +,   5.4987767E-03,   6.0799215E-03,   6.7342743E-03
     +,   7.4552177E-03,   8.2315048E-03,   9.0466682E-03
     +,   9.8792445E-03,   1.0705256E-02,   1.1504551E-02
     +,   1.2269022E-02,   1.3007839E-02,   1.3743233E-02
     +,   1.4494504E-02,   1.5255643E-02,   1.5978292E-02
     +,   1.6571552E-02,   1.6922176E-02,   1.6926611E-02
     +,   1.6520876E-02,   1.5696356E-02,   1.4498596E-02
     +,   1.3013220E-02,   1.1347929E-02,   9.6155806E-03
     +,   7.9206862E-03,   6.3492130E-03,   4.9618692E-03
     +,   3.7912170E-03,   2.8428496E-03,   2.1013140E-03
     +,   1.5378922E-03,   1.1188663E-03,   8.1159530E-04
     +,   5.8818544E-04,   4.2655392E-04,   3.1007230E-04
     +,   2.2644039E-04,   1.6659386E-04,   1.2380267E-04
     +,   9.3080496E-05,   7.0784808E-05,   5.4318414E-05
     +,   4.1895004E-05,   3.2323351E-05,   2.4830075E-05
     +,   1.8912757E-05,   1.4236842E-05,   1.0564218E-05
     +,   7.7125424E-06,   5.5316054E-06,   3.8932922E-06
     +,   2.6865446E-06,   1.8162449E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz1128 = Yx/0.10185
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.8543448E-06,   5.1234201E-06
     +,   5.4050447E-06,   5.6997242E-06,   6.0079865E-06
     +,   6.3303837E-06,   6.6674997E-06,   7.0199458E-06
     +,   7.3883530E-06,   7.7734139E-06,   8.1758335E-06
     +,   8.5963629E-06,   9.0357944E-06,   9.4949619E-06
     +,   9.9747485E-06,   1.0476081E-05,   1.0999936E-05
     +,   1.1547352E-05,   1.2119413E-05,   1.2717260E-05
     +,   1.3342094E-05,   1.3995180E-05,   1.4677820E-05
     +,   1.5391437E-05,   1.6137421E-05,   1.6917314E-05
     +,   1.7732664E-05,   1.8585089E-05,   1.9476267E-05
     +,   2.0407924E-05,   2.1381835E-05,   2.2399810E-05
     +,   2.3463723E-05,   2.4575449E-05,   2.5736890E-05
     +,   2.6949991E-05,   2.8216671E-05,   2.9538838E-05
     +,   3.0918469E-05,   3.2357355E-05,   3.3857410E-05
     +,   3.5420395E-05,   3.7048023E-05,   3.8741939E-05
     +,   4.0503666E-05,   4.2334632E-05,   4.4236116E-05
     +,   4.6209265E-05,   4.8255053E-05,   5.0374270E-05
     +,   5.2567531E-05,   5.4835247E-05,   5.7177534E-05
     +,   5.9594458E-05,   6.2085579E-05,   6.4650449E-05
     +,   6.7288223E-05,   6.9997819E-05,   7.2777882E-05
     +,   7.5626813E-05,   7.8542682E-05,   8.1523409E-05
     +,   8.4566382E-05,   8.7669054E-05,   9.0828566E-05
     +,   9.4041556E-05,   9.7304830E-05,   1.0061457E-04
     +,   1.0396721E-04,   1.0735859E-04,   1.1078479E-04
     +,   1.1424129E-04,   1.1772405E-04,   1.2122835E-04
     +,   1.2474979E-04,   1.2828397E-04,   1.3182612E-04
     +,   1.3537168E-04,   1.3891613E-04,   1.4245506E-04
     +,   1.4598375E-04,   1.4949816E-04,   1.5299360E-04
     +,   1.5646618E-04,   1.5991153E-04,   1.6332581E-04
     +,   1.6670498E-04,   1.7004542E-04,   1.7334335E-04
     +,   1.7659526E-04,   1.7979796E-04,   1.8294802E-04
     +,   1.8604216E-04,   1.8907759E-04,   1.9205146E-04
     +,   1.9496093E-04,   1.9780350E-04,   2.0057672E-04
     +,   2.0327851E-04,   2.0590662E-04,   2.0845940E-04
     +,   2.1093525E-04,   2.1333288E-04,   2.1565137E-04
     +,   2.1788994E-04,   2.2004868E-04,   2.2212756E-04
     +,   2.2412725E-04,   2.2604915E-04,   2.2789514E-04
     +,   2.2966746E-04,   2.3136941E-04,   2.3300479E-04
     +,   2.3457833E-04,   2.3609538E-04,   2.3756236E-04
     +,   2.3898632E-04,   2.4037529E-04,   2.4173810E-04
     +,   2.4308435E-04,   2.4442471E-04,   2.4577026E-04
     +,   2.4713294E-04,   2.4852523E-04,   2.4996031E-04
     +,   2.5145148E-04,   2.5301255E-04,   2.5465718E-04
     +,   2.5639916E-04,   2.5825214E-04,   2.6022911E-04
     +,   2.6234239E-04,   2.6460385E-04,   2.6702374E-04
     +,   2.6961163E-04,   2.7237518E-04,   2.7532061E-04
     +,   2.7845171E-04,   2.8177083E-04,   2.8527773E-04
     +,   2.8896969E-04,   2.9284140E-04,   2.9688486E-04
     +,   3.0108960E-04,   3.0544179E-04,   3.0992541E-04
     +,   3.1452155E-04,   3.1920819E-04,   3.2396114E-04
     +,   3.2875381E-04,   3.3355795E-04,   3.3834242E-04
     +,   3.4307520E-04,   3.4772290E-04,   3.5225146E-04
     +,   3.5662614E-04,   3.6081194E-04,   3.6477501E-04
     +,   3.6848182E-04,   3.7190018E-04,   3.7499995E-04
     +,   3.7775302E-04,   3.8013369E-04,   3.8211938E-04
     +,   3.8369070E-04,   3.8483198E-04,   3.8553102E-04
     +,   3.8577945E-04,   3.8557299E-04,   3.8491140E-04
     +,   3.8379832E-04,   3.8224118E-04,   3.8025109E-04
     +,   3.7784281E-04,   3.7503414E-04,   3.7184590E-04
     +,   3.6830158E-04,   3.6442711E-04,   3.6025059E-04
     +,   3.5580216E-04,   3.5111321E-04,   3.4621719E-04
     +,   3.4114963E-04,   3.3594706E-04,   3.3064833E-04
     +,   3.2529503E-04,   3.1993148E-04,   3.1460539E-04
     +,   3.0936889E-04,   3.0427997E-04,   2.9940251E-04
     +,   2.9480801E-04,   2.9057695E-04,   2.8680012E-04
     +,   2.8357955E-04,   2.8102993E-04,   2.7928030E-04
     +,   2.7847520E-04,   2.7877543E-04,   2.8035944E-04
     +,   2.8342375E-04,   2.8818395E-04,   2.9487483E-04
     +,   3.0375068E-04,   3.1508342E-04,   3.2916316E-04
     +,   3.4629620E-04,   3.6680143E-04,   3.9100728E-04
     +,   4.1924967E-04,   4.5186558E-04,   4.8918440E-04
     +,   5.3152116E-04,   5.7916815E-04,   6.3238275E-04
     +,   6.9136656E-04,   7.5625326E-04,   8.2709140E-04
     +,   9.0382621E-04,   9.8627293E-04,   1.0741227E-03
     +,   1.1669362E-03,   1.2641477E-03,   1.3650927E-03
     +,   1.4690590E-03,   1.5753203E-03,   1.6831812E-03
     +,   1.7920325E-03,   1.9013990E-03,   2.0109671E-03
     +,   2.1206134E-03,   2.2304405E-03,   2.3408236E-03
     +,   2.4524212E-03,   2.5661732E-03,   2.6832798E-03
     +,   2.8051035E-03,   2.9330631E-03,   3.0685973E-03
     +,   3.2133264E-03,   3.3694585E-03,   3.5404824E-03
     +,   3.7319737E-03,   3.9520673E-03,   4.2111049E-03
     +,   4.5200312E-03,   4.8877466E-03,   5.3181811E-03
     +,   5.8083925E-03,   6.3488777E-03,   6.9266711E-03
     +,   7.5297789E-03,   8.1509370E-03,   8.7882420E-03
     +,   9.4419932E-03,   1.0108742E-02,   1.0776039E-02
     +,   1.1421233E-02,   1.2015626E-02,   1.2532202E-02
     +,   1.2952443E-02,   1.3267523E-02,   1.3472253E-02
     +,   1.3555050E-02,   1.3490906E-02,   1.3243180E-02
     +,   1.2775226E-02,   1.2066844E-02,   1.1127438E-02
     +,   9.9995928E-03,   8.7517938E-03,   7.4639278E-03
     +,   6.2113698E-03,   5.0531002E-03,   4.0267203E-03
     +,   3.1493881E-03,   2.4220510E-03,   1.8350629E-03
     +,   1.3725954E-03,   1.0161208E-03,   7.4652157E-04
     +,   5.4572249E-04,   3.9767442E-04,   2.8903293E-04
     +,   2.0929676E-04,   1.5063127E-04,   1.0738711E-04
     +,   7.5563126E-05,   5.2305910E-05,   3.5518489E-05
     +,   2.3610228E-05,   1.5339197E-05,   9.7299708E-06
     +,   6.0215316E-06,   3.6341173E-06,   2.1381218E-06
     +,   1.2260606E-06,   6.8504676E-07,   3.7287850E-07
     +,   1.9765952E-07,   1.0201358E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz114 = Yx/0.093975
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8030385E-05,   1.8479981E-05
     +,   1.8937548E-05,   1.9403107E-05,   1.9876676E-05
     +,   2.0358280E-05,   2.0847951E-05,   2.1345724E-05
     +,   2.1851643E-05,   2.2365772E-05,   2.2888180E-05
     +,   2.3418939E-05,   2.3958142E-05,   2.4505900E-05
     +,   2.5062336E-05,   2.5627600E-05,   2.6201851E-05
     +,   2.6785268E-05,   2.7378066E-05,   2.7980479E-05
     +,   2.8592765E-05,   2.9215202E-05,   2.9848095E-05
     +,   3.0491827E-05,   3.1146719E-05,   3.1813226E-05
     +,   3.2491771E-05,   3.3182827E-05,   3.3886925E-05
     +,   3.4604593E-05,   3.5336452E-05,   3.6083093E-05
     +,   3.6845217E-05,   3.7623522E-05,   3.8418755E-05
     +,   3.9231712E-05,   4.0063216E-05,   4.0914154E-05
     +,   4.1785479E-05,   4.2678097E-05,   4.3593074E-05
     +,   4.4531433E-05,   4.5494300E-05,   4.6482844E-05
     +,   4.7498252E-05,   4.8541791E-05,   4.9614788E-05
     +,   5.0718609E-05,   5.1854713E-05,   5.3024625E-05
     +,   5.4229913E-05,   5.5472286E-05,   5.6753444E-05
     +,   5.8075348E-05,   5.9439906E-05,   6.0849252E-05
     +,   6.2305626E-05,   6.3811385E-05,   6.5369095E-05
     +,   6.6981476E-05,   6.8651447E-05,   7.0382150E-05
     +,   7.2176823E-05,   7.4039148E-05,   7.5972988E-05
     +,   7.7982317E-05,   8.0071637E-05,   8.2245468E-05
     +,   8.4508851E-05,   8.6866887E-05,   8.9325156E-05
     +,   9.1889255E-05,   9.4565337E-05,   9.7359371E-05
     +,   1.0027782E-04,   1.0332721E-04,   1.0651404E-04
     +,   1.0984472E-04,   1.1332587E-04,   1.1696381E-04
     +,   1.2076443E-04,   1.2473365E-04,   1.2887637E-04
     +,   1.3319751E-04,   1.3770061E-04,   1.4238893E-04
     +,   1.4726423E-04,   1.5232757E-04,   1.5757825E-04
     +,   1.6301460E-04,   1.6863333E-04,   1.7442933E-04
     +,   1.8039561E-04,   1.8652373E-04,   1.9280339E-04
     +,   1.9922193E-04,   2.0576533E-04,   2.1241687E-04
     +,   2.1915897E-04,   2.2597123E-04,   2.3283248E-04
     +,   2.3971903E-04,   2.4660694E-04,   2.5346995E-04
     +,   2.6028167E-04,   2.6701484E-04,   2.7364164E-04
     +,   2.8013386E-04,   2.8646391E-04,   2.9260493E-04
     +,   2.9853007E-04,   3.0421451E-04,   3.0963402E-04
     +,   3.1476718E-04,   3.1959335E-04,   3.2409540E-04
     +,   3.2825785E-04,   3.3206854E-04,   3.3551772E-04
     +,   3.3859897E-04,   3.4130900E-04,   3.4364720E-04
     +,   3.4561657E-04,   3.4722255E-04,   3.4847425E-04
     +,   3.4938296E-04,   3.4996285E-04,   3.5023032E-04
     +,   3.5020406E-04,   3.4990450E-04,   3.4935353E-04
     +,   3.4857460E-04,   3.4759147E-04,   3.4642898E-04
     +,   3.4511191E-04,   3.4366490E-04,   3.4211221E-04
     +,   3.4047736E-04,   3.3878259E-04,   3.3704893E-04
     +,   3.3529592E-04,   3.3354125E-04,   3.3180078E-04
     +,   3.3008796E-04,   3.2841452E-04,   3.2678962E-04
     +,   3.2522052E-04,   3.2371216E-04,   3.2226741E-04
     +,   3.2088731E-04,   3.1957094E-04,   3.1831619E-04
     +,   3.1711927E-04,   3.1597583E-04,   3.1488063E-04
     +,   3.1382815E-04,   3.1281306E-04,   3.1183072E-04
     +,   3.1087722E-04,   3.0994994E-04,   3.0904837E-04
     +,   3.0817385E-04,   3.0733075E-04,   3.0652614E-04
     +,   3.0577029E-04,   3.0507729E-04,   3.0446501E-04
     +,   3.0395520E-04,   3.0357344E-04,   3.0334975E-04
     +,   3.0331797E-04,   3.0351547E-04,   3.0398372E-04
     +,   3.0476690E-04,   3.0591246E-04,   3.0746995E-04
     +,   3.0949147E-04,   3.1203020E-04,   3.1514047E-04
     +,   3.1887754E-04,   3.2329690E-04,   3.2845451E-04
     +,   3.3440584E-04,   3.4120693E-04,   3.4891444E-04
     +,   3.5758497E-04,   3.6727550E-04,   3.7804496E-04
     +,   3.8995373E-04,   4.0306197E-04,   4.1743144E-04
     +,   4.3312451E-04,   4.5019976E-04,   4.6871122E-04
     +,   4.8870675E-04,   5.1022228E-04,   5.3327577E-04
     +,   5.5786304E-04,   5.8395346E-04,   6.1148446E-04
     +,   6.4035342E-04,   6.7041739E-04,   7.0149341E-04
     +,   7.3336012E-04,   7.6575694E-04,   7.9840113E-04
     +,   8.3099672E-04,   8.6324930E-04,   8.9488726E-04
     +,   9.2568685E-04,   9.5549470E-04,   9.8424696E-04
     +,   1.0119946E-03,   1.0389211E-03,   1.0653503E-03
     +,   1.0917452E-03,   1.1186996E-03,   1.1469166E-03
     +,   1.1771737E-03,   1.2102736E-03,   1.2470051E-03
     +,   1.2880950E-03,   1.3341755E-03,   1.3857833E-03
     +,   1.4433906E-03,   1.5074681E-03,   1.5785592E-03
     +,   1.6573791E-03,   1.7448631E-03,   1.8421460E-03
     +,   1.9504288E-03,   2.0707413E-03,   2.2036326E-03
     +,   2.3488333E-03,   2.5049679E-03,   2.6695253E-03
     +,   2.8390328E-03,   3.0095284E-03,   3.1772864E-03
     +,   3.3396364E-03,   3.4956974E-03,   3.6468590E-03
     +,   3.7969025E-03,   3.9517023E-03,   4.1185571E-03
     +,   4.3052547E-03,   4.5191785E-03,   4.7665620E-03
     +,   5.0520478E-03,   5.3786095E-03,   5.7478207E-03
     +,   6.1601456E-03,   6.6149393E-03,   7.1101296E-03
     +,   7.6413727E-03,   8.2007693E-03,   8.7756310E-03
     +,   9.3476623E-03,   9.8929750E-03,   1.0383147E-02
     +,   1.0787214E-02,   1.1074575E-02,   1.1218023E-02
     +,   1.1196602E-02,   1.0997904E-02,   1.0619512E-02
     +,   1.0069643E-02,   9.3670450E-03,   8.5399244E-03
     +,   7.6239603E-03,   6.6595054E-03,   5.6881462E-03
     +,   4.7489242E-03,   3.8748153E-03,   3.0903281E-03
     +,   2.4102994E-03,   1.8398942E-03,   1.3761271E-03
     +,   1.0098080E-03,   7.2807603E-04,   5.1652244E-04
     +,   3.6102330E-04,   2.4883455E-04,   1.6921553E-04
     +,   1.1353123E-04,   7.5118747E-05,   4.8974656E-05
     +,   3.1426996E-05,   1.9825453E-05,   1.2279235E-05
     +,   7.4581840E-06,   4.4371313E-06,   2.5831284E-06
     +,   1.4700975E-06,   8.1725830E-07,   4.4345947E-07
     +,   2.3473724E-07,   1.2115242E-07,   6.0960744E-08
     +,   2.9913991E-08,   1.4336790E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz115 = Yx/0.0838205128205128
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.8098078E-05,   5.9184342E-05
     +,   6.0267768E-05,   6.1348415E-05,   6.2426436E-05
     +,   6.3502128E-05,   6.4575972E-05,   6.5648572E-05
     +,   6.6720662E-05,   6.7793248E-05,   6.8867455E-05
     +,   6.9944632E-05,   7.1026283E-05,   7.2114191E-05
     +,   7.3210300E-05,   7.4316784E-05,   7.5436066E-05
     +,   7.6570759E-05,   7.7723707E-05,   7.8897967E-05
     +,   8.0096826E-05,   8.1323720E-05,   8.2582359E-05
     +,   8.3876621E-05,   8.5210399E-05,   8.6587934E-05
     +,   8.8013505E-05,   8.9491434E-05,   9.1026166E-05
     +,   9.2622140E-05,   9.4283831E-05,   9.6015654E-05
     +,   9.7821969E-05,   9.9706944E-05,   1.0167467E-04
     +,   1.0372896E-04,   1.0587341E-04,   1.0811121E-04
     +,   1.1044546E-04,   1.1287846E-04,   1.1541251E-04
     +,   1.1804901E-04,   1.2078916E-04,   1.2363341E-04
     +,   1.2658162E-04,   1.2963318E-04,   1.3278662E-04
     +,   1.3603999E-04,   1.3939061E-04,   1.4283510E-04
     +,   1.4636951E-04,   1.4998914E-04,   1.5368867E-04
     +,   1.5746252E-04,   1.6130402E-04,   1.6520644E-04
     +,   1.6916246E-04,   1.7316455E-04,   1.7720464E-04
     +,   1.8127475E-04,   1.8536666E-04,   1.8947212E-04
     +,   1.9358299E-04,   1.9769132E-04,   2.0178975E-04
     +,   2.0587079E-04,   2.0992805E-04,   2.1395511E-04
     +,   2.1794681E-04,   2.2189824E-04,   2.2580600E-04
     +,   2.2966677E-04,   2.3347906E-04,   2.3724150E-04
     +,   2.4095451E-04,   2.4461915E-04,   2.4823734E-04
     +,   2.5181213E-04,   2.5534767E-04,   2.5884877E-04
     +,   2.6232080E-04,   2.6577021E-04,   2.6920362E-04
     +,   2.7262833E-04,   2.7605158E-04,   2.7948114E-04
     +,   2.8292421E-04,   2.8638821E-04,   2.8987980E-04
     +,   2.9340523E-04,   2.9697033E-04,   3.0057938E-04
     +,   3.0423590E-04,   3.0794239E-04,   3.1170005E-04
     +,   3.1550834E-04,   3.1936579E-04,   3.2326876E-04
     +,   3.2721268E-04,   3.3119094E-04,   3.3519568E-04
     +,   3.3921760E-04,   3.4324583E-04,   3.4726827E-04
     +,   3.5127162E-04,   3.5524188E-04,   3.5916385E-04
     +,   3.6302122E-04,   3.6679837E-04,   3.7047829E-04
     +,   3.7404444E-04,   3.7748032E-04,   3.8076981E-04
     +,   3.8389707E-04,   3.8684692E-04,   3.8960538E-04
     +,   3.9215913E-04,   3.9449619E-04,   3.9660549E-04
     +,   3.9847766E-04,   4.0010450E-04,   4.0147919E-04
     +,   4.0259620E-04,   4.0345159E-04,   4.0404272E-04
     +,   4.0436824E-04,   4.0442805E-04,   4.0422310E-04
     +,   4.0375549E-04,   4.0302856E-04,   4.0204590E-04
     +,   4.0081242E-04,   3.9933366E-04,   3.9761540E-04
     +,   3.9566442E-04,   3.9348777E-04,   3.9109302E-04
     +,   3.8848803E-04,   3.8568102E-04,   3.8268088E-04
     +,   3.7949655E-04,   3.7613793E-04,   3.7261503E-04
     +,   3.6893858E-04,   3.6512004E-04,   3.6117170E-04
     +,   3.5710621E-04,   3.5293758E-04,   3.4868103E-04
     +,   3.4435259E-04,   3.3996903E-04,   3.3554927E-04
     +,   3.3111285E-04,   3.2668078E-04,   3.2227539E-04
     +,   3.1792038E-04,   3.1364095E-04,   3.0946315E-04
     +,   3.0541391E-04,   3.0152206E-04,   2.9781667E-04
     +,   2.9432750E-04,   2.9108534E-04,   2.8812111E-04
     +,   2.8546559E-04,   2.8314977E-04,   2.8120415E-04
     +,   2.7965856E-04,   2.7854240E-04,   2.7788320E-04
     +,   2.7770764E-04,   2.7804071E-04,   2.7890533E-04
     +,   2.8032289E-04,   2.8231225E-04,   2.8489012E-04
     +,   2.8807114E-04,   2.9186756E-04,   2.9628930E-04
     +,   3.0134429E-04,   3.0703924E-04,   3.1337852E-04
     +,   3.2036577E-04,   3.2800392E-04,   3.3629630E-04
     +,   3.4524652E-04,   3.5485902E-04,   3.6514190E-04
     +,   3.7610604E-04,   3.8776617E-04,   4.0014338E-04
     +,   4.1326621E-04,   4.2716929E-04,   4.4189699E-04
     +,   4.5750433E-04,   4.7405611E-04,   4.9162621E-04
     +,   5.1029737E-04,   5.3016178E-04,   5.5131450E-04
     +,   5.7385123E-04,   5.9786194E-04,   6.2342786E-04
     +,   6.5061101E-04,   6.7944539E-04,   7.0993317E-04
     +,   7.4203603E-04,   7.7566708E-04,   8.1068889E-04
     +,   8.4691617E-04,   8.8412024E-04,   9.2203252E-04
     +,   9.6036377E-04,   9.9882553E-04,   1.0371486E-03
     +,   1.0751095E-03,   1.1125568E-03,   1.1494415E-03
     +,   1.1858332E-03,   1.2219336E-03,   1.2580897E-03
     +,   1.2947944E-03,   1.3326772E-03,   1.3724965E-03
     +,   1.4151315E-03,   1.4615698E-03,   1.5128935E-03
     +,   1.5702676E-03,   1.6349284E-03,   1.7081418E-03
     +,   1.7911451E-03,   1.8850770E-03,   1.9908901E-03
     +,   2.1092652E-03,   2.2405460E-03,   2.3847700E-03
     +,   2.5417700E-03,   2.7113587E-03,   2.8936181E-03
     +,   3.0892044E-03,   3.2995490E-03,   3.5268909E-03
     +,   3.7740532E-03,   4.0439740E-03,   4.3389467E-03
     +,   4.6597891E-03,   5.0050938E-03,   5.3708008E-03
     +,   5.7501541E-03,   6.1341324E-03,   6.5124081E-03
     +,   6.8744896E-03,   7.2108582E-03,   7.5139632E-03
     +,   7.7787852E-03,   8.0028065E-03,   8.1854798E-03
     +,   8.3272960E-03,   8.4286332E-03,   8.4886579E-03
     +,   8.5045043E-03,   8.4710959E-03,   8.3816126E-03
     +,   8.2285414E-03,   8.0053285E-03,   7.7079833E-03
     +,   7.3365355E-03,   6.8959058E-03,   6.3959700E-03
     +,   5.8507784E-03,   5.2772453E-03,   4.6934718E-03
     +,   4.1169799E-03,   3.5632073E-03,   3.0445082E-03
     +,   2.5697139E-03,   2.1439812E-03,   1.7692940E-03
     +,   1.4449448E-03,   1.1683325E-03,   9.3554979E-04
     +,   7.4203877E-04,   5.8298017E-04,   4.5365983E-04
     +,   3.4962341E-04,   2.6681955E-04,   2.0162149E-04
     +,   1.5084709E-04,   1.1174870E-04,   8.1977385E-05
     +,   5.9563237E-05,   4.2872736E-05,   3.0577983E-05
     +,   2.1613921E-05,   1.5143089E-05,   1.0515836E-05
     +,   7.2373168E-06,   4.9350347E-06,   3.3328733E-06
     +,   2.2280608E-06,   1.4735378E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz116 = Yx/0.080051282051282
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9883795E-05,   3.0599844E-05
     +,   3.1321404E-05,   3.2048392E-05,   3.2780757E-05
     +,   3.3518500E-05,   3.4261669E-05,   3.5010384E-05
     +,   3.5764806E-05,   3.6525220E-05,   3.7291906E-05
     +,   3.8065293E-05,   3.8845868E-05,   3.9634204E-05
     +,   4.0430979E-05,   4.1236970E-05,   4.2053063E-05
     +,   4.2880234E-05,   4.3719599E-05,   4.4572367E-05
     +,   4.5439876E-05,   4.6323556E-05,   4.7224970E-05
     +,   4.8145845E-05,   4.9087903E-05,   5.0053106E-05
     +,   5.1043455E-05,   5.2061052E-05,   5.3108120E-05
     +,   5.4186949E-05,   5.5299923E-05,   5.6449473E-05
     +,   5.7638143E-05,   5.8868416E-05,   6.0142895E-05
     +,   6.1464161E-05,   6.2834755E-05,   6.4257241E-05
     +,   6.5734181E-05,   6.7267909E-05,   6.8860871E-05
     +,   7.0515256E-05,   7.2233182E-05,   7.4016622E-05
     +,   7.5867370E-05,   7.7786986E-05,   7.9776881E-05
     +,   8.1838145E-05,   8.3971696E-05,   8.6178115E-05
     +,   8.8457738E-05,   9.0810645E-05,   9.3236442E-05
     +,   9.5734700E-05,   9.8304379E-05,   1.0094442E-04
     +,   1.0365326E-04,   1.0642915E-04,   1.0927009E-04
     +,   1.1217371E-04,   1.1513753E-04,   1.1815898E-04
     +,   1.2123503E-04,   1.2436286E-04,   1.2753958E-04
     +,   1.3076204E-04,   1.3402745E-04,   1.3733280E-04
     +,   1.4067568E-04,   1.4405337E-04,   1.4746404E-04
     +,   1.5090556E-04,   1.5437684E-04,   1.5787670E-04
     +,   1.6140479E-04,   1.6496131E-04,   1.6854687E-04
     +,   1.7216256E-04,   1.7581042E-04,   1.7949298E-04
     +,   1.8321302E-04,   1.8697446E-04,   1.9078102E-04
     +,   1.9463757E-04,   1.9854879E-04,   2.0252008E-04
     +,   2.0655651E-04,   2.1066373E-04,   2.1484675E-04
     +,   2.1911084E-04,   2.2346083E-04,   2.2790091E-04
     +,   2.3243426E-04,   2.3706391E-04,   2.4179164E-04
     +,   2.4661794E-04,   2.5154249E-04,   2.5656327E-04
     +,   2.6167731E-04,   2.6687977E-04,   2.7216494E-04
     +,   2.7752496E-04,   2.8295157E-04,   2.8843427E-04
     +,   2.9396199E-04,   2.9952268E-04,   3.0510334E-04
     +,   3.1069000E-04,   3.1626906E-04,   3.2182669E-04
     +,   3.2734883E-04,   3.3282238E-04,   3.3823482E-04
     +,   3.4357517E-04,   3.4883313E-04,   3.5400077E-04
     +,   3.5907139E-04,   3.6404119E-04,   3.6890764E-04
     +,   3.7367136E-04,   3.7833516E-04,   3.8290385E-04
     +,   3.8738467E-04,   3.9178738E-04,   3.9612359E-04
     +,   4.0040584E-04,   4.0464930E-04,   4.0886883E-04
     +,   4.1308085E-04,   4.1730131E-04,   4.2154620E-04
     +,   4.2583028E-04,   4.3016713E-04,   4.3456830E-04
     +,   4.3904324E-04,   4.4359855E-04,   4.4823784E-04
     +,   4.5296029E-04,   4.5776230E-04,   4.6263638E-04
     +,   4.6757000E-04,   4.7254661E-04,   4.7754656E-04
     +,   4.8254535E-04,   4.8751489E-04,   4.9242406E-04
     +,   4.9723824E-04,   5.0192076E-04,   5.0643284E-04
     +,   5.1073398E-04,   5.1478425E-04,   5.1854231E-04
     +,   5.2196806E-04,   5.2502321E-04,   5.2767136E-04
     +,   5.2987895E-04,   5.3161575E-04,   5.3285586E-04
     +,   5.3357799E-04,   5.3376541E-04,   5.3340738E-04
     +,   5.3249806E-04,   5.3103815E-04,   5.2903366E-04
     +,   5.2649627E-04,   5.2344374E-04,   5.1989907E-04
     +,   5.1588978E-04,   5.1144842E-04,   5.0661113E-04
     +,   5.0141755E-04,   4.9591099E-04,   4.9013580E-04
     +,   4.8413844E-04,   4.7796659E-04,   4.7166811E-04
     +,   4.6529091E-04,   4.5888269E-04,   4.5249160E-04
     +,   4.4616419E-04,   4.3994718E-04,   4.3388826E-04
     +,   4.2803565E-04,   4.2243954E-04,   4.1715294E-04
     +,   4.1223370E-04,   4.0774528E-04,   4.0375843E-04
     +,   4.0035232E-04,   3.9761729E-04,   3.9565447E-04
     +,   3.9457731E-04,   3.9451319E-04,   3.9560109E-04
     +,   3.9799357E-04,   4.0185425E-04,   4.0735642E-04
     +,   4.1468121E-04,   4.2401516E-04,   4.3554776E-04
     +,   4.4946690E-04,   4.6595625E-04,   4.8519357E-04
     +,   5.0734548E-04,   5.3256156E-04,   5.6097494E-04
     +,   5.9269555E-04,   6.2780268E-04,   6.6634268E-04
     +,   7.0832524E-04,   7.5371924E-04,   8.0244412E-04
     +,   8.5437478E-04,   9.0934604E-04,   9.6716004E-04
     +,   1.0275905E-03,   1.0904062E-03,   1.1553930E-03
     +,   1.2223738E-03,   1.2912255E-03,   1.3619052E-03
     +,   1.4344627E-03,   1.5090264E-03,   1.5858059E-03
     +,   1.6650661E-03,   1.7470905E-03,   1.8321380E-03
     +,   1.9204062E-03,   2.0120095E-03,   2.1069602E-03
     +,   2.2051709E-03,   2.3064874E-03,   2.4107490E-03
     +,   2.5178345E-03,   2.6277197E-03,   2.7405361E-03
     +,   2.8565889E-03,   2.9763575E-03,   3.1004660E-03
     +,   3.2296453E-03,   3.3646449E-03,   3.5061669E-03
     +,   3.6547720E-03,   3.8108139E-03,   3.9743870E-03
     +,   4.1452614E-03,   4.3229121E-03,   4.5065596E-03
     +,   4.6952581E-03,   4.8879720E-03,   5.0837118E-03
     +,   5.2815378E-03,   5.4804562E-03,   5.6792418E-03
     +,   5.8760992E-03,   6.0682595E-03,   6.2515759E-03
     +,   6.4203604E-03,   6.5673757E-03,   6.6841943E-03
     +,   6.7617982E-03,   6.7914543E-03,   6.7656599E-03
     +,   6.6789617E-03,   6.5286653E-03,   6.3151573E-03
     +,   6.0419259E-03,   5.7153199E-03,   5.3440379E-03
     +,   4.9384125E-03,   4.5097372E-03,   4.0695751E-03
     +,   3.6290884E-03,   3.1984495E-03,   2.7864422E-03
     +,   2.4001810E-03,   2.0448624E-03,   1.7238314E-03
     +,   1.4385958E-03,   1.1891216E-03,   9.7404473E-04
     +,   7.9106912E-04,   6.3723995E-04,   5.0929748E-04
     +,   4.0389007E-04,   3.1779829E-04,   2.4803585E-04
     +,   1.9193230E-04,   1.4715940E-04,   1.1171243E-04
     +,   8.3894600E-05,   6.2272746E-05,   4.5647925E-05
     +,   3.3016146E-05,   2.3543835E-05,   1.6540438E-05
     +,   1.1440909E-05,   7.7867326E-06,   5.2122100E-06
     +,   3.4297177E-06,   2.2177549E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz118 = Yx/0.0720263157894737
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7296674E-05,   2.8035478E-05
     +,   2.8790091E-05,   2.9560802E-05,   3.0347908E-05
     +,   3.1151714E-05,   3.1972537E-05,   3.2810723E-05
     +,   3.3666587E-05,   3.4540542E-05,   3.5432942E-05
     +,   3.6344172E-05,   3.7274644E-05,   3.8224793E-05
     +,   3.9195053E-05,   4.0185885E-05,   4.1197789E-05
     +,   4.2231237E-05,   4.3286775E-05,   4.4364937E-05
     +,   4.5466313E-05,   4.6591482E-05,   4.7741079E-05
     +,   4.8915790E-05,   5.0116261E-05,   5.1343279E-05
     +,   5.2597596E-05,   5.3880038E-05,   5.5191464E-05
     +,   5.6532812E-05,   5.7905079E-05,   5.9309295E-05
     +,   6.0746595E-05,   6.2218183E-05,   6.3725340E-05
     +,   6.5269480E-05,   6.6852073E-05,   6.8474670E-05
     +,   7.0139111E-05,   7.1847149E-05,   7.3600873E-05
     +,   7.5402430E-05,   7.7254175E-05,   7.9158672E-05
     +,   8.1118684E-05,   8.3137238E-05,   8.5217558E-05
     +,   8.7363231E-05,   8.9578134E-05,   9.1866459E-05
     +,   9.4232826E-05,   9.6682183E-05,   9.9219964E-05
     +,   1.0185221E-04,   1.0458521E-04,   1.0742606E-04
     +,   1.1038233E-04,   1.1346224E-04,   1.1667472E-04
     +,   1.2002926E-04,   1.2353617E-04,   1.2720651E-04
     +,   1.3105184E-04,   1.3508466E-04,   1.3931819E-04
     +,   1.4376595E-04,   1.4844247E-04,   1.5336230E-04
     +,   1.5854079E-04,   1.6399317E-04,   1.6973504E-04
     +,   1.7578143E-04,   1.8214766E-04,   1.8884752E-04
     +,   1.9589468E-04,   2.0330158E-04,   2.1107846E-04
     +,   2.1923383E-04,   2.2777417E-04,   2.3670358E-04
     +,   2.4602204E-04,   2.5572718E-04,   2.6581180E-04
     +,   2.7626567E-04,   2.8707259E-04,   2.9821339E-04
     +,   3.0966228E-04,   3.2138973E-04,   3.3335984E-04
     +,   3.4553240E-04,   3.5786250E-04,   3.7029939E-04
     +,   3.8278781E-04,   3.9526945E-04,   4.0768230E-04
     +,   4.1996004E-04,   4.3203638E-04,   4.4384148E-04
     +,   4.5530664E-04,   4.6636254E-04,   4.7694260E-04
     +,   4.8698153E-04,   4.9641862E-04,   5.0519680E-04
     +,   5.1326549E-04,   5.2058068E-04,   5.2710512E-04
     +,   5.3280964E-04,   5.3767493E-04,   5.4168969E-04
     +,   5.4485269E-04,   5.4717262E-04,   5.4866663E-04
     +,   5.4936286E-04,   5.4929743E-04,   5.4851471E-04
     +,   5.4706720E-04,   5.4501393E-04,   5.4241938E-04
     +,   5.3935283E-04,   5.3588615E-04,   5.3209387E-04
     +,   5.2805059E-04,   5.2383018E-04,   5.1950407E-04
     +,   5.1514100E-04,   5.1080418E-04,   5.0655211E-04
     +,   5.0243607E-04,   4.9850030E-04,   4.9478072E-04
     +,   4.9130560E-04,   4.8809370E-04,   4.8515628E-04
     +,   4.8249558E-04,   4.8010587E-04,   4.7797387E-04
     +,   4.7607991E-04,   4.7439776E-04,   4.7289691E-04
     +,   4.7154189E-04,   4.7029532E-04,   4.6911687E-04
     +,   4.6796666E-04,   4.6680475E-04,   4.6559199E-04
     +,   4.6429274E-04,   4.6287355E-04,   4.6130651E-04
     +,   4.5956663E-04,   4.5763573E-04,   4.5549989E-04
     +,   4.5315214E-04,   4.5059033E-04,   4.4781886E-04
     +,   4.4484713E-04,   4.4169044E-04,   4.3836838E-04
     +,   4.3490515E-04,   4.3132872E-04,   4.2767002E-04
     +,   4.2396240E-04,   4.2024106E-04,   4.1654275E-04
     +,   4.1290387E-04,   4.0936100E-04,   4.0595009E-04
     +,   4.0270571E-04,   3.9966078E-04,   3.9684551E-04
     +,   3.9428848E-04,   3.9201544E-04,   3.9004881E-04
     +,   3.8840881E-04,   3.8711188E-04,   3.8617247E-04
     +,   3.8560104E-04,   3.8540649E-04,   3.8559435E-04
     +,   3.8616767E-04,   3.8712751E-04,   3.8847289E-04
     +,   3.9020152E-04,   3.9230892E-04,   3.9479084E-04
     +,   3.9764220E-04,   4.0085751E-04,   4.0443317E-04
     +,   4.0836690E-04,   4.1265905E-04,   4.1731409E-04
     +,   4.2234140E-04,   4.2775620E-04,   4.3358223E-04
     +,   4.3985102E-04,   4.4660550E-04,   4.5389880E-04
     +,   4.6179609E-04,   4.7037555E-04,   4.7972702E-04
     +,   4.8995193E-04,   5.0116156E-04,   5.1347463E-04
     +,   5.2701653E-04,   5.4191152E-04,   5.5828213E-04
     +,   5.7624409E-04,   5.9589994E-04,   6.1733311E-04
     +,   6.4060866E-04,   6.6576496E-04,   6.9281278E-04
     +,   7.2173245E-04,   7.5247674E-04,   7.8497175E-04
     +,   8.1911613E-04,   8.5478742E-04,   8.9185050E-04
     +,   9.3015970E-04,   9.6955989E-04,   1.0099012E-03
     +,   1.0510399E-03,   1.0928417E-03,   1.1351866E-03
     +,   1.1779810E-03,   1.2211594E-03,   1.2646921E-03
     +,   1.3085972E-03,   1.3529585E-03,   1.3979343E-03
     +,   1.4437753E-03,   1.4908416E-03,   1.5396186E-03
     +,   1.5907274E-03,   1.6449229E-03,   1.7030948E-03
     +,   1.7662522E-03,   1.8354977E-03,   1.9119864E-03
     +,   1.9968871E-03,   2.0913281E-03,   2.1963150E-03
     +,   2.3126688E-03,   2.4409569E-03,   2.5813992E-03
     +,   2.7337905E-03,   2.8974412E-03,   3.0711293E-03
     +,   3.2530788E-03,   3.4409263E-03,   3.6318053E-03
     +,   3.8223823E-03,   4.0089521E-03,   4.1875541E-03
     +,   4.3541235E-03,   4.5045973E-03,   4.6350555E-03
     +,   4.7418475E-03,   4.8217177E-03,   4.8719095E-03
     +,   4.8902738E-03,   4.8753754E-03,   4.8265569E-03
     +,   4.7440394E-03,   4.6289098E-03,   4.4831275E-03
     +,   4.3094563E-03,   4.1113570E-03,   3.8928294E-03
     +,   3.6582088E-03,   3.4119771E-03,   3.1585973E-03
     +,   2.9023224E-03,   2.6470514E-03,   2.3962555E-03
     +,   2.1529559E-03,   1.9196416E-03,   1.6983559E-03
     +,   1.4906558E-03,   1.2977027E-03,   1.1202489E-03
     +,   9.5871428E-04,   8.1317726E-04,   6.8344310E-04
     +,   5.6903786E-04,   4.6927368E-04,   3.8325926E-04
     +,   3.0995350E-04,   2.4821452E-04,   1.9682826E-04
     +,   1.5456793E-04,   1.2022073E-04,   9.2632697E-05
     +,   7.0726433E-05,   5.3527401E-05,   4.0169336E-05
     +,   2.9902845E-05,   2.2089938E-05,   1.6200140E-05
     +,   1.1798707E-05,   8.5366510E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz120 = Yx/0.0579444444444445
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3705881E-05,   2.4175439E-05
     +,   2.4664803E-05,   2.5175965E-05,   2.5711019E-05
     +,   2.6272181E-05,   2.6861770E-05,   2.7482223E-05
     +,   2.8136086E-05,   2.8826027E-05,   2.9554834E-05
     +,   3.0325393E-05,   3.1140720E-05,   3.2003954E-05
     +,   3.2918360E-05,   3.3887314E-05,   3.4914334E-05
     +,   3.6003104E-05,   3.7157395E-05,   3.8381189E-05
     +,   3.9678587E-05,   4.1053852E-05,   4.2511449E-05
     +,   4.4056069E-05,   4.5692457E-05,   4.7425729E-05
     +,   4.9261092E-05,   5.1204013E-05,   5.3260163E-05
     +,   5.5435441E-05,   5.7735928E-05,   6.0167935E-05
     +,   6.2737963E-05,   6.5452688E-05,   6.8318892E-05
     +,   7.1343493E-05,   7.4533476E-05,   7.7895784E-05
     +,   8.1437538E-05,   8.5165317E-05,   8.9085996E-05
     +,   9.3205832E-05,   9.7530879E-05,   1.0206662E-04
     +,   1.0681810E-04,   1.1178954E-04,   1.1698448E-04
     +,   1.2240544E-04,   1.2805405E-04,   1.3393068E-04
     +,   1.4003468E-04,   1.4636393E-04,   1.5291521E-04
     +,   1.5968436E-04,   1.6666569E-04,   1.7385386E-04
     +,   1.8124298E-04,   1.8882894E-04,   1.9661024E-04
     +,   2.0459043E-04,   2.1278084E-04,   2.2120439E-04
     +,   2.2989933E-04,   2.3892532E-04,   2.4836871E-04
     +,   2.5834687E-04,   2.6901526E-04,   2.8056841E-04
     +,   2.9324478E-04,   3.0732166E-04,   3.2311442E-04
     +,   3.4096534E-04,   3.6123881E-04,   3.8430982E-04
     +,   4.1056698E-04,   4.4042116E-04,   4.7433382E-04
     +,   5.1286863E-04,   5.5677269E-04,   6.0707045E-04
     +,   6.6515413E-04,   7.3286850E-04,   8.1250031E-04
     +,   9.0670382E-04,   1.0182649E-03,   1.1498049E-03
     +,   1.3034146E-03,   1.4804571E-03,   1.6815924E-03
     +,   1.9073313E-03,   2.1590043E-03,   2.4400158E-03
     +,   2.7569344E-03,   3.1197639E-03,   3.5406845E-03
     +,   4.0310589E-03,   4.5973593E-03,   5.2371123E-03
     +,   5.9372066E-03,   6.6756825E-03,   7.4276840E-03
     +,   8.1730224E-03,   8.9023514E-03,   9.6176146E-03
     +,   1.0326068E-02,   1.1029407E-02,   1.1713515E-02
     +,   1.2344743E-02,   1.2876086E-02,   1.3261408E-02
     +,   1.3471954E-02,   1.3507204E-02,   1.3394651E-02
     +,   1.3178726E-02,   1.2904647E-02,   1.2604622E-02
     +,   1.2292050E-02,   1.1963689E-02,   1.1606607E-02
     +,   1.1205749E-02,   1.0750298E-02,   1.0238313E-02
     +,   9.6791117E-03,   9.0923868E-03,   8.5038682E-03
     +,   7.9385741E-03,   7.4145887E-03,   6.9399453E-03
     +,   6.5130033E-03,   6.1257626E-03,   5.7679331E-03
     +,   5.4307482E-03,   5.1091700E-03,   4.8026824E-03
     +,   4.5142462E-03,   4.2484584E-03,   4.0094489E-03
     +,   3.7992825E-03,   3.6173447E-03,   3.4606636E-03
     +,   3.3247832E-03,   3.2047485E-03,   3.0959230E-03
     +,   2.9944428E-03,   2.8973741E-03,   2.8026020E-03
     +,   2.7086567E-03,   2.6145282E-03,   2.5195049E-03
     +,   2.4230881E-03,   2.3249649E-03,   2.2250311E-03
     +,   2.1234110E-03,   2.0204652E-03,   1.9167917E-03
     +,   1.8132026E-03,   1.7106496E-03,   1.6101487E-03
     +,   1.5127021E-03,   1.4192447E-03,   1.3305667E-03
     +,   1.2472975E-03,   1.1698987E-03,   1.0986625E-03
     +,   1.0337251E-03,   9.7509945E-04,   9.2269992E-04
     +,   8.7636383E-04,   8.3586969E-04,   8.0096012E-04
     +,   7.7135733E-04,   7.4677041E-04,   7.2690344E-04
     +,   7.1146077E-04,   7.0015260E-04,   6.9269130E-04
     +,   6.8879320E-04,   6.8817660E-04,   6.9055654E-04
     +,   6.9564342E-04,   7.0313952E-04,   7.1273511E-04
     +,   7.2410714E-04,   7.3691882E-04,   7.5082161E-04
     +,   7.6545286E-04,   7.8044448E-04,   7.9542433E-04
     +,   8.1002503E-04,   8.2388875E-04,   8.3667692E-04
     +,   8.4807625E-04,   8.5780787E-04,   8.6563342E-04
     +,   8.7136298E-04,   8.7485806E-04,   8.7603537E-04
     +,   8.7486854E-04,   8.7138743E-04,   8.6567522E-04
     +,   8.5786509E-04,   8.4813294E-04,   8.3668990E-04
     +,   8.2377420E-04,   8.0964394E-04,   7.9456362E-04
     +,   7.7879737E-04,   7.6260115E-04,   7.4621470E-04
     +,   7.2985183E-04,   7.1370020E-04,   6.9791469E-04
     +,   6.8261725E-04,   6.6789432E-04,   6.5379927E-04
     +,   6.4035493E-04,   6.2755606E-04,   6.1537256E-04
     +,   6.0375413E-04,   5.9263728E-04,   5.8194587E-04
     +,   5.7159865E-04,   5.6151254E-04,   5.5160595E-04
     +,   5.4180238E-04,   5.3203118E-04,   5.2223256E-04
     +,   5.1235664E-04,   5.0236384E-04,   4.9222604E-04
     +,   4.8192599E-04,   4.7145729E-04,   4.6082199E-04
     +,   4.5003000E-04,   4.3909965E-04,   4.2805329E-04
     +,   4.1691744E-04,   4.0572227E-04,   3.9450009E-04
     +,   3.8328176E-04,   3.7209858E-04,   3.6098098E-04
     +,   3.4995697E-04,   3.3905171E-04,   3.2828696E-04
     +,   3.1768216E-04,   3.0725327E-04,   2.9701259E-04
     +,   2.8696892E-04,   2.7712932E-04,   2.6749706E-04
     +,   2.5807318E-04,   2.4885748E-04,   2.3984813E-04
     +,   2.3104153E-04,   2.2243333E-04,   2.1401935E-04
     +,   2.0579519E-04,   1.9775631E-04,   1.8989820E-04
     +,   1.8221776E-04,   1.7471242E-04,   1.6738007E-04
     +,   1.6021915E-04,   1.5322986E-04,   1.4641235E-04
     +,   1.3976746E-04,   1.3329717E-04,   1.2700380E-04
     +,   1.2088957E-04,   1.1495701E-04,   1.0920906E-04
     +,   1.0364858E-04,   9.8277793E-05,   9.3098664E-05
     +,   8.8113258E-05,   8.3322462E-05,   7.8727193E-05
     +,   7.4327196E-05,   7.0122078E-05,   6.6110239E-05
     +,   6.2289946E-05,   5.8658272E-05,   5.5212171E-05
     +,   5.1947536E-05,   4.8860111E-05,   4.5944864E-05
     +,   4.3196316E-05,   4.0608895E-05,   3.8176364E-05
     +,   3.5892561E-05,   3.3750810E-05,   3.1744647E-05
     +,   2.9867209E-05,   2.8111919E-05,   2.6471973E-05
     +,   2.4940869E-05,   2.3512039E-05,   2.2179234E-05
     +,   2.0936224E-05,   1.9777151E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz75 = Yx/0.125666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4910886E-05,   1.4965602E-05
     +,   1.5013366E-05,   1.5054545E-05,   1.5089572E-05
     +,   1.5118955E-05,   1.5143276E-05,   1.5163189E-05
     +,   1.5179438E-05,   1.5192862E-05,   1.5204387E-05
     +,   1.5215049E-05,   1.5225994E-05,   1.5238491E-05
     +,   1.5253935E-05,   1.5273859E-05,   1.5299953E-05
     +,   1.5334068E-05,   1.5378235E-05,   1.5434673E-05
     +,   1.5505821E-05,   1.5594343E-05,   1.5703152E-05
     +,   1.5835438E-05,   1.5994681E-05,   1.6184698E-05
     +,   1.6409645E-05,   1.6674068E-05,   1.6982924E-05
     +,   1.7341612E-05,   1.7756005E-05,   1.8232500E-05
     +,   1.8778026E-05,   1.9400091E-05,   2.0106805E-05
     +,   2.0906900E-05,   2.1809758E-05,   2.2825405E-05
     +,   2.3964592E-05,   2.5238611E-05,   2.6659522E-05
     +,   2.8239905E-05,   2.9992936E-05,   3.1932283E-05
     +,   3.4072025E-05,   3.6426558E-05,   3.9010443E-05
     +,   4.1838306E-05,   4.4924629E-05,   4.8283568E-05
     +,   5.1928819E-05,   5.5873254E-05,   6.0128805E-05
     +,   6.4706408E-05,   6.9615111E-05,   7.4862844E-05
     +,   8.0455349E-05,   8.6396409E-05,   9.2687740E-05
     +,   9.9328776E-05,   1.0631668E-04,   1.1364665E-04
     +,   1.2131136E-04,   1.2930253E-04,   1.3761036E-04
     +,   1.4622374E-04,   1.5513238E-04,   1.6432573E-04
     +,   1.7379606E-04,   1.8353724E-04,   1.9354859E-04
     +,   2.0383329E-04,   2.1440294E-04,   2.2527597E-04
     +,   2.3648131E-04,   2.4805931E-04,   2.6006153E-04
     +,   2.7255295E-04,   2.8561297E-04,   2.9933514E-04
     +,   3.1382553E-04,   3.2920486E-04,   3.4560385E-04
     +,   3.6316502E-04,   3.8203719E-04,   4.0237748E-04
     +,   4.2434552E-04,   4.4810833E-04,   4.7383600E-04
     +,   5.0171011E-04,   5.3192832E-04,   5.6471076E-04
     +,   6.0031260E-04,   6.3904031E-04,   6.8126514E-04
     +,   7.2743150E-04,   7.7807956E-04,   8.3384285E-04
     +,   8.9546450E-04,   9.6378761E-04,   1.0397806E-03
     +,   1.1245483E-03,   1.2194231E-03,   1.3260876E-03
     +,   1.4468422E-03,   1.5849631E-03,   1.7451653E-03
     +,   1.9341165E-03,   2.1608418E-03,   2.4367371E-03
     +,   2.7748819E-03,   3.1884790E-03,   3.6881659E-03
     +,   4.2790291E-03,   4.9579688E-03,   5.7134251E-03
     +,   6.5276953E-03,   7.3820315E-03,   8.2611218E-03
     +,   9.1546485E-03,   1.0054132E-02,   1.0948407E-02
     +,   1.1823192E-02,   1.2666823E-02,   1.3476420E-02
     +,   1.4255918E-02,   1.5007379E-02,   1.5729623E-02
     +,   1.6434193E-02,   1.7160153E-02,   1.7951185E-02
     +,   1.8789023E-02,   1.9538309E-02,   1.9975655E-02
     +,   1.9912807E-02,   1.9328889E-02,   1.8403115E-02
     +,   1.7413000E-02,   1.6573384E-02,   1.5934279E-02
     +,   1.5398232E-02,   1.4820329E-02,   1.4105613E-02
     +,   1.3247220E-02,   1.2307434E-02,   1.1374680E-02
     +,   1.0523333E-02,   9.7872335E-03,   9.1525251E-03
     +,   8.5718576E-03,   7.9929084E-03,   7.3846956E-03
     +,   6.7479801E-03,   6.1079613E-03,   5.4979166E-03
     +,   4.9445289E-03,   4.4606854E-03,   4.0458627E-03
     +,   3.6908039E-03,   3.3829659E-03,   3.1104984E-03
     +,   2.8643501E-03,   2.6387617E-03,   2.4307091E-03
     +,   2.2389991E-03,   2.0634150E-03,   1.9040586E-03
     +,   1.7609436E-03,   1.6337894E-03,   1.5220047E-03
     +,   1.4247324E-03,   1.3409265E-03,   1.2694246E-03
     +,   1.2090314E-03,   1.1585711E-03,   1.1169225E-03
     +,   1.0830474E-03,   1.0560063E-03,   1.0349656E-03
     +,   1.0191930E-03,   1.0080532E-03,   1.0010031E-03
     +,   9.9757698E-04,   9.9737966E-04,   1.0000806E-03
     +,   1.0054037E-03,   1.0131282E-03,   1.0230781E-03
     +,   1.0351198E-03,   1.0491507E-03,   1.0650891E-03
     +,   1.0828587E-03,   1.1023664E-03,   1.1234827E-03
     +,   1.1460226E-03,   1.1697223E-03,   1.1942217E-03
     +,   1.2190560E-03,   1.2436534E-03,   1.2673431E-03
     +,   1.2893702E-03,   1.3089230E-03,   1.3251685E-03
     +,   1.3372940E-03,   1.3445443E-03,   1.3462729E-03
     +,   1.3419732E-03,   1.3313150E-03,   1.3141637E-03
     +,   1.2905921E-03,   1.2608784E-03,   1.2254923E-03
     +,   1.1850746E-03,   1.1403974E-03,   1.0923282E-03
     +,   1.0417936E-03,   9.8973198E-04,   9.3705306E-04
     +,   8.8460621E-04,   8.3315821E-04,   7.8336260E-04
     +,   7.3575525E-04,   6.9074979E-04,   6.4863818E-04
     +,   6.0959504E-04,   5.7369290E-04,   5.4091774E-04
     +,   5.1118282E-04,   4.8434283E-04,   4.6021087E-04
     +,   4.3857394E-04,   4.1920372E-04,   4.0186459E-04
     +,   3.8632349E-04,   3.7235772E-04,   3.5975638E-04
     +,   3.4832375E-04,   3.3788310E-04,   3.2827570E-04
     +,   3.1935974E-04,   3.1101142E-04,   3.0312373E-04
     +,   2.9560458E-04,   2.8837545E-04,   2.8137001E-04
     +,   2.7453335E-04,   2.6782023E-04,   2.6119332E-04
     +,   2.5462260E-04,   2.4808486E-04,   2.4156176E-04
     +,   2.3503936E-04,   2.2850845E-04,   2.2196295E-04
     +,   2.1539930E-04,   2.0881667E-04,   2.0221670E-04
     +,   1.9560321E-04,   1.8898110E-04,   1.8235682E-04
     +,   1.7573852E-04,   1.6913556E-04,   1.6255780E-04
     +,   1.5601583E-04,   1.4952147E-04,   1.4308645E-04
     +,   1.3672275E-04,   1.3044277E-04,   1.2425912E-04
     +,   1.1818348E-04,   1.1222748E-04,   1.0640248E-04
     +,   1.0071927E-04,   9.5187519E-05,   8.9816072E-05
     +,   8.4613406E-05,   7.9586280E-05,   7.4741074E-05
     +,   7.0082468E-05,   6.5614578E-05,   6.1339888E-05
     +,   5.7260317E-05,   5.3376170E-05,   4.9687271E-05
     +,   4.6191890E-05,   4.2887903E-05,   3.9771967E-05
     +,   3.6839971E-05,   3.4087399E-05,   3.1508749E-05
     +,   2.9098328E-05,   2.6849686E-05,   2.4756293E-05
     +,   2.2811073E-05,   2.1007005E-05,   1.9336705E-05
     +,   1.7792951E-05,   1.6368322E-05,   1.5055648E-05
     +,   1.3847712E-05,   1.2737611E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz80 = Yx/0.159046511627907
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8652025E-05,   1.9080824E-05
     +,   1.9516683E-05,   1.9960131E-05,   2.0411780E-05
     +,   2.0872287E-05,   2.1342368E-05,   2.1822818E-05
     +,   2.2314462E-05,   2.2818218E-05,   2.3335047E-05
     +,   2.3865949E-05,   2.4411995E-05,   2.4974290E-05
     +,   2.5553993E-05,   2.6152280E-05,   2.6770371E-05
     +,   2.7409500E-05,   2.8070916E-05,   2.8755869E-05
     +,   2.9465602E-05,   3.0201340E-05,   3.0964267E-05
     +,   3.1755593E-05,   3.2576365E-05,   3.3427688E-05
     +,   3.4310524E-05,   3.5225763E-05,   3.6174228E-05
     +,   3.7156628E-05,   3.8173566E-05,   3.9225528E-05
     +,   4.0312902E-05,   4.1435957E-05,   4.2594831E-05
     +,   4.3789561E-05,   4.5020079E-05,   4.6286194E-05
     +,   4.7587735E-05,   4.8924292E-05,   5.0295585E-05
     +,   5.1701241E-05,   5.3140873E-05,   5.4614193E-05
     +,   5.6120982E-05,   5.7661149E-05,   5.9234782E-05
     +,   6.0842234E-05,   6.2484083E-05,   6.4161308E-05
     +,   6.5875305E-05,   6.7627916E-05,   6.9421520E-05
     +,   7.1259194E-05,   7.3144540E-05,   7.5082127E-05
     +,   7.7077144E-05,   7.9135702E-05,   8.1264880E-05
     +,   8.3472682E-05,   8.5768093E-05,   8.8161214E-05
     +,   9.0662972E-05,   9.3285533E-05,   9.6042088E-05
     +,   9.8946490E-05,   1.0201388E-04,   1.0525984E-04
     +,   1.0870110E-04,   1.1235451E-04,   1.1623789E-04
     +,   1.2036883E-04,   1.2476562E-04,   1.2944588E-04
     +,   1.3442735E-04,   1.3972748E-04,   1.4536252E-04
     +,   1.5134775E-04,   1.5769777E-04,   1.6442579E-04
     +,   1.7154275E-04,   1.7905884E-04,   1.8698130E-04
     +,   1.9531626E-04,   2.0406675E-04,   2.1323442E-04
     +,   2.2281791E-04,   2.3281440E-04,   2.4321779E-04
     +,   2.5402106E-04,   2.6521544E-04,   2.7678997E-04
     +,   2.8873293E-04,   3.0103317E-04,   3.1368068E-04
     +,   3.2666663E-04,   3.3998839E-04,   3.5364897E-04
     +,   3.6766418E-04,   3.8206406E-04,   3.9690285E-04
     +,   4.1226283E-04,   4.2826668E-04,   4.4508345E-04
     +,   4.6294185E-04,   4.8213880E-04,   5.0304306E-04
     +,   5.2610243E-04,   5.5184169E-04,   5.8085698E-04
     +,   6.1380124E-04,   6.5137941E-04,   6.9433270E-04
     +,   7.4345205E-04,   7.9959061E-04,   8.6372794E-04
     +,   9.3703961E-04,   1.0210212E-03,   1.1175827E-03
     +,   1.2291444E-03,   1.3586193E-03,   1.5092291E-03
     +,   1.6841443E-03,   1.8859499E-03,   2.1160415E-03
     +,   2.3742269E-03,   2.6589555E-03,   2.9682822E-03
     +,   3.3018307E-03,   3.6630523E-03,   4.0612575E-03
     +,   4.5119794E-03,   5.0353832E-03,   5.6523224E-03
     +,   6.3800509E-03,   7.2297924E-03,   8.2083559E-03
     +,   9.3222661E-03,   1.0577460E-02,   1.1967697E-02
     +,   1.3455662E-02,   1.4964349E-02,   1.6392987E-02
     +,   1.7651422E-02,   1.8694770E-02,   1.9551694E-02
     +,   2.0347700E-02,   2.1291178E-02,   2.2555519E-02
     +,   2.4075203E-02,   2.5452834E-02,   2.6173295E-02
     +,   2.5992179E-02,   2.5103906E-02,   2.3928020E-02
     +,   2.2781897E-02,   2.1749616E-02,   2.0756627E-02
     +,   1.9686645E-02,   1.8451594E-02,   1.7023342E-02
     +,   1.5443755E-02,   1.3804414E-02,   1.2199785E-02
     +,   1.0686917E-02,   9.2811165E-03,   7.9810023E-03
     +,   6.7927088E-03,   5.7341577E-03,   4.8239916E-03
     +,   4.0699276E-03,   3.4654182E-03,   2.9938160E-03
     +,   2.6346941E-03,   2.3682436E-03,   2.1770527E-03
     +,   2.0464123E-03,   1.9640762E-03,   1.9198913E-03
     +,   1.9054613E-03,   1.9137600E-03,   1.9387639E-03
     +,   1.9751620E-03,   2.0181907E-03,   2.0635624E-03
     +,   2.1074589E-03,   2.1465735E-03,   2.1781796E-03
     +,   2.2001930E-03,   2.2112434E-03,   2.2107242E-03
     +,   2.1988053E-03,   2.1764024E-03,   2.1450943E-03
     +,   2.1069613E-03,   2.0644111E-03,   2.0199497E-03
     +,   1.9759629E-03,   1.9344960E-03,   1.8971029E-03
     +,   1.8647270E-03,   1.8376635E-03,   1.8155804E-03
     +,   1.7975924E-03,   1.7823931E-03,   1.7683936E-03
     +,   1.7538856E-03,   1.7371909E-03,   1.7167932E-03
     +,   1.6914424E-03,   1.6602254E-03,   1.6226107E-03
     +,   1.5784558E-03,   1.5279843E-03,   1.4717488E-03
     +,   1.4105793E-03,   1.3455061E-03,   1.2776889E-03
     +,   1.2083404E-03,   1.1386691E-03,   1.0698001E-03
     +,   1.0027371E-03,   9.3832961E-04,   8.7724440E-04
     +,   8.1995846E-04,   7.6676492E-04,   7.1779225E-04
     +,   6.7302270E-04,   6.3231564E-04,   5.9544062E-04
     +,   5.6210702E-04,   5.3198717E-04,   5.0473586E-04
     +,   4.8001116E-04,   4.5748972E-04,   4.3687114E-04
     +,   4.1788531E-04,   4.0029659E-04,   3.8390225E-04
     +,   3.6852955E-04,   3.5403477E-04,   3.4030032E-04
     +,   3.2723055E-04,   3.1474727E-04,   3.0278740E-04
     +,   2.9130082E-04,   2.8024698E-04,   2.6959201E-04
     +,   2.5930780E-04,   2.4937140E-04,   2.3976188E-04
     +,   2.3046076E-04,   2.2145164E-04,   2.1271939E-04
     +,   2.0424943E-04,   1.9602783E-04,   1.8804213E-04
     +,   1.8028074E-04,   1.7273234E-04,   1.6538659E-04
     +,   1.5823479E-04,   1.5126917E-04,   1.4448288E-04
     +,   1.3787011E-04,   1.3142705E-04,   1.2515025E-04
     +,   1.1903758E-04,   1.1308822E-04,   1.0730229E-04
     +,   1.0168037E-04,   9.6223645E-05,   9.0934191E-05
     +,   8.5814412E-05,   8.0866543E-05,   7.6092845E-05
     +,   7.1495982E-05,   6.7077679E-05,   6.2839979E-05
     +,   5.8783797E-05,   5.4910088E-05,   5.1218649E-05
     +,   4.7709178E-05,   4.4380129E-05,   4.1229763E-05
     +,   3.8255264E-05,   3.5453490E-05,   3.2820430E-05
     +,   3.0351508E-05,   2.8041857E-05,   2.5885856E-05
     +,   2.3877768E-05,   2.2011252E-05,   2.0279978E-05
     +,   1.8677187E-05,   1.7196207E-05,   1.5830123E-05
     +,   1.4572187E-05,   1.3415553E-05,   1.2353629E-05
     +,   1.1379841E-05,   1.0487917E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz85 = Yx/0.178022727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5167698E-05,   1.5714037E-05
     +,   1.6269238E-05,   1.6832992E-05,   1.7404987E-05
     +,   1.7984910E-05,   1.8572444E-05,   1.9167268E-05
     +,   1.9769066E-05,   2.0377553E-05,   2.0992424E-05
     +,   2.1613407E-05,   2.2240247E-05,   2.2872715E-05
     +,   2.3510607E-05,   2.4153749E-05,   2.4802026E-05
     +,   2.5455349E-05,   2.6113692E-05,   2.6777070E-05
     +,   2.7445589E-05,   2.8119399E-05,   2.8798740E-05
     +,   2.9483970E-05,   3.0175463E-05,   3.0873784E-05
     +,   3.1579551E-05,   3.2293530E-05,   3.3016611E-05
     +,   3.3749806E-05,   3.4494318E-05,   3.5251458E-05
     +,   3.6022742E-05,   3.6809863E-05,   3.7614700E-05
     +,   3.8439310E-05,   3.9285962E-05,   4.0157160E-05
     +,   4.1055646E-05,   4.1984302E-05,   4.2946347E-05
     +,   4.3945169E-05,   4.4984412E-05,   4.6067955E-05
     +,   4.7199908E-05,   4.8384602E-05,   4.9626582E-05
     +,   5.0930616E-05,   5.2301632E-05,   5.3744759E-05
     +,   5.5265260E-05,   5.6868492E-05,   5.8559915E-05
     +,   6.0345148E-05,   6.2229621E-05,   6.4218919E-05
     +,   6.6318469E-05,   6.8533627E-05,   7.0869501E-05
     +,   7.3331023E-05,   7.5922842E-05,   7.8649260E-05
     +,   8.1513987E-05,   8.4520536E-05,   8.7671833E-05
     +,   9.0969894E-05,   9.4416544E-05,   9.8012424E-05
     +,   1.0175777E-04,   1.0565160E-04,   1.0969255E-04
     +,   1.1387780E-04,   1.1820409E-04,   1.2266672E-04
     +,   1.2726035E-04,   1.3197877E-04,   1.3681450E-04
     +,   1.4175916E-04,   1.4680380E-04,   1.5193885E-04
     +,   1.5715361E-04,   1.6243753E-04,   1.6777910E-04
     +,   1.7316762E-04,   1.7859176E-04,   1.8404156E-04
     +,   1.8950725E-04,   1.9498124E-04,   2.0045693E-04
     +,   2.0593079E-04,   2.1140216E-04,   2.1687376E-04
     +,   2.2235268E-04,   2.2785121E-04,   2.3338785E-04
     +,   2.3898702E-04,   2.4468129E-04,   2.5051102E-04
     +,   2.5652637E-04,   2.6278646E-04,   2.6936183E-04
     +,   2.7633357E-04,   2.8379497E-04,   2.9185010E-04
     +,   3.0061582E-04,   3.1022006E-04,   3.2080119E-04
     +,   3.3250707E-04,   3.4549463E-04,   3.5992809E-04
     +,   3.7597585E-04,   3.9381202E-04,   4.1361182E-04
     +,   4.3555570E-04,   4.5982425E-04,   4.8660600E-04
     +,   5.1609293E-04,   5.4848980E-04,   5.8401009E-04
     +,   6.2288344E-04,   6.6535361E-04,   7.1167108E-04
     +,   7.6208595E-04,   8.1683841E-04,   8.7613560E-04
     +,   9.4012037E-04,   1.0088554E-03,   1.0822803E-03
     +,   1.1602063E-03,   1.2422905E-03,   1.3280768E-03
     +,   1.4170322E-03,   1.5086740E-03,   1.6027255E-03
     +,   1.6993646E-03,   1.7995191E-03,   1.9051863E-03
     +,   2.0197590E-03,   2.1482639E-03,   2.2973737E-03
     +,   2.4750843E-03,   2.6899700E-03,   2.9499703E-03
     +,   3.2608360E-03,   3.6245610E-03,   4.0385858E-03
     +,   4.4963621E-03,   4.9901828E-03,   5.5163894E-03
     +,   6.0815979E-03,   6.7066210E-03,   7.4240742E-03
     +,   8.2674799E-03,   9.2538008E-03,   1.0366305E-02
     +,   1.1546663E-02,   1.2703931E-02,   1.3742293E-02
     +,   1.4599766E-02,   1.5278679E-02,   1.5845584E-02
     +,   1.6393555E-02,   1.6989756E-02,   1.7642703E-02
     +,   1.8301262E-02,   1.8866803E-02,   1.9204387E-02
     +,   1.9169217E-02,   1.8664168E-02,   1.7699555E-02
     +,   1.6398527E-02,   1.4935157E-02,   1.3458082E-02
     +,   1.2059853E-02,   1.0796584E-02,   9.7189397E-03
     +,   8.8834986E-03,   8.3430801E-03,   8.1307087E-03
     +,   8.2468390E-03,   8.6518284E-03,   9.2646936E-03
     +,   9.9716429E-03,   1.0645648E-02,   1.1172090E-02
     +,   1.1471427E-02,   1.1510818E-02,   1.1301562E-02
     +,   1.0886599E-02,   1.0324920E-02,   9.6787037E-03
     +,   9.0057403E-03,   8.3556511E-03,   7.7669551E-03
     +,   7.2636418E-03,   6.8522459E-03,   6.5216124E-03
     +,   6.2467642E-03,   5.9962869E-03,   5.7407469E-03
     +,   5.4593515E-03,   5.1431148E-03,   4.7944277E-03
     +,   4.4240495E-03,   4.0470045E-03,   3.6786399E-03
     +,   3.3318426E-03,   3.0156721E-03,   2.7351850E-03
     +,   2.4920560E-03,   2.2855832E-03,   2.1136000E-03
     +,   1.9731345E-03,   1.8607947E-03,   1.7729875E-03
     +,   1.7060271E-03,   1.6562017E-03,   1.6198746E-03
     +,   1.5935937E-03,   1.5742024E-03,   1.5589134E-03
     +,   1.5453689E-03,   1.5316554E-03,   1.5162925E-03
     +,   1.4981967E-03,   1.4766413E-03,   1.4512083E-03
     +,   1.4217466E-03,   1.3883241E-03,   1.3511932E-03
     +,   1.3107542E-03,   1.2675178E-03,   1.2220665E-03
     +,   1.1750198E-03,   1.1270063E-03,   1.0786242E-03
     +,   1.0304179E-03,   9.8286220E-04,   9.3634595E-04
     +,   8.9116493E-04,   8.4752362E-04,   8.0554688E-04
     +,   7.6528866E-04,   7.2674191E-04,   6.8985892E-04
     +,   6.5456645E-04,   6.2077725E-04,   5.8839837E-04
     +,   5.5734190E-04,   5.2753242E-04,   4.9890409E-04
     +,   4.7140382E-04,   4.4499265E-04,   4.1964164E-04
     +,   3.9532621E-04,   3.7202809E-04,   3.4973185E-04
     +,   3.2842249E-04,   3.0808258E-04,   2.8869245E-04
     +,   2.7023169E-04,   2.5267704E-04,   2.3600234E-04
     +,   2.2017970E-04,   2.0518198E-04,   1.9098024E-04
     +,   1.7754569E-04,   1.6485098E-04,   1.5286970E-04
     +,   1.4157558E-04,   1.3094359E-04,   1.2095028E-04
     +,   1.1157307E-04,   1.0278926E-04,   9.4576819E-05
     +,   8.6914537E-05,   7.9780330E-05,   7.3152820E-05
     +,   6.7009598E-05,   6.1328668E-05,   5.6087047E-05
     +,   5.1262101E-05,   4.6830395E-05,   4.2768977E-05
     +,   3.9054386E-05,   3.5663834E-05,   3.2574499E-05
     +,   2.9764080E-05,   2.7211185E-05,   2.4894816E-05
     +,   2.2795179E-05,   2.0893154E-05,   1.9170937E-05
     +,   1.7611575E-05,   1.6199489E-05,   1.4920035E-05
     +,   1.3759908E-05,   1.2706772E-05,   1.1749529E-05
     +,   1.0878010E-05,   1.0083159E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz90 = Yx/0.177227272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1712291E-06,   9.9183526E-06
     +,   1.0711736E-05,   1.1552745E-05,   1.2442639E-05
     +,   1.3382547E-05,   1.4373457E-05,   1.5416192E-05
     +,   1.6511380E-05,   1.7659506E-05,   1.8860790E-05
     +,   2.0115242E-05,   2.1422620E-05,   2.2782431E-05
     +,   2.4193916E-05,   2.5656014E-05,   2.7167385E-05
     +,   2.8726399E-05,   3.0331086E-05,   3.1979198E-05
     +,   3.3668159E-05,   3.5395089E-05,   3.7156769E-05
     +,   3.8949809E-05,   4.0770319E-05,   4.2614327E-05
     +,   4.4477514E-05,   4.6355330E-05,   4.8243008E-05
     +,   5.0135604E-05,   5.2027990E-05,   5.3914926E-05
     +,   5.5791057E-05,   5.7650985E-05,   5.9489241E-05
     +,   6.1300409E-05,   6.3079096E-05,   6.4819993E-05
     +,   6.6518020E-05,   6.8168083E-05,   6.9765498E-05
     +,   7.1305709E-05,   7.2784555E-05,   7.4198106E-05
     +,   7.5542906E-05,   7.6815842E-05,   7.8014302E-05
     +,   7.9136102E-05,   8.0179598E-05,   8.1143684E-05
     +,   8.2027800E-05,   8.2831946E-05,   8.3556748E-05
     +,   8.4203450E-05,   8.4773877E-05,   8.5270542E-05
     +,   8.5696549E-05,   8.6055661E-05,   8.6352258E-05
     +,   8.6591383E-05,   8.6778658E-05,   8.6920372E-05
     +,   8.7023378E-05,   8.7095126E-05,   8.7143584E-05
     +,   8.7177323E-05,   8.7205364E-05,   8.7237240E-05
     +,   8.7282853E-05,   8.7352579E-05,   8.7457076E-05
     +,   8.7607288E-05,   8.7814435E-05,   8.8089830E-05
     +,   8.8444918E-05,   8.8891138E-05,   8.9439818E-05
     +,   9.0102090E-05,   9.0888840E-05,   9.1810551E-05
     +,   9.2877097E-05,   9.4097872E-05,   9.5481359E-05
     +,   9.7035219E-05,   9.8766068E-05,   1.0067946E-04
     +,   1.0277957E-04,   1.0506945E-04,   1.0755037E-04
     +,   1.1022249E-04,   1.1308432E-04,   1.1613276E-04
     +,   1.1936322E-04,   1.2276984E-04,   1.2634569E-04
     +,   1.3008229E-04,   1.3397099E-04,   1.3800208E-04
     +,   1.4216641E-04,   1.4645467E-04,   1.5085901E-04
     +,   1.5537249E-04,   1.5999100E-04,   1.6471246E-04
     +,   1.6953878E-04,   1.7447589E-04,   1.7953414E-04
     +,   1.8472888E-04,   1.9008142E-04,   1.9561894E-04
     +,   2.0137406E-04,   2.0738582E-04,   2.1369803E-04
     +,   2.2036042E-04,   2.2742587E-04,   2.3495137E-04
     +,   2.4299520E-04,   2.5161717E-04,   2.6087576E-04
     +,   2.7082796E-04,   2.8152778E-04,   2.9302359E-04
     +,   3.0535876E-04,   3.1857044E-04,   3.3268900E-04
     +,   3.4773676E-04,   3.6372972E-04,   3.8067656E-04
     +,   3.9858150E-04,   4.1744238E-04,   4.3725691E-04
     +,   4.5802034E-04,   4.7973421E-04,   5.0240400E-04
     +,   5.2605127E-04,   5.5071514E-04,   5.7645951E-04
     +,   6.0338102E-04,   6.3161779E-04,   6.6135253E-04
     +,   6.9281703E-04,   7.2629080E-04,   7.6210103E-04
     +,   8.0061302E-04,   8.4221398E-04,   8.8730978E-04
     +,   9.3630911E-04,   9.8961941E-04,   1.0476527E-03
     +,   1.1108440E-03,   1.1796745E-03,   1.2546817E-03
     +,   1.3364688E-03,   1.4256752E-03,   1.5228920E-03
     +,   1.6285154E-03,   1.7425650E-03,   1.8644849E-03
     +,   1.9929628E-03,   2.1258339E-03,   2.2601618E-03
     +,   2.3924618E-03,   2.5190727E-03,   2.6366543E-03
     +,   2.7426591E-03,   2.8356572E-03,   2.9154494E-03
     +,   2.9829603E-03,   3.0399843E-03,   3.0889849E-03
     +,   3.1331491E-03,   3.1768430E-03,   3.2263808E-03
     +,   3.2907971E-03,   3.3821680E-03,   3.5152235E-03
     +,   3.7062252E-03,   3.9717858E-03,   4.3284190E-03
     +,   4.7935378E-03,   5.3876089E-03,   6.1355946E-03
     +,   7.0639169E-03,   8.1889927E-03,   9.4976770E-03
     +,   1.0929358E-02,   1.2375492E-02,   1.3707080E-02
     +,   1.4822753E-02,   1.5696099E-02,   1.6394325E-02
     +,   1.7048098E-02,   1.7780771E-02,   1.8642863E-02
     +,   1.9597605E-02,   2.0551085E-02,   2.1380538E-02
     +,   2.1947032E-02,   2.2111030E-02,   2.1755941E-02
     +,   2.0823788E-02,   1.9374784E-02,   1.7626420E-02
     +,   1.5892467E-02,   1.4431064E-02,   1.3321977E-02
     +,   1.2470134E-02,   1.1710744E-02,   1.0922365E-02
     +,   1.0075572E-02,   9.2087165E-03,   8.3717881E-03
     +,   7.5869192E-03,   6.8466235E-03,   6.1363992E-03
     +,   5.4552360E-03,   4.8190574E-03,   4.2501809E-03
     +,   3.7645756E-03,   3.3654035E-03,   3.0440618E-03
     +,   2.7854487E-03,   2.5733921E-03,   2.3940834E-03
     +,   2.2373996E-03,   2.0967654E-03,   1.9683384E-03
     +,   1.8500584E-03,   1.7408719E-03,   1.6402097E-03
     +,   1.5477110E-03,   1.4630670E-03,   1.3859674E-03
     +,   1.3160724E-03,   1.2529999E-03,   1.1962836E-03
     +,   1.1453623E-03,   1.0995783E-03,   1.0581837E-03
     +,   1.0203670E-03,   9.8529318E-04,   9.5215178E-04
     +,   9.2019181E-04,   8.8875787E-04,   8.5731741E-04
     +,   8.2547578E-04,   7.9297950E-04,   7.5970765E-04
     +,   7.2566082E-04,   6.9094496E-04,   6.5574242E-04
     +,   6.2029180E-04,   5.8486674E-04,   5.4975238E-04
     +,   5.1522523E-04,   4.8153999E-04,   4.4892155E-04
     +,   4.1755562E-04,   3.8758357E-04,   3.5910434E-04
     +,   3.3217869E-04,   3.0683103E-04,   2.8305326E-04
     +,   2.6081214E-04,   2.4005743E-04,   2.2072341E-04
     +,   2.0273549E-04,   1.8601610E-04,   1.7048663E-04
     +,   1.5606890E-04,   1.4268841E-04,   1.3027611E-04
     +,   1.1876800E-04,   1.0810470E-04,   9.8231896E-05
     +,   8.9101042E-05,   8.0666410E-05,   7.2886942E-05
     +,   6.5723543E-05,   5.9140370E-05,   5.3102671E-05
     +,   4.7577996E-05,   4.2534448E-05,   3.7941798E-05
     +,   3.3770142E-05,   2.9990984E-05,   2.6576292E-05
     +,   2.3498967E-05,   2.0733161E-05,   1.8253666E-05
     +,   1.6036722E-05,   1.4059421E-05,   1.2300371E-05
     +,   1.0739192E-05,   9.3570316E-06,   8.1361377E-06
     +,   7.0602418E-06,   6.1141895E-06,   5.2842020E-06
     +,   4.5575816E-06,   3.9228657E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ttz95 = Yx/0.155953488372093
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2561728E-05,   1.2743404E-05
     +,   1.2916306E-05,   1.3080010E-05,   1.3234107E-05
     +,   1.3378210E-05,   1.3511957E-05,   1.3635009E-05
     +,   1.3747051E-05,   1.3847796E-05,   1.3936985E-05
     +,   1.4014385E-05,   1.4079804E-05,   1.4133067E-05
     +,   1.4174039E-05,   1.4202620E-05,   1.4218736E-05
     +,   1.4222359E-05,   1.4213484E-05,   1.4192142E-05
     +,   1.4158406E-05,   1.4112378E-05,   1.4054203E-05
     +,   1.3984041E-05,   1.3902116E-05,   1.3808662E-05
     +,   1.3703954E-05,   1.3588306E-05,   1.3462060E-05
     +,   1.3325590E-05,   1.3179304E-05,   1.3023645E-05
     +,   1.2859081E-05,   1.2686111E-05,   1.2505273E-05
     +,   1.2317126E-05,   1.2122263E-05,   1.1921312E-05
     +,   1.1714914E-05,   1.1503770E-05,   1.1288581E-05
     +,   1.1070100E-05,   1.0849099E-05,   1.0626398E-05
     +,   1.0402836E-05,   1.0179298E-05,   9.9567023E-06
     +,   9.7360016E-06,   9.5181949E-06,   9.3043218E-06
     +,   9.0954627E-06,   8.8927472E-06,   8.6973578E-06
     +,   8.5105085E-06,   8.3334926E-06,   8.1676317E-06
     +,   8.0143200E-06,   7.8750045E-06,   7.7511868E-06
     +,   7.6444294E-06,   7.5563557E-06,   7.4886480E-06
     +,   7.4430463E-06,   7.4213435E-06,   7.4253880E-06
     +,   7.4570803E-06,   7.5183680E-06,   7.6112315E-06
     +,   7.7376935E-06,   7.8997928E-06,   8.0995987E-06
     +,   8.3391651E-06,   8.6205646E-06,   8.9458235E-06
     +,   9.3169519E-06,   9.7359243E-06,   1.0204619E-05
     +,   1.0724817E-05,   1.1298239E-05,   1.1926478E-05
     +,   1.2610921E-05,   1.3352873E-05,   1.4153363E-05
     +,   1.5013299E-05,   1.5933256E-05,   1.6913666E-05
     +,   1.7954559E-05,   1.9055809E-05,   2.0216839E-05
     +,   2.1436841E-05,   2.2714674E-05,   2.4048766E-05
     +,   2.5437166E-05,   2.6877640E-05,   2.8367605E-05
     +,   2.9903926E-05,   3.1483331E-05,   3.3101962E-05
     +,   3.4755827E-05,   3.6440400E-05,   3.8151036E-05
     +,   3.9882601E-05,   4.1629912E-05,   4.3387339E-05
     +,   4.5149220E-05,   4.6909718E-05,   4.8662801E-05
     +,   5.0402308E-05,   5.2122185E-05,   5.3816369E-05
     +,   5.5478667E-05,   5.7103214E-05,   5.8684040E-05
     +,   6.0215567E-05,   6.1692204E-05,   6.3108790E-05
     +,   6.4460284E-05,   6.5742075E-05,   6.6949724E-05
     +,   6.8079251E-05,   6.9127032E-05,   7.0089700E-05
     +,   7.0964321E-05,   7.1748349E-05,   7.2439601E-05
     +,   7.3036208E-05,   7.3536728E-05,   7.3939977E-05
     +,   7.4245188E-05,   7.4451818E-05,   7.4559692E-05
     +,   7.4568852E-05,   7.4479671E-05,   7.4292715E-05
     +,   7.4008800E-05,   7.3628951E-05,   7.3154442E-05
     +,   7.2586736E-05,   7.1927461E-05,   7.1178460E-05
     +,   7.0341775E-05,   6.9419671E-05,   6.8414600E-05
     +,   6.7329143E-05,   6.6166234E-05,   6.4928943E-05
     +,   6.3620515E-05,   6.2244566E-05,   6.0804938E-05
     +,   5.9305665E-05,   5.7751095E-05,   5.6145989E-05
     +,   5.4495558E-05,   5.2805481E-05,   5.1082214E-05
     +,   4.9333488E-05,   4.7568799E-05,   4.5800167E-05
     +,   4.4043591E-05,   4.2321204E-05,   4.0663570E-05
     +,   3.9113605E-05,   3.7731508E-05,   3.6600668E-05
     +,   3.5834986E-05,   3.5587338E-05,   3.6058645E-05
     +,   3.7506528E-05,   4.0252991E-05,   4.4689277E-05
     +,   5.1275754E-05,   6.0535742E-05,   7.3042465E-05
     +,   8.9396679E-05,   1.1019396E-04,   1.3599101E-04
     +,   1.6726511E-04,   2.0437413E-04,   2.4752886E-04
     +,   2.9678180E-04,   3.5202992E-04,   4.1303574E-04
     +,   4.7947172E-04,   5.5097695E-04,   6.2719954E-04
     +,   7.0781709E-04,   7.9253141E-04,   8.8101730E-04
     +,   9.7281300E-04,   1.0671692E-03,   1.1629136E-03
     +,   1.2583134E-03,   1.3509981E-03,   1.4379969E-03
     +,   1.5158921E-03,   1.5810714E-03,   1.6300794E-03
     +,   1.6600089E-03,   1.6688723E-03,   1.6558690E-03
     +,   1.6215182E-03,   1.5676260E-03,   1.4970761E-03
     +,   1.4134962E-03,   1.3208615E-03,   1.2230710E-03
     +,   1.1236046E-03,   1.0252864E-03,   9.3016657E-04
     +,   8.3952653E-04,   7.5399695E-04,   6.7373761E-04
     +,   5.9862208E-04,   5.2840711E-04,   4.6286843E-04
     +,   4.0187896E-04,   3.4542664E-04,   2.9358783E-04
     +,   2.4648642E-04,   2.0424153E-04,   1.6690698E-04
     +,   1.3444127E-04,   1.0669210E-04,   8.3394800E-05
     +,   6.4188076E-05,   4.8642130E-05,   3.6289555E-05
     +,   2.6653142E-05,   1.9270967E-05,   1.3716494E-05
     +,   9.6111353E-06,   6.6298717E-06,   4.5022175E-06
     +,   3.0097015E-06,   1.9805716E-06,   1.2829126E-06
     +,   8.1790671E-07,   5.1318852E-07,   3.1686847E-07
     +,   1.9251102E-07,   1.1506725E-07,   6.7659876E-08
     +,   3.9135305E-08,   2.2265921E-08,   1.2460970E-08
     +,   6.8606947E-09,   3.7172925E-09,   1.9831545E-09
     +,   1.0426899E-09,   5.4113897E-10,   2.7789326E-10
     +,   1.4174778E-10,   7.2234288E-11,   3.7082355E-11
     +,   1.9388716E-11,   1.0458143E-11,   5.8911140E-12
     +,   3.4931834E-12,   2.1819033E-12,   1.4265150E-12
     +,   9.6607097E-13,   6.7029346E-13,   4.7210152E-13
     +,   3.3526881E-13,   2.3899995E-13,   1.7053904E-13
     +,   1.2159930E-13,   8.6555939E-14,   6.1472982E-14
     +,   4.3546723E-14,   3.0763254E-14,   2.1671160E-14
     +,   1.5222627E-14,   1.0662026E-14,   7.4460278E-15
     +,   5.1850245E-15,   3.6000463E-15,   2.4923413E-15
     +,   1.7204388E-15,   1.1841733E-15,   8.1269301E-16
     +,   5.5614161E-16,   3.7947457E-16,   2.5818681E-16
     +,   1.7515776E-16,   1.1849050E-16,   7.9927485E-17
     +,   5.3760678E-17,   3.6058626E-17,   2.4117046E-17
     +,   1.6085298E-17,   1.0698497E-17,   7.0962658E-18
     +,   4.6940998E-18,   3.0968623E-18,   2.0377373E-18
     +,   1.3374223E-18,   8.7559498E-19,   5.7188042E-19
     +,   3.7265753E-19,   2.4231791E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz100 = Yx/0.01092
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.6270396E-06,   9.9889539E-06
     +,   1.0352027E-05,   1.0715412E-05,   1.1078237E-05
     +,   1.1439591E-05,   1.1798547E-05,   1.2154153E-05
     +,   1.2505438E-05,   1.2851429E-05,   1.3191135E-05
     +,   1.3523560E-05,   1.3847713E-05,   1.4162609E-05
     +,   1.4467269E-05,   1.4760740E-05,   1.5042077E-05
     +,   1.5310370E-05,   1.5564734E-05,   1.5804320E-05
     +,   1.6028327E-05,   1.6235987E-05,   1.6426584E-05
     +,   1.6599470E-05,   1.6754024E-05,   1.6889713E-05
     +,   1.7006056E-05,   1.7102639E-05,   1.7179114E-05
     +,   1.7235210E-05,   1.7270726E-05,   1.7285531E-05
     +,   1.7279574E-05,   1.7252876E-05,   1.7205535E-05
     +,   1.7137716E-05,   1.7049668E-05,   1.6941705E-05
     +,   1.6814207E-05,   1.6667631E-05,   1.6502490E-05
     +,   1.6319367E-05,   1.6118895E-05,   1.5901767E-05
     +,   1.5668726E-05,   1.5420559E-05,   1.5158100E-05
     +,   1.4882213E-05,   1.4593803E-05,   1.4293797E-05
     +,   1.3983144E-05,   1.3662817E-05,   1.3333803E-05
     +,   1.2997077E-05,   1.2653648E-05,   1.2304497E-05
     +,   1.1950612E-05,   1.1592968E-05,   1.1232522E-05
     +,   1.0870214E-05,   1.0506959E-05,   1.0143645E-05
     +,   9.7811453E-06,   9.4202760E-06,   9.0618178E-06
     +,   8.7065446E-06,   8.3551504E-06,   8.0083228E-06
     +,   7.6666729E-06,   7.3308070E-06,   7.0012393E-06
     +,   6.6784860E-06,   6.3629736E-06,   6.0551288E-06
     +,   5.7552984E-06,   5.4637890E-06,   5.1808843E-06
     +,   4.9068253E-06,   4.6417986E-06,   4.3859527E-06
     +,   4.1394301E-06,   3.9023084E-06,   3.6746696E-06
     +,   3.4565414E-06,   3.2479622E-06,   3.0489284E-06
     +,   2.8594513E-06,   2.6795142E-06,   2.5091279E-06
     +,   2.3482924E-06,   2.1970277E-06,   2.0553875E-06
     +,   1.9234594E-06,   1.8013656E-06,   1.6892834E-06
     +,   1.5874692E-06,   1.4962424E-06,   1.4160278E-06
     +,   1.3473471E-06,   1.2908516E-06,   1.2473239E-06
     +,   1.2177076E-06,   1.2031128E-06,   1.2048422E-06
     +,   1.2244031E-06,   1.2635300E-06,   1.3241951E-06
     +,   1.4086235E-06,   1.5193150E-06,   1.6590539E-06
     +,   1.8308984E-06,   2.0382247E-06,   2.2846800E-06
     +,   2.5742331E-06,   2.9111056E-06,   3.2998275E-06
     +,   3.7451318E-06,   4.2520287E-06,   4.8256534E-06
     +,   5.4713346E-06,   6.1945116E-06,   7.0006126E-06
     +,   7.8950461E-06,   8.8831794E-06,   9.9702384E-06
     +,   1.1161096E-05,   1.2460474E-05,   1.3872520E-05
     +,   1.5401090E-05,   1.7049279E-05,   1.8819761E-05
     +,   2.0714253E-05,   2.2733922E-05,   2.4878795E-05
     +,   2.7148160E-05,   2.9540271E-05,   3.2052147E-05
     +,   3.4679601E-05,   3.7417332E-05,   4.0258736E-05
     +,   4.3195570E-05,   4.6218040E-05,   4.9314935E-05
     +,   5.2473351E-05,   5.5678232E-05,   5.8913003E-05
     +,   6.2159139E-05,   6.5395965E-05,   6.8600864E-05
     +,   7.1749571E-05,   7.4816038E-05,   7.7772449E-05
     +,   8.0589707E-05,   8.3237930E-05,   8.5686683E-05
     +,   8.7905355E-05,   8.9863919E-05,   9.1533810E-05
     +,   9.2888469E-05,   9.3904273E-05,   9.4561852E-05
     +,   9.4847193E-05,   9.4753406E-05,   9.4282907E-05
     +,   9.3450311E-05,   9.2286231E-05,   9.0842434E-05
     +,   8.9198300E-05,   8.7468703E-05,   8.5813605E-05
     +,   8.4448278E-05,   8.3653424E-05,   8.3783409E-05
     +,   8.5271182E-05,   8.8626170E-05,   9.4424337E-05
     +,   1.0328754E-04,   1.1585139E-04,   1.3272424E-04
     +,   1.5444285E-04,   1.8142753E-04,   2.1394558E-04
     +,   2.5209563E-04,   2.9582003E-04,   3.4494055E-04
     +,   3.9921678E-04,   4.5842599E-04,   5.2244315E-04
     +,   5.9129274E-04,   6.6515384E-04,   7.4433064E-04
     +,   8.2914036E-04,   9.1974559E-04,   1.0159594E-03
     +,   1.1170486E-03,   1.2215493E-03,   1.3271540E-03
     +,   1.4307012E-03,   1.5282909E-03,   1.6155069E-03
     +,   1.6877514E-03,   1.7406862E-03,   1.7707007E-03
     +,   1.7753555E-03,   1.7537386E-03,   1.7066679E-03
     +,   1.6366751E-03,   1.5477746E-03,   1.4450196E-03
     +,   1.3339134E-03,   1.2197929E-03,   1.1072868E-03
     +,   9.9991600E-04,   8.9990825E-04,   8.0824923E-04
     +,   7.2491152E-04,   6.4917514E-04,   5.7997892E-04
     +,   5.1623478E-04,   4.5705037E-04,   4.0182576E-04
     +,   3.5027202E-04,   3.0235533E-04,   2.5819943E-04
     +,   2.1798206E-04,   1.8185482E-04,   1.4988822E-04
     +,   1.2204157E-04,   9.8159522E-05,   7.7990037E-05
     +,   6.1210631E-05,   4.7454421E-05,   3.6335987E-05
     +,   2.7474185E-05,   2.0508727E-05,   1.5109037E-05
     +,   1.0981260E-05,   7.8705989E-06,   5.5605115E-06
     +,   3.8705120E-06,   2.6531461E-06,   1.7901965E-06
     +,   1.1885118E-06,   7.7604136E-07,   4.9816515E-07
     +,   3.1428530E-07,   1.9480848E-07,   1.1860349E-07
     +,   7.0905529E-08,   4.1617685E-08,   2.3977545E-08
     +,   1.3557655E-08,   7.5226101E-09,   4.0956132E-09
     +,   2.1877016E-09,   1.1464005E-09,   5.8931704E-10
     +,   2.9717903E-10,   1.4700285E-10,   7.1328006E-11
     +,   3.3949898E-11,   1.5852378E-11,   7.2621037E-12
     +,   3.2644382E-12,   1.4404117E-12,   6.2418197E-13
     +,   2.6585665E-13,   1.1146828E-13,   4.6123570E-14
     +,   1.8914000E-14,   7.7399347E-15,   3.1956505E-15
     +,   1.3526154E-15,   5.9873662E-16,   2.8257281E-16
     +,   1.4375282E-16,   7.8601355E-17,   4.5537011E-17
     +,   2.7446255E-17,   1.6939709E-17,   1.0585973E-17
     +,   6.6512890E-18,   4.1844809E-18,   2.6300574E-18
     +,   1.6494515E-18,   1.0315825E-18,   6.4314885E-19
     +,   3.9965482E-19,   2.4751563E-19,   1.5276810E-19
     +,   9.3968680E-20,   5.7601006E-20,   3.5187885E-20
     +,   2.1421542E-20,   1.2996363E-20,   7.8577206E-21
     +,   4.7346340E-21,   2.8430559E-21,   1.7014188E-21
     +,   1.0147481E-21,   6.0318880E-22
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz102 = Yx/0.0110833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4412152E-05,   1.4604838E-05
     +,   1.4805275E-05,   1.5013492E-05,   1.5229492E-05
     +,   1.5453257E-05,   1.5684740E-05,   1.5923863E-05
     +,   1.6170519E-05,   1.6424587E-05,   1.6685899E-05
     +,   1.6954267E-05,   1.7229471E-05,   1.7511258E-05
     +,   1.7799352E-05,   1.8093437E-05,   1.8393175E-05
     +,   1.8698202E-05,   1.9008108E-05,   1.9322470E-05
     +,   1.9640833E-05,   1.9962712E-05,   2.0287589E-05
     +,   2.0614945E-05,   2.0944206E-05,   2.1274793E-05
     +,   2.1606105E-05,   2.1937514E-05,   2.2268374E-05
     +,   2.2598029E-05,   2.2925800E-05,   2.3250999E-05
     +,   2.3572928E-05,   2.3890872E-05,   2.4204121E-05
     +,   2.4511952E-05,   2.4813640E-05,   2.5108462E-05
     +,   2.5395708E-05,   2.5674643E-05,   2.5944568E-05
     +,   2.6204787E-05,   2.6454600E-05,   2.6693348E-05
     +,   2.6920361E-05,   2.7135007E-05,   2.7336662E-05
     +,   2.7524744E-05,   2.7698676E-05,   2.7857915E-05
     +,   2.8001959E-05,   2.8130327E-05,   2.8242566E-05
     +,   2.8338274E-05,   2.8417071E-05,   2.8478624E-05
     +,   2.8522631E-05,   2.8548844E-05,   2.8557039E-05
     +,   2.8547043E-05,   2.8518734E-05,   2.8472015E-05
     +,   2.8406845E-05,   2.8323233E-05,   2.8221206E-05
     +,   2.8100871E-05,   2.7962340E-05,   2.7805801E-05
     +,   2.7631460E-05,   2.7439592E-05,   2.7230475E-05
     +,   2.7004462E-05,   2.6761920E-05,   2.6503274E-05
     +,   2.6228970E-05,   2.5939486E-05,   2.5635341E-05
     +,   2.5317109E-05,   2.4985347E-05,   2.4640667E-05
     +,   2.4283720E-05,   2.3915145E-05,   2.3535664E-05
     +,   2.3145960E-05,   2.2746792E-05,   2.2338894E-05
     +,   2.1923075E-05,   2.1500106E-05,   2.1070829E-05
     +,   2.0636084E-05,   2.0196714E-05,   1.9753626E-05
     +,   1.9307747E-05,   1.8859999E-05,   1.8411334E-05
     +,   1.7962779E-05,   1.7515340E-05,   1.7070111E-05
     +,   1.6628172E-05,   1.6190712E-05,   1.5758900E-05
     +,   1.5334021E-05,   1.4917363E-05,   1.4510328E-05
     +,   1.4114341E-05,   1.3730896E-05,   1.3361584E-05
     +,   1.3008069E-05,   1.2672061E-05,   1.2355345E-05
     +,   1.2059803E-05,   1.1787345E-05,   1.1539973E-05
     +,   1.1319705E-05,   1.1128626E-05,   1.0968816E-05
     +,   1.0842387E-05,   1.0751407E-05,   1.0697929E-05
     +,   1.0683925E-05,   1.0711278E-05,   1.0781744E-05
     +,   1.0896911E-05,   1.1058176E-05,   1.1266700E-05
     +,   1.1523359E-05,   1.1828729E-05,   1.2183008E-05
     +,   1.2586044E-05,   1.3037207E-05,   1.3535469E-05
     +,   1.4079254E-05,   1.4666541E-05,   1.5294721E-05
     +,   1.5960708E-05,   1.6660872E-05,   1.7391030E-05
     +,   1.8146466E-05,   1.8922041E-05,   1.9712146E-05
     +,   2.0510735E-05,   2.1311387E-05,   2.2107457E-05
     +,   2.2892074E-05,   2.3658171E-05,   2.4398680E-05
     +,   2.5106629E-05,   2.5775122E-05,   2.6397585E-05
     +,   2.6967875E-05,   2.7480424E-05,   2.7930349E-05
     +,   2.8313680E-05,   2.8627665E-05,   2.8870933E-05
     +,   2.9043886E-05,   2.9149109E-05,   2.9191888E-05
     +,   2.9180837E-05,   2.9128694E-05,   2.9053266E-05
     +,   2.8978568E-05,   2.8936200E-05,   2.8966902E-05
     +,   2.9122350E-05,   2.9467219E-05,   3.0081297E-05
     +,   3.1061805E-05,   3.2525837E-05,   3.4612640E-05
     +,   3.7485588E-05,   4.1333889E-05,   4.6374094E-05
     +,   5.2850486E-05,   6.1033621E-05,   7.1219780E-05
     +,   8.3727347E-05,   9.8890661E-05,   1.1705352E-04
     +,   1.3856143E-04,   1.6374988E-04,   1.9292896E-04
     +,   2.2636903E-04,   2.6428612E-04,   3.0682239E-04
     +,   3.5402409E-04,   4.0582454E-04,   4.6203117E-04
     +,   5.2230753E-04,   5.8615609E-04,   6.5292383E-04
     +,   7.2179688E-04,   7.9180341E-04,   8.6183328E-04
     +,   9.3066721E-04,   9.9700317E-04,   1.0594926E-03
     +,   1.1167896E-03,   1.1676039E-03,   1.2107460E-03
     +,   1.2451734E-03,   1.2700409E-03,   1.2847366E-03
     +,   1.2889076E-03,   1.2824766E-03,   1.2656455E-03
     +,   1.2388843E-03,   1.2029115E-03,   1.1586602E-03
     +,   1.1072333E-03,   1.0498569E-03,   9.8783383E-04
     +,   9.2249084E-04,   8.5512525E-04,   7.8696676E-04
     +,   7.1914698E-04,   6.5266865E-04,   5.8838277E-04
     +,   5.2698428E-04,   4.6901629E-04,   4.1486474E-04
     +,   3.6477452E-04,   3.1886820E-04,   2.7715965E-04
     +,   2.3957001E-04,   2.0594957E-04,   1.7609709E-04
     +,   1.4977287E-04,   1.2671147E-04,   1.0663543E-04
     +,   8.9265915E-05,   7.4328360E-05,   6.1557352E-05
     +,   5.0701990E-05,   4.1529205E-05,   3.3823220E-05
     +,   2.7387468E-05,   2.2044926E-05,   1.7637045E-05
     +,   1.4022804E-05,   1.1078075E-05,   8.6945674E-06
     +,   6.7782707E-06,   5.2481105E-06,   4.0348350E-06
     +,   3.0797901E-06,   2.3335851E-06,   1.7549411E-06
     +,   1.3096877E-06,   9.6980364E-07,   7.1243556E-07
     +,   5.1914526E-07,   3.7519985E-07,   2.6891666E-07
     +,   1.9111681E-07,   1.3466475E-07,   9.4068184E-08
     +,   6.5137300E-08,   4.4706564E-08,   3.0410739E-08
     +,   2.0500776E-08,   1.3695570E-08,   9.0662056E-09
     +,   5.9467880E-09,   3.8649928E-09,   2.4889182E-09
     +,   1.5880469E-09,   1.0039835E-09,   6.2897743E-10
     +,   3.9051221E-10,   2.4032770E-10,   1.4665001E-10
     +,   8.8773357E-11,   5.3347052E-11,   3.1858585E-11
     +,   1.8938569E-11,   1.1232858E-11,   6.6706181E-12
     +,   3.9852401E-12,   2.4108836E-12,   1.4886606E-12
     +,   9.4663242E-13,   6.2501431E-13,   4.3084920E-13
     +,   3.1043901E-13,   2.3299982E-13,   1.8094669E-13
     +,   1.4425155E-13,   1.1717614E-13,   9.6396056E-14
     +,   7.9950058E-14,   6.6640520E-14,   5.5706162E-14
     +,   4.6635212E-14,   3.9065796E-14,   3.2727503E-14
     +,   2.7410901E-14,   2.2947634E-14,   1.9200338E-14
     +,   1.6054674E-14,   1.3415378E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz104 = Yx/0.009625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3727920E-05,   1.3918328E-05
     +,   1.4116300E-05,   1.4322376E-05,   1.4537099E-05
     +,   1.4761017E-05,   1.4994685E-05,   1.5238662E-05
     +,   1.5493499E-05,   1.5759766E-05,   1.6038002E-05
     +,   1.6328757E-05,   1.6632563E-05,   1.6949945E-05
     +,   1.7281416E-05,   1.7627459E-05,   1.7988550E-05
     +,   1.8365139E-05,   1.8757639E-05,   1.9166451E-05
     +,   1.9591929E-05,   2.0034400E-05,   2.0494148E-05
     +,   2.0971434E-05,   2.1466434E-05,   2.1979329E-05
     +,   2.2510210E-05,   2.3059134E-05,   2.3626108E-05
     +,   2.4211065E-05,   2.4813895E-05,   2.5434423E-05
     +,   2.6072410E-05,   2.6727548E-05,   2.7399474E-05
     +,   2.8087752E-05,   2.8791881E-05,   2.9511280E-05
     +,   3.0245346E-05,   3.0993320E-05,   3.1754476E-05
     +,   3.2527954E-05,   3.3312845E-05,   3.4108183E-05
     +,   3.4912926E-05,   3.5725981E-05,   3.6546193E-05
     +,   3.7372345E-05,   3.8203172E-05,   3.9037357E-05
     +,   3.9873532E-05,   4.0710289E-05,   4.1546158E-05
     +,   4.2379699E-05,   4.3209344E-05,   4.4033583E-05
     +,   4.4850833E-05,   4.5659519E-05,   4.6458037E-05
     +,   4.7244779E-05,   4.8018148E-05,   4.8776550E-05
     +,   4.9518352E-05,   5.0242001E-05,   5.0945968E-05
     +,   5.1628656E-05,   5.2288611E-05,   5.2924323E-05
     +,   5.3534401E-05,   5.4117416E-05,   5.4672080E-05
     +,   5.5197073E-05,   5.5691202E-05,   5.6153291E-05
     +,   5.6582248E-05,   5.6977075E-05,   5.7336809E-05
     +,   5.7660571E-05,   5.7947582E-05,   5.8197140E-05
     +,   5.8408608E-05,   5.8581467E-05,   5.8715243E-05
     +,   5.8809601E-05,   5.8864251E-05,   5.8879017E-05
     +,   5.8853813E-05,   5.8788632E-05,   5.8683563E-05
     +,   5.8538786E-05,   5.8354562E-05,   5.8131231E-05
     +,   5.7869249E-05,   5.7569119E-05,   5.7231431E-05
     +,   5.6856868E-05,   5.6446166E-05,   5.6000164E-05
     +,   5.5519711E-05,   5.5005803E-05,   5.4459411E-05
     +,   5.3881646E-05,   5.3273583E-05,   5.2636446E-05
     +,   5.1971427E-05,   5.1279763E-05,   5.0562772E-05
     +,   4.9821814E-05,   4.9058221E-05,   4.8273338E-05
     +,   4.7468635E-05,   4.6645477E-05,   4.5805336E-05
     +,   4.4949607E-05,   4.4079781E-05,   4.3197244E-05
     +,   4.2303494E-05,   4.1399893E-05,   4.0487928E-05
     +,   3.9568964E-05,   3.8644364E-05,   3.7715505E-05
     +,   3.6783771E-05,   3.5850426E-05,   3.4916735E-05
     +,   3.3983993E-05,   3.3053366E-05,   3.2126070E-05
     +,   3.1203195E-05,   3.0285895E-05,   2.9375160E-05
     +,   2.8472054E-05,   2.7577496E-05,   2.6692447E-05
     +,   2.5817764E-05,   2.4954246E-05,   2.4102690E-05
     +,   2.3263872E-05,   2.2438451E-05,   2.1627053E-05
     +,   2.0830317E-05,   2.0048856E-05,   1.9283189E-05
     +,   1.8533829E-05,   1.7801349E-05,   1.7086270E-05
     +,   1.6389120E-05,   1.5710546E-05,   1.5051266E-05
     +,   1.4412086E-05,   1.3793987E-05,   1.3198228E-05
     +,   1.2626381E-05,   1.2080389E-05,   1.1562718E-05
     +,   1.1076522E-05,   1.0625769E-05,   1.0215397E-05
     +,   9.8515538E-06,   9.5419136E-06,   9.2958689E-06
     +,   9.1249303E-06,   9.0431158E-06,   9.0673693E-06
     +,   9.2180862E-06,   9.5197192E-06,   1.0001413E-05
     +,   1.0697749E-05,   1.1649678E-05,   1.2905472E-05
     +,   1.4521695E-05,   1.6564387E-05,   1.9110468E-05
     +,   2.2248980E-05,   2.6081983E-05,   3.0726329E-05
     +,   3.6314505E-05,   4.2994870E-05,   5.0932020E-05
     +,   6.0307004E-05,   7.1315641E-05,   8.4165411E-05
     +,   9.9072218E-05,   1.1625647E-04,   1.3593603E-04
     +,   1.5831635E-04,   1.8358199E-04,   2.1188721E-04
     +,   2.4334287E-04,   2.7800020E-04,   3.1584426E-04
     +,   3.5677929E-04,   4.0061478E-04,   4.4705966E-04
     +,   4.9572019E-04,   5.4609583E-04,   5.9757882E-04
     +,   6.4946531E-04,   7.0097181E-04,   7.5124961E-04
     +,   7.9940486E-04,   8.4452768E-04,   8.8572397E-04
     +,   9.2214282E-04,   9.5300330E-04,   9.7763096E-04
     +,   9.9547848E-04,   1.0061458E-03,   1.0093981E-03
     +,   1.0051751E-03,   9.9358871E-04,   9.7492209E-04
     +,   9.4961625E-04,   9.1825007E-04,   8.8151789E-04
     +,   8.4020622E-04,   7.9516292E-04,   7.4726442E-04
     +,   6.9738965E-04,   6.4639852E-04,   5.9509877E-04
     +,   5.4423115E-04,   4.9445772E-04,   4.4634839E-04
     +,   4.0037133E-04,   3.5689556E-04,   3.1619592E-04
     +,   2.7845483E-04,   2.4376874E-04,   2.1216032E-04
     +,   1.8359115E-04,   1.5797032E-04,   1.3516407E-04
     +,   1.1500821E-04,   9.7319440E-05,   8.1899525E-05
     +,   6.8544949E-05,   5.7053381E-05,   4.7227248E-05
     +,   3.8876835E-05,   3.1823794E-05,   2.5903058E-05
     +,   2.0963289E-05,   1.6866990E-05,   1.3490944E-05
     +,   1.0725898E-05,   8.4755839E-06,   6.6558018E-06
     +,   5.1936754E-06,   4.0267259E-06,   3.1015663E-06
     +,   2.3730765E-06,   1.8034428E-06,   1.3611746E-06
     +,   1.0202363E-06,   7.5931274E-07,   5.6110133E-07
     +,   4.1165620E-07,   2.9982488E-07,   2.1677553E-07
     +,   1.5557751E-07,   1.1083247E-07,   7.8371393E-08
     +,   5.5006304E-08,   3.8322202E-08,   2.6502509E-08
     +,   1.8195051E-08,   1.2402566E-08,   8.3955971E-09
     +,   5.6453193E-09,   3.7721177E-09,   2.5060007E-09
     +,   1.6565463E-09,   1.0906405E-09,   7.1613487E-10
     +,   4.6981458E-10,   3.0865044E-10,   2.0365135E-10
     +,   1.3542534E-10,   9.1129285E-11,   6.2314827E-11
     +,   4.3475949E-11,   3.1045586E-11,   2.2731619E-11
     +,   1.7067334E-11,   1.3119833E-11,   1.0296285E-11
     +,   8.2204131E-12,   6.6526893E-12,   5.4391756E-12
     +,   4.4799433E-12,   3.7087030E-12,   3.0805534E-12
     +,   2.5640423E-12,   2.1365373E-12,   1.7811130E-12
     +,   1.4848176E-12,   1.2374093E-12,   1.0306772E-12
     +,   8.5789806E-13,   7.1353568E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz106 = Yx/0.00852173913043478
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.8862767E-06,   5.2797686E-06
     +,   5.6973086E-06,   6.1396404E-06,   6.6074672E-06
     +,   7.1014374E-06,   7.6221440E-06,   8.1701128E-06
     +,   8.7457893E-06,   9.3495673E-06,   9.9817244E-06
     +,   1.0642452E-05,   1.1331846E-05,   1.2049884E-05
     +,   1.2796437E-05,   1.3571252E-05,   1.4373950E-05
     +,   1.5204020E-05,   1.6060818E-05,   1.6943561E-05
     +,   1.7851316E-05,   1.8783017E-05,   1.9737430E-05
     +,   2.0713242E-05,   2.1708878E-05,   2.2722734E-05
     +,   2.3753009E-05,   2.4797775E-05,   2.5854968E-05
     +,   2.6922411E-05,   2.7997792E-05,   2.9078710E-05
     +,   3.0162644E-05,   3.1246993E-05,   3.2329073E-05
     +,   3.3406130E-05,   3.4475364E-05,   3.5533907E-05
     +,   3.6578938E-05,   3.7607508E-05,   3.8616778E-05
     +,   3.9603863E-05,   4.0565938E-05,   4.1500214E-05
     +,   4.2403979E-05,   4.3274587E-05,   4.4109496E-05
     +,   4.4906268E-05,   4.5662589E-05,   4.6376281E-05
     +,   4.7045312E-05,   4.7667807E-05,   4.8242062E-05
     +,   4.8766571E-05,   4.9239963E-05,   4.9661106E-05
     +,   5.0029052E-05,   5.0343053E-05,   5.0602568E-05
     +,   5.0807244E-05,   5.0956958E-05,   5.1051782E-05
     +,   5.1091978E-05,   5.1078008E-05,   5.1010535E-05
     +,   5.0890390E-05,   5.0718591E-05,   5.0496310E-05
     +,   5.0224877E-05,   4.9905797E-05,   4.9540649E-05
     +,   4.9131206E-05,   4.8679278E-05,   4.8186841E-05
     +,   4.7655907E-05,   4.7088561E-05,   4.6486955E-05
     +,   4.5853314E-05,   4.5189852E-05,   4.4498785E-05
     +,   4.3782409E-05,   4.3042932E-05,   4.2282620E-05
     +,   4.1503637E-05,   4.0708182E-05,   3.9898343E-05
     +,   3.9076222E-05,   3.8243768E-05,   3.7402988E-05
     +,   3.6555692E-05,   3.5703659E-05,   3.4848614E-05
     +,   3.3992193E-05,   3.3135901E-05,   3.2281161E-05
     +,   3.1429372E-05,   3.0581741E-05,   2.9739502E-05
     +,   2.8903680E-05,   2.8075337E-05,   2.7255335E-05
     +,   2.6444568E-05,   2.5643732E-05,   2.4853573E-05
     +,   2.4074674E-05,   2.3307561E-05,   2.2552735E-05
     +,   2.1810654E-05,   2.1081660E-05,   2.0366044E-05
     +,   1.9664123E-05,   1.8976079E-05,   1.8302142E-05
     +,   1.7642416E-05,   1.6997064E-05,   1.6366126E-05
     +,   1.5749703E-05,   1.5147791E-05,   1.4560436E-05
     +,   1.3987615E-05,   1.3429281E-05,   1.2885413E-05
     +,   1.2355970E-05,   1.1840864E-05,   1.1339999E-05
     +,   1.0853314E-05,   1.0380674E-05,   9.9219969E-06
     +,   9.4771349E-06,   9.0459844E-06,   8.6283790E-06
     +,   8.2242050E-06,   7.8332778E-06,   7.4554669E-06
     +,   7.0905899E-06,   6.7384622E-06,   6.3989146E-06
     +,   6.0717725E-06,   5.7568313E-06,   5.4538887E-06
     +,   5.1627562E-06,   4.8832485E-06,   4.6151627E-06
     +,   4.3583091E-06,   4.1125404E-06,   3.8777112E-06
     +,   3.6537210E-06,   3.4405452E-06,   3.2382466E-06
     +,   3.0469978E-06,   2.8671398E-06,   2.6992518E-06
     +,   2.5442127E-06,   2.4032834E-06,   2.2782315E-06
     +,   2.1714793E-06,   2.0862533E-06,   2.0267730E-06
     +,   1.9984784E-06,   2.0082721E-06,   2.0647785E-06
     +,   2.1786325E-06,   2.3627524E-06,   2.6326056E-06
     +,   3.0064878E-06,   3.5057180E-06,   4.1547473E-06
     +,   4.9812165E-06,   6.0159737E-06,   7.2929024E-06
     +,   8.8485340E-06,   1.0721706E-05,   1.2953210E-05
     +,   1.5585241E-05,   1.8660545E-05,   2.2222564E-05
     +,   2.6314980E-05,   3.0981551E-05,   3.6266669E-05
     +,   4.2216838E-05,   4.8881848E-05,   5.6316603E-05
     +,   6.4583961E-05,   7.3758602E-05,   8.3930106E-05
     +,   9.5205723E-05,   1.0771401E-04,   1.2160825E-04
     +,   1.3706725E-04,   1.5429338E-04,   1.7351350E-04
     +,   1.9497299E-04,   2.1892721E-04,   2.4563237E-04
     +,   2.7533530E-04,   3.0825671E-04,   3.4457204E-04
     +,   3.8439393E-04,   4.2775611E-04,   4.7459136E-04
     +,   5.2471028E-04,   5.7778717E-04,   6.3335209E-04
     +,   6.9077912E-04,   7.4927940E-04,   8.0791785E-04
     +,   8.6562178E-04,   9.2120032E-04,   9.7338040E-04
     +,   1.0208511E-03,   1.0623079E-03,   1.0965050E-03
     +,   1.1223155E-03,   1.1387886E-03,   1.1452008E-03
     +,   1.1410974E-03,   1.1263303E-03,   1.1010732E-03
     +,   1.0658223E-03,   1.0213855E-03,   9.6884306E-04
     +,   9.0950151E-04,   8.4483926E-04,   7.7643618E-04
     +,   7.0589624E-04,   6.3478469E-04,   5.6456809E-04
     +,   4.9655710E-04,   4.3186132E-04,   3.7136726E-04
     +,   3.1573043E-04,   2.6537254E-04,   2.2049238E-04
     +,   1.8109324E-04,   1.4701646E-04,   1.1796755E-04
     +,   9.3555856E-05,   7.3329502E-05,   5.6803514E-05
     +,   4.3485499E-05,   3.2898111E-05,   2.4595080E-05
     +,   1.8170687E-05,   1.3265635E-05,   9.5698761E-06
     +,   6.8218733E-06,   4.8052852E-06,   3.3445881E-06
     +,   2.3001915E-06,   1.5631086E-06,   1.0495644E-06
     +,   6.9632807E-07,   4.5646388E-07,   2.9565820E-07
     +,   1.8921509E-07,   1.1964536E-07,   7.4750680E-08
     +,   4.6144496E-08,   2.8145200E-08,   1.6961474E-08
     +,   1.0099731E-08,   5.9423666E-09,   3.4547816E-09
     +,   1.9847699E-09,   1.1268972E-09,   6.3241240E-10
     +,   3.5087713E-10,   1.9254240E-10,   1.0456803E-10
     +,   5.6261534E-11,   3.0038787E-11,   1.5958606E-11
     +,   8.4728197E-12,   4.5254785E-12,   2.4555269E-12
     +,   1.3714787E-12,   8.0053959E-13,   4.9506915E-13
     +,   3.2667337E-13,   2.2944594E-13,   1.6975505E-13
     +,   1.3049006E-13,   1.0289438E-13,   8.2417614E-14
     +,   6.6613341E-14,   5.4099737E-14,   4.4037263E-14
     +,   3.5875318E-14,   2.9225686E-14,   2.3796852E-14
     +,   1.9362187E-14,   1.5740019E-14,   1.2783318E-14
     +,   1.0371697E-14,   8.4065530E-15,   6.8067263E-15
     +,   5.5057552E-15,   4.4488152E-15,   3.5910927E-15
     +,   2.8957227E-15,   2.3326082E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz108 = Yx/0.00827272727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3874456E-05,   1.3935949E-05
     +,   1.3997895E-05,   1.4060462E-05,   1.4123819E-05
     +,   1.4188124E-05,   1.4253544E-05,   1.4320239E-05
     +,   1.4388369E-05,   1.4458094E-05,   1.4529567E-05
     +,   1.4602939E-05,   1.4678354E-05,   1.4755957E-05
     +,   1.4835879E-05,   1.4918254E-05,   1.5003205E-05
     +,   1.5090848E-05,   1.5181292E-05,   1.5274645E-05
     +,   1.5370992E-05,   1.5470421E-05,   1.5573012E-05
     +,   1.5678832E-05,   1.5787931E-05,   1.5900363E-05
     +,   1.6016160E-05,   1.6135349E-05,   1.6257947E-05
     +,   1.6383958E-05,   1.6513372E-05,   1.6646167E-05
     +,   1.6782320E-05,   1.6921786E-05,   1.7064509E-05
     +,   1.7210421E-05,   1.7359453E-05,   1.7511506E-05
     +,   1.7666487E-05,   1.7824274E-05,   1.7984754E-05
     +,   1.8147786E-05,   1.8313223E-05,   1.8480911E-05
     +,   1.8650679E-05,   1.8822348E-05,   1.8995732E-05
     +,   1.9170633E-05,   1.9346844E-05,   1.9524150E-05
     +,   1.9702324E-05,   1.9881134E-05,   2.0060339E-05
     +,   2.0239697E-05,   2.0418942E-05,   2.0597830E-05
     +,   2.0776086E-05,   2.0953443E-05,   2.1129623E-05
     +,   2.1304351E-05,   2.1477341E-05,   2.1648319E-05
     +,   2.1816979E-05,   2.1983045E-05,   2.2146236E-05
     +,   2.2306249E-05,   2.2462804E-05,   2.2615606E-05
     +,   2.2764381E-05,   2.2908833E-05,   2.3048688E-05
     +,   2.3183668E-05,   2.3313498E-05,   2.3437908E-05
     +,   2.3556635E-05,   2.3669430E-05,   2.3776036E-05
     +,   2.3876204E-05,   2.3969700E-05,   2.4056299E-05
     +,   2.4135772E-05,   2.4207917E-05,   2.4272525E-05
     +,   2.4329409E-05,   2.4378378E-05,   2.4419265E-05
     +,   2.4451911E-05,   2.4476165E-05,   2.4491887E-05
     +,   2.4498953E-05,   2.4497247E-05,   2.4486671E-05
     +,   2.4467130E-05,   2.4438556E-05,   2.4400881E-05
     +,   2.4354054E-05,   2.4298042E-05,   2.4232822E-05
     +,   2.4158380E-05,   2.4074732E-05,   2.3981876E-05
     +,   2.3879862E-05,   2.3768722E-05,   2.3648525E-05
     +,   2.3519329E-05,   2.3381226E-05,   2.3234314E-05
     +,   2.3078703E-05,   2.2914513E-05,   2.2741877E-05
     +,   2.2560953E-05,   2.2371882E-05,   2.2174852E-05
     +,   2.1970032E-05,   2.1757631E-05,   2.1537828E-05
     +,   2.1310858E-05,   2.1076923E-05,   2.0836276E-05
     +,   2.0589148E-05,   2.0335776E-05,   2.0076428E-05
     +,   1.9811374E-05,   1.9540874E-05,   1.9265197E-05
     +,   1.8984641E-05,   1.8699475E-05,   1.8410010E-05
     +,   1.8116521E-05,   1.7819324E-05,   1.7518703E-05
     +,   1.7214976E-05,   1.6908429E-05,   1.6599388E-05
     +,   1.6288150E-05,   1.5975007E-05,   1.5660275E-05
     +,   1.5344263E-05,   1.5027270E-05,   1.4709575E-05
     +,   1.4391493E-05,   1.4073318E-05,   1.3755330E-05
     +,   1.3437804E-05,   1.3121035E-05,   1.2805287E-05
     +,   1.2490820E-05,   1.2177901E-05,   1.1866800E-05
     +,   1.1557760E-05,   1.1251013E-05,   1.0946815E-05
     +,   1.0645417E-05,   1.0347049E-05,   1.0051956E-05
     +,   9.7604034E-06,   9.4726838E-06,   9.1891052E-06
     +,   8.9100286E-06,   8.6359096E-06,   8.3672903E-06
     +,   8.1048647E-06,   7.8495441E-06,   7.6025226E-06
     +,   7.3653487E-06,   7.1400686E-06,   6.9293910E-06
     +,   6.7368519E-06,   6.5670597E-06,   6.4259821E-06
     +,   6.3213283E-06,   6.2629533E-06,   6.2633926E-06
     +,   6.3384787E-06,   6.5080881E-06,   6.7970109E-06
     +,   7.2359903E-06,   7.8628555E-06,   8.7238741E-06
     +,   9.8753453E-06,   1.1385297E-05,   1.3335227E-05
     +,   1.5822085E-05,   1.8960540E-05,   2.2884920E-05
     +,   2.7750817E-05,   3.3736756E-05,   4.1045718E-05
     +,   4.9905277E-05,   6.0565930E-05,   7.3300675E-05
     +,   8.8400899E-05,   1.0616954E-04,   1.2691390E-04
     +,   1.5093718E-04,   1.7852504E-04,   2.0992862E-04
     +,   2.4534931E-04,   2.8492251E-04,   3.2869747E-04
     +,   3.7661477E-04,   4.2849127E-04,   4.8400857E-04
     +,   5.4269942E-04,   6.0393562E-04,   6.6694029E-04
     +,   7.3078991E-04,   7.9442665E-04,   8.5668592E-04
     +,   9.1633177E-04,   9.7209227E-04,   1.0226980E-03
     +,   1.0669343E-03,   1.1036904E-03,   1.1320034E-03
     +,   1.1510962E-03,   1.1604179E-03,   1.1596680E-03
     +,   1.1488104E-03,   1.1280786E-03,   1.0979658E-03
     +,   1.0592036E-03,   1.0127361E-03,   9.5967931E-04
     +,   9.0126978E-04,   8.3882042E-04,   7.7367382E-04
     +,   7.0715131E-04,   6.4050278E-04,   5.7487446E-04
     +,   5.1128236E-04,   4.5058643E-04,   3.9347372E-04
     +,   3.4045862E-04,   2.9189160E-04,   2.4795876E-04
     +,   2.0870351E-04,   1.7404821E-04,   1.4381284E-04
     +,   1.1773551E-04,   9.5497686E-05,   7.6745760E-05
     +,   6.1107428E-05,   4.8206850E-05,   3.7678743E-05
     +,   2.9178540E-05,   2.2388240E-05,   1.7020448E-05
     +,   1.2821126E-05,   9.5700170E-06,   7.0787100E-06
     +,   5.1890038E-06,   3.7701586E-06,   2.7155645E-06
     +,   1.9394715E-06,   1.3739407E-06,   9.6586780E-07
     +,   6.7424133E-07,   4.6777950E-07,   3.2294116E-07
     +,   2.2222802E-07,   1.5277872E-07,   1.0524991E-07
     +,   7.2937311E-08,   5.1086626E-08,   3.6359680E-08
     +,   2.6440995E-08,   1.9742046E-08,   1.5183897E-08
     +,   1.2041158E-08,   9.8312398E-09,   8.2361051E-09
     +,   7.0477970E-09,   6.1312795E-09,   5.3994187E-09
     +,   4.7961879E-09,   4.2854285E-09,   3.8437600E-09
     +,   3.4557890E-09,   3.1112166E-09,   2.8028828E-09
     +,   2.5256666E-09,   2.2756725E-09,   2.0498609E-09
     +,   1.8457073E-09,   1.6610912E-09,   1.4941477E-09
     +,   1.3432212E-09,   1.2068428E-09,   1.0836643E-09
     +,   9.7247832E-10,   8.7217017E-10,   7.8173673E-10
     +,   7.0025175E-10,   6.2688066E-10,   5.6085264E-10
     +,   5.0147547E-10,   4.4810908E-10,   4.0017908E-10
     +,   3.5715608E-10,   3.1856490E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz110 = Yx/0.00827272727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz111(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3136146E-05,   1.3212079E-05
     +,   1.3283148E-05,   1.3349413E-05,   1.3410948E-05
     +,   1.3467833E-05,   1.3520173E-05,   1.3568077E-05
     +,   1.3611670E-05,   1.3651090E-05,   1.3686487E-05
     +,   1.3718021E-05,   1.3745867E-05,   1.3770203E-05
     +,   1.3791223E-05,   1.3809130E-05,   1.3824133E-05
     +,   1.3836448E-05,   1.3846306E-05,   1.3853932E-05
     +,   1.3859566E-05,   1.3863450E-05,   1.3865828E-05
     +,   1.3866949E-05,   1.3867068E-05,   1.3866436E-05
     +,   1.3865304E-05,   1.3863927E-05,   1.3862559E-05
     +,   1.3861445E-05,   1.3860837E-05,   1.3860979E-05
     +,   1.3862107E-05,   1.3864460E-05,   1.3868266E-05
     +,   1.3873746E-05,   1.3881116E-05,   1.3890587E-05
     +,   1.3902356E-05,   1.3916616E-05,   1.3933548E-05
     +,   1.3953324E-05,   1.3976109E-05,   1.4002051E-05
     +,   1.4031295E-05,   1.4063968E-05,   1.4100191E-05
     +,   1.4140072E-05,   1.4183710E-05,   1.4231187E-05
     +,   1.4282577E-05,   1.4337944E-05,   1.4397338E-05
     +,   1.4460800E-05,   1.4528358E-05,   1.4600032E-05
     +,   1.4675828E-05,   1.4755739E-05,   1.4839760E-05
     +,   1.4927864E-05,   1.5020019E-05,   1.5116184E-05
     +,   1.5216303E-05,   1.5320322E-05,   1.5428175E-05
     +,   1.5539783E-05,   1.5655065E-05,   1.5773925E-05
     +,   1.5896279E-05,   1.6022006E-05,   1.6151011E-05
     +,   1.6283164E-05,   1.6418351E-05,   1.6556436E-05
     +,   1.6697290E-05,   1.6840777E-05,   1.6986744E-05
     +,   1.7135037E-05,   1.7285503E-05,   1.7437989E-05
     +,   1.7592314E-05,   1.7748318E-05,   1.7905812E-05
     +,   1.8064620E-05,   1.8224546E-05,   1.8385401E-05
     +,   1.8546976E-05,   1.8709070E-05,   1.8871462E-05
     +,   1.9033936E-05,   1.9196268E-05,   1.9358218E-05
     +,   1.9519541E-05,   1.9679996E-05,   1.9839326E-05
     +,   1.9997267E-05,   2.0153553E-05,   2.0307896E-05
     +,   2.0460026E-05,   2.0609636E-05,   2.0756441E-05
     +,   2.0900128E-05,   2.1040394E-05,   2.1176913E-05
     +,   2.1309368E-05,   2.1437434E-05,   2.1560780E-05
     +,   2.1679069E-05,   2.1791968E-05,   2.1899148E-05
     +,   2.2000260E-05,   2.2094990E-05,   2.2182992E-05
     +,   2.2263956E-05,   2.2337568E-05,   2.2403530E-05
     +,   2.2461549E-05,   2.2511373E-05,   2.2552760E-05
     +,   2.2585496E-05,   2.2609420E-05,   2.2624406E-05
     +,   2.2630382E-05,   2.2627346E-05,   2.2615366E-05
     +,   2.2594604E-05,   2.2565329E-05,   2.2527929E-05
     +,   2.2482929E-05,   2.2431028E-05,   2.2373086E-05
     +,   2.2310191E-05,   2.2243643E-05,   2.2175005E-05
     +,   2.2106118E-05,   2.2039116E-05,   2.1976466E-05
     +,   2.1920976E-05,   2.1875814E-05,   2.1844513E-05
     +,   2.1830994E-05,   2.1839545E-05,   2.1874826E-05
     +,   2.1941862E-05,   2.2045993E-05,   2.2192873E-05
     +,   2.2388418E-05,   2.2638755E-05,   2.2950169E-05
     +,   2.3329068E-05,   2.3781922E-05,   2.4315161E-05
     +,   2.4935136E-05,   2.5648091E-05,   2.6460108E-05
     +,   2.7376946E-05,   2.8404042E-05,   2.9546503E-05
     +,   3.0808991E-05,   3.2195472E-05,   3.3709348E-05
     +,   3.5353220E-05,   3.7128561E-05,   3.9035604E-05
     +,   4.1073217E-05,   4.3238491E-05,   4.5526300E-05
     +,   4.7929057E-05,   5.0436647E-05,   5.3035979E-05
     +,   5.5710683E-05,   5.8441361E-05,   6.1205894E-05
     +,   6.3979955E-05,   6.6737601E-05,   6.9453206E-05
     +,   7.2103074E-05,   7.4667725E-05,   7.7135133E-05
     +,   7.9504345E-05,   8.1789476E-05,   8.4023748E-05
     +,   8.6264234E-05,   8.8596229E-05,   9.1136906E-05
     +,   9.4038245E-05,   9.7488912E-05,   1.0171490E-04
     +,   1.0697820E-04,   1.1357338E-04,   1.2182398E-04
     +,   1.3207691E-04,   1.4469532E-04,   1.6005256E-04
     +,   1.7852742E-04,   2.0049857E-04,   2.2633852E-04
     +,   2.5641039E-04,   2.9106528E-04,   3.3063377E-04
     +,   3.7541159E-04,   4.2564291E-04,   4.8149796E-04
     +,   5.4303510E-04,   6.1015057E-04,   6.8254006E-04
     +,   7.5964077E-04,   8.4057817E-04,   9.2413404E-04
     +,   1.0087339E-03,   1.0924536E-03,   1.1730531E-03
     +,   1.2480632E-03,   1.3148976E-03,   1.3709894E-03
     +,   1.4139432E-03,   1.4417046E-03,   1.4527116E-03
     +,   1.4460182E-03,   1.4213843E-03,   1.3793124E-03
     +,   1.3210312E-03,   1.2484303E-03,   1.1639427E-03
     +,   1.0703856E-03,   9.7078801E-04,   8.6822000E-04
     +,   7.6561444E-04,   6.6561409E-04,   5.7046406E-04
     +,   4.8194572E-04,   4.0133554E-04,   3.2940533E-04
     +,   2.6646740E-04,   2.1244012E-04,   1.6691322E-04
     +,   1.2923841E-04,   9.8613113E-05,   7.4151561E-05
     +,   5.4947242E-05,   4.0124993E-05,   2.8876804E-05
     +,   2.0482541E-05,   1.4320704E-05,   9.8710470E-06
     +,   6.7097271E-06,   4.4996332E-06,   2.9788614E-06
     +,   1.9486583E-06,   1.2614614E-06,   8.0984364E-07
     +,   5.1725647E-07,   3.3022786E-07,   2.1210188E-07
     +,   1.3822172E-07,   9.2316220E-08,   6.3842165E-08
     +,   4.6085333E-08,   3.4843392E-08,   2.7530902E-08
     +,   2.2582327E-08,   1.9062936E-08,   1.6421442E-08
     +,   1.4335762E-08,   1.2618544E-08,   1.1160036E-08
     +,   9.8948805E-09,   8.7828571E-09,   7.7978441E-09
     +,   6.9216082E-09,   6.1405157E-09,   5.4437468E-09
     +,   4.8222275E-09,   4.2680597E-09,   3.7742716E-09
     +,   3.3346648E-09,   2.9436151E-09,   2.5961013E-09
     +,   2.2875395E-09,   2.0138493E-09,   1.7712973E-09
     +,   1.5565617E-09,   1.3666184E-09,   1.1987773E-09
     +,   1.0505985E-09,   9.1990821E-10,   8.0475088E-10
     +,   7.0337125E-10,   6.1421146E-10,   5.3586918E-10
     +,   4.6710014E-10,   4.0678724E-10,   3.5394535E-10
     +,   3.0768862E-10,   2.6723784E-10,   2.3189500E-10
     +,   2.0104642E-10,   1.7414392E-10,   1.5070623E-10
     +,   1.3030520E-10,   1.1256520E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz111 = Yx/0.00933333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5393741E-05,   2.5638143E-05
     +,   2.5876943E-05,   2.6110465E-05,   2.6339072E-05
     +,   2.6563182E-05,   2.6783278E-05,   2.6999882E-05
     +,   2.7213579E-05,   2.7425005E-05,   2.7634858E-05
     +,   2.7843875E-05,   2.8052855E-05,   2.8262639E-05
     +,   2.8474115E-05,   2.8688228E-05,   2.8905952E-05
     +,   2.9128309E-05,   2.9356353E-05,   2.9591176E-05
     +,   2.9833889E-05,   3.0085630E-05,   3.0347544E-05
     +,   3.0620817E-05,   3.0906594E-05,   3.1206069E-05
     +,   3.1520402E-05,   3.1850734E-05,   3.2198201E-05
     +,   3.2563905E-05,   3.2948901E-05,   3.3354205E-05
     +,   3.3780791E-05,   3.4229550E-05,   3.4701330E-05
     +,   3.5196881E-05,   3.5716876E-05,   3.6261881E-05
     +,   3.6832407E-05,   3.7428774E-05,   3.8051283E-05
     +,   3.8700036E-05,   3.9375045E-05,   4.0076175E-05
     +,   4.0803148E-05,   4.1555555E-05,   4.2332824E-05
     +,   4.3134238E-05,   4.3958931E-05,   4.4805864E-05
     +,   4.5673871E-05,   4.6561596E-05,   4.7467533E-05
     +,   4.8390084E-05,   4.9327387E-05,   5.0277547E-05
     +,   5.1238465E-05,   5.2207917E-05,   5.3183576E-05
     +,   5.4162952E-05,   5.5143486E-05,   5.6122524E-05
     +,   5.7097241E-05,   5.8064823E-05,   5.9022404E-05
     +,   5.9966958E-05,   6.0895545E-05,   6.1805069E-05
     +,   6.2692554E-05,   6.3554915E-05,   6.4389198E-05
     +,   6.5192355E-05,   6.5961518E-05,   6.6693778E-05
     +,   6.7386361E-05,   6.8036628E-05,   6.8641952E-05
     +,   6.9199894E-05,   6.9708127E-05,   7.0164540E-05
     +,   7.0567112E-05,   7.0914037E-05,   7.1203685E-05
     +,   7.1434653E-05,   7.1605704E-05,   7.1715862E-05
     +,   7.1764342E-05,   7.1750619E-05,   7.1674389E-05
     +,   7.1535600E-05,   7.1334427E-05,   7.1071314E-05
     +,   7.0746966E-05,   7.0362286E-05,   6.9918460E-05
     +,   6.9416907E-05,   6.8859263E-05,   6.8247464E-05
     +,   6.7583584E-05,   6.6870001E-05,   6.6109220E-05
     +,   6.5304012E-05,   6.4457286E-05,   6.3572195E-05
     +,   6.2651983E-05,   6.1700033E-05,   6.0719929E-05
     +,   5.9715367E-05,   5.8690068E-05,   5.7647834E-05
     +,   5.6592642E-05,   5.5528333E-05,   5.4458931E-05
     +,   5.3388303E-05,   5.2320425E-05,   5.1259096E-05
     +,   5.0208138E-05,   4.9171180E-05,   4.8151840E-05
     +,   4.7153499E-05,   4.6179350E-05,   4.5232471E-05
     +,   4.4315741E-05,   4.3431708E-05,   4.2582706E-05
     +,   4.1770858E-05,   4.0997911E-05,   4.0265433E-05
     +,   3.9574563E-05,   3.8926260E-05,   3.8321068E-05
     +,   3.7759310E-05,   3.7240949E-05,   3.6765727E-05
     +,   3.6333098E-05,   3.5942237E-05,   3.5592173E-05
     +,   3.5281759E-05,   3.5009671E-05,   3.4774541E-05
     +,   3.4574972E-05,   3.4409593E-05,   3.4277135E-05
     +,   3.4176490E-05,   3.4106790E-05,   3.4067500E-05
     +,   3.4058456E-05,   3.4079985E-05,   3.4132958E-05
     +,   3.4218854E-05,   3.4339864E-05,   3.4498920E-05
     +,   3.4699766E-05,   3.4946992E-05,   3.5246117E-05
     +,   3.5603534E-05,   3.6026566E-05,   3.6523481E-05
     +,   3.7103484E-05,   3.7776565E-05,   3.8553695E-05
     +,   3.9446604E-05,   4.0467792E-05,   4.1630468E-05
     +,   4.2948599E-05,   4.4436918E-05,   4.6110708E-05
     +,   4.7985999E-05,   5.0079761E-05,   5.2409901E-05
     +,   5.4995297E-05,   5.7856116E-05,   6.1014274E-05
     +,   6.4493659E-05,   6.8320129E-05,   7.2522591E-05
     +,   7.7133118E-05,   8.2187173E-05,   8.7724104E-05
     +,   9.3788025E-05,   1.0042785E-04,   1.0769679E-04
     +,   1.1565280E-04,   1.2435883E-04,   1.3388193E-04
     +,   1.4429167E-04,   1.5565944E-04,   1.6805777E-04
     +,   1.8155758E-04,   1.9622460E-04,   2.1211911E-04
     +,   2.2929178E-04,   2.4777887E-04,   2.6760006E-04
     +,   2.8875601E-04,   3.1122347E-04,   3.3495095E-04
     +,   3.5985641E-04,   3.8582683E-04,   4.1271516E-04
     +,   4.4033738E-04,   4.6847411E-04,   4.9687392E-04
     +,   5.2525406E-04,   5.5330090E-04,   5.8068044E-04
     +,   6.0704187E-04,   6.3202152E-04,   6.5525435E-04
     +,   6.7638239E-04,   6.9506222E-04,   7.1097253E-04
     +,   7.2382513E-04,   7.3337229E-04,   7.3941378E-04
     +,   7.4180204E-04,   7.4044860E-04,   7.3532580E-04
     +,   7.2646828E-04,   7.1397430E-04,   6.9800089E-04
     +,   6.7876128E-04,   6.5652048E-04,   6.3158839E-04
     +,   6.0430955E-04,   5.7505519E-04,   5.4421776E-04
     +,   5.1219849E-04,   4.7939626E-04,   4.4620153E-04
     +,   4.1298952E-04,   3.8011180E-04,   3.4788752E-04
     +,   3.1660125E-04,   2.8650259E-04,   2.5779734E-04
     +,   2.3065061E-04,   2.0518819E-04,   1.8149651E-04
     +,   1.5962284E-04,   1.3958086E-04,   1.2135501E-04
     +,   1.0490302E-04,   9.0159272E-05,   7.7040386E-05
     +,   6.5450091E-05,   5.5282089E-05,   4.6423185E-05
     +,   3.8757473E-05,   3.2169763E-05,   2.6546437E-05
     +,   2.1778331E-05,   1.7762430E-05,   1.4402570E-05
     +,   1.1609978E-05,   9.3040235E-06,   7.4123927E-06
     +,   5.8707724E-06,   4.6224845E-06,   3.6182055E-06
     +,   2.8154625E-06,   2.1779413E-06,   1.6748546E-06
     +,   1.2803736E-06,   9.7303939E-07,   7.3511052E-07
     +,   5.5207425E-07,   4.1216120E-07,   3.0588930E-07
     +,   2.2567485E-07,   1.6550750E-07,   1.2066212E-07
     +,   8.7447233E-08,   6.2999533E-08,   4.5116835E-08
     +,   3.2118731E-08,   2.2729298E-08,   1.5989336E-08
     +,   1.1180994E-08,   7.7722317E-09,   5.3705063E-09
     +,   3.6889203E-09,   2.5187572E-09,   1.7095727E-09
     +,   1.1534318E-09,   7.7358997E-10,   5.1575028E-10
     +,   3.4180070E-10,   2.2517721E-10,   1.4746356E-10
     +,   9.5999271E-11,   6.2125020E-11,   3.9966710E-11
     +,   2.5559794E-11,   1.6250447E-11,   1.0271210E-11
     +,   6.4543900E-12,   4.0324957E-12,   2.5050587E-12
     +,   1.5474299E-12,   9.5063692E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz112 = Yx/0.00852173913043478
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz1128(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2646687E-05,   1.2737582E-05
     +,   1.2832413E-05,   1.2931449E-05,   1.3034964E-05
     +,   1.3143228E-05,   1.3256504E-05,   1.3375055E-05
     +,   1.3499135E-05,   1.3629002E-05,   1.3764899E-05
     +,   1.3907058E-05,   1.4055713E-05,   1.4211076E-05
     +,   1.4373363E-05,   1.4542763E-05,   1.4719463E-05
     +,   1.4903631E-05,   1.5095424E-05,   1.5294981E-05
     +,   1.5502423E-05,   1.5717860E-05,   1.5941372E-05
     +,   1.6173040E-05,   1.6412903E-05,   1.6660999E-05
     +,   1.6917325E-05,   1.7181874E-05,   1.7454611E-05
     +,   1.7735474E-05,   1.8024384E-05,   1.8321232E-05
     +,   1.8625895E-05,   1.8938217E-05,   1.9258025E-05
     +,   1.9585115E-05,   1.9919265E-05,   2.0260226E-05
     +,   2.0607742E-05,   2.0961492E-05,   2.1321188E-05
     +,   2.1686477E-05,   2.2057007E-05,   2.2432390E-05
     +,   2.2812237E-05,   2.3196126E-05,   2.3583616E-05
     +,   2.3974262E-05,   2.4367595E-05,   2.4763127E-05
     +,   2.5160369E-05,   2.5558806E-05,   2.5957919E-05
     +,   2.6357204E-05,   2.6756092E-05,   2.7154070E-05
     +,   2.7550586E-05,   2.7945092E-05,   2.8337037E-05
     +,   2.8725883E-05,   2.9111077E-05,   2.9492090E-05
     +,   2.9868370E-05,   3.0239393E-05,   3.0604664E-05
     +,   3.0963649E-05,   3.1315867E-05,   3.1660831E-05
     +,   3.1998086E-05,   3.2327163E-05,   3.2647658E-05
     +,   3.2959146E-05,   3.3261254E-05,   3.3553599E-05
     +,   3.3835855E-05,   3.4107728E-05,   3.4368910E-05
     +,   3.4619152E-05,   3.4858233E-05,   3.5085970E-05
     +,   3.5302190E-05,   3.5506793E-05,   3.5699675E-05
     +,   3.5880799E-05,   3.6050144E-05,   3.6207763E-05
     +,   3.6353715E-05,   3.6488123E-05,   3.6611149E-05
     +,   3.6722988E-05,   3.6823920E-05,   3.6914222E-05
     +,   3.6994250E-05,   3.7064401E-05,   3.7125119E-05
     +,   3.7176898E-05,   3.7220281E-05,   3.7255857E-05
     +,   3.7284262E-05,   3.7306170E-05,   3.7322312E-05
     +,   3.7333459E-05,   3.7340400E-05,   3.7343980E-05
     +,   3.7345068E-05,   3.7344547E-05,   3.7343336E-05
     +,   3.7342361E-05,   3.7342546E-05,   3.7344835E-05
     +,   3.7350146E-05,   3.7359376E-05,   3.7373407E-05
     +,   3.7393078E-05,   3.7419184E-05,   3.7452450E-05
     +,   3.7493552E-05,   3.7543057E-05,   3.7601465E-05
     +,   3.7669164E-05,   3.7746431E-05,   3.7833408E-05
     +,   3.7930105E-05,   3.8036396E-05,   3.8152011E-05
     +,   3.8276503E-05,   3.8409264E-05,   3.8549533E-05
     +,   3.8696362E-05,   3.8848633E-05,   3.9005085E-05
     +,   3.9164253E-05,   3.9324539E-05,   3.9484174E-05
     +,   3.9641262E-05,   3.9793798E-05,   3.9939634E-05
     +,   4.0076557E-05,   4.0202271E-05,   4.0314451E-05
     +,   4.0410778E-05,   4.0488940E-05,   4.0546714E-05
     +,   4.0581970E-05,   4.0592768E-05,   4.0577386E-05
     +,   4.0534396E-05,   4.0462743E-05,   4.0361840E-05
     +,   4.0231651E-05,   4.0072795E-05,   3.9886694E-05
     +,   3.9675717E-05,   3.9443272E-05,   3.9194030E-05
     +,   3.8934031E-05,   3.8670976E-05,   3.8414280E-05
     +,   3.8175283E-05,   3.7967540E-05,   3.7806767E-05
     +,   3.7711161E-05,   3.7701360E-05,   3.7800528E-05
     +,   3.8034326E-05,   3.8430797E-05,   3.9020160E-05
     +,   3.9834536E-05,   4.0907616E-05,   4.2274190E-05
     +,   4.3969510E-05,   4.6028632E-05,   4.8486003E-05
     +,   5.1374715E-05,   5.4725471E-05,   5.8566675E-05
     +,   6.2923769E-05,   6.7818757E-05,   7.3270443E-05
     +,   7.9295118E-05,   8.5907210E-05,   9.3119706E-05
     +,   1.0094610E-04,   1.0940267E-04,   1.1851023E-04
     +,   1.2829590E-04,   1.3879573E-04,   1.5005801E-04
     +,   1.6214447E-04,   1.7513050E-04,   1.8910832E-04
     +,   2.0418552E-04,   2.2048262E-04,   2.3813089E-04
     +,   2.5726948E-04,   2.7803821E-04,   3.0056899E-04
     +,   3.2497797E-04,   3.5135716E-04,   3.7976299E-04
     +,   4.1020292E-04,   4.4262639E-04,   4.7691769E-04
     +,   5.1288574E-04,   5.5025512E-04,   5.8866950E-04
     +,   6.2768930E-04,   6.6679338E-04,   7.0539030E-04
     +,   7.4283272E-04,   7.7843113E-04,   8.1147254E-04
     +,   8.4124313E-04,   8.6705585E-04,   8.8827184E-04
     +,   9.0432347E-04,   9.1473822E-04,   9.1915927E-04
     +,   9.1735920E-04,   9.0925081E-04,   8.9489331E-04
     +,   8.7449059E-04,   8.4838609E-04,   8.1705238E-04
     +,   7.8107032E-04,   7.4111181E-04,   6.9791696E-04
     +,   6.5226888E-04,   6.0496357E-04,   5.5678800E-04
     +,   5.0849991E-04,   4.6080432E-04,   4.1433322E-04
     +,   3.6963576E-04,   3.2717414E-04,   2.8730984E-04
     +,   2.5030790E-04,   2.1634249E-04,   1.8550007E-04
     +,   1.5778640E-04,   1.3313943E-04,   1.1144194E-04
     +,   9.2531642E-05,   7.6211574E-05,   6.2263091E-05
     +,   5.0456270E-05,   4.0557494E-05,   3.2336251E-05
     +,   2.5571813E-05,   2.0058036E-05,   1.5604939E-05
     +,   1.2041336E-05,   9.2156479E-06,   6.9954681E-06
     +,   5.2667301E-06,   3.9327224E-06,   2.9125745E-06
     +,   2.1394287E-06,   1.5586697E-06,   1.1262795E-06
     +,   8.0720963E-07,   5.7384074E-07,   4.0464428E-07
     +,   2.8304211E-07,   1.9641158E-07,   1.3522661E-07
     +,   9.2383289E-08,   6.2640069E-08,   4.2165976E-08
     +,   2.8189019E-08,   1.8725013E-08,   1.2367989E-08
     +,   8.1307885E-09,   5.3269753E-09,   3.4841188E-09
     +,   2.2802262E-09,   1.4976304E-09,   9.9076891E-10
     +,   6.6303296E-10,   4.5096216E-10,   3.1316369E-10
     +,   2.2289463E-10,   1.6298043E-10,   1.2248101E-10
     +,   9.4454729E-11,   7.4521028E-11,   5.9915017E-11
     +,   4.8890836E-11,   4.0340006E-11,   3.3549580E-11
     +,   2.8054344E-11,   2.3542135E-11,   1.9798290E-11
     +,   1.6669005E-11,   1.4040948E-11,   1.1826986E-11
     +,   9.9588272E-12,   8.3810294E-12,   7.0482934E-12
     +,   5.9226977E-12,   4.9725935E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz1128 = Yx/0.00852173913043478
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1995053E-05,   1.1945403E-05
     +,   1.1894339E-05,   1.1842153E-05,   1.1789152E-05
     +,   1.1735659E-05,   1.1682012E-05,   1.1628569E-05
     +,   1.1575703E-05,   1.1523800E-05,   1.1473273E-05
     +,   1.1424539E-05,   1.1378042E-05,   1.1334239E-05
     +,   1.1293604E-05,   1.1256625E-05,   1.1223811E-05
     +,   1.1195680E-05,   1.1172770E-05,   1.1155632E-05
     +,   1.1144828E-05,   1.1140937E-05,   1.1144549E-05
     +,   1.1156259E-05,   1.1176680E-05,   1.1206429E-05
     +,   1.1246130E-05,   1.1296409E-05,   1.1357904E-05
     +,   1.1431245E-05,   1.1517069E-05,   1.1616006E-05
     +,   1.1728681E-05,   1.1855713E-05,   1.1997709E-05
     +,   1.2155268E-05,   1.2328966E-05,   1.2519363E-05
     +,   1.2727006E-05,   1.2952394E-05,   1.3196025E-05
     +,   1.3458346E-05,   1.3739772E-05,   1.4040687E-05
     +,   1.4361417E-05,   1.4702257E-05,   1.5063442E-05
     +,   1.5445159E-05,   1.5847534E-05,   1.6270635E-05
     +,   1.6714463E-05,   1.7178960E-05,   1.7663977E-05
     +,   1.8169338E-05,   1.8694729E-05,   1.9239817E-05
     +,   1.9804154E-05,   2.0387230E-05,   2.0988446E-05
     +,   2.1607128E-05,   2.2242508E-05,   2.2893773E-05
     +,   2.3559958E-05,   2.4240102E-05,   2.4933152E-05
     +,   2.5637926E-05,   2.6353258E-05,   2.7077836E-05
     +,   2.7810383E-05,   2.8549472E-05,   2.9293735E-05
     +,   3.0041658E-05,   3.0791820E-05,   3.1542666E-05
     +,   3.2292712E-05,   3.3040484E-05,   3.3784458E-05
     +,   3.4523157E-05,   3.5255165E-05,   3.5979137E-05
     +,   3.6693720E-05,   3.7397716E-05,   3.8089936E-05
     +,   3.8769398E-05,   3.9435108E-05,   4.0086325E-05
     +,   4.0722342E-05,   4.1342675E-05,   4.1946958E-05
     +,   4.2535012E-05,   4.3106869E-05,   4.3662669E-05
     +,   4.4202778E-05,   4.4727738E-05,   4.5238314E-05
     +,   4.5735422E-05,   4.6220197E-05,   4.6693887E-05
     +,   4.7157988E-05,   4.7614078E-05,   4.8063957E-05
     +,   4.8509453E-05,   4.8952592E-05,   4.9395418E-05
     +,   4.9840059E-05,   5.0288709E-05,   5.0743500E-05
     +,   5.1206567E-05,   5.1680006E-05,   5.2165840E-05
     +,   5.2665888E-05,   5.3181913E-05,   5.3715419E-05
     +,   5.4267741E-05,   5.4839918E-05,   5.5432793E-05
     +,   5.6046803E-05,   5.6682140E-05,   5.7338628E-05
     +,   5.8015739E-05,   5.8712620E-05,   5.9428010E-05
     +,   6.0160266E-05,   6.0907456E-05,   6.1667313E-05
     +,   6.2437190E-05,   6.3214262E-05,   6.3995329E-05
     +,   6.4777138E-05,   6.5556153E-05,   6.6328859E-05
     +,   6.7091634E-05,   6.7840941E-05,   6.8573303E-05
     +,   6.9285452E-05,   6.9974427E-05,   7.0637550E-05
     +,   7.1272523E-05,   7.1877635E-05,   7.2451672E-05
     +,   7.2994080E-05,   7.3504962E-05,   7.3985204E-05
     +,   7.4436473E-05,   7.4861244E-05,   7.5262855E-05
     +,   7.5645468E-05,   7.6014127E-05,   7.6374679E-05
     +,   7.6733762E-05,   7.7098775E-05,   7.7477795E-05
     +,   7.7879420E-05,   7.8312827E-05,   7.8787562E-05
     +,   7.9313410E-05,   7.9900274E-05,   8.0558129E-05
     +,   8.1296799E-05,   8.2125691E-05,   8.3053928E-05
     +,   8.4090061E-05,   8.5241831E-05,   8.6516186E-05
     +,   8.7919187E-05,   8.9455854E-05,   9.1130081E-05
     +,   9.2944509E-05,   9.4900752E-05,   9.6999225E-05
     +,   9.9239027E-05,   1.0161811E-04,   1.0413351E-04
     +,   1.0678130E-04,   1.0955641E-04,   1.1245329E-04
     +,   1.1546579E-04,   1.1858706E-04,   1.2181005E-04
     +,   1.2512761E-04,   1.2853269E-04,   1.3201807E-04
     +,   1.3557682E-04,   1.3920249E-04,   1.4288908E-04
     +,   1.4663074E-04,   1.5042206E-04,   1.5425826E-04
     +,   1.5813486E-04,   1.6204726E-04,   1.6599133E-04
     +,   1.6996272E-04,   1.7395674E-04,   1.7796799E-04
     +,   1.8199065E-04,   1.8601796E-04,   1.9004173E-04
     +,   1.9405219E-04,   1.9803832E-04,   2.0198718E-04
     +,   2.0588370E-04,   2.0971072E-04,   2.1344927E-04
     +,   2.1707828E-04,   2.2057438E-04,   2.2391265E-04
     +,   2.2706656E-04,   2.3000799E-04,   2.3270780E-04
     +,   2.3513641E-04,   2.3726399E-04,   2.3906077E-04
     +,   2.4049779E-04,   2.4154750E-04,   2.4218409E-04
     +,   2.4238393E-04,   2.4212632E-04,   2.4139372E-04
     +,   2.4017230E-04,   2.3845234E-04,   2.3622828E-04
     +,   2.3349911E-04,   2.3026863E-04,   2.2654542E-04
     +,   2.2234266E-04,   2.1767800E-04,   2.1257384E-04
     +,   2.0705674E-04,   2.0115677E-04,   1.9490744E-04
     +,   1.8834551E-04,   1.8151029E-04,   1.7444255E-04
     +,   1.6718439E-04,   1.5977955E-04,   1.5227108E-04
     +,   1.4470195E-04,   1.3711455E-04,   1.2955007E-04
     +,   1.2204745E-04,   1.1464335E-04,   1.0737243E-04
     +,   1.0026646E-04,   9.3353701E-05,   8.6659173E-05
     +,   8.0204998E-05,   7.4009818E-05,   6.8088484E-05
     +,   6.2452520E-05,   5.7110738E-05,   5.2068270E-05
     +,   4.7327376E-05,   4.2887881E-05,   3.8747094E-05
     +,   3.4899807E-05,   3.1338845E-05,   2.8055574E-05
     +,   2.5039846E-05,   2.2280148E-05,   1.9764022E-05
     +,   1.7478509E-05,   1.5410124E-05,   1.3544971E-05
     +,   1.1869095E-05,   1.0368788E-05,   9.0303975E-06
     +,   7.8406429E-06,   6.7867836E-06,   5.8566006E-06
     +,   5.0384183E-06,   4.3212303E-06,   3.6947670E-06
     +,   3.1494526E-06,   2.6763903E-06,   2.2673960E-06
     +,   1.9150216E-06,   1.6124392E-06,   1.3535098E-06
     +,   1.1326683E-06,   9.4495772E-07,   7.8593257E-07
     +,   6.5166819E-07,   5.3868030E-07,   4.4391950E-07
     +,   3.6470411E-07,   2.9870728E-07,   2.4390303E-07
     +,   1.9854181E-07,   1.6112237E-07,   1.3035365E-07
     +,   1.0513806E-07,   8.4539664E-08,   6.7768973E-08
     +,   5.4158289E-08,   4.3148823E-08,   3.4271810E-08
     +,   2.7137869E-08,   2.1422904E-08,   1.6859779E-08
     +,   1.3227867E-08,   1.0346629E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz114 = Yx/0.00515789473684211
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6839765E-07,   4.1477807E-07
     +,   4.6631277E-07,   5.2348315E-07,   5.8680382E-07
     +,   6.5682440E-07,   7.3412946E-07,   8.1934036E-07
     +,   9.1311330E-07,   1.0161459E-06,   1.1291690E-06
     +,   1.2529524E-06,   1.3883014E-06,   1.5360580E-06
     +,   1.6970994E-06,   1.8723360E-06,   2.0627087E-06
     +,   2.2691895E-06,   2.4927772E-06,   2.7344934E-06
     +,   2.9953801E-06,   3.2764940E-06,   3.5789012E-06
     +,   3.9036913E-06,   4.2519214E-06,   4.6246778E-06
     +,   5.0230160E-06,   5.4479751E-06,   5.9005697E-06
     +,   6.3817793E-06,   6.8925406E-06,   7.4337368E-06
     +,   8.0061936E-06,   8.6106675E-06,   9.2478267E-06
     +,   9.9182616E-06,   1.0622452E-05,   1.1360768E-05
     +,   1.2133499E-05,   1.2940724E-05,   1.3782474E-05
     +,   1.4658579E-05,   1.5568730E-05,   1.6512457E-05
     +,   1.7489110E-05,   1.8497876E-05,   1.9537754E-05
     +,   2.0607557E-05,   2.1705913E-05,   2.2831251E-05
     +,   2.3981818E-05,   2.5155659E-05,   2.6350626E-05
     +,   2.7564447E-05,   2.8794546E-05,   3.0038302E-05
     +,   3.1292853E-05,   3.2555206E-05,   3.3822213E-05
     +,   3.5090601E-05,   3.6356992E-05,   3.7617905E-05
     +,   3.8869704E-05,   4.0108793E-05,   4.1331528E-05
     +,   4.2534110E-05,   4.3712898E-05,   4.4864119E-05
     +,   4.5984176E-05,   4.7069389E-05,   4.8116308E-05
     +,   4.9121438E-05,   5.0081559E-05,   5.0993451E-05
     +,   5.1854153E-05,   5.2660911E-05,   5.3411073E-05
     +,   5.4102256E-05,   5.4732333E-05,   5.5299410E-05
     +,   5.5801822E-05,   5.6238208E-05,   5.6607445E-05
     +,   5.6908717E-05,   5.7141475E-05,   5.7305460E-05
     +,   5.7400666E-05,   5.7427413E-05,   5.7386249E-05
     +,   5.7277994E-05,   5.7103731E-05,   5.6864774E-05
     +,   5.6562698E-05,   5.6199242E-05,   5.5776360E-05
     +,   5.5296234E-05,   5.4761123E-05,   5.4173528E-05
     +,   5.3535994E-05,   5.2851250E-05,   5.2122035E-05
     +,   5.1351228E-05,   5.0541697E-05,   4.9696413E-05
     +,   4.8818310E-05,   4.7910293E-05,   4.6975318E-05
     +,   4.6016310E-05,   4.5036093E-05,   4.4037421E-05
     +,   4.3023065E-05,   4.1995612E-05,   4.0957668E-05
     +,   3.9911629E-05,   3.8859900E-05,   3.7804664E-05
     +,   3.6748115E-05,   3.5692210E-05,   3.4638921E-05
     +,   3.3590000E-05,   3.2547101E-05,   3.1511809E-05
     +,   3.0485624E-05,   2.9469849E-05,   2.8465705E-05
     +,   2.7474392E-05,   2.6496898E-05,   2.5534242E-05
     +,   2.4587225E-05,   2.3656703E-05,   2.2743319E-05
     +,   2.1847773E-05,   2.0970574E-05,   2.0112284E-05
     +,   1.9273333E-05,   1.8454088E-05,   1.7654937E-05
     +,   1.6876214E-05,   1.6118194E-05,   1.5381123E-05
     +,   1.4665293E-05,   1.3971010E-05,   1.3298564E-05
     +,   1.2648306E-05,   1.2020751E-05,   1.1416468E-05
     +,   1.0836229E-05,   1.0281084E-05,   9.7523971E-06
     +,   9.2519094E-06,   8.7818771E-06,   8.3452142E-06
     +,   7.9455958E-06,   7.5875778E-06,   7.2767853E-06
     +,   7.0201081E-06,   6.8258300E-06,   6.7038118E-06
     +,   6.6656712E-06,   6.7249507E-06,   6.8972563E-06
     +,   7.2004077E-06,   7.6545384E-06,   8.2821844E-06
     +,   9.1084366E-06,   1.0161021E-05,   1.1470318E-05
     +,   1.3069492E-05,   1.4994779E-05,   1.7285620E-05
     +,   1.9984713E-05,   2.3138384E-05,   2.6797145E-05
     +,   3.1015879E-05,   3.5853642E-05,   4.1374660E-05
     +,   4.7648071E-05,   5.4747183E-05,   6.2749183E-05
     +,   7.1734692E-05,   8.1785860E-05,   9.2983435E-05
     +,   1.0540450E-04,   1.1911996E-04,   1.3419011E-04
     +,   1.5065917E-04,   1.6855159E-04,   1.8786907E-04
     +,   2.0858567E-04,   2.3064272E-04,   2.5395089E-04
     +,   2.7838853E-04,   3.0380144E-04,   3.3000868E-04
     +,   3.5681028E-04,   3.8399367E-04,   4.1134149E-04
     +,   4.3864385E-04,   4.6571007E-04,   4.9237628E-04
     +,   5.1851006E-04,   5.4401578E-04,   5.6883472E-04
     +,   5.9293793E-04,   6.1631144E-04,   6.3894712E-04
     +,   6.6081987E-04,   6.8186637E-04,   7.0196635E-04
     +,   7.2092714E-04,   7.3847041E-04,   7.5422705E-04
     +,   7.6774484E-04,   7.7850383E-04,   7.8594027E-04
     +,   7.8948017E-04,   7.8857911E-04,   7.8276423E-04
     +,   7.7167409E-04,   7.5509661E-04,   7.3299417E-04
     +,   7.0552115E-04,   6.7302870E-04,   6.3605461E-04
     +,   5.9529691E-04,   5.5158261E-04,   5.0582876E-04
     +,   4.5899409E-04,   4.1202886E-04,   3.6583340E-04
     +,   3.2122302E-04,   2.7889485E-04,   2.3940457E-04
     +,   2.0315935E-04,   1.7042016E-04,   1.4130305E-04
     +,   1.1579734E-04,   9.3786803E-05,   7.5069773E-05
     +,   5.9381240E-05,   4.6416950E-05,   3.5854089E-05
     +,   2.7367138E-05,   2.0641275E-05,   1.5383281E-05
     +,   1.1328287E-05,   8.2429378E-06,   5.9264357E-06
     +,   4.2100810E-06,   2.9551488E-06,   2.0495229E-06
     +,   1.4044400E-06,   9.5089797E-07,   6.3613527E-07
     +,   4.2047779E-07,   2.7460459E-07,   1.7719405E-07
     +,   1.1297267E-07,   7.1166362E-08,   4.4294236E-08
     +,   2.7239500E-08,   1.6551612E-08,   9.9372963E-09
     +,   5.8949827E-09,   3.4554783E-09,   2.0014914E-09
     +,   1.1456068E-09,   6.4803501E-10,   3.6233308E-10
     +,   2.0028362E-10,   1.0948192E-10,   5.9214363E-11
     +,   3.1714392E-11,   1.6841167E-11,   8.8845832E-12
     +,   4.6712387E-12,   2.4594239E-12,   1.3060598E-12
     +,   7.0651753E-13,   3.9423686E-13,   2.2993901E-13
     +,   1.4166954E-13,   9.2566417E-14,   6.3882690E-14
     +,   4.6100012E-14,   3.4371011E-14,   2.6189905E-14
     +,   2.0226203E-14,   1.5741889E-14,   1.2301410E-14
     +,   9.6301319E-15,   7.5421855E-15,   5.9049166E-15
     +,   4.6193598E-15,   3.6099244E-15,   2.8176907E-15
     +,   2.1965515E-15,   1.7100877E-15,   1.3295982E-15
     +,   1.0323726E-15,   8.0051554E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz115 = Yx/0.00733333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1530957E-05,   1.2091383E-05
     +,   1.2666568E-05,   1.3256063E-05,   1.3859358E-05
     +,   1.4475876E-05,   1.5104984E-05,   1.5745989E-05
     +,   1.6398108E-05,   1.7060545E-05,   1.7732407E-05
     +,   1.8412751E-05,   1.9100577E-05,   1.9794828E-05
     +,   2.0494403E-05,   2.1198144E-05,   2.1904858E-05
     +,   2.2613300E-05,   2.3322187E-05,   2.4030216E-05
     +,   2.4736040E-05,   2.5438305E-05,   2.6135629E-05
     +,   2.6826645E-05,   2.7509925E-05,   2.8184109E-05
     +,   2.8847804E-05,   2.9499641E-05,   3.0138282E-05
     +,   3.0762392E-05,   3.1370710E-05,   3.1961983E-05
     +,   3.2535019E-05,   3.3088687E-05,   3.3621913E-05
     +,   3.4133689E-05,   3.4623074E-05,   3.5089222E-05
     +,   3.5531382E-05,   3.5948848E-05,   3.6341058E-05
     +,   3.6707523E-05,   3.7047859E-05,   3.7361784E-05
     +,   3.7649141E-05,   3.7909867E-05,   3.8144015E-05
     +,   3.8351740E-05,   3.8533319E-05,   3.8689148E-05
     +,   3.8819711E-05,   3.8925617E-05,   3.9007566E-05
     +,   3.9066374E-05,   3.9102935E-05,   3.9118262E-05
     +,   3.9113427E-05,   3.9089602E-05,   3.9048031E-05
     +,   3.8990020E-05,   3.8916944E-05,   3.8830221E-05
     +,   3.8731323E-05,   3.8621758E-05,   3.8503051E-05
     +,   3.8376762E-05,   3.8244438E-05,   3.8107646E-05
     +,   3.7967944E-05,   3.7826849E-05,   3.7685866E-05
     +,   3.7546470E-05,   3.7410075E-05,   3.7278045E-05
     +,   3.7151673E-05,   3.7032194E-05,   3.6920748E-05
     +,   3.6818412E-05,   3.6726149E-05,   3.6644822E-05
     +,   3.6575198E-05,   3.6517933E-05,   3.6473572E-05
     +,   3.6442521E-05,   3.6425099E-05,   3.6421487E-05
     +,   3.6431731E-05,   3.6455764E-05,   3.6493402E-05
     +,   3.6544330E-05,   3.6608104E-05,   3.6684181E-05
     +,   3.6771882E-05,   3.6870439E-05,   3.6978960E-05
     +,   3.7096452E-05,   3.7221849E-05,   3.7353966E-05
     +,   3.7491562E-05,   3.7633305E-05,   3.7777816E-05
     +,   3.7923641E-05,   3.8069287E-05,   3.8213220E-05
     +,   3.8353883E-05,   3.8489688E-05,   3.8619044E-05
     +,   3.8740352E-05,   3.8852028E-05,   3.8952512E-05
     +,   3.9040249E-05,   3.9113747E-05,   3.9171548E-05
     +,   3.9212242E-05,   3.9234485E-05,   3.9237013E-05
     +,   3.9218627E-05,   3.9178216E-05,   3.9114751E-05
     +,   3.9027324E-05,   3.8915081E-05,   3.8777325E-05
     +,   3.8613449E-05,   3.8422932E-05,   3.8205395E-05
     +,   3.7960577E-05,   3.7688304E-05,   3.7388556E-05
     +,   3.7061393E-05,   3.6707017E-05,   3.6325728E-05
     +,   3.5917961E-05,   3.5484205E-05,   3.5025110E-05
     +,   3.4541401E-05,   3.4033874E-05,   3.3503457E-05
     +,   3.2951160E-05,   3.2378048E-05,   3.1785246E-05
     +,   3.1173986E-05,   3.0545565E-05,   2.9901305E-05
     +,   2.9242567E-05,   2.8570836E-05,   2.7887576E-05
     +,   2.7194301E-05,   2.6492613E-05,   2.5784182E-05
     +,   2.5070691E-05,   2.4353913E-05,   2.3635774E-05
     +,   2.2918337E-05,   2.2203811E-05,   2.1494643E-05
     +,   2.0793646E-05,   2.0104046E-05,   1.9429532E-05
     +,   1.8774477E-05,   1.8144148E-05,   1.7544777E-05
     +,   1.6983875E-05,   1.6470531E-05,   1.6015672E-05
     +,   1.5632384E-05,   1.5336329E-05,   1.5146162E-05
     +,   1.5083921E-05,   1.5175466E-05,   1.5450949E-05
     +,   1.5945205E-05,   1.6698108E-05,   1.7754965E-05
     +,   1.9166762E-05,   2.0990108E-05,   2.3287514E-05
     +,   2.6127156E-05,   2.9582292E-05,   3.3730790E-05
     +,   3.8654667E-05,   4.4438915E-05,   5.1169762E-05
     +,   5.8933398E-05,   6.7814748E-05,   7.7895231E-05
     +,   8.9249792E-05,   1.0194496E-04,   1.1603739E-04
     +,   1.3157075E-04,   1.4857136E-04,   1.6704883E-04
     +,   1.8699229E-04,   2.0836676E-04,   2.3111232E-04
     +,   2.5514406E-04,   2.8034952E-04,   3.0658609E-04
     +,   3.3368263E-04,   3.6144120E-04,   3.8963673E-04
     +,   4.1801666E-04,   4.4630544E-04,   4.7420934E-04
     +,   5.0141866E-04,   5.2761007E-04,   5.5245671E-04
     +,   5.7563180E-04,   5.9681380E-04,   6.1569456E-04
     +,   6.3198782E-04,   6.4543390E-04,   6.5580674E-04
     +,   6.6292012E-04,   6.6663453E-04,   6.6686003E-04
     +,   6.6355948E-04,   6.5675238E-04,   6.4651365E-04
     +,   6.3297286E-04,   6.1631401E-04,   5.9676851E-04
     +,   5.7461072E-04,   5.5015349E-04,   5.2373979E-04
     +,   4.9573177E-04,   4.6650431E-04,   4.3643804E-04
     +,   4.0590897E-04,   3.7527824E-04,   3.4488685E-04
     +,   3.1505103E-04,   2.8605523E-04,   2.5814562E-04
     +,   2.3152988E-04,   2.0637801E-04,   1.8281692E-04
     +,   1.6093432E-04,   1.4078192E-04,   1.2237666E-04
     +,   1.0570313E-04,   9.0719048E-05,   7.7360542E-05
     +,   6.5545115E-05,   5.5175486E-05,   4.6144753E-05
     +,   3.8340648E-05,   3.1648189E-05,   2.5952364E-05
     +,   2.1141219E-05,   1.7108176E-05,   1.3752605E-05
     +,   1.0981486E-05,   8.7101544E-06,   6.8623644E-06
     +,   5.3702329E-06,   4.1741905E-06,   3.2226044E-06
     +,   2.4711214E-06,   1.8820157E-06,   1.4235886E-06
     +,   1.0694897E-06,   7.9799310E-07,   5.9135016E-07
     +,   4.3521777E-07,   3.1812121E-07,   2.3094016E-07
     +,   1.6650439E-07,   1.1922890E-07,   8.4797229E-08
     +,   5.9901204E-08,   4.2029896E-08,   2.9294316E-08
     +,   2.0284006E-08,   1.3954583E-08,   9.5397530E-09
     +,   6.4821495E-09,   4.3790167E-09,   2.9422993E-09
     +,   1.9672468E-09,   1.3097713E-09,   8.6909419E-10
     +,   5.7541649E-10,   3.8068776E-10,   2.5214195E-10
     +,   1.6756894E-10,   1.1204910E-10,   7.5618588E-11
     +,   5.1675050E-11,   3.5873624E-11,   2.5368830E-11
     +,   1.8310331E-11,   1.3498328E-11,   1.0158878E-11
     +,   7.7926762E-12,   6.0781029E-12,   4.8069730E-12
     +,   3.8439334E-12,   3.0998693E-12,   2.5153829E-12
     +,   2.0500006E-12,   1.6755936E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz116 = Yx/0.00666666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6865957E-07,   1.9538234E-07
     +,   2.2593952E-07,   2.6081534E-07,   3.0054466E-07
     +,   3.4571715E-07,   3.9698119E-07,   4.5504780E-07
     +,   5.2069345E-07,   5.9476889E-07,   6.7819627E-07
     +,   7.7197706E-07,   8.7719474E-07,   9.9501904E-07
     +,   1.1267076E-06,   1.2736095E-06,   1.4371677E-06
     +,   1.6189200E-06,   1.8205008E-06,   2.0436407E-06
     +,   2.2901670E-06,   2.5620006E-06,   2.8611512E-06
     +,   3.1897357E-06,   3.5499181E-06,   3.9439797E-06
     +,   4.3742471E-06,   4.8431166E-06,   5.3530339E-06
     +,   5.9064828E-06,   6.5059730E-06,   7.1540253E-06
     +,   7.8531484E-06,   8.6058326E-06,   9.4145216E-06
     +,   1.0281587E-05,   1.1209318E-05,   1.2199871E-05
     +,   1.3255325E-05,   1.4377490E-05,   1.5568092E-05
     +,   1.6828573E-05,   1.8160154E-05,   1.9563777E-05
     +,   2.1040081E-05,   2.2589387E-05,   2.4211666E-05
     +,   2.5906511E-05,   2.7673115E-05,   2.9510267E-05
     +,   3.1416323E-05,   3.3389180E-05,   3.5426259E-05
     +,   3.7524653E-05,   3.9680726E-05,   4.1890642E-05
     +,   4.4149951E-05,   4.6453784E-05,   4.8796843E-05
     +,   5.1173396E-05,   5.3577314E-05,   5.6002129E-05
     +,   5.8440910E-05,   6.0886567E-05,   6.3331790E-05
     +,   6.5768763E-05,   6.8189860E-05,   7.0586990E-05
     +,   7.2952280E-05,   7.5277567E-05,   7.7554971E-05
     +,   7.9776437E-05,   8.1934333E-05,   8.4020918E-05
     +,   8.6028936E-05,   8.7951383E-05,   8.9781468E-05
     +,   9.1512826E-05,   9.3139621E-05,   9.4656447E-05
     +,   9.6058262E-05,   9.7340766E-05,   9.8499972E-05
     +,   9.9532655E-05,   1.0043601E-04,   1.0120792E-04
     +,   1.0184679E-04,   1.0235165E-04,   1.0272205E-04
     +,   1.0295815E-04,   1.0306061E-04,   1.0303064E-04
     +,   1.0286992E-04,   1.0258061E-04,   1.0216532E-04
     +,   1.0162705E-04,   1.0096916E-04,   1.0019541E-04
     +,   9.9309771E-05,   9.8316588E-05,   9.7220305E-05
     +,   9.6025746E-05,   9.4737705E-05,   9.3361305E-05
     +,   9.1901631E-05,   9.0363850E-05,   8.8753281E-05
     +,   8.7075292E-05,   8.5335116E-05,   8.3538012E-05
     +,   8.1689344E-05,   7.9794234E-05,   7.7857963E-05
     +,   7.5885502E-05,   7.3882002E-05,   7.1852250E-05
     +,   6.9801201E-05,   6.7733468E-05,   6.5653774E-05
     +,   6.3566549E-05,   6.1476094E-05,   5.9386730E-05
     +,   5.7302623E-05,   5.5227680E-05,   5.3165655E-05
     +,   5.1120362E-05,   4.9095193E-05,   4.7093647E-05
     +,   4.5118799E-05,   4.3173804E-05,   4.1261417E-05
     +,   3.9384428E-05,   3.7545229E-05,   3.5746252E-05
     +,   3.3989567E-05,   3.2277065E-05,   3.0610547E-05
     +,   2.8991622E-05,   2.7421598E-05,   2.5901612E-05
     +,   2.4432709E-05,   2.3015757E-05,   2.1651360E-05
     +,   2.0339987E-05,   1.9082092E-05,   1.7877890E-05
     +,   1.6727514E-05,   1.5631118E-05,   1.4588830E-05
     +,   1.3600740E-05,   1.2667023E-05,   1.1788066E-05
     +,   1.0964466E-05,   1.0197073E-05,   9.4871484E-06
     +,   8.8365177E-06,   8.2476408E-06,   7.7237210E-06
     +,   7.2689118E-06,   6.8885183E-06,   6.5890949E-06
     +,   6.3786943E-06,   6.2670897E-06,   6.2659583E-06
     +,   6.3891075E-06,   6.6527314E-06,   7.0756087E-06
     +,   7.6793085E-06,   8.4884641E-06,   9.5309679E-06
     +,   1.0838058E-05,   1.2444521E-05,   1.4388927E-05
     +,   1.6713688E-05,   1.9464798E-05,   2.2692329E-05
     +,   2.6450136E-05,   3.0795472E-05,   3.5788824E-05
     +,   4.1493957E-05,   4.7977184E-05,   5.5306209E-05
     +,   6.3549553E-05,   7.2776085E-05,   8.3053339E-05
     +,   9.4445175E-05,   1.0701048E-04,   1.2080192E-04
     +,   1.3586301E-04,   1.5222382E-04,   1.6990116E-04
     +,   1.8889444E-04,   2.0918126E-04,   2.3071570E-04
     +,   2.5342705E-04,   2.7721663E-04,   3.0195378E-04
     +,   3.2747659E-04,   3.5359312E-04,   3.8008037E-04
     +,   4.0668441E-04,   4.3312437E-04,   4.5909864E-04
     +,   4.8428751E-04,   5.0835719E-04,   5.3097162E-04
     +,   5.5179757E-04,   5.7051110E-04,   5.8680831E-04
     +,   6.0041365E-04,   6.1108696E-04,   6.1862962E-04
     +,   6.2289234E-04,   6.2377925E-04,   6.2125101E-04
     +,   6.1532669E-04,   6.0608366E-04,   5.9365598E-04
     +,   5.7822966E-04,   5.6004041E-04,   5.3936447E-04
     +,   5.1651156E-04,   4.9181917E-04,   4.6564257E-04
     +,   4.3834385E-04,   4.1028493E-04,   3.8182139E-04
     +,   3.5329323E-04,   3.2501647E-04,   2.9727918E-04
     +,   2.7033975E-04,   2.4442104E-04,   2.1970764E-04
     +,   1.9634671E-04,   1.7445060E-04,   1.5409400E-04
     +,   1.3531823E-04,   1.1813561E-04,   1.0253118E-04
     +,   8.8465436E-05,   7.5879732E-05,   6.4700507E-05
     +,   5.4842203E-05,   4.6210214E-05,   3.8704977E-05
     +,   3.2225205E-05,   2.6669757E-05,   2.1939461E-05
     +,   1.7939254E-05,   1.4579778E-05,   1.1777509E-05
     +,   9.4558191E-06,   7.5453795E-06,   5.9840172E-06
     +,   4.7165108E-06,   3.6944655E-06,   2.8759287E-06
     +,   2.2248137E-06,   1.7103480E-06,   1.3065807E-06
     +,   9.9184183E-07,   7.4816415E-07,   5.6077096E-07
     +,   4.1763235E-07,   3.0904462E-07,   2.2722311E-07
     +,   1.6598713E-07,   1.2047072E-07,   8.6869854E-08
     +,   6.2233475E-08,   4.4292726E-08,   3.1317729E-08
     +,   2.1998561E-08,   1.5350816E-08,   1.0641153E-08
     +,   7.3277149E-09,   5.0124860E-09,   3.4060108E-09
     +,   2.2989477E-09,   1.5413704E-09,   1.0265071E-09
     +,   6.7904599E-10,   4.4617110E-10,   2.9118818E-10
     +,   1.8875543E-10,   1.2153040E-10,   7.7717596E-11
     +,   4.9361827E-11,   3.1139293E-11,   1.9509869E-11
     +,   1.2140517E-11,   7.5030737E-12,   4.6054354E-12
     +,   2.8074596E-12,   1.6997271E-12,   1.0219936E-12
     +,   6.1028694E-13,   3.6192430E-13,   2.1316281E-13
     +,   1.2468008E-13,   7.2424936E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz118 = Yx/0.00666666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4892848E-05,   3.5679674E-05
     +,   3.6459853E-05,   3.7232305E-05,   3.7995971E-05
     +,   3.8749782E-05,   3.9492708E-05,   4.0223731E-05
     +,   4.0941846E-05,   4.1646130E-05,   4.2335651E-05
     +,   4.3009532E-05,   4.3666951E-05,   4.4307133E-05
     +,   4.4929358E-05,   4.5532975E-05,   4.6117410E-05
     +,   4.6682133E-05,   4.7226727E-05,   4.7750833E-05
     +,   4.8254180E-05,   4.8736594E-05,   4.9197992E-05
     +,   4.9638402E-05,   5.0057908E-05,   5.0456758E-05
     +,   5.0835260E-05,   5.1193845E-05,   5.1533043E-05
     +,   5.1853487E-05,   5.2155956E-05,   5.2441279E-05
     +,   5.2710431E-05,   5.2964482E-05,   5.3204585E-05
     +,   5.3432021E-05,   5.3648135E-05,   5.3854379E-05
     +,   5.4052285E-05,   5.4243454E-05,   5.4429554E-05
     +,   5.4612330E-05,   5.4793571E-05,   5.4975106E-05
     +,   5.5158798E-05,   5.5346532E-05,   5.5540226E-05
     +,   5.5741762E-05,   5.5953038E-05,   5.6175919E-05
     +,   5.6412238E-05,   5.6663750E-05,   5.6932186E-05
     +,   5.7219189E-05,   5.7526286E-05,   5.7854930E-05
     +,   5.8206442E-05,   5.8582002E-05,   5.8982674E-05
     +,   5.9409344E-05,   5.9862745E-05,   6.0343413E-05
     +,   6.0851700E-05,   6.1387786E-05,   6.1951621E-05
     +,   6.2542924E-05,   6.3161249E-05,   6.3805848E-05
     +,   6.4475826E-05,   6.5169996E-05,   6.5886976E-05
     +,   6.6625085E-05,   6.7382542E-05,   6.8157198E-05
     +,   6.8946778E-05,   6.9748778E-05,   7.0560462E-05
     +,   7.1378876E-05,   7.2200972E-05,   7.3023490E-05
     +,   7.3842959E-05,   7.4655873E-05,   7.5458505E-05
     +,   7.6247103E-05,   7.7017794E-05,   7.7766657E-05
     +,   7.8489713E-05,   7.9183010E-05,   7.9842517E-05
     +,   8.0464350E-05,   8.1044585E-05,   8.1579426E-05
     +,   8.2065111E-05,   8.2498096E-05,   8.2874933E-05
     +,   8.3192332E-05,   8.3447201E-05,   8.3636682E-05
     +,   8.3758132E-05,   8.3809173E-05,   8.3787629E-05
     +,   8.3691710E-05,   8.3519815E-05,   8.3270745E-05
     +,   8.2943530E-05,   8.2537576E-05,   8.2052604E-05
     +,   8.1488681E-05,   8.0846192E-05,   8.0125843E-05
     +,   7.9328725E-05,   7.8456193E-05,   7.7509998E-05
     +,   7.6492135E-05,   7.5404991E-05,   7.4251155E-05
     +,   7.3033640E-05,   7.1755559E-05,   7.0420494E-05
     +,   6.9032132E-05,   6.7594417E-05,   6.6111614E-05
     +,   6.4588239E-05,   6.3028870E-05,   6.1438383E-05
     +,   5.9821952E-05,   5.8184771E-05,   5.6532459E-05
     +,   5.4870634E-05,   5.3205385E-05,   5.1542767E-05
     +,   4.9889339E-05,   4.8251728E-05,   4.6637066E-05
     +,   4.5052642E-05,   4.3506116E-05,   4.2005664E-05
     +,   4.0559858E-05,   3.9177674E-05,   3.7868609E-05
     +,   3.6642763E-05,   3.5510846E-05,   3.4484099E-05
     +,   3.3574419E-05,   3.2794440E-05,   3.2157415E-05
     +,   3.1677253E-05,   3.1368567E-05,   3.1246585E-05
     +,   3.1327065E-05,   3.1626314E-05,   3.2161013E-05
     +,   3.2948130E-05,   3.4004825E-05,   3.5348276E-05
     +,   3.6995381E-05,   3.8962626E-05,   4.1265950E-05
     +,   4.3920460E-05,   4.6939847E-05,   5.0336639E-05
     +,   5.4121723E-05,   5.8303747E-05,   6.2889034E-05
     +,   6.7881701E-05,   7.3283103E-05,   7.9091304E-05
     +,   8.5301057E-05,   9.1904280E-05,   9.8889410E-05
     +,   1.0624099E-04,   1.1394000E-04,   1.2196453E-04
     +,   1.3028934E-04,   1.3888524E-04,   1.4772103E-04
     +,   1.5676286E-04,   1.6597411E-04,   1.7531608E-04
     +,   1.8474946E-04,   1.9423375E-04,   2.0372737E-04
     +,   2.1318867E-04,   2.2257694E-04,   2.3185227E-04
     +,   2.4097544E-04,   2.4990871E-04,   2.5861690E-04
     +,   2.6706699E-04,   2.7522744E-04,   2.8307005E-04
     +,   2.9056906E-04,   2.9770078E-04,   3.0444402E-04
     +,   3.1078031E-04,   3.1669333E-04,   3.2216837E-04
     +,   3.2719216E-04,   3.3175337E-04,   3.3584179E-04
     +,   3.3944764E-04,   3.4256195E-04,   3.4517652E-04
     +,   3.4728300E-04,   3.4887344E-04,   3.4994000E-04
     +,   3.5047505E-04,   3.5047109E-04,   3.4992132E-04
     +,   3.4881916E-04,   3.4715916E-04,   3.4493709E-04
     +,   3.4215025E-04,   3.3879772E-04,   3.3488075E-04
     +,   3.3040348E-04,   3.2537288E-04,   3.1979900E-04
     +,   3.1369532E-04,   3.0707938E-04,   2.9997207E-04
     +,   2.9239792E-04,   2.8438578E-04,   2.7596808E-04
     +,   2.6718032E-04,   2.5806081E-04,   2.4865154E-04
     +,   2.3899671E-04,   2.2914184E-04,   2.1913381E-04
     +,   2.0902105E-04,   1.9885205E-04,   1.8867462E-04
     +,   1.7853543E-04,   1.6848092E-04,   1.5855451E-04
     +,   1.4879731E-04,   1.3924828E-04,   1.2994315E-04
     +,   1.2091358E-04,   1.1218759E-04,   1.0379002E-04
     +,   9.5741627E-05,   8.8058725E-05,   8.0753758E-05
     +,   7.3835814E-05,   6.7310262E-05,   6.1178573E-05
     +,   5.5438955E-05,   5.0087248E-05,   4.5115998E-05
     +,   4.0515406E-05,   3.6273897E-05,   3.2378110E-05
     +,   2.8812950E-05,   2.5562214E-05,   2.2609103E-05
     +,   1.9936178E-05,   1.7525501E-05,   1.5359075E-05
     +,   1.3419180E-05,   1.1688353E-05,   1.0149474E-05
     +,   8.7860390E-06,   7.5823668E-06,   6.5234117E-06
     +,   5.5949936E-06,   4.7838744E-06,   4.0777099E-06
     +,   3.4650188E-06,   2.9352407E-06,   2.4787437E-06
     +,   2.0867492E-06,   1.7512808E-06,   1.4651572E-06
     +,   1.2219655E-06,   1.0159528E-06,   8.4203754E-07
     +,   6.9570592E-07,   5.7300758E-07,   4.7046578E-07
     +,   3.8506363E-07,   3.1417156E-07,   2.5552563E-07
     +,   2.0717069E-07,   1.6743729E-07,   1.3489665E-07
     +,   1.0833552E-07,   8.6729166E-08,   6.9211104E-08
     +,   5.5056372E-08,   4.3656797E-08,   3.4507508E-08
     +,   2.7188424E-08,   2.1353445E-08,   1.6716935E-08
     +,   1.3045330E-08,   1.0147386E-08,   7.8679134E-09
     +,   6.0808127E-09,   4.6845297E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz120 = Yx/0.007
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2658656E-06,   3.5150329E-06
     +,   3.7773843E-06,   4.0530667E-06,   4.3421719E-06
     +,   4.6447376E-06,   4.9607347E-06,   5.2900746E-06
     +,   5.6325889E-06,   5.9880540E-06,   6.3561542E-06
     +,   6.7364995E-06,   7.1286204E-06,   7.5319617E-06
     +,   7.9458923E-06,   8.3696868E-06,   8.8025454E-06
     +,   9.2435848E-06,   9.6918420E-06,   1.0146280E-05
     +,   1.0605791E-05,   1.1069205E-05,   1.1535284E-05
     +,   1.2002778E-05,   1.2470344E-05,   1.2936666E-05
     +,   1.3400395E-05,   1.3860183E-05,   1.4314717E-05
     +,   1.4762722E-05,   1.5202992E-05,   1.5634409E-05
     +,   1.6055976E-05,   1.6466845E-05,   1.6866335E-05
     +,   1.7253993E-05,   1.7629591E-05,   1.7993187E-05
     +,   1.8345167E-05,   1.8686238E-05,   1.9017516E-05
     +,   1.9340519E-05,   1.9657215E-05,   1.9970044E-05
     +,   2.0281936E-05,   2.0596346E-05,   2.0917252E-05
     +,   2.1249163E-05,   2.1597139E-05,   2.1966787E-05
     +,   2.2364242E-05,   2.2796197E-05,   2.3269875E-05
     +,   2.3793087E-05,   2.4374131E-05,   2.5021960E-05
     +,   2.5746103E-05,   2.6556740E-05,   2.7464743E-05
     +,   2.8481740E-05,   2.9620151E-05,   3.0893232E-05
     +,   3.2315005E-05,   3.3900396E-05,   3.5665056E-05
     +,   3.7625021E-05,   3.9796858E-05,   4.2196811E-05
     +,   4.4840850E-05,   4.7743495E-05,   5.0917868E-05
     +,   5.4374072E-05,   5.8119356E-05,   6.2156396E-05
     +,   6.6483582E-05,   7.1094189E-05,   7.5975840E-05
     +,   8.1111015E-05,   8.6477892E-05,   9.2051152E-05
     +,   9.7802673E-05,   1.0370465E-04,   1.0973010E-04
     +,   1.1585661E-04,   1.2206667E-04,   1.2835105E-04
     +,   1.3470871E-04,   1.4114894E-04,   1.4768995E-04
     +,   1.5435970E-04,   1.6119434E-04,   1.6823635E-04
     +,   1.7553347E-04,   1.8313834E-04,   1.9110765E-04
     +,   1.9950260E-04,   2.0839287E-04,   2.1785905E-04
     +,   2.2800120E-04,   2.3894428E-04,   2.5084961E-04
     +,   2.6391965E-04,   2.7840643E-04,   2.9460673E-04
     +,   3.1285427E-04,   3.3349587E-04,   3.5685115E-04
     +,   3.8316144E-04,   4.1252931E-04,   4.4485118E-04
     +,   4.7975633E-04,   5.1657803E-04,   5.5434369E-04
     +,   5.9182895E-04,   6.2764226E-04,   6.6037686E-04
     +,   6.8877521E-04,   7.1192213E-04,   7.2940264E-04
     +,   7.4142218E-04,   7.4884010E-04,   7.5310859E-04
     +,   7.5611030E-04,   7.5990928E-04,   7.6644059E-04
     +,   7.7719160E-04,   7.9292047E-04,   8.1346743E-04
     +,   8.3770120E-04,   8.6360821E-04,   8.8854221E-04
     +,   9.0957008E-04,   9.2389365E-04,   9.2924741E-04
     +,   9.2423178E-04,   9.0851000E-04,   8.8285079E-04
     +,   8.4900868E-04,   8.0946641E-04,   7.6709461E-04
     +,   7.2478649E-04,   6.8511220E-04,   6.5005146E-04
     +,   6.2083272E-04,   5.9788593E-04,   5.8088941E-04
     +,   5.6890718E-04,   5.6057103E-04,   5.5428274E-04
     +,   5.4840848E-04,   5.4144504E-04,   5.3214590E-04
     +,   5.1960035E-04,   5.0326769E-04,   4.8297318E-04
     +,   4.5887619E-04,   4.3141367E-04,   4.0122919E-04
     +,   3.6910261E-04,   3.3588306E-04,   3.0241880E-04
     +,   2.6950720E-04,   2.3785607E-04,   2.0805288E-04
     +,   1.8054710E-04,   1.5564791E-04,   1.3353063E-04
     +,   1.1424689E-04,   9.7741286E-05,   8.3873718E-05
     +,   7.2441799E-05,   6.3200707E-05,   5.5882250E-05
     +,   5.0212293E-05,   4.5924418E-05,   4.2768719E-05
     +,   4.0519189E-05,   3.8977480E-05,   3.7973987E-05
     +,   3.7367259E-05,   3.7042235E-05,   3.6907466E-05
     +,   3.6891881E-05,   3.6941543E-05,   3.7016540E-05
     +,   3.7088124E-05,   3.7136324E-05,   3.7147838E-05
     +,   3.7114372E-05,   3.7031390E-05,   3.6897050E-05
     +,   3.6711430E-05,   3.6476013E-05,   3.6193243E-05
     +,   3.5866189E-05,   3.5498328E-05,   3.5093410E-05
     +,   3.4655299E-05,   3.4187884E-05,   3.3694952E-05
     +,   3.3180229E-05,   3.2647276E-05,   3.2099390E-05
     +,   3.1539646E-05,   3.0970896E-05,   3.0395671E-05
     +,   2.9816198E-05,   2.9234454E-05,   2.8652115E-05
     +,   2.8070548E-05,   2.7490838E-05,   2.6913851E-05
     +,   2.6340216E-05,   2.5770312E-05,   2.5204325E-05
     +,   2.4642311E-05,   2.4084196E-05,   2.3529754E-05
     +,   2.2978671E-05,   2.2430644E-05,   2.1885266E-05
     +,   2.1342130E-05,   2.0800873E-05,   2.0261165E-05
     +,   1.9722678E-05,   1.9185149E-05,   1.8648419E-05
     +,   1.8112405E-05,   1.7577073E-05,   1.7042474E-05
     +,   1.6508786E-05,   1.5976269E-05,   1.5445232E-05
     +,   1.4916056E-05,   1.4389257E-05,   1.3865355E-05
     +,   1.3344928E-05,   1.2828631E-05,   1.2317159E-05
     +,   1.1811198E-05,   1.1311456E-05,   1.0818668E-05
     +,   1.0333581E-05,   9.8568898E-06,   9.3892713E-06
     +,   8.9314044E-06,   8.4839357E-06,   8.0474383E-06
     +,   7.6224396E-06,   7.2094599E-06,   6.8089216E-06
     +,   6.4211949E-06,   6.0466100E-06,   5.6854433E-06
     +,   5.3378812E-06,   5.0040535E-06,   4.6840564E-06
     +,   4.3779200E-06,   4.0856062E-06,   3.8070193E-06
     +,   3.5420383E-06,   3.2904898E-06,   3.0521428E-06
     +,   2.8267282E-06,   2.6139605E-06,   2.4135059E-06
     +,   2.2249990E-06,   2.0480666E-06,   1.8823121E-06
     +,   1.7273129E-06,   1.5826341E-06,   1.4478406E-06
     +,   1.3224918E-06,   1.2061340E-06,   1.0983149E-06
     +,   9.9859517E-07,   9.0652628E-07,   8.2167918E-07
     +,   7.4362185E-07,   6.7194367E-07,   6.0623535E-07
     +,   5.4611019E-07,   4.9118682E-07,   4.4110689E-07
     +,   3.9551992E-07,   3.5409795E-07,   3.1652431E-07
     +,   2.8249974E-07,   2.5174435E-07,   2.2398979E-07
     +,   1.9898819E-07,   1.7650355E-07,   1.5631841E-07
     +,   1.3822724E-07,   1.2204154E-07,   1.0758426E-07
     +,   9.4693476E-08,   8.3218225E-08,   7.3020921E-08
     +,   6.3973914E-08,   5.5961465E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz75 = Yx/0.0107916666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6964281E-05,   1.7035620E-05
     +,   1.7083636E-05,   1.7108132E-05,   1.7109001E-05
     +,   1.7086244E-05,   1.7039956E-05,   1.6970325E-05
     +,   1.6877644E-05,   1.6762286E-05,   1.6624728E-05
     +,   1.6465530E-05,   1.6285336E-05,   1.6084876E-05
     +,   1.5864940E-05,   1.5626407E-05,   1.5370204E-05
     +,   1.5097325E-05,   1.4808815E-05,   1.4505756E-05
     +,   1.4189279E-05,   1.3860542E-05,   1.3520728E-05
     +,   1.3171024E-05,   1.2812656E-05,   1.2446822E-05
     +,   1.2074737E-05,   1.1697600E-05,   1.1316593E-05
     +,   1.0932878E-05,   1.0547588E-05,   1.0161825E-05
     +,   9.7766515E-06,   9.3930876E-06,   9.0121102E-06
     +,   8.6346463E-06,   8.2615661E-06,   7.8936973E-06
     +,   7.5317826E-06,   7.1765494E-06,   6.8286222E-06
     +,   6.4885917E-06,   6.1569808E-06,   5.8342525E-06
     +,   5.5208088E-06,   5.2169962E-06,   4.9231012E-06
     +,   4.6393579E-06,   4.3659479E-06,   4.1030003E-06
     +,   3.8505977E-06,   3.6087820E-06,   3.3775564E-06
     +,   3.1568741E-06,   2.9466878E-06,   2.7468971E-06
     +,   2.5574009E-06,   2.3780863E-06,   2.2088407E-06
     +,   2.0495647E-06,   1.9001845E-06,   1.7606662E-06
     +,   1.6310460E-06,   1.5114348E-06,   1.4020562E-06
     +,   1.3032890E-06,   1.2156825E-06,   1.1400238E-06
     +,   1.0773686E-06,   1.0291179E-06,   9.9706722E-07
     +,   9.8349210E-07,   9.9121746E-07,   1.0237060E-06
     +,   1.0851448E-06,   1.1805378E-06,   1.3157838E-06
     +,   1.4977569E-06,   1.7343898E-06,   2.0347261E-06
     +,   2.4089138E-06,   2.8682834E-06,   3.4252198E-06
     +,   4.0932146E-06,   4.8866000E-06,   5.8205724E-06
     +,   6.9107718E-06,   8.1732724E-06,   9.6239955E-06
     +,   1.1278652E-05,   1.3152284E-05,   1.5258744E-05
     +,   1.7610386E-05,   2.0217851E-05,   2.3089578E-05
     +,   2.6231153E-05,   2.9645611E-05,   3.3332351E-05
     +,   3.7287737E-05,   4.1503859E-05,   4.5969409E-05
     +,   5.0668419E-05,   5.5581357E-05,   6.0684037E-05
     +,   6.5949003E-05,   7.1345770E-05,   7.6841396E-05
     +,   8.2402461E-05,   8.7997447E-05,   9.3599032E-05
     +,   9.9186531E-05,   1.0475060E-04,   1.1029476E-04
     +,   1.1583954E-04,   1.2142239E-04,   1.2709883E-04
     +,   1.3293883E-04,   1.3902392E-04,   1.4543982E-04
     +,   1.5227200E-04,   1.5960092E-04,   1.6750261E-04
     +,   1.7605795E-04,   1.8537400E-04,   1.9561769E-04
     +,   2.0706223E-04,   2.2014588E-04,   2.3552589E-04
     +,   2.5412635E-04,   2.7714772E-04,   3.0603926E-04
     +,   3.4240185E-04,   3.8784550E-04,   4.4378405E-04
     +,   5.1123678E-04,   5.9064390E-04,   6.8174739E-04
     +,   7.8357413E-04,   8.9451089E-04,   1.0124182E-03
     +,   1.1347313E-03,   1.2585187E-03,   1.3804575E-03
     +,   1.4967481E-03,   1.6030598E-03,   1.6946588E-03
     +,   1.7667194E-03,   1.8148675E-03,   1.8358731E-03
     +,   1.8282756E-03,   1.7927741E-03,   1.7322412E-03
     +,   1.6513226E-03,   1.5557040E-03,   1.4512590E-03
     +,   1.3432885E-03,   1.2360016E-03,   1.1323290E-03
     +,   1.0340520E-03,   9.4212400E-04,   8.5700990E-04
     +,   7.7898346E-04,   7.0827728E-04,   6.4508640E-04
     +,   5.8947614E-04,   5.4127839E-04,   5.0001644E-04
     +,   4.6489481E-04,   4.3486388E-04,   4.0874330E-04
     +,   3.8536050E-04,   3.6367335E-04,   3.4285831E-04
     +,   3.2235379E-04,   3.0186161E-04,   2.8130822E-04
     +,   2.6079378E-04,   2.4053223E-04,   2.2079363E-04
     +,   2.0185474E-04,   1.8396589E-04,   1.6732964E-04
     +,   1.5208811E-04,   1.3831996E-04,   1.2604572E-04
     +,   1.1523697E-04,   1.0582522E-04,   9.7712509E-05
     +,   9.0782363E-05,   8.4909028E-05,   7.9963451E-05
     +,   7.5819233E-05,   7.2356692E-05,   6.9464717E-05
     +,   6.7041852E-05,   6.4996973E-05,   6.3249143E-05
     +,   6.1727056E-05,   6.0368344E-05,   5.9119109E-05
     +,   5.7933441E-05,   5.6772718E-05,   5.5605167E-05
     +,   5.4405373E-05,   5.3154046E-05,   5.1837276E-05
     +,   5.0446099E-05,   4.8976202E-05,   4.7427155E-05
     +,   4.5801829E-05,   4.4105891E-05,   4.2347376E-05
     +,   4.0536052E-05,   3.8682803E-05,   3.6799298E-05
     +,   3.4897701E-05,   3.2990203E-05,   3.1088621E-05
     +,   2.9204257E-05,   2.7347880E-05,   2.5529231E-05
     +,   2.3757064E-05,   2.2039214E-05,   2.0382433E-05
     +,   1.8792245E-05,   1.7273102E-05,   1.5828497E-05
     +,   1.4460912E-05,   1.3171781E-05,   1.1961672E-05
     +,   1.0830445E-05,   9.7772345E-06,   8.8004736E-06
     +,   7.8980693E-06,   7.0675596E-06,   6.3060247E-06
     +,   5.6102572E-06,   4.9768764E-06,   4.4023418E-06
     +,   3.8829844E-06,   3.4151021E-06,   2.9950390E-06
     +,   2.6191847E-06,   2.2839931E-06,   1.9860390E-06
     +,   1.7220586E-06,   1.4889422E-06,   1.2837352E-06
     +,   1.1036675E-06,   9.4617155E-07,   8.0884854E-07
     +,   6.8948736E-07,   5.8606730E-07,   4.9674236E-07
     +,   4.1982941E-07,   3.5380737E-07,   2.9731262E-07
     +,   2.4912160E-07,   2.0813975E-07,   1.7339576E-07
     +,   1.4403263E-07,   1.1929463E-07,   9.8517255E-08
     +,   8.1120078E-08,   6.6599462E-08,   5.4517095E-08
     +,   4.4494652E-08,   3.6207162E-08,   2.9375952E-08
     +,   2.3762599E-08,   1.9164302E-08,   1.5409503E-08
     +,   1.2353211E-08,   9.8732711E-09,   7.8672819E-09
     +,   6.2499197E-09,   4.9499400E-09,   3.9084544E-09
     +,   3.0766609E-09,   2.4145039E-09,   1.8890352E-09
     +,   1.4733990E-09,   1.1456704E-09,   8.8810076E-10
     +,   6.8630662E-10,   5.2872956E-10,   4.0607059E-10
     +,   3.1089728E-10,   2.3729335E-10,   1.8055024E-10
     +,   1.3694931E-10,   1.0355283E-10,   7.8056957E-11
     +,   5.8653964E-11,   4.3936802E-11,   3.2809051E-11
     +,   2.4423132E-11,   1.8123473E-11,   1.3406678E-11
     +,   9.8862541E-12,   7.2674288E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz80 = Yx/0.0123846153846154
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4923707E-16,   2.5545982E-16
     +,   4.3486184E-16,   7.3614575E-16,   1.2392576E-15
     +,   2.0746456E-15,   3.4539014E-15,   5.7182152E-15
     +,   9.4143748E-15,   1.5413818E-14,   2.5096522E-14
     +,   4.0635033E-14,   6.5429399E-14,   1.0476809E-13
     +,   1.6682795E-13,   2.6417635E-13,   4.1600902E-13
     +,   6.5147258E-13,   1.0145494E-12,   1.5712149E-12
     +,   2.4198078E-12,   3.7060524E-12,   5.6444736E-12
     +,   8.5491857E-12,   1.2876721E-11,   1.9287377E-11
     +,   2.8729288E-11,   4.2556025E-11,   6.2687550E-11
     +,   9.1830238E-11,   1.3377500E-10,   1.9379744E-10
     +,   2.7919345E-10,   3.9998829E-10,   5.6986643E-10
     +,   8.0739004E-10,   1.1375703E-09,   1.5938767E-09
     +,   2.2208553E-09,   3.0772687E-09,   4.2403050E-09
     +,   5.8104979E-09,   7.9179676E-09,   1.0729963E-08
     +,   1.4459971E-08,   1.9378509E-08,   2.5826035E-08
     +,   3.4227842E-08,   4.5111328E-08,   5.9125689E-08
     +,   7.7063852E-08,   9.9887146E-08,   1.2875107E-07
     +,   1.6503660E-07,   2.1037319E-07,   2.6667746E-07
     +,   3.3617602E-07,   4.2143569E-07,   5.2538803E-07
     +,   6.5134839E-07,   8.0302829E-07,   9.8454143E-07
     +,   1.2003799E-06,   1.4554180E-06,   1.7548646E-06
     +,   2.1041717E-06,   2.5090289E-06,   2.9751716E-06
     +,   3.5083665E-06,   4.1141470E-06,   4.7977892E-06
     +,   5.5639707E-06,   6.4167425E-06,   7.3591355E-06
     +,   8.3931200E-06,   9.5193236E-06,   1.0736754E-05
     +,   1.2042661E-05,   1.3432483E-05,   1.4899646E-05
     +,   1.6435330E-05,   1.8028790E-05,   1.9666981E-05
     +,   2.1335083E-05,   2.3016226E-05,   2.4692166E-05
     +,   2.6343147E-05,   2.7948676E-05,   2.9487523E-05
     +,   3.0938532E-05,   3.2280932E-05,   3.3494740E-05
     +,   3.4561377E-05,   3.5464167E-05,   3.6188714E-05
     +,   3.6723213E-05,   3.7058911E-05,   3.7190257E-05
     +,   3.7115078E-05,   3.6834666E-05,   3.6353707E-05
     +,   3.5680259E-05,   3.4825418E-05,   3.3803248E-05
     +,   3.2630298E-05,   3.1325344E-05,   2.9909152E-05
     +,   2.8404143E-05,   2.6834055E-05,   2.5223930E-05
     +,   2.3600274E-05,   2.1990885E-05,   2.0425579E-05
     +,   1.8936254E-05,   1.7557868E-05,   1.6328626E-05
     +,   1.5290841E-05,   1.4490844E-05,   1.3979043E-05
     +,   1.3808869E-05,   1.4035230E-05,   1.4711829E-05
     +,   1.5887441E-05,   1.7601458E-05,   1.9878647E-05
     +,   2.2723463E-05,   2.6115769E-05,   3.0007019E-05
     +,   3.4321321E-05,   3.8960137E-05,   4.3817650E-05
     +,   4.8806291E-05,   5.3901178E-05,   5.9201619E-05
     +,   6.5013432E-05,   7.1938397E-05,   8.0949845E-05
     +,   9.3417424E-05,   1.1103426E-04,   1.3560454E-04
     +,   1.6868289E-04,   2.1112814E-04,   2.6272034E-04
     +,   3.2205941E-04,   3.8698214E-04,   4.5562518E-04
     +,   5.2787899E-04,   6.0658396E-04,   6.9750636E-04
     +,   8.0733327E-04,   9.3987148E-04,   1.0919818E-03
     +,   1.2516184E-03,   1.3997074E-03,   1.5156597E-03
     +,   1.5843641E-03,   1.6017449E-03,   1.5766392E-03
     +,   1.5282597E-03,   1.4798180E-03,   1.4501555E-03
     +,   1.4465043E-03,   1.4617293E-03,   1.4777740E-03
     +,   1.4738753E-03,   1.4354852E-03,   1.3596963E-03
     +,   1.2551543E-03,   1.1374010E-03,   1.0225276E-03
     +,   9.2206971E-04,   8.4081374E-04,   7.7754050E-04
     +,   7.2748249E-04,   6.8490958E-04,   6.4478687E-04
     +,   6.0335430E-04,   5.5806828E-04,   5.0746993E-04
     +,   4.5124051E-04,   3.9034197E-04,   3.2697816E-04
     +,   2.6421490E-04,   2.0532910E-04,   1.5311952E-04
     +,   1.0940272E-04,   7.4817362E-05,   4.8940467E-05
     +,   3.0609259E-05,   1.8301302E-05,   1.0459521E-05
     +,   5.7138350E-06,   2.9836715E-06,   1.4894212E-06
     +,   7.1080478E-07,   3.2432041E-07,   1.4149379E-07
     +,   5.9032459E-08,   2.3553847E-08,   8.9882430E-09
     +,   3.2807990E-09,   1.1455855E-09,   3.8268261E-10
     +,   1.2230075E-10,   3.7399181E-11,   1.0943341E-11
     +,   3.0640731E-12,   8.2101416E-13,   2.1054461E-13
     +,   5.1674834E-14,   1.2138060E-14,   2.7288918E-15
     +,   5.8724964E-16,   1.2096108E-16,   2.3847428E-17
     +,   4.5004039E-18,   8.1310319E-19,   1.4068725E-19
     +,   2.3336969E-20,   3.7259208E-21,   5.8007484E-22
     +,   9.1951413E-23,   1.6727933E-23,   4.2231582E-24
     +,   1.5410024E-24,   6.8829805E-25,   3.2840149E-25
     +,   1.5890760E-25,   7.6839779E-26,   3.6991226E-26
     +,   1.7713718E-26,   8.4360562E-27,   3.9953717E-27
     +,   1.8817004E-27,   8.8133308E-28,   4.1049945E-28
     +,   1.9013398E-28,   8.7576597E-29,   4.0115836E-29
     +,   1.8273560E-29,   8.2776755E-30,   3.7288498E-30
     +,   1.6704717E-30,   7.4419123E-31,   3.2969161E-31
     +,   1.4524822E-31,   6.3637026E-32,   2.7726503E-32
     +,   1.2013003E-32,   5.1761571E-33,   2.2179136E-33
     +,   9.4504621E-34,   4.0044790E-34,   1.6874855E-34
     +,   7.0715077E-35,   2.9468536E-35,   1.2212079E-35
     +,   5.0329411E-36,   2.0626800E-36,   8.4065245E-37
     +,   3.4071065E-37,   1.3732492E-37,   5.5042421E-38
     +,   2.1939008E-38,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz85 = Yx/0.00991666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.6497411E-06,   5.9548979E-06
     +,   6.2698423E-06,   6.5944391E-06,   6.9285238E-06
     +,   7.2718972E-06,   7.6243323E-06,   7.9855663E-06
     +,   8.3553023E-06,   8.7332273E-06,   9.1189831E-06
     +,   9.5121850E-06,   9.9124200E-06,   1.0319248E-05
     +,   1.0732203E-05,   1.1150792E-05,   1.1574498E-05
     +,   1.2002786E-05,   1.2435097E-05,   1.2870855E-05
     +,   1.3309468E-05,   1.3750328E-05,   1.4192808E-05
     +,   1.4636299E-05,   1.5080134E-05,   1.5523690E-05
     +,   1.5966309E-05,   1.6407337E-05,   1.6846123E-05
     +,   1.7282015E-05,   1.7714359E-05,   1.8142517E-05
     +,   1.8565845E-05,   1.8983712E-05,   1.9395491E-05
     +,   1.9800571E-05,   2.0198346E-05,   2.0588221E-05
     +,   2.0969626E-05,   2.1341975E-05,   2.1704736E-05
     +,   2.2057355E-05,   2.2399316E-05,   2.2730108E-05
     +,   2.3049241E-05,   2.3356244E-05,   2.3650662E-05
     +,   2.3932074E-05,   2.4200070E-05,   2.4454275E-05
     +,   2.4694345E-05,   2.4919977E-05,   2.5130907E-05
     +,   2.5326934E-05,   2.5507901E-05,   2.5673744E-05
     +,   2.5824478E-05,   2.5960224E-05,   2.6081232E-05
     +,   2.6187892E-05,   2.6280783E-05,   2.6360676E-05
     +,   2.6428585E-05,   2.6485810E-05,   2.6533964E-05
     +,   2.6575028E-05,   2.6611420E-05,   2.6646005E-05
     +,   2.6682195E-05,   2.6723988E-05,   2.6776032E-05
     +,   2.6843676E-05,   2.6933036E-05,   2.7051043E-05
     +,   2.7205460E-05,   2.7404985E-05,   2.7659171E-05
     +,   2.7978498E-05,   2.8374350E-05,   2.8858974E-05
     +,   2.9445362E-05,   3.0147266E-05,   3.0978939E-05
     +,   3.1955140E-05,   3.3090750E-05,   3.4400804E-05
     +,   3.5899935E-05,   3.7602447E-05,   3.9521623E-05
     +,   4.1669769E-05,   4.4057761E-05,   4.6694509E-05
     +,   4.9586768E-05,   5.2738986E-05,   5.6152890E-05
     +,   5.9826838E-05,   6.3756372E-05,   6.7933121E-05
     +,   7.2345611E-05,   7.6978191E-05,   8.1812199E-05
     +,   8.6824693E-05,   9.1990027E-05,   9.7278564E-05
     +,   1.0265822E-04,   1.0809428E-04,   1.1354933E-04
     +,   1.1898406E-04,   1.2435808E-04,   1.2962992E-04
     +,   1.3475711E-04,   1.3969780E-04,   1.4440985E-04
     +,   1.4885257E-04,   1.5298610E-04,   1.5677276E-04
     +,   1.6017655E-04,   1.6316453E-04,   1.6570621E-04
     +,   1.6777462E-04,   1.6934639E-04,   1.7040189E-04
     +,   1.7092576E-04,   1.7090711E-04,   1.7033961E-04
     +,   1.6922195E-04,   1.6755755E-04,   1.6535522E-04
     +,   1.6262854E-04,   1.5939660E-04,   1.5568294E-04
     +,   1.5151643E-04,   1.4692984E-04,   1.4196070E-04
     +,   1.3664973E-04,   1.3104084E-04,   1.2518090E-04
     +,   1.1911886E-04,   1.1290489E-04,   1.0659021E-04
     +,   1.0022763E-04,   9.3871378E-05,   8.7577791E-05
     +,   8.1408100E-05,   7.5432843E-05,   6.9736801E-05
     +,   6.4428670E-05,   5.9653761E-05,   5.5610082E-05
     +,   5.2568113E-05,   5.0894574E-05,   5.1076884E-05
     +,   5.3745069E-05,   5.9687911E-05,   6.9856964E-05
     +,   8.5352171E-05,   1.0738748E-04,   1.3723932E-04
     +,   1.7618161E-04,   2.2541912E-04,   2.8605523E-04
     +,   3.5908882E-04,   4.4544809E-04,   5.4605689E-04
     +,   6.6187890E-04,   7.9385517E-04,   9.4266928E-04
     +,   1.1083204E-03,   1.2895276E-03,   1.4830432E-03
     +,   1.6830921E-03,   1.8811930E-03,   2.0665240E-03
     +,   2.2268812E-03,   2.3501634E-03,   2.4261707E-03
     +,   2.4482496E-03,   2.4144787E-03,   2.3281053E-03
     +,   2.1970966E-03,   2.0329345E-03,   1.8489463E-03
     +,   1.6584735E-03,   1.4732397E-03,   1.3022216E-03
     +,   1.1510946E-03,   1.0222326E-03,   9.1516861E-04
     +,   8.2736398E-04,   7.5507641E-04,   6.9415703E-04
     +,   6.4071745E-04,   5.9157307E-04,   5.4445473E-04
     +,   4.9802702E-04,   4.5176758E-04,   4.0576691E-04
     +,   3.6049876E-04,   3.1661135E-04,   2.7477305E-04
     +,   2.3557135E-04,   1.9945731E-04,   1.6672704E-04
     +,   1.3753223E-04,   1.1190082E-04,   8.9752284E-05
     +,   7.0921909E-05,   5.5180113E-05,   4.2248292E-05
     +,   3.1814849E-05,   2.3552635E-05,   1.7134442E-05
     +,   1.2245697E-05,   8.5952897E-06,   5.9238773E-06
     +,   4.0082687E-06,   2.6623763E-06,   1.7358172E-06
     +,   1.1107871E-06,   6.9766833E-07,   4.3007566E-07
     +,   2.6020044E-07,   1.5450604E-07,   9.0046498E-08
     +,   5.1507371E-08,   2.8916771E-08,   1.5934049E-08
     +,   8.6183496E-09,   4.5757726E-09,   2.3850242E-09
     +,   1.2207214E-09,   6.1379984E-10,   3.0341871E-10
     +,   1.4765619E-10,   7.0918917E-11,   3.3769376E-11
     +,   1.6068607E-11,   7.7438906E-12,   3.8584335E-12
     +,   2.0411374E-12,   1.1754093E-12,   7.4492430E-13
     +,   5.1468416E-13,   3.7897945E-13,   2.9043993E-13
     +,   2.2760019E-13,   1.8037310E-13,   1.4366880E-13
     +,   1.1463852E-13,   9.1490448E-14,   7.2970194E-14
     +,   5.8139928E-14,   4.6268941E-14,   3.6775470E-14
     +,   2.9191808E-14,   2.3141413E-14,   1.8320708E-14
     +,   1.4485138E-14,   1.1437372E-14,   9.0188358E-15
     +,   7.1022637E-15,   5.5856169E-15,   4.3869899E-15
     +,   3.4409843E-15,   2.6954102E-15,   2.1085837E-15
     +,   1.6473106E-15,   1.2852390E-15,   1.0014232E-15
     +,   7.7924845E-16,   6.0555285E-16,   4.6995119E-16
     +,   3.6423253E-16,   2.8192163E-16,   2.1792027E-16
     +,   1.6822593E-16,   1.2969014E-16,   9.9849978E-17
     +,   7.6772988E-17,   5.8951528E-17,   4.5206701E-17
     +,   3.4620705E-17,   2.6478146E-17,   2.0223959E-17
     +,   1.5426389E-17,   1.1751370E-17,   8.9399745E-18
     +,   6.7920797E-18,   5.1534270E-18,   3.9048980E-18
     +,   2.9549398E-18,   2.2330938E-18,   1.6853549E-18
     +,   1.2702677E-18,   9.5614996E-19,   7.1874587E-19
     +,   5.3957576E-19,   4.0452678E-19,   3.0287944E-19
     +,   2.2647014E-19,   1.6911346E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz90 = Yx/0.0137307692307692
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.1913656E-07,   5.8557146E-07
     +,   6.5919903E-07,   7.4061381E-07,   8.3043466E-07
     +,   9.2930389E-07,   1.0378834E-06,   1.1568527E-06
     +,   1.2869015E-06,   1.4287355E-06,   1.5830586E-06
     +,   1.7505749E-06,   1.9319828E-06,   2.1279645E-06
     +,   2.3391833E-06,   2.5662723E-06,   2.8098311E-06
     +,   3.0704098E-06,   3.3485089E-06,   3.6445629E-06
     +,   3.9589354E-06,   4.2919091E-06,   4.6436680E-06
     +,   5.0143217E-06,   5.4038273E-06,   5.8120700E-06
     +,   6.2387821E-06,   6.6835705E-06,   7.1459035E-06
     +,   7.6251081E-06,   8.1203589E-06,   8.6306818E-06
     +,   9.1549482E-06,   9.6918830E-06,   1.0240046E-05
     +,   1.0797863E-05,   1.1363611E-05,   1.1935421E-05
     +,   1.2511333E-05,   1.3089207E-05,   1.3666860E-05
     +,   1.4241988E-05,   1.4812204E-05,   1.5375083E-05
     +,   1.5928144E-05,   1.6468890E-05,   1.6994833E-05
     +,   1.7503489E-05,   1.7992439E-05,   1.8459315E-05
     +,   1.8901845E-05,   1.9317869E-05,   1.9705354E-05
     +,   2.0062453E-05,   2.0387446E-05,   2.0678857E-05
     +,   2.0935397E-05,   2.1156013E-05,   2.1339900E-05
     +,   2.1486507E-05,   2.1595552E-05,   2.1667025E-05
     +,   2.1701189E-05,   2.1698603E-05,   2.1660093E-05
     +,   2.1586760E-05,   2.1479980E-05,   2.1341393E-05
     +,   2.1172877E-05,   2.0976560E-05,   2.0754764E-05
     +,   2.0510039E-05,   2.0245083E-05,   1.9962779E-05
     +,   1.9666119E-05,   1.9358187E-05,   1.9042174E-05
     +,   1.8721317E-05,   1.8398852E-05,   1.8078008E-05
     +,   1.7762002E-05,   1.7453955E-05,   1.7156923E-05
     +,   1.6873810E-05,   1.6607404E-05,   1.6360298E-05
     +,   1.6134903E-05,   1.5933405E-05,   1.5757760E-05
     +,   1.5609670E-05,   1.5490561E-05,   1.5401587E-05
     +,   1.5343610E-05,   1.5317188E-05,   1.5322570E-05
     +,   1.5359712E-05,   1.5428257E-05,   1.5527539E-05
     +,   1.5656609E-05,   1.5814208E-05,   1.5998832E-05
     +,   1.6208680E-05,   1.6441723E-05,   1.6695691E-05
     +,   1.6968106E-05,   1.7256329E-05,   1.7557515E-05
     +,   1.7868693E-05,   1.8186796E-05,   1.8508677E-05
     +,   1.8831091E-05,   1.9150822E-05,   1.9464598E-05
     +,   1.9769228E-05,   2.0061540E-05,   2.0338477E-05
     +,   2.0597066E-05,   2.0834505E-05,   2.1048123E-05
     +,   2.1235453E-05,   2.1394239E-05,   2.1522428E-05
     +,   2.1618212E-05,   2.1680053E-05,   2.1706657E-05
     +,   2.1697013E-05,   2.1650385E-05,   2.1566320E-05
     +,   2.1444637E-05,   2.1285445E-05,   2.1089108E-05
     +,   2.0856278E-05,   2.0587831E-05,   2.0284911E-05
     +,   1.9948873E-05,   1.9581266E-05,   1.9183855E-05
     +,   1.8758579E-05,   1.8307504E-05,   1.7832808E-05
     +,   1.7336826E-05,   1.6821959E-05,   1.6290664E-05
     +,   1.5745440E-05,   1.5188909E-05,   1.4623734E-05
     +,   1.4052775E-05,   1.3479306E-05,   1.2907370E-05
     +,   1.2342401E-05,   1.1792397E-05,   1.1269729E-05
     +,   1.0793740E-05,   1.0394377E-05,   1.0116875E-05
     +,   1.0027175E-05,   1.0217144E-05,   1.0808594E-05
     +,   1.1954271E-05,   1.3833942E-05,   1.6645317E-05
     +,   2.0590625E-05,   2.5863659E-05,   3.2648113E-05
     +,   4.1142637E-05,   5.1629642E-05,   6.4604159E-05
     +,   8.0968741E-05,   1.0227603E-04,   1.3096457E-04
     +,   1.7049997E-04,   2.2531515E-04,   3.0045045E-04
     +,   4.0083792E-04,   5.3027674E-04,   6.9031952E-04
     +,   8.7928743E-04,   1.0917265E-03,   1.3185659E-03
     +,   1.5480120E-03,   1.7669952E-03,   1.9628729E-03
     +,   2.1250180E-03,   2.2458984E-03,   2.3214119E-03
     +,   2.3505657E-03,   2.3347493E-03,   2.2769540E-03
     +,   2.1812958E-03,   2.0529693E-03,   1.8984055E-03
     +,   1.7253479E-03,   1.5425342E-03,   1.3589037E-03
     +,   1.1825840E-03,   1.0200422E-03,   8.7566092E-04
     +,   7.5175223E-04,   6.4889016E-04,   5.6634122E-04
     +,   5.0240342E-04,   4.5462744E-04,   4.2000142E-04
     +,   3.9518112E-04,   3.7678055E-04,   3.6168974E-04
     +,   3.4736155E-04,   3.3199132E-04,   3.1456442E-04
     +,   2.9477919E-04,   2.7288738E-04,   2.4949922E-04
     +,   2.2539195E-04,   2.0135251E-04,   1.7807225E-04
     +,   1.5608979E-04,   1.3577087E-04,   1.1731724E-04
     +,   1.0079507E-04,   8.6169806E-05,   7.3336349E-05
     +,   6.2149549E-05,   5.2447405E-05,   4.4065797E-05
     +,   3.6848243E-05,   3.0651907E-05,   2.5349966E-05
     +,   2.0830807E-05,   1.6996448E-05,   1.3760984E-05
     +,   1.1048733E-05,   8.7921853E-06,   6.9305393E-06
     +,   5.4089073E-06,   4.1777798E-06,   3.1923369E-06
     +,   2.4124297E-06,   1.8024646E-06,   1.3312134E-06
     +,   9.7164695E-07,   7.0076698E-07,   4.9933226E-07
     +,   3.5149111E-07,   2.4440214E-07,   1.6785170E-07
     +,   1.1385643E-07,   7.6275931E-08,   5.0465641E-08
     +,   3.2973521E-08,   2.1276506E-08,   1.3557822E-08
     +,   8.5314733E-09,   5.3015983E-09,   3.2534779E-09
     +,   1.9717084E-09,   1.1800200E-09,   6.9743722E-10
     +,   4.0710915E-10,   2.3470406E-10,   1.3364640E-10
     +,   7.5175040E-11,   4.1777779E-11,   2.2943774E-11
     +,   1.2455821E-11,   6.6882207E-12,   3.5547650E-12
     +,   1.8722994E-12,   9.7900930E-13,   5.0957350E-13
     +,   2.6504501E-13,   1.3852335E-13,   7.3295841E-14
     +,   3.9631852E-14,   2.2122742E-14,   1.2864482E-14
     +,   7.8352708E-15,   4.9978616E-15,   3.3214116E-15
     +,   2.2805238E-15,   1.6033867E-15,   1.1453017E-15
     +,   8.2615914E-16,   5.9924659E-16,   4.3582632E-16
     +,   3.1723721E-16,   2.3085068E-16,   1.6782071E-16
     +,   1.2182731E-16,   8.8293272E-17,   6.3874371E-17
     +,   4.6122483E-17,   3.3239767E-17,   2.3908901E-17
     +,   1.7163323E-17,   1.2296780E-17,   8.7925767E-18
     +,   6.2745806E-18,   4.4687721E-18,   3.1763897E-18
     +,   2.2532737E-18,   1.5952825E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ttz95 = Yx/0.01148
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4585566E-05,   4.5623325E-05
     +,   4.6679626E-05,   4.7755762E-05,   4.8853093E-05
     +,   4.9973041E-05,   5.1117160E-05,   5.2287050E-05
     +,   5.3484415E-05,   5.4711032E-05,   5.5968707E-05
     +,   5.7259334E-05,   5.8584788E-05,   5.9947037E-05
     +,   6.1348030E-05,   6.2789724E-05,   6.4274049E-05
     +,   6.5802917E-05,   6.7378169E-05,   6.9001588E-05
     +,   7.0674876E-05,   7.2399598E-05,   7.4177166E-05
     +,   7.6008961E-05,   7.7895893E-05,   7.9839025E-05
     +,   8.1838938E-05,   8.3896099E-05,   8.6010594E-05
     +,   8.8182300E-05,   9.0410751E-05,   9.2695140E-05
     +,   9.5034266E-05,   9.7426702E-05,   9.9870442E-05
     +,   1.0236323E-04,   1.0490236E-04,   1.0748473E-04
     +,   1.1010688E-04,   1.1276477E-04,   1.1545418E-04
     +,   1.1817038E-04,   1.2090823E-04,   1.2366232E-04
     +,   1.2642685E-04,   1.2919570E-04,   1.3196253E-04
     +,   1.3472064E-04,   1.3746317E-04,   1.4018323E-04
     +,   1.4287358E-04,   1.4552707E-04,   1.4813645E-04
     +,   1.5069473E-04,   1.5319469E-04,   1.5562955E-04
     +,   1.5799260E-04,   1.6027754E-04,   1.6247845E-04
     +,   1.6458968E-04,   1.6660625E-04,   1.6852363E-04
     +,   1.7033792E-04,   1.7204597E-04,   1.7364527E-04
     +,   1.7513413E-04,   1.7651170E-04,   1.7777787E-04
     +,   1.7893359E-04,   1.7998044E-04,   1.8092131E-04
     +,   1.8175958E-04,   1.8249983E-04,   1.8314729E-04
     +,   1.8370834E-04,   1.8418999E-04,   1.8459998E-04
     +,   1.8494691E-04,   1.8523996E-04,   1.8548897E-04
     +,   1.8570402E-04,   1.8589587E-04,   1.8607540E-04
     +,   1.8625389E-04,   1.8644253E-04,   1.8665260E-04
     +,   1.8689515E-04,   1.8718130E-04,   1.8752152E-04
     +,   1.8792621E-04,   1.8840526E-04,   1.8896785E-04
     +,   1.8962276E-04,   1.9037812E-04,   1.9124156E-04
     +,   1.9221980E-04,   1.9331927E-04,   1.9454557E-04
     +,   1.9590397E-04,   1.9739907E-04,   1.9903532E-04
     +,   2.0081662E-04,   2.0274680E-04,   2.0482956E-04
     +,   2.0706846E-04,   2.0946733E-04,   2.1202993E-04
     +,   2.1476019E-04,   2.1766256E-04,   2.2074155E-04
     +,   2.2400171E-04,   2.2744820E-04,   2.3108581E-04
     +,   2.3491969E-04,   2.3895421E-04,   2.4319396E-04
     +,   2.4764231E-04,   2.5230212E-04,   2.5717460E-04
     +,   2.6225980E-04,   2.6755582E-04,   2.7305845E-04
     +,   2.7876120E-04,   2.8465502E-04,   2.9072841E-04
     +,   2.9696652E-04,   3.0335219E-04,   3.0986505E-04
     +,   3.1648311E-04,   3.2318148E-04,   3.2993458E-04
     +,   3.3671557E-04,   3.4349738E-04,   3.5025383E-04
     +,   3.5696095E-04,   3.6359759E-04,   3.7014612E-04
     +,   3.7659422E-04,   3.8293592E-04,   3.8917255E-04
     +,   3.9531296E-04,   4.0137494E-04,   4.0738547E-04
     +,   4.1338074E-04,   4.1940523E-04,   4.2551276E-04
     +,   4.3176458E-04,   4.3822793E-04,   4.4497492E-04
     +,   4.5208036E-04,   4.5962149E-04,   4.6767268E-04
     +,   4.7630610E-04,   4.8558938E-04,   4.9558474E-04
     +,   5.0634652E-04,   5.1792356E-04,   5.3036073E-04
     +,   5.4370140E-04,   5.5799173E-04,   5.7328871E-04
     +,   5.8966927E-04,   6.0723792E-04,   6.2614109E-04
     +,   6.4657861E-04,   6.6881429E-04,   6.9318432E-04
     +,   7.2010036E-04,   7.5005169E-04,   7.8359462E-04
     +,   8.2133408E-04,   8.6390314E-04,   9.1194356E-04
     +,   9.6608198E-04,   1.0269120E-03,   1.0950068E-03
     +,   1.1709416E-03,   1.2553275E-03,   1.3488836E-03
     +,   1.4525158E-03,   1.5673970E-03,   1.6950417E-03
     +,   1.8374018E-03,   1.9969996E-03,   2.1770890E-03
     +,   2.3818749E-03,   2.6168246E-03,   2.8889813E-03
     +,   3.2071359E-03,   3.5816329E-03,   4.0236143E-03
     +,   4.5432351E-03,   5.1467204E-03,   5.8328840E-03
     +,   6.5902318E-03,   7.3969336E-03,   8.2259923E-03
     +,   9.0567144E-03,   9.8895589E-03,   1.0757384E-02
     +,   1.1723504E-02,   1.2861446E-02,   1.4225266E-02
     +,   1.5834305E-02,   1.7691409E-02,   1.9817919E-02
     +,   2.2253882E-02,   2.4995655E-02,   2.7927697E-02
     +,   3.0854313E-02,   3.3641506E-02,   3.6293462E-02
     +,   3.8810510E-02,   4.1002866E-02,   4.2559125E-02
     +,   4.3326035E-02,   4.3503281E-02,   4.3508772E-02
     +,   4.3498863E-02,   4.3106992E-02,   4.1922752E-02
     +,   4.0068883E-02,   3.8002022E-02,   3.5941318E-02
     +,   3.3785064E-02,   3.1441376E-02,   2.8986501E-02
     +,   2.6552590E-02,   2.4217393E-02,   2.2003718E-02
     +,   1.9915214E-02,   1.7961795E-02,   1.6169906E-02
     +,   1.4571443E-02,   1.3178818E-02,   1.1971139E-02
     +,   1.0906169E-02,   9.9443980E-03,   9.0653263E-03
     +,   8.2683815E-03,   7.5632310E-03,   6.9578262E-03
     +,   6.4505679E-03,   6.0289758E-03,   5.6734942E-03
     +,   5.3630983E-03,   5.0798901E-03,   4.8111919E-03
     +,   4.5494423E-03,   4.2908201E-03,   4.0336107E-03
     +,   3.7771475E-03,   3.5213784E-03,   3.2667755E-03
     +,   3.0144176E-03,   2.7660090E-03,   2.5237526E-03
     +,   2.2900747E-03,   2.0673254E-03,   1.8575364E-03
     +,   1.6622684E-03,   1.4825171E-03,   1.3187132E-03
     +,   1.1707842E-03,   1.0382637E-03,   9.2035328E-04
     +,   8.1603299E-04,   7.2415167E-04,   6.4348499E-04
     +,   5.7279243E-04,   5.1086931E-04,   4.5658488E-04
     +,   4.0890128E-04,   3.6688670E-04,   3.2972623E-04
     +,   2.9672388E-04,   2.6728844E-04,   2.4093165E-04
     +,   2.1724821E-04,   1.9590960E-04,   1.7664378E-04
     +,   1.5923000E-04,   1.4348186E-04,   1.2924409E-04
     +,   1.1638090E-04,   1.0477452E-04,   9.4317882E-05
     +,   8.4913532E-05,   7.6472177E-05,   6.8909510E-05
     +,   6.2147592E-05,   5.6112447E-05,   5.0735587E-05
     +,   4.5952373E-05,   4.1703352E-05,   3.7932929E-05
     +,   3.4590517E-05,   3.1629363E-05,   2.9007320E-05
     +,   2.6685902E-05,   2.4630766E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz100 = Yx/0.306104166666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8581737E-05,   1.9291561E-05
     +,   2.0024570E-05,   2.0781306E-05,   2.1562313E-05
     +,   2.2368140E-05,   2.3199324E-05,   2.4056400E-05
     +,   2.4939895E-05,   2.5850361E-05,   2.6788315E-05
     +,   2.7754266E-05,   2.8748727E-05,   2.9772200E-05
     +,   3.0825187E-05,   3.1908174E-05,   3.3021650E-05
     +,   3.4166096E-05,   3.5341996E-05,   3.6549853E-05
     +,   3.7790167E-05,   3.9063445E-05,   4.0370262E-05
     +,   4.1711231E-05,   4.3086919E-05,   4.4498116E-05
     +,   4.5945588E-05,   4.7430214E-05,   4.8953036E-05
     +,   5.0515206E-05,   5.2118048E-05,   5.3763095E-05
     +,   5.5452074E-05,   5.7186997E-05,   5.8970109E-05
     +,   6.0803945E-05,   6.2691397E-05,   6.4635620E-05
     +,   6.6640248E-05,   6.8709021E-05,   7.0846312E-05
     +,   7.3056661E-05,   7.5344949E-05,   7.7716359E-05
     +,   8.0176367E-05,   8.2730527E-05,   8.5384585E-05
     +,   8.8144305E-05,   9.1015303E-05,   9.4003059E-05
     +,   9.7112657E-05,   1.0034873E-04,   1.0371517E-04
     +,   1.0721525E-04,   1.1085088E-04,   1.1462320E-04
     +,   1.1853161E-04,   1.2257414E-04,   1.2674709E-04
     +,   1.3104477E-04,   1.3545956E-04,   1.3998173E-04
     +,   1.4459903E-04,   1.4929737E-04,   1.5406030E-04
     +,   1.5886874E-04,   1.6370209E-04,   1.6853699E-04
     +,   1.7334898E-04,   1.7811131E-04,   1.8279649E-04
     +,   1.8737547E-04,   1.9181916E-04,   1.9609748E-04
     +,   2.0018127E-04,   2.0404180E-04,   2.0765128E-04
     +,   2.1098343E-04,   2.1401448E-04,   2.1672291E-04
     +,   2.1909003E-04,   2.2110052E-04,   2.2274279E-04
     +,   2.2400908E-04,   2.2489576E-04,   2.2540356E-04
     +,   2.2553759E-04,   2.2530701E-04,   2.2472568E-04
     +,   2.2381125E-04,   2.2258534E-04,   2.2107323E-04
     +,   2.1930320E-04,   2.1730650E-04,   2.1511658E-04
     +,   2.1276889E-04,   2.1029991E-04,   2.0774717E-04
     +,   2.0514801E-04,   2.0253999E-04,   1.9995928E-04
     +,   1.9744119E-04,   1.9501892E-04,   1.9272383E-04
     +,   1.9058457E-04,   1.8862706E-04,   1.8687428E-04
     +,   1.8534611E-04,   1.8405901E-04,   1.8302634E-04
     +,   1.8225836E-04,   1.8176189E-04,   1.8154111E-04
     +,   1.8159726E-04,   1.8192902E-04,   1.8253307E-04
     +,   1.8340384E-04,   1.8453422E-04,   1.8591572E-04
     +,   1.8753899E-04,   1.8939373E-04,   1.9146937E-04
     +,   1.9375511E-04,   1.9624009E-04,   1.9891404E-04
     +,   2.0176667E-04,   2.0478862E-04,   2.0797054E-04
     +,   2.1130430E-04,   2.1478176E-04,   2.1839561E-04
     +,   2.2213865E-04,   2.2600393E-04,   2.2998443E-04
     +,   2.3407293E-04,   2.3826181E-04,   2.4254269E-04
     +,   2.4690598E-04,   2.5134138E-04,   2.5583719E-04
     +,   2.6038007E-04,   2.6495510E-04,   2.6954620E-04
     +,   2.7413599E-04,   2.7870521E-04,   2.8323443E-04
     +,   2.8770370E-04,   2.9209300E-04,   2.9638328E-04
     +,   3.0055753E-04,   3.0460188E-04,   3.0850607E-04
     +,   3.1226559E-04,   3.1588334E-04,   3.1937103E-04
     +,   3.2275106E-04,   3.2605851E-04,   3.2934317E-04
     +,   3.3267247E-04,   3.3613152E-04,   3.3982730E-04
     +,   3.4388914E-04,   3.4847000E-04,   3.5374778E-04
     +,   3.5992512E-04,   3.6723001E-04,   3.7591255E-04
     +,   3.8624438E-04,   3.9851631E-04,   4.1303449E-04
     +,   4.3011736E-04,   4.5009441E-04,   4.7330747E-04
     +,   5.0011463E-04,   5.3089345E-04,   5.6605908E-04
     +,   6.0608186E-04,   6.5150496E-04,   7.0297194E-04
     +,   7.6125347E-04,   8.2726346E-04,   9.0206129E-04
     +,   9.8684407E-04,   1.0829242E-03,   1.1916814E-03
     +,   1.3145002E-03,   1.4527238E-03,   1.6076346E-03
     +,   1.7804551E-03,   1.9723859E-03,   2.1847510E-03
     +,   2.4191407E-03,   2.6775612E-03,   2.9625522E-03
     +,   3.2771267E-03,   3.6243135E-03,   4.0061483E-03
     +,   4.4222157E-03,   4.8680962E-03,   5.3347345E-03
     +,   5.8102645E-03,   6.2856143E-03,   6.7634773E-03
     +,   7.2672381E-03,   7.8438772E-03,   8.5551823E-03
     +,   9.4565600E-03,   1.0571163E-02,   1.1873008E-02
     +,   1.3291040E-02,   1.4741271E-02,   1.6187131E-02
     +,   1.7708993E-02,   1.9527871E-02,   2.1917028E-02
     +,   2.5015678E-02,   2.8679917E-02,   3.2502551E-02
     +,   3.5991490E-02,   3.8801733E-02,   4.0864490E-02
     +,   4.2290311E-02,   4.3184623E-02,   4.3611430E-02
     +,   4.3642603E-02,   4.3381859E-02,   4.3005690E-02
     +,   4.2661678E-02,   4.2144574E-02,   4.0899765E-02
     +,   3.8657278E-02,   3.5832193E-02,   3.3006981E-02
     +,   3.0323219E-02,   2.7647605E-02,   2.5010811E-02
     +,   2.2602729E-02,   2.0516001E-02,   1.8700339E-02
     +,   1.7101284E-02,   1.5721975E-02,   1.4564027E-02
     +,   1.3579224E-02,   1.2691552E-02,   1.1839761E-02
     +,   1.0992018E-02,   1.0137928E-02,   9.2805745E-03
     +,   8.4338663E-03,   7.6183742E-03,   6.8535316E-03
     +,   6.1512073E-03,   5.5143372E-03,   4.9396437E-03
     +,   4.4211810E-03,   3.9527100E-03,   3.5285517E-03
     +,   3.1436791E-03,   2.7937382E-03,   2.4751506E-03
     +,   2.1851829E-03,   1.9218052E-03,   1.6834855E-03
     +,   1.4689497E-03,   1.2770041E-03,   1.1063622E-03
     +,   9.5562497E-04,   8.2329084E-04,   7.0778257E-04
     +,   6.0748128E-04,   5.2077876E-04,   4.4611731E-04
     +,   3.8201286E-04,   3.2707836E-04,   2.8004724E-04
     +,   2.3979091E-04,   2.0531366E-04,   1.7576064E-04
     +,   1.5040042E-04,   1.2862013E-04,   1.0990297E-04
     +,   9.3818264E-05,   8.0001155E-05,   6.8144196E-05
     +,   5.7982528E-05,   4.9288679E-05,   4.1863757E-05
     +,   3.5533769E-05,   3.0146719E-05,   2.5568539E-05
     +,   2.1682561E-05,   1.8386616E-05,   1.5592565E-05
     +,   1.3224098E-05,   1.1216113E-05,   9.5128671E-06
     +,   8.0673044E-06,   6.8394720E-06,   5.7958878E-06
     +,   4.9082582E-06,   4.1529406E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz102 = Yx/0.301729166666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3329007E-05,   7.5999269E-05
     +,   7.8693432E-05,   8.1407139E-05,   8.4136016E-05
     +,   8.6875451E-05,   8.9620829E-05,   9.2367438E-05
     +,   9.5110452E-05,   9.7845223E-05,   1.0056685E-04
     +,   1.0327058E-04,   1.0595172E-04,   1.0860561E-04
     +,   1.1122770E-04,   1.1381353E-04,   1.1635881E-04
     +,   1.1885939E-04,   1.2131131E-04,   1.2371072E-04
     +,   1.2605416E-04,   1.2833823E-04,   1.3055978E-04
     +,   1.3271609E-04,   1.3480439E-04,   1.3682249E-04
     +,   1.3876832E-04,   1.4064011E-04,   1.4243637E-04
     +,   1.4415596E-04,   1.4579792E-04,   1.4736174E-04
     +,   1.4884707E-04,   1.5025387E-04,   1.5158248E-04
     +,   1.5283341E-04,   1.5400758E-04,   1.5510610E-04
     +,   1.5613035E-04,   1.5708210E-04,   1.5796332E-04
     +,   1.5877622E-04,   1.5952338E-04,   1.6020764E-04
     +,   1.6083206E-04,   1.6139995E-04,   1.6191501E-04
     +,   1.6238120E-04,   1.6280272E-04,   1.6318401E-04
     +,   1.6352997E-04,   1.6384562E-04,   1.6413636E-04
     +,   1.6440793E-04,   1.6466629E-04,   1.6491777E-04
     +,   1.6516885E-04,   1.6542652E-04,   1.6569789E-04
     +,   1.6599038E-04,   1.6631161E-04,   1.6666955E-04
     +,   1.6707227E-04,   1.6752804E-04,   1.6804523E-04
     +,   1.6863231E-04,   1.6929790E-04,   1.7005033E-04
     +,   1.7089811E-04,   1.7184940E-04,   1.7291225E-04
     +,   1.7409430E-04,   1.7540278E-04,   1.7684436E-04
     +,   1.7842514E-04,   1.8015064E-04,   1.8202529E-04
     +,   1.8405270E-04,   1.8623556E-04,   1.8857532E-04
     +,   1.9107200E-04,   1.9372473E-04,   1.9653077E-04
     +,   1.9948627E-04,   2.0258548E-04,   2.0582142E-04
     +,   2.0918516E-04,   2.1266653E-04,   2.1625316E-04
     +,   2.1993172E-04,   2.2368708E-04,   2.2750252E-04
     +,   2.3136007E-04,   2.3524069E-04,   2.3912423E-04
     +,   2.4298932E-04,   2.4681439E-04,   2.5057697E-04
     +,   2.5425467E-04,   2.5782493E-04,   2.6126561E-04
     +,   2.6455501E-04,   2.6767259E-04,   2.7059845E-04
     +,   2.7331483E-04,   2.7580530E-04,   2.7805544E-04
     +,   2.8005330E-04,   2.8178966E-04,   2.8325769E-04
     +,   2.8445377E-04,   2.8537761E-04,   2.8603183E-04
     +,   2.8642293E-04,   2.8656045E-04,   2.8645771E-04
     +,   2.8613114E-04,   2.8560066E-04,   2.8488942E-04
     +,   2.8402344E-04,   2.8303146E-04,   2.8194467E-04
     +,   2.8079623E-04,   2.7962099E-04,   2.7845503E-04
     +,   2.7733512E-04,   2.7629788E-04,   2.7538009E-04
     +,   2.7461699E-04,   2.7404266E-04,   2.7368881E-04
     +,   2.7358456E-04,   2.7375546E-04,   2.7422362E-04
     +,   2.7500669E-04,   2.7611779E-04,   2.7756454E-04
     +,   2.7934954E-04,   2.8147010E-04,   2.8391747E-04
     +,   2.8667800E-04,   2.8973189E-04,   2.9305488E-04
     +,   2.9661783E-04,   3.0038739E-04,   3.0432679E-04
     +,   3.0839693E-04,   3.1255616E-04,   3.1676269E-04
     +,   3.2097482E-04,   3.2515288E-04,   3.2925946E-04
     +,   3.3326168E-04,   3.3713240E-04,   3.4085134E-04
     +,   3.4440661E-04,   3.4779619E-04,   3.5102948E-04
     +,   3.5412848E-04,   3.5712885E-04,   3.6008106E-04
     +,   3.6305145E-04,   3.6612345E-04,   3.6939673E-04
     +,   3.7298939E-04,   3.7703704E-04,   3.8169153E-04
     +,   3.8712210E-04,   3.9351286E-04,   4.0106211E-04
     +,   4.0997975E-04,   4.2048492E-04,   4.3280391E-04
     +,   4.4716720E-04,   4.6380499E-04,   4.8294594E-04
     +,   5.0481438E-04,   5.2962481E-04,   5.5758294E-04
     +,   5.8888545E-04,   6.2371918E-04,   6.6226145E-04
     +,   7.0468505E-04,   7.5116695E-04,   8.0189545E-04
     +,   8.5707713E-04,   9.1695215E-04,   9.8181388E-04
     +,   1.0520215E-03,   1.1280045E-03,   1.2102878E-03
     +,   1.2994857E-03,   1.3962878E-03,   1.5014445E-03
     +,   1.6157355E-03,   1.7399322E-03,   1.8747499E-03
     +,   2.0208417E-03,   2.1788559E-03,   2.3495234E-03
     +,   2.5338395E-03,   2.7332949E-03,   2.9501030E-03
     +,   3.1872841E-03,   3.4485599E-03,   3.7381363E-03
     +,   4.0604402E-03,   4.4202078E-03,   4.8232600E-03
     +,   5.2781338E-03,   5.7980302E-03,   6.4019347E-03
     +,   7.1130055E-03,   7.9525867E-03,   8.9301271E-03
     +,   1.0034349E-02,   1.1235148E-02,   1.2504140E-02
     +,   1.3848636E-02,   1.5334890E-02,   1.7067704E-02
     +,   1.9116461E-02,   2.1436421E-02,   2.3880344E-02
     +,   2.6346100E-02,   2.8946372E-02,   3.1960402E-02
     +,   3.5491478E-02,   3.9172165E-02,   4.2368162E-02
     +,   4.4724327E-02,   4.6337254E-02,   4.7346257E-02
     +,   4.7611423E-02,   4.6914771E-02,   4.5271493E-02
     +,   4.2934794E-02,   4.0256318E-02,   3.7617713E-02
     +,   3.5334703E-02,   3.3477440E-02,   3.1824343E-02
     +,   3.0076835E-02,   2.8109953E-02,   2.6005125E-02
     +,   2.3905130E-02,   2.1898333E-02,   2.0021295E-02
     +,   1.8304298E-02,   1.6770527E-02,   1.5400304E-02
     +,   1.4123588E-02,   1.2858474E-02,   1.1558667E-02
     +,   1.0231905E-02,   8.9242412E-03,   7.6905978E-03
     +,   6.5722652E-03,   5.5890316E-03,   4.7424990E-03
     +,   4.0232195E-03,   3.4166956E-03,   2.9069358E-03
     +,   2.4782869E-03,   2.1163956E-03,   1.8087556E-03
     +,   1.5451454E-03,   1.3176925E-03,   1.1205726E-03
     +,   9.4952807E-04,   8.0137426E-04,   6.7358691E-04
     +,   5.6399632E-04,   4.7061883E-04,   3.9159000E-04
     +,   3.2515204E-04,   2.6964204E-04,   2.2352618E-04
     +,   1.8540128E-04,   1.5401682E-04,   1.2826861E-04
     +,   1.0720376E-04,   9.0005065E-05,   7.5984055E-05
     +,   6.4561988E-05,   5.5258937E-05,   4.7676840E-05
     +,   4.1488183E-05,   3.6425012E-05,   3.2268064E-05
     +,   2.8839766E-05,   2.5996062E-05,   2.3621349E-05
     +,   2.1622620E-05,   1.9925812E-05,   1.8471696E-05
     +,   1.7213335E-05,   1.6113252E-05,   1.5141796E-05
     +,   1.4275246E-05,   1.3494824E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz104 = Yx/0.303531914893617
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.6353801E-05,   6.8381341E-05
     +,   7.0417242E-05,   7.2459596E-05,   7.4506657E-05
     +,   7.6556862E-05,   7.8608973E-05,   8.0661921E-05
     +,   8.2715000E-05,   8.4767918E-05,   8.6820633E-05
     +,   8.8873574E-05,   9.0927526E-05,   9.2983762E-05
     +,   9.5043899E-05,   9.7110234E-05,   9.9185316E-05
     +,   1.0127228E-04,   1.0337462E-04,   1.0549647E-04
     +,   1.0764222E-04,   1.0981679E-04,   1.1202539E-04
     +,   1.1427379E-04,   1.1656775E-04,   1.1891352E-04
     +,   1.2131748E-04,   1.2378611E-04,   1.2632596E-04
     +,   1.2894359E-04,   1.3164537E-04,   1.3443756E-04
     +,   1.3732607E-04,   1.4031646E-04,   1.4341378E-04
     +,   1.4662243E-04,   1.4994625E-04,   1.5338807E-04
     +,   1.5695022E-04,   1.6063344E-04,   1.6443808E-04
     +,   1.6836281E-04,   1.7240531E-04,   1.7656195E-04
     +,   1.8082766E-04,   1.8519630E-04,   1.8965991E-04
     +,   1.9420938E-04,   1.9883426E-04,   2.0352253E-04
     +,   2.0826103E-04,   2.1303527E-04,   2.1782955E-04
     +,   2.2262739E-04,   2.2741081E-04,   2.3216150E-04
     +,   2.3686027E-04,   2.4148748E-04,   2.4602312E-04
     +,   2.5044699E-04,   2.5473922E-04,   2.5887974E-04
     +,   2.6284929E-04,   2.6662913E-04,   2.7020180E-04
     +,   2.7355013E-04,   2.7665906E-04,   2.7951435E-04
     +,   2.8210392E-04,   2.8441683E-04,   2.8644485E-04
     +,   2.8818133E-04,   2.8962185E-04,   2.9076423E-04
     +,   2.9160857E-04,   2.9215758E-04,   2.9241591E-04
     +,   2.9239070E-04,   2.9209157E-04,   2.9153001E-04
     +,   2.9072003E-04,   2.8967738E-04,   2.8841986E-04
     +,   2.8696688E-04,   2.8533980E-04,   2.8356098E-04
     +,   2.8165444E-04,   2.7964477E-04,   2.7755785E-04
     +,   2.7541973E-04,   2.7325712E-04,   2.7109674E-04
     +,   2.6896546E-04,   2.6688928E-04,   2.6489413E-04
     +,   2.6300509E-04,   2.6124588E-04,   2.5963938E-04
     +,   2.5820671E-04,   2.5696750E-04,   2.5593938E-04
     +,   2.5513783E-04,   2.5457612E-04,   2.5426521E-04
     +,   2.5421329E-04,   2.5442592E-04,   2.5490564E-04
     +,   2.5565227E-04,   2.5666240E-04,   2.5792976E-04
     +,   2.5944464E-04,   2.6119471E-04,   2.6316405E-04
     +,   2.6533412E-04,   2.6768359E-04,   2.7018809E-04
     +,   2.7282088E-04,   2.7555297E-04,   2.7835311E-04
     +,   2.8118843E-04,   2.8402475E-04,   2.8682657E-04
     +,   2.8955762E-04,   2.9218147E-04,   2.9466223E-04
     +,   2.9696382E-04,   2.9905184E-04,   3.0089298E-04
     +,   3.0245600E-04,   3.0371215E-04,   3.0463500E-04
     +,   3.0520206E-04,   3.0539351E-04,   3.0519415E-04
     +,   3.0459234E-04,   3.0358124E-04,   3.0215830E-04
     +,   3.0032574E-04,   2.9809066E-04,   2.9546494E-04
     +,   2.9246518E-04,   2.8911294E-04,   2.8543398E-04
     +,   2.8145892E-04,   2.7722237E-04,   2.7276317E-04
     +,   2.6812335E-04,   2.6334898E-04,   2.5848940E-04
     +,   2.5359602E-04,   2.4872305E-04,   2.4392700E-04
     +,   2.3926658E-04,   2.3480118E-04,   2.3059167E-04
     +,   2.2670042E-04,   2.2318980E-04,   2.2012278E-04
     +,   2.1756237E-04,   2.1557184E-04,   2.1421362E-04
     +,   2.1355003E-04,   2.1364236E-04,   2.1455127E-04
     +,   2.1633597E-04,   2.1905487E-04,   2.2276417E-04
     +,   2.2751879E-04,   2.3337160E-04,   2.4037366E-04
     +,   2.4857293E-04,   2.5801483E-04,   2.6874183E-04
     +,   2.8079428E-04,   2.9420707E-04,   3.0901315E-04
     +,   3.2524255E-04,   3.4292135E-04,   3.6207342E-04
     +,   3.8272340E-04,   4.0489828E-04,   4.2862783E-04
     +,   4.5395002E-04,   4.8091786E-04,   5.0960260E-04
     +,   5.4009701E-04,   5.7252246E-04,   6.0703553E-04
     +,   6.4382894E-04,   6.8312784E-04,   7.2519650E-04
     +,   7.7032828E-04,   8.1883773E-04,   8.7105378E-04
     +,   9.2731923E-04,   9.8798762E-04,   1.0534250E-03
     +,   1.1240341E-03,   1.2002948E-03,   1.2828081E-03
     +,   1.3723499E-03,   1.4699363E-03,   1.5768765E-03
     +,   1.6947917E-03,   1.8255708E-03,   1.9713263E-03
     +,   2.1342568E-03,   2.3164998E-03,   2.5200320E-03
     +,   2.7466665E-03,   2.9981430E-03,   3.2763442E-03
     +,   3.5835970E-03,   3.9228834E-03,   4.2977738E-03
     +,   4.7119968E-03,   5.1687527E-03,   5.6700138E-03
     +,   6.2161149E-03,   6.8059345E-03,   7.4385195E-03
     +,   8.1167733E-03,   8.8543296E-03,   9.6848998E-03
     +,   1.0666700E-02,   1.1871599E-02,   1.3355014E-02
     +,   1.5123488E-02,   1.7129602E-02,   1.9305926E-02
     +,   2.1615477E-02,   2.4080163E-02,   2.6770627E-02
     +,   2.9760776E-02,   3.3061411E-02,   3.6564145E-02
     +,   4.0033951E-02,   4.3155894E-02,   4.5617715E-02
     +,   4.7219131E-02,   4.7965202E-02,   4.8057076E-02
     +,   4.7762346E-02,   4.7239587E-02,   4.6427779E-02
     +,   4.5105148E-02,   4.3095957E-02,   4.0438049E-02
     +,   3.7368134E-02,   3.4167077E-02,   3.1020952E-02
     +,   2.8009683E-02,   2.5188649E-02,   2.2632243E-02
     +,   2.0389257E-02,   1.8430028E-02,   1.6657548E-02
     +,   1.4965321E-02,   1.3286601E-02,   1.1611105E-02
     +,   9.9752210E-03,   8.4386673E-03,   7.0580416E-03
     +,   5.8673238E-03,   4.8714355E-03,   4.0518329E-03
     +,   3.3786215E-03,   2.8216494E-03,   2.3566596E-03
     +,   1.9664785E-03,   1.6392882E-03,   1.3661769E-03
     +,   1.1393623E-03,   9.5148222E-04,   7.9564657E-04
     +,   6.6576485E-04,   5.5677071E-04,   4.6471582E-04
     +,   3.8661977E-04,   3.2027677E-04,   2.6400367E-04
     +,   2.1646655E-04,   1.7653346E-04,   1.4321097E-04
     +,   1.1559506E-04,   9.2866991E-05,   7.4283147E-05
     +,   5.9179598E-05,   4.6973266E-05,   3.7156671E-05
     +,   2.9297475E-05,   2.3029796E-05,   1.8049359E-05
     +,   1.4104304E-05,   1.0988957E-05,   8.5357169E-06
     +,   6.6094494E-06,   5.1011662E-06,   3.9237116E-06
     +,   3.0072827E-06,   2.2963654E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz106 = Yx/0.301875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.4298834E-05,   7.6437704E-05
     +,   7.8599653E-05,   8.0784092E-05,   8.2990366E-05
     +,   8.5217856E-05,   8.7465982E-05,   8.9734232E-05
     +,   9.2022063E-05,   9.4329014E-05,   9.6654658E-05
     +,   9.8998491E-05,   1.0136010E-04,   1.0373906E-04
     +,   1.0613498E-04,   1.0854743E-04,   1.1097602E-04
     +,   1.1342026E-04,   1.1587969E-04,   1.1835383E-04
     +,   1.2084216E-04,   1.2334403E-04,   1.2585880E-04
     +,   1.2838589E-04,   1.3092434E-04,   1.3347335E-04
     +,   1.3603205E-04,   1.3859934E-04,   1.4117411E-04
     +,   1.4375517E-04,   1.4634122E-04,   1.4893083E-04
     +,   1.5152250E-04,   1.5411471E-04,   1.5670576E-04
     +,   1.5929392E-04,   1.6187747E-04,   1.6445447E-04
     +,   1.6702308E-04,   1.6958138E-04,   1.7212752E-04
     +,   1.7465958E-04,   1.7717562E-04,   1.7967385E-04
     +,   1.8215254E-04,   1.8460998E-04,   1.8704460E-04
     +,   1.8945502E-04,   1.9183994E-04,   1.9419831E-04
     +,   1.9652916E-04,   1.9883180E-04,   2.0110582E-04
     +,   2.0335101E-04,   2.0556724E-04,   2.0775494E-04
     +,   2.0991468E-04,   2.1204726E-04,   2.1415374E-04
     +,   2.1623551E-04,   2.1829437E-04,   2.2033202E-04
     +,   2.2235056E-04,   2.2435244E-04,   2.2634023E-04
     +,   2.2831645E-04,   2.3028410E-04,   2.3224605E-04
     +,   2.3420535E-04,   2.3616487E-04,   2.3812783E-04
     +,   2.4009708E-04,   2.4207553E-04,   2.4406574E-04
     +,   2.4607018E-04,   2.4809132E-04,   2.5013092E-04
     +,   2.5219060E-04,   2.5427155E-04,   2.5637462E-04
     +,   2.5850005E-04,   2.6064756E-04,   2.6281652E-04
     +,   2.6500551E-04,   2.6721257E-04,   2.6943526E-04
     +,   2.7167035E-04,   2.7391405E-04,   2.7616191E-04
     +,   2.7840864E-04,   2.8064891E-04,   2.8287625E-04
     +,   2.8508372E-04,   2.8726400E-04,   2.8940919E-04
     +,   2.9151098E-04,   2.9356068E-04,   2.9554917E-04
     +,   2.9746731E-04,   2.9930548E-04,   3.0105424E-04
     +,   3.0270399E-04,   3.0424519E-04,   3.0566871E-04
     +,   3.0696529E-04,   3.0812653E-04,   3.0914409E-04
     +,   3.1001036E-04,   3.1071855E-04,   3.1126247E-04
     +,   3.1163674E-04,   3.1183712E-04,   3.1186032E-04
     +,   3.1170406E-04,   3.1136742E-04,   3.1085074E-04
     +,   3.1015521E-04,   3.0928417E-04,   3.0824149E-04
     +,   3.0703281E-04,   3.0566525E-04,   3.0414702E-04
     +,   3.0248769E-04,   3.0069830E-04,   2.9879066E-04
     +,   2.9677831E-04,   2.9467524E-04,   2.9249693E-04
     +,   2.9025920E-04,   2.8797865E-04,   2.8567258E-04
     +,   2.8335853E-04,   2.8105421E-04,   2.7877753E-04
     +,   2.7654605E-04,   2.7437694E-04,   2.7228723E-04
     +,   2.7029304E-04,   2.6840961E-04,   2.6665130E-04
     +,   2.6503135E-04,   2.6356173E-04,   2.6225293E-04
     +,   2.6111410E-04,   2.6015291E-04,   2.5937537E-04
     +,   2.5878634E-04,   2.5838870E-04,   2.5818433E-04
     +,   2.5817344E-04,   2.5835572E-04,   2.5872944E-04
     +,   2.5929211E-04,   2.6004142E-04,   2.6097454E-04
     +,   2.6208907E-04,   2.6338329E-04,   2.6485659E-04
     +,   2.6650997E-04,   2.6834654E-04,   2.7037150E-04
     +,   2.7259352E-04,   2.7502439E-04,   2.7767944E-04
     +,   2.8057865E-04,   2.8374640E-04,   2.8721176E-04
     +,   2.9100891E-04,   2.9517733E-04,   2.9976206E-04
     +,   3.0481393E-04,   3.1038912E-04,   3.1655049E-04
     +,   3.2336722E-04,   3.3091471E-04,   3.3927648E-04
     +,   3.4854410E-04,   3.5881822E-04,   3.7020896E-04
     +,   3.8283831E-04,   3.9684147E-04,   4.1236653E-04
     +,   4.2957591E-04,   4.4864882E-04,   4.6978044E-04
     +,   4.9318082E-04,   5.1907403E-04,   5.4770010E-04
     +,   5.7931000E-04,   6.1416160E-04,   6.5252144E-04
     +,   6.9465931E-04,   7.4084388E-04,   7.9133979E-04
     +,   8.4640866E-04,   9.0630649E-04,   9.7126974E-04
     +,   1.0415219E-03,   1.1172632E-03,   1.1986680E-03
     +,   1.2858640E-03,   1.3789297E-03,   1.4778969E-03
     +,   1.5827476E-03,   1.6934137E-03,   1.8098389E-03
     +,   1.9320258E-03,   2.0601156E-03,   2.1945187E-03
     +,   2.3360513E-03,   2.4860529E-03,   2.6464495E-03
     +,   2.8197404E-03,   3.0088485E-03,   3.2168028E-03
     +,   3.4463468E-03,   3.6995532E-03,   3.9777067E-03
     +,   4.2815292E-03,   4.6118321E-03,   4.9706292E-03
     +,   5.3622341E-03,   5.7939757E-03,   6.2762890E-03
     +,   6.8218824E-03,   7.4438713E-03,   8.1528965E-03
     +,   8.9536710E-03,   9.8420205E-03,   1.0804930E-02
     +,   1.1826069E-02,   1.2896272E-02,   1.4023554E-02
     +,   1.5236157E-02,   1.6577367E-02,   1.8095683E-02
     +,   1.9829452E-02,   2.1782069E-02,   2.3903528E-02
     +,   2.6114311E-02,   2.8374946E-02,   3.0734137E-02
     +,   3.3289313E-02,   3.6104184E-02,   3.9170738E-02
     +,   4.2391341E-02,   4.5505237E-02,   4.8043337E-02
     +,   4.9490701E-02,   4.9607888E-02,   4.8603624E-02
     +,   4.6968225E-02,   4.5139965E-02,   4.3319497E-02
     +,   4.1516606E-02,   3.9654873E-02,   3.7609670E-02
     +,   3.5237711E-02,   3.2451116E-02,   2.9272223E-02
     +,   2.5820019E-02,   2.2267293E-02,   1.8803962E-02
     +,   1.5598432E-02,   1.2762315E-02,   1.0340426E-02
     +,   8.3272289E-03,   6.6869920E-03,   5.3670746E-03
     +,   4.3083299E-03,   3.4553900E-03,   2.7637854E-03
     +,   2.2013388E-03,   1.7453545E-03,   1.3787347E-03
     +,   1.0871466E-03,   8.5765653E-04,   6.7858625E-04
     +,   5.3963001E-04,   4.3207122E-04,   3.4875926E-04
     +,   2.8401930E-04,   2.3342855E-04,   1.9361169E-04
     +,   1.6201299E-04,   1.3671965E-04,   1.1629822E-04
     +,   9.9675555E-05,   8.6045788E-05,   7.4797019E-05
     +,   6.5463944E-05,   5.7687412E-05,   5.1189218E-05
     +,   4.5749599E-05,   4.1193642E-05,   3.7378715E-05
     +,   3.4187389E-05,   3.1520718E-05,   2.9294974E-05
     +,   2.7438175E-05,   2.5888668E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz108 = Yx/0.306979166666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3563308E-05,   7.6068958E-05
     +,   7.8620171E-05,   8.1215898E-05,   8.3855026E-05
     +,   8.6536391E-05,   8.9258698E-05,   9.2020688E-05
     +,   9.4820934E-05,   9.7658056E-05,   1.0053060E-04
     +,   1.0343700E-04,   1.0637568E-04,   1.0934508E-04
     +,   1.1234355E-04,   1.1536944E-04,   1.1842101E-04
     +,   1.2149666E-04,   1.2459459E-04,   1.2771302E-04
     +,   1.3085027E-04,   1.3400456E-04,   1.3717395E-04
     +,   1.4035687E-04,   1.4355125E-04,   1.4675535E-04
     +,   1.4996722E-04,   1.5318500E-04,   1.5640658E-04
     +,   1.5962996E-04,   1.6285303E-04,   1.6607366E-04
     +,   1.6928941E-04,   1.7249801E-04,   1.7569705E-04
     +,   1.7888368E-04,   1.8205524E-04,   1.8520880E-04
     +,   1.8834138E-04,   1.9144949E-04,   1.9452994E-04
     +,   1.9757889E-04,   2.0059258E-04,   2.0356692E-04
     +,   2.0649763E-04,   2.0938032E-04,   2.1221022E-04
     +,   2.1498244E-04,   2.1769200E-04,   2.2033360E-04
     +,   2.2290180E-04,   2.2539111E-04,   2.2779568E-04
     +,   2.3011009E-04,   2.3232827E-04,   2.3444438E-04
     +,   2.3645273E-04,   2.3834739E-04,   2.4012278E-04
     +,   2.4177330E-04,   2.4329353E-04,   2.4467841E-04
     +,   2.4592300E-04,   2.4702278E-04,   2.4797357E-04
     +,   2.4877163E-04,   2.4941351E-04,   2.4989646E-04
     +,   2.5021817E-04,   2.5037688E-04,   2.5037135E-04
     +,   2.5020132E-04,   2.4986651E-04,   2.4936793E-04
     +,   2.4870690E-04,   2.4788544E-04,   2.4690627E-04
     +,   2.4577291E-04,   2.4448911E-04,   2.4305958E-04
     +,   2.4148967E-04,   2.3978499E-04,   2.3795194E-04
     +,   2.3599726E-04,   2.3392809E-04,   2.3175224E-04
     +,   2.2947764E-04,   2.2711242E-04,   2.2466537E-04
     +,   2.2214507E-04,   2.1956023E-04,   2.1692010E-04
     +,   2.1423351E-04,   2.1150963E-04,   2.0875710E-04
     +,   2.0598514E-04,   2.0320203E-04,   2.0041653E-04
     +,   1.9763688E-04,   1.9487122E-04,   1.9212718E-04
     +,   1.8941244E-04,   1.8673408E-04,   1.8409906E-04
     +,   1.8151400E-04,   1.7898492E-04,   1.7651789E-04
     +,   1.7411853E-04,   1.7179207E-04,   1.6954342E-04
     +,   1.6737750E-04,   1.6529848E-04,   1.6331069E-04
     +,   1.6141795E-04,   1.5962413E-04,   1.5793253E-04
     +,   1.5634665E-04,   1.5486957E-04,   1.5350433E-04
     +,   1.5225372E-04,   1.5112053E-04,   1.5010731E-04
     +,   1.4921655E-04,   1.4845069E-04,   1.4781188E-04
     +,   1.4730223E-04,   1.4692370E-04,   1.4667807E-04
     +,   1.4656698E-04,   1.4659176E-04,   1.4675374E-04
     +,   1.4705375E-04,   1.4749252E-04,   1.4807031E-04
     +,   1.4878719E-04,   1.4964287E-04,   1.5063645E-04
     +,   1.5176677E-04,   1.5303219E-04,   1.5443077E-04
     +,   1.5595986E-04,   1.5761626E-04,   1.5939659E-04
     +,   1.6129696E-04,   1.6331284E-04,   1.6543946E-04
     +,   1.6767193E-04,   1.7000463E-04,   1.7243229E-04
     +,   1.7494921E-04,   1.7755010E-04,   1.8022953E-04
     +,   1.8298271E-04,   1.8580543E-04,   1.8869428E-04
     +,   1.9164667E-04,   1.9466122E-04,   1.9773838E-04
     +,   2.0088012E-04,   2.0409003E-04,   2.0737467E-04
     +,   2.1074254E-04,   2.1420502E-04,   2.1777628E-04
     +,   2.2147357E-04,   2.2531788E-04,   2.2933286E-04
     +,   2.3354564E-04,   2.3798703E-04,   2.4269070E-04
     +,   2.4769385E-04,   2.5303572E-04,   2.5875866E-04
     +,   2.6490708E-04,   2.7152622E-04,   2.7866269E-04
     +,   2.8636368E-04,   2.9467486E-04,   3.0364085E-04
     +,   3.1330445E-04,   3.2370543E-04,   3.3487956E-04
     +,   3.4685747E-04,   3.5966578E-04,   3.7332607E-04
     +,   3.8785339E-04,   4.0325749E-04,   4.1954473E-04
     +,   4.3671866E-04,   4.5477954E-04,   4.7373094E-04
     +,   4.9358164E-04,   5.1434839E-04,   5.3606171E-04
     +,   5.5877434E-04,   5.8256596E-04,   6.0754968E-04
     +,   6.3387951E-04,   6.6175964E-04,   6.9144834E-04
     +,   7.2326022E-04,   7.5756887E-04,   7.9480605E-04
     +,   8.3545543E-04,   8.8003819E-04,   9.2910422E-04
     +,   9.8321598E-04,   1.0429273E-03,   1.1087697E-03
     +,   1.1812539E-03,   1.2608633E-03,   1.3480663E-03
     +,   1.4433470E-03,   1.5472504E-03,   1.6604331E-03
     +,   1.7836925E-03,   1.9180152E-03,   2.0645866E-03
     +,   2.2247578E-03,   2.3999498E-03,   2.5915790E-03
     +,   2.8009291E-03,   3.0290582E-03,   3.2768368E-03
     +,   3.5451686E-03,   3.8354003E-03,   4.1499902E-03
     +,   4.4933776E-03,   4.8728348E-03,   5.2987873E-03
     +,   5.7840482E-03,   6.3413708E-03,   6.9793426E-03
     +,   7.6975436E-03,   8.4835952E-03,   9.3151424E-03
     +,   1.0167645E-02,   1.1026287E-02,   1.1897082E-02
     +,   1.2812288E-02,   1.3826183E-02,   1.5000589E-02
     +,   1.6385194E-02,   1.8008644E-02,   1.9892886E-02
     +,   2.2074714E-02,   2.4594381E-02,   2.7449356E-02
     +,   3.0570988E-02,   3.3859361E-02,   3.7235934E-02
     +,   4.0662427E-02,   4.4107497E-02,   4.7438249E-02
     +,   5.0339483E-02,   5.2468434E-02,   5.3706884E-02
     +,   5.4087039E-02,   5.3521629E-02,   5.1866278E-02
     +,   4.9212091E-02,   4.5877747E-02,   4.2134810E-02
     +,   3.8084339E-02,   3.3761542E-02,   2.9250691E-02
     +,   2.4704035E-02,   2.0308251E-02,   1.6247083E-02
     +,   1.2670182E-02,   9.6679302E-03,   7.2595500E-03
     +,   5.4003517E-03,   4.0045702E-03,   2.9729828E-03
     +,   2.2144078E-03,   1.6559439E-03,   1.2439326E-03
     +,   9.3969837E-04,   7.1501790E-04,   5.4875127E-04
     +,   4.2501581E-04,   3.3201632E-04,   2.6123156E-04
     +,   2.0662684E-04,   1.6399715E-04,   1.3039871E-04
     +,   1.0374385E-04,   8.2518767E-05,   6.5592460E-05
     +,   5.2104413E-05,   4.1383431E-05,   3.2900072E-05
     +,   2.6228458E-05,   2.1023356E-05,   1.7000410E-05
     +,   1.3924750E-05,   1.1600866E-05,   9.8669952E-06
     +,   8.5896581E-06,   7.6603073E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz110 = Yx/0.293702127659574
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz111(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.3611464E-05,   6.6408822E-05
     +,   6.9300266E-05,   7.2285773E-05,   7.5365060E-05
     +,   7.8537530E-05,   8.1802245E-05,   8.5157866E-05
     +,   8.8602799E-05,   9.2135044E-05,   9.5752192E-05
     +,   9.9451427E-05,   1.0322963E-04,   1.0708316E-04
     +,   1.1100808E-04,   1.1500001E-04,   1.1905425E-04
     +,   1.2316550E-04,   1.2732846E-04,   1.3153710E-04
     +,   1.3578525E-04,   1.4006643E-04,   1.4437380E-04
     +,   1.4870038E-04,   1.5303864E-04,   1.5738122E-04
     +,   1.6172038E-04,   1.6604846E-04,   1.7035732E-04
     +,   1.7463924E-04,   1.7888632E-04,   1.8309054E-04
     +,   1.8724428E-04,   1.9133995E-04,   1.9537017E-04
     +,   1.9932800E-04,   2.0320645E-04,   2.0699922E-04
     +,   2.1070056E-04,   2.1430483E-04,   2.1780717E-04
     +,   2.2120334E-04,   2.2448962E-04,   2.2766279E-04
     +,   2.3072086E-04,   2.3366217E-04,   2.3648604E-04
     +,   2.3919236E-04,   2.4178196E-04,   2.4425687E-04
     +,   2.4661940E-04,   2.4887279E-04,   2.5102159E-04
     +,   2.5307073E-04,   2.5502598E-04,   2.5689389E-04
     +,   2.5868183E-04,   2.6039785E-04,   2.6205034E-04
     +,   2.6364843E-04,   2.6520170E-04,   2.6672013E-04
     +,   2.6821383E-04,   2.6969321E-04,   2.7116892E-04
     +,   2.7265129E-04,   2.7415084E-04,   2.7567759E-04
     +,   2.7724137E-04,   2.7885140E-04,   2.8051657E-04
     +,   2.8224458E-04,   2.8404308E-04,   2.8591807E-04
     +,   2.8787515E-04,   2.8991839E-04,   2.9205112E-04
     +,   2.9427500E-04,   2.9659082E-04,   2.9899779E-04
     +,   3.0149386E-04,   3.0407586E-04,   3.0673901E-04
     +,   3.0947686E-04,   3.1228235E-04,   3.1514699E-04
     +,   3.1806069E-04,   3.2101286E-04,   3.2399126E-04
     +,   3.2698346E-04,   3.2997568E-04,   3.3295347E-04
     +,   3.3590221E-04,   3.3880674E-04,   3.4165170E-04
     +,   3.4442160E-04,   3.4710101E-04,   3.4967432E-04
     +,   3.5212727E-04,   3.5444513E-04,   3.5661430E-04
     +,   3.5862185E-04,   3.6045566E-04,   3.6210462E-04
     +,   3.6355879E-04,   3.6480941E-04,   3.6584894E-04
     +,   3.6667095E-04,   3.6727075E-04,   3.6764462E-04
     +,   3.6779034E-04,   3.6770728E-04,   3.6739625E-04
     +,   3.6685847E-04,   3.6609796E-04,   3.6511861E-04
     +,   3.6392655E-04,   3.6252831E-04,   3.6093171E-04
     +,   3.5914584E-04,   3.5717990E-04,   3.5504470E-04
     +,   3.5275143E-04,   3.5031184E-04,   3.4773824E-04
     +,   3.4504317E-04,   3.4223954E-04,   3.3934080E-04
     +,   3.3636016E-04,   3.3331083E-04,   3.3020618E-04
     +,   3.2705953E-04,   3.2388346E-04,   3.2069112E-04
     +,   3.1749462E-04,   3.1430574E-04,   3.1113590E-04
     +,   3.0799658E-04,   3.0489775E-04,   3.0184921E-04
     +,   2.9886028E-04,   2.9593962E-04,   2.9309510E-04
     +,   2.9033370E-04,   2.8766241E-04,   2.8508675E-04
     +,   2.8261211E-04,   2.8024308E-04,   2.7798358E-04
     +,   2.7583688E-04,   2.7380564E-04,   2.7189218E-04
     +,   2.7009824E-04,   2.6842492E-04,   2.6687302E-04
     +,   2.6544312E-04,   2.6413551E-04,   2.6295008E-04
     +,   2.6188669E-04,   2.6094529E-04,   2.6012567E-04
     +,   2.5942791E-04,   2.5885223E-04,   2.5839935E-04
     +,   2.5807050E-04,   2.5786750E-04,   2.5779294E-04
     +,   2.5785068E-04,   2.5804588E-04,   2.5838503E-04
     +,   2.5887677E-04,   2.5953184E-04,   2.6036400E-04
     +,   2.6138994E-04,   2.6263061E-04,   2.6411132E-04
     +,   2.6586308E-04,   2.6792361E-04,   2.7033794E-04
     +,   2.7316049E-04,   2.7645647E-04,   2.8030344E-04
     +,   2.8479341E-04,   2.9003527E-04,   2.9615776E-04
     +,   3.0331151E-04,   3.1167208E-04,   3.2144377E-04
     +,   3.3286260E-04,   3.4619792E-04,   3.6175689E-04
     +,   3.7988607E-04,   4.0097130E-04,   4.2543712E-04
     +,   4.5374664E-04,   4.8639716E-04,   5.2390911E-04
     +,   5.6681625E-04,   6.1565556E-04,   6.7094743E-04
     +,   7.3316821E-04,   8.0273062E-04,   8.7996072E-04
     +,   9.6506882E-04,   1.0581177E-03,   1.1590159E-03
     +,   1.2675032E-03,   1.3831375E-03,   1.5053091E-03
     +,   1.6332731E-03,   1.7661727E-03,   1.9030753E-03
     +,   2.0430221E-03,   2.1850937E-03,   2.3284378E-03
     +,   2.4723043E-03,   2.6160711E-03,   2.7592650E-03
     +,   2.9015520E-03,   3.0427135E-03,   3.1826647E-03
     +,   3.3214474E-03,   3.4592482E-03,   3.5964698E-03
     +,   3.7338841E-03,   3.8727992E-03,   4.0153051E-03
     +,   4.1645300E-03,   4.3248218E-03,   4.5017903E-03
     +,   4.7020623E-03,   4.9329139E-03,   5.2017965E-03
     +,   5.5160364E-03,   5.8828108E-03,   6.3095102E-03
     +,   6.8038851E-03,   7.3735896E-03,   8.0252746E-03
     +,   8.7641636E-03,   9.5960144E-03,   1.0532785E-02
     +,   1.1600017E-02,   1.2839360E-02,   1.4298367E-02
     +,   1.6007904E-02,   1.7960472E-02,   2.0107295E-02
     +,   2.2380203E-02,   2.4725890E-02,   2.7137499E-02
     +,   2.9666500E-02,   3.2393735E-02,   3.5357252E-02
     +,   3.8506601E-02,   4.1775919E-02,   4.5213118E-02
     +,   4.8924915E-02,   5.2759383E-02,   5.6063913E-02
     +,   5.7917714E-02,   5.7727285E-02,   5.5622350E-02
     +,   5.2287821E-02,   4.8440643E-02,   4.4434123E-02
     +,   4.0245309E-02,   3.5725728E-02,   3.0843470E-02
     +,   2.5759840E-02,   2.0760287E-02,   1.6141696E-02
     +,   1.2132017E-02,   8.8546053E-03,   6.3240882E-03
     +,   4.4648303E-03,   3.1474659E-03,   2.2319611E-03
     +,   1.5982523E-03,   1.1578802E-03,   8.5047679E-04
     +,   6.3535402E-04,   4.8418262E-04,   3.7676972E-04
     +,   2.9879497E-04,   2.4047584E-04,   1.9542647E-04
     +,   1.5965839E-04,   1.3074400E-04,   1.0718490E-04
     +,   8.8005960E-05,   7.2500181E-05,   6.0098424E-05
     +,   5.0300456E-05,   4.2653432E-05,   3.6744263E-05
     +,   3.2205491E-05,   2.8718736E-05,   2.6019017E-05
     +,   2.3893481E-05,   2.2178483E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz111 = Yx/0.301446808510638
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.8961155E-05,   9.1766924E-05
     +,   9.4615687E-05,   9.7506847E-05,   1.0043989E-04
     +,   1.0341441E-04,   1.0643000E-04,   1.0948627E-04
     +,   1.1258291E-04,   1.1571982E-04,   1.1889671E-04
     +,   1.2211350E-04,   1.2537018E-04,   1.2866671E-04
     +,   1.3200309E-04,   1.3537935E-04,   1.3879561E-04
     +,   1.4225196E-04,   1.4574839E-04,   1.4928493E-04
     +,   1.5286163E-04,   1.5647824E-04,   1.6013472E-04
     +,   1.6383069E-04,   1.6756565E-04,   1.7133907E-04
     +,   1.7515007E-04,   1.7899755E-04,   1.8288038E-04
     +,   1.8679681E-04,   1.9074509E-04,   1.9472295E-04
     +,   1.9872791E-04,   2.0275699E-04,   2.0680697E-04
     +,   2.1087423E-04,   2.1495466E-04,   2.1904371E-04
     +,   2.2313683E-04,   2.2722840E-04,   2.3131302E-04
     +,   2.3538475E-04,   2.3943702E-04,   2.4346354E-04
     +,   2.4745727E-04,   2.5141108E-04,   2.5531778E-04
     +,   2.5916996E-04,   2.6296018E-04,   2.6668113E-04
     +,   2.7032531E-04,   2.7388570E-04,   2.7735523E-04
     +,   2.8072763E-04,   2.8399623E-04,   2.8715577E-04
     +,   2.9020075E-04,   2.9312700E-04,   2.9593045E-04
     +,   2.9860830E-04,   3.0115826E-04,   3.0357920E-04
     +,   3.0587064E-04,   3.0803322E-04,   3.1006898E-04
     +,   3.1198023E-04,   3.1377096E-04,   3.1544565E-04
     +,   3.1701021E-04,   3.1847114E-04,   3.1983631E-04
     +,   3.2111365E-04,   3.2231241E-04,   3.2344210E-04
     +,   3.2451341E-04,   3.2553647E-04,   3.2652245E-04
     +,   3.2748232E-04,   3.2842704E-04,   3.2936735E-04
     +,   3.3031404E-04,   3.3127709E-04,   3.3226598E-04
     +,   3.3328935E-04,   3.3435502E-04,   3.3546967E-04
     +,   3.3663888E-04,   3.3786724E-04,   3.3915753E-04
     +,   3.4051135E-04,   3.4192880E-04,   3.4340844E-04
     +,   3.4494721E-04,   3.4654047E-04,   3.4818240E-04
     +,   3.4986524E-04,   3.5158006E-04,   3.5331657E-04
     +,   3.5506298E-04,   3.5680700E-04,   3.5853489E-04
     +,   3.6023193E-04,   3.6188320E-04,   3.6347294E-04
     +,   3.6498508E-04,   3.6640372E-04,   3.6771238E-04
     +,   3.6889539E-04,   3.6993698E-04,   3.7082235E-04
     +,   3.7153738E-04,   3.7206849E-04,   3.7240333E-04
     +,   3.7253089E-04,   3.7244064E-04,   3.7212460E-04
     +,   3.7157556E-04,   3.7078760E-04,   3.6975692E-04
     +,   3.6848086E-04,   3.6695850E-04,   3.6519088E-04
     +,   3.6318004E-04,   3.6092981E-04,   3.5844554E-04
     +,   3.5573417E-04,   3.5280405E-04,   3.4966494E-04
     +,   3.4632691E-04,   3.4280296E-04,   3.3910567E-04
     +,   3.3524929E-04,   3.3124906E-04,   3.2712100E-04
     +,   3.2288168E-04,   3.1854870E-04,   3.1414040E-04
     +,   3.0967547E-04,   3.0517348E-04,   3.0065412E-04
     +,   2.9613782E-04,   2.9164588E-04,   2.8719945E-04
     +,   2.8282037E-04,   2.7853125E-04,   2.7435453E-04
     +,   2.7031373E-04,   2.6643262E-04,   2.6273556E-04
     +,   2.5924740E-04,   2.5599322E-04,   2.5299913E-04
     +,   2.5029160E-04,   2.4789735E-04,   2.4584361E-04
     +,   2.4415861E-04,   2.4287039E-04,   2.4200740E-04
     +,   2.4159854E-04,   2.4167288E-04,   2.4225935E-04
     +,   2.4338713E-04,   2.4508478E-04,   2.4738081E-04
     +,   2.5030316E-04,   2.5387955E-04,   2.5813663E-04
     +,   2.6310008E-04,   2.6879524E-04,   2.7524636E-04
     +,   2.8247698E-04,   2.9050931E-04,   2.9936564E-04
     +,   3.0906868E-04,   3.1963954E-04,   3.3110118E-04
     +,   3.4347802E-04,   3.5679573E-04,   3.7108202E-04
     +,   3.8636982E-04,   4.0269608E-04,   4.2010314E-04
     +,   4.3863902E-04,   4.5836100E-04,   4.7933462E-04
     +,   5.0163362E-04,   5.2534172E-04,   5.5055361E-04
     +,   5.7737558E-04,   6.0592068E-04,   6.3631544E-04
     +,   6.6869351E-04,   7.0319662E-04,   7.3997071E-04
     +,   7.7916693E-04,   8.2093792E-04,   8.6542999E-04
     +,   9.1277738E-04,   9.6310413E-04,   1.0165103E-03
     +,   1.0730607E-03,   1.1327786E-03,   1.1956432E-03
     +,   1.2615753E-03,   1.3304310E-03,   1.4020114E-03
     +,   1.4760691E-03,   1.5523175E-03,   1.6304709E-03
     +,   1.7102815E-03,   1.7915979E-03,   1.8744250E-03
     +,   1.9589926E-03,   2.0458400E-03,   2.1358670E-03
     +,   2.2303711E-03,   2.3310555E-03,   2.4399916E-03
     +,   2.5595173E-03,   2.6920910E-03,   2.8401122E-03
     +,   3.0057225E-03,   3.1906131E-03,   3.3959243E-03
     +,   3.6222611E-03,   3.8698341E-03,   4.1387612E-03
     +,   4.4295257E-03,   4.7435258E-03,   5.0835223E-03
     +,   5.4538264E-03,   5.8600828E-03,   6.3084518E-03
     +,   6.8040462E-03,   7.3488234E-03,   7.9396833E-03
     +,   8.5671060E-03,   9.2153568E-03,   9.8647168E-03
     +,   1.0495885E-02,   1.1095341E-02,   1.1660445E-02
     +,   1.2202807E-02,   1.2748942E-02,   1.3339510E-02
     +,   1.4027836E-02,   1.4875553E-02,   1.5940556E-02
     +,   1.7257612E-02,   1.8824259E-02,   2.0610394E-02
     +,   2.2591498E-02,   2.4782086E-02,   2.7238011E-02
     +,   3.0015867E-02,   3.3105437E-02,   3.6384597E-02
     +,   3.9662808E-02,   4.2814009E-02,   4.5867898E-02
     +,   4.8914447E-02,   5.1883869E-02,   5.4433767E-02
     +,   5.6044932E-02,   5.6202453E-02,   5.4545935E-02
     +,   5.0995179E-02,   4.5831591E-02,   3.9644547E-02
     +,   3.3132173E-02,   2.6883855E-02,   2.1267613E-02
     +,   1.6441297E-02,   1.2427059E-02,   9.1822138E-03
     +,   6.6362540E-03,   4.7010146E-03,   3.2760182E-03
     +,   2.2565487E-03,   1.5447348E-03,   1.0570211E-03
     +,   7.2727469E-04,   5.0588651E-04,   3.5731279E-04
     +,   2.5697963E-04,   1.8845171E-04,   1.4098677E-04
     +,   1.0766008E-04,   8.3996172E-05,   6.7036686E-05
     +,   5.4766722E-05,   4.5770157E-05,   3.9041759E-05
     +,   3.3872719E-05,   2.9777695E-05,   2.6434853E-05
     +,   2.3638226E-05,   2.1257221E-05,   1.9207680E-05
     +,   1.7431086E-05,   1.5882930E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz112 = Yx/0.299212765957447
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz1128(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.4859036E-05,   6.7640831E-05
     +,   7.0544782E-05,   7.3576412E-05,   7.6741380E-05
     +,   8.0045422E-05,   8.3494226E-05,   8.7093562E-05
     +,   9.0848924E-05,   9.4765957E-05,   9.8849800E-05
     +,   1.0310542E-04,   1.0753737E-04,   1.1214979E-04
     +,   1.1694617E-04,   1.2192929E-04,   1.2710136E-04
     +,   1.3246352E-04,   1.3801607E-04,   1.4375809E-04
     +,   1.4968764E-04,   1.5580133E-04,   1.6209450E-04
     +,   1.6856118E-04,   1.7519339E-04,   1.8198213E-04
     +,   1.8891651E-04,   1.9598393E-04,   2.0317014E-04
     +,   2.1045918E-04,   2.1783370E-04,   2.2527426E-04
     +,   2.3276029E-04,   2.4026970E-04,   2.4777889E-04
     +,   2.5526324E-04,   2.6269705E-04,   2.7005357E-04
     +,   2.7730616E-04,   2.8442641E-04,   2.9138706E-04
     +,   2.9816001E-04,   3.0471804E-04,   3.1103412E-04
     +,   3.1708216E-04,   3.2283715E-04,   3.2827578E-04
     +,   3.3337597E-04,   3.3811745E-04,   3.4248261E-04
     +,   3.4645590E-04,   3.5002382E-04,   3.5317626E-04
     +,   3.5590588E-04,   3.5820770E-04,   3.6008042E-04
     +,   3.6152548E-04,   3.6254749E-04,   3.6315428E-04
     +,   3.6335617E-04,   3.6316740E-04,   3.6260398E-04
     +,   3.6168555E-04,   3.6043359E-04,   3.5887229E-04
     +,   3.5702772E-04,   3.5492799E-04,   3.5260274E-04
     +,   3.5008299E-04,   3.4740096E-04,   3.4458938E-04
     +,   3.4168194E-04,   3.3871192E-04,   3.3571341E-04
     +,   3.3271938E-04,   3.2976276E-04,   3.2687554E-04
     +,   3.2408853E-04,   3.2143129E-04,   3.1893206E-04
     +,   3.1661752E-04,   3.1451203E-04,   3.1263882E-04
     +,   3.1101791E-04,   3.0966834E-04,   3.0860610E-04
     +,   3.0784510E-04,   3.0739681E-04,   3.0727027E-04
     +,   3.0747251E-04,   3.0800747E-04,   3.0887712E-04
     +,   3.1008071E-04,   3.1161594E-04,   3.1347739E-04
     +,   3.1565802E-04,   3.1814852E-04,   3.2093716E-04
     +,   3.2401111E-04,   3.2735502E-04,   3.3095232E-04
     +,   3.3478448E-04,   3.3883186E-04,   3.4307322E-04
     +,   3.4748638E-04,   3.5204797E-04,   3.5673406E-04
     +,   3.6151914E-04,   3.6637796E-04,   3.7128484E-04
     +,   3.7621296E-04,   3.8113628E-04,   3.8602811E-04
     +,   3.9086243E-04,   3.9561297E-04,   4.0025465E-04
     +,   4.0476184E-04,   4.0911094E-04,   4.1327815E-04
     +,   4.1724124E-04,   4.2097931E-04,   4.2447168E-04
     +,   4.2769959E-04,   4.3064597E-04,   4.3329483E-04
     +,   4.3563196E-04,   4.3764457E-04,   4.3932191E-04
     +,   4.4065478E-04,   4.4163628E-04,   4.4226064E-04
     +,   4.4252462E-04,   4.4242680E-04,   4.4196734E-04
     +,   4.4114937E-04,   4.3997681E-04,   4.3845619E-04
     +,   4.3659643E-04,   4.3440732E-04,   4.3190163E-04
     +,   4.2909343E-04,   4.2599937E-04,   4.2263689E-04
     +,   4.1902656E-04,   4.1518957E-04,   4.1114981E-04
     +,   4.0693214E-04,   4.0256378E-04,   3.9807337E-04
     +,   3.9349127E-04,   3.8884894E-04,   3.8417996E-04
     +,   3.7951974E-04,   3.7490431E-04,   3.7037191E-04
     +,   3.6596227E-04,   3.6171611E-04,   3.5767601E-04
     +,   3.5388500E-04,   3.5038896E-04,   3.4723349E-04
     +,   3.4446613E-04,   3.4213479E-04,   3.4028862E-04
     +,   3.3897744E-04,   3.3825068E-04,   3.3815892E-04
     +,   3.3875174E-04,   3.4007858E-04,   3.4218840E-04
     +,   3.4512806E-04,   3.4894413E-04,   3.5367996E-04
     +,   3.5937876E-04,   3.6607965E-04,   3.7382037E-04
     +,   3.8263705E-04,   3.9256195E-04,   4.0362673E-04
     +,   4.1586137E-04,   4.2929643E-04,   4.4396147E-04
     +,   4.5988779E-04,   4.7711015E-04,   4.9566850E-04
     +,   5.1560631E-04,   5.3697568E-04,   5.5983727E-04
     +,   5.8426219E-04,   6.1032921E-04,   6.3813018E-04
     +,   6.6776766E-04,   6.9935078E-04,   7.3299720E-04
     +,   7.6883205E-04,   8.0698496E-04,   8.4758434E-04
     +,   8.9076016E-04,   9.3664345E-04,   9.8536850E-04
     +,   1.0370674E-03,   1.0918839E-03,   1.1499781E-03
     +,   1.2115345E-03,   1.2767613E-03,   1.3459136E-03
     +,   1.4192872E-03,   1.4972178E-03,   1.5800830E-03
     +,   1.6682900E-03,   1.7622617E-03,   1.8624079E-03
     +,   1.9691153E-03,   2.0827418E-03,   2.2036054E-03
     +,   2.3320008E-03,   2.4682332E-03,   2.6126907E-03
     +,   2.7659147E-03,   2.9286710E-03,   3.1020683E-03
     +,   3.2876271E-03,   3.4873099E-03,   3.7035267E-03
     +,   3.9390405E-03,   4.1967686E-03,   4.4794446E-03
     +,   4.7892518E-03,   5.1274747E-03,   5.4941992E-03
     +,   5.8882306E-03,   6.3072173E-03,   6.7478837E-03
     +,   7.2060502E-03,   7.6763062E-03,   8.1516663E-03
     +,   8.6234575E-03,   9.0827206E-03,   9.5238313E-03
     +,   9.9504804E-03,   1.0381815E-02,   1.0855240E-02
     +,   1.1421790E-02,   1.2132642E-02,   1.3021040E-02
     +,   1.4088179E-02,   1.5301357E-02,   1.6605327E-02
     +,   1.7938003E-02,   1.9241406E-02,   2.0468004E-02
     +,   2.1591920E-02,   2.2635138E-02,   2.3698725E-02
     +,   2.4967091E-02,   2.6649928E-02,   2.8865285E-02
     +,   3.1541325E-02,   3.4443915E-02,   3.7348658E-02
     +,   4.0207695E-02,   4.3116208E-02,   4.6064436E-02
     +,   4.8711814E-02,   5.0429579E-02,   5.0605156E-02
     +,   4.8953038E-02,   4.5601442E-02,   4.0954035E-02
     +,   3.5497665E-02,   2.9693982E-02,   2.3955839E-02
     +,   1.8636061E-02,   1.3995608E-02,   1.0173058E-02
     +,   7.1846405E-03,   4.9549555E-03,   3.3598591E-03
     +,   2.2605390E-03,   1.5261909E-03,   1.0459466E-03
     +,   7.3417020E-04,   5.2995485E-04,   3.9315489E-04
     +,   2.9872594E-04,   2.3150000E-04,   1.8222744E-04
     +,   1.4510618E-04,   1.1638582E-04,   9.3605311E-05
     +,   7.5165372E-05,   6.0035112E-05,   4.7550740E-05
     +,   3.7264199E-05,   2.8848759E-05,   2.2038603E-05
     +,   1.6601352E-05,   1.2324300E-05,   9.0129579E-06
     +,   6.4908031E-06,   4.6018413E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz1128 = Yx/0.282829787234043
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5197624E-04,   1.5645214E-04
     +,   1.6097850E-04,   1.6555518E-04,   1.7018212E-04
     +,   1.7485952E-04,   1.7958738E-04,   1.8436610E-04
     +,   1.8919593E-04,   1.9407722E-04,   1.9901038E-04
     +,   2.0399560E-04,   2.0903313E-04,   2.1412292E-04
     +,   2.1926506E-04,   2.2445909E-04,   2.2970451E-04
     +,   2.3500048E-04,   2.4034563E-04,   2.4573843E-04
     +,   2.5117677E-04,   2.5665821E-04,   2.6217956E-04
     +,   2.6773737E-04,   2.7332723E-04,   2.7894453E-04
     +,   2.8458386E-04,   2.9023926E-04,   2.9590377E-04
     +,   3.0157052E-04,   3.0723118E-04,   3.1287753E-04
     +,   3.1850027E-04,   3.2409022E-04,   3.2963682E-04
     +,   3.3512968E-04,   3.4055789E-04,   3.4591023E-04
     +,   3.5117546E-04,   3.5634165E-04,   3.6139737E-04
     +,   3.6633082E-04,   3.7113047E-04,   3.7578499E-04
     +,   3.8028354E-04,   3.8461492E-04,   3.8876958E-04
     +,   3.9273742E-04,   3.9650989E-04,   4.0007860E-04
     +,   4.0343634E-04,   4.0657664E-04,   4.0949407E-04
     +,   4.1218413E-04,   4.1464344E-04,   4.1687020E-04
     +,   4.1886285E-04,   4.2062183E-04,   4.2214824E-04
     +,   4.2344467E-04,   4.2451467E-04,   4.2536357E-04
     +,   4.2599672E-04,   4.2642170E-04,   4.2664667E-04
     +,   4.2668061E-04,   4.2653395E-04,   4.2621756E-04
     +,   4.2574361E-04,   4.2512486E-04,   4.2437433E-04
     +,   4.2350663E-04,   4.2253578E-04,   4.2147734E-04
     +,   4.2034642E-04,   4.1915884E-04,   4.1793071E-04
     +,   4.1667811E-04,   4.1541713E-04,   4.1416407E-04
     +,   4.1293475E-04,   4.1174571E-04,   4.1061209E-04
     +,   4.0954939E-04,   4.0857273E-04,   4.0769659E-04
     +,   4.0693503E-04,   4.0630129E-04,   4.0580801E-04
     +,   4.0546758E-04,   4.0529069E-04,   4.0528754E-04
     +,   4.0546776E-04,   4.0583935E-04,   4.0640932E-04
     +,   4.0718351E-04,   4.0816658E-04,   4.0936188E-04
     +,   4.1077094E-04,   4.1239438E-04,   4.1423080E-04
     +,   4.1627776E-04,   4.1853052E-04,   4.2098298E-04
     +,   4.2362738E-04,   4.2645456E-04,   4.2945292E-04
     +,   4.3260943E-04,   4.3591010E-04,   4.3933821E-04
     +,   4.4287642E-04,   4.4650532E-04,   4.5020418E-04
     +,   4.5395188E-04,   4.5772491E-04,   4.6149996E-04
     +,   4.6525232E-04,   4.6895718E-04,   4.7258910E-04
     +,   4.7612263E-04,   4.7953328E-04,   4.8279541E-04
     +,   4.8588528E-04,   4.8877980E-04,   4.9145694E-04
     +,   4.9389625E-04,   4.9607916E-04,   4.9798843E-04
     +,   4.9960974E-04,   5.0093030E-04,   5.0194067E-04
     +,   5.0263375E-04,   5.0300459E-04,   5.0305243E-04
     +,   5.0277804E-04,   5.0218613E-04,   5.0128379E-04
     +,   5.0008082E-04,   4.9859029E-04,   4.9682712E-04
     +,   4.9480924E-04,   4.9255654E-04,   4.9009052E-04
     +,   4.8743494E-04,   4.8461440E-04,   4.8165492E-04
     +,   4.7858301E-04,   4.7542548E-04,   4.7220953E-04
     +,   4.6896227E-04,   4.6570943E-04,   4.6247686E-04
     +,   4.5928906E-04,   4.5616925E-04,   4.5313919E-04
     +,   4.5021981E-04,   4.4743056E-04,   4.4478872E-04
     +,   4.4231195E-04,   4.4001552E-04,   4.3791608E-04
     +,   4.3602858E-04,   4.3436975E-04,   4.3295746E-04
     +,   4.3181109E-04,   4.3095311E-04,   4.3040997E-04
     +,   4.3021244E-04,   4.3039679E-04,   4.3100581E-04
     +,   4.3208912E-04,   4.3370482E-04,   4.3591904E-04
     +,   4.3880733E-04,   4.4245378E-04,   4.4695244E-04
     +,   4.5240641E-04,   4.5892669E-04,   4.6663251E-04
     +,   4.7564888E-04,   4.8610856E-04,   4.9814535E-04
     +,   5.1189569E-04,   5.2749796E-04,   5.4508791E-04
     +,   5.6479819E-04,   5.8675511E-04,   6.1108131E-04
     +,   6.3789217E-04,   6.6729373E-04,   6.9938827E-04
     +,   7.3427183E-04,   7.7203609E-04,   8.1277022E-04
     +,   8.5656781E-04,   9.0352667E-04,   9.5375086E-04
     +,   1.0073504E-03,   1.0644523E-03,   1.1251905E-03
     +,   1.1897074E-03,   1.2581446E-03,   1.3306512E-03
     +,   1.4073682E-03,   1.4884156E-03,   1.5739063E-03
     +,   1.6639312E-03,   1.7585570E-03,   1.8578345E-03
     +,   1.9618189E-03,   2.0705760E-03,   2.1841957E-03
     +,   2.3028227E-03,   2.4266925E-03,   2.5561587E-03
     +,   2.6917141E-03,   2.8340421E-03,   2.9840821E-03
     +,   3.1430514E-03,   3.3124862E-03,   3.4942897E-03
     +,   3.6907489E-03,   3.9044914E-03,   4.1384506E-03
     +,   4.3957974E-03,   4.6798107E-03,   4.9937521E-03
     +,   5.3407140E-03,   5.7235514E-03,   6.1448212E-03
     +,   6.6066850E-03,   7.1110413E-03,   7.6595224E-03
     +,   8.2533043E-03,   8.8923592E-03,   9.5741861E-03
     +,   1.0291695E-02,   1.1030863E-02,   1.1769220E-02
     +,   1.2476718E-02,   1.3119821E-02,   1.3669720E-02
     +,   1.4113690E-02,   1.4466515E-02,   1.4778485E-02
     +,   1.5134688E-02,   1.5643027E-02,   1.6409967E-02
     +,   1.7509460E-02,   1.8955458E-02,   2.0691425E-02
     +,   2.2604508E-02,   2.4561815E-02,   2.6454734E-02
     +,   2.8230879E-02,   2.9896976E-02,   3.1495582E-02
     +,   3.3072013E-02,   3.4651779E-02,   3.6233466E-02
     +,   3.7784208E-02,   3.9224647E-02,   4.0409833E-02
     +,   4.1132819E-02,   4.1168611E-02,   4.0343363E-02
     +,   3.8591795E-02,   3.5972197E-02,   3.2640804E-02
     +,   2.8810099E-02,   2.4714632E-02,   2.0588508E-02
     +,   1.6646290E-02,   1.3062415E-02,   9.9541489E-03
     +,   7.3750396E-03,   5.3208629E-03,   3.7461452E-03
     +,   2.5817021E-03,   1.7501446E-03,   1.1760005E-03
     +,   7.9216395E-04,   5.4282462E-04,   3.8440200E-04
     +,   2.8474981E-04,   2.2150157E-04,   1.7993141E-04
     +,   1.5088067E-04,   1.2897060E-04,   1.1122128E-04
     +,   9.6088494E-05,   8.2825063E-05,   7.1098213E-05
     +,   6.0764491E-05,   5.1753152E-05,   4.4003988E-05
     +,   3.7443529E-05,   3.1975287E-05,   2.7483840E-05
     +,   2.3840264E-05,   2.0911895E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz114 = Yx/0.280148936170213
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2642733E-04,   1.3098284E-04
     +,   1.3564256E-04,   1.4040712E-04,   1.4527737E-04
     +,   1.5025433E-04,   1.5533931E-04,   1.6053401E-04
     +,   1.6584032E-04,   1.7126078E-04,   1.7679794E-04
     +,   1.8245510E-04,   1.8823569E-04,   1.9414363E-04
     +,   2.0018335E-04,   2.0635925E-04,   2.1267668E-04
     +,   2.1914068E-04,   2.2575687E-04,   2.3253057E-04
     +,   2.3946752E-04,   2.4657321E-04,   2.5385252E-04
     +,   2.6131084E-04,   2.6895216E-04,   2.7678002E-04
     +,   2.8479719E-04,   2.9300526E-04,   3.0140445E-04
     +,   3.0999360E-04,   3.1876986E-04,   3.2772828E-04
     +,   3.3686223E-04,   3.4616259E-04,   3.5561790E-04
     +,   3.6521399E-04,   3.7493469E-04,   3.8476015E-04
     +,   3.9466907E-04,   4.0463603E-04,   4.1463421E-04
     +,   4.2463344E-04,   4.3460171E-04,   4.4450408E-04
     +,   4.5430410E-04,   4.6396343E-04,   4.7344228E-04
     +,   4.8270018E-04,   4.9169559E-04,   5.0038693E-04
     +,   5.0873286E-04,   5.1669282E-04,   5.2422739E-04
     +,   5.3129939E-04,   5.3787290E-04,   5.4391514E-04
     +,   5.4939679E-04,   5.5429089E-04,   5.5857596E-04
     +,   5.6223368E-04,   5.6525005E-04,   5.6761655E-04
     +,   5.6932896E-04,   5.7038781E-04,   5.7079911E-04
     +,   5.7057297E-04,   5.6972535E-04,   5.6827487E-04
     +,   5.6624628E-04,   5.6366704E-04,   5.6056876E-04
     +,   5.5698591E-04,   5.5295514E-04,   5.4851623E-04
     +,   5.4370955E-04,   5.3857744E-04,   5.3316221E-04
     +,   5.2750693E-04,   5.2165333E-04,   5.1564322E-04
     +,   5.0951663E-04,   5.0331175E-04,   4.9706537E-04
     +,   4.9081090E-04,   4.8458058E-04,   4.7840230E-04
     +,   4.7230290E-04,   4.6630428E-04,   4.6042702E-04
     +,   4.5468795E-04,   4.4910150E-04,   4.4367864E-04
     +,   4.3842912E-04,   4.3335883E-04,   4.2847247E-04
     +,   4.2377281E-04,   4.1926067E-04,   4.1493610E-04
     +,   4.1079696E-04,   4.0684204E-04,   4.0306748E-04
     +,   3.9947077E-04,   3.9604845E-04,   3.9279740E-04
     +,   3.8971458E-04,   3.8679704E-04,   3.8404303E-04
     +,   3.8145095E-04,   3.7901933E-04,   3.7674815E-04
     +,   3.7463719E-04,   3.7268735E-04,   3.7089962E-04
     +,   3.6927563E-04,   3.6781741E-04,   3.6652680E-04
     +,   3.6540569E-04,   3.6445679E-04,   3.6368126E-04
     +,   3.6308132E-04,   3.6265783E-04,   3.6241146E-04
     +,   3.6234246E-04,   3.6245037E-04,   3.6273338E-04
     +,   3.6318999E-04,   3.6381677E-04,   3.6461049E-04
     +,   3.6556646E-04,   3.6668003E-04,   3.6794529E-04
     +,   3.6935613E-04,   3.7090629E-04,   3.7258872E-04
     +,   3.7439712E-04,   3.7632484E-04,   3.7836577E-04
     +,   3.8051393E-04,   3.8276435E-04,   3.8511291E-04
     +,   3.8755703E-04,   3.9009447E-04,   3.9272534E-04
     +,   3.9545106E-04,   3.9827480E-04,   4.0120140E-04
     +,   4.0423794E-04,   4.0739329E-04,   4.1067874E-04
     +,   4.1410702E-04,   4.1769329E-04,   4.2145455E-04
     +,   4.2540950E-04,   4.2957912E-04,   4.3398555E-04
     +,   4.3865273E-04,   4.4360562E-04,   4.4887126E-04
     +,   4.5447779E-04,   4.6045444E-04,   4.6683222E-04
     +,   4.7364380E-04,   4.8092322E-04,   4.8870727E-04
     +,   4.9703522E-04,   5.0595065E-04,   5.1550020E-04
     +,   5.2573538E-04,   5.3671538E-04,   5.4850517E-04
     +,   5.6117761E-04,   5.7481439E-04,   5.8950781E-04
     +,   6.0535921E-04,   6.2247959E-04,   6.4099085E-04
     +,   6.6102267E-04,   6.8271224E-04,   7.0620095E-04
     +,   7.3163409E-04,   7.5915671E-04,   7.8890781E-04
     +,   8.2101696E-04,   8.5560681E-04,   8.9278282E-04
     +,   9.3263219E-04,   9.7522180E-04,   1.0206029E-03
     +,   1.0688076E-03,   1.1198481E-03,   1.1737297E-03
     +,   1.2304519E-03,   1.2900105E-03,   1.3524096E-03
     +,   1.4176655E-03,   1.4858185E-03,   1.5569187E-03
     +,   1.6310351E-03,   1.7082508E-03,   1.7886495E-03
     +,   1.8722919E-03,   1.9591991E-03,   2.0493371E-03
     +,   2.1425940E-03,   2.2387425E-03,   2.3374627E-03
     +,   2.4383287E-03,   2.5408347E-03,   2.6444490E-03
     +,   2.7486854E-03,   2.8532094E-03,   2.9579396E-03
     +,   3.0631977E-03,   3.1698637E-03,   3.2794862E-03
     +,   3.3943765E-03,   3.5176417E-03,   3.6531528E-03
     +,   3.8053705E-03,   3.9790664E-03,   4.1789836E-03
     +,   4.4093584E-03,   4.6734679E-03,   4.9732081E-03
     +,   5.3089298E-03,   5.6794472E-03,   6.0823802E-03
     +,   6.5148571E-03,   6.9744196E-03,   7.4598421E-03
     +,   7.9716071E-03,   8.5118590E-03,   9.0836212E-03
     +,   9.6892025E-03,   1.0328216E-02,   1.0996120E-02
     +,   1.1683811E-02,   1.2378922E-02,   1.3068787E-02
     +,   1.3744106E-02,   1.4401295E-02,   1.5042347E-02
     +,   1.5672853E-02,   1.6299531E-02,   1.6929768E-02
     +,   1.7573971E-02,   1.8248770E-02,   1.8976523E-02
     +,   1.9779053E-02,   2.0666521E-02,   2.1628784E-02
     +,   2.2635266E-02,   2.3645634E-02,   2.4625806E-02
     +,   2.5559714E-02,   2.6450679E-02,   2.7313583E-02
     +,   2.8164247E-02,   2.9010883E-02,   2.9848708E-02
     +,   3.0657372E-02,   3.1400207E-02,   3.2023065E-02
     +,   3.2451034E-02,   3.2582391E-02,   3.2290306E-02
     +,   3.1443033E-02,   2.9944787E-02,   2.7780591E-02
     +,   2.5039181E-02,   2.1900533E-02,   1.8593090E-02
     +,   1.5341841E-02,   1.2327923E-02,   9.6701542E-03
     +,   7.4252510E-03,   5.5984897E-03,   4.1594328E-03
     +,   3.0563856E-03,   2.2295266E-03,   1.6200265E-03
     +,   1.1760837E-03,   8.5524836E-04,   6.2459061E-04
     +,   4.5930000E-04,   3.4104066E-04,   2.5633752E-04
     +,   1.9537059E-04,   1.5106692E-04,   1.1840733E-04
     +,   9.3907569E-05,   7.5186137E-05,   6.0638060E-05
     +,   4.9178336E-05,   4.0066279E-05,   3.2780245E-05
     +,   2.6941418E-05,   2.2262815E-05,   1.8521238E-05
     +,   1.5538049E-05,   1.3169052E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz115 = Yx/0.272255319148936
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0593691E-04,   2.1224095E-04
     +,   2.1855019E-04,   2.2485592E-04,   2.3114975E-04
     +,   2.3742332E-04,   2.4366817E-04,   2.4987629E-04
     +,   2.5603955E-04,   2.6215045E-04,   2.6820161E-04
     +,   2.7418559E-04,   2.8009553E-04,   2.8592520E-04
     +,   2.9166811E-04,   2.9731856E-04,   3.0287111E-04
     +,   3.0832077E-04,   3.1366310E-04,   3.1889355E-04
     +,   3.2400875E-04,   3.2900504E-04,   3.3387973E-04
     +,   3.3863043E-04,   3.4325483E-04,   3.4775143E-04
     +,   3.5211901E-04,   3.5635676E-04,   3.6046430E-04
     +,   3.6444145E-04,   3.6828854E-04,   3.7200612E-04
     +,   3.7559538E-04,   3.7905748E-04,   3.8239404E-04
     +,   3.8560689E-04,   3.8869819E-04,   3.9167033E-04
     +,   3.9452603E-04,   3.9726775E-04,   3.9989891E-04
     +,   4.0242259E-04,   4.0484197E-04,   4.0716058E-04
     +,   4.0938178E-04,   4.1150962E-04,   4.1354736E-04
     +,   4.1549903E-04,   4.1736846E-04,   4.1915959E-04
     +,   4.2087617E-04,   4.2252181E-04,   4.2410052E-04
     +,   4.2561622E-04,   4.2707278E-04,   4.2847358E-04
     +,   4.2982268E-04,   4.3112383E-04,   4.3238059E-04
     +,   4.3359643E-04,   4.3477534E-04,   4.3592110E-04
     +,   4.3703732E-04,   4.3812761E-04,   4.3919624E-04
     +,   4.4024721E-04,   4.4128459E-04,   4.4231297E-04
     +,   4.4333687E-04,   4.4436110E-04,   4.4539096E-04
     +,   4.4643183E-04,   4.4748950E-04,   4.4857030E-04
     +,   4.4968067E-04,   4.5082718E-04,   4.5201750E-04
     +,   4.5325933E-04,   4.5456004E-04,   4.5592830E-04
     +,   4.5737260E-04,   4.5890143E-04,   4.6052309E-04
     +,   4.6224720E-04,   4.6408159E-04,   4.6603524E-04
     +,   4.6811561E-04,   4.7033100E-04,   4.7268771E-04
     +,   4.7519241E-04,   4.7785018E-04,   4.8066548E-04
     +,   4.8364123E-04,   4.8677874E-04,   4.9007841E-04
     +,   4.9353880E-04,   4.9715675E-04,   5.0092681E-04
     +,   5.0484226E-04,   5.0889392E-04,   5.1307154E-04
     +,   5.1736133E-04,   5.2174943E-04,   5.2621827E-04
     +,   5.3075008E-04,   5.3532491E-04,   5.3992111E-04
     +,   5.4451521E-04,   5.4908439E-04,   5.5360352E-04
     +,   5.5804738E-04,   5.6239060E-04,   5.6660717E-04
     +,   5.7067256E-04,   5.7456159E-04,   5.7825109E-04
     +,   5.8171793E-04,   5.8494112E-04,   5.8790116E-04
     +,   5.9058162E-04,   5.9296656E-04,   5.9504295E-04
     +,   5.9680146E-04,   5.9823459E-04,   5.9933687E-04
     +,   6.0010760E-04,   6.0054753E-04,   6.0066069E-04
     +,   6.0045492E-04,   5.9993961E-04,   5.9912796E-04
     +,   5.9803436E-04,   5.9667823E-04,   5.9507927E-04
     +,   5.9326098E-04,   5.9124758E-04,   5.8906624E-04
     +,   5.8674527E-04,   5.8431557E-04,   5.8180885E-04
     +,   5.7925750E-04,   5.7669735E-04,   5.7416270E-04
     +,   5.7168939E-04,   5.6931539E-04,   5.6707812E-04
     +,   5.6501519E-04,   5.6316628E-04,   5.6156988E-04
     +,   5.6026533E-04,   5.5929174E-04,   5.5868912E-04
     +,   5.5849651E-04,   5.5875367E-04,   5.5949832E-04
     +,   5.6077039E-04,   5.6260644E-04,   5.6504493E-04
     +,   5.6812144E-04,   5.7187176E-04,   5.7632971E-04
     +,   5.8152928E-04,   5.8750133E-04,   5.9427641E-04
     +,   6.0188200E-04,   6.1034452E-04,   6.1968772E-04
     +,   6.2993192E-04,   6.4109551E-04,   6.5319322E-04
     +,   6.6623453E-04,   6.8022509E-04,   6.9516554E-04
     +,   7.1105047E-04,   7.2786736E-04,   7.4559712E-04
     +,   7.6421280E-04,   7.8367954E-04,   8.0395298E-04
     +,   8.2498259E-04,   8.4671064E-04,   8.6907187E-04
     +,   8.9199742E-04,   9.1541663E-04,   9.3926152E-04
     +,   9.6346805E-04,   9.8798145E-04,   1.0127637E-03
     +,   1.0377993E-03,   1.0630996E-03,   1.0887112E-03
     +,   1.1147278E-03,   1.1412925E-03,   1.1686077E-03
     +,   1.1969509E-03,   1.2266776E-03,   1.2582280E-03
     +,   1.2921366E-03,   1.3290370E-03,   1.3696646E-03
     +,   1.4148372E-03,   1.4654506E-03,   1.5224518E-03
     +,   1.5868014E-03,   1.6594147E-03,   1.7411183E-03
     +,   1.8325765E-03,   1.9342207E-03,   2.0461935E-03
     +,   2.1683157E-03,   2.3000604E-03,   2.4405539E-03
     +,   2.5886258E-03,   2.7428940E-03,   2.9018517E-03
     +,   3.0639640E-03,   3.2278146E-03,   3.3922133E-03
     +,   3.5563302E-03,   3.7197962E-03,   3.8828761E-03
     +,   4.0466059E-03,   4.2129634E-03,   4.3850117E-03
     +,   4.5670681E-03,   4.7646803E-03,   4.9846238E-03
     +,   5.2346168E-03,   5.5230246E-03,   5.8583110E-03
     +,   6.2482939E-03,   6.6992715E-03,   7.2148461E-03
     +,   7.7945287E-03,   8.4322719E-03,   9.1157611E-03
     +,   9.8267663E-03,   1.0543707E-02,   1.1246747E-02
     +,   1.1924635E-02,   1.2580903E-02,   1.3236293E-02
     +,   1.3924325E-02,   1.4679523E-02,   1.5522423E-02
     +,   1.6449058E-02,   1.7432723E-02,   1.8439414E-02
     +,   1.9449169E-02,   2.0469554E-02,   2.1530738E-02
     +,   2.2662703E-02,   2.3868013E-02,   2.5107760E-02
     +,   2.6309883E-02,   2.7395675E-02,   2.8311567E-02
     +,   2.9050037E-02,   2.9649505E-02,   3.0170871E-02
     +,   3.0659841E-02,   3.1109691E-02,   3.1443734E-02
     +,   3.1526819E-02,   3.1203570E-02,   3.0348128E-02
     +,   2.8904356E-02,   2.6902089E-02,   2.4446532E-02
     +,   2.1689244E-02,   1.8795667E-02,   1.5919447E-02
     +,   1.3187563E-02,   1.0694020E-02,   8.4991790E-03
     +,   6.6315574E-03,   5.0912369E-03,   3.8562948E-03
     +,   2.8900013E-03,   2.1488937E-03,   1.5890875E-03
     +,   1.1708568E-03,   8.6069177E-04,   6.3187192E-04
     +,   4.6375499E-04,   3.4076496E-04,   2.5121108E-04
     +,   1.8633294E-04,   1.3955237E-04,   1.0591477E-04
     +,   8.1715822E-05,   6.4208769E-05,   5.1395044E-05
     +,   4.1845491E-05,   3.4561890E-05,   2.8858931E-05
     +,   2.4275285E-05,   2.0502941E-05,   1.7338056E-05
     +,   1.4644554E-05,   1.2331001E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz116 = Yx/0.257934782608696
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3545037E-04,   2.4227913E-04
     +,   2.4908033E-04,   2.5584342E-04,   2.6255756E-04
     +,   2.6921267E-04,   2.7579910E-04,   2.8230745E-04
     +,   2.8872912E-04,   2.9505647E-04,   3.0128245E-04
     +,   3.0740062E-04,   3.1340623E-04,   3.1929457E-04
     +,   3.2506298E-04,   3.3070907E-04,   3.3623207E-04
     +,   3.4163237E-04,   3.4691131E-04,   3.5207166E-04
     +,   3.5711730E-04,   3.6205302E-04,   3.6688504E-04
     +,   3.7162082E-04,   3.7626803E-04,   3.8083617E-04
     +,   3.8533477E-04,   3.8977471E-04,   3.9416668E-04
     +,   3.9852300E-04,   4.0285531E-04,   4.0717577E-04
     +,   4.1149644E-04,   4.1582965E-04,   4.2018716E-04
     +,   4.2458024E-04,   4.2901956E-04,   4.3351535E-04
     +,   4.3807668E-04,   4.4271161E-04,   4.4742718E-04
     +,   4.5222900E-04,   4.5712138E-04,   4.6210707E-04
     +,   4.6718746E-04,   4.7236256E-04,   4.7762989E-04
     +,   4.8298648E-04,   4.8842706E-04,   4.9394462E-04
     +,   4.9953087E-04,   5.0517631E-04,   5.1086931E-04
     +,   5.1659788E-04,   5.2234798E-04,   5.2810466E-04
     +,   5.3385249E-04,   5.3957495E-04,   5.4525497E-04
     +,   5.5087480E-04,   5.5641698E-04,   5.6186330E-04
     +,   5.6719588E-04,   5.7239732E-04,   5.7745026E-04
     +,   5.8233790E-04,   5.8704446E-04,   5.9155468E-04
     +,   5.9585419E-04,   5.9992942E-04,   6.0376851E-04
     +,   6.0736068E-04,   6.1069604E-04,   6.1376631E-04
     +,   6.1656442E-04,   6.1908510E-04,   6.2132400E-04
     +,   6.2327803E-04,   6.2494585E-04,   6.2632735E-04
     +,   6.2742410E-04,   6.2823831E-04,   6.2877394E-04
     +,   6.2903611E-04,   6.2903069E-04,   6.2876550E-04
     +,   6.2824885E-04,   6.2749034E-04,   6.2650017E-04
     +,   6.2529033E-04,   6.2387262E-04,   6.2226062E-04
     +,   6.2046782E-04,   6.1851001E-04,   6.1640132E-04
     +,   6.1415863E-04,   6.1179872E-04,   6.0933811E-04
     +,   6.0679537E-04,   6.0418784E-04,   6.0153427E-04
     +,   5.9885340E-04,   5.9616443E-04,   5.9348595E-04
     +,   5.9083779E-04,   5.8823818E-04,   5.8570743E-04
     +,   5.8326282E-04,   5.8092404E-04,   5.7870941E-04
     +,   5.7663652E-04,   5.7472265E-04,   5.7298486E-04
     +,   5.7143957E-04,   5.7010172E-04,   5.6898635E-04
     +,   5.6810793E-04,   5.6747923E-04,   5.6711282E-04
     +,   5.6701963E-04,   5.6721107E-04,   5.6769565E-04
     +,   5.6848268E-04,   5.6958018E-04,   5.7099370E-04
     +,   5.7272933E-04,   5.7479209E-04,   5.7718484E-04
     +,   5.7991082E-04,   5.8297062E-04,   5.8636564E-04
     +,   5.9009413E-04,   5.9415417E-04,   5.9854228E-04
     +,   6.0325384E-04,   6.0828211E-04,   6.1362050E-04
     +,   6.1925821E-04,   6.2518584E-04,   6.3138996E-04
     +,   6.3785631E-04,   6.4456800E-04,   6.5150793E-04
     +,   6.5865577E-04,   6.6599069E-04,   6.7348871E-04
     +,   6.8112632E-04,   6.8887701E-04,   6.9671380E-04
     +,   7.0461043E-04,   7.1253895E-04,   7.2047260E-04
     +,   7.2838436E-04,   7.3624926E-04,   7.4404490E-04
     +,   7.5175078E-04,   7.5934891E-04,   7.6682650E-04
     +,   7.7417580E-04,   7.8139291E-04,   7.8848063E-04
     +,   7.9544663E-04,   8.0230780E-04,   8.0908550E-04
     +,   8.1580912E-04,   8.2251511E-04,   8.2924677E-04
     +,   8.3605462E-04,   8.4299373E-04,   8.5012725E-04
     +,   8.5752137E-04,   8.6524739E-04,   8.7337883E-04
     +,   8.8199292E-04,   8.9116639E-04,   9.0097729E-04
     +,   9.1150246E-04,   9.2281611E-04,   9.3498820E-04
     +,   9.4808650E-04,   9.6217130E-04,   9.7729766E-04
     +,   9.9351141E-04,   1.0108524E-03,   1.0293497E-03
     +,   1.0490253E-03,   1.0698881E-03,   1.0919388E-03
     +,   1.1151679E-03,   1.1395562E-03,   1.1650714E-03
     +,   1.1916781E-03,   1.2193281E-03,   1.2479650E-03
     +,   1.2775302E-03,   1.3079585E-03,   1.3391851E-03
     +,   1.3711442E-03,   1.4037803E-03,   1.4370498E-03
     +,   1.4709294E-03,   1.5054238E-03,   1.5405895E-03
     +,   1.5765361E-03,   1.6134479E-03,   1.6516095E-03
     +,   1.6914177E-03,   1.7334019E-03,   1.7782466E-03
     +,   1.8268053E-03,   1.8801164E-03,   1.9393995E-03
     +,   2.0060642E-03,   2.0816945E-03,   2.1680198E-03
     +,   2.2668706E-03,   2.3801138E-03,   2.5095781E-03
     +,   2.6569506E-03,   2.8236583E-03,   3.0107982E-03
     +,   3.2190734E-03,   3.4487527E-03,   3.6997630E-03
     +,   3.9718226E-03,   4.2646364E-03,   4.5781033E-03
     +,   4.9125245E-03,   5.2687554E-03,   5.6481669E-03
     +,   6.0523967E-03,   6.4829900E-03,   6.9408985E-03
     +,   7.4258102E-03,   7.9355966E-03,   8.4660864E-03
     +,   9.0110702E-03,   9.5628574E-03,   1.0113452E-02
     +,   1.0656111E-02,   1.1187146E-02,   1.1707588E-02
     +,   1.2224476E-02,   1.2751529E-02,   1.3308647E-02
     +,   1.3920172E-02,   1.4611647E-02,   1.5405099E-02
     +,   1.6313206E-02,   1.7334051E-02,   1.8448802E-02
     +,   1.9623175E-02,   2.0813344E-02,   2.1973690E-02
     +,   2.3064202E-02,   2.4053602E-02,   2.4918813E-02
     +,   2.5641698E-02,   2.6206756E-02,   2.6600707E-02
     +,   2.6814152E-02,   2.6843550E-02,   2.6690217E-02
     +,   2.6356269E-02,   2.5838548E-02,   2.5124907E-02
     +,   2.4194531E-02,   2.3025014E-02,   2.1603083E-02
     +,   1.9935712E-02,   1.8056752E-02,   1.6026810E-02
     +,   1.3925551E-02,   1.1839547E-02,   9.8497290E-03
     +,   8.0214888E-03,   6.3986573E-03,   5.0032213E-03
     +,   3.8375822E-03,   2.8896031E-03,   2.1373620E-03
     +,   1.5540128E-03,   1.1111981E-03,   7.8175915E-04
     +,   5.4123107E-04,   3.6873153E-04,   2.4711259E-04
     +,   1.6279213E-04,   1.0532002E-04,   6.6832719E-05
     +,   4.1542753E-05,   2.5258805E-05,   1.5002766E-05
     +,   8.6939644E-06,   4.9101163E-06,   2.7000426E-06
     +,   1.4445582E-06,   7.5144476E-07,   3.7989429E-07
     +,   1.8657593E-07,   8.8999393E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz118 = Yx/0.236934782608696
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3212338E-04,   2.3956760E-04
     +,   2.4708407E-04,   2.5466786E-04,   2.6231469E-04
     +,   2.7001993E-04,   2.7777956E-04,   2.8558922E-04
     +,   2.9344528E-04,   3.0134409E-04,   3.0928207E-04
     +,   3.1725594E-04,   3.2526258E-04,   3.3329910E-04
     +,   3.4136258E-04,   3.4945062E-04,   3.5756087E-04
     +,   3.6569082E-04,   3.7383815E-04,   3.8200087E-04
     +,   3.9017675E-04,   3.9836366E-04,   4.0655915E-04
     +,   4.1476154E-04,   4.2296783E-04,   4.3117607E-04
     +,   4.3938300E-04,   4.4758632E-04,   4.5578269E-04
     +,   4.6396846E-04,   4.7214061E-04,   4.8029464E-04
     +,   4.8842671E-04,   4.9653195E-04,   5.0460506E-04
     +,   5.1264185E-04,   5.2063609E-04,   5.2858150E-04
     +,   5.3647300E-04,   5.4430310E-04,   5.5206538E-04
     +,   5.5975269E-04,   5.6735822E-04,   5.7487434E-04
     +,   5.8229355E-04,   5.8960792E-04,   5.9681101E-04
     +,   6.0389424E-04,   6.1085023E-04,   6.1767228E-04
     +,   6.2435289E-04,   6.3088554E-04,   6.3726370E-04
     +,   6.4348197E-04,   6.4953387E-04,   6.5541576E-04
     +,   6.6112360E-04,   6.6665281E-04,   6.7200238E-04
     +,   6.7716971E-04,   6.8215473E-04,   6.8695727E-04
     +,   6.9157919E-04,   6.9602218E-04,   7.0029014E-04
     +,   7.0438790E-04,   7.0832088E-04,   7.1209553E-04
     +,   7.1571959E-04,   7.1920152E-04,   7.2255085E-04
     +,   7.2577724E-04,   7.2889146E-04,   7.3190482E-04
     +,   7.3482865E-04,   7.3767448E-04,   7.4045401E-04
     +,   7.4317789E-04,   7.4585795E-04,   7.4850360E-04
     +,   7.5112528E-04,   7.5373071E-04,   7.5632799E-04
     +,   7.5892342E-04,   7.6152163E-04,   7.6412573E-04
     +,   7.6673826E-04,   7.6935929E-04,   7.7198632E-04
     +,   7.7461754E-04,   7.7724730E-04,   7.7986927E-04
     +,   7.8247552E-04,   7.8505656E-04,   7.8760216E-04
     +,   7.9010043E-04,   7.9253822E-04,   7.9490256E-04
     +,   7.9717889E-04,   7.9935300E-04,   8.0141035E-04
     +,   8.0333644E-04,   8.0511678E-04,   8.0673711E-04
     +,   8.0818409E-04,   8.0944592E-04,   8.1051060E-04
     +,   8.1136700E-04,   8.1200688E-04,   8.1242091E-04
     +,   8.1260299E-04,   8.1254810E-04,   8.1225217E-04
     +,   8.1171334E-04,   8.1093010E-04,   8.0990442E-04
     +,   8.0863858E-04,   8.0713688E-04,   8.0540479E-04
     +,   8.0345018E-04,   8.0128195E-04,   7.9891033E-04
     +,   7.9634809E-04,   7.9360907E-04,   7.9070753E-04
     +,   7.8766042E-04,   7.8448583E-04,   7.8120222E-04
     +,   7.7783043E-04,   7.7439134E-04,   7.7090692E-04
     +,   7.6740084E-04,   7.6389516E-04,   7.6041440E-04
     +,   7.5698202E-04,   7.5362122E-04,   7.5035566E-04
     +,   7.4720749E-04,   7.4419752E-04,   7.4134587E-04
     +,   7.3867134E-04,   7.3618948E-04,   7.3391525E-04
     +,   7.3185924E-04,   7.3003140E-04,   7.2843698E-04
     +,   7.2708004E-04,   7.2595902E-04,   7.2507135E-04
     +,   7.2441128E-04,   7.2396878E-04,   7.2373141E-04
     +,   7.2368543E-04,   7.2381407E-04,   7.2410022E-04
     +,   7.2452368E-04,   7.2506542E-04,   7.2570716E-04
     +,   7.2643021E-04,   7.2721997E-04,   7.2806363E-04
     +,   7.2895293E-04,   7.2988443E-04,   7.3086051E-04
     +,   7.3189050E-04,   7.3299214E-04,   7.3419022E-04
     +,   7.3552050E-04,   7.3702756E-04,   7.3876639E-04
     +,   7.4080238E-04,   7.4321113E-04,   7.4607809E-04
     +,   7.4949965E-04,   7.5357885E-04,   7.5842696E-04
     +,   7.6416339E-04,   7.7091018E-04,   7.7879295E-04
     +,   7.8793720E-04,   7.9846865E-04,   8.1050809E-04
     +,   8.2416803E-04,   8.3955383E-04,   8.5675903E-04
     +,   8.7586226E-04,   8.9692493E-04,   9.1999216E-04
     +,   9.4509113E-04,   9.7222597E-04,   1.0013871E-03
     +,   1.0325462E-03,   1.0656604E-03,   1.1006752E-03
     +,   1.1375367E-03,   1.1761914E-03,   1.2165909E-03
     +,   1.2587043E-03,   1.3025238E-03,   1.3480694E-03
     +,   1.3953889E-03,   1.4445594E-03,   1.4956897E-03
     +,   1.5489112E-03,   1.6043608E-03,   1.6621843E-03
     +,   1.7225164E-03,   1.7854703E-03,   1.8511342E-03
     +,   1.9195765E-03,   1.9908585E-03,   2.0650500E-03
     +,   2.1422654E-03,   2.2227240E-03,   2.3067927E-03
     +,   2.3950539E-03,   2.4883565E-03,   2.5878837E-03
     +,   2.6951830E-03,   2.8121481E-03,   2.9410117E-03
     +,   3.0842419E-03,   3.2443739E-03,   3.4238133E-03
     +,   3.6245831E-03,   3.8480409E-03,   4.0945918E-03
     +,   4.3635224E-03,   4.6529593E-03,   4.9600005E-03
     +,   5.2809864E-03,   5.6120795E-03,   5.9499093E-03
     +,   6.2922416E-03,   6.6385446E-03,   6.9904206E-03
     +,   7.3516448E-03,   7.7278749E-03,   8.1260996E-03
     +,   8.5539399E-03,   9.0189511E-03,   9.5280241E-03
     +,   1.0087183E-02,   1.0701434E-02,   1.1374744E-02
     +,   1.2109553E-02,   1.2906295E-02,   1.3762319E-02
     +,   1.4670822E-02,   1.5619863E-02,   1.6592300E-02
     +,   1.7566429E-02,   1.8517768E-02,   1.9421890E-02
     +,   2.0257866E-02,   2.1011412E-02,   2.1676788E-02
     +,   2.2256704E-02,   2.2759896E-02,   2.3195963E-02
     +,   2.3569588E-02,   2.3874750E-02,   2.4091527E-02
     +,   2.4185427E-02,   2.4110936E-02,   2.3818042E-02
     +,   2.3261160E-02,   2.2408854E-02,   2.1251986E-02
     +,   1.9808350E-02,   1.8122481E-02,   1.6261101E-02
     +,   1.4304376E-02,   1.2335455E-02,   1.0431158E-02
     +,   8.6546252E-03,   7.0508346E-03,   5.6460714E-03
     +,   4.4491235E-03,   3.4548698E-03,   2.6479263E-03
     +,   2.0067894E-03,   1.5070136E-03,   1.1240259E-03
     +,   8.3480071E-04,   6.1905809E-04,   4.5966500E-04
     +,   3.4270936E-04,   2.5725740E-04,   1.9491953E-04
     +,   1.4941563E-04,   1.1610994E-04,   9.1629910E-05
     +,   7.3533723E-05,   6.0063503E-05,   4.9950868E-05
     +,   4.2281707E-05,   3.6393627E-05,   3.1806692E-05
     +,   2.8171396E-05,   2.5233287E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz120 = Yx/0.223086956521739
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1759005E-05,   6.3629304E-05
     +,   6.5534354E-05,   6.7475310E-05,   6.9453556E-05
     +,   7.1470698E-05,   7.3528565E-05,   7.5629228E-05
     +,   7.7774974E-05,   7.9968457E-05,   8.2212449E-05
     +,   8.4510088E-05,   8.6864711E-05,   8.9279885E-05
     +,   9.1759444E-05,   9.4307397E-05,   9.6927935E-05
     +,   9.9625446E-05,   1.0240441E-04,   1.0526945E-04
     +,   1.0822529E-04,   1.1127666E-04,   1.1442837E-04
     +,   1.1768555E-04,   1.2105298E-04,   1.2453600E-04
     +,   1.2814005E-04,   1.3187088E-04,   1.3573487E-04
     +,   1.3973910E-04,   1.4389162E-04,   1.4820196E-04
     +,   1.5268120E-04,   1.5734260E-04,   1.6220220E-04
     +,   1.6727897E-04,   1.7259574E-04,   1.7817931E-04
     +,   1.8406192E-04,   1.9028007E-04,   1.9687683E-04
     +,   2.0390094E-04,   2.1140734E-04,   2.1945755E-04
     +,   2.2811929E-04,   2.3746669E-04,   2.4757977E-04
     +,   2.5854443E-04,   2.7045218E-04,   2.8339989E-04
     +,   2.9749013E-04,   3.1283146E-04,   3.2953834E-04
     +,   3.4773498E-04,   3.6755300E-04,   3.8913896E-04
     +,   4.1265404E-04,   4.3828026E-04,   4.6622497E-04
     +,   4.9672648E-04,   5.3006090E-04,   5.6654803E-04
     +,   6.0655345E-04,   6.5049826E-04,   6.9885649E-04
     +,   7.5214740E-04,   8.1093918E-04,   8.7582186E-04
     +,   9.4740529E-04,   1.0262831E-03,   1.1130287E-03
     +,   1.2081618E-03,   1.3121692E-03,   1.4255031E-03
     +,   1.5486543E-03,   1.6822574E-03,   1.8272318E-03
     +,   1.9850321E-03,   2.1579608E-03,   2.3495376E-03
     +,   2.5648510E-03,   2.8109099E-03,   3.0966336E-03
     +,   3.4325807E-03,   3.8301002E-03,   4.3003019E-03
     +,   4.8529222E-03,   5.4960041E-03,   6.2362077E-03
     +,   7.0803328E-03,   8.0368109E-03,   9.1159279E-03
     +,   1.0327627E-02,   1.1676323E-02,   1.3155144E-02
     +,   1.4744055E-02,   1.6416874E-02,   1.8155010E-02
     +,   1.9962583E-02,   2.1870086E-02,   2.3919510E-02
     +,   2.6126681E-02,   2.8435173E-02,   3.0688992E-02
     +,   3.2658000E-02,   3.4115870E-02,   3.4931559E-02
     +,   3.5124622E-02,   3.4858096E-02,   3.4368403E-02
     +,   3.3852912E-02,   3.3376064E-02,   3.2853168E-02
     +,   3.2109018E-02,   3.0969275E-02,   2.9357258E-02
     +,   2.7365359E-02,   2.5238812E-02,   2.3258531E-02
     +,   2.1601880E-02,   2.0283399E-02,   1.9192684E-02
     +,   1.8176962E-02,   1.7111763E-02,   1.5936341E-02
     +,   1.4656923E-02,   1.3328080E-02,   1.2025614E-02
     +,   1.0820572E-02,   9.7625060E-03,   8.8733435E-03
     +,   8.1507349E-03,   7.5757364E-03,   7.1213017E-03
     +,   6.7582312E-03,   6.4589651E-03,   6.1997436E-03
     +,   5.9618759E-03,   5.7323333E-03,   5.5036573E-03
     +,   5.2729025E-03,   5.0400719E-03,   4.8065051E-03
     +,   4.5736572E-03,   4.3425909E-03,   4.1139503E-03
     +,   3.8883633E-03,   3.6668568E-03,   3.4510861E-03
     +,   3.2432757E-03,   3.0459990E-03,   2.8618057E-03
     +,   2.6928314E-03,   2.5405413E-03,   2.4055911E-03
     +,   2.2878558E-03,   2.1865207E-03,   2.1002523E-03
     +,   2.0273821E-03,   1.9660648E-03,   1.9144005E-03
     +,   1.8705175E-03,   1.8326306E-03,   1.7990714E-03
     +,   1.7683042E-03,   1.7389458E-03,   1.7097857E-03
     +,   1.6798053E-03,   1.6481871E-03,   1.6143322E-03
     +,   1.5778723E-03,   1.5386603E-03,   1.4967566E-03
     +,   1.4524130E-03,   1.4060372E-03,   1.3581592E-03
     +,   1.3093875E-03,   1.2603799E-03,   1.2117986E-03
     +,   1.1642788E-03,   1.1184012E-03,   1.0746805E-03
     +,   1.0335431E-03,   9.9532364E-04,   9.6026319E-04
     +,   9.2851726E-04,   9.0015895E-04,   8.7519054E-04
     +,   8.5355277E-04,   8.3514204E-04,   8.1981492E-04
     +,   8.0740318E-04,   7.9772010E-04,   7.9056836E-04
     +,   7.8574597E-04,   7.8304985E-04,   7.8227755E-04
     +,   7.8323006E-04,   7.8571058E-04,   7.8952615E-04
     +,   7.9448405E-04,   8.0039294E-04,   8.0706296E-04
     +,   8.1430341E-04,   8.2192261E-04,   8.2972873E-04
     +,   8.3753042E-04,   8.4513880E-04,   8.5236685E-04
     +,   8.5903239E-04,   8.6496287E-04,   8.6999417E-04
     +,   8.7397394E-04,   8.7676744E-04,   8.7825547E-04
     +,   8.7834039E-04,   8.7694492E-04,   8.7401620E-04
     +,   8.6952618E-04,   8.6347002E-04,   8.5586839E-04
     +,   8.4676570E-04,   8.3622808E-04,   8.2434388E-04
     +,   8.1121759E-04,   7.9696969E-04,   7.8173453E-04
     +,   7.6565408E-04,   7.4887677E-04,   7.3155173E-04
     +,   7.1382977E-04,   6.9585652E-04,   6.7777070E-04
     +,   6.5970037E-04,   6.4176560E-04,   6.2407122E-04
     +,   6.0670736E-04,   5.8975094E-04,   5.7326414E-04
     +,   5.5729185E-04,   5.4186553E-04,   5.2700384E-04
     +,   5.1271217E-04,   4.9898413E-04,   4.8580309E-04
     +,   4.7314542E-04,   4.6098034E-04,   4.4927126E-04
     +,   4.3797769E-04,   4.2705861E-04,   4.1647040E-04
     +,   4.0617023E-04,   3.9611707E-04,   3.8627215E-04
     +,   3.7659894E-04,   3.6706458E-04,   3.5764015E-04
     +,   3.4830158E-04,   3.3902779E-04,   3.2980225E-04
     +,   3.2061306E-04,   3.1145217E-04,   3.0231490E-04
     +,   2.9319961E-04,   2.8410880E-04,   2.7504694E-04
     +,   2.6602042E-04,   2.5703851E-04,   2.4811181E-04
     +,   2.3925162E-04,   2.3047021E-04,   2.2178079E-04
     +,   2.1319685E-04,   2.0473140E-04,   1.9639723E-04
     +,   1.8820730E-04,   1.8017292E-04,   1.7230585E-04
     +,   1.6461579E-04,   1.5711236E-04,   1.4980343E-04
     +,   1.4269644E-04,   1.3579705E-04,   1.2911049E-04
     +,   1.2264025E-04,   1.1638943E-04,   1.1035954E-04
     +,   1.0455117E-04,   9.8964410E-05,   9.3597970E-05
     +,   8.8450368E-05,   8.3518687E-05,   7.8800091E-05
     +,   7.4290569E-05,   6.9986054E-05,   6.5881650E-05
     +,   6.1972540E-05,   5.8253077E-05,   5.4717875E-05
     +,   5.1360912E-05,   4.8176404E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz75 = Yx/0.282531914893617
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.1456565E-05,   5.3354193E-05
     +,   5.5287870E-05,   5.7256639E-05,   5.9259452E-05
     +,   6.1295243E-05,   6.3362939E-05,   6.5461456E-05
     +,   6.7589688E-05,   6.9746617E-05,   7.1931237E-05
     +,   7.4142547E-05,   7.6379620E-05,   7.8641715E-05
     +,   8.0928054E-05,   8.3238076E-05,   8.5571366E-05
     +,   8.7927612E-05,   9.0306799E-05,   9.2709015E-05
     +,   9.5134732E-05,   9.7584583E-05,   1.0005950E-04
     +,   1.0256095E-04,   1.0509042E-04,   1.0765011E-04
     +,   1.1024249E-04,   1.1287060E-04,   1.1553787E-04
     +,   1.1824839E-04,   1.2100670E-04,   1.2381804E-04
     +,   1.2668829E-04,   1.2962399E-04,   1.3263250E-04
     +,   1.3572177E-04,   1.3890064E-04,   1.4217863E-04
     +,   1.4556643E-04,   1.4907507E-04,   1.5271682E-04
     +,   1.5650457E-04,   1.6045217E-04,   1.6457410E-04
     +,   1.6888567E-04,   1.7340279E-04,   1.7814201E-04
     +,   1.8312027E-04,   1.8835482E-04,   1.9386291E-04
     +,   1.9966184E-04,   2.0576842E-04,   2.1219876E-04
     +,   2.1896829E-04,   2.2609039E-04,   2.3357727E-04
     +,   2.4143883E-04,   2.4968194E-04,   2.5831049E-04
     +,   2.6732482E-04,   2.7672097E-04,   2.8649077E-04
     +,   2.9662042E-04,   3.0709186E-04,   3.1788184E-04
     +,   3.2896115E-04,   3.4029695E-04,   3.5185070E-04
     +,   3.6358248E-04,   3.7544861E-04,   3.8740679E-04
     +,   3.9941567E-04,   4.1144033E-04,   4.2345290E-04
     +,   4.3543987E-04,   4.4740559E-04,   4.5937893E-04
     +,   4.7142067E-04,   4.8363447E-04,   4.9617660E-04
     +,   5.0926965E-04,   5.2321982E-04,   5.3843227E-04
     +,   5.5543438E-04,   5.7489111E-04,   5.9762562E-04
     +,   6.2462484E-04,   6.5704487E-04,   6.9618539E-04
     +,   7.4345618E-04,   8.0031343E-04,   8.6816901E-04
     +,   9.4829849E-04,   1.0417647E-03,   1.1493722E-03
     +,   1.2716888E-03,   1.4092122E-03,   1.5625871E-03
     +,   1.7329990E-03,   1.9225379E-03,   2.1346346E-03
     +,   2.3743287E-03,   2.6485077E-03,   2.9658610E-03
     +,   3.3367118E-03,   3.7723747E-03,   4.2838939E-03
     +,   4.8801554E-03,   5.5655558E-03,   6.3380362E-03
     +,   7.1888384E-03,   8.1059122E-03,   9.0811364E-03
     +,   1.0121132E-02,   1.1256654E-02,   1.2544202E-02
     +,   1.4051435E-02,   1.5826944E-02,   1.7865080E-02
     +,   2.0090669E-02,   2.2379607E-02,   2.4608910E-02
     +,   2.6705300E-02,   2.8661437E-02,   3.0515915E-02
     +,   3.2316010E-02,   3.4069002E-02,   3.5681836E-02
     +,   3.6929697E-02,   3.7525326E-02,   3.7289284E-02
     +,   3.6282811E-02,   3.4759048E-02,   3.2976765E-02
     +,   3.1069305E-02,   2.9080965E-02,   2.7068816E-02
     +,   2.5124842E-02,   2.3316760E-02,   2.1651035E-02
     +,   2.0101327E-02,   1.8648822E-02,   1.7287666E-02
     +,   1.6008262E-02,   1.4791875E-02,   1.3622251E-02
     +,   1.2498529E-02,   1.1437540E-02,   1.0466230E-02
     +,   9.6103083E-03,   8.8844718E-03,   8.2866391E-03
     +,   7.7981413E-03,   7.3896255E-03,   7.0297853E-03
     +,   6.6930046E-03,   6.3633155E-03,   6.0341829E-03
     +,   5.7056970E-03,   5.3810854E-03,   5.0639636E-03
     +,   4.7570951E-03,   4.4621658E-03,   4.1801757E-03
     +,   3.9119041E-03,   3.6582281E-03,   3.4202256E-03
     +,   3.1990695E-03,   2.9958275E-03,   2.8113043E-03
     +,   2.6459082E-03,   2.4995531E-03,   2.3716406E-03
     +,   2.2611085E-03,   2.1665364E-03,   2.0862438E-03
     +,   2.0184412E-03,   1.9613607E-03,   1.9133651E-03
     +,   1.8730290E-03,   1.8391903E-03,   1.8109605E-03
     +,   1.7877035E-03,   1.7689806E-03,   1.7544948E-03
     +,   1.7440175E-03,   1.7373225E-03,   1.7341295E-03
     +,   1.7340649E-03,   1.7366392E-03,   1.7412475E-03
     +,   1.7471778E-03,   1.7536466E-03,   1.7598305E-03
     +,   1.7649143E-03,   1.7681317E-03,   1.7688093E-03
     +,   1.7663970E-03,   1.7605006E-03,   1.7508897E-03
     +,   1.7375075E-03,   1.7204613E-03,   1.7000145E-03
     +,   1.6765527E-03,   1.6505689E-03,   1.6226205E-03
     +,   1.5933046E-03,   1.5632249E-03,   1.5329657E-03
     +,   1.5030646E-03,   1.4739945E-03,   1.4461559E-03
     +,   1.4198675E-03,   1.3953593E-03,   1.3727796E-03
     +,   1.3522037E-03,   1.3336355E-03,   1.3170250E-03
     +,   1.3022737E-03,   1.2892504E-03,   1.2777982E-03
     +,   1.2677448E-03,   1.2589123E-03,   1.2511221E-03
     +,   1.2441977E-03,   1.2379744E-03,   1.2322936E-03
     +,   1.2270079E-03,   1.2219806E-03,   1.2170832E-03
     +,   1.2121942E-03,   1.2071985E-03,   1.2019819E-03
     +,   1.1964311E-03,   1.1904335E-03,   1.1838732E-03
     +,   1.1766306E-03,   1.1685846E-03,   1.1596128E-03
     +,   1.1495908E-03,   1.1383997E-03,   1.1259238E-03
     +,   1.1120585E-03,   1.0967107E-03,   1.0798053E-03
     +,   1.0612870E-03,   1.0411252E-03,   1.0193145E-03
     +,   9.9587464E-04,   9.7086001E-04,   9.4434695E-04
     +,   9.1644085E-04,   8.8727346E-04,   8.5699675E-04
     +,   8.2578062E-04,   7.9380727E-04,   7.6127128E-04
     +,   7.2837115E-04,   6.9530407E-04,   6.6226244E-04
     +,   6.2943326E-04,   5.9699250E-04,   5.6509854E-04
     +,   5.3389528E-04,   5.0351070E-04,   4.7405157E-04
     +,   4.4560590E-04,   4.1824544E-04,   3.9202339E-04
     +,   3.6697517E-04,   3.4312054E-04,   3.2046725E-04
     +,   2.9901080E-04,   2.7873510E-04,   2.5961502E-04
     +,   2.4162058E-04,   2.2471356E-04,   2.0885380E-04
     +,   1.9399624E-04,   1.8009545E-04,   1.6710322E-04
     +,   1.5497296E-04,   1.4365668E-04,   1.3310855E-04
     +,   1.2328281E-04,   1.1413630E-04,   1.0562676E-04
     +,   9.7713695E-05,   9.0359448E-05,   8.3527229E-05
     +,   7.7183184E-05,   7.1294417E-05,   6.5830893E-05
     +,   6.0763534E-05,   5.6065681E-05,   5.1711781E-05
     +,   4.7678463E-05,   4.3943262E-05,   4.0485687E-05
     +,   3.7286089E-05,   3.4326516E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz80 = Yx/0.28
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.9975537E-05,   5.1880888E-05
     +,   5.3848311E-05,   5.5879751E-05,   5.7977126E-05
     +,   6.0142178E-05,   6.2376523E-05,   6.4681633E-05
     +,   6.7058696E-05,   6.9508751E-05,   7.2032439E-05
     +,   7.4630101E-05,   7.7301709E-05,   8.0046826E-05
     +,   8.2864586E-05,   8.5753614E-05,   8.8712084E-05
     +,   9.1737580E-05,   9.4827192E-05,   9.7977456E-05
     +,   1.0118433E-04,   1.0444321E-04,   1.0774891E-04
     +,   1.1109586E-04,   1.1447776E-04,   1.1788804E-04
     +,   1.2131964E-04,   1.2476509E-04,   1.2821674E-04
     +,   1.3166660E-04,   1.3510663E-04,   1.3852865E-04
     +,   1.4192460E-04,   1.4528664E-04,   1.4860710E-04
     +,   1.5187867E-04,   1.5509473E-04,   1.5824899E-04
     +,   1.6133618E-04,   1.6435160E-04,   1.6729179E-04
     +,   1.7015412E-04,   1.7293713E-04,   1.7564063E-04
     +,   1.7826566E-04,   1.8081444E-04,   1.8329082E-04
     +,   1.8569980E-04,   1.8804765E-04,   1.9034206E-04
     +,   1.9259195E-04,   1.9480719E-04,   1.9699898E-04
     +,   1.9917934E-04,   2.0136080E-04,   2.0355692E-04
     +,   2.0578137E-04,   2.0804821E-04,   2.1037141E-04
     +,   2.1276485E-04,   2.1524198E-04,   2.1781572E-04
     +,   2.2049806E-04,   2.2330020E-04,   2.2623240E-04
     +,   2.2930306E-04,   2.3252012E-04,   2.3588941E-04
     +,   2.3941582E-04,   2.4310267E-04,   2.4695226E-04
     +,   2.5096530E-04,   2.5514222E-04,   2.5948198E-04
     +,   2.6398385E-04,   2.6864643E-04,   2.7346888E-04
     +,   2.7845052E-04,   2.8359218E-04,   2.8889618E-04
     +,   2.9436618E-04,   3.0000895E-04,   3.0583344E-04
     +,   3.1185249E-04,   3.1808254E-04,   3.2454525E-04
     +,   3.3126739E-04,   3.3828252E-04,   3.4563153E-04
     +,   3.5336477E-04,   3.6154481E-04,   3.7024647E-04
     +,   3.7956150E-04,   3.8960236E-04,   4.0050552E-04
     +,   4.1243466E-04,   4.2558895E-04,   4.4020393E-04
     +,   4.5656093E-04,   4.7498712E-04,   4.9586542E-04
     +,   5.1963236E-04,   5.4678984E-04,   5.7790196E-04
     +,   6.1361055E-04,   6.5464288E-04,   7.0182717E-04
     +,   7.5611583E-04,   8.1862230E-04,   8.9065422E-04
     +,   9.7374170E-04,   1.0696847E-03,   1.1805438E-03
     +,   1.3086366E-03,   1.4564283E-03,   1.6263939E-03
     +,   1.8207139E-03,   2.0409324E-03,   2.2874295E-03
     +,   2.5589771E-03,   2.8523169E-03,   3.1620022E-03
     +,   3.4807683E-03,   3.8005044E-03,   4.1139349E-03
     +,   4.4169785E-03,   4.7117271E-03,   5.0094365E-03
     +,   5.3329952E-03,   5.7170969E-03,   6.2046647E-03
     +,   6.8382756E-03,   7.6487483E-03,   8.6459359E-03
     +,   9.8189013E-03,   1.1146649E-02,   1.2611908E-02
     +,   1.4204579E-02,   1.5910277E-02,   1.7698923E-02
     +,   1.9538930E-02,   2.1436211E-02,   2.3452349E-02
     +,   2.5647521E-02,   2.7963335E-02,   3.0153386E-02
     +,   3.1869546E-02,   3.2876756E-02,   3.3217434E-02
     +,   3.3167511E-02,   3.3020519E-02,   3.2897580E-02
     +,   3.2740023E-02,   3.2451794E-02,   3.2004509E-02
     +,   3.1388465E-02,   3.0510250E-02,   2.9212493E-02
     +,   2.7411511E-02,   2.5188610E-02,   2.2747371E-02
     +,   2.0311171E-02,   1.8056178E-02,   1.6091859E-02
     +,   1.4458300E-02,   1.3131980E-02,   1.2045874E-02
     +,   1.1120388E-02,   1.0289419E-02,   9.5117586E-03
     +,   8.7698586E-03,   8.0620032E-03,   7.3941383E-03
     +,   6.7741806E-03,   6.2094284E-03,   5.7059256E-03
     +,   5.2686008E-03,   4.9009915E-03,   4.6043238E-03
     +,   4.3766252E-03,   4.2122579E-03,   4.1021239E-03
     +,   4.0344829E-03,   3.9961329E-03,   3.9737616E-03
     +,   3.9552022E-03,   3.9304527E-03,   3.8923048E-03
     +,   3.8365677E-03,   3.7619090E-03,   3.6693444E-03
     +,   3.5615857E-03,   3.4422937E-03,   3.3154355E-03
     +,   3.1847360E-03,   3.0533357E-03,   2.9236325E-03
     +,   2.7972518E-03,   2.6751230E-03,   2.5576563E-03
     +,   2.4449246E-03,   2.3368481E-03,   2.2333188E-03
     +,   2.1343101E-03,   2.0399427E-03,   1.9504589E-03
     +,   1.8662022E-03,   1.7875714E-03,   1.7149445E-03
     +,   1.6486270E-03,   1.5888048E-03,   1.5355309E-03
     +,   1.4887165E-03,   1.4481404E-03,   1.4134904E-03
     +,   1.3843921E-03,   1.3604512E-03,   1.3412790E-03
     +,   1.3265224E-03,   1.3158753E-03,   1.3090819E-03
     +,   1.3059209E-03,   1.3061964E-03,   1.3097053E-03
     +,   1.3162157E-03,   1.3254383E-03,   1.3370104E-03
     +,   1.3504708E-03,   1.3652602E-03,   1.3807203E-03
     +,   1.3961043E-03,   1.4105943E-03,   1.4233335E-03
     +,   1.4334553E-03,   1.4401190E-03,   1.4425518E-03
     +,   1.4400766E-03,   1.4321498E-03,   1.4183838E-03
     +,   1.3985652E-03,   1.3726605E-03,   1.3408198E-03
     +,   1.3033686E-03,   1.2607808E-03,   1.2136627E-03
     +,   1.1627242E-03,   1.1087444E-03,   1.0525341E-03
     +,   9.9490816E-04,   9.3666173E-04,   8.7853189E-04
     +,   8.2118594E-04,   7.6520734E-04,   7.1108603E-04
     +,   6.5920886E-04,   6.0986535E-04,   5.6325662E-04
     +,   5.1949965E-04,   4.7863470E-04,   4.4064125E-04
     +,   4.0545154E-04,   3.7295939E-04,   3.4302953E-04
     +,   3.1550918E-04,   2.9023906E-04,   2.6705427E-04
     +,   2.4579227E-04,   2.2629760E-04,   2.0842330E-04
     +,   1.9203041E-04,   1.7699113E-04,   1.6318864E-04
     +,   1.5051637E-04,   1.3887623E-04,   1.2817918E-04
     +,   1.1834501E-04,   1.0929949E-04,   1.0097591E-04
     +,   9.3312497E-05,   8.6253509E-05,   7.9747100E-05
     +,   7.3746727E-05,   6.8208938E-05,   6.3094747E-05
     +,   5.8367907E-05,   5.3995995E-05,   4.9949049E-05
     +,   4.6199952E-05,   4.2724387E-05,   3.9499941E-05
     +,   3.6506794E-05,   3.3726632E-05,   3.1143289E-05
     +,   2.8741826E-05,   2.6509086E-05,   2.4432826E-05
     +,   2.2502252E-05,   2.0707263E-05,   1.9038895E-05
     +,   1.7488717E-05,   1.6049175E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz85 = Yx/0.268234042553191
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.9417573E-05,   5.1178791E-05
     +,   5.2979503E-05,   5.4820168E-05,   5.6701272E-05
     +,   5.8623376E-05,   6.0587034E-05,   6.2592888E-05
     +,   6.4641514E-05,   6.6733701E-05,   6.8870031E-05
     +,   7.1051189E-05,   7.3277843E-05,   7.5550604E-05
     +,   7.7870078E-05,   8.0236758E-05,   8.2651044E-05
     +,   8.5113301E-05,   8.7623681E-05,   9.0182308E-05
     +,   9.2789058E-05,   9.5443625E-05,   9.8145531E-05
     +,   1.0089422E-04,   1.0368860E-04,   1.0652765E-04
     +,   1.0940994E-04,   1.1233385E-04,   1.1529747E-04
     +,   1.1829865E-04,   1.2133503E-04,   1.2440397E-04
     +,   1.2750270E-04,   1.3062809E-04,   1.3377701E-04
     +,   1.3694608E-04,   1.4013181E-04,   1.4333059E-04
     +,   1.4653904E-04,   1.4975329E-04,   1.5296991E-04
     +,   1.5618533E-04,   1.5939631E-04,   1.6259955E-04
     +,   1.6579209E-04,   1.6897121E-04,   1.7213436E-04
     +,   1.7527943E-04,   1.7840466E-04,   1.8150859E-04
     +,   1.8459011E-04,   1.8764853E-04,   1.9068361E-04
     +,   1.9369565E-04,   1.9668478E-04,   1.9965216E-04
     +,   2.0259884E-04,   2.0552638E-04,   2.0843660E-04
     +,   2.1133157E-04,   2.1421346E-04,   2.1708486E-04
     +,   2.1994821E-04,   2.2280638E-04,   2.2566227E-04
     +,   2.2851865E-04,   2.3137862E-04,   2.3424524E-04
     +,   2.3712187E-04,   2.4001178E-04,   2.4291863E-04
     +,   2.4584620E-04,   2.4879887E-04,   2.5178111E-04
     +,   2.5479824E-04,   2.5785642E-04,   2.6096214E-04
     +,   2.6412311E-04,   2.6734819E-04,   2.7064761E-04
     +,   2.7403247E-04,   2.7751611E-04,   2.8111271E-04
     +,   2.8483881E-04,   2.8871221E-04,   2.9275296E-04
     +,   2.9698265E-04,   3.0142500E-04,   3.0610527E-04
     +,   3.1105062E-04,   3.1629016E-04,   3.2185420E-04
     +,   3.2777456E-04,   3.3408494E-04,   3.4082006E-04
     +,   3.4801569E-04,   3.5570920E-04,   3.6393863E-04
     +,   3.7274379E-04,   3.8216499E-04,   3.9224446E-04
     +,   4.0302536E-04,   4.1455391E-04,   4.2687668E-04
     +,   4.4004482E-04,   4.5411321E-04,   4.6914042E-04
     +,   4.8519025E-04,   5.0233590E-04,   5.2065874E-04
     +,   5.4024940E-04,   5.6121428E-04,   5.8367173E-04
     +,   6.0776068E-04,   6.3363684E-04,   6.6147995E-04
     +,   6.9149100E-04,   7.2389934E-04,   7.5895811E-04
     +,   7.9695095E-04,   8.3818956E-04,   8.8301196E-04
     +,   9.3178393E-04,   9.8489493E-04,   1.0427561E-03
     +,   1.1057800E-03,   1.1743850E-03,   1.2489608E-03
     +,   1.3298688E-03,   1.4174066E-03,   1.5118156E-03
     +,   1.6132585E-03,   1.7218764E-03,   1.8378175E-03
     +,   1.9613765E-03,   2.0931489E-03,   2.2342619E-03
     +,   2.3866701E-03,   2.5534718E-03,   2.7391301E-03
     +,   2.9494925E-03,   3.1914462E-03,   3.4720961E-03
     +,   3.7974275E-03,   4.1707568E-03,   4.5917565E-03
     +,   5.0566690E-03,   5.5605490E-03,   6.1014155E-03
     +,   6.6851079E-03,   7.3282234E-03,   8.0567710E-03
     +,   8.8992463E-03,   9.8757446E-03,   1.0986696E-02
     +,   1.2207286E-02,   1.3492473E-02,   1.4794081E-02
     +,   1.6084790E-02,   1.7376544E-02,   1.8717673E-02
     +,   2.0158194E-02,   2.1694526E-02,   2.3227204E-02
     +,   2.4571732E-02,   2.5532728E-02,   2.6002046E-02
     +,   2.6012043E-02,   2.5707457E-02,   2.5264032E-02
     +,   2.4811082E-02,   2.4390852E-02,   2.3958918E-02
     +,   2.3428606E-02,   2.2751413E-02,   2.1989603E-02
     +,   2.1315841E-02,   2.0917119E-02,   2.0861495E-02
     +,   2.1029193E-02,   2.1166399E-02,   2.1022936E-02
     +,   2.0475686E-02,   1.9559991E-02,   1.8412137E-02
     +,   1.7184801E-02,   1.5993565E-02,   1.4909634E-02
     +,   1.3976312E-02,   1.3220929E-02,   1.2650586E-02
     +,   1.2241448E-02,   1.1936179E-02,   1.1657638E-02
     +,   1.1333404E-02,   1.0917713E-02,   1.0400654E-02
     +,   9.8032011E-03,   9.1641843E-03,   8.5268375E-03
     +,   7.9293223E-03,   7.3997043E-03,   6.9539729E-03
     +,   6.5960949E-03,   6.3193226E-03,   6.1086160E-03
     +,   5.9441123E-03,   5.8049066E-03,   5.6723002E-03
     +,   5.5320226E-03,   5.3751762E-03,   5.1980508E-03
     +,   5.0011226E-03,   4.7876909E-03,   4.5625656E-03
     +,   4.3309522E-03,   4.0977052E-03,   3.8668576E-03
     +,   3.6415178E-03,   3.4239371E-03,   3.2156373E-03
     +,   3.0176421E-03,   2.8306488E-03,   2.6551455E-03
     +,   2.4914388E-03,   2.3396963E-03,   2.1999120E-03
     +,   2.0718838E-03,   1.9552025E-03,   1.8492802E-03
     +,   1.7533916E-03,   1.6667268E-03,   1.5884347E-03
     +,   1.5176814E-03,   1.4536903E-03,   1.3957394E-03
     +,   1.3431739E-03,   1.2954053E-03,   1.2518852E-03
     +,   1.2120955E-03,   1.1755367E-03,   1.1417239E-03
     +,   1.1101820E-03,   1.0804471E-03,   1.0520744E-03
     +,   1.0246512E-03,   9.9779898E-04,   9.7118615E-04
     +,   9.4453001E-04,   9.1760809E-04,   8.9025236E-04
     +,   8.6235115E-04,   8.3384814E-04,   8.0473535E-04
     +,   7.7504572E-04,   7.4484816E-04,   7.1424199E-04
     +,   6.8334898E-04,   6.5230363E-04,   6.2125036E-04
     +,   5.9033866E-04,   5.5971747E-04,   5.2952906E-04
     +,   4.9990736E-04,   4.7097873E-04,   4.4285436E-04
     +,   4.1563137E-04,   3.8939438E-04,   3.6421264E-04
     +,   3.4013842E-04,   3.1720990E-04,   2.9545280E-04
     +,   2.7487922E-04,   2.5548800E-04,   2.3726720E-04
     +,   2.2019702E-04,   2.0424709E-04,   1.8938238E-04
     +,   1.7556021E-04,   1.6273533E-04,   1.5085784E-04
     +,   1.3987717E-04,   1.2974029E-04,   1.2039519E-04
     +,   1.1178909E-04,   1.0387141E-04,   9.6592441E-05
     +,   8.9904192E-05,   8.3761734E-05,   7.8121629E-05
     +,   7.2943636E-05,   6.8189525E-05,   6.3824082E-05
     +,   5.9814163E-05,   5.6129538E-05,   5.2741827E-05
     +,   4.9625400E-05,   4.6756246E-05,   4.4112825E-05
     +,   4.1674994E-05,   3.9424740E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz90 = Yx/0.268234042553191
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4671095E-05,   3.5607394E-05
     +,   3.6551912E-05,   3.7503800E-05,   3.8462138E-05
     +,   3.9426006E-05,   4.0394421E-05,   4.1366438E-05
     +,   4.2341046E-05,   4.3317279E-05,   4.4294164E-05
     +,   4.5270739E-05,   4.6246059E-05,   4.7219237E-05
     +,   4.8189446E-05,   4.9155868E-05,   5.0117840E-05
     +,   5.1074741E-05,   5.2026066E-05,   5.2971423E-05
     +,   5.3910611E-05,   5.4843509E-05,   5.5770204E-05
     +,   5.6691035E-05,   5.7606405E-05,   5.8517122E-05
     +,   5.9424092E-05,   6.0328570E-05,   6.1232022E-05
     +,   6.2136285E-05,   6.3043452E-05,   6.3955922E-05
     +,   6.4876484E-05,   6.5808206E-05,   6.6754554E-05
     +,   6.7719273E-05,   6.8706533E-05,   6.9720780E-05
     +,   7.0766888E-05,   7.1849900E-05,   7.2975272E-05
     +,   7.4148753E-05,   7.5376251E-05,   7.6663942E-05
     +,   7.8018158E-05,   7.9445381E-05,   8.0952137E-05
     +,   8.2544910E-05,   8.4230232E-05,   8.6014443E-05
     +,   8.7903689E-05,   8.9903828E-05,   9.2020287E-05
     +,   9.4258256E-05,   9.6622025E-05,   9.9115598E-05
     +,   1.0174201E-04,   1.0450361E-04,   1.0740181E-04
     +,   1.1043701E-04,   1.1360864E-04,   1.1691493E-04
     +,   1.2035292E-04,   1.2391857E-04,   1.2760662E-04
     +,   1.3141026E-04,   1.3532185E-04,   1.3933201E-04
     +,   1.4343078E-04,   1.4760636E-04,   1.5184657E-04
     +,   1.5613760E-04,   1.6046541E-04,   1.6481466E-04
     +,   1.6916974E-04,   1.7351485E-04,   1.7783353E-04
     +,   1.8210939E-04,   1.8632640E-04,   1.9046913E-04
     +,   1.9452236E-04,   1.9847217E-04,   2.0230557E-04
     +,   2.0601125E-04,   2.0957903E-04,   2.1300146E-04
     +,   2.1627228E-04,   2.1938841E-04,   2.2234872E-04
     +,   2.2515531E-04,   2.2781317E-04,   2.3033009E-04
     +,   2.3271723E-04,   2.3498929E-04,   2.3716422E-04
     +,   2.3926355E-04,   2.4131204E-04,   2.4333807E-04
     +,   2.4537341E-04,   2.4745284E-04,   2.4961442E-04
     +,   2.5189892E-04,   2.5434955E-04,   2.5701185E-04
     +,   2.5993286E-04,   2.6316114E-04,   2.6674574E-04
     +,   2.7073562E-04,   2.7517899E-04,   2.8012306E-04
     +,   2.8561204E-04,   2.9168755E-04,   2.9838653E-04
     +,   3.0574162E-04,   3.1377882E-04,   3.2251855E-04
     +,   3.3197261E-04,   3.4214652E-04,   3.5303604E-04
     +,   3.6463008E-04,   3.7690939E-04,   3.8984648E-04
     +,   4.0340747E-04,   4.1755388E-04,   4.3224436E-04
     +,   4.4743481E-04,   4.6308441E-04,   4.7915563E-04
     +,   4.9562060E-04,   5.1246234E-04,   5.2968151E-04
     +,   5.4729759E-04,   5.6535855E-04,   5.8393850E-04
     +,   6.0314836E-04,   6.2313752E-04,   6.4409641E-04
     +,   6.6625996E-04,   6.8991288E-04,   7.1538740E-04
     +,   7.4306311E-04,   7.7336514E-04,   8.0676022E-04
     +,   8.4375159E-04,   8.8486163E-04,   9.3062816E-04
     +,   9.8158547E-04,   1.0382409E-03,   1.1010612E-03
     +,   1.1704528E-03,   1.2467413E-03,   1.3301451E-03
     +,   1.4207648E-03,   1.5185784E-03,   1.6234294E-03
     +,   1.7350243E-03,   1.8529432E-03,   1.9766907E-03
     +,   2.1057313E-03,   2.2395551E-03,   2.3778086E-03
     +,   2.5204036E-03,   2.6676385E-03,   2.8203169E-03
     +,   2.9797924E-03,   3.1479087E-03,   3.3267974E-03
     +,   3.5186072E-03,   3.7252693E-03,   3.9484985E-03
     +,   4.1904133E-03,   4.4550807E-03,   4.7509698E-03
     +,   5.0936509E-03,   5.5079395E-03,   6.0283351E-03
     +,   6.6964743E-03,   7.5535984E-03,   8.6263176E-03
     +,   9.9073909E-03,   1.1342084E-02,   1.2839295E-02
     +,   1.4319911E-02,   1.5785992E-02,   1.7363697E-02
     +,   1.9271346E-02,   2.1706687E-02,   2.4706567E-02
     +,   2.8063491E-02,   3.1350691E-02,   3.4057833E-02
     +,   3.5826556E-02,   3.6706477E-02,   3.7174996E-02
     +,   3.7748732E-02,   3.8521748E-02,   3.9162617E-02
     +,   3.9315648E-02,   3.8899973E-02,   3.8099751E-02
     +,   3.7139840E-02,   3.5998933E-02,   3.4372721E-02
     +,   3.2020144E-02,   2.9106209E-02,   2.6141221E-02
     +,   2.3629578E-02,   2.1788267E-02,   2.0513941E-02
     +,   1.9534938E-02,   1.8595919E-02,   1.7562123E-02
     +,   1.6417598E-02,   1.5205818E-02,   1.3976725E-02
     +,   1.2769530E-02,   1.1617714E-02,   1.0552933E-02
     +,   9.6008023E-03,   8.7741734E-03,   8.0703720E-03
     +,   7.4739102E-03,   6.9618439E-03,   6.5095997E-03
     +,   6.0961964E-03,   5.7078637E-03,   5.3390441E-03
     +,   4.9907239E-03,   4.6671377E-03,   4.3723080E-03
     +,   4.1077854E-03,   3.8719282E-03,   3.6605713E-03
     +,   3.4684376E-03,   3.2905417E-03,   3.1231097E-03
     +,   2.9639739E-03,   2.8124547E-03,   2.6689004E-03
     +,   2.5341120E-03,   2.4088791E-03,   2.2936214E-03
     +,   2.1882011E-03,   2.0919063E-03,   2.0035522E-03
     +,   1.9216505E-03,   1.8445915E-03,   1.7708155E-03
     +,   1.6989519E-03,   1.6279176E-03,   1.5569489E-03
     +,   1.4856053E-03,   1.4137417E-03,   1.3414517E-03
     +,   1.2690006E-03,   1.1967686E-03,   1.1251969E-03
     +,   1.0547407E-03,   9.8582834E-04,   9.1884314E-04
     +,   8.5411349E-04,   7.9190283E-04,   7.3240558E-04
     +,   6.7575503E-04,   6.2203564E-04,   5.7127897E-04
     +,   5.2347826E-04,   4.7859881E-04,   4.3658185E-04
     +,   3.9734866E-04,   3.6080784E-04,   3.2686291E-04
     +,   2.9541177E-04,   2.6634728E-04,   2.3956092E-04
     +,   2.1494618E-04,   1.9239313E-04,   1.7179431E-04
     +,   1.5304012E-04,   1.3602301E-04,   1.2063366E-04
     +,   1.0676524E-04,   9.4309813E-05,   8.3162493E-05
     +,   7.3218856E-05,   6.4378350E-05,   5.6542704E-05
     +,   4.9617720E-05,   4.3514316E-05,   3.8147598E-05
     +,   3.3438853E-05,   2.9314413E-05,   2.5707079E-05
     +,   2.2555047E-05,   1.9802819E-05,   1.7400165E-05
     +,   1.5302621E-05,   1.3470518E-05,   1.1869174E-05
     +,   1.0468020E-05,   9.2405999E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ttz95 = Yx/0.296531914893617
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8923257E-06,   3.1460947E-06
     +,   3.4176649E-06,   3.7078373E-06,   4.0174077E-06
     +,   4.3471618E-06,   4.6978721E-06,   5.0702915E-06
     +,   5.4651400E-06,   5.8831306E-06,   6.3249204E-06
     +,   6.7911315E-06,   7.2823423E-06,   7.7990790E-06
     +,   8.3418090E-06,   8.9109362E-06,   9.5068035E-06
     +,   1.0129668E-05,   1.0779720E-05,   1.1457056E-05
     +,   1.2161691E-05,   1.2893548E-05,   1.3652438E-05
     +,   1.4438124E-05,   1.5250175E-05,   1.6088152E-05
     +,   1.6951451E-05,   1.7839382E-05,   1.8751140E-05
     +,   1.9685816E-05,   2.0642397E-05,   2.1619771E-05
     +,   2.2616714E-05,   2.3631917E-05,   2.4663972E-05
     +,   2.5711393E-05,   2.6772605E-05,   2.7845945E-05
     +,   2.8929771E-05,   3.0022238E-05,   3.1121599E-05
     +,   3.2226002E-05,   3.3333585E-05,   3.4442473E-05
     +,   3.5550820E-05,   3.6656762E-05,   3.7758527E-05
     +,   3.8854349E-05,   3.9942570E-05,   4.1021602E-05
     +,   4.2089996E-05,   4.3146443E-05,   4.4189801E-05
     +,   4.5219178E-05,   4.6233828E-05,   4.7233367E-05
     +,   4.8217720E-05,   4.9187132E-05,   5.0142291E-05
     +,   5.1084382E-05,   5.2015101E-05,   5.2936768E-05
     +,   5.3852342E-05,   5.4765602E-05,   5.5681139E-05
     +,   5.6604429E-05,   5.7542013E-05,   5.8501450E-05
     +,   5.9491525E-05,   6.0522176E-05,   6.1604725E-05
     +,   6.2751700E-05,   6.3977102E-05,   6.5296081E-05
     +,   6.6725217E-05,   6.8282257E-05,   6.9985974E-05
     +,   7.1855968E-05,   7.3912590E-05,   7.6176671E-05
     +,   7.8668818E-05,   8.1409591E-05,   8.4418469E-05
     +,   8.7714085E-05,   9.1312890E-05,   9.5229581E-05
     +,   9.9475576E-05,   1.0405960E-04,   1.0898613E-04
     +,   1.1425598E-04,   1.1986565E-04,   1.2580668E-04
     +,   1.3206589E-04,   1.3862601E-04,   1.4546518E-04
     +,   1.5255716E-04,   1.5987286E-04,   1.6737946E-04
     +,   1.7504321E-04,   1.8282805E-04,   1.9069891E-04
     +,   1.9862047E-04,   2.0656023E-04,   2.1448775E-04
     +,   2.2237675E-04,   2.3020561E-04,   2.3795696E-04
     +,   2.4561890E-04,   2.5318516E-04,   2.6065472E-04
     +,   2.6803053E-04,   2.7532072E-04,   2.8253542E-04
     +,   2.8968780E-04,   2.9679193E-04,   3.0386160E-04
     +,   3.1091008E-04,   3.1794899E-04,   3.2498702E-04
     +,   3.3203134E-04,   3.3908672E-04,   3.4615654E-04
     +,   3.5324346E-04,   3.6035295E-04,   3.6749366E-04
     +,   3.7467902E-04,   3.8193233E-04,   3.8928591E-04
     +,   3.9678506E-04,   4.0448786E-04,   4.1246621E-04
     +,   4.2080373E-04,   4.2959541E-04,   4.3894147E-04
     +,   4.4894413E-04,   4.5970091E-04,   4.7129596E-04
     +,   4.8379428E-04,   4.9723359E-04,   5.1161926E-04
     +,   5.2691699E-04,   5.4305326E-04,   5.5991637E-04
     +,   5.7736126E-04,   5.9521780E-04,   6.1330583E-04
     +,   6.3144986E-04,   6.4949720E-04,   6.6733820E-04
     +,   6.8492617E-04,   7.0229248E-04,   7.1955653E-04
     +,   7.3693314E-04,   7.5473223E-04,   7.7334628E-04
     +,   7.9323165E-04,   8.1488624E-04,   8.3881622E-04
     +,   8.6550135E-04,   8.9535653E-04,   9.2869956E-04
     +,   9.6571987E-04,   1.0064536E-03,   1.0507748E-03
     +,   1.0984067E-03,   1.1489486E-03,   1.2019273E-03
     +,   1.2568850E-03,   1.3135032E-03,   1.3717395E-03
     +,   1.4319834E-03,   1.4952059E-03,   1.5630684E-03
     +,   1.6379347E-03,   1.7227439E-03,   1.8207467E-03
     +,   1.9350389E-03,   2.0679717E-03,   2.2205207E-03
     +,   2.3917672E-03,   2.5786147E-03,   2.7758891E-03
     +,   2.9769444E-03,   3.1746624E-03,   3.3627141E-03
     +,   3.5368374E-03,   3.6959515E-03,   3.8428549E-03
     +,   3.9844331E-03,   4.1312687E-03,   4.2965729E-03
     +,   4.4943518E-03,   4.7372184E-03,   5.0355750E-03
     +,   5.4011391E-03,   5.8584409E-03,   6.4653032E-03
     +,   7.3392522E-03,   8.6860415E-03,   1.0820450E-02
     +,   1.4136460E-02,   1.9052995E-02,   2.5988489E-02
     +,   3.5234790E-02,   4.9293503E-02,   7.4176364E-02
     +,   0.1094075    ,   0.1569995    ,   0.2134550    
     +,   0.2432997    ,   0.2378173    ,   0.2070058    
     +,   0.1581690    ,   0.1096287    ,   7.3460385E-02
     +,   5.0152544E-02,   3.4375738E-02,   2.3094393E-02
     +,   1.5497955E-02,   1.0446947E-02,   7.0402836E-03
     +,   4.7848900E-03,   3.3196735E-03,   2.3475240E-03
     +,   1.6722522E-03,   1.1898107E-03,   8.4564288E-04
     +,   6.0383475E-04,   4.3600105E-04,   3.1967819E-04
     +,   2.3838592E-04,   1.8088798E-04,   1.3981717E-04
     +,   1.1032059E-04,   8.9077628E-05,   7.3710973E-05
     +,   6.2478677E-05,   5.4106611E-05,   4.7682108E-05
     +,   4.2572650E-05,   3.8356240E-05,   3.4761295E-05
     +,   3.1617608E-05,   2.8819621E-05,   2.6301239E-05
     +,   2.4019440E-05,   2.1944032E-05,   2.0051919E-05
     +,   1.8324225E-05,   1.6744942E-05,   1.5299833E-05
     +,   1.3976288E-05,   1.2763162E-05,   1.1650533E-05
     +,   1.0629503E-05,   9.6921440E-06,   8.8314409E-06
     +,   8.0410928E-06,   7.3153828E-06,   6.6491457E-06
     +,   6.0377379E-06,   5.4769289E-06,   4.9628115E-06
     +,   4.4918097E-06,   4.0606787E-06,   3.6663819E-06
     +,   3.3061140E-06,   2.9773012E-06,   2.6775499E-06
     +,   2.4046119E-06,   2.1563978E-06,   1.9309750E-06
     +,   1.7265395E-06,   1.5413931E-06,   1.3739557E-06
     +,   1.2227694E-06,   1.0864562E-06,   9.6375277E-07
     +,   8.5346915E-07,   7.5451572E-07,   6.6586995E-07
     +,   5.8659776E-07,   5.1582623E-07,   4.5275928E-07
     +,   3.9665619E-07,   3.4684348E-07,   3.0269797E-07
     +,   2.6364887E-07,   2.2917840E-07,   1.9880883E-07
     +,   1.7210893E-07,   1.4868282E-07,   1.2817418E-07
     +,   1.1025747E-07,   9.4640477E-08,   8.1057536E-08
     +,   6.9271316E-08,   5.9066821E-08,   5.0252922E-08
     +,   4.2657437E-08,   3.6127847E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_hatt100 = Yx/0.476960784313725
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7252891E-05,   1.7805267E-05
     +,   1.8371196E-05,   1.8950641E-05,   1.9543551E-05
     +,   2.0149828E-05,   2.0769374E-05,   2.1402060E-05
     +,   2.2047734E-05,   2.2706261E-05,   2.3377464E-05
     +,   2.4061170E-05,   2.4757195E-05,   2.5465350E-05
     +,   2.6185468E-05,   2.6917380E-05,   2.7660923E-05
     +,   2.8415971E-05,   2.9182416E-05,   2.9960191E-05
     +,   3.0749259E-05,   3.1549629E-05,   3.2361379E-05
     +,   3.3184668E-05,   3.4019653E-05,   3.4866669E-05
     +,   3.5726069E-05,   3.6598336E-05,   3.7484031E-05
     +,   3.8383856E-05,   3.9298611E-05,   4.0229243E-05
     +,   4.1176827E-05,   4.2142550E-05,   4.3127809E-05
     +,   4.4134089E-05,   4.5163073E-05,   4.6216570E-05
     +,   4.7296602E-05,   4.8405276E-05,   4.9544946E-05
     +,   5.0718063E-05,   5.1927258E-05,   5.3175329E-05
     +,   5.4465196E-05,   5.5799897E-05,   5.7182660E-05
     +,   5.8616770E-05,   6.0105634E-05,   6.1652776E-05
     +,   6.3261788E-05,   6.4936219E-05,   6.6679801E-05
     +,   6.8496251E-05,   7.0389149E-05,   7.2362243E-05
     +,   7.4419113E-05,   7.6563352E-05,   7.8798388E-05
     +,   8.1127604E-05,   8.3554267E-05,   8.6081520E-05
     +,   8.8712222E-05,   9.1449256E-05,   9.4295356E-05
     +,   9.7252792E-05,   1.0032402E-04,   1.0351094E-04
     +,   1.0681566E-04,   1.1023969E-04,   1.1378474E-04
     +,   1.1745198E-04,   1.2124279E-04,   1.2515791E-04
     +,   1.2919825E-04,   1.3336462E-04,   1.3765735E-04
     +,   1.4207649E-04,   1.4662223E-04,   1.5129468E-04
     +,   1.5609302E-04,   1.6101685E-04,   1.6606503E-04
     +,   1.7123645E-04,   1.7652917E-04,   1.8194146E-04
     +,   1.8747042E-04,   1.9311358E-04,   1.9886701E-04
     +,   2.0472702E-04,   2.1068938E-04,   2.1674889E-04
     +,   2.2289994E-04,   2.2913690E-04,   2.3545373E-04
     +,   2.4184366E-04,   2.4830055E-04,   2.5481737E-04
     +,   2.6138831E-04,   2.6800716E-04,   2.7466915E-04
     +,   2.8137010E-04,   2.8810790E-04,   2.9488161E-04
     +,   3.0169319E-04,   3.0854793E-04,   3.1545421E-04
     +,   3.2242454E-04,   3.2947690E-04,   3.3663530E-04
     +,   3.4392937E-04,   3.5139685E-04,   3.5908251E-04
     +,   3.6704066E-04,   3.7533321E-04,   3.8403241E-04
     +,   3.9321819E-04,   4.0298025E-04,   4.1341528E-04
     +,   4.2462756E-04,   4.3672737E-04,   4.4982898E-04
     +,   4.6404873E-04,   4.7950508E-04,   4.9631664E-04
     +,   5.1459891E-04,   5.3446717E-04,   5.5603281E-04
     +,   5.7940674E-04,   6.0469826E-04,   6.3202030E-04
     +,   6.6148519E-04,   6.9321459E-04,   7.2733458E-04
     +,   7.6398038E-04,   8.0329453E-04,   8.4542093E-04
     +,   8.9049945E-04,   9.3865907E-04,   9.9000253E-04
     +,   1.0445861E-03,   1.1023988E-03,   1.1633493E-03
     +,   1.2272357E-03,   1.2937200E-03,   1.3623254E-03
     +,   1.4324192E-03,   1.5032096E-03,   1.5737613E-03
     +,   1.6430292E-03,   1.7098833E-03,   1.7731636E-03
     +,   1.8317404E-03,   1.8845838E-03,   1.9308208E-03
     +,   1.9698062E-03,   2.0011654E-03,   2.0248450E-03
     +,   2.0411301E-03,   2.0506608E-03,   2.0544226E-03
     +,   2.0537546E-03,   2.0503211E-03,   2.0461259E-03
     +,   2.0435085E-03,   2.0451639E-03,   2.0541528E-03
     +,   2.0739005E-03,   2.1081422E-03,   2.1607999E-03
     +,   2.2357528E-03,   2.3364972E-03,   2.4657142E-03
     +,   2.6247809E-03,   2.8133010E-03,   3.0288224E-03
     +,   3.2667506E-03,   3.5205525E-03,   3.7822793E-03
     +,   4.0433565E-03,   4.2953813E-03,   4.5308941E-03
     +,   4.7439365E-03,   4.9303444E-03,   5.0877426E-03
     +,   5.2154111E-03,   5.3142156E-03,   5.3866515E-03
     +,   5.4371720E-03,   5.4726400E-03,   5.5026887E-03
     +,   5.5396133E-03,   5.5974880E-03,   5.6902799E-03
     +,   5.8291424E-03,   6.0194298E-03,   6.2584211E-03
     +,   6.5349485E-03,   6.8315775E-03,   7.1294466E-03
     +,   7.4144755E-03,   7.6829009E-03,   7.9436852E-03
     +,   8.2160197E-03,   8.5222824E-03,   8.8799344E-03
     +,   9.2994440E-03,   9.7940732E-03,   1.0396071E-02
     +,   1.1157339E-02,   1.2117721E-02,   1.3284489E-02
     +,   1.4721852E-02,   1.6755993E-02,   2.0151699E-02
     +,   2.5961375E-02,   3.5534665E-02,   5.2944463E-02
     +,   8.5136108E-02,   0.1379708    ,   0.2120265    
     +,   0.2745077    ,   0.2681192    ,   0.1873365    
     +,   9.5291927E-02,   3.8864478E-02,   1.3906034E-02
     +,   4.5635351E-03,   1.4747792E-03,   5.5009953E-04
     +,   2.7786091E-04,   1.8358648E-04,   1.4378448E-04
     +,   1.2707872E-04,   1.2010700E-04,   1.1563403E-04
     +,   1.1064603E-04,   1.0444480E-04,   9.7218108E-05
     +,   8.9378227E-05,   8.1337232E-05,   7.3437797E-05
     +,   6.5931512E-05,   5.8978363E-05,   5.2659852E-05
     +,   4.6998022E-05,   4.1974698E-05,   3.7548391E-05
     +,   3.3667355E-05,   3.0277895E-05,   2.7327766E-05
     +,   2.4768095E-05,   2.2553686E-05,   2.0642372E-05
     +,   1.8994619E-05,   1.7573562E-05,   1.6345248E-05
     +,   1.5278714E-05,   1.4346273E-05,   1.3523740E-05
     +,   1.2790534E-05,   1.2129492E-05,   1.1526598E-05
     +,   1.0970703E-05,   1.0453183E-05,   9.9674262E-06
     +,   9.5085052E-06,   9.0728463E-06,   8.6578793E-06
     +,   8.2617562E-06,   7.8831617E-06,   7.5211719E-06
     +,   7.1751024E-06,   6.8443856E-06,   6.5285385E-06
     +,   6.2271383E-06,   5.9397285E-06,   5.6658773E-06
     +,   5.4050965E-06,   5.1569104E-06,   4.9207902E-06
     +,   4.6962200E-06,   4.4826415E-06,   4.2795232E-06
     +,   4.0863047E-06,   3.9024571E-06,   3.7274431E-06
     +,   3.5607443E-06,   3.4018744E-06,   3.2503508E-06
     +,   3.1057336E-06,   2.9675889E-06,   2.8355294E-06
     +,   2.7091769E-06,   2.5881975E-06,   2.4722667E-06
     +,   2.3611017E-06,   2.2544295E-06,   2.1520154E-06
     +,   2.0536320E-06,   1.9590871E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_hatt102 = Yx/0.4263
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_hatt103(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7252891E-05,   1.7805267E-05
     +,   1.8371196E-05,   1.8950641E-05,   1.9543551E-05
     +,   2.0149828E-05,   2.0769374E-05,   2.1402060E-05
     +,   2.2047734E-05,   2.2706261E-05,   2.3377464E-05
     +,   2.4061170E-05,   2.4757195E-05,   2.5465350E-05
     +,   2.6185468E-05,   2.6917380E-05,   2.7660923E-05
     +,   2.8415971E-05,   2.9182416E-05,   2.9960191E-05
     +,   3.0749259E-05,   3.1549629E-05,   3.2361379E-05
     +,   3.3184668E-05,   3.4019653E-05,   3.4866669E-05
     +,   3.5726069E-05,   3.6598336E-05,   3.7484031E-05
     +,   3.8383856E-05,   3.9298611E-05,   4.0229243E-05
     +,   4.1176827E-05,   4.2142550E-05,   4.3127809E-05
     +,   4.4134089E-05,   4.5163073E-05,   4.6216570E-05
     +,   4.7296602E-05,   4.8405276E-05,   4.9544946E-05
     +,   5.0718063E-05,   5.1927258E-05,   5.3175329E-05
     +,   5.4465196E-05,   5.5799897E-05,   5.7182660E-05
     +,   5.8616770E-05,   6.0105634E-05,   6.1652776E-05
     +,   6.3261788E-05,   6.4936219E-05,   6.6679801E-05
     +,   6.8496251E-05,   7.0389149E-05,   7.2362243E-05
     +,   7.4419113E-05,   7.6563352E-05,   7.8798388E-05
     +,   8.1127604E-05,   8.3554267E-05,   8.6081520E-05
     +,   8.8712222E-05,   9.1449256E-05,   9.4295356E-05
     +,   9.7252792E-05,   1.0032402E-04,   1.0351094E-04
     +,   1.0681566E-04,   1.1023969E-04,   1.1378474E-04
     +,   1.1745198E-04,   1.2124279E-04,   1.2515791E-04
     +,   1.2919825E-04,   1.3336462E-04,   1.3765735E-04
     +,   1.4207649E-04,   1.4662223E-04,   1.5129468E-04
     +,   1.5609302E-04,   1.6101685E-04,   1.6606503E-04
     +,   1.7123645E-04,   1.7652917E-04,   1.8194146E-04
     +,   1.8747042E-04,   1.9311358E-04,   1.9886701E-04
     +,   2.0472702E-04,   2.1068938E-04,   2.1674889E-04
     +,   2.2289994E-04,   2.2913690E-04,   2.3545373E-04
     +,   2.4184366E-04,   2.4830055E-04,   2.5481737E-04
     +,   2.6138831E-04,   2.6800716E-04,   2.7466915E-04
     +,   2.8137010E-04,   2.8810790E-04,   2.9488161E-04
     +,   3.0169319E-04,   3.0854793E-04,   3.1545421E-04
     +,   3.2242454E-04,   3.2947690E-04,   3.3663530E-04
     +,   3.4392937E-04,   3.5139685E-04,   3.5908251E-04
     +,   3.6704066E-04,   3.7533321E-04,   3.8403241E-04
     +,   3.9321819E-04,   4.0298025E-04,   4.1341528E-04
     +,   4.2462756E-04,   4.3672737E-04,   4.4982898E-04
     +,   4.6404873E-04,   4.7950508E-04,   4.9631664E-04
     +,   5.1459891E-04,   5.3446717E-04,   5.5603281E-04
     +,   5.7940674E-04,   6.0469826E-04,   6.3202030E-04
     +,   6.6148519E-04,   6.9321459E-04,   7.2733458E-04
     +,   7.6398038E-04,   8.0329453E-04,   8.4542093E-04
     +,   8.9049945E-04,   9.3865907E-04,   9.9000253E-04
     +,   1.0445861E-03,   1.1023988E-03,   1.1633493E-03
     +,   1.2272357E-03,   1.2937200E-03,   1.3623254E-03
     +,   1.4324192E-03,   1.5032096E-03,   1.5737613E-03
     +,   1.6430292E-03,   1.7098833E-03,   1.7731636E-03
     +,   1.8317404E-03,   1.8845838E-03,   1.9308208E-03
     +,   1.9698062E-03,   2.0011654E-03,   2.0248450E-03
     +,   2.0411301E-03,   2.0506608E-03,   2.0544226E-03
     +,   2.0537546E-03,   2.0503211E-03,   2.0461259E-03
     +,   2.0435085E-03,   2.0451639E-03,   2.0541528E-03
     +,   2.0739005E-03,   2.1081422E-03,   2.1607999E-03
     +,   2.2357528E-03,   2.3364972E-03,   2.4657142E-03
     +,   2.6247809E-03,   2.8133010E-03,   3.0288224E-03
     +,   3.2667506E-03,   3.5205525E-03,   3.7822793E-03
     +,   4.0433565E-03,   4.2953813E-03,   4.5308941E-03
     +,   4.7439365E-03,   4.9303444E-03,   5.0877426E-03
     +,   5.2154111E-03,   5.3142156E-03,   5.3866515E-03
     +,   5.4371720E-03,   5.4726400E-03,   5.5026887E-03
     +,   5.5396133E-03,   5.5974880E-03,   5.6902799E-03
     +,   5.8291424E-03,   6.0194298E-03,   6.2584211E-03
     +,   6.5349485E-03,   6.8315775E-03,   7.1294466E-03
     +,   7.4144755E-03,   7.6829009E-03,   7.9436852E-03
     +,   8.2160197E-03,   8.5222824E-03,   8.8799344E-03
     +,   9.2994440E-03,   9.7940732E-03,   1.0396071E-02
     +,   1.1157339E-02,   1.2117721E-02,   1.3284489E-02
     +,   1.4721852E-02,   1.6755993E-02,   2.0151699E-02
     +,   2.5961375E-02,   3.5534665E-02,   5.2944463E-02
     +,   8.5136108E-02,   0.1379708    ,   0.2120265    
     +,   0.2745077    ,   0.2681192    ,   0.1873365    
     +,   9.5291927E-02,   3.8864478E-02,   1.3906034E-02
     +,   4.5635351E-03,   1.4747792E-03,   5.5009953E-04
     +,   2.7786091E-04,   1.8358648E-04,   1.4378448E-04
     +,   1.2707872E-04,   1.2010700E-04,   1.1563403E-04
     +,   1.1064603E-04,   1.0444480E-04,   9.7218108E-05
     +,   8.9378227E-05,   8.1337232E-05,   7.3437797E-05
     +,   6.5931512E-05,   5.8978363E-05,   5.2659852E-05
     +,   4.6998022E-05,   4.1974698E-05,   3.7548391E-05
     +,   3.3667355E-05,   3.0277895E-05,   2.7327766E-05
     +,   2.4768095E-05,   2.2553686E-05,   2.0642372E-05
     +,   1.8994619E-05,   1.7573562E-05,   1.6345248E-05
     +,   1.5278714E-05,   1.4346273E-05,   1.3523740E-05
     +,   1.2790534E-05,   1.2129492E-05,   1.1526598E-05
     +,   1.0970703E-05,   1.0453183E-05,   9.9674262E-06
     +,   9.5085052E-06,   9.0728463E-06,   8.6578793E-06
     +,   8.2617562E-06,   7.8831617E-06,   7.5211719E-06
     +,   7.1751024E-06,   6.8443856E-06,   6.5285385E-06
     +,   6.2271383E-06,   5.9397285E-06,   5.6658773E-06
     +,   5.4050965E-06,   5.1569104E-06,   4.9207902E-06
     +,   4.6962200E-06,   4.4826415E-06,   4.2795232E-06
     +,   4.0863047E-06,   3.9024571E-06,   3.7274431E-06
     +,   3.5607443E-06,   3.4018744E-06,   3.2503508E-06
     +,   3.1057336E-06,   2.9675889E-06,   2.8355294E-06
     +,   2.7091769E-06,   2.5881975E-06,   2.4722667E-06
     +,   2.3611017E-06,   2.2544295E-06,   2.1520154E-06
     +,   2.0536320E-06,   1.9590871E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_hatt103 = Yx/0.4263
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8314695E-05,   1.8995839E-05
     +,   1.9710604E-05,   2.0461322E-05,   2.1250489E-05
     +,   2.2080798E-05,   2.2955131E-05,   2.3876570E-05
     +,   2.4848399E-05,   2.5874178E-05,   2.6957647E-05
     +,   2.8102781E-05,   2.9313807E-05,   3.0595180E-05
     +,   3.1951589E-05,   3.3387965E-05,   3.4909433E-05
     +,   3.6521335E-05,   3.8229202E-05,   4.0038707E-05
     +,   4.1955656E-05,   4.3985958E-05,   4.6135538E-05
     +,   4.8410438E-05,   5.0816434E-05,   5.3359436E-05
     +,   5.6045035E-05,   5.8878621E-05,   6.1865278E-05
     +,   6.5009721E-05,   6.8316258E-05,   7.1788636E-05
     +,   7.5430085E-05,   7.9243262E-05,   8.3230116E-05
     +,   8.7392036E-05,   9.1729722E-05,   9.6243231E-05
     +,   1.0093236E-04,   1.0579602E-04,   1.1083340E-04
     +,   1.1604335E-04,   1.2142506E-04,   1.2697841E-04
     +,   1.3270433E-04,   1.3860541E-04,   1.4468649E-04
     +,   1.5095563E-04,   1.5742474E-04,   1.6411101E-04
     +,   1.7103780E-04,   1.7823628E-04,   1.8574680E-04
     +,   1.9362124E-04,   2.0192382E-04,   2.1073446E-04
     +,   2.2014994E-04,   2.3028626E-04,   2.4128061E-04
     +,   2.5329270E-04,   2.6650637E-04,   2.8112959E-04
     +,   2.9739348E-04,   3.1555374E-04,   3.3588836E-04
     +,   3.5869557E-04,   3.8429847E-04,   4.1304296E-04
     +,   4.4531035E-04,   4.8152194E-04,   5.2216428E-04
     +,   5.6780450E-04,   6.1913132E-04,   6.7698181E-04
     +,   7.4240495E-04,   8.1672444E-04,   9.0163708E-04
     +,   9.9936151E-04,   1.1128560E-03,   1.2460640E-03
     +,   1.4041250E-03,   1.5934909E-03,   1.8216482E-03
     +,   2.0965291E-03,   2.4255824E-03,   2.8154037E-03
     +,   3.2727728E-03,   3.8083366E-03,   4.4417689E-03
     +,   5.2059935E-03,   6.1489865E-03,   7.3397635E-03
     +,   8.8897869E-03,   1.0985157E-02,   1.3889177E-02
     +,   1.7847324E-02,   2.2892823E-02,   2.8774112E-02
     +,   3.5289697E-02,   4.2670779E-02,   5.1086515E-02
     +,   5.9708793E-02,   6.7538880E-02,   7.5224318E-02
     +,   8.3875135E-02,   9.2809103E-02,   9.9693120E-02
     +,   0.1018322    ,   9.8214470E-02,   9.0395838E-02
     +,   8.2826033E-02,   7.6658122E-02,   6.9827162E-02
     +,   6.2069509E-02,   5.4498501E-02,   4.7306795E-02
     +,   4.0503055E-02,   3.4321938E-02,   2.9003428E-02
     +,   2.4841132E-02,   2.1808386E-02,   1.9459387E-02
     +,   1.7346073E-02,   1.5336089E-02,   1.3546952E-02
     +,   1.2107396E-02,   1.1022541E-02,   1.0199434E-02
     +,   9.5276115E-03,   8.9281173E-03,   8.3586285E-03
     +,   7.8007849E-03,   7.2482978E-03,   6.7013586E-03
     +,   6.1646206E-03,   5.6465953E-03,   5.1588956E-03
     +,   4.7145369E-03,   4.3257591E-03,   4.0018894E-03
     +,   3.7479135E-03,   3.5639280E-03,   3.4455494E-03
     +,   3.3848037E-03,   3.3710448E-03,   3.3917350E-03
     +,   3.4331300E-03,   3.4810195E-03,   3.5216368E-03
     +,   3.5427529E-03,   3.5348281E-03,   3.4919421E-03
     +,   3.4123403E-03,   3.2983643E-03,   3.1558329E-03
     +,   2.9929602E-03,   2.8190061E-03,   2.6429724E-03
     +,   2.4725418E-03,   2.3134109E-03,   2.1690461E-03
     +,   2.0408179E-03,   1.9284353E-03,   1.8304536E-03
     +,   1.7448055E-03,   1.6692562E-03,   1.6017091E-03
     +,   1.5403829E-03,   1.4838624E-03,   1.4310874E-03
     +,   1.3812986E-03,   1.3339524E-03,   1.2886561E-03
     +,   1.2451176E-03,   1.2031116E-03,   1.1624545E-03
     +,   1.1230031E-03,   1.0846477E-03,   1.0473173E-03
     +,   1.0109681E-03,   9.7558583E-04,   9.4117876E-04
     +,   9.0776396E-04,   8.7535655E-04,   8.4396056E-04
     +,   8.1356440E-04,   7.8413251E-04,   7.5560209E-04
     +,   7.2788791E-04,   7.0088974E-04,   6.7449221E-04
     +,   6.4857909E-04,   6.2304054E-04,   5.9777993E-04
     +,   5.7271944E-04,   5.4780411E-04,   5.2300940E-04
     +,   4.9833622E-04,   4.7381004E-04,   4.4947900E-04
     +,   4.2541043E-04,   4.0168577E-04,   3.7839194E-04
     +,   3.5561991E-04,   3.3346057E-04,   3.1199696E-04
     +,   2.9130341E-04,   2.7144441E-04,   2.5247136E-04
     +,   2.3442115E-04,   2.1731734E-04,   2.0117163E-04
     +,   1.8598407E-04,   1.7174290E-04,   1.5842781E-04
     +,   1.4601187E-04,   1.3446239E-04,   1.2374129E-04
     +,   1.1380812E-04,   1.0462103E-04,   9.6136733E-05
     +,   8.8311870E-05,   8.1104197E-05,   7.4472555E-05
     +,   6.8376736E-05,   6.2778236E-05,   5.7640784E-05
     +,   5.2929921E-05,   4.8612786E-05,   4.4658478E-05
     +,   4.1038260E-05,   3.7725145E-05,   3.4693727E-05
     +,   3.1920325E-05,   2.9383176E-05,   2.7061833E-05
     +,   2.4937364E-05,   2.2992450E-05,   2.1211106E-05
     +,   1.9578547E-05,   1.8081246E-05,   1.6706934E-05
     +,   1.5444428E-05,   1.4283496E-05,   1.3214841E-05
     +,   1.2230151E-05,   1.1321889E-05,   1.0483222E-05
     +,   9.7079937E-06,   8.9907435E-06,   8.3264877E-06
     +,   7.7107570E-06,   7.1395780E-06,   6.6093685E-06
     +,   6.1168712E-06,   5.6591580E-06,   5.2336140E-06
     +,   4.8378724E-06,   4.4697613E-06,   4.1273092E-06
     +,   3.8087430E-06,   3.5124367E-06,   3.2368830E-06
     +,   2.9806956E-06,   2.7426197E-06,   2.5214699E-06
     +,   2.3161469E-06,   2.1256401E-06,   1.9490062E-06
     +,   1.7853503E-06,   1.6338333E-06,   1.4936795E-06
     +,   1.3641564E-06,   1.2445666E-06,   1.1342526E-06
     +,   1.0326052E-06,   9.3903617E-07,   8.5300201E-07
     +,   7.7397897E-07,   7.0148263E-07,   6.3504700E-07
     +,   5.7424103E-07,   5.1865072E-07,   4.6789401E-07
     +,   4.2160460E-07,   3.7944457E-07,   3.4109252E-07
     +,   3.0624767E-07,   2.7463187E-07,   2.4598097E-07
     +,   2.2005216E-07,   1.9661582E-07,   1.7546131E-07
     +,   1.5639043E-07,   1.3922165E-07,   1.2378460E-07
     +,   1.0992387E-07,   9.7494265E-08,   8.6363450E-08
     +,   7.6408348E-08,   6.7517171E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_hatt75 = Yx/0.44268
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2759847E-05,   2.3245308E-05
     +,   2.3732791E-05,   2.4221896E-05,   2.4712239E-05
     +,   2.5203462E-05,   2.5695248E-05,   2.6187292E-05
     +,   2.6679354E-05,   2.7171236E-05,   2.7662787E-05
     +,   2.8153903E-05,   2.8644543E-05,   2.9134724E-05
     +,   2.9624533E-05,   3.0114110E-05,   3.0603685E-05
     +,   3.1093528E-05,   3.1583997E-05,   3.2075513E-05
     +,   3.2568591E-05,   3.3063767E-05,   3.3561682E-05
     +,   3.4063043E-05,   3.4568595E-05,   3.5079174E-05
     +,   3.5595651E-05,   3.6118945E-05,   3.6650072E-05
     +,   3.7190050E-05,   3.7739945E-05,   3.8300899E-05
     +,   3.8874092E-05,   3.9460756E-05,   4.0062190E-05
     +,   4.0679766E-05,   4.1314957E-05,   4.1969368E-05
     +,   4.2644799E-05,   4.3343218E-05,   4.4066957E-05
     +,   4.4818706E-05,   4.5601624E-05,   4.6419555E-05
     +,   4.7277048E-05,   4.8179714E-05,   4.9134265E-05
     +,   5.0148894E-05,   5.1233445E-05,   5.2399704E-05
     +,   5.3661763E-05,   5.5036213E-05,   5.6542456E-05
     +,   5.8203103E-05,   6.0043800E-05,   6.2093844E-05
     +,   6.4385880E-05,   6.6955894E-05,   6.9843089E-05
     +,   7.3089344E-05,   7.6738761E-05,   8.0836879E-05
     +,   8.5429347E-05,   9.0561407E-05,   9.6276199E-05
     +,   1.0261270E-04,   1.0960536E-04,   1.1728092E-04
     +,   1.2565860E-04,   1.3474663E-04,   1.4454340E-04
     +,   1.5503413E-04,   1.6619332E-04,   1.7798248E-04
     +,   1.9035411E-04,   2.0325316E-04,   2.1662004E-04
     +,   2.3039748E-04,   2.4453914E-04,   2.5902031E-04
     +,   2.7385043E-04,   2.8909597E-04,   3.0490133E-04
     +,   3.2152398E-04,   3.3936909E-04,   3.5903984E-04
     +,   3.8138393E-04,   4.0755249E-04,   4.3904281E-04
     +,   4.7773847E-04,   5.2591407E-04,   5.8619521E-04
     +,   6.6146656E-04,   7.5471617E-04,   8.6880563E-04
     +,   1.0061694E-03,   1.1685141E-03,   1.3564548E-03
     +,   1.5692494E-03,   1.8045342E-03,   2.0583156E-03
     +,   2.3251665E-03,   2.5991451E-03,   2.8755630E-03
     +,   3.1542962E-03,   3.4445031E-03,   3.7701421E-03
     +,   4.1741505E-03,   4.7173663E-03,   5.4673427E-03
     +,   6.4754575E-03,   7.7522323E-03,   9.2664976E-03
     +,   1.1008572E-02,   1.3145777E-02,   1.6208887E-02
     +,   2.1000870E-02,   2.7872408E-02,   3.5949025E-02
     +,   4.3962285E-02,   5.2102070E-02,   6.1469037E-02
     +,   7.2760954E-02,   8.6974069E-02,   0.1035411    
     +,   0.1204966    ,   0.1355689    ,   0.1412857    
     +,   0.1341353    ,   0.1198502    ,   0.1102751    
     +,   0.1024741    ,   9.4274700E-02,   8.3772272E-02
     +,   7.0789061E-02,   5.8735665E-02,   4.9163915E-02
     +,   4.1692737E-02,   3.5517838E-02,   3.0111510E-02
     +,   2.5497094E-02,   2.1952141E-02,   1.9453082E-02
     +,   1.7691309E-02,   1.6321896E-02,   1.5069959E-02
     +,   1.3771361E-02,   1.2404218E-02,   1.1072583E-02
     +,   9.9255340E-03,   9.0637021E-03,   8.4971404E-03
     +,   8.1649059E-03,   7.9796501E-03,   7.8613069E-03
     +,   7.7490392E-03,   7.6000337E-03,   7.3858332E-03
     +,   7.0913550E-03,   6.7158714E-03,   6.2728543E-03
     +,   5.7866322E-03,   5.2862177E-03,   4.7982554E-03
     +,   4.3418785E-03,   3.9269403E-03,   3.5554525E-03
     +,   3.2247051E-03,   2.9304335E-03,   2.6689044E-03
     +,   2.4376253E-03,   2.2349930E-03,   2.0595891E-03
     +,   1.9095819E-03,   1.7824983E-03,   1.6752760E-03
     +,   1.5845808E-03,   1.5071643E-03,   1.4401356E-03
     +,   1.3811128E-03,   1.3282588E-03,   1.2802238E-03
     +,   1.2360218E-03,   1.1949111E-03,   1.1562976E-03
     +,   1.1196678E-03,   1.0845507E-03,   1.0505109E-03
     +,   1.0171586E-03,   9.8417269E-04,   9.5130637E-04
     +,   9.1840461E-04,   8.8540360E-04,   8.5232273E-04
     +,   8.1924791E-04,   7.8631425E-04,   7.5368950E-04
     +,   7.2154863E-04,   6.9005729E-04,   6.5935828E-04
     +,   6.2956498E-04,   6.0075475E-04,   5.7296536E-04
     +,   5.4620171E-04,   5.2044191E-04,   4.9564021E-04
     +,   4.7173724E-04,   4.4866916E-04,   4.2637193E-04
     +,   4.0478693E-04,   3.8386567E-04,   3.6357364E-04
     +,   3.4388964E-04,   3.2480407E-04,   3.0631860E-04
     +,   2.8844512E-04,   2.7120137E-04,   2.5460697E-04
     +,   2.3868182E-04,   2.2344508E-04,   2.0891009E-04
     +,   1.9508449E-04,   1.8197051E-04,   1.6956319E-04
     +,   1.5785050E-04,   1.4681443E-04,   1.3643260E-04
     +,   1.2667869E-04,   1.1752284E-04,   1.0893361E-04
     +,   1.0087951E-04,   9.3329312E-05,   8.6252148E-05
     +,   7.9619014E-05,   7.3403295E-05,   6.7579982E-05
     +,   6.2126295E-05,   5.7021967E-05,   5.2248655E-05
     +,   4.7789443E-05,   4.3628919E-05,   3.9753206E-05
     +,   3.6149322E-05,   3.2804728E-05,   2.9707417E-05
     +,   2.6845915E-05,   2.4208883E-05,   2.1784910E-05
     +,   1.9562638E-05,   1.7530956E-05,   1.5678555E-05
     +,   1.3994204E-05,   1.2466902E-05,   1.1085787E-05
     +,   9.8401242E-06,   8.7194903E-06,   7.7138784E-06
     +,   6.8136746E-06,   6.0096495E-06,   5.2930677E-06
     +,   4.6557552E-06,   4.0900591E-06,   3.5888218E-06
     +,   3.1454347E-06,   2.7538606E-06,   2.4085311E-06
     +,   2.1043838E-06,   1.8368453E-06,   1.6017837E-06
     +,   1.3954678E-06,   1.2145547E-06,   1.0560690E-06
     +,   9.1735814E-07,   7.9605377E-07,   6.9005813E-07
     +,   5.9752341E-07,   5.1680382E-07,   4.4645756E-07
     +,   3.8520386E-07,   3.3192248E-07,   2.8562002E-07
     +,   2.4542868E-07,   2.1057996E-07,   1.8040231E-07
     +,   1.5430197E-07,   1.3176070E-07,   1.1232051E-07
     +,   9.5579978E-08,   8.1188162E-08,   6.8835355E-08
     +,   5.8251842E-08,   4.9199940E-08,   4.1472934E-08
     +,   3.4889137E-08,   2.9290852E-08,   2.4539876E-08
     +,   2.0516572E-08,   1.7116436E-08,   1.4249295E-08
     +,   1.1836723E-08,   9.8112514E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_hatt80 = Yx/0.533098039215686
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2367514E-05,   1.2460119E-05
     +,   1.2562510E-05,   1.2675200E-05,   1.2798692E-05
     +,   1.2933476E-05,   1.3080022E-05,   1.3238786E-05
     +,   1.3410200E-05,   1.3594679E-05,   1.3792602E-05
     +,   1.4004308E-05,   1.4230122E-05,   1.4470321E-05
     +,   1.4725142E-05,   1.4994790E-05,   1.5279413E-05
     +,   1.5579128E-05,   1.5894004E-05,   1.6224054E-05
     +,   1.6569265E-05,   1.6929573E-05,   1.7304863E-05
     +,   1.7695020E-05,   1.8099843E-05,   1.8519164E-05
     +,   1.8952771E-05,   1.9400461E-05,   1.9862040E-05
     +,   2.0337344E-05,   2.0826257E-05,   2.1328751E-05
     +,   2.1844906E-05,   2.2374914E-05,   2.2919188E-05
     +,   2.3478337E-05,   2.4053263E-05,   2.4645191E-05
     +,   2.5255802E-05,   2.5887181E-05,   2.6542046E-05
     +,   2.7223738E-05,   2.7936336E-05,   2.8684779E-05
     +,   2.9474944E-05,   3.0313757E-05,   3.1209296E-05
     +,   3.2170876E-05,   3.3209119E-05,   3.4336004E-05
     +,   3.5564968E-05,   3.6910798E-05,   3.8389659E-05
     +,   4.0019102E-05,   4.1817657E-05,   4.3804979E-05
     +,   4.6001351E-05,   4.8427424E-05,   5.1103852E-05
     +,   5.4050808E-05,   5.7287452E-05,   6.0831531E-05
     +,   6.4698295E-05,   6.8900619E-05,   7.3448020E-05
     +,   7.8345685E-05,   8.3594947E-05,   8.9191715E-05
     +,   9.5127500E-05,   1.0138786E-04,   1.0795417E-04
     +,   1.1480199E-04,   1.2190371E-04,   1.2922724E-04
     +,   1.3673873E-04,   1.4440311E-04,   1.5218502E-04
     +,   1.6005074E-04,   1.6797044E-04,   1.7591908E-04
     +,   1.8387713E-04,   1.9183385E-04,   1.9978601E-04
     +,   2.0774073E-04,   2.1571317E-04,   2.2372881E-04
     +,   2.3181975E-04,   2.4002610E-04,   2.4839106E-04
     +,   2.5696139E-04,   2.6578354E-04,   2.7490084E-04
     +,   2.8435228E-04,   2.9417130E-04,   3.0438561E-04
     +,   3.1501672E-04,   3.2608575E-04,   3.3761509E-04
     +,   3.4963855E-04,   3.6220677E-04,   3.7540111E-04
     +,   3.8934057E-04,   4.0419522E-04,   4.2019217E-04
     +,   4.3762225E-04,   4.5684099E-04,   4.7826246E-04
     +,   5.0235243E-04,   5.2962103E-04,   5.6061434E-04
     +,   5.9591606E-04,   6.3617056E-04,   6.8211381E-04
     +,   7.3464285E-04,   7.9487817E-04,   8.6425786E-04
     +,   9.4458839E-04,   1.0381187E-03,   1.1475616E-03
     +,   1.2761945E-03,   1.4280116E-03,   1.6080011E-03
     +,   1.8225267E-03,   2.0796303E-03,   2.3889409E-03
     +,   2.7609253E-03,   3.2058374E-03,   3.7333211E-03
     +,   4.3553230E-03,   5.0935382E-03,   5.9894831E-03
     +,   7.1089193E-03,   8.5382294E-03,   1.0381692E-02
     +,   1.2759327E-02,   1.5761267E-02,   1.9371985E-02
     +,   2.3578599E-02,   2.8760420E-02,   3.5662048E-02
     +,   4.4355813E-02,   5.3990498E-02,   6.5201804E-02
     +,   7.9105109E-02,   9.2773572E-02,   0.1096601    
     +,   0.1294111    ,   0.1415639    ,   0.1472660    
     +,   0.1412531    ,   0.1344852    ,   0.1267832    
     +,   0.1100074    ,   9.5081590E-02,   8.1849813E-02
     +,   6.7266956E-02,   5.4930918E-02,   4.6283215E-02
     +,   3.9532237E-02,   3.3691019E-02,   2.8597886E-02
     +,   2.4193374E-02,   2.0504519E-02,   1.7547427E-02
     +,   1.5215803E-02,   1.3383545E-02,   1.1996721E-02
     +,   1.1001346E-02,   1.0282857E-02,   9.7092977E-03
     +,   9.1899969E-03,   8.6867604E-03,   8.1922030E-03
     +,   7.7068782E-03,   7.2283084E-03,   6.7502297E-03
     +,   6.2667853E-03,   5.7766582E-03,   5.2847541E-03
     +,   4.8011597E-03,   4.3384824E-03,   3.9088675E-03
     +,   3.5215684E-03,   3.1816915E-03,   2.8901093E-03
     +,   2.6442201E-03,   2.4390568E-03,   2.2684624E-03
     +,   2.1260632E-03,   2.0058919E-03,   1.9026706E-03
     +,   1.8119100E-03,   1.7298807E-03,   1.6535600E-03
     +,   1.5805692E-03,   1.5091565E-03,   1.4381723E-03
     +,   1.3670158E-03,   1.2955634E-03,   1.2240795E-03
     +,   1.1531102E-03,   1.0833605E-03,   1.0155765E-03
     +,   9.5046026E-04,   8.8860287E-04,   8.3042897E-04
     +,   7.7618414E-04,   7.2594074E-04,   6.7961379E-04
     +,   6.3698640E-04,   5.9774943E-04,   5.6153879E-04
     +,   5.2796549E-04,   4.9664103E-04,   4.6720321E-04
     +,   4.3933309E-04,   4.1276318E-04,   3.8727999E-04
     +,   3.6272669E-04,   3.3900150E-04,   3.1604717E-04
     +,   2.9384583E-04,   2.7241174E-04,   2.5178061E-04
     +,   2.3200031E-04,   2.1312427E-04,   1.9520610E-04
     +,   1.7829309E-04,   1.6242081E-04,   1.4761214E-04
     +,   1.3387635E-04,   1.2120781E-04,   1.0958590E-04
     +,   9.8977158E-05,   8.9338151E-05,   8.0615384E-05
     +,   7.2748917E-05,   6.5674925E-05,   5.9327296E-05
     +,   5.3639204E-05,   4.8545331E-05,   4.3983400E-05
     +,   3.9894847E-05,   3.6225294E-05,   3.2925327E-05
     +,   2.9950854E-05,   2.7262764E-05,   2.4826641E-05
     +,   2.2612643E-05,   2.0595300E-05,   1.8752622E-05
     +,   1.7065913E-05,   1.5519376E-05,   1.4099595E-05
     +,   1.2795034E-05,   1.1595813E-05,   1.0493463E-05
     +,   9.4805882E-06,   8.5505726E-06,   7.6975111E-06
     +,   6.9160869E-06,   6.2014174E-06,   5.5489263E-06
     +,   4.9543287E-06,   4.4136468E-06,   3.9230481E-06
     +,   3.4789018E-06,   3.0777794E-06,   2.7164131E-06
     +,   2.3916707E-06,   2.1005810E-06,   1.8403466E-06
     +,   1.6083222E-06,   1.4019989E-06,   1.2190231E-06
     +,   1.0572102E-06,   9.1449874E-07,   7.8899473E-07
     +,   6.7892631E-07,   5.8267545E-07,   4.9874149E-07
     +,   4.2576278E-07,   3.6248787E-07,   3.0778864E-07
     +,   2.6063674E-07,   2.2011170E-07,   1.8538259E-07
     +,   1.5570664E-07,   1.3042451E-07,   1.0894751E-07
     +,   9.0757766E-08,   7.5396478E-08,   6.2462924E-08
     +,   5.1604786E-08,   4.2516540E-08,   3.4931631E-08
     +,   2.8620486E-08,   2.3384366E-08,   1.9053259E-08
     +,   1.5481064E-08,   1.2543704E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_hatt85 = Yx/0.538588235294118
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9706107E-06,   3.3170650E-06
     +,   3.6962090E-06,   4.1099752E-06,   4.5602510E-06
     +,   5.0488552E-06,   5.5775090E-06,   6.1478090E-06
     +,   6.7611877E-06,   7.4189211E-06,   8.1220369E-06
     +,   8.8713332E-06,   9.6673239E-06,   1.0510223E-05
     +,   1.1399910E-05,   1.2335908E-05,   1.3317369E-05
     +,   1.4343045E-05,   1.5411293E-05,   1.6520047E-05
     +,   1.7666838E-05,   1.8848785E-05,   2.0062593E-05
     +,   2.1304675E-05,   2.2570948E-05,   2.3857139E-05
     +,   2.5158650E-05,   2.6470638E-05,   2.7788095E-05
     +,   2.9105904E-05,   3.0418874E-05,   3.1721851E-05
     +,   3.3009768E-05,   3.4277691E-05,   3.5520974E-05
     +,   3.6735280E-05,   3.7916656E-05,   3.9061655E-05
     +,   4.0167415E-05,   4.1231629E-05,   4.2252785E-05
     +,   4.3230106E-05,   4.4163626E-05,   4.5054287E-05
     +,   4.5903966E-05,   4.6715479E-05,   4.7492689E-05
     +,   4.8240407E-05,   4.8964517E-05,   4.9671911E-05
     +,   5.0370483E-05,   5.1069092E-05,   5.1777559E-05
     +,   5.2506588E-05,   5.3267639E-05,   5.4072974E-05
     +,   5.4935426E-05,   5.5868339E-05,   5.6885430E-05
     +,   5.8000634E-05,   5.9227907E-05,   6.0581096E-05
     +,   6.2073603E-05,   6.3718413E-05,   6.5527689E-05
     +,   6.7512468E-05,   6.9682741E-05,   7.2046758E-05
     +,   7.4611351E-05,   7.7381119E-05,   8.0358863E-05
     +,   8.3544706E-05,   8.6936700E-05,   9.0529917E-05
     +,   9.4317067E-05,   9.8288241E-05,   1.0243052E-04
     +,   1.0672844E-04,   1.1116425E-04,   1.1571785E-04
     +,   1.2036666E-04,   1.2508678E-04,   1.2985212E-04
     +,   1.3463607E-04,   1.3941052E-04,   1.4414755E-04
     +,   1.4881858E-04,   1.5339606E-04,   1.5785269E-04
     +,   1.6216270E-04,   1.6630207E-04,   1.7024839E-04
     +,   1.7398159E-04,   1.7748457E-04,   1.8074304E-04
     +,   1.8374559E-04,   1.8648471E-04,   1.8895596E-04
     +,   1.9115937E-04,   1.9309849E-04,   1.9478149E-04
     +,   1.9622089E-04,   1.9743392E-04,   1.9844294E-04
     +,   1.9927538E-04,   1.9996439E-04,   2.0054902E-04
     +,   2.0107438E-04,   2.0159227E-04,   2.0216101E-04
     +,   2.0284658E-04,   2.0372221E-04,   2.0486876E-04
     +,   2.0637574E-04,   2.0834107E-04,   2.1087217E-04
     +,   2.1408648E-04,   2.1811284E-04,   2.2309227E-04
     +,   2.2918051E-04,   2.3655014E-04,   2.4539159E-04
     +,   2.5591650E-04,   2.6835964E-04,   2.8298021E-04
     +,   3.0005816E-04,   3.1989545E-04,   3.4280185E-04
     +,   3.6909018E-04,   3.9905211E-04,   4.3294518E-04
     +,   4.7096450E-04,   5.1323837E-04,   5.5982475E-04
     +,   6.1075896E-04,   6.6614535E-04,   7.2632119E-04
     +,   7.9210353E-04,   8.6510583E-04,   9.4805419E-04
     +,   1.0450139E-03,   1.1614142E-03,   1.3037691E-03
     +,   1.4790919E-03,   1.6942325E-03,   1.9557208E-03
     +,   2.2708236E-03,   2.6506670E-03,   3.1156978E-03
     +,   3.7017693E-03,   4.4616847E-03,   5.4551680E-03
     +,   6.7252805E-03,   8.2732048E-03,   1.0055115E-02
     +,   1.2019159E-02,   1.4177156E-02,   1.6698873E-02
     +,   2.0040220E-02,   2.4981849E-02,   3.2204598E-02
     +,   4.1972902E-02,   5.4924037E-02,   7.1615994E-02
     +,   9.2647508E-02,   0.1128907    ,   0.1287144    
     +,   0.1477565    ,   0.1643933    ,   0.1717054    
     +,   0.1626679    ,   0.1477340    ,   0.1357240    
     +,   0.1167147    ,   9.4036922E-02,   7.8971244E-02
     +,   6.6880666E-02,   5.4251149E-02,   4.4272754E-02
     +,   3.5704959E-02,   2.8704876E-02,   2.3887388E-02
     +,   2.0839954E-02,   1.8617019E-02,   1.6446104E-02
     +,   1.4133231E-02,   1.1881725E-02,   9.9360980E-03
     +,   8.4130885E-03,   7.3123947E-03,   6.5730074E-03
     +,   6.1088693E-03,   5.8270670E-03,   5.6413556E-03
     +,   5.4817270E-03,   5.2985195E-03,   5.0631273E-03
     +,   4.7668386E-03,   4.4175731E-03,   4.0342971E-03
     +,   3.6400713E-03,   3.2557431E-03,   2.8959757E-03
     +,   2.5681693E-03,   2.2736336E-03,   2.0097983E-03
     +,   1.7725577E-03,   1.5580200E-03,   1.3634010E-03
     +,   1.1871974E-03,   1.0288917E-03,   8.8844949E-04
     +,   7.6580304E-04,   6.6049671E-04,   5.7154859E-04
     +,   4.9747486E-04,   4.3642454E-04,   3.8636159E-04
     +,   3.4525443E-04,   3.1122172E-04,   2.8261740E-04
     +,   2.5807886E-04,   2.3653213E-04,   2.1716711E-04
     +,   1.9940067E-04,   1.8283562E-04,   1.6722037E-04
     +,   1.5241114E-04,   1.3833876E-04,   1.2498467E-04
     +,   1.1236148E-04,   1.0049642E-04,   8.9419453E-05
     +,   7.9156351E-05,   6.9724498E-05,   6.1128107E-05
     +,   5.3358282E-05,   4.6393885E-05,   4.0202096E-05
     +,   3.4740042E-05,   2.9957489E-05,   2.5799474E-05
     +,   2.2208049E-05,   1.9124182E-05,   1.6489812E-05
     +,   1.4249365E-05,   1.2350571E-05,   1.0745148E-05
     +,   9.3894059E-06,   8.2445404E-06,   7.2763482E-06
     +,   6.4552219E-06,   5.7559014E-06,   5.1570337E-06
     +,   4.6407349E-06,   4.1922372E-06,   3.7994773E-06
     +,   3.4526695E-06,   3.1439199E-06,   2.8669281E-06
     +,   2.6167102E-06,   2.3893249E-06,   2.1816500E-06
     +,   1.9912218E-06,   1.8161070E-06,   1.6547438E-06
     +,   1.5058724E-06,   1.3684655E-06,   1.2416616E-06
     +,   1.1247121E-06,   1.0169604E-06,   9.1782169E-07
     +,   8.2675848E-07,   7.4326272E-07,   6.6685442E-07
     +,   5.9708350E-07,   5.3350823E-07,   4.7571277E-07
     +,   4.2328890E-07,   3.7585136E-07,   3.3302442E-07
     +,   2.9445388E-07,   2.5979728E-07,   2.2873357E-07
     +,   2.0095489E-07,   1.7617478E-07,   1.5412135E-07
     +,   1.3454063E-07,   1.1719773E-07,   1.0187224E-07
     +,   8.8362441E-08,   7.6480362E-08,   6.6055144E-08
     +,   5.6929100E-08,   4.8959421E-08,   4.2015408E-08
     +,   3.5979546E-08,   3.0744893E-08,   2.6215902E-08
     +,   2.2306274E-08,   1.8939296E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_hatt90 = Yx/0.551627450980392
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.9313003E-06,   5.1582529E-06
     +,   5.3874423E-06,   5.6183189E-06,   5.8503138E-06
     +,   6.0828606E-06,   6.3153816E-06,   6.5473155E-06
     +,   6.7781107E-06,   7.0072538E-06,   7.2342609E-06
     +,   7.4586992E-06,   7.6801998E-06,   7.8984731E-06
     +,   8.1133221E-06,   8.3246523E-06,   8.5325046E-06
     +,   8.7370508E-06,   8.9386367E-06,   9.1377860E-06
     +,   9.3352182E-06,   9.5318810E-06,   9.7289567E-06
     +,   9.9279077E-06,   1.0130448E-05,   1.0338616E-05
     +,   1.0554759E-05,   1.0781558E-05,   1.1022034E-05
     +,   1.1279571E-05,   1.1557912E-05,   1.1861154E-05
     +,   1.2193773E-05,   1.2560573E-05,   1.2966712E-05
     +,   1.3417654E-05,   1.3919146E-05,   1.4477172E-05
     +,   1.5097960E-05,   1.5787809E-05,   1.6553173E-05
     +,   1.7400478E-05,   1.8336101E-05,   1.9366251E-05
     +,   2.0496913E-05,   2.1733711E-05,   2.3081855E-05
     +,   2.4545978E-05,   2.6130101E-05,   2.7837486E-05
     +,   2.9670566E-05,   3.1630836E-05,   3.3718767E-05
     +,   3.5933859E-05,   3.8274313E-05,   4.0737341E-05
     +,   4.3318876E-05,   4.6013687E-05,   4.8815360E-05
     +,   5.1716390E-05,   5.4708173E-05,   5.7781181E-05
     +,   6.0924802E-05,   6.4127897E-05,   6.7378714E-05
     +,   7.0664690E-05,   7.3973351E-05,   7.7291712E-05
     +,   8.0607169E-05,   8.3906954E-05,   8.7179127E-05
     +,   9.0411857E-05,   9.3594528E-05,   9.6717042E-05
     +,   9.9770608E-05,   1.0274774E-04,   1.0564206E-04
     +,   1.0844865E-04,   1.1116431E-04,   1.1378742E-04
     +,   1.1631780E-04,   1.1875732E-04,   1.2110901E-04
     +,   1.2337805E-04,   1.2557083E-04,   1.2769562E-04
     +,   1.2976181E-04,   1.3178051E-04,   1.3376391E-04
     +,   1.3572554E-04,   1.3768020E-04,   1.3964379E-04
     +,   1.4163334E-04,   1.4366744E-04,   1.4576607E-04
     +,   1.4795073E-04,   1.5024537E-04,   1.5267587E-04
     +,   1.5527155E-04,   1.5806452E-04,   1.6109143E-04
     +,   1.6439283E-04,   1.6801433E-04,   1.7200626E-04
     +,   1.7642412E-04,   1.8132820E-04,   1.8678234E-04
     +,   1.9285289E-04,   1.9960769E-04,   2.0711326E-04
     +,   2.1543124E-04,   2.2461696E-04,   2.3471344E-04
     +,   2.4575010E-04,   2.5773598E-04,   2.7065907E-04
     +,   2.8447976E-04,   2.9913188E-04,   3.1451779E-04
     +,   3.3051104E-04,   3.4695721E-04,   3.6367538E-04
     +,   3.8046390E-04,   3.9710815E-04,   4.1338746E-04
     +,   4.2908255E-04,   4.4398854E-04,   4.5792203E-04
     +,   4.7073365E-04,   4.8231357E-04,   4.9260259E-04
     +,   5.0159340E-04,   5.0933636E-04,   5.1593670E-04
     +,   5.2155252E-04,   5.2638858E-04,   5.3068652E-04
     +,   5.3471437E-04,   5.3875439E-04,   5.4309214E-04
     +,   5.4800289E-04,   5.5374432E-04,   5.6054979E-04
     +,   5.6862831E-04,   5.7816412E-04,   5.8932859E-04
     +,   6.0228916E-04,   6.1722583E-04,   6.3434587E-04
     +,   6.5390242E-04,   6.7620340E-04,   7.0161512E-04
     +,   7.3055760E-04,   7.6349149E-04,   8.0088945E-04
     +,   8.4319996E-04,   8.9081592E-04,   9.4406109E-04
     +,   1.0031993E-03,   1.0684958E-03,   1.1403705E-03
     +,   1.2196252E-03,   1.3077598E-03,   1.4073532E-03
     +,   1.5224544E-03,   1.6589210E-03,   1.8247693E-03
     +,   2.0308231E-03,   2.2921558E-03,   2.6305672E-03
     +,   3.0770232E-03,   3.6709441E-03,   4.4529629E-03
     +,   5.4530245E-03,   6.6841124E-03,   8.1538940E-03
     +,   9.8966267E-03,   1.2024297E-02,   1.4802980E-02
     +,   1.8760450E-02,   2.4705136E-02,   3.3094998E-02
     +,   4.3270756E-02,   5.4410525E-02,   6.8175606E-02
     +,   9.2616543E-02,   0.1247401    ,   0.1584541    
     +,   0.1915885    ,   0.2022875    ,   0.1913686    
     +,   0.1777579    ,   0.1550996    ,   0.1249436    
     +,   9.5965371E-02,   7.1542390E-02,   5.2754864E-02
     +,   4.1107003E-02,   3.4433682E-02,   2.9181533E-02
     +,   2.4012275E-02,   1.9340413E-02,   1.5666861E-02
     +,   1.2918182E-02,   1.0811155E-02,   9.1863899E-03
     +,   7.9535618E-03,   6.9912183E-03,   6.1660595E-03
     +,   5.3873630E-03,   4.6241148E-03,   3.8873297E-03
     +,   3.2036533E-03,   2.5969280E-03,   2.0806356E-03
     +,   1.6573434E-03,   1.3210755E-03,   1.0604463E-03
     +,   8.6164428E-04,   7.1081828E-04,   5.9563149E-04
     +,   5.0607597E-04,   4.3461364E-04,   3.7589297E-04
     +,   3.2629515E-04,   2.8347239E-04,   2.4594858E-04
     +,   2.1281128E-04,   1.8349047E-04,   1.5761208E-04
     +,   1.3490202E-04,   1.1512421E-04,   9.8046832E-05
     +,   8.3430234E-05,   7.1025745E-05,   6.0577488E-05
     +,   5.1831816E-05,   4.4545581E-05,   3.8492093E-05
     +,   3.3465687E-05,   2.9284991E-05,   2.5793901E-05
     +,   2.2860575E-05,   2.0375595E-05,   1.8249875E-05
     +,   1.6412105E-05,   1.4805820E-05,   1.3386789E-05
     +,   1.2120795E-05,   1.0981682E-05,   9.9493891E-06
     +,   9.0086505E-06,   8.1478993E-06,   7.3582523E-06
     +,   6.6327784E-06,   5.9659883E-06,   5.3534618E-06
     +,   4.7914887E-06,   4.2768065E-06,   3.8064918E-06
     +,   3.3778647E-06,   2.9883852E-06,   2.6355794E-06
     +,   2.3170460E-06,   2.0304662E-06,   1.7735445E-06
     +,   1.5440390E-06,   1.3397885E-06,   1.1586960E-06
     +,   9.9873307E-07,   8.5796313E-07,   7.3455612E-07
     +,   6.2678322E-07,   5.3301710E-07,   4.5174357E-07
     +,   3.8156881E-07,   3.2120172E-07,   2.6947038E-07
     +,   2.2530273E-07,   1.8773660E-07,   1.5590241E-07
     +,   1.2902777E-07,   1.0642265E-07,   8.7480480E-08
     +,   7.1665262E-08,   5.8510299E-08,   4.7607880E-08
     +,   3.8605169E-08,   3.1198823E-08,   2.5127582E-08
     +,   2.0169233E-08,   1.6134218E-08,   1.2862712E-08
     +,   1.0219669E-08,   8.0922149E-09,   6.3858359E-09
     +,   5.0222031E-09,   3.9363188E-09,   3.0747702E-09
     +,   2.3936177E-09,   1.8570496E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_hatt95 = Yx/0.525
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4301509E-05,   3.5842058E-05
     +,   3.7449394E-05,   3.9124821E-05,   4.0869450E-05
     +,   4.2684253E-05,   4.4569988E-05,   4.6527210E-05
     +,   4.8556172E-05,   5.0656996E-05,   5.2829448E-05
     +,   5.5072982E-05,   5.7386762E-05,   5.9769638E-05
     +,   6.2220090E-05,   6.4736239E-05,   6.7315865E-05
     +,   6.9956317E-05,   7.2654613E-05,   7.5407290E-05
     +,   7.8210614E-05,   8.1060367E-05,   8.3951927E-05
     +,   8.6880500E-05,   8.9840636E-05,   9.2826849E-05
     +,   9.5833209E-05,   9.8853518E-05,   1.0188137E-04
     +,   1.0491021E-04,   1.0793329E-04,   1.1094385E-04
     +,   1.1393503E-04,   1.1690006E-04,   1.1983238E-04
     +,   1.2272547E-04,   1.2557312E-04,   1.2836955E-04
     +,   1.3110935E-04,   1.3378760E-04,   1.3640005E-04
     +,   1.3894316E-04,   1.4141398E-04,   1.4381060E-04
     +,   1.4613208E-04,   1.4837827E-04,   1.5055026E-04
     +,   1.5265027E-04,   1.5468174E-04,   1.5664933E-04
     +,   1.5855895E-04,   1.6041788E-04,   1.6223482E-04
     +,   1.6401985E-04,   1.6578415E-04,   1.6754065E-04
     +,   1.6930334E-04,   1.7108745E-04,   1.7290973E-04
     +,   1.7478770E-04,   1.7674024E-04,   1.7878716E-04
     +,   1.8094885E-04,   1.8324654E-04,   1.8570210E-04
     +,   1.8833742E-04,   1.9117484E-04,   1.9423614E-04
     +,   1.9754315E-04,   2.0111665E-04,   2.0497674E-04
     +,   2.0914193E-04,   2.1362948E-04,   2.1845418E-04
     +,   2.2362875E-04,   2.2916349E-04,   2.3506500E-04
     +,   2.4133675E-04,   2.4797843E-04,   2.5498611E-04
     +,   2.6235037E-04,   2.7005869E-04,   2.7809234E-04
     +,   2.8642907E-04,   2.9504072E-04,   3.0389542E-04
     +,   3.1295529E-04,   3.2217981E-04,   3.3152290E-04
     +,   3.4093589E-04,   3.5036783E-04,   3.5976444E-04
     +,   3.6907027E-04,   3.7823012E-04,   3.8718942E-04
     +,   3.9589405E-04,   4.0429400E-04,   4.1234144E-04
     +,   4.1999464E-04,   4.2721667E-04,   4.3397804E-04
     +,   4.4025562E-04,   4.4603608E-04,   4.5131322E-04
     +,   4.5609029E-04,   4.6038022E-04,   4.6420435E-04
     +,   4.6759265E-04,   4.7058330E-04,   4.7322188E-04
     +,   4.7556005E-04,   4.7765460E-04,   4.7956579E-04
     +,   4.8135631E-04,   4.8308927E-04,   4.8482628E-04
     +,   4.8662635E-04,   4.8854476E-04,   4.9062964E-04
     +,   4.9292250E-04,   4.9545639E-04,   4.9825467E-04
     +,   5.0133024E-04,   5.0468626E-04,   5.0831470E-04
     +,   5.1219674E-04,   5.1630486E-04,   5.2060088E-04
     +,   5.2503968E-04,   5.2956870E-04,   5.3413061E-04
     +,   5.3866353E-04,   5.4310414E-04,   5.4738892E-04
     +,   5.5145496E-04,   5.5524282E-04,   5.5869727E-04
     +,   5.6176801E-04,   5.6441204E-04,   5.6659355E-04
     +,   5.6828494E-04,   5.6946685E-04,   5.7012803E-04
     +,   5.7026610E-04,   5.6988653E-04,   5.6900253E-04
     +,   5.6763471E-04,   5.6580978E-04,   5.6356104E-04
     +,   5.6092738E-04,   5.5795227E-04,   5.5468449E-04
     +,   5.5117806E-04,   5.4749078E-04,   5.4368551E-04
     +,   5.3983042E-04,   5.3599960E-04,   5.3227186E-04
     +,   5.2873394E-04,   5.2547769E-04,   5.2260334E-04
     +,   5.2021811E-04,   5.1843672E-04,   5.1738153E-04
     +,   5.1718287E-04,   5.1797769E-04,   5.1991065E-04
     +,   5.2313349E-04,   5.2780594E-04,   5.3409603E-04
     +,   5.4218067E-04,   5.5224693E-04,   5.6449510E-04
     +,   5.7914027E-04,   5.9641385E-04,   6.1656622E-04
     +,   6.3987053E-04,   6.6662021E-04,   6.9713144E-04
     +,   7.3174387E-04,   7.7081926E-04,   8.1473688E-04
     +,   8.6389214E-04,   9.1870350E-04,   9.7960723E-04
     +,   1.0470613E-03,   1.1215509E-03,   1.2036037E-03
     +,   1.2937932E-03,   1.3927327E-03,   1.5010856E-03
     +,   1.6195443E-03,   1.7487891E-03,   1.8894390E-03
     +,   2.0419948E-03,   2.2067565E-03,   2.3837278E-03
     +,   2.5725651E-03,   2.7725634E-03,   2.9826879E-03
     +,   3.2017042E-03,   3.4284631E-03,   3.6623809E-03
     +,   3.9040546E-03,   4.1559944E-03,   4.4233445E-03
     +,   4.7142096E-03,   5.0391937E-03,   5.4099644E-03
     +,   5.8368421E-03,   6.3260072E-03,   6.8775178E-03
     +,   7.4854721E-03,   8.1407325E-03,   8.8351388E-03
     +,   9.5649231E-03,   1.0331228E-02,   1.1137460E-02
     +,   1.1987552E-02,   1.2892553E-02,   1.3894235E-02
     +,   1.5103781E-02,   1.6729293E-02,   1.9040195E-02
     +,   2.2255147E-02,   2.6459794E-02,   3.1679545E-02
     +,   3.7971184E-02,   4.5259144E-02,   5.3083986E-02
     +,   6.0669988E-02,   6.7210473E-02,   7.2268724E-02
     +,   7.6113857E-02,   7.9060271E-02,   8.0862731E-02
     +,   8.1647493E-02,   8.1966445E-02,   8.1678316E-02
     +,   8.0225110E-02,   7.7424824E-02,   7.3536731E-02
     +,   6.9169521E-02,   6.4818725E-02,   6.0240407E-02
     +,   5.4906264E-02,   4.8962824E-02,   4.3149348E-02
     +,   3.8050584E-02,   3.3740524E-02,   2.9943388E-02
     +,   2.6373573E-02,   2.2941122E-02,   1.9718543E-02
     +,   1.6804788E-02,   1.4243989E-02,   1.2028019E-02
     +,   1.0130182E-02,   8.5242204E-03,   7.1821315E-03
     +,   6.0678376E-03,   5.1391306E-03,   4.3560667E-03
     +,   3.6878209E-03,   3.1139690E-03,   2.6216169E-03
     +,   2.2017595E-03,   1.8466257E-03,   1.5483884E-03
     +,   1.2990294E-03,   1.0907580E-03,   9.1650657E-04
     +,   7.7022950E-04,   6.4699387E-04,   5.4289837E-04
     +,   4.5489182E-04,   3.8053910E-04,   3.1786432E-04
     +,   2.6520021E-04,   2.2111808E-04,   1.8436371E-04
     +,   1.5383981E-04,   1.2857858E-04,   1.0773761E-04
     +,   9.0582871E-05,   7.6484837E-05,   6.4904554E-05
     +,   5.5386467E-05,   4.7549482E-05,   4.1076022E-05
     +,   3.5705456E-05,   3.1224201E-05,   2.7459873E-05
     +,   2.4273320E-05,   2.1553724E-05,   1.9212688E-05
     +,   1.7180579E-05,   1.5402265E-05,   1.3834582E-05
     +,   1.2443410E-05,   1.1202032E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_hatt100 = Yx/0.476960784313725
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0407695E-04,   1.0677299E-04
     +,   1.0946507E-04,   1.1215056E-04,   1.1482678E-04
     +,   1.1749138E-04,   1.2014199E-04,   1.2277644E-04
     +,   1.2539278E-04,   1.2798927E-04,   1.3056432E-04
     +,   1.3311663E-04,   1.3564511E-04,   1.3814904E-04
     +,   1.4062795E-04,   1.4308156E-04,   1.4551019E-04
     +,   1.4791427E-04,   1.5029473E-04,   1.5265279E-04
     +,   1.5499009E-04,   1.5730869E-04,   1.5961101E-04
     +,   1.6189997E-04,   1.6417885E-04,   1.6645141E-04
     +,   1.6872172E-04,   1.7099448E-04,   1.7327466E-04
     +,   1.7556771E-04,   1.7787958E-04,   1.8021656E-04
     +,   1.8258541E-04,   1.8499317E-04,   1.8744734E-04
     +,   1.8995591E-04,   1.9252692E-04,   1.9516895E-04
     +,   1.9789106E-04,   2.0070199E-04,   2.0361140E-04
     +,   2.0662871E-04,   2.0976365E-04,   2.1302608E-04
     +,   2.1642592E-04,   2.1997314E-04,   2.2367771E-04
     +,   2.2754938E-04,   2.3159797E-04,   2.3583301E-04
     +,   2.4026376E-04,   2.4489901E-04,   2.4974742E-04
     +,   2.5481722E-04,   2.6011563E-04,   2.6564964E-04
     +,   2.7142550E-04,   2.7744850E-04,   2.8372329E-04
     +,   2.9025361E-04,   2.9704196E-04,   3.0409035E-04
     +,   3.1139870E-04,   3.1896704E-04,   3.2679399E-04
     +,   3.3487598E-04,   3.4320995E-04,   3.5179028E-04
     +,   3.6061165E-04,   3.6966623E-04,   3.7894689E-04
     +,   3.8844411E-04,   3.9814939E-04,   4.0805223E-04
     +,   4.1814276E-04,   4.2841097E-04,   4.3884624E-04
     +,   4.4943826E-04,   4.6017763E-04,   4.7105629E-04
     +,   4.8206522E-04,   4.9319892E-04,   5.0445070E-04
     +,   5.1581761E-04,   5.2729686E-04,   5.3888885E-04
     +,   5.5059406E-04,   5.6241732E-04,   5.7436316E-04
     +,   5.8643951E-04,   5.9865578E-04,   6.1102328E-04
     +,   6.2355446E-04,   6.3626311E-04,   6.4916565E-04
     +,   6.6227675E-04,   6.7561411E-04,   6.8919326E-04
     +,   7.0303126E-04,   7.1714248E-04,   7.3154218E-04
     +,   7.4624212E-04,   7.6125277E-04,   7.7658193E-04
     +,   7.9223257E-04,   8.0820854E-04,   8.2450506E-04
     +,   8.4111368E-04,   8.5802336E-04,   8.7521580E-04
     +,   8.9266733E-04,   9.1034936E-04,   9.2822470E-04
     +,   9.4625313E-04,   9.6438249E-04,   9.8255894E-04
     +,   1.0007172E-03,   1.0187884E-03,   1.0366919E-03
     +,   1.0543435E-03,   1.0716530E-03,   1.0885190E-03
     +,   1.1048374E-03,   1.1204988E-03,   1.1353894E-03
     +,   1.1493893E-03,   1.1623808E-03,   1.1742424E-03
     +,   1.1848545E-03,   1.1941001E-03,   1.2018681E-03
     +,   1.2080525E-03,   1.2125578E-03,   1.2152977E-03
     +,   1.2162011E-03,   1.2152109E-03,   1.2122866E-03
     +,   1.2074085E-03,   1.2005748E-03,   1.1918045E-03
     +,   1.1811403E-03,   1.1686451E-03,   1.1544052E-03
     +,   1.1385247E-03,   1.1211325E-03,   1.1023716E-03
     +,   1.0824053E-03,   1.0614080E-03,   1.0395695E-03
     +,   1.0170866E-03,   9.9416287E-04,   9.7100739E-04
     +,   9.4783033E-04,   9.2483853E-04,   9.0223568E-04
     +,   8.8022021E-04,   8.5898343E-04,   8.3870598E-04
     +,   8.1955752E-04,   8.0170098E-04,   7.8528567E-04
     +,   7.7045057E-04,   7.5732497E-04,   7.4603158E-04
     +,   7.3668361E-04,   7.2938908E-04,   7.2425231E-04
     +,   7.2137691E-04,   7.2086533E-04,   7.2282582E-04
     +,   7.2736910E-04,   7.3461648E-04,   7.4470119E-04
     +,   7.5777114E-04,   7.7399221E-04,   7.9355272E-04
     +,   8.1666844E-04,   8.4358046E-04,   8.7456097E-04
     +,   9.0991583E-04,   9.4998215E-04,   9.9512015E-04
     +,   1.0457088E-03,   1.1021366E-03,   1.1647831E-03
     +,   1.2339946E-03,   1.3100591E-03,   1.3931850E-03
     +,   1.4834624E-03,   1.5808310E-03,   1.6850636E-03
     +,   1.7957393E-03,   1.9122325E-03,   2.0337144E-03
     +,   2.1591766E-03,   2.2874656E-03,   2.4173025E-03
     +,   2.5473640E-03,   2.6763384E-03,   2.8029939E-03
     +,   2.9262197E-03,   3.0451019E-03,   3.1589619E-03
     +,   3.2673860E-03,   3.3702175E-03,   3.4675822E-03
     +,   3.5598597E-03,   3.6476518E-03,   3.7317539E-03
     +,   3.8131238E-03,   3.8928273E-03,   3.9720023E-03
     +,   4.0517957E-03,   4.1333488E-03,   4.2177350E-03
     +,   4.3059131E-03,   4.3987203E-03,   4.4968529E-03
     +,   4.6008648E-03,   4.7112242E-03,   4.8284107E-03
     +,   4.9530473E-03,   5.0860634E-03,   5.2288948E-03
     +,   5.3836540E-03,   5.5532181E-03,   5.7411557E-03
     +,   5.9515904E-03,   6.1888648E-03,   6.4571211E-03
     +,   6.7597809E-03,   7.0989504E-03,   7.4749645E-03
     +,   7.8857737E-03,   8.3266869E-03,   8.7906951E-03
     +,   9.2696864E-03,   9.7567784E-03,   1.0249306E-02
     +,   1.0751595E-02,   1.1275772E-02,   1.1840506E-02
     +,   1.2469038E-02,   1.3189740E-02,   1.4043103E-02
     +,   1.5092787E-02,   1.6432106E-02,   1.8171217E-02
     +,   2.0400815E-02,   2.3152085E-02,   2.6390996E-02
     +,   3.0064704E-02,   3.4168977E-02,   3.8777452E-02
     +,   4.4001821E-02,   4.9909070E-02,   5.6421857E-02
     +,   6.3214824E-02,   6.9666512E-02,   7.4956551E-02
     +,   7.8313477E-02,   7.9267651E-02,   7.7795662E-02
     +,   7.4321166E-02,   6.9545306E-02,   6.4125121E-02
     +,   5.8430132E-02,   5.2587349E-02,   4.6699084E-02
     +,   4.0936645E-02,   3.5444651E-02,   3.0251252E-02
     +,   2.5321476E-02,   2.0674827E-02,   1.6426621E-02
     +,   1.2725885E-02,   9.6670911E-03,   7.2512696E-03
     +,   5.4025478E-03,   4.0112552E-03,   2.9696880E-03
     +,   2.1901350E-03,   1.6070777E-03,   1.1728860E-03
     +,   8.5218059E-04,   6.1790802E-04,   4.4883497E-04
     +,   3.2821108E-04,   2.4293696E-04,   1.8293718E-04
     +,   1.4067616E-04,   1.1066670E-04,   8.9034904E-05
     +,   7.3110081E-05,   6.1091792E-05,   5.1779636E-05
     +,   4.4380326E-05,   3.8367562E-05,   3.3390963E-05
     +,   2.9212699E-05,   2.5668580E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_hatt102 = Yx/0.4263
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_hatt103(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0407695E-04,   1.0677299E-04
     +,   1.0946507E-04,   1.1215056E-04,   1.1482678E-04
     +,   1.1749138E-04,   1.2014199E-04,   1.2277644E-04
     +,   1.2539278E-04,   1.2798927E-04,   1.3056432E-04
     +,   1.3311663E-04,   1.3564511E-04,   1.3814904E-04
     +,   1.4062795E-04,   1.4308156E-04,   1.4551019E-04
     +,   1.4791427E-04,   1.5029473E-04,   1.5265279E-04
     +,   1.5499009E-04,   1.5730869E-04,   1.5961101E-04
     +,   1.6189997E-04,   1.6417885E-04,   1.6645141E-04
     +,   1.6872172E-04,   1.7099448E-04,   1.7327466E-04
     +,   1.7556771E-04,   1.7787958E-04,   1.8021656E-04
     +,   1.8258541E-04,   1.8499317E-04,   1.8744734E-04
     +,   1.8995591E-04,   1.9252692E-04,   1.9516895E-04
     +,   1.9789106E-04,   2.0070199E-04,   2.0361140E-04
     +,   2.0662871E-04,   2.0976365E-04,   2.1302608E-04
     +,   2.1642592E-04,   2.1997314E-04,   2.2367771E-04
     +,   2.2754938E-04,   2.3159797E-04,   2.3583301E-04
     +,   2.4026376E-04,   2.4489901E-04,   2.4974742E-04
     +,   2.5481722E-04,   2.6011563E-04,   2.6564964E-04
     +,   2.7142550E-04,   2.7744850E-04,   2.8372329E-04
     +,   2.9025361E-04,   2.9704196E-04,   3.0409035E-04
     +,   3.1139870E-04,   3.1896704E-04,   3.2679399E-04
     +,   3.3487598E-04,   3.4320995E-04,   3.5179028E-04
     +,   3.6061165E-04,   3.6966623E-04,   3.7894689E-04
     +,   3.8844411E-04,   3.9814939E-04,   4.0805223E-04
     +,   4.1814276E-04,   4.2841097E-04,   4.3884624E-04
     +,   4.4943826E-04,   4.6017763E-04,   4.7105629E-04
     +,   4.8206522E-04,   4.9319892E-04,   5.0445070E-04
     +,   5.1581761E-04,   5.2729686E-04,   5.3888885E-04
     +,   5.5059406E-04,   5.6241732E-04,   5.7436316E-04
     +,   5.8643951E-04,   5.9865578E-04,   6.1102328E-04
     +,   6.2355446E-04,   6.3626311E-04,   6.4916565E-04
     +,   6.6227675E-04,   6.7561411E-04,   6.8919326E-04
     +,   7.0303126E-04,   7.1714248E-04,   7.3154218E-04
     +,   7.4624212E-04,   7.6125277E-04,   7.7658193E-04
     +,   7.9223257E-04,   8.0820854E-04,   8.2450506E-04
     +,   8.4111368E-04,   8.5802336E-04,   8.7521580E-04
     +,   8.9266733E-04,   9.1034936E-04,   9.2822470E-04
     +,   9.4625313E-04,   9.6438249E-04,   9.8255894E-04
     +,   1.0007172E-03,   1.0187884E-03,   1.0366919E-03
     +,   1.0543435E-03,   1.0716530E-03,   1.0885190E-03
     +,   1.1048374E-03,   1.1204988E-03,   1.1353894E-03
     +,   1.1493893E-03,   1.1623808E-03,   1.1742424E-03
     +,   1.1848545E-03,   1.1941001E-03,   1.2018681E-03
     +,   1.2080525E-03,   1.2125578E-03,   1.2152977E-03
     +,   1.2162011E-03,   1.2152109E-03,   1.2122866E-03
     +,   1.2074085E-03,   1.2005748E-03,   1.1918045E-03
     +,   1.1811403E-03,   1.1686451E-03,   1.1544052E-03
     +,   1.1385247E-03,   1.1211325E-03,   1.1023716E-03
     +,   1.0824053E-03,   1.0614080E-03,   1.0395695E-03
     +,   1.0170866E-03,   9.9416287E-04,   9.7100739E-04
     +,   9.4783033E-04,   9.2483853E-04,   9.0223568E-04
     +,   8.8022021E-04,   8.5898343E-04,   8.3870598E-04
     +,   8.1955752E-04,   8.0170098E-04,   7.8528567E-04
     +,   7.7045057E-04,   7.5732497E-04,   7.4603158E-04
     +,   7.3668361E-04,   7.2938908E-04,   7.2425231E-04
     +,   7.2137691E-04,   7.2086533E-04,   7.2282582E-04
     +,   7.2736910E-04,   7.3461648E-04,   7.4470119E-04
     +,   7.5777114E-04,   7.7399221E-04,   7.9355272E-04
     +,   8.1666844E-04,   8.4358046E-04,   8.7456097E-04
     +,   9.0991583E-04,   9.4998215E-04,   9.9512015E-04
     +,   1.0457088E-03,   1.1021366E-03,   1.1647831E-03
     +,   1.2339946E-03,   1.3100591E-03,   1.3931850E-03
     +,   1.4834624E-03,   1.5808310E-03,   1.6850636E-03
     +,   1.7957393E-03,   1.9122325E-03,   2.0337144E-03
     +,   2.1591766E-03,   2.2874656E-03,   2.4173025E-03
     +,   2.5473640E-03,   2.6763384E-03,   2.8029939E-03
     +,   2.9262197E-03,   3.0451019E-03,   3.1589619E-03
     +,   3.2673860E-03,   3.3702175E-03,   3.4675822E-03
     +,   3.5598597E-03,   3.6476518E-03,   3.7317539E-03
     +,   3.8131238E-03,   3.8928273E-03,   3.9720023E-03
     +,   4.0517957E-03,   4.1333488E-03,   4.2177350E-03
     +,   4.3059131E-03,   4.3987203E-03,   4.4968529E-03
     +,   4.6008648E-03,   4.7112242E-03,   4.8284107E-03
     +,   4.9530473E-03,   5.0860634E-03,   5.2288948E-03
     +,   5.3836540E-03,   5.5532181E-03,   5.7411557E-03
     +,   5.9515904E-03,   6.1888648E-03,   6.4571211E-03
     +,   6.7597809E-03,   7.0989504E-03,   7.4749645E-03
     +,   7.8857737E-03,   8.3266869E-03,   8.7906951E-03
     +,   9.2696864E-03,   9.7567784E-03,   1.0249306E-02
     +,   1.0751595E-02,   1.1275772E-02,   1.1840506E-02
     +,   1.2469038E-02,   1.3189740E-02,   1.4043103E-02
     +,   1.5092787E-02,   1.6432106E-02,   1.8171217E-02
     +,   2.0400815E-02,   2.3152085E-02,   2.6390996E-02
     +,   3.0064704E-02,   3.4168977E-02,   3.8777452E-02
     +,   4.4001821E-02,   4.9909070E-02,   5.6421857E-02
     +,   6.3214824E-02,   6.9666512E-02,   7.4956551E-02
     +,   7.8313477E-02,   7.9267651E-02,   7.7795662E-02
     +,   7.4321166E-02,   6.9545306E-02,   6.4125121E-02
     +,   5.8430132E-02,   5.2587349E-02,   4.6699084E-02
     +,   4.0936645E-02,   3.5444651E-02,   3.0251252E-02
     +,   2.5321476E-02,   2.0674827E-02,   1.6426621E-02
     +,   1.2725885E-02,   9.6670911E-03,   7.2512696E-03
     +,   5.4025478E-03,   4.0112552E-03,   2.9696880E-03
     +,   2.1901350E-03,   1.6070777E-03,   1.1728860E-03
     +,   8.5218059E-04,   6.1790802E-04,   4.4883497E-04
     +,   3.2821108E-04,   2.4293696E-04,   1.8293718E-04
     +,   1.4067616E-04,   1.1066670E-04,   8.9034904E-05
     +,   7.3110081E-05,   6.1091792E-05,   5.1779636E-05
     +,   4.4380326E-05,   3.8367562E-05,   3.3390963E-05
     +,   2.9212699E-05,   2.5668580E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_hatt103 = Yx/0.4263
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0846594E-04,   3.2775183E-04
     +,   3.4781173E-04,   3.6866861E-04,   3.9035073E-04
     +,   4.1289386E-04,   4.3634183E-04,   4.6074763E-04
     +,   4.8617483E-04,   5.1269756E-04,   5.4040289E-04
     +,   5.6939048E-04,   5.9977511E-04,   6.3168682E-04
     +,   6.6527218E-04,   7.0069800E-04,   7.3814992E-04
     +,   7.7783759E-04,   8.1999454E-04,   8.6488260E-04
     +,   9.1279281E-04,   9.6404832E-04,   1.0190069E-03
     +,   1.0780651E-03,   1.1416494E-03,   1.2102287E-03
     +,   1.2843022E-03,   1.3643963E-03,   1.4510610E-03
     +,   1.5448504E-03,   1.6463109E-03,   1.7559498E-03
     +,   1.8742061E-03,   2.0014038E-03,   2.1377061E-03
     +,   2.2830509E-03,   2.4370987E-03,   2.5991702E-03
     +,   2.7682392E-03,   2.9428776E-03,   3.1213574E-03
     +,   3.3016948E-03,   3.4818302E-03,   3.6598353E-03
     +,   3.8341885E-03,   4.0040701E-03,   4.1696513E-03
     +,   4.3323636E-03,   4.4950498E-03,   4.6620332E-03
     +,   4.8389914E-03,   5.0326884E-03,   5.2505103E-03
     +,   5.4998668E-03,   5.7874518E-03,   6.1185108E-03
     +,   6.4960951E-03,   6.9204955E-03,   7.3890700E-03
     +,   7.8965202E-03,   8.4359562E-03,   9.0005966E-03
     +,   9.5857820E-03,   1.0190878E-02,   1.0819801E-02
     +,   1.1479815E-02,   1.2178803E-02,   1.2921911E-02
     +,   1.3710479E-02,   1.4544820E-02,   1.5431680E-02
     +,   1.6392300E-02,   1.7466079E-02,   1.8702978E-02
     +,   2.0144371E-02,   2.1799523E-02,   2.3633610E-02
     +,   2.5582919E-02,   2.7594307E-02,   2.9651560E-02
     +,   3.1747628E-02,   3.3814006E-02,   3.5692614E-02
     +,   3.7228495E-02,   3.8426973E-02,   3.9512500E-02
     +,   4.0803727E-02,   4.2507730E-02,   4.4599008E-02
     +,   4.6833780E-02,   4.8859067E-02,   5.0363429E-02
     +,   5.1206570E-02,   5.1449828E-02,   5.1259410E-02
     +,   5.0745353E-02,   4.9850024E-02,   4.8385851E-02
     +,   4.6209928E-02,   4.3382287E-02,   4.0147856E-02
     +,   3.6777291E-02,   3.3438362E-02,   3.0199295E-02
     +,   2.7098108E-02,   2.4183568E-02,   2.1510717E-02
     +,   1.9121753E-02,   1.7034411E-02,   1.5239152E-02
     +,   1.3704984E-02,   1.2390653E-02,   1.1256973E-02
     +,   1.0272550E-02,   9.4136195E-03,   8.6607598E-03
     +,   7.9968153E-03,   7.4064708E-03,   6.8771634E-03
     +,   6.3994592E-03,   5.9667849E-03,   5.5745407E-03
     +,   5.2189529E-03,   4.8963074E-03,   4.6025943E-03
     +,   4.3335804E-03,   4.0850318E-03,   3.8531288E-03
     +,   3.6346724E-03,   3.4273062E-03,   3.2294909E-03
     +,   3.0404611E-03,   2.8600509E-03,   2.6885532E-03
     +,   2.5265010E-03,   2.3745217E-03,   2.2332014E-03
     +,   2.1029646E-03,   1.9839983E-03,   1.8762313E-03
     +,   1.7793512E-03,   1.6928199E-03,   1.6159213E-03
     +,   1.5478232E-03,   1.4876386E-03,   1.4344539E-03
     +,   1.3873806E-03,   1.3455809E-03,   1.3082806E-03
     +,   1.2747763E-03,   1.2444417E-03,   1.2167263E-03
     +,   1.1911488E-03,   1.1672938E-03,   1.1448046E-03
     +,   1.1233848E-03,   1.1027877E-03,   1.0828143E-03
     +,   1.0633091E-03,   1.0441577E-03,   1.0252815E-03
     +,   1.0066329E-03,   9.8819414E-04,   9.6996810E-04
     +,   9.5197861E-04,   9.3426148E-04,   9.1686548E-04
     +,   8.9984492E-04,   8.8325649E-04,   8.6715684E-04
     +,   8.5160125E-04,   8.3664188E-04,   8.2232407E-04
     +,   8.0868794E-04,   7.9576799E-04,   7.8359136E-04
     +,   7.7217945E-04,   7.6154957E-04,   7.5171370E-04
     +,   7.4267964E-04,   7.3445158E-04,   7.2703179E-04
     +,   7.2042114E-04,   7.1461737E-04,   7.0961745E-04
     +,   7.0541835E-04,   7.0201443E-04,   6.9939846E-04
     +,   6.9756299E-04,   6.9649820E-04,   6.9619116E-04
     +,   6.9662801E-04,   6.9778966E-04,   6.9965573E-04
     +,   7.0220081E-04,   7.0539658E-04,   7.0921035E-04
     +,   7.1360497E-04,   7.1854028E-04,   7.2397158E-04
     +,   7.2985189E-04,   7.3612994E-04,   7.4275193E-04
     +,   7.4966298E-04,   7.5680553E-04,   7.6412066E-04
     +,   7.7154959E-04,   7.7903201E-04,   7.8650803E-04
     +,   7.9391769E-04,   8.0120302E-04,   8.0830377E-04
     +,   8.1516267E-04,   8.2172191E-04,   8.2792528E-04
     +,   8.3371642E-04,   8.3903928E-04,   8.4383873E-04
     +,   8.4806047E-04,   8.5164956E-04,   8.5455342E-04
     +,   8.5671793E-04,   8.5809291E-04,   8.5862720E-04
     +,   8.5827243E-04,   8.5698313E-04,   8.5471716E-04
     +,   8.5143594E-04,   8.4710488E-04,   8.4169587E-04
     +,   8.3518663E-04,   8.2756160E-04,   8.1881334E-04
     +,   8.0894085E-04,   7.9795386E-04,   7.8586920E-04
     +,   7.7271299E-04,   7.5852108E-04,   7.4333785E-04
     +,   7.2721473E-04,   7.1021222E-04,   6.9239823E-04
     +,   6.7384710E-04,   6.5463799E-04,   6.3485384E-04
     +,   6.1458314E-04,   5.9391581E-04,   5.7294284E-04
     +,   5.5175408E-04,   5.3044164E-04,   5.0909276E-04
     +,   4.8779164E-04,   4.6662125E-04,   4.4565892E-04
     +,   4.2497573E-04,   4.0463725E-04,   3.8470465E-04
     +,   3.6523247E-04,   3.4626716E-04,   3.2784938E-04
     +,   3.1001429E-04,   2.9279053E-04,   2.7619989E-04
     +,   2.6025806E-04,   2.4497727E-04,   2.3036271E-04
     +,   2.1641533E-04,   2.0313264E-04,   1.9050844E-04
     +,   1.7853224E-04,   1.6719080E-04,   1.5646937E-04
     +,   1.4635074E-04,   1.3681548E-04,   1.2784307E-04
     +,   1.1941250E-04,   1.1150121E-04,   1.0408707E-04
     +,   9.7146774E-05,   9.0657959E-05,   8.4597363E-05
     +,   7.8943020E-05,   7.3672527E-05,   6.8764704E-05
     +,   6.4198270E-05,   5.9953334E-05,   5.6010154E-05
     +,   5.2349853E-05,   4.8954662E-05,   4.5807115E-05
     +,   4.2891028E-05,   4.0190560E-05,   3.7691108E-05
     +,   3.5378409E-05,   3.3239372E-05,   3.1261330E-05
     +,   2.9432595E-05,   2.7741975E-05,   2.6179152E-05
     +,   2.4734296E-05,   2.3398368E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_hatt75 = Yx/0.44268
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4463621E-04,   1.5127906E-04
     +,   1.5829323E-04,   1.6570534E-04,   1.7354260E-04
     +,   1.8183257E-04,   1.9060304E-04,   1.9988179E-04
     +,   2.0969582E-04,   2.2007215E-04,   2.3103655E-04
     +,   2.4261391E-04,   2.5482784E-04,   2.6770090E-04
     +,   2.8125456E-04,   2.9550915E-04,   3.1048496E-04
     +,   3.2620196E-04,   3.4268081E-04,   3.5994424E-04
     +,   3.7801737E-04,   3.9692945E-04,   4.1671511E-04
     +,   4.3741759E-04,   4.5908609E-04,   4.8178225E-04
     +,   5.0557876E-04,   5.3056079E-04,   5.5682712E-04
     +,   5.8449013E-04,   6.1367609E-04,   6.4452272E-04
     +,   6.7717920E-04,   7.1180169E-04,   7.4855180E-04
     +,   7.8759313E-04,   8.2908652E-04,   8.7318860E-04
     +,   9.2005177E-04,   9.6981798E-04,   1.0226306E-03
     +,   1.0786322E-03,   1.1379791E-03,   1.2008535E-03
     +,   1.2674840E-03,   1.3381667E-03,   1.4132940E-03
     +,   1.4933818E-03,   1.5790955E-03,   1.6712713E-03
     +,   1.7709245E-03,   1.8792426E-03,   1.9975447E-03
     +,   2.1272297E-03,   2.2696562E-03,   2.4260296E-03
     +,   2.5972438E-03,   2.7837246E-03,   2.9853021E-03
     +,   3.2011503E-03,   3.4297877E-03,   3.6692475E-03
     +,   3.9173029E-03,   4.1719247E-03,   4.4316920E-03
     +,   4.6962295E-03,   4.9666213E-03,   5.2454397E-03
     +,   5.5366419E-03,   5.8449339E-03,   6.1750663E-03
     +,   6.5307575E-03,   6.9139865E-03,   7.3244162E-03
     +,   7.7595869E-03,   8.2155168E-03,   8.6877216E-03
     +,   9.1724498E-03,   9.6676210E-03,   1.0173241E-02
     +,   1.0691252E-02,   1.1225317E-02,   1.1780591E-02
     +,   1.2365453E-02,   1.2994435E-02,   1.3691810E-02
     +,   1.4491785E-02,   1.5432566E-02,   1.6544217E-02
     +,   1.7836668E-02,   1.9296438E-02,   2.0895684E-02
     +,   2.2607077E-02,   2.4413181E-02,   2.6304880E-02
     +,   2.8284486E-02,   3.0388201E-02,   3.2702044E-02
     +,   3.5302706E-02,   3.8119581E-02,   4.0904339E-02
     +,   4.3485936E-02,   4.6080723E-02,   4.9133711E-02
     +,   5.2699074E-02,   5.6117915E-02,   5.8510777E-02
     +,   5.9643500E-02,   6.0283035E-02,   6.1588839E-02
     +,   6.3975930E-02,   6.6536896E-02,   6.7774720E-02
     +,   6.7061037E-02,   6.5137655E-02,   6.3057996E-02
     +,   6.1082877E-02,   5.8793891E-02,   5.5796567E-02
     +,   5.2065481E-02,   4.7861639E-02,   4.3515269E-02
     +,   3.9263807E-02,   3.5217624E-02,   3.1416677E-02
     +,   2.7881470E-02,   2.4617812E-02,   2.1614281E-02
     +,   1.8864626E-02,   1.6391145E-02,   1.4232565E-02
     +,   1.2411416E-02,   1.0914179E-02,   9.6976673E-03
     +,   8.7062968E-03,   7.8864386E-03,   7.1930480E-03
     +,   6.5916055E-03,   6.0581677E-03,   5.5779247E-03
     +,   5.1426385E-03,   4.7475710E-03,   4.3891431E-03
     +,   4.0638740E-03,   3.7682927E-03,   3.4991947E-03
     +,   3.2539519E-03,   3.0306007E-03,   2.8276388E-03
     +,   2.6437673E-03,   2.4776948E-03,   2.3280110E-03
     +,   2.1931515E-03,   2.0714574E-03,   1.9612727E-03
     +,   1.8610385E-03,   1.7693575E-03,   1.6850255E-03
     +,   1.6070541E-03,   1.5346570E-03,   1.4672138E-03
     +,   1.4042374E-03,   1.3453487E-03,   1.2902428E-03
     +,   1.2386625E-03,   1.1903866E-03,   1.1452254E-03
     +,   1.1030057E-03,   1.0635739E-03,   1.0267912E-03
     +,   9.9254283E-04,   9.6072751E-04,   9.3126076E-04
     +,   9.0407295E-04,   8.7911019E-04,   8.5632899E-04
     +,   8.3569170E-04,   8.1717147E-04,   8.0074294E-04
     +,   7.8638404E-04,   7.7407266E-04,   7.6378736E-04
     +,   7.5550616E-04,   7.4920314E-04,   7.4485020E-04
     +,   7.4241625E-04,   7.4186386E-04,   7.4315106E-04
     +,   7.4622786E-04,   7.5103610E-04,   7.5750746E-04
     +,   7.6556252E-04,   7.7510776E-04,   7.8603561E-04
     +,   7.9822203E-04,   8.1152737E-04,   8.2579220E-04
     +,   8.4084028E-04,   8.5647858E-04,   8.7249745E-04
     +,   8.8867196E-04,   9.0476387E-04,   9.2052820E-04
     +,   9.3571306E-04,   9.5006428E-04,   9.6333161E-04
     +,   9.7527460E-04,   9.8566245E-04,   9.9428545E-04
     +,   1.0009558E-03,   1.0055136E-03,   1.0078289E-03
     +,   1.0078080E-03,   1.0053917E-03,   1.0005591E-03
     +,   9.9332677E-04,   9.8374893E-04,   9.7191473E-04
     +,   9.5794542E-04,   9.4199210E-04,   9.2422939E-04
     +,   9.0485206E-04,   8.8407175E-04,   8.6210761E-04
     +,   8.3918456E-04,   8.1552594E-04,   7.9135090E-04
     +,   7.6687068E-04,   7.4228022E-04,   7.1776012E-04
     +,   6.9347356E-04,   6.6956377E-04,   6.4615224E-04
     +,   6.2333880E-04,   6.0120499E-04,   5.7981029E-04
     +,   5.5919588E-04,   5.3938618E-04,   5.2039174E-04
     +,   5.0220697E-04,   4.8481557E-04,   4.6819332E-04
     +,   4.5230854E-04,   4.3712233E-04,   4.2259280E-04
     +,   4.0867648E-04,   3.9532880E-04,   3.8250469E-04
     +,   3.7016053E-04,   3.5825500E-04,   3.4674947E-04
     +,   3.3560692E-04,   3.2479508E-04,   3.1428484E-04
     +,   3.0405019E-04,   2.9406810E-04,   2.8431954E-04
     +,   2.7478905E-04,   2.6546331E-04,   2.5633146E-04
     +,   2.4738620E-04,   2.3862201E-04,   2.3003508E-04
     +,   2.2162299E-04,   2.1338563E-04,   2.0532339E-04
     +,   1.9743732E-04,   1.8972975E-04,   1.8220364E-04
     +,   1.7486130E-04,   1.6770561E-04,   1.6073961E-04
     +,   1.5396620E-04,   1.4738756E-04,   1.4100534E-04
     +,   1.3482160E-04,   1.2883688E-04,   1.2305209E-04
     +,   1.1746657E-04,   1.1208012E-04,   1.0689104E-04
     +,   1.0189782E-04,   9.7097676E-05,   9.2488110E-05
     +,   8.8065419E-05,   8.3826082E-05,   7.9765865E-05
     +,   7.5880045E-05,   7.2164221E-05,   6.8613066E-05
     +,   6.5221684E-05,   6.1984509E-05,   5.8896338E-05
     +,   5.5951539E-05,   5.3144831E-05,   5.0470571E-05
     +,   4.7923531E-05,   4.5498244E-05,   4.3189637E-05
     +,   4.0992432E-05,   3.8901824E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_hatt80 = Yx/0.533098039215686
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.3728744E-05,   8.6503351E-05
     +,   8.9327979E-05,   9.2204886E-05,   9.5136660E-05
     +,   9.8126489E-05,   1.0117794E-04,   1.0429514E-04
     +,   1.0748271E-04,   1.1074576E-04,   1.1408993E-04
     +,   1.1752122E-04,   1.2104605E-04,   1.2467137E-04
     +,   1.2840425E-04,   1.3225223E-04,   1.3622285E-04
     +,   1.4032400E-04,   1.4456348E-04,   1.4894917E-04
     +,   1.5348886E-04,   1.5819012E-04,   1.6306026E-04
     +,   1.6810674E-04,   1.7333594E-04,   1.7875471E-04
     +,   1.8436895E-04,   1.9018442E-04,   1.9620650E-04
     +,   2.0244031E-04,   2.0889056E-04,   2.1556186E-04
     +,   2.2245884E-04,   2.2958592E-04,   2.3694782E-04
     +,   2.4454950E-04,   2.5239630E-04,   2.6049392E-04
     +,   2.6884954E-04,   2.7747030E-04,   2.8636516E-04
     +,   2.9554419E-04,   3.0501917E-04,   3.1480388E-04
     +,   3.2491444E-04,   3.3537022E-04,   3.4619390E-04
     +,   3.5741329E-04,   3.6906148E-04,   3.8117910E-04
     +,   3.9381563E-04,   4.0703180E-04,   4.2090195E-04
     +,   4.3551813E-04,   4.5099150E-04,   4.6745938E-04
     +,   4.8508737E-04,   5.0407508E-04,   5.2466028E-04
     +,   5.4712436E-04,   5.7179533E-04,   5.9905020E-04
     +,   6.2931288E-04,   6.6305709E-04,   7.0079346E-04
     +,   7.4305909E-04,   7.9040648E-04,   8.4337167E-04
     +,   9.0245844E-04,   9.6809753E-04,   1.0406281E-03
     +,   1.1202525E-03,   1.2070310E-03,   1.3008503E-03
     +,   1.4014393E-03,   1.5083862E-03,   1.6211605E-03
     +,   1.7391780E-03,   1.8618769E-03,   1.9887839E-03
     +,   2.1195740E-03,   2.2541676E-03,   2.3927346E-03
     +,   2.5357413E-03,   2.6838891E-03,   2.8380968E-03
     +,   2.9993518E-03,   3.1686362E-03,   3.3467484E-03
     +,   3.5342423E-03,   3.7313683E-03,   3.9381431E-03
     +,   4.1545746E-03,   4.3810778E-03,   4.6189823E-03
     +,   4.8711337E-03,   5.1425509E-03,   5.4409592E-03
     +,   5.7772240E-03,   6.1654281E-03,   6.6224700E-03
     +,   7.1664718E-03,   7.8138513E-03,   8.5746292E-03
     +,   9.4477013E-03,   1.0417987E-02,   1.1458759E-02
     +,   1.2541299E-02,   1.3650172E-02,   1.4797564E-02
     +,   1.6026223E-02,   1.7392581E-02,   1.8932523E-02
     +,   2.0631069E-02,   2.2421805E-02,   2.4227651E-02
     +,   2.6015878E-02,   2.7822267E-02,   2.9720409E-02
     +,   3.1791195E-02,   3.4183104E-02,   3.7227686E-02
     +,   4.1340921E-02,   4.6569664E-02,   5.2238941E-02
     +,   5.7280250E-02,   6.1003644E-02,   6.3560799E-02
     +,   6.5842688E-02,   6.8872802E-02,   7.2586700E-02
     +,   7.5377792E-02,   7.6308131E-02,   7.6567627E-02
     +,   7.6871090E-02,   7.6089911E-02,   7.3792510E-02
     +,   7.1145184E-02,   6.8763852E-02,   6.5729186E-02
     +,   6.1055336E-02,   5.5015210E-02,   4.8656356E-02
     +,   4.2686138E-02,   3.7224937E-02,   3.2240897E-02
     +,   2.7791770E-02,   2.3923008E-02,   2.0585263E-02
     +,   1.7699746E-02,   1.5229216E-02,   1.3165615E-02
     +,   1.1483795E-02,   1.0124832E-02,   9.0139154E-03
     +,   8.0848718E-03,   7.2921505E-03,   6.6088517E-03
     +,   6.0185478E-03,   5.5078804E-03,   5.0630379E-03
     +,   4.6698987E-03,   4.3157442E-03,   3.9907768E-03
     +,   3.6886823E-03,   3.4062725E-03,   3.1425941E-03
     +,   2.8979070E-03,   2.6728606E-03,   2.4679918E-03
     +,   2.2834893E-03,   2.1190995E-03,   1.9741601E-03
     +,   1.8476907E-03,   1.7385108E-03,   1.6453046E-03
     +,   1.5667060E-03,   1.5013539E-03,   1.4479195E-03
     +,   1.4051176E-03,   1.3717219E-03,   1.3465683E-03
     +,   1.3285539E-03,   1.3166443E-03,   1.3098728E-03
     +,   1.3073477E-03,   1.3082527E-03,   1.3118533E-03
     +,   1.3174870E-03,   1.3245665E-03,   1.3325711E-03
     +,   1.3410380E-03,   1.3495581E-03,   1.3577642E-03
     +,   1.3653281E-03,   1.3719539E-03,   1.3773690E-03
     +,   1.3813355E-03,   1.3836352E-03,   1.3840823E-03
     +,   1.3825186E-03,   1.3788230E-03,   1.3729070E-03
     +,   1.3647234E-03,   1.3542620E-03,   1.3415568E-03
     +,   1.3266746E-03,   1.3097255E-03,   1.2908477E-03
     +,   1.2702089E-03,   1.2479982E-03,   1.2244234E-03
     +,   1.1997018E-03,   1.1740547E-03,   1.1477016E-03
     +,   1.1208594E-03,   1.0937327E-03,   1.0665135E-03
     +,   1.0393775E-03,   1.0124841E-03,   9.8597340E-04
     +,   9.5996459E-04,   9.3456078E-04,   9.0984418E-04
     +,   8.8587805E-04,   8.6270645E-04,   8.4035977E-04
     +,   8.1884989E-04,   7.9817203E-04,   7.7830878E-04
     +,   7.5923040E-04,   7.4089470E-04,   7.2324881E-04
     +,   7.0623122E-04,   6.8977586E-04,   6.7380868E-04
     +,   6.5825367E-04,   6.4303487E-04,   6.2807574E-04
     +,   6.1330292E-04,   5.9864653E-04,   5.8404310E-04
     +,   5.6943699E-04,   5.5477908E-04,   5.4002966E-04
     +,   5.2515900E-04,   5.1014777E-04,   4.9498479E-04
     +,   4.7966896E-04,   4.6420965E-04,   4.4862245E-04
     +,   4.3293161E-04,   4.1716837E-04,   4.0136970E-04
     +,   3.8557636E-04,   3.6983186E-04,   3.5418355E-04
     +,   3.3867979E-04,   3.2336763E-04,   3.0829388E-04
     +,   2.9350413E-04,   2.7904144E-04,   2.6494483E-04
     +,   2.5124924E-04,   2.3798725E-04,   2.2518513E-04
     +,   2.1286460E-04,   2.0104343E-04,   1.8973448E-04
     +,   1.7894516E-04,   1.6867828E-04,   1.5893330E-04
     +,   1.4970559E-04,   1.4098635E-04,   1.3276351E-04
     +,   1.2502325E-04,   1.1774828E-04,   1.1092031E-04
     +,   1.0451873E-04,   9.8522753E-05,   9.2909926E-05
     +,   8.7658351E-05,   8.2745319E-05,   7.8148965E-05
     +,   7.3847390E-05,   6.9819864E-05,   6.6046159E-05
     +,   6.2507024E-05,   5.9184666E-05,   5.6061930E-05
     +,   5.3123294E-05,   5.0354043E-05,   4.7741014E-05
     +,   4.5271805E-05,   4.2935539E-05,   4.0722010E-05
     +,   3.8622322E-05,   3.6628222E-05,   3.4732569E-05
     +,   3.2928721E-05,   3.1211031E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_hatt85 = Yx/0.538588235294118
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9368193E-05,   3.0945132E-05
     +,   3.2570839E-05,   3.4244433E-05,   3.5964884E-05
     +,   3.7731057E-05,   3.9541676E-05,   4.1395338E-05
     +,   4.3290544E-05,   4.5225795E-05,   4.7199421E-05
     +,   4.9209724E-05,   5.1255003E-05,   5.3333522E-05
     +,   5.5443543E-05,   5.7583376E-05,   5.9751404E-05
     +,   6.1946026E-05,   6.4165775E-05,   6.6409310E-05
     +,   6.8675377E-05,   7.0962960E-05,   7.3271098E-05
     +,   7.5599193E-05,   7.7946621E-05,   8.0313206E-05
     +,   8.2698825E-05,   8.5103668E-05,   8.7528097E-05
     +,   8.9972738E-05,   9.2438437E-05,   9.4926210E-05
     +,   9.7437303E-05,   9.9973113E-05,   1.0253517E-04
     +,   1.0512518E-04,   1.0774491E-04,   1.1039615E-04
     +,   1.1308090E-04,   1.1580077E-04,   1.1855771E-04
     +,   1.2135342E-04,   1.2418936E-04,   1.2706699E-04
     +,   1.2998740E-04,   1.3295149E-04,   1.3595990E-04
     +,   1.3901282E-04,   1.4211021E-04,   1.4525153E-04
     +,   1.4843594E-04,   1.5166210E-04,   1.5492826E-04
     +,   1.5823251E-04,   1.6157198E-04,   1.6494408E-04
     +,   1.6834537E-04,   1.7177250E-04,   1.7522163E-04
     +,   1.7868888E-04,   1.8217033E-04,   1.8566223E-04
     +,   1.8916059E-04,   1.9266228E-04,   1.9616449E-04
     +,   1.9966488E-04,   2.0316256E-04,   2.0665728E-04
     +,   2.1015080E-04,   2.1364630E-04,   2.1714965E-04
     +,   2.2066900E-04,   2.2421629E-04,   2.2780665E-04
     +,   2.3146023E-04,   2.3520229E-04,   2.3906394E-04
     +,   2.4308356E-04,   2.4730735E-04,   2.5179068E-04
     +,   2.5659884E-04,   2.6180828E-04,   2.6750736E-04
     +,   2.7379804E-04,   2.8079524E-04,   2.8862915E-04
     +,   2.9744345E-04,   3.0739748E-04,   3.1866279E-04
     +,   3.3142482E-04,   3.4588031E-04,   3.6223372E-04
     +,   3.8069533E-04,   4.0147887E-04,   4.2479747E-04
     +,   4.5085599E-04,   4.7985290E-04,   5.1196880E-04
     +,   5.4737035E-04,   5.8619864E-04,   6.2857760E-04
     +,   6.7460322E-04,   7.2435738E-04,   7.7789923E-04
     +,   8.3528354E-04,   8.9656352E-04,   9.6179266E-04
     +,   1.0310378E-03,   1.1043884E-03,   1.1819574E-03
     +,   1.2638806E-03,   1.3503467E-03,   1.4416045E-03
     +,   1.5380428E-03,   1.6402650E-03,   1.7492645E-03
     +,   1.8666124E-03,   1.9947507E-03,   2.1372540E-03
     +,   2.2991097E-03,   2.4868587E-03,   2.7084823E-03
     +,   2.9729663E-03,   3.2894642E-03,   3.6660277E-03
     +,   4.1081123E-03,   4.6174740E-03,   5.1916204E-03
     +,   5.8247866E-03,   6.5100170E-03,   7.2426740E-03
     +,   8.0237640E-03,   8.8630570E-03,   9.7801043E-03
     +,   1.0803928E-02,   1.1971166E-02,   1.3324103E-02
     +,   1.4907208E-02,   1.6754309E-02,   1.8859584E-02
     +,   2.1147160E-02,   2.3485538E-02,   2.5775893E-02
     +,   2.8062163E-02,   3.0551182E-02,   3.3478372E-02
     +,   3.6877207E-02,   4.0460553E-02,   4.3842237E-02
     +,   4.6955604E-02,   5.0184309E-02,   5.4042779E-02
     +,   5.8754981E-02,   6.4281441E-02,   7.0638016E-02
     +,   7.7264592E-02,   8.2211718E-02,   8.3800666E-02
     +,   8.3245233E-02,   8.3912991E-02,   8.7299317E-02
     +,   9.0832189E-02,   9.0539709E-02,   8.5389391E-02
     +,   7.7860244E-02,   6.9787510E-02,   6.0766988E-02
     +,   5.0983567E-02,   4.1805767E-02,   3.4031510E-02
     +,   2.7623191E-02,   2.2426290E-02,   1.8330656E-02
     +,   1.5170768E-02,   1.2782174E-02,   1.1052160E-02
     +,   9.8832007E-03,   9.1578085E-03,   8.7482110E-03
     +,   8.5437773E-03,   8.4669767E-03,   8.4720440E-03
     +,   8.5340943E-03,   8.6377459E-03,   8.7691601E-03
     +,   8.9118304E-03,   9.0456400E-03,   9.1483546E-03
     +,   9.1990205E-03,   9.1818999E-03,   9.0895938E-03
     +,   8.9237578E-03,   8.6935163E-03,   8.4117455E-03
     +,   8.0911545E-03,   7.7414596E-03,   7.3686070E-03
     +,   6.9758226E-03,   6.5657911E-03,   6.1427336E-03
     +,   5.7136626E-03,   5.2882689E-03,   4.8778309E-03
     +,   4.4936542E-03,   4.1455766E-03,   3.8407871E-03
     +,   3.5833265E-03,   3.3740827E-03,   3.2111374E-03
     +,   3.0902978E-03,   3.0057742E-03,   2.9507889E-03
     +,   2.9181335E-03,   2.9006600E-03,   2.8916399E-03
     +,   2.8850590E-03,   2.8757779E-03,   2.8596395E-03
     +,   2.8334770E-03,   2.7951086E-03,   2.7432612E-03
     +,   2.6774872E-03,   2.5980968E-03,   2.5060447E-03
     +,   2.4028190E-03,   2.2903353E-03,   2.1708212E-03
     +,   2.0466766E-03,   1.9203486E-03,   1.7942030E-03
     +,   1.6704299E-03,   1.5509403E-03,   1.4372948E-03
     +,   1.3306686E-03,   1.2318604E-03,   1.1412797E-03
     +,   1.0589970E-03,   9.8480470E-04,   9.1826671E-04
     +,   8.5878279E-04,   8.0565125E-04,   7.5812807E-04
     +,   7.1546639E-04,   6.7694735E-04,   6.4191147E-04
     +,   6.0977112E-04,   5.8001740E-04,   5.5221765E-04
     +,   5.2601693E-04,   5.0113059E-04,   4.7733387E-04
     +,   4.5445486E-04,   4.3236729E-04,   4.1098142E-04
     +,   3.9023542E-04,   3.7008946E-04,   3.5052455E-04
     +,   3.3153268E-04,   3.1311493E-04,   2.9527859E-04
     +,   2.7803570E-04,   2.6140010E-04,   2.4538470E-04
     +,   2.3000171E-04,   2.1526239E-04,   2.0117448E-04
     +,   1.8774226E-04,   1.7496767E-04,   1.6284903E-04
     +,   1.5138030E-04,   1.4055197E-04,   1.3035216E-04
     +,   1.2076585E-04,   1.1177470E-04,   1.0335814E-04
     +,   9.5494426E-05,   8.8159344E-05,   8.1328479E-05
     +,   7.4975789E-05,   6.9075621E-05,   6.3601532E-05
     +,   5.8527996E-05,   5.3829364E-05,   4.9481307E-05
     +,   4.5459787E-05,   4.1742329E-05,   3.8307240E-05
     +,   3.5134020E-05,   3.2203745E-05,   2.9498313E-05
     +,   2.7001235E-05,   2.4696878E-05,   2.2571070E-05
     +,   2.0610469E-05,   1.8802981E-05,   1.7137256E-05
     +,   1.5603038E-05,   1.4190675E-05,   1.2891448E-05
     +,   1.1697121E-05,   1.0600247E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_hatt90 = Yx/0.551627450980392
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2833686E-05,   5.4375123E-05
     +,   5.5926645E-05,   5.7487108E-05,   5.9055419E-05
     +,   6.0630467E-05,   6.2211162E-05,   6.3796440E-05
     +,   6.5385226E-05,   6.6976572E-05,   6.8569461E-05
     +,   7.0162961E-05,   7.1756127E-05,   7.3348121E-05
     +,   7.4938107E-05,   7.6525306E-05,   7.8108984E-05
     +,   7.9688471E-05,   8.1263126E-05,   8.2832383E-05
     +,   8.4395717E-05,   8.5952684E-05,   8.7502827E-05
     +,   8.9045927E-05,   9.0581561E-05,   9.2109607E-05
     +,   9.3629882E-05,   9.5142321E-05,   9.6646872E-05
     +,   9.8143581E-05,   9.9632605E-05,   1.0111406E-04
     +,   1.0258830E-04,   1.0405562E-04,   1.0551638E-04
     +,   1.0697116E-04,   1.0842046E-04,   1.0986497E-04
     +,   1.1130545E-04,   1.1274267E-04,   1.1417764E-04
     +,   1.1561137E-04,   1.1704496E-04,   1.1847966E-04
     +,   1.1991683E-04,   1.2135791E-04,   1.2280456E-04
     +,   1.2425850E-04,   1.2572156E-04,   1.2719595E-04
     +,   1.2868381E-04,   1.3018769E-04,   1.3171020E-04
     +,   1.3325443E-04,   1.3482360E-04,   1.3642135E-04
     +,   1.3805172E-04,   1.3971920E-04,   1.4142873E-04
     +,   1.4318591E-04,   1.4499693E-04,   1.4686881E-04
     +,   1.4880909E-04,   1.5082650E-04,   1.5293059E-04
     +,   1.5513178E-04,   1.5744187E-04,   1.5987322E-04
     +,   1.6243993E-04,   1.6515651E-04,   1.6803914E-04
     +,   1.7110433E-04,   1.7436987E-04,   1.7785373E-04
     +,   1.8157461E-04,   1.8555115E-04,   1.8980150E-04
     +,   1.9434298E-04,   1.9919191E-04,   2.0436302E-04
     +,   2.0986791E-04,   2.1571630E-04,   2.2191305E-04
     +,   2.2846006E-04,   2.3535345E-04,   2.4258466E-04
     +,   2.5013869E-04,   2.5799524E-04,   2.6612647E-04
     +,   2.7449901E-04,   2.8307296E-04,   2.9180187E-04
     +,   3.0063381E-04,   3.0951243E-04,   3.1837760E-04
     +,   3.2716605E-04,   3.3581420E-04,   3.4425806E-04
     +,   3.5243711E-04,   3.6029427E-04,   3.6777975E-04
     +,   3.7485210E-04,   3.8148128E-04,   3.8764946E-04
     +,   3.9335480E-04,   3.9861165E-04,   4.0345290E-04
     +,   4.0793049E-04,   4.1211655E-04,   4.1610352E-04
     +,   4.2000256E-04,   4.2394319E-04,   4.2807119E-04
     +,   4.3254503E-04,   4.3753319E-04,   4.4320957E-04
     +,   4.4974769E-04,   4.5731617E-04,   4.6607252E-04
     +,   4.7615741E-04,   4.8768971E-04,   5.0075998E-04
     +,   5.1542680E-04,   5.3171505E-04,   5.4961513E-04
     +,   5.6908076E-04,   5.9003656E-04,   6.1237812E-04
     +,   6.3598604E-04,   6.6072843E-04,   6.8647898E-04
     +,   7.1312208E-04,   7.4057147E-04,   7.6877425E-04
     +,   7.9772755E-04,   8.2747900E-04,   8.5812993E-04
     +,   8.8983373E-04,   9.2279154E-04,   9.5723948E-04
     +,   9.9343294E-04,   1.0316322E-03,   1.0720912E-03
     +,   1.1150432E-03,   1.1606889E-03,   1.2092099E-03
     +,   1.2607740E-03,   1.3155557E-03,   1.3737692E-03
     +,   1.4357130E-03,   1.5018082E-03,   1.5726228E-03
     +,   1.6489016E-03,   1.7315700E-03,   1.8216860E-03
     +,   1.9203664E-03,   2.0286732E-03,   2.1474618E-03
     +,   2.2771989E-03,   2.4177530E-03,   2.5682501E-03
     +,   2.7269311E-03,   2.8911019E-03,   3.0571967E-03
     +,   3.2210101E-03,   3.3780362E-03,   3.5239921E-03
     +,   3.6554965E-03,   3.7708438E-03,   3.8707471E-03
     +,   3.9589303E-03,   4.0424620E-03,   4.1316468E-03
     +,   4.2395419E-03,   4.3812748E-03,   4.5738141E-03
     +,   4.8366552E-03,   5.1938118E-03,   5.6763384E-03
     +,   6.3232216E-03,   7.1775028E-03,   8.2756337E-03
     +,   9.6326713E-03,   1.1231545E-02,   1.3028249E-02
     +,   1.4984041E-02,   1.7128238E-02,   1.9630529E-02
     +,   2.2814859E-02,   2.7050652E-02,   3.2615617E-02
     +,   3.9689086E-02,   4.8239026E-02,   5.7575267E-02
     +,   6.6473275E-02,   7.4077725E-02,   7.9742268E-02
     +,   8.2942478E-02,   8.4887676E-02,   8.7436721E-02
     +,   8.9355163E-02,   8.7965652E-02,   8.4172577E-02
     +,   8.0908187E-02,   7.9101346E-02,   7.7173524E-02
     +,   7.3698960E-02,   6.9070324E-02,   6.3487440E-02
     +,   5.6684781E-02,   4.9567498E-02,   4.3686558E-02
     +,   3.9627329E-02,   3.6671963E-02,   3.3798117E-02
     +,   3.0609604E-02,   2.7312772E-02,   2.4227211E-02
     +,   2.1525029E-02,   1.9241871E-02,   1.7335674E-02
     +,   1.5719306E-02,   1.4295035E-02,   1.2992392E-02
     +,   1.1784290E-02,   1.0676114E-02,   9.6842535E-03
     +,   8.8204276E-03,   8.0867102E-03,   7.4765440E-03
     +,   6.9767842E-03,   6.5686963E-03,   6.2288833E-03
     +,   5.9313718E-03,   5.6508179E-03,   5.3659575E-03
     +,   5.0623151E-03,   4.7333464E-03,   4.3799374E-03
     +,   4.0086689E-03,   3.6295771E-03,   3.2538732E-03
     +,   2.8920744E-03,   2.5527130E-03,   2.2417614E-03
     +,   1.9625709E-03,   1.7161581E-03,   1.5017018E-03
     +,   1.3171321E-03,   1.1596672E-03,   1.0261917E-03
     +,   9.1357360E-04,   8.1884547E-04,   7.3929055E-04
     +,   6.7247025E-04,   6.1623519E-04,   5.6870974E-04
     +,   5.2826985E-04,   4.9351860E-04,   4.6327361E-04
     +,   4.3655030E-04,   4.1254115E-04,   3.9059759E-04
     +,   3.7021202E-04,   3.5100101E-04,   3.3268187E-04
     +,   3.1505644E-04,   2.9799508E-04,   2.8142074E-04
     +,   2.6529434E-04,   2.4960531E-04,   2.3436316E-04
     +,   2.1958967E-04,   2.0531210E-04,   1.9156025E-04
     +,   1.7836443E-04,   1.6575024E-04,   1.5374101E-04
     +,   1.4235290E-04,   1.3159803E-04,   1.2148124E-04
     +,   1.1200290E-04,   1.0315665E-04,   9.4932286E-05
     +,   8.7313827E-05,   8.0282276E-05,   7.3814495E-05
     +,   6.7884524E-05,   6.2464875E-05,   5.7525573E-05
     +,   5.3036332E-05,   4.8965710E-05,   4.5282755E-05
     +,   4.1956402E-05,   3.8956754E-05,   3.6254562E-05
     +,   3.3822267E-05,   3.1633394E-05,   2.9663453E-05
     +,   2.7889386E-05,   2.6290125E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_hatt95 = Yx/0.525
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7117223E-11,   6.2865144E-11
     +,   8.3606809E-11,   1.1083489E-10,   1.4645792E-10
     +,   1.9290865E-10,   2.5327521E-10,   3.3146433E-10
     +,   4.3239551E-10,   5.6225191E-10,   7.2875800E-10
     +,   9.4153918E-10,   1.2125433E-09,   1.5565360E-09
     +,   1.9917039E-09,   2.5403513E-09,   3.2297376E-09
     +,   4.0930268E-09,   5.1704219E-09,   6.5104739E-09
     +,   8.1715399E-09,   1.0223523E-08,   1.2749743E-08
     +,   1.5849334E-08,   1.9639211E-08,   2.4257472E-08
     +,   2.9865792E-08,   3.6653056E-08,   4.4838877E-08
     +,   5.4677429E-08,   6.6461610E-08,   8.0527364E-08
     +,   9.7258393E-08,   1.1709072E-07,   1.4051740E-07
     +,   1.6809369E-07,   2.0044099E-07,   2.3825193E-07
     +,   2.8229621E-07,   3.3341823E-07,   3.9254886E-07
     +,   4.6070070E-07,   5.3897207E-07,   6.2854662E-07
     +,   7.3069225E-07,   8.4675810E-07,   9.7816928E-07
     +,   1.1264214E-06,   1.2930703E-06,   1.4797250E-06
     +,   1.6880293E-06,   1.9196516E-06,   2.1762578E-06
     +,   2.4595211E-06,   2.7710414E-06,   3.1123948E-06
     +,   3.4850518E-06,   3.8903740E-06,   4.3295850E-06
     +,   4.8037396E-06,   5.3136973E-06,   5.8601063E-06
     +,   6.4433311E-06,   7.0635006E-06,   7.7204641E-06
     +,   8.4136873E-06,   9.1423999E-06,   9.9054014E-06
     +,   1.0701244E-05,   1.1528033E-05,   1.2383639E-05
     +,   1.3265499E-05,   1.4170838E-05,   1.5096482E-05
     +,   1.6039068E-05,   1.6995005E-05,   1.7960436E-05
     +,   1.8931334E-05,   1.9903619E-05,   2.0873127E-05
     +,   2.1835562E-05,   2.2786769E-05,   2.3722509E-05
     +,   2.4638764E-05,   2.5531523E-05,   2.6397058E-05
     +,   2.7231719E-05,   2.8032186E-05,   2.8795277E-05
     +,   2.9518136E-05,   3.0198171E-05,   3.0833009E-05
     +,   3.1420557E-05,   3.1959014E-05,   3.2446824E-05
     +,   3.2882639E-05,   3.3265384E-05,   3.3594140E-05
     +,   3.3868244E-05,   3.4087174E-05,   3.4250595E-05
     +,   3.4358327E-05,   3.4410336E-05,   3.4406756E-05
     +,   3.4347846E-05,   3.4234039E-05,   3.4065917E-05
     +,   3.3844255E-05,   3.3570006E-05,   3.3244320E-05
     +,   3.2868626E-05,   3.2444543E-05,   3.1974025E-05
     +,   3.1459247E-05,   3.0902789E-05,   3.0307463E-05
     +,   2.9676494E-05,   2.9013383E-05,   2.8322040E-05
     +,   2.7606651E-05,   2.6871718E-05,   2.6122072E-05
     +,   2.5362837E-05,   2.4599283E-05,   2.3836887E-05
     +,   2.3081317E-05,   2.2338227E-05,   2.1613369E-05
     +,   2.0912352E-05,   2.0240757E-05,   1.9603873E-05
     +,   1.9006811E-05,   1.8454270E-05,   1.7950608E-05
     +,   1.7499662E-05,   1.7104747E-05,   1.6768610E-05
     +,   1.6493361E-05,   1.6280404E-05,   1.6130452E-05
     +,   1.6043488E-05,   1.6018746E-05,   1.6054708E-05
     +,   1.6149115E-05,   1.6298980E-05,   1.6500637E-05
     +,   1.6749760E-05,   1.7041413E-05,   1.7370114E-05
     +,   1.7729921E-05,   1.8114511E-05,   1.8517234E-05
     +,   1.8931236E-05,   1.9349600E-05,   1.9765448E-05
     +,   2.0172038E-05,   2.0562951E-05,   2.0932286E-05
     +,   2.1274829E-05,   2.1586218E-05,   2.1863279E-05
     +,   2.2104243E-05,   2.2309046E-05,   2.2479657E-05
     +,   2.2620430E-05,   2.2738415E-05,   2.2843647E-05
     +,   2.2949387E-05,   2.3072231E-05,   2.3232085E-05
     +,   2.3451883E-05,   2.3757071E-05,   2.4174797E-05
     +,   2.4732723E-05,   2.5457455E-05,   2.6372820E-05
     +,   2.7497765E-05,   2.8844117E-05,   3.0414476E-05
     +,   3.2200642E-05,   3.4182543E-05,   3.6328751E-05
     +,   3.8599981E-05,   4.0957671E-05,   4.3380052E-05
     +,   4.5888923E-05,   4.8588921E-05,   5.1715459E-05
     +,   5.5681336E-05,   6.1106941E-05,   6.8821639E-05
     +,   7.9826590E-05,   9.5213771E-05,   1.1603705E-04
     +,   1.4316977E-04,   1.7733239E-04,   2.1972903E-04
     +,   2.7379932E-04,   3.4800739E-04,   4.5866569E-04
     +,   6.3306221E-04,   9.1955374E-04,   1.4153002E-03
     +,   2.2983274E-03,   3.7932210E-03,   5.9985421E-03
     +,   8.6636683E-03,   1.1167186E-02,   1.2794119E-02
     +,   1.3090396E-02,   1.2056114E-02,   1.0109160E-02
     +,   7.8429263E-03,   5.7420325E-03,   4.0591354E-03
     +,   2.8466771E-03,   2.0259491E-03,   1.4642004E-03
     +,   1.0517250E-03,   7.3379988E-04,   4.9194432E-04
     +,   3.1618591E-04,   1.9429078E-04,   1.1323503E-04
     +,   6.1865838E-05,   3.1321204E-05,   1.4565620E-05
     +,   6.1902679E-06,   2.4022129E-06,   8.5634235E-07
     +,   2.8662743E-07,   9.5754764E-08,   3.6399303E-08
     +,   1.8201886E-08,   1.1852623E-08,   8.8355474E-09
     +,   6.8894876E-09,   5.4305711E-09,   4.2846096E-09
     +,   3.3748013E-09,   2.6517457E-09,   2.0779796E-09
     +,   1.6237170E-09,   1.2649964E-09,   9.8251762E-10
     +,   7.6075446E-10,   5.8720345E-10,   4.5181120E-10
     +,   3.4652808E-10,   2.6493291E-10,   2.0190194E-10
     +,   1.5337248E-10,   1.1613348E-10,   8.7654682E-11
     +,   6.5947012E-11,   4.9455315E-11,   3.6968529E-11
     +,   2.7545955E-11,   2.0458989E-11,   1.5146355E-11
     +,   1.1177203E-11,   8.2217531E-12,   6.0283198E-12
     +,   4.4058099E-12,   3.2096691E-12,   2.3307543E-12
     +,   1.6870577E-12,   1.2172067E-12,   8.7539595E-13
     +,   6.2754738E-13,   4.4841949E-13,   3.1939206E-13
     +,   2.2676171E-13,   1.6047825E-13,   1.1320360E-13
     +,   7.9599474E-14,   5.5789961E-14,   3.8977027E-14
     +,   2.7142961E-14,   1.8841374E-14,   1.3036582E-14
     +,   8.9912666E-15,   6.1812403E-15,   4.2357987E-15
     +,   2.8932894E-15,   1.9699498E-15,   1.3369654E-15
     +,   9.0444113E-16,   6.0988379E-16,   4.0993094E-16
     +,   2.7465038E-16,   1.8341955E-16,   1.2210059E-16
     +,   8.1018801E-17,   5.3587248E-17,   3.5329069E-17
     +,   2.3217236E-17,   1.5208386E-17,   9.9303388E-18
     +,   6.4630884E-18,   4.1929893E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_hatt100 = Yx/0.0268709677419355
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2225904E-05,   1.2633961E-05
     +,   1.3047474E-05,   1.3466288E-05,   1.3890260E-05
     +,   1.4319278E-05,   1.4753251E-05,   1.5192116E-05
     +,   1.5635846E-05,   1.6084465E-05,   1.6538021E-05
     +,   1.6996622E-05,   1.7460423E-05,   1.7929642E-05
     +,   1.8404551E-05,   1.8885496E-05,   1.9372876E-05
     +,   1.9867188E-05,   2.0368985E-05,   2.0878904E-05
     +,   2.1397669E-05,   2.1926076E-05,   2.2465010E-05
     +,   2.3015464E-05,   2.3578465E-05,   2.4155170E-05
     +,   2.4746800E-05,   2.5354646E-05,   2.5980085E-05
     +,   2.6624550E-05,   2.7289556E-05,   2.7976648E-05
     +,   2.8687435E-05,   2.9423554E-05,   3.0186680E-05
     +,   3.0978474E-05,   3.1800620E-05,   3.2654760E-05
     +,   3.3542572E-05,   3.4465578E-05,   3.5425332E-05
     +,   3.6423240E-05,   3.7460653E-05,   3.8538768E-05
     +,   3.9658629E-05,   4.0821156E-05,   4.2027055E-05
     +,   4.3276839E-05,   4.4570810E-05,   4.5909008E-05
     +,   4.7291236E-05,   4.8717004E-05,   5.0185536E-05
     +,   5.1695817E-05,   5.3246382E-05,   5.4835575E-05
     +,   5.6461362E-05,   5.8121364E-05,   5.9812879E-05
     +,   6.1532868E-05,   6.3277963E-05,   6.5044529E-05
     +,   6.6828463E-05,   6.8625544E-05,   7.0431277E-05
     +,   7.2240699E-05,   7.4048898E-05,   7.5850461E-05
     +,   7.7640092E-05,   7.9412064E-05,   8.1160819E-05
     +,   8.2880455E-05,   8.4565268E-05,   8.6209366E-05
     +,   8.7807035E-05,   8.9352616E-05,   9.0840549E-05
     +,   9.2265349E-05,   9.3621922E-05,   9.4905365E-05
     +,   9.6110962E-05,   9.7234457E-05,   9.8271819E-05
     +,   9.9219564E-05,   1.0007446E-04,   1.0083387E-04
     +,   1.0149553E-04,   1.0205773E-04,   1.0251923E-04
     +,   1.0287936E-04,   1.0313795E-04,   1.0329542E-04
     +,   1.0335266E-04,   1.0331118E-04,   1.0317301E-04
     +,   1.0294071E-04,   1.0261737E-04,   1.0220662E-04
     +,   1.0171256E-04,   1.0113983E-04,   1.0049342E-04
     +,   9.9778903E-05,   9.9002158E-05,   9.8169563E-05
     +,   9.7287797E-05,   9.6363823E-05,   9.5405034E-05
     +,   9.4419083E-05,   9.3413801E-05,   9.2397233E-05
     +,   9.1377675E-05,   9.0363494E-05,   8.9363231E-05
     +,   8.8385401E-05,   8.7438646E-05,   8.6531458E-05
     +,   8.5672415E-05,   8.4869840E-05,   8.4131956E-05
     +,   8.3466774E-05,   8.2881968E-05,   8.2384940E-05
     +,   8.1982704E-05,   8.1681719E-05,   8.1488011E-05
     +,   8.1406957E-05,   8.1443308E-05,   8.1601043E-05
     +,   8.1883351E-05,   8.2292565E-05,   8.2830054E-05
     +,   8.3496190E-05,   8.4290332E-05,   8.5210675E-05
     +,   8.6254266E-05,   8.7417073E-05,   8.8693741E-05
     +,   9.0077723E-05,   9.1561356E-05,   9.3135772E-05
     +,   9.4790965E-05,   9.6515803E-05,   9.8298355E-05
     +,   1.0012571E-04,   1.0198421E-04,   1.0385970E-04
     +,   1.0573771E-04,   1.0760343E-04,   1.0944210E-04
     +,   1.1123937E-04,   1.1298139E-04,   1.1465509E-04
     +,   1.1624835E-04,   1.1775063E-04,   1.1915292E-04
     +,   1.2044793E-04,   1.2163050E-04,   1.2269776E-04
     +,   1.2364924E-04,   1.2448672E-04,   1.2521460E-04
     +,   1.2583965E-04,   1.2637088E-04,   1.2681946E-04
     +,   1.2719838E-04,   1.2752222E-04,   1.2780704E-04
     +,   1.2807008E-04,   1.2832972E-04,   1.2860575E-04
     +,   1.2891961E-04,   1.2929527E-04,   1.2976040E-04
     +,   1.3034782E-04,   1.3109751E-04,   1.3205901E-04
     +,   1.3329393E-04,   1.3487830E-04,   1.3690483E-04
     +,   1.3948460E-04,   1.4274751E-04,   1.4684074E-04
     +,   1.5192572E-04,   1.5817283E-04,   1.6575235E-04
     +,   1.7482215E-04,   1.8551276E-04,   1.9791005E-04
     +,   2.1203511E-04,   2.2782298E-04,   2.4510780E-04
     +,   2.6361126E-04,   2.8294060E-04,   3.0260559E-04
     +,   3.2205472E-04,   3.4073240E-04,   3.5815951E-04
     +,   3.7403748E-04,   3.8836626E-04,   4.0156403E-04
     +,   4.1457868E-04,   4.2897917E-04,   4.4701714E-04
     +,   4.7166180E-04,   5.0661882E-04,   5.5638113E-04
     +,   6.2633358E-04,   7.2294084E-04,   8.5399853E-04
     +,   1.0288572E-03,   1.2583678E-03,   1.5542395E-03
     +,   1.9275405E-03,   2.3861446E-03,   2.9312142E-03
     +,   3.5532964E-03,   4.2291465E-03,   4.9205283E-03
     +,   5.5759563E-03,   6.1359522E-03,   6.5415585E-03
     +,   6.7441198E-03,   6.7144148E-03,   6.4487425E-03
     +,   5.9701884E-03,   5.3247353E-03,   4.5732958E-03
     +,   3.7814854E-03,   3.0096469E-03,   2.3053542E-03
     +,   1.6994602E-03,   1.2057017E-03,   8.2325871E-04
     +,   5.4103241E-04,   3.4225787E-04,   2.0843509E-04
     +,   1.2221547E-04,   6.9007168E-05,   3.7528651E-05
     +,   1.9661824E-05,   9.9265490E-06,   4.8316269E-06
     +,   2.2690781E-06,   1.0295691E-06,   4.5254106E-07
     +,   1.9372470E-07,   8.1641247E-08,   3.4584431E-08
     +,   1.5273878E-08,   7.3976572E-09,   4.0999337E-09
     +,   2.6076101E-09,   1.8356550E-09,   1.3691384E-09
     +,   1.0495267E-09,   8.1357987E-10,   6.3306499E-10
     +,   4.9293919E-10,   3.8362979E-10,   2.9827896E-10
     +,   2.3167705E-10,   1.7976449E-10,   1.3935007E-10
     +,   1.0792487E-10,   8.3519767E-11,   6.4586753E-11
     +,   4.9913264E-11,   3.8551929E-11,   2.9762658E-11
     +,   2.2967923E-11,   1.7718349E-11,   1.3664969E-11
     +,   1.0536757E-11,   8.1233943E-12,   6.2620447E-12
     +,   4.8268833E-12,   3.7204411E-12,   2.8675803E-12
     +,   2.2101828E-12,   1.7035026E-12,   1.3129567E-12
     +,   1.0119378E-12,   7.7989899E-13,   6.0103983E-13
     +,   4.6315561E-13,   3.5686574E-13,   2.7492627E-13
     +,   2.1175879E-13,   1.6306811E-13,   1.2553789E-13
     +,   9.6615065E-14,   7.4328300E-14,   5.7159816E-14
     +,   4.3936853E-14,   3.3756543E-14,   2.5921084E-14
     +,   1.9893158E-14,   1.5257655E-14,   1.1694916E-14
     +,   8.9579841E-15,   6.8568054E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_hatt102 = Yx/0.0270967741935484
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_hatt103(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2225904E-05,   1.2633961E-05
     +,   1.3047474E-05,   1.3466288E-05,   1.3890260E-05
     +,   1.4319278E-05,   1.4753251E-05,   1.5192116E-05
     +,   1.5635846E-05,   1.6084465E-05,   1.6538021E-05
     +,   1.6996622E-05,   1.7460423E-05,   1.7929642E-05
     +,   1.8404551E-05,   1.8885496E-05,   1.9372876E-05
     +,   1.9867188E-05,   2.0368985E-05,   2.0878904E-05
     +,   2.1397669E-05,   2.1926076E-05,   2.2465010E-05
     +,   2.3015464E-05,   2.3578465E-05,   2.4155170E-05
     +,   2.4746800E-05,   2.5354646E-05,   2.5980085E-05
     +,   2.6624550E-05,   2.7289556E-05,   2.7976648E-05
     +,   2.8687435E-05,   2.9423554E-05,   3.0186680E-05
     +,   3.0978474E-05,   3.1800620E-05,   3.2654760E-05
     +,   3.3542572E-05,   3.4465578E-05,   3.5425332E-05
     +,   3.6423240E-05,   3.7460653E-05,   3.8538768E-05
     +,   3.9658629E-05,   4.0821156E-05,   4.2027055E-05
     +,   4.3276839E-05,   4.4570810E-05,   4.5909008E-05
     +,   4.7291236E-05,   4.8717004E-05,   5.0185536E-05
     +,   5.1695817E-05,   5.3246382E-05,   5.4835575E-05
     +,   5.6461362E-05,   5.8121364E-05,   5.9812879E-05
     +,   6.1532868E-05,   6.3277963E-05,   6.5044529E-05
     +,   6.6828463E-05,   6.8625544E-05,   7.0431277E-05
     +,   7.2240699E-05,   7.4048898E-05,   7.5850461E-05
     +,   7.7640092E-05,   7.9412064E-05,   8.1160819E-05
     +,   8.2880455E-05,   8.4565268E-05,   8.6209366E-05
     +,   8.7807035E-05,   8.9352616E-05,   9.0840549E-05
     +,   9.2265349E-05,   9.3621922E-05,   9.4905365E-05
     +,   9.6110962E-05,   9.7234457E-05,   9.8271819E-05
     +,   9.9219564E-05,   1.0007446E-04,   1.0083387E-04
     +,   1.0149553E-04,   1.0205773E-04,   1.0251923E-04
     +,   1.0287936E-04,   1.0313795E-04,   1.0329542E-04
     +,   1.0335266E-04,   1.0331118E-04,   1.0317301E-04
     +,   1.0294071E-04,   1.0261737E-04,   1.0220662E-04
     +,   1.0171256E-04,   1.0113983E-04,   1.0049342E-04
     +,   9.9778903E-05,   9.9002158E-05,   9.8169563E-05
     +,   9.7287797E-05,   9.6363823E-05,   9.5405034E-05
     +,   9.4419083E-05,   9.3413801E-05,   9.2397233E-05
     +,   9.1377675E-05,   9.0363494E-05,   8.9363231E-05
     +,   8.8385401E-05,   8.7438646E-05,   8.6531458E-05
     +,   8.5672415E-05,   8.4869840E-05,   8.4131956E-05
     +,   8.3466774E-05,   8.2881968E-05,   8.2384940E-05
     +,   8.1982704E-05,   8.1681719E-05,   8.1488011E-05
     +,   8.1406957E-05,   8.1443308E-05,   8.1601043E-05
     +,   8.1883351E-05,   8.2292565E-05,   8.2830054E-05
     +,   8.3496190E-05,   8.4290332E-05,   8.5210675E-05
     +,   8.6254266E-05,   8.7417073E-05,   8.8693741E-05
     +,   9.0077723E-05,   9.1561356E-05,   9.3135772E-05
     +,   9.4790965E-05,   9.6515803E-05,   9.8298355E-05
     +,   1.0012571E-04,   1.0198421E-04,   1.0385970E-04
     +,   1.0573771E-04,   1.0760343E-04,   1.0944210E-04
     +,   1.1123937E-04,   1.1298139E-04,   1.1465509E-04
     +,   1.1624835E-04,   1.1775063E-04,   1.1915292E-04
     +,   1.2044793E-04,   1.2163050E-04,   1.2269776E-04
     +,   1.2364924E-04,   1.2448672E-04,   1.2521460E-04
     +,   1.2583965E-04,   1.2637088E-04,   1.2681946E-04
     +,   1.2719838E-04,   1.2752222E-04,   1.2780704E-04
     +,   1.2807008E-04,   1.2832972E-04,   1.2860575E-04
     +,   1.2891961E-04,   1.2929527E-04,   1.2976040E-04
     +,   1.3034782E-04,   1.3109751E-04,   1.3205901E-04
     +,   1.3329393E-04,   1.3487830E-04,   1.3690483E-04
     +,   1.3948460E-04,   1.4274751E-04,   1.4684074E-04
     +,   1.5192572E-04,   1.5817283E-04,   1.6575235E-04
     +,   1.7482215E-04,   1.8551276E-04,   1.9791005E-04
     +,   2.1203511E-04,   2.2782298E-04,   2.4510780E-04
     +,   2.6361126E-04,   2.8294060E-04,   3.0260559E-04
     +,   3.2205472E-04,   3.4073240E-04,   3.5815951E-04
     +,   3.7403748E-04,   3.8836626E-04,   4.0156403E-04
     +,   4.1457868E-04,   4.2897917E-04,   4.4701714E-04
     +,   4.7166180E-04,   5.0661882E-04,   5.5638113E-04
     +,   6.2633358E-04,   7.2294084E-04,   8.5399853E-04
     +,   1.0288572E-03,   1.2583678E-03,   1.5542395E-03
     +,   1.9275405E-03,   2.3861446E-03,   2.9312142E-03
     +,   3.5532964E-03,   4.2291465E-03,   4.9205283E-03
     +,   5.5759563E-03,   6.1359522E-03,   6.5415585E-03
     +,   6.7441198E-03,   6.7144148E-03,   6.4487425E-03
     +,   5.9701884E-03,   5.3247353E-03,   4.5732958E-03
     +,   3.7814854E-03,   3.0096469E-03,   2.3053542E-03
     +,   1.6994602E-03,   1.2057017E-03,   8.2325871E-04
     +,   5.4103241E-04,   3.4225787E-04,   2.0843509E-04
     +,   1.2221547E-04,   6.9007168E-05,   3.7528651E-05
     +,   1.9661824E-05,   9.9265490E-06,   4.8316269E-06
     +,   2.2690781E-06,   1.0295691E-06,   4.5254106E-07
     +,   1.9372470E-07,   8.1641247E-08,   3.4584431E-08
     +,   1.5273878E-08,   7.3976572E-09,   4.0999337E-09
     +,   2.6076101E-09,   1.8356550E-09,   1.3691384E-09
     +,   1.0495267E-09,   8.1357987E-10,   6.3306499E-10
     +,   4.9293919E-10,   3.8362979E-10,   2.9827896E-10
     +,   2.3167705E-10,   1.7976449E-10,   1.3935007E-10
     +,   1.0792487E-10,   8.3519767E-11,   6.4586753E-11
     +,   4.9913264E-11,   3.8551929E-11,   2.9762658E-11
     +,   2.2967923E-11,   1.7718349E-11,   1.3664969E-11
     +,   1.0536757E-11,   8.1233943E-12,   6.2620447E-12
     +,   4.8268833E-12,   3.7204411E-12,   2.8675803E-12
     +,   2.2101828E-12,   1.7035026E-12,   1.3129567E-12
     +,   1.0119378E-12,   7.7989899E-13,   6.0103983E-13
     +,   4.6315561E-13,   3.5686574E-13,   2.7492627E-13
     +,   2.1175879E-13,   1.6306811E-13,   1.2553789E-13
     +,   9.6615065E-14,   7.4328300E-14,   5.7159816E-14
     +,   4.3936853E-14,   3.3756543E-14,   2.5921084E-14
     +,   1.9893158E-14,   1.5257655E-14,   1.1694916E-14
     +,   8.9579841E-15,   6.8568054E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_hatt103 = Yx/0.0270967741935484
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8437953E-05,   1.8848268E-05
     +,   1.9290464E-05,   1.9766743E-05,   2.0279183E-05
     +,   2.0829717E-05,   2.1420110E-05,   2.2051934E-05
     +,   2.2726523E-05,   2.3445007E-05,   2.4208228E-05
     +,   2.5016750E-05,   2.5870850E-05,   2.6770505E-05
     +,   2.7715376E-05,   2.8704824E-05,   2.9737916E-05
     +,   3.0813411E-05,   3.1929834E-05,   3.3085467E-05
     +,   3.4278408E-05,   3.5506662E-05,   3.6768128E-05
     +,   3.8060862E-05,   3.9382954E-05,   4.0732935E-05
     +,   4.2109761E-05,   4.3513130E-05,   4.4943707E-05
     +,   4.6403413E-05,   4.7895850E-05,   4.9426679E-05
     +,   5.1004121E-05,   5.2639443E-05,   5.4347627E-05
     +,   5.6147925E-05,   5.8064543E-05,   6.0127266E-05
     +,   6.2372208E-05,   6.4842046E-05,   6.7587018E-05
     +,   7.0664857E-05,   7.4141448E-05,   7.8090838E-05
     +,   8.2595419E-05,   8.7745975E-05,   9.3641793E-05
     +,   1.0039025E-04,   1.0810688E-04,   1.1691459E-04
     +,   1.2694258E-04,   1.3832429E-04,   1.5119379E-04
     +,   1.6568165E-04,   1.8190473E-04,   1.9995951E-04
     +,   2.1990627E-04,   2.4175530E-04,   2.6545019E-04
     +,   2.9085146E-04,   3.1772366E-04,   3.4572763E-04
     +,   3.7441944E-04,   4.0326701E-04,   4.3167523E-04
     +,   4.5902564E-04,   4.8474065E-04,   5.0834543E-04
     +,   5.2955194E-04,   5.4832624E-04,   5.6495907E-04
     +,   5.8010244E-04,   5.9478707E-04,   6.1040104E-04
     +,   6.2864879E-04,   6.5150153E-04,   6.8115955E-04
     +,   7.2004931E-04,   7.7085302E-04,   8.3651801E-04
     +,   9.2017313E-04,   1.0249125E-03,   1.1533849E-03
     +,   1.3074341E-03,   1.4880719E-03,   1.6965823E-03
     +,   1.9374364E-03,   2.2234325E-03,   2.5804823E-03
     +,   3.0453701E-03,   3.6484266E-03,   4.3852804E-03
     +,   5.2044750E-03,   6.0441624E-03,   6.9173509E-03
     +,   7.9851951E-03,   9.5327413E-03,   1.1839519E-02
     +,   1.4998440E-02,   1.8678639E-02,   2.2073651E-02
     +,   2.4465460E-02,   2.6041158E-02,   2.7750371E-02
     +,   3.0035181E-02,   3.1853139E-02,   3.1687010E-02
     +,   2.9385442E-02,   2.5736844E-02,   2.1908863E-02
     +,   1.9102907E-02,   1.7195556E-02,   1.5204428E-02
     +,   1.2813372E-02,   1.0378312E-02,   8.2213013E-03
     +,   6.4362073E-03,   5.0257379E-03,   3.9667389E-03
     +,   3.2045161E-03,   2.6678732E-03,   2.2905744E-03
     +,   2.0184920E-03,   1.8105835E-03,   1.6398098E-03
     +,   1.4918613E-03,   1.3608796E-03,   1.2447418E-03
     +,   1.1419896E-03,   1.0508479E-03,   9.6932735E-04
     +,   8.9563697E-04,   8.2837668E-04,   7.6656468E-04
     +,   7.0951245E-04,   6.5672043E-04,   6.0780614E-04
     +,   5.6246994E-04,   5.2048289E-04,   4.8168804E-04
     +,   4.4599269E-04,   4.1334936E-04,   3.8373345E-04
     +,   3.5712391E-04,   3.3348854E-04,   3.1276554E-04
     +,   2.9485853E-04,   2.7963432E-04,   2.6692095E-04
     +,   2.5651068E-04,   2.4816618E-04,   2.4162752E-04
     +,   2.3661905E-04,   2.3285708E-04,   2.3005852E-04
     +,   2.2794800E-04,   2.2626444E-04,   2.2476663E-04
     +,   2.2323769E-04,   2.2148866E-04,   2.1936084E-04
     +,   2.1672677E-04,   2.1349134E-04,   2.0959084E-04
     +,   2.0499194E-04,   1.9968979E-04,   1.9370591E-04
     +,   1.8708498E-04,   1.7989110E-04,   1.7220416E-04
     +,   1.6411663E-04,   1.5572898E-04,   1.4714529E-04
     +,   1.3846997E-04,   1.2980527E-04,   1.2124658E-04
     +,   1.1288087E-04,   1.0478533E-04,   9.7025397E-05
     +,   8.9653549E-05,   8.2709608E-05,   7.6221484E-05
     +,   7.0205177E-05,   6.4665554E-05,   5.9597955E-05
     +,   5.4989894E-05,   5.0822113E-05,   4.7069851E-05
     +,   4.3704571E-05,   4.0695537E-05,   3.8010359E-05
     +,   3.5616376E-05,   3.3481658E-05,   3.1575430E-05
     +,   2.9868566E-05,   2.8334051E-05,   2.6947322E-05
     +,   2.5686282E-05,   2.4531217E-05,   2.3464872E-05
     +,   2.2472403E-05,   2.1541129E-05,   2.0660313E-05
     +,   1.9821056E-05,   1.9016154E-05,   1.8239742E-05
     +,   1.7487215E-05,   1.6755075E-05,   1.6040731E-05
     +,   1.5342293E-05,   1.4658516E-05,   1.3988691E-05
     +,   1.3332523E-05,   1.2689979E-05,   1.2061274E-05
     +,   1.1446834E-05,   1.0847197E-05,   1.0262930E-05
     +,   9.6946342E-06,   9.1429647E-06,   8.6084901E-06
     +,   8.0917380E-06,   7.5932057E-06,   7.1133150E-06
     +,   6.6523689E-06,   6.2105942E-06,   5.7881502E-06
     +,   5.3851095E-06,   5.0014287E-06,   4.6369805E-06
     +,   4.2915840E-06,   3.9649790E-06,   3.6568133E-06
     +,   3.3666761E-06,   3.0941262E-06,   2.8386451E-06
     +,   2.5996728E-06,   2.3766297E-06,   2.1689054E-06
     +,   1.9758518E-06,   1.7968046E-06,   1.6311026E-06
     +,   1.4780763E-06,   1.3370443E-06,   1.2073317E-06
     +,   1.0882793E-06,   9.7923851E-07,   8.7956749E-07
     +,   7.8864360E-07,   7.0587242E-07,   6.3067228E-07
     +,   5.6248575E-07,   5.0078455E-07,   4.4506504E-07
     +,   3.9484573E-07,   3.4967195E-07,   3.0911860E-07
     +,   2.7278591E-07,   2.4029754E-07,   2.1130286E-07
     +,   1.8547772E-07,   1.6252116E-07,   1.4215357E-07
     +,   1.2411770E-07,   1.0817852E-07,   9.4119059E-08
     +,   8.1741227E-08,   7.0865319E-08,   6.1327754E-08
     +,   5.2979633E-08,   4.5686424E-08,   3.9327254E-08
     +,   3.3793260E-08,   2.8986420E-08,   2.4818997E-08
     +,   2.1213072E-08,   1.8098731E-08,   1.5414228E-08
     +,   1.3104486E-08,   1.1121092E-08,   9.4210364E-09
     +,   7.9667055E-09,   6.7248518E-09,   5.6665015E-09
     +,   4.7661781E-09,   4.0017878E-09,   3.3539991E-09
     +,   2.8060438E-09,   2.3434408E-09,   1.9536006E-09
     +,   1.6257151E-09,   1.3504393E-09,   1.1197797E-09
     +,   9.2685576E-10,   7.6580364E-10,   6.3160316E-10
     +,   5.1999327E-10,   4.2733789E-10,   3.5056713E-10
     +,   2.8707256E-10,   2.3465915E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_hatt75 = Yx/0.123439024390244
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3905689E-05,   4.8914906E-05
     +,   5.4358046E-05,   6.0244744E-05,   6.6579429E-05
     +,   7.3360570E-05,   8.0579812E-05,   8.8221343E-05
     +,   9.6261138E-05,   1.0466710E-04,   1.1339792E-04
     +,   1.2240365E-04,   1.3162577E-04,   1.4099749E-04
     +,   1.5044477E-04,   1.5988703E-04,   1.6923854E-04
     +,   1.7840997E-04,   1.8730995E-04,   1.9584727E-04
     +,   2.0393249E-04,   2.1148044E-04,   2.1841197E-04
     +,   2.2465657E-04,   2.3015299E-04,   2.3485259E-04
     +,   2.3871947E-04,   2.4173208E-04,   2.4388391E-04
     +,   2.4518371E-04,   2.4565548E-04,   2.4533781E-04
     +,   2.4428323E-04,   2.4255656E-04,   2.4023348E-04
     +,   2.3739842E-04,   2.3414256E-04,   2.3056149E-04
     +,   2.2675248E-04,   2.2281277E-04,   2.1883645E-04
     +,   2.1491281E-04,   2.1112425E-04,   2.0754451E-04
     +,   2.0423719E-04,   2.0125488E-04,   1.9863827E-04
     +,   1.9641584E-04,   1.9460403E-04,   1.9320736E-04
     +,   1.9221928E-04,   1.9162307E-04,   1.9139334E-04
     +,   1.9149698E-04,   1.9189542E-04,   1.9254585E-04
     +,   1.9340357E-04,   1.9442341E-04,   1.9556200E-04
     +,   1.9677955E-04,   1.9804150E-04,   1.9932054E-04
     +,   2.0059780E-04,   2.0186474E-04,   2.0312415E-04
     +,   2.0439118E-04,   2.0569481E-04,   2.0707786E-04
     +,   2.0859830E-04,   2.1032880E-04,   2.1235739E-04
     +,   2.1478660E-04,   2.1773316E-04,   2.2132604E-04
     +,   2.2570514E-04,   2.3101796E-04,   2.3741540E-04
     +,   2.4504660E-04,   2.5405284E-04,   2.6455912E-04
     +,   2.7666407E-04,   2.9043207E-04,   3.0587986E-04
     +,   3.2297152E-04,   3.4160740E-04,   3.6162685E-04
     +,   3.8280743E-04,   4.0488230E-04,   4.2755652E-04
     +,   4.5054214E-04,   4.7359455E-04,   4.9655203E-04
     +,   5.1937712E-04,   5.4218702E-04,   5.6526740E-04
     +,   5.8906275E-04,   6.1415799E-04,   6.4124755E-04
     +,   6.7113817E-04,   7.0479763E-04,   7.4351154E-04
     +,   7.8911858E-04,   8.4432727E-04,   9.1297395E-04
     +,   1.0001465E-03,   1.1120276E-03,   1.2554483E-03
     +,   1.4372448E-03,   1.6635980E-03,   1.9395369E-03
     +,   2.2688492E-03,   2.6547508E-03,   3.1009051E-03
     +,   3.6122731E-03,   4.1937111E-03,   4.8455582E-03
     +,   5.5566276E-03,   6.2993006E-03,   7.0310934E-03
     +,   7.7052740E-03,   8.2852971E-03,   8.7544220E-03
     +,   9.1136880E-03,   9.3696769E-03,   9.5211873E-03
     +,   9.5537892E-03,   9.4439397E-03,   9.1673834E-03
     +,   8.7067494E-03,   8.0583617E-03,   7.2399033E-03
     +,   6.2971795E-03,   5.3028464E-03,   4.3434175E-03
     +,   3.4972134E-03,   2.8142715E-03,   2.3074772E-03
     +,   1.9573532E-03,   1.7258734E-03,   1.5714822E-03
     +,   1.4595378E-03,   1.3665947E-03,   1.2799180E-03
     +,   1.1946621E-03,   1.1106541E-03,   1.0297941E-03
     +,   9.5437933E-04,   8.8620954E-04,   8.2620542E-04
     +,   7.7436341E-04,   7.2990003E-04,   6.9149391E-04
     +,   6.5755245E-04,   6.2646857E-04,   5.9682725E-04
     +,   5.6754128E-04,   5.3790881E-04,   5.0760631E-04
     +,   4.7664013E-04,   4.4527423E-04,   4.1393947E-04
     +,   3.8315571E-04,   3.5346451E-04,   3.2537122E-04
     +,   2.9930435E-04,   2.7559247E-04,   2.5445415E-04
     +,   2.3599582E-04,   2.2021856E-04,   2.0703425E-04
     +,   1.9628332E-04,   1.8775274E-04,   1.8119412E-04
     +,   1.7634132E-04,   1.7292469E-04,   1.7068138E-04
     +,   1.6936437E-04,   1.6874768E-04,   1.6862915E-04
     +,   1.6883214E-04,   1.6920506E-04,   1.6962012E-04
     +,   1.6997149E-04,   1.7017324E-04,   1.7015696E-04
     +,   1.6986957E-04,   1.6927122E-04,   1.6833351E-04
     +,   1.6703777E-04,   1.6537383E-04,   1.6333854E-04
     +,   1.6093497E-04,   1.5817165E-04,   1.5506175E-04
     +,   1.5162225E-04,   1.4787352E-04,   1.4383909E-04
     +,   1.3954497E-04,   1.3501885E-04,   1.3029011E-04
     +,   1.2538943E-04,   1.2034825E-04,   1.1519814E-04
     +,   1.0997045E-04,   1.0469664E-04,   9.9406861E-05
     +,   9.4130140E-05,   8.8894391E-05,   8.3725812E-05
     +,   7.8648322E-05,   7.3683732E-05,   6.8851950E-05
     +,   6.4170417E-05,   5.9653881E-05,   5.5314653E-05
     +,   5.1162900E-05,   4.7206409E-05,   4.3450411E-05
     +,   3.9898034E-05,   3.6550708E-05,   3.3407701E-05
     +,   3.0466615E-05,   2.7723792E-05,   2.5174253E-05
     +,   2.2811742E-05,   2.0629142E-05,   1.8618748E-05
     +,   1.6772290E-05,   1.5080980E-05,   1.3535817E-05
     +,   1.2127794E-05,   1.0847893E-05,   9.6871308E-06
     +,   8.6367327E-06,   7.6882980E-06,   6.8336471E-06
     +,   6.0649877E-06,   5.3749827E-06,   4.7567100E-06
     +,   4.2036436E-06,   3.7097047E-06,   3.2692867E-06
     +,   2.8772024E-06,   2.5286552E-06,   2.2192494E-06
     +,   1.9449881E-06,   1.7022260E-06,   1.4876350E-06
     +,   1.2982024E-06,   1.1312197E-06,   9.8422686E-07
     +,   8.5500869E-07,   7.4158271E-07,   6.4216732E-07
     +,   5.5515903E-07,   4.7912431E-07,   4.1278597E-07
     +,   3.5500298E-07,   3.0475451E-07,   2.6113145E-07
     +,   2.2332861E-07,   1.9062999E-07,   1.6239812E-07
     +,   1.3806873E-07,   1.1714507E-07,   9.9185840E-08
     +,   8.3802263E-08,   7.0653186E-08,   5.9438356E-08
     +,   4.9893806E-08,   4.1788571E-08,   3.4921360E-08
     +,   2.9116544E-08,   2.4220990E-08,   2.0101833E-08
     +,   1.6644416E-08,   1.3749188E-08,   1.1330783E-08
     +,   9.3154773E-09,   7.6403257E-09,   6.2512755E-09
     +,   5.1024269E-09,   4.1545620E-09,   3.3745433E-09
     +,   2.7342411E-09,   2.2100028E-09,   1.7818721E-09
     +,   1.4331168E-09,   1.1497714E-09,   9.2014746E-10
     +,   7.3455259E-10,   5.8492444E-10,   4.6461412E-10
     +,   3.6812281E-10,   2.9094130E-10,   2.2936236E-10
     +,   1.8036356E-10,   1.4147417E-10,   1.1069117E-10
     +,   8.6386814E-11,   6.7249470E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_hatt80 = Yx/0.0554166666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0614367E-05,   3.0406727E-05
     +,   3.0207008E-05,   3.0017885E-05,   2.9842053E-05
     +,   2.9682218E-05,   2.9541085E-05,   2.9421351E-05
     +,   2.9325691E-05,   2.9256735E-05,   2.9217075E-05
     +,   2.9209255E-05,   2.9235734E-05,   2.9298897E-05
     +,   2.9401033E-05,   2.9544344E-05,   2.9730896E-05
     +,   2.9962652E-05,   3.0241448E-05,   3.0568990E-05
     +,   3.0946831E-05,   3.1376399E-05,   3.1858981E-05
     +,   3.2395754E-05,   3.2987708E-05,   3.3635788E-05
     +,   3.4340796E-05,   3.5103443E-05,   3.5924408E-05
     +,   3.6804326E-05,   3.7743815E-05,   3.8743561E-05
     +,   3.9804319E-05,   4.0926985E-05,   4.2112631E-05
     +,   4.3362597E-05,   4.4678527E-05,   4.6062385E-05
     +,   4.7516714E-05,   4.9044382E-05,   5.0649011E-05
     +,   5.2334752E-05,   5.4106476E-05,   5.5969798E-05
     +,   5.7931124E-05,   5.9997637E-05,   6.2177351E-05
     +,   6.4479056E-05,   6.6912340E-05,   6.9487440E-05
     +,   7.2215276E-05,   7.5107302E-05,   7.8175217E-05
     +,   8.1431230E-05,   8.4887171E-05,   8.8555105E-05
     +,   9.2446397E-05,   9.6571806E-05,   1.0094109E-04
     +,   1.0556277E-04,   1.1044375E-04,   1.1558911E-04
     +,   1.2100134E-04,   1.2668084E-04,   1.3262514E-04
     +,   1.3882805E-04,   1.4528078E-04,   1.5197005E-04
     +,   1.5887960E-04,   1.6598839E-04,   1.7327224E-04
     +,   1.8070207E-04,   1.8824583E-04,   1.9586674E-04
     +,   2.0352537E-04,   2.1117929E-04,   2.1878285E-04
     +,   2.2628858E-04,   2.3364807E-04,   2.4081244E-04
     +,   2.4773224E-04,   2.5436023E-04,   2.6065021E-04
     +,   2.6655980E-04,   2.7204989E-04,   2.7708671E-04
     +,   2.8164196E-04,   2.8569440E-04,   2.8923017E-04
     +,   2.9224475E-04,   2.9474343E-04,   2.9674268E-04
     +,   2.9827206E-04,   2.9937556E-04,   3.0011320E-04
     +,   3.0056344E-04,   3.0082435E-04,   3.0101527E-04
     +,   3.0127744E-04,   3.0177407E-04,   3.0268796E-04
     +,   3.0421838E-04,   3.0657480E-04,   3.0996787E-04
     +,   3.1459867E-04,   3.2064397E-04,   3.2824048E-04
     +,   3.3746706E-04,   3.4832963E-04,   3.6074547E-04
     +,   3.7453245E-04,   3.8940855E-04,   4.0499395E-04
     +,   4.2083181E-04,   4.3641264E-04,   4.5122040E-04
     +,   4.6478177E-04,   4.7673416E-04,   4.8689346E-04
     +,   4.9533258E-04,   5.0245429E-04,   5.0905853E-04
     +,   5.1640038E-04,   5.2622362E-04,   5.4077129E-04
     +,   5.6275551E-04,   5.9529056E-04,   6.4176042E-04
     +,   7.0564670E-04,   7.9027610E-04,   8.9854829E-04
     +,   1.0325905E-03,   1.1934568E-03,   1.3807920E-03
     +,   1.5926142E-03,   1.8251470E-03,   2.0727415E-03
     +,   2.3279618E-03,   2.5817933E-03,   2.8239854E-03
     +,   3.0435615E-03,   3.2295603E-03,   3.3719626E-03
     +,   3.4626988E-03,   3.4966692E-03,   3.4725603E-03
     +,   3.3932340E-03,   3.2655573E-03,   3.0996220E-03
     +,   2.9074547E-03,   2.7014718E-03,   2.4930248E-03
     +,   2.2912233E-03,   2.1023115E-03,   1.9296180E-03
     +,   1.7739721E-03,   1.6343938E-03,   1.5088439E-03
     +,   1.3949240E-03,   1.2903751E-03,   1.1933264E-03
     +,   1.1024026E-03,   1.0166882E-03,   9.3561731E-04
     +,   8.5885241E-04,   7.8618684E-04,   7.1748038E-04
     +,   6.5261783E-04,   5.9149554E-04,   5.3403043E-04
     +,   4.8017493E-04,   4.2991759E-04,   3.8327707E-04
     +,   3.4029424E-04,   3.0101670E-04,   2.6546800E-04
     +,   2.3363389E-04,   2.0544864E-04,   1.8078640E-04
     +,   1.5946050E-04,   1.4123329E-04,   1.2582952E-04
     +,   1.1294907E-04,   1.0228166E-04,   9.3521623E-05
     +,   8.6379441E-05,   8.0589016E-05,   7.5912612E-05
     +,   7.2143543E-05,   6.9106223E-05,   6.6653498E-05
     +,   6.4664098E-05,   6.3039057E-05,   6.1697850E-05
     +,   6.0574839E-05,   5.9616341E-05,   5.8778081E-05
     +,   5.8023175E-05,   5.7320547E-05,   5.6643970E-05
     +,   5.5971315E-05,   5.5284017E-05,   5.4566699E-05
     +,   5.3806911E-05,   5.2995063E-05,   5.2124022E-05
     +,   5.1189007E-05,   5.0187464E-05,   4.9118713E-05
     +,   4.7983744E-05,   4.6784986E-05,   4.5526140E-05
     +,   4.4211960E-05,   4.2847889E-05,   4.1439980E-05
     +,   3.9994811E-05,   3.8519243E-05,   3.7020189E-05
     +,   3.5504574E-05,   3.3979421E-05,   3.2451400E-05
     +,   3.0926978E-05,   2.9412391E-05,   2.7913542E-05
     +,   2.6435842E-05,   2.4984269E-05,   2.3563454E-05
     +,   2.2177574E-05,   2.0830235E-05,   1.9524565E-05
     +,   1.8263325E-05,   1.7048806E-05,   1.5882759E-05
     +,   1.4766525E-05,   1.3701132E-05,   1.2687115E-05
     +,   1.1724654E-05,   1.0813654E-05,   9.9537074E-06
     +,   9.1440770E-06,   8.3837776E-06,   7.6716597E-06
     +,   7.0063766E-06,   6.3863799E-06,   5.8099895E-06
     +,   5.2754581E-06,   4.7809503E-06,   4.3245395E-06
     +,   3.9042643E-06,   3.5181838E-06,   3.1643181E-06
     +,   2.8407023E-06,   2.5454251E-06,   2.2766114E-06
     +,   2.0324194E-06,   1.8110686E-06,   1.6108636E-06
     +,   1.4301754E-06,   1.2674425E-06,   1.1211832E-06
     +,   9.9000817E-07,   8.7260884E-07,   7.6774950E-07
     +,   6.7427891E-07,   5.9113370E-07,   5.1731894E-07
     +,   4.5191607E-07,   3.9408303E-07,   3.4304597E-07
     +,   2.9809263E-07,   2.5857358E-07,   2.2390014E-07
     +,   1.9353764E-07,   1.6700005E-07,   1.4384896E-07
     +,   1.2369189E-07,   1.0617349E-07,   9.0978062E-08
     +,   7.7821447E-08,   6.6452088E-08,   5.6644797E-08
     +,   4.8201294E-08,   4.0944894E-08,   3.4720642E-08
     +,   2.9391247E-08,   2.4836746E-08,   2.0951472E-08
     +,   1.7643117E-08,   1.4831347E-08,   1.2445865E-08
     +,   1.0425877E-08,   8.7184064E-09,   7.2778432E-09
     +,   6.0646155E-09,   5.0447815E-09,   4.1890384E-09
     +,   3.4723382E-09,   2.8731575E-09,   2.3731777E-09
     +,   1.9567155E-09,   1.6104791E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_hatt85 = Yx/0.0259677419354839
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5574072E-05,   2.6123616E-05
     +,   2.6671891E-05,   2.7217731E-05,   2.7759972E-05
     +,   2.8297387E-05,   2.8828723E-05,   2.9352701E-05
     +,   2.9868032E-05,   3.0373430E-05,   3.0867595E-05
     +,   3.1349256E-05,   3.1817155E-05,   3.2270087E-05
     +,   3.2706888E-05,   3.3126460E-05,   3.3527791E-05
     +,   3.3909972E-05,   3.4272205E-05,   3.4613811E-05
     +,   3.4934299E-05,   3.5233305E-05,   3.5510697E-05
     +,   3.5766549E-05,   3.6001140E-05,   3.6215057E-05
     +,   3.6409139E-05,   3.6584523E-05,   3.6742687E-05
     +,   3.6885463E-05,   3.7015041E-05,   3.7134003E-05
     +,   3.7245361E-05,   3.7352544E-05,   3.7459435E-05
     +,   3.7570375E-05,   3.7690199E-05,   3.7824208E-05
     +,   3.7978221E-05,   3.8158549E-05,   3.8371971E-05
     +,   3.8625818E-05,   3.8927839E-05,   3.9286304E-05
     +,   3.9709899E-05,   4.0207731E-05,   4.0789328E-05
     +,   4.1464486E-05,   4.2243348E-05,   4.3136293E-05
     +,   4.4153803E-05,   4.5306515E-05,   4.6605008E-05
     +,   4.8059817E-05,   4.9681141E-05,   5.1478968E-05
     +,   5.3462754E-05,   5.5641325E-05,   5.8022742E-05
     +,   6.0614137E-05,   6.3421496E-05,   6.6449596E-05
     +,   6.9701469E-05,   7.3178773E-05,   7.6881304E-05
     +,   8.0806451E-05,   8.4949890E-05,   8.9304369E-05
     +,   9.3860683E-05,   9.8606404E-05,   1.0352697E-04
     +,   1.0860444E-04,   1.1381864E-04,   1.1914610E-04
     +,   1.2456105E-04,   1.3003525E-04,   1.3553770E-04
     +,   1.4103540E-04,   1.4649383E-04,   1.5187702E-04
     +,   1.5714751E-04,   1.6226798E-04,   1.6720041E-04
     +,   1.7190783E-04,   1.7635389E-04,   1.8050431E-04
     +,   1.8432662E-04,   1.8779152E-04,   1.9087263E-04
     +,   1.9354784E-04,   1.9579900E-04,   1.9761281E-04
     +,   1.9898069E-04,   1.9989944E-04,   2.0037113E-04
     +,   2.0040302E-04,   2.0000774E-04,   1.9920286E-04
     +,   1.9801057E-04,   1.9645771E-04,   1.9457463E-04
     +,   1.9239534E-04,   1.8995610E-04,   1.8729566E-04
     +,   1.8445382E-04,   1.8147087E-04,   1.7838740E-04
     +,   1.7524316E-04,   1.7207638E-04,   1.6892349E-04
     +,   1.6581875E-04,   1.6279329E-04,   1.5987561E-04
     +,   1.5709053E-04,   1.5445982E-04,   1.5200159E-04
     +,   1.4973084E-04,   1.4765917E-04,   1.4579533E-04
     +,   1.4414526E-04,   1.4271241E-04,   1.4149820E-04
     +,   1.4050225E-04,   1.3972266E-04,   1.3915625E-04
     +,   1.3879882E-04,   1.3864516E-04,   1.3868914E-04
     +,   1.3892347E-04,   1.3934003E-04,   1.3992981E-04
     +,   1.4068361E-04,   1.4159383E-04,   1.4265678E-04
     +,   1.4387722E-04,   1.4527493E-04,   1.4689365E-04
     +,   1.4881260E-04,   1.5116148E-04,   1.5413675E-04
     +,   1.5801976E-04,   1.6319565E-04,   1.7017088E-04
     +,   1.7958805E-04,   1.9223479E-04,   2.0904934E-04
     +,   2.3111663E-04,   2.5965349E-04,   2.9598636E-04
     +,   3.4151966E-04,   3.9768740E-04,   4.6588556E-04
     +,   5.4739311E-04,   6.4327562E-04,   7.5425633E-04
     +,   8.8056060E-04,   1.0217528E-03,   1.1765755E-03
     +,   1.3427836E-03,   1.5170031E-03,   1.6947249E-03
     +,   1.8703460E-03,   2.0373622E-03,   2.1887287E-03
     +,   2.3173706E-03,   2.4167642E-03,   2.4815754E-03
     +,   2.5082708E-03,   2.4955745E-03,   2.4447027E-03
     +,   2.3593374E-03,   2.2453137E-03,   2.1100354E-03
     +,   1.9617428E-03,   1.8087229E-03,   1.6585120E-03
     +,   1.5172987E-03,   1.3895273E-03,   1.2777284E-03
     +,   1.1825842E-03,   1.1031999E-03,   1.0374902E-03
     +,   9.8261621E-04,   9.3541254E-04,   8.9277112E-04
     +,   8.5193687E-04,   8.1069767E-04,   7.6748536E-04
     +,   7.2139781E-04,   6.7215756E-04,   6.2001328E-04
     +,   5.6562631E-04,   5.0994486E-04,   4.5407299E-04
     +,   3.9915036E-04,   3.4625741E-04,   2.9634248E-04
     +,   2.5016590E-04,   2.0826848E-04,   1.7096887E-04
     +,   1.3837675E-04,   1.1041488E-04,   8.6851716E-05
     +,   6.7342640E-05,   5.1470077E-05,   3.8775677E-05
     +,   2.8793513E-05,   2.1074844E-05,   1.5204645E-05
     +,   1.0812666E-05,   7.5794551E-06,   5.2373061E-06
     +,   3.5674780E-06,   2.3955624E-06,   1.5858254E-06
     +,   1.0349653E-06,   6.6594822E-07,   4.2248146E-07
     +,   2.6426133E-07,   1.6298348E-07,   9.9115283E-08
     +,   5.9432516E-08,   3.5140335E-08,   2.0487814E-08
     +,   1.1778343E-08,   6.6766663E-09,   3.7318459E-09
     +,   2.0567252E-09,   1.1176386E-09,   5.9880434E-10
     +,   3.1632705E-10,   1.6477170E-10,   8.4637436E-11
     +,   4.2881688E-11,   2.1440951E-11,   1.0589738E-11
     +,   5.1757977E-12,   2.5119405E-12,   1.2181709E-12
     +,   5.9683633E-13,   3.0081365E-13,   1.6005297E-13
     +,   9.2502049E-14,   5.9163225E-14,   4.1768445E-14
     +,   3.1867982E-14,   2.5590139E-14,   2.1167162E-14
     +,   1.7785578E-14,   1.5060541E-14,   1.2798045E-14
     +,   1.0890534E-14,   9.2704698E-15,   7.8901509E-15
     +,   6.7126476E-15,   5.7078929E-15,   4.8507870E-15
     +,   4.1199852E-15,   3.4971797E-15,   2.9667121E-15
     +,   2.5151762E-15,   2.1310839E-15,   1.8045429E-15
     +,   1.5270963E-15,   1.2915233E-15,   1.0916228E-15
     +,   9.2209330E-16,   7.7841386E-16,   6.5672508E-16
     +,   5.5371830E-16,   4.6658026E-16,   3.9291241E-16
     +,   3.3067552E-16,   2.7812610E-16,   2.3378223E-16
     +,   1.9638927E-16,   1.6487438E-16,   1.3833219E-16
     +,   1.1599134E-16,   9.7198983E-17,   8.1400885E-17
     +,   6.8128852E-17,   5.6985260E-17,   4.7635346E-17
     +,   3.9794875E-17,   3.3224510E-17,   2.7721881E-17
     +,   2.3116232E-17,   1.9264002E-17,   1.6043759E-17
     +,   1.3353625E-17,   1.1107673E-17,   9.2338172E-18
     +,   7.6712970E-18,   6.3693180E-18,   5.2850058E-18
     +,   4.3826208E-18,   3.6320396E-18,   3.0081699E-18
     +,   2.4899175E-18,   2.0596855E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_hatt90 = Yx/0.0185
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0170247E-06,   3.3311069E-06
     +,   3.6718684E-06,   4.0408754E-06,   4.4397088E-06
     +,   4.8699585E-06,   5.3332151E-06,   5.8310566E-06
     +,   6.3650346E-06,   6.9366902E-06,   7.5475041E-06
     +,   8.1989028E-06,   8.8922525E-06,   9.6288431E-06
     +,   1.0409878E-05,   1.1236453E-05,   1.2109561E-05
     +,   1.3030073E-05,   1.3998731E-05,   1.5016141E-05
     +,   1.6082762E-05,   1.7198909E-05,   1.8364715E-05
     +,   1.9580249E-05,   2.0845271E-05,   2.2159538E-05
     +,   2.3522571E-05,   2.4933752E-05,   2.6392336E-05
     +,   2.7897438E-05,   2.9448056E-05,   3.1043051E-05
     +,   3.2681215E-05,   3.4361223E-05,   3.6081692E-05
     +,   3.7841142E-05,   3.9638078E-05,   4.1470903E-05
     +,   4.3338110E-05,   4.5237954E-05,   4.7168891E-05
     +,   4.9129212E-05,   5.1117237E-05,   5.3131251E-05
     +,   5.5169494E-05,   5.7230180E-05,   5.9311453E-05
     +,   6.1411360E-05,   6.3527878E-05,   6.5658831E-05
     +,   6.7801891E-05,   6.9954520E-05,   7.2113980E-05
     +,   7.4277355E-05,   7.6441240E-05,   7.8602119E-05
     +,   8.0756006E-05,   8.2898609E-05,   8.5025153E-05
     +,   8.7130531E-05,   8.9209185E-05,   9.1255119E-05
     +,   9.3261864E-05,   9.5222640E-05,   9.7130302E-05
     +,   9.8977172E-05,   1.0075551E-04,   1.0245710E-04
     +,   1.0407371E-04,   1.0559685E-04,   1.0701812E-04
     +,   1.0832904E-04,   1.0952143E-04,   1.1058719E-04
     +,   1.1151869E-04,   1.1230868E-04,   1.1295049E-04
     +,   1.1343804E-04,   1.1376608E-04,   1.1393015E-04
     +,   1.1392666E-04,   1.1375306E-04,   1.1340784E-04
     +,   1.1289053E-04,   1.1220186E-04,   1.1134359E-04
     +,   1.1031876E-04,   1.0913140E-04,   1.0778680E-04
     +,   1.0629120E-04,   1.0465182E-04,   1.0287690E-04
     +,   1.0097560E-04,   9.8957709E-05,   9.6833654E-05
     +,   9.4614566E-05,   9.2311850E-05,   8.9937406E-05
     +,   8.7503089E-05,   8.5021115E-05,   8.2503335E-05
     +,   7.9961777E-05,   7.7407858E-05,   7.4852956E-05
     +,   7.2307710E-05,   6.9782232E-05,   6.7286172E-05
     +,   6.4828448E-05,   6.2417093E-05,   6.0059392E-05
     +,   5.7761965E-05,   5.5530367E-05,   5.3369575E-05
     +,   5.1283452E-05,   4.9275324E-05,   4.7347447E-05
     +,   4.5501572E-05,   4.3738488E-05,   4.2058564E-05
     +,   4.0461335E-05,   3.8945818E-05,   3.7510632E-05
     +,   3.6153982E-05,   3.4873618E-05,   3.3667045E-05
     +,   3.2531745E-05,   3.1464937E-05,   3.0464065E-05
     +,   2.9526600E-05,   2.8650426E-05,   2.7833757E-05
     +,   2.7075537E-05,   2.6375385E-05,   2.5733965E-05
     +,   2.5153029E-05,   2.4635658E-05,   2.4186447E-05
     +,   2.3811588E-05,   2.3518931E-05,   2.3318009E-05
     +,   2.3219965E-05,   2.3237288E-05,   2.3383480E-05
     +,   2.3672588E-05,   2.4118492E-05,   2.4734189E-05
     +,   2.5530933E-05,   2.6517271E-05,   2.7698283E-05
     +,   2.9075105E-05,   3.0644886E-05,   3.2401309E-05
     +,   3.4336557E-05,   3.6444784E-05,   3.8727259E-05
     +,   4.1199815E-05,   4.3902917E-05,   4.6914116E-05
     +,   5.0361799E-05,   5.4439006E-05,   5.9416550E-05
     +,   6.5650973E-05,   7.3584823E-05,   8.3737250E-05
     +,   9.6682845E-05,   1.1301711E-04,   1.3331097E-04
     +,   1.5806479E-04,   1.8767510E-04,   2.2243155E-04
     +,   2.6257386E-04,   3.0844825E-04,   3.6079087E-04
     +,   4.2114354E-04,   4.9237855E-04,   5.7927880E-04
     +,   6.8898621E-04,   8.3111000E-04,   1.0172524E-03
     +,   1.2597748E-03,   1.5698069E-03,   1.9548717E-03
     +,   2.4168536E-03,   2.9509766E-03,   3.5459117E-03
     +,   4.1844416E-03,   4.8436364E-03,   5.4936600E-03
     +,   6.0956348E-03,   6.6009937E-03,   6.9553913E-03
     +,   7.1082208E-03,   7.0259878E-03,   6.7042732E-03
     +,   6.1723972E-03,   5.4879785E-03,   4.7233547E-03
     +,   3.9493027E-03,   3.2221759E-03,   2.5780150E-03
     +,   2.0332600E-03,   1.5893197E-03,   1.2381892E-03
     +,   9.6721022E-04,   7.6230167E-04,   6.0982601E-04
     +,   4.9764046E-04,   4.1552834E-04,   3.5523783E-04
     +,   3.1030326E-04,   2.7578531E-04,   2.4800896E-04
     +,   2.2434711E-04,   2.0304565E-04,   1.8306893E-04
     +,   1.6394178E-04,   1.4558325E-04,   1.2814776E-04
     +,   1.1188922E-04,   9.7059310E-05,   8.3839193E-05
     +,   7.2311217E-05,   6.2457104E-05,   5.4172600E-05
     +,   4.7291749E-05,   4.1614534E-05,   3.6931222E-05
     +,   3.3040615E-05,   2.9762854E-05,   2.6946724E-05
     +,   2.4472125E-05,   2.2248596E-05,   2.0211754E-05
     +,   1.8318868E-05,   1.6544098E-05,   1.4873506E-05
     +,   1.3301236E-05,   1.1826381E-05,   1.0450435E-05
     +,   9.1754691E-06,   8.0031132E-06,   6.9339740E-06
     +,   5.9672252E-06,   5.1004999E-06,   4.3300693E-06
     +,   3.6510805E-06,   3.0577362E-06,   2.5435359E-06
     +,   2.1015751E-06,   1.7248177E-06,   1.4062118E-06
     +,   1.1389116E-06,   9.1642039E-07,   7.3266659E-07
     +,   5.8206035E-07,   4.5955008E-07,   3.6063946E-07
     +,   2.8136986E-07,   2.1829612E-07,   1.6846207E-07
     +,   1.2936127E-07,   9.8888414E-08,   7.5292576E-08
     +,   5.7134393E-08,   4.3243670E-08,   3.2675146E-08
     +,   2.4674025E-08,   1.8643318E-08,   1.4114499E-08
     +,   1.0722816E-08,   8.1870368E-09,   6.2921450E-09
     +,   4.8748223E-09,   3.8119219E-09,   3.0113048E-09
     +,   2.4045235E-09,   1.9409037E-09,   1.5832288E-09
     +,   1.3041910E-09,   1.0838784E-09,   9.0774099E-10
     +,   7.6518386E-10,   6.4844091E-10,   5.5182214E-10
     +,   4.7110332E-10,   4.0313794E-10,   3.4553868E-10
     +,   2.9647304E-10,   2.5451713E-10,   2.1853584E-10
     +,   1.8761984E-10,   1.6102041E-10,   1.3812043E-10
     +,   1.1839907E-10,   1.0141763E-10,   8.6799436E-11
     +,   7.4223135E-11,   6.3410201E-11,   5.4121232E-11
     +,   4.6147964E-11,   3.9310766E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_hatt95 = Yx/0.0282258064516129
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1107834E-04,   1.1530380E-04
     +,   1.1963448E-04,   1.2406972E-04,   1.2860852E-04
     +,   1.3324940E-04,   1.3799043E-04,   1.4282913E-04
     +,   1.4776255E-04,   1.5278715E-04,   1.5789868E-04
     +,   1.6309242E-04,   1.6836291E-04,   1.7370391E-04
     +,   1.7910870E-04,   1.8456961E-04,   1.9007848E-04
     +,   1.9562634E-04,   2.0120361E-04,   2.0679983E-04
     +,   2.1240413E-04,   2.1800502E-04,   2.2359012E-04
     +,   2.2914722E-04,   2.3466274E-04,   2.4012355E-04
     +,   2.4551572E-04,   2.5082528E-04,   2.5603818E-04
     +,   2.6114006E-04,   2.6611687E-04,   2.7095474E-04
     +,   2.7564008E-04,   2.8015941E-04,   2.8450022E-04
     +,   2.8865022E-04,   2.9259792E-04,   2.9633282E-04
     +,   2.9984544E-04,   3.0312684E-04,   3.0616979E-04
     +,   3.0896789E-04,   3.1151611E-04,   3.1381057E-04
     +,   3.1584932E-04,   3.1763109E-04,   3.1915671E-04
     +,   3.2042799E-04,   3.2144846E-04,   3.2222294E-04
     +,   3.2275770E-04,   3.2306049E-04,   3.2314000E-04
     +,   3.2300639E-04,   3.2267103E-04,   3.2214608E-04
     +,   3.2144482E-04,   3.2058131E-04,   3.1957022E-04
     +,   3.1842667E-04,   3.1716641E-04,   3.1580555E-04
     +,   3.1435993E-04,   3.1284578E-04,   3.1127880E-04
     +,   3.0967491E-04,   3.0804909E-04,   3.0641610E-04
     +,   3.0478992E-04,   3.0318377E-04,   3.0161001E-04
     +,   3.0007990E-04,   2.9860387E-04,   2.9719109E-04
     +,   2.9584963E-04,   2.9458641E-04,   2.9340689E-04
     +,   2.9231576E-04,   2.9131590E-04,   2.9040937E-04
     +,   2.8959705E-04,   2.8887851E-04,   2.8825225E-04
     +,   2.8771599E-04,   2.8726616E-04,   2.8689840E-04
     +,   2.8660777E-04,   2.8638853E-04,   2.8623422E-04
     +,   2.8613818E-04,   2.8609295E-04,   2.8609126E-04
     +,   2.8612523E-04,   2.8618719E-04,   2.8626926E-04
     +,   2.8636394E-04,   2.8646353E-04,   2.8656097E-04
     +,   2.8664936E-04,   2.8672218E-04,   2.8677355E-04
     +,   2.8679782E-04,   2.8679005E-04,   2.8674598E-04
     +,   2.8666187E-04,   2.8653463E-04,   2.8636176E-04
     +,   2.8614141E-04,   2.8587246E-04,   2.8555427E-04
     +,   2.8518701E-04,   2.8477106E-04,   2.8430799E-04
     +,   2.8379943E-04,   2.8324741E-04,   2.8265503E-04
     +,   2.8202514E-04,   2.8136154E-04,   2.8066803E-04
     +,   2.7994905E-04,   2.7920911E-04,   2.7845299E-04
     +,   2.7768602E-04,   2.7691340E-04,   2.7614066E-04
     +,   2.7537390E-04,   2.7461853E-04,   2.7388104E-04
     +,   2.7316756E-04,   2.7248458E-04,   2.7183886E-04
     +,   2.7123725E-04,   2.7068672E-04,   2.7019499E-04
     +,   2.6976934E-04,   2.6941803E-04,   2.6914952E-04
     +,   2.6897254E-04,   2.6889646E-04,   2.6893124E-04
     +,   2.6908726E-04,   2.6937574E-04,   2.6980831E-04
     +,   2.7039761E-04,   2.7115687E-04,   2.7210006E-04
     +,   2.7324224E-04,   2.7459886E-04,   2.7618668E-04
     +,   2.7802310E-04,   2.8012658E-04,   2.8251641E-04
     +,   2.8521277E-04,   2.8823750E-04,   2.9161325E-04
     +,   2.9536471E-04,   2.9951759E-04,   3.0410066E-04
     +,   3.0914511E-04,   3.1468479E-04,   3.2075820E-04
     +,   3.2740831E-04,   3.3468334E-04,   3.4263785E-04
     +,   3.5133422E-04,   3.6084317E-04,   3.7124398E-04
     +,   3.8262553E-04,   3.9508703E-04,   4.0873795E-04
     +,   4.2369575E-04,   4.4008563E-04,   4.5803867E-04
     +,   4.7768836E-04,   4.9916486E-04,   5.2259269E-04
     +,   5.4808526E-04,   5.7573634E-04,   6.0561602E-04
     +,   6.3777005E-04,   6.7221338E-04,   7.0892938E-04
     +,   7.4787508E-04,   7.8899047E-04,   8.3220814E-04
     +,   8.7746809E-04,   9.2473748E-04,   9.7403862E-04
     +,   1.0254675E-03,   1.0792101E-03,   1.1355681E-03
     +,   1.1949649E-03,   1.2579361E-03,   1.3251237E-03
     +,   1.3972543E-03,   1.4751039E-03,   1.5594604E-03
     +,   1.6510998E-03,   1.7507824E-03,   1.8592590E-03
     +,   1.9773054E-03,   2.1057944E-03,   2.2457684E-03
     +,   2.3984895E-03,   2.5654139E-03,   2.7481327E-03
     +,   2.9481596E-03,   3.1666327E-03,   3.4039933E-03
     +,   3.6597338E-03,   3.9322679E-03,   4.2191031E-03
     +,   4.5173285E-03,   4.8244470E-03,   5.1393057E-03
     +,   5.4630162E-03,   5.7997070E-03,   6.1567742E-03
     +,   6.5443800E-03,   6.9740992E-03,   7.4567869E-03
     +,   7.9999520E-03,   8.6053507E-03,   9.2678629E-03
     +,   9.9762119E-03,   1.0715080E-02,   1.1467867E-02
     +,   1.2219040E-02,   1.2955231E-02,   1.3665776E-02
     +,   1.4343204E-02,   1.4984114E-02,   1.5589031E-02
     +,   1.6160017E-02,   1.6696073E-02,   1.7188493E-02
     +,   1.7618855E-02,   1.7962316E-02,   1.8194836E-02
     +,   1.8301187E-02,   1.8278094E-02,   1.8131107E-02
     +,   1.7866312E-02,   1.7482294E-02,   1.6968060E-02
     +,   1.6309137E-02,   1.5498558E-02,   1.4546887E-02
     +,   1.3485360E-02,   1.2361132E-02,   1.1226475E-02
     +,   1.0128049E-02,   9.0996856E-03,   8.1603108E-03
     +,   7.3160371E-03,   6.5642837E-03,   5.8978102E-03
     +,   5.3072837E-03,   4.7826441E-03,   4.3137036E-03
     +,   3.8905947E-03,   3.5042446E-03,   3.1470652E-03
     +,   2.8135697E-03,   2.5006593E-03,   2.2073654E-03
     +,   1.9343286E-03,   1.6830487E-03,   1.4551237E-03
     +,   1.2516573E-03,   1.0729469E-03,   9.1840274E-04
     +,   7.8661845E-04,   6.7556818E-04,   5.8285723E-04
     +,   5.0595449E-04,   4.4236236E-04,   3.8976953E-04
     +,   3.4611762E-04,   3.0965314E-04,   2.7891932E-04
     +,   2.5274602E-04,   2.3020833E-04,   2.1059369E-04
     +,   1.9335518E-04,   1.7807995E-04,   1.6445284E-04
     +,   1.5223224E-04,   1.4123099E-04,   1.3129831E-04
     +,   1.2231211E-04,   1.1416862E-04,   1.0677957E-04
     +,   1.0006672E-04,   9.3961164E-05,   8.8400149E-05
     +,   8.3327657E-05,   7.8691963E-05,   7.4446674E-05
     +,   7.0548907E-05,   6.6960238E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_hatt100 = Yx/0.162953488372093
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0794307E-04,   2.1554162E-04
     +,   2.2333073E-04,   2.3130934E-04,   2.3947579E-04
     +,   2.4782735E-04,   2.5636089E-04,   2.6507239E-04
     +,   2.7395677E-04,   2.8300870E-04,   2.9222170E-04
     +,   3.0158830E-04,   3.1110059E-04,   3.2074968E-04
     +,   3.3052612E-04,   3.4041965E-04,   3.5041990E-04
     +,   3.6051532E-04,   3.7069459E-04,   3.8094583E-04
     +,   3.9125734E-04,   4.0161700E-04,   4.1201315E-04
     +,   4.2243479E-04,   4.3287050E-04,   4.4331048E-04
     +,   4.5374481E-04,   4.6416520E-04,   4.7456409E-04
     +,   4.8493507E-04,   4.9527286E-04,   5.0557376E-04
     +,   5.1583495E-04,   5.2605593E-04,   5.3623674E-04
     +,   5.4637861E-04,   5.5648433E-04,   5.6655781E-04
     +,   5.7660404E-04,   5.8662775E-04,   5.9663528E-04
     +,   6.0663291E-04,   6.1662641E-04,   6.2662165E-04
     +,   6.3662347E-04,   6.4663606E-04,   6.5666228E-04
     +,   6.6670310E-04,   6.7675783E-04,   6.8682333E-04
     +,   6.9689500E-04,   7.0696441E-04,   7.1702135E-04
     +,   7.2705204E-04,   7.3704129E-04,   7.4696948E-04
     +,   7.5681601E-04,   7.6655677E-04,   7.7616563E-04
     +,   7.8561530E-04,   7.9487567E-04,   8.0391852E-04
     +,   8.1271044E-04,   8.2122238E-04,   8.2942354E-04
     +,   8.3728530E-04,   8.4477977E-04,   8.5188163E-04
     +,   8.5856934E-04,   8.6482184E-04,   8.7062531E-04
     +,   8.7596686E-04,   8.8083994E-04,   8.8524231E-04
     +,   8.8917528E-04,   8.9264620E-04,   8.9566666E-04
     +,   8.9825259E-04,   9.0042455E-04,   9.0220699E-04
     +,   9.0362801E-04,   9.0471836E-04,   9.0551202E-04
     +,   9.0604380E-04,   9.0635044E-04,   9.0646872E-04
     +,   9.0643531E-04,   9.0628647E-04,   9.0605498E-04
     +,   9.0577302E-04,   9.0546918E-04,   9.0516749E-04
     +,   9.0489030E-04,   9.0465241E-04,   9.0446603E-04
     +,   9.0433715E-04,   9.0426672E-04,   9.0425083E-04
     +,   9.0427959E-04,   9.0433896E-04,   9.0440945E-04
     +,   9.0446702E-04,   9.0448413E-04,   9.0442871E-04
     +,   9.0426719E-04,   9.0396137E-04,   9.0347492E-04
     +,   9.0276642E-04,   9.0179592E-04,   9.0052374E-04
     +,   8.9891098E-04,   8.9691998E-04,   8.9451595E-04
     +,   8.9166529E-04,   8.8833907E-04,   8.8451122E-04
     +,   8.8015996E-04,   8.7526761E-04,   8.6982118E-04
     +,   8.6381234E-04,   8.5723761E-04,   8.5009856E-04
     +,   8.4240199E-04,   8.3415868E-04,   8.2538417E-04
     +,   8.1609917E-04,   8.0632785E-04,   7.9609948E-04
     +,   7.8544446E-04,   7.7439996E-04,   7.6300348E-04
     +,   7.5129641E-04,   7.3932129E-04,   7.2712312E-04
     +,   7.1474846E-04,   7.0224371E-04,   6.8965787E-04
     +,   6.7703851E-04,   6.6443346E-04,   6.5188989E-04
     +,   6.3945499E-04,   6.2717515E-04,   6.1509421E-04
     +,   6.0325436E-04,   5.9169828E-04,   5.8046490E-04
     +,   5.6959107E-04,   5.5911322E-04,   5.4906448E-04
     +,   5.3947628E-04,   5.3037720E-04,   5.2179495E-04
     +,   5.1375589E-04,   5.0628255E-04,   4.9939775E-04
     +,   4.9312203E-04,   4.8747618E-04,   4.8247815E-04
     +,   4.7814741E-04,   4.7450190E-04,   4.7156084E-04
     +,   4.6934295E-04,   4.6786788E-04,   4.6715746E-04
     +,   4.6723327E-04,   4.6812012E-04,   4.6984290E-04
     +,   4.7243002E-04,   4.7591105E-04,   4.8031766E-04
     +,   4.8568333E-04,   4.9204309E-04,   4.9943366E-04
     +,   5.0789322E-04,   5.1745994E-04,   5.2817288E-04
     +,   5.4007093E-04,   5.5319216E-04,   5.6757295E-04
     +,   5.8324978E-04,   6.0025684E-04,   6.1862561E-04
     +,   6.3838548E-04,   6.5956509E-04,   6.8219152E-04
     +,   7.0628960E-04,   7.3188148E-04,   7.5899332E-04
     +,   7.8764971E-04,   8.1787648E-04,   8.4970292E-04
     +,   8.8316406E-04,   9.1829762E-04,   9.5514557E-04
     +,   9.9376263E-04,   1.0342097E-03,   1.0765562E-03
     +,   1.1208786E-03,   1.1672698E-03,   1.2158310E-03
     +,   1.2666724E-03,   1.3199139E-03,   1.3756870E-03
     +,   1.4341325E-03,   1.4953936E-03,   1.5596185E-03
     +,   1.6269617E-03,   1.6975694E-03,   1.7715744E-03
     +,   1.8491093E-03,   1.9302827E-03,   2.0151695E-03
     +,   2.1038093E-03,   2.1962011E-03,   2.2922854E-03
     +,   2.3919402E-03,   2.4949592E-03,   2.6010661E-03
     +,   2.7098937E-03,   2.8209793E-03,   2.9337902E-03
     +,   3.0477312E-03,   3.1621712E-03,   3.2764992E-03
     +,   3.3902137E-03,   3.5030020E-03,   3.6148550E-03
     +,   3.7261883E-03,   3.8379715E-03,   3.9518015E-03
     +,   4.0699327E-03,   4.1952506E-03,   4.3311468E-03
     +,   4.4812639E-03,   4.6492033E-03,   4.8381016E-03
     +,   5.0502475E-03,   5.2866582E-03,   5.5467971E-03
     +,   5.8285031E-03,   6.1280834E-03,   6.4406306E-03
     +,   6.7606894E-03,   7.0830020E-03,   7.4033453E-03
     +,   7.7192155E-03,   8.0304379E-03,   8.3393808E-03
     +,   8.6508365E-03,   8.9715384E-03,   9.3095889E-03
     +,   9.6735433E-03,   1.0071486E-02,   1.0510085E-02
     +,   1.0993617E-02,   1.1522935E-02,   1.2094373E-02
     +,   1.2698790E-02,   1.3320887E-02,   1.3939036E-02
     +,   1.4525493E-02,   1.5048067E-02,   1.5472337E-02
     +,   1.5764574E-02,   1.5895130E-02,   1.5841646E-02
     +,   1.5591543E-02,   1.5143576E-02,   1.4508072E-02
     +,   1.3705867E-02,   1.2766314E-02,   1.1724644E-02
     +,   1.0618906E-02,   9.4869407E-03,   8.3639221E-03
     +,   7.2804485E-03,   6.2610274E-03,   5.3236727E-03
     +,   4.4796886E-03,   3.7344182E-03,   3.0878840E-03
     +,   2.5360945E-03,   2.0720204E-03,   1.6868514E-03
     +,   1.3708246E-03,   1.1140991E-03,   9.0722315E-04
     +,   7.4155058E-04,   6.0944085E-04,   5.0429918E-04
     +,   4.2060105E-04,   3.5378928E-04,   3.0019679E-04
     +,   2.5690946E-04,   2.2166054E-04,   1.9270406E-04
     +,   1.6871779E-04,   1.4870259E-04,   1.3190926E-04
     +,   1.1776853E-04,   1.0584368E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_hatt102 = Yx/0.164181818181818
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_hatt103(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0794307E-04,   2.1554162E-04
     +,   2.2333073E-04,   2.3130934E-04,   2.3947579E-04
     +,   2.4782735E-04,   2.5636089E-04,   2.6507239E-04
     +,   2.7395677E-04,   2.8300870E-04,   2.9222170E-04
     +,   3.0158830E-04,   3.1110059E-04,   3.2074968E-04
     +,   3.3052612E-04,   3.4041965E-04,   3.5041990E-04
     +,   3.6051532E-04,   3.7069459E-04,   3.8094583E-04
     +,   3.9125734E-04,   4.0161700E-04,   4.1201315E-04
     +,   4.2243479E-04,   4.3287050E-04,   4.4331048E-04
     +,   4.5374481E-04,   4.6416520E-04,   4.7456409E-04
     +,   4.8493507E-04,   4.9527286E-04,   5.0557376E-04
     +,   5.1583495E-04,   5.2605593E-04,   5.3623674E-04
     +,   5.4637861E-04,   5.5648433E-04,   5.6655781E-04
     +,   5.7660404E-04,   5.8662775E-04,   5.9663528E-04
     +,   6.0663291E-04,   6.1662641E-04,   6.2662165E-04
     +,   6.3662347E-04,   6.4663606E-04,   6.5666228E-04
     +,   6.6670310E-04,   6.7675783E-04,   6.8682333E-04
     +,   6.9689500E-04,   7.0696441E-04,   7.1702135E-04
     +,   7.2705204E-04,   7.3704129E-04,   7.4696948E-04
     +,   7.5681601E-04,   7.6655677E-04,   7.7616563E-04
     +,   7.8561530E-04,   7.9487567E-04,   8.0391852E-04
     +,   8.1271044E-04,   8.2122238E-04,   8.2942354E-04
     +,   8.3728530E-04,   8.4477977E-04,   8.5188163E-04
     +,   8.5856934E-04,   8.6482184E-04,   8.7062531E-04
     +,   8.7596686E-04,   8.8083994E-04,   8.8524231E-04
     +,   8.8917528E-04,   8.9264620E-04,   8.9566666E-04
     +,   8.9825259E-04,   9.0042455E-04,   9.0220699E-04
     +,   9.0362801E-04,   9.0471836E-04,   9.0551202E-04
     +,   9.0604380E-04,   9.0635044E-04,   9.0646872E-04
     +,   9.0643531E-04,   9.0628647E-04,   9.0605498E-04
     +,   9.0577302E-04,   9.0546918E-04,   9.0516749E-04
     +,   9.0489030E-04,   9.0465241E-04,   9.0446603E-04
     +,   9.0433715E-04,   9.0426672E-04,   9.0425083E-04
     +,   9.0427959E-04,   9.0433896E-04,   9.0440945E-04
     +,   9.0446702E-04,   9.0448413E-04,   9.0442871E-04
     +,   9.0426719E-04,   9.0396137E-04,   9.0347492E-04
     +,   9.0276642E-04,   9.0179592E-04,   9.0052374E-04
     +,   8.9891098E-04,   8.9691998E-04,   8.9451595E-04
     +,   8.9166529E-04,   8.8833907E-04,   8.8451122E-04
     +,   8.8015996E-04,   8.7526761E-04,   8.6982118E-04
     +,   8.6381234E-04,   8.5723761E-04,   8.5009856E-04
     +,   8.4240199E-04,   8.3415868E-04,   8.2538417E-04
     +,   8.1609917E-04,   8.0632785E-04,   7.9609948E-04
     +,   7.8544446E-04,   7.7439996E-04,   7.6300348E-04
     +,   7.5129641E-04,   7.3932129E-04,   7.2712312E-04
     +,   7.1474846E-04,   7.0224371E-04,   6.8965787E-04
     +,   6.7703851E-04,   6.6443346E-04,   6.5188989E-04
     +,   6.3945499E-04,   6.2717515E-04,   6.1509421E-04
     +,   6.0325436E-04,   5.9169828E-04,   5.8046490E-04
     +,   5.6959107E-04,   5.5911322E-04,   5.4906448E-04
     +,   5.3947628E-04,   5.3037720E-04,   5.2179495E-04
     +,   5.1375589E-04,   5.0628255E-04,   4.9939775E-04
     +,   4.9312203E-04,   4.8747618E-04,   4.8247815E-04
     +,   4.7814741E-04,   4.7450190E-04,   4.7156084E-04
     +,   4.6934295E-04,   4.6786788E-04,   4.6715746E-04
     +,   4.6723327E-04,   4.6812012E-04,   4.6984290E-04
     +,   4.7243002E-04,   4.7591105E-04,   4.8031766E-04
     +,   4.8568333E-04,   4.9204309E-04,   4.9943366E-04
     +,   5.0789322E-04,   5.1745994E-04,   5.2817288E-04
     +,   5.4007093E-04,   5.5319216E-04,   5.6757295E-04
     +,   5.8324978E-04,   6.0025684E-04,   6.1862561E-04
     +,   6.3838548E-04,   6.5956509E-04,   6.8219152E-04
     +,   7.0628960E-04,   7.3188148E-04,   7.5899332E-04
     +,   7.8764971E-04,   8.1787648E-04,   8.4970292E-04
     +,   8.8316406E-04,   9.1829762E-04,   9.5514557E-04
     +,   9.9376263E-04,   1.0342097E-03,   1.0765562E-03
     +,   1.1208786E-03,   1.1672698E-03,   1.2158310E-03
     +,   1.2666724E-03,   1.3199139E-03,   1.3756870E-03
     +,   1.4341325E-03,   1.4953936E-03,   1.5596185E-03
     +,   1.6269617E-03,   1.6975694E-03,   1.7715744E-03
     +,   1.8491093E-03,   1.9302827E-03,   2.0151695E-03
     +,   2.1038093E-03,   2.1962011E-03,   2.2922854E-03
     +,   2.3919402E-03,   2.4949592E-03,   2.6010661E-03
     +,   2.7098937E-03,   2.8209793E-03,   2.9337902E-03
     +,   3.0477312E-03,   3.1621712E-03,   3.2764992E-03
     +,   3.3902137E-03,   3.5030020E-03,   3.6148550E-03
     +,   3.7261883E-03,   3.8379715E-03,   3.9518015E-03
     +,   4.0699327E-03,   4.1952506E-03,   4.3311468E-03
     +,   4.4812639E-03,   4.6492033E-03,   4.8381016E-03
     +,   5.0502475E-03,   5.2866582E-03,   5.5467971E-03
     +,   5.8285031E-03,   6.1280834E-03,   6.4406306E-03
     +,   6.7606894E-03,   7.0830020E-03,   7.4033453E-03
     +,   7.7192155E-03,   8.0304379E-03,   8.3393808E-03
     +,   8.6508365E-03,   8.9715384E-03,   9.3095889E-03
     +,   9.6735433E-03,   1.0071486E-02,   1.0510085E-02
     +,   1.0993617E-02,   1.1522935E-02,   1.2094373E-02
     +,   1.2698790E-02,   1.3320887E-02,   1.3939036E-02
     +,   1.4525493E-02,   1.5048067E-02,   1.5472337E-02
     +,   1.5764574E-02,   1.5895130E-02,   1.5841646E-02
     +,   1.5591543E-02,   1.5143576E-02,   1.4508072E-02
     +,   1.3705867E-02,   1.2766314E-02,   1.1724644E-02
     +,   1.0618906E-02,   9.4869407E-03,   8.3639221E-03
     +,   7.2804485E-03,   6.2610274E-03,   5.3236727E-03
     +,   4.4796886E-03,   3.7344182E-03,   3.0878840E-03
     +,   2.5360945E-03,   2.0720204E-03,   1.6868514E-03
     +,   1.3708246E-03,   1.1140991E-03,   9.0722315E-04
     +,   7.4155058E-04,   6.0944085E-04,   5.0429918E-04
     +,   4.2060105E-04,   3.5378928E-04,   3.0019679E-04
     +,   2.5690946E-04,   2.2166054E-04,   1.9270406E-04
     +,   1.6871779E-04,   1.4870259E-04,   1.3190926E-04
     +,   1.1776853E-04,   1.0584368E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_hatt103 = Yx/0.164181818181818
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3513299E-04,   2.5040610E-04
     +,   2.6636940E-04,   2.8301249E-04,   3.0031908E-04
     +,   3.1826668E-04,   3.3682687E-04,   3.5596523E-04
     +,   3.7564055E-04,   3.9580761E-04,   4.1641522E-04
     +,   4.3740807E-04,   4.5872753E-04,   4.8031303E-04
     +,   5.0210266E-04,   5.2403507E-04,   5.4605049E-04
     +,   5.6809327E-04,   5.9011270E-04,   6.1206485E-04
     +,   6.3391461E-04,   6.5563724E-04,   6.7721965E-04
     +,   6.9866364E-04,   7.1998453E-04,   7.4121589E-04
     +,   7.6240796E-04,   7.8363123E-04,   8.0497586E-04
     +,   8.2655321E-04,   8.4849389E-04,   8.7095215E-04
     +,   8.9409976E-04,   9.1812533E-04,   9.4323151E-04
     +,   9.6963131E-04,   9.9753763E-04,   1.0271564E-03
     +,   1.0586797E-03,   1.0922693E-03,   1.1280469E-03
     +,   1.1660825E-03,   1.2063793E-03,   1.2488679E-03
     +,   1.2933993E-03,   1.3397420E-03,   1.3875887E-03
     +,   1.4365668E-03,   1.4862573E-03,   1.5362216E-03
     +,   1.5860314E-03,   1.6353012E-03,   1.6837311E-03
     +,   1.7311354E-03,   1.7774681E-03,   1.8228475E-03
     +,   1.8675618E-03,   1.9120561E-03,   1.9569169E-03
     +,   2.0028322E-03,   2.0505460E-03,   2.1008004E-03
     +,   2.1542767E-03,   2.2115514E-03,   2.2730436E-03
     +,   2.3389785E-03,   2.4093860E-03,   2.4840995E-03
     +,   2.5627834E-03,   2.6449671E-03,   2.7301062E-03
     +,   2.8176138E-03,   2.9069202E-03,   2.9974892E-03
     +,   3.0888428E-03,   3.1805418E-03,   3.2721465E-03
     +,   3.3631804E-03,   3.4530731E-03,   3.5411231E-03
     +,   3.6264537E-03,   3.7080282E-03,   3.7846637E-03
     +,   3.8551087E-03,   3.9181369E-03,   3.9726212E-03
     +,   4.0176562E-03,   4.0526446E-03,   4.0773130E-03
     +,   4.0917420E-03,   4.0963041E-03,   4.0916009E-03
     +,   4.0783421E-03,   4.0572407E-03,   4.0288991E-03
     +,   3.9937319E-03,   3.9519467E-03,   3.9035303E-03
     +,   3.8483017E-03,   3.7860044E-03,   3.7164043E-03
     +,   3.6393907E-03,   3.5550592E-03,   3.4638029E-03
     +,   3.3663113E-03,   3.2635715E-03,   3.1568320E-03
     +,   3.0475261E-03,   2.9371551E-03,   2.8272178E-03
     +,   2.7190959E-03,   2.6139668E-03,   2.5127635E-03
     +,   2.4161132E-03,   2.3243518E-03,   2.2375372E-03
     +,   2.1554974E-03,   2.0778726E-03,   2.0042020E-03
     +,   1.9339664E-03,   1.8666543E-03,   1.8018131E-03
     +,   1.7390704E-03,   1.6781535E-03,   1.6188874E-03
     +,   1.5611920E-03,   1.5050562E-03,   1.4505201E-03
     +,   1.3976445E-03,   1.3465002E-03,   1.2971360E-03
     +,   1.2495809E-03,   1.2038244E-03,   1.1598304E-03
     +,   1.1175268E-03,   1.0768208E-03,   1.0376088E-03
     +,   9.9978666E-04,   9.6325099E-04,   9.2791620E-04
     +,   8.9372107E-04,   8.6062658E-04,   8.2862185E-04
     +,   7.9771911E-04,   7.6795946E-04,   7.3939841E-04
     +,   7.1210618E-04,   6.8616564E-04,   6.6165969E-04
     +,   6.3866976E-04,   6.1726850E-04,   5.9751997E-04
     +,   5.7947234E-04,   5.6315667E-04,   5.4858573E-04
     +,   5.3575262E-04,   5.2463356E-04,   5.1518384E-04
     +,   5.0734251E-04,   5.0103327E-04,   4.9616606E-04
     +,   4.9263932E-04,   4.9034186E-04,   4.8915669E-04
     +,   4.8896094E-04,   4.8963027E-04,   4.9104035E-04
     +,   4.9306831E-04,   4.9559493E-04,   4.9850770E-04
     +,   5.0170004E-04,   5.0507399E-04,   5.0854188E-04
     +,   5.1202608E-04,   5.1545928E-04,   5.1878672E-04
     +,   5.2196474E-04,   5.2496162E-04,   5.2775745E-04
     +,   5.3034240E-04,   5.3271826E-04,   5.3489575E-04
     +,   5.3689466E-04,   5.3874229E-04,   5.4047344E-04
     +,   5.4212700E-04,   5.4374727E-04,   5.4538000E-04
     +,   5.4707384E-04,   5.4887682E-04,   5.5083598E-04
     +,   5.5299688E-04,   5.5540097E-04,   5.5808516E-04
     +,   5.6108180E-04,   5.6441763E-04,   5.6811137E-04
     +,   5.7217578E-04,   5.7661562E-04,   5.8142812E-04
     +,   5.8660324E-04,   5.9212267E-04,   5.9796142E-04
     +,   6.0408685E-04,   6.1046059E-04,   6.1703811E-04
     +,   6.2376959E-04,   6.3060143E-04,   6.3747540E-04
     +,   6.4433174E-04,   6.5110845E-04,   6.5774302E-04
     +,   6.6417304E-04,   6.7033665E-04,   6.7617482E-04
     +,   6.8163109E-04,   6.8665162E-04,   6.9118803E-04
     +,   6.9519621E-04,   6.9863745E-04,   7.0147862E-04
     +,   7.0369290E-04,   7.0525956E-04,   7.0616411E-04
     +,   7.0639839E-04,   7.0596015E-04,   7.0485374E-04
     +,   7.0308801E-04,   7.0067792E-04,   6.9764233E-04
     +,   6.9400441E-04,   6.8979122E-04,   6.8503228E-04
     +,   6.7975884E-04,   6.7400531E-04,   6.6780479E-04
     +,   6.6119264E-04,   6.5420283E-04,   6.4686954E-04
     +,   6.3922419E-04,   6.3129730E-04,   6.2311796E-04
     +,   6.1471225E-04,   6.0610374E-04,   5.9731310E-04
     +,   5.8835925E-04,   5.7925831E-04,   5.7002320E-04
     +,   5.6066457E-04,   5.5119209E-04,   5.4161216E-04
     +,   5.3192972E-04,   5.2214909E-04,   5.1227381E-04
     +,   5.0230551E-04,   4.9224560E-04,   4.8209689E-04
     +,   4.7186122E-04,   4.6154085E-04,   4.5113868E-04
     +,   4.4065906E-04,   4.3010723E-04,   4.1948934E-04
     +,   4.0881216E-04,   3.9808510E-04,   3.8731776E-04
     +,   3.7652047E-04,   3.6570622E-04,   3.5488792E-04
     +,   3.4407972E-04,   3.3329590E-04,   3.2255214E-04
     +,   3.1186480E-04,   3.0124938E-04,   2.9072198E-04
     +,   2.8029940E-04,   2.6999679E-04,   2.5983041E-04
     +,   2.4981465E-04,   2.3996440E-04,   2.3029263E-04
     +,   2.2081271E-04,   2.1153557E-04,   2.0247276E-04
     +,   1.9363308E-04,   1.8502562E-04,   1.7665744E-04
     +,   1.6853446E-04,   1.6066218E-04,   1.5304406E-04
     +,   1.4568323E-04,   1.3858102E-04,   1.3173859E-04
     +,   1.2515514E-04,   1.1882994E-04,   1.1276047E-04
     +,   1.0694433E-04,   1.0137760E-04,   9.6056356E-05
     +,   9.0975489E-05,   8.6130014E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_hatt75 = Yx/0.0838205128205128
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.8600718E-05,   9.2657589E-05
     +,   9.6876618E-05,   1.0126738E-04,   1.0584019E-04
     +,   1.1060620E-04,   1.1557734E-04,   1.2076624E-04
     +,   1.2618618E-04,   1.3185121E-04,   1.3777582E-04
     +,   1.4397490E-04,   1.5046397E-04,   1.5725860E-04
     +,   1.6437487E-04,   1.7182902E-04,   1.7963740E-04
     +,   1.8781684E-04,   1.9638424E-04,   2.0535718E-04
     +,   2.1475366E-04,   2.2459263E-04,   2.3489409E-04
     +,   2.4568004E-04,   2.5697323E-04,   2.6880007E-04
     +,   2.8118881E-04,   2.9417127E-04,   3.0778267E-04
     +,   3.2206194E-04,   3.3705204E-04,   3.5280004E-04
     +,   3.6935616E-04,   3.8677381E-04,   4.0510835E-04
     +,   4.2441604E-04,   4.4475214E-04,   4.6616883E-04
     +,   4.8871402E-04,   5.1242643E-04,   5.3733605E-04
     +,   5.6345947E-04,   5.9079833E-04,   6.1933720E-04
     +,   6.4904382E-04,   6.7986693E-04,   7.1173906E-04
     +,   7.4457750E-04,   7.7828905E-04,   8.1277284E-04
     +,   8.4792788E-04,   8.8365865E-04,   9.1988104E-04
     +,   9.5653284E-04,   9.9357381E-04,   1.0309982E-03
     +,   1.0688324E-03,   1.1071410E-03,   1.1460263E-03
     +,   1.1856265E-03,   1.2261135E-03,   1.2676864E-03
     +,   1.3105635E-03,   1.3549771E-03,   1.4011628E-03
     +,   1.4493384E-03,   1.4997027E-03,   1.5524054E-03
     +,   1.6075427E-03,   1.6651277E-03,   1.7250903E-03
     +,   1.7872567E-03,   1.8513672E-03,   1.9170775E-03
     +,   1.9840118E-03,   2.0518140E-03,   2.1202224E-03
     +,   2.1891680E-03,   2.2588850E-03,   2.3299973E-03
     +,   2.4035834E-03,   2.4812149E-03,   2.5648919E-03
     +,   2.6569383E-03,   2.7597779E-03,   2.8756813E-03
     +,   3.0064234E-03,   3.1530138E-03,   3.3154052E-03
     +,   3.4923956E-03,   3.6816141E-03,   3.8797029E-03
     +,   4.0826434E-03,   4.2862338E-03,   4.4865385E-03
     +,   4.6803141E-03,   4.8653446E-03,   5.0404887E-03
     +,   5.2055884E-03,   5.3610802E-03,   5.5075851E-03
     +,   5.6454008E-03,   5.7741352E-03,   5.8925943E-03
     +,   5.9988508E-03,   6.0906638E-03,   6.1659450E-03
     +,   6.2233415E-03,   6.2626475E-03,   6.2849266E-03
     +,   6.2923348E-03,   6.2875766E-03,   6.2731802E-03
     +,   6.2506646E-03,   6.2199049E-03,   6.1788140E-03
     +,   6.1234827E-03,   6.0488195E-03,   5.9495056E-03
     +,   5.8211251E-03,   5.6611747E-03,   5.4697203E-03
     +,   5.2495440E-03,   5.0057680E-03,   4.7450839E-03
     +,   4.4747940E-03,   4.2018429E-03,   3.9321436E-03
     +,   3.6701537E-03,   3.4188994E-03,   3.1801267E-03
     +,   2.9547266E-03,   2.7430232E-03,   2.5451190E-03
     +,   2.3609968E-03,   2.1905974E-03,   2.0337759E-03
     +,   1.8902526E-03,   1.7595525E-03,   1.6410036E-03
     +,   1.5337795E-03,   1.4369489E-03,   1.3495357E-03
     +,   1.2705961E-03,   1.1992698E-03,   1.1347916E-03
     +,   1.0765096E-03,   1.0238759E-03,   9.7643107E-04
     +,   9.3378022E-04,   8.9557841E-04,   8.6151931E-04
     +,   8.3132385E-04,   8.0473034E-04,   7.8149239E-04
     +,   7.6137838E-04,   7.4416556E-04,   7.2963873E-04
     +,   7.1758748E-04,   7.0780551E-04,   7.0008758E-04
     +,   6.9422612E-04,   6.9001323E-04,   6.8723818E-04
     +,   6.8568939E-04,   6.8515463E-04,   6.8542449E-04
     +,   6.8629318E-04,   6.8756257E-04,   6.8904524E-04
     +,   6.9056696E-04,   6.9196912E-04,   6.9311133E-04
     +,   6.9387385E-04,   6.9415738E-04,   6.9388532E-04
     +,   6.9300242E-04,   6.9147407E-04,   6.8928802E-04
     +,   6.8644888E-04,   6.8297976E-04,   6.7891844E-04
     +,   6.7431590E-04,   6.6923309E-04,   6.6373963E-04
     +,   6.5791100E-04,   6.5182673E-04,   6.4556743E-04
     +,   6.3921232E-04,   6.3284056E-04,   6.2652543E-04
     +,   6.2033616E-04,   6.1433506E-04,   6.0857809E-04
     +,   6.0311210E-04,   5.9797644E-04,   5.9320172E-04
     +,   5.8880990E-04,   5.8481365E-04,   5.8121822E-04
     +,   5.7802029E-04,   5.7520979E-04,   5.7276944E-04
     +,   5.7067472E-04,   5.6889746E-04,   5.6740351E-04
     +,   5.6615501E-04,   5.6511123E-04,   5.6422886E-04
     +,   5.6346325E-04,   5.6276866E-04,   5.6209986E-04
     +,   5.6141178E-04,   5.6066096E-04,   5.5980589E-04
     +,   5.5880717E-04,   5.5762922E-04,   5.5623916E-04
     +,   5.5460789E-04,   5.5271055E-04,   5.5052689E-04
     +,   5.4804009E-04,   5.4523844E-04,   5.4211449E-04
     +,   5.3866475E-04,   5.3488970E-04,   5.3079461E-04
     +,   5.2638719E-04,   5.2167912E-04,   5.1668409E-04
     +,   5.1141903E-04,   5.0590292E-04,   5.0015474E-04
     +,   4.9419637E-04,   4.8804932E-04,   4.8173574E-04
     +,   4.7527661E-04,   4.6869315E-04,   4.6200596E-04
     +,   4.5523327E-04,   4.4839241E-04,   4.4149926E-04
     +,   4.3456795E-04,   4.2761004E-04,   4.2063533E-04
     +,   4.1365225E-04,   4.0666765E-04,   3.9968535E-04
     +,   3.9270832E-04,   3.8573868E-04,   3.7877643E-04
     +,   3.7182058E-04,   3.6486986E-04,   3.5792220E-04
     +,   3.5097514E-04,   3.4402564E-04,   3.3707119E-04
     +,   3.3010961E-04,   3.2313858E-04,   3.1615607E-04
     +,   3.0916161E-04,   3.0215501E-04,   2.9513615E-04
     +,   2.8810650E-04,   2.8106838E-04,   2.7402432E-04
     +,   2.6697785E-04,   2.5993341E-04,   2.5289634E-04
     +,   2.4587207E-04,   2.3886652E-04,   2.3188653E-04
     +,   2.2493939E-04,   2.1803204E-04,   2.1117169E-04
     +,   2.0436640E-04,   1.9762327E-04,   1.9095023E-04
     +,   1.8435418E-04,   1.7784281E-04,   1.7142255E-04
     +,   1.6510047E-04,   1.5888239E-04,   1.5277465E-04
     +,   1.4678226E-04,   1.4091072E-04,   1.3516440E-04
     +,   1.2954728E-04,   1.2406333E-04,   1.1871545E-04
     +,   1.1350681E-04,   1.0843925E-04,   1.0351501E-04
     +,   9.8735218E-05,   9.4101131E-05,   8.9613124E-05
     +,   8.5271640E-05,   8.1076287E-05,   7.7026816E-05
     +,   7.3122159E-05,   6.9361427E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_hatt80 = Yx/0.0959
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8114769E-05,   3.9671868E-05
     +,   4.1278545E-05,   4.2934447E-05,   4.4639146E-05
     +,   4.6392091E-05,   4.8192680E-05,   5.0040268E-05
     +,   5.1934152E-05,   5.3873777E-05,   5.5858585E-05
     +,   5.7888181E-05,   5.9962393E-05,   6.2081366E-05
     +,   6.4245578E-05,   6.6456065E-05,   6.8714413E-05
     +,   7.1022929E-05,   7.3384806E-05,   7.5804237E-05
     +,   7.8286525E-05,   8.0838297E-05,   8.3467632E-05
     +,   8.6184358E-05,   8.8999826E-05,   9.1927643E-05
     +,   9.4983341E-05,   9.8184741E-05,   1.0155201E-04
     +,   1.0510784E-04,   1.0887743E-04,   1.1288852E-04
     +,   1.1717158E-04,   1.2175956E-04,   1.2668784E-04
     +,   1.3199425E-04,   1.3771864E-04,   1.4390267E-04
     +,   1.5058983E-04,   1.5782409E-04,   1.6565049E-04
     +,   1.7411372E-04,   1.8325770E-04,   1.9312465E-04
     +,   2.0375448E-04,   2.1518338E-04,   2.2744326E-04
     +,   2.4056005E-04,   2.5455328E-04,   2.6943441E-04
     +,   2.8520625E-04,   3.0186173E-04,   3.1938354E-04
     +,   3.3774436E-04,   3.5690461E-04,   3.7681643E-04
     +,   3.9742145E-04,   4.1865418E-04,   4.4044381E-04
     +,   4.6271685E-04,   4.8540140E-04,   5.0843117E-04
     +,   5.3174834E-04,   5.5531226E-04,   5.7910354E-04
     +,   6.0312491E-04,   6.2741345E-04,   6.5203756E-04
     +,   6.7710632E-04,   7.0276548E-04,   7.2920241E-04
     +,   7.5664179E-04,   7.8534440E-04,   8.1559928E-04
     +,   8.4772165E-04,   8.8204368E-04,   9.1890397E-04
     +,   9.5864007E-04,   1.0015813E-03,   1.0480379E-03
     +,   1.0982850E-03,   1.1525601E-03,   1.2110398E-03
     +,   1.2738366E-03,   1.3409653E-03,   1.4123451E-03
     +,   1.4877656E-03,   1.5668921E-03,   1.6492417E-03
     +,   1.7342165E-03,   1.8211200E-03,   1.9092077E-03
     +,   1.9977679E-03,   2.0862359E-03,   2.1743071E-03
     +,   2.2620664E-03,   2.3501301E-03,   2.4397215E-03
     +,   2.5327306E-03,   2.6316473E-03,   2.7394297E-03
     +,   2.8592204E-03,   2.9939886E-03,   3.1460852E-03
     +,   3.3168208E-03,   3.5061319E-03,   3.7124066E-03
     +,   3.9326120E-03,   4.1627036E-03,   4.3982752E-03
     +,   4.6353196E-03,   4.8710504E-03,   5.1043560E-03
     +,   5.3360388E-03,   5.5683427E-03,   5.8042319E-03
     +,   6.0461224E-03,   6.2947567E-03,   6.5481551E-03
     +,   6.8013361E-03,   7.0467573E-03,   7.2755422E-03
     +,   7.4794441E-03,   7.6528238E-03,   7.7943150E-03
     +,   7.9073934E-03,   7.9998933E-03,   8.0822092E-03
     +,   8.1648277E-03,   8.2557844E-03,   8.3586313E-03
     +,   8.4714498E-03,   8.5870977E-03,   8.6942632E-03
     +,   8.7792017E-03,   8.8275475E-03,   8.8259904E-03
     +,   8.7637156E-03,   8.6335111E-03,   8.4325634E-03
     +,   8.1629148E-03,   7.8315465E-03,   7.4497517E-03
     +,   7.0320871E-03,   6.5948684E-03,   6.1543211E-03
     +,   5.7249824E-03,   5.3184666E-03,   4.9427012E-03
     +,   4.6017696E-03,   4.2963461E-03,   4.0244283E-03
     +,   3.7822260E-03,   3.5650416E-03,   3.3680100E-03
     +,   3.1866936E-03,   3.0173738E-03,   2.8571901E-03
     +,   2.7041652E-03,   2.5571161E-03,   2.4154847E-03
     +,   2.2791864E-03,   2.1484543E-03,   2.0236671E-03
     +,   1.9052243E-03,   1.7934426E-03,   1.6884995E-03
     +,   1.5903914E-03,   1.4989310E-03,   1.4137744E-03
     +,   1.3344744E-03,   1.2605217E-03,   1.1913872E-03
     +,   1.1265817E-03,   1.0656823E-03,   1.0083491E-03
     +,   9.5433142E-04,   9.0347487E-04,   8.5570046E-04
     +,   8.1098836E-04,   7.6936558E-04,   7.3088706E-04
     +,   6.9561973E-04,   6.6362805E-04,   6.3496793E-04
     +,   6.0968078E-04,   5.8778701E-04,   5.6928612E-04
     +,   5.5415550E-04,   5.4235425E-04,   5.3381990E-04
     +,   5.2847370E-04,   5.2622193E-04,   5.2695675E-04
     +,   5.3055672E-04,   5.3689134E-04,   5.4581714E-04
     +,   5.5718317E-04,   5.7082728E-04,   5.8657915E-04
     +,   6.0425745E-04,   6.2366942E-04,   6.4461381E-04
     +,   6.6687708E-04,   6.9023436E-04,   7.1445020E-04
     +,   7.3927979E-04,   7.6446717E-04,   7.8975019E-04
     +,   8.1486034E-04,   8.3952869E-04,   8.6348347E-04
     +,   8.8645704E-04,   9.0818939E-04,   9.2843291E-04
     +,   9.4695174E-04,   9.6352992E-04,   9.7797462E-04
     +,   9.9011709E-04,   9.9981762E-04,   1.0069670E-03
     +,   1.0114888E-03,   1.0133400E-03,   1.0125122E-03
     +,   1.0090310E-03,   1.0029547E-03,   9.9437346E-04
     +,   9.8340912E-04,   9.7020651E-04,   9.5493754E-04
     +,   9.3779096E-04,   9.1897626E-04,   8.9871034E-04
     +,   8.7721919E-04,   8.5473480E-04,   8.3148613E-04
     +,   8.0769759E-04,   7.8358798E-04,   7.5936451E-04
     +,   7.3521864E-04,   7.1132625E-04,   6.8784616E-04
     +,   6.6491764E-04,   6.4265815E-04,   6.2116474E-04
     +,   6.0051552E-04,   5.8076793E-04,   5.6195940E-04
     +,   5.4410932E-04,   5.2722276E-04,   5.1128794E-04
     +,   4.9628061E-04,   4.8216654E-04,   4.6890246E-04
     +,   4.5643697E-04,   4.4471337E-04,   4.3367292E-04
     +,   4.2325375E-04,   4.1339375E-04,   4.0403105E-04
     +,   3.9510647E-04,   3.8656348E-04,   3.7834805E-04
     +,   3.7041053E-04,   3.6270614E-04,   3.5519357E-04
     +,   3.4783676E-04,   3.4060419E-04,   3.3346910E-04
     +,   3.2640839E-04,   3.1940328E-04,   3.1243890E-04
     +,   3.0550431E-04,   2.9859101E-04,   2.9169337E-04
     +,   2.8480904E-04,   2.7793687E-04,   2.7107846E-04
     +,   2.6423630E-04,   2.5741506E-04,   2.5061946E-04
     +,   2.4385618E-04,   2.3713137E-04,   2.3045296E-04
     +,   2.2382790E-04,   2.1726447E-04,   2.1077011E-04
     +,   2.0435246E-04,   1.9801939E-04,   1.9177790E-04
     +,   1.8563530E-04,   1.7959774E-04,   1.7367193E-04
     +,   1.6786321E-04,   1.6217714E-04,   1.5661809E-04
     +,   1.5119057E-04,   1.4589794E-04,   1.4074358E-04
     +,   1.3572973E-04,   1.3085864E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_hatt85 = Yx/0.120024390243902
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1658181E-04,   1.2069270E-04
     +,   1.2481298E-04,   1.2893323E-04,   1.3304372E-04
     +,   1.3713450E-04,   1.4119546E-04,   1.4521620E-04
     +,   1.4918628E-04,   1.5309533E-04,   1.5693292E-04
     +,   1.6068858E-04,   1.6435210E-04,   1.6791344E-04
     +,   1.7136283E-04,   1.7469078E-04,   1.7788824E-04
     +,   1.8094658E-04,   1.8385764E-04,   1.8661388E-04
     +,   1.8920831E-04,   1.9163471E-04,   1.9388745E-04
     +,   1.9596187E-04,   1.9785386E-04,   1.9956048E-04
     +,   2.0107938E-04,   2.0240949E-04,   2.0355040E-04
     +,   2.0450298E-04,   2.0526897E-04,   2.0585132E-04
     +,   2.0625407E-04,   2.0648236E-04,   2.0654255E-04
     +,   2.0644216E-04,   2.0618997E-04,   2.0579601E-04
     +,   2.0527151E-04,   2.0462909E-04,   2.0388258E-04
     +,   2.0304706E-04,   2.0213910E-04,   2.0117644E-04
     +,   2.0017804E-04,   1.9916428E-04,   1.9815669E-04
     +,   1.9717788E-04,   1.9625173E-04,   1.9540291E-04
     +,   1.9465730E-04,   1.9404119E-04,   1.9358177E-04
     +,   1.9330642E-04,   1.9324286E-04,   1.9341870E-04
     +,   1.9386130E-04,   1.9459712E-04,   1.9565200E-04
     +,   1.9705028E-04,   1.9881446E-04,   2.0096521E-04
     +,   2.0352037E-04,   2.0649495E-04,   2.0990091E-04
     +,   2.1374601E-04,   2.1803427E-04,   2.2276505E-04
     +,   2.2793365E-04,   2.3352980E-04,   2.3953909E-04
     +,   2.4594157E-04,   2.5271354E-04,   2.5982573E-04
     +,   2.6724566E-04,   2.7493783E-04,   2.8286304E-04
     +,   2.9098077E-04,   2.9925001E-04,   3.0763066E-04
     +,   3.1608317E-04,   3.2457264E-04,   3.3306796E-04
     +,   3.4154471E-04,   3.4998573E-04,   3.5838384E-04
     +,   3.6674115E-04,   3.7507224E-04,   3.8340341E-04
     +,   3.9177414E-04,   4.0023759E-04,   4.0885858E-04
     +,   4.1771497E-04,   4.2689615E-04,   4.3650178E-04
     +,   4.4663856E-04,   4.5742057E-04,   4.6896448E-04
     +,   4.8138938E-04,   4.9481209E-04,   5.0934707E-04
     +,   5.2510196E-04,   5.4217980E-04,   5.6067307E-04
     +,   5.8066880E-04,   6.0224964E-04,   6.2549266E-04
     +,   6.5047579E-04,   6.7728513E-04,   7.0602074E-04
     +,   7.3680037E-04,   7.6977519E-04,   8.0512901E-04
     +,   8.4309833E-04,   8.8396447E-04,   9.2807849E-04
     +,   9.7585079E-04,   1.0277737E-03,   1.0844137E-03
     +,   1.1464285E-03,   1.2145697E-03,   1.2896722E-03
     +,   1.3726448E-03,   1.4644447E-03,   1.5660122E-03
     +,   1.6781683E-03,   1.8015233E-03,   1.9362899E-03
     +,   2.0821753E-03,   2.2382094E-03,   2.4027224E-03
     +,   2.5733314E-03,   2.7471401E-03,   2.9210222E-03
     +,   3.0921085E-03,   3.2583454E-03,   3.4191406E-03
     +,   3.5760002E-03,   3.7330606E-03,   3.8973538E-03
     +,   4.0786960E-03,   4.2890431E-03,   4.5412215E-03
     +,   4.8469785E-03,   5.2145552E-03,   5.6462628E-03
     +,   6.1366139E-03,   6.6718115E-03,   7.2312858E-03
     +,   7.7912589E-03,   8.3296001E-03,   8.8303750E-03
     +,   9.2864446E-03,   9.6987803E-03,   1.0072242E-02
     +,   1.0409556E-02,   1.0705840E-02,   1.0946154E-02
     +,   1.1107229E-02,   1.1162972E-02,   1.1092060E-02
     +,   1.0884756E-02,   1.0547060E-02,   1.0100767E-02
     +,   9.5797274E-03,   9.0235127E-03,   8.4702736E-03
     +,   7.9508927E-03,   7.4852942E-03,   7.0818807E-03
     +,   6.7392113E-03,   6.4490694E-03,   6.1998940E-03
     +,   5.9797377E-03,   5.7782307E-03,   5.5875145E-03
     +,   5.4023620E-03,   5.2196700E-03,   5.0377520E-03
     +,   4.8556132E-03,   4.6725087E-03,   4.4878079E-03
     +,   4.3010758E-03,   4.1123163E-03,   3.9221840E-03
     +,   3.7320973E-03,   3.5441401E-03,   3.3608088E-03
     +,   3.1847165E-03,   3.0182728E-03,   2.8634022E-03
     +,   2.7213627E-03,   2.5926929E-03,   2.4772182E-03
     +,   2.3741410E-03,   2.2821962E-03,   2.1998354E-03
     +,   2.1253910E-03,   2.0572294E-03,   1.9938953E-03
     +,   1.9341942E-03,   1.8772377E-03,   1.8224468E-03
     +,   1.7695348E-03,   1.7184550E-03,   1.6693242E-03
     +,   1.6223558E-03,   1.5777923E-03,   1.5358450E-03
     +,   1.4966453E-03,   1.4602237E-03,   1.4265012E-03
     +,   1.3952926E-03,   1.3663258E-03,   1.3392613E-03
     +,   1.3137285E-03,   1.2893423E-03,   1.2657311E-03
     +,   1.2425567E-03,   1.2195260E-03,   1.1964013E-03
     +,   1.1730019E-03,   1.1492105E-03,   1.1249643E-03
     +,   1.1002540E-03,   1.0751149E-03,   1.0496223E-03
     +,   1.0238857E-03,   9.9803298E-04,   9.7221165E-04
     +,   9.4657560E-04,   9.2128245E-04,   8.9648366E-04
     +,   8.7232166E-04,   8.4892794E-04,   8.2641526E-04
     +,   8.0487877E-04,   7.8439544E-04,   7.6502195E-04
     +,   7.4679352E-04,   7.2972773E-04,   7.1382342E-04
     +,   6.9906312E-04,   6.8541226E-04,   6.7282142E-04
     +,   6.6122931E-04,   6.5056240E-04,   6.4073672E-04
     +,   6.3165877E-04,   6.2323007E-04,   6.1534491E-04
     +,   6.0789473E-04,   6.0076901E-04,   5.9385737E-04
     +,   5.8705150E-04,   5.8024598E-04,   5.7334115E-04
     +,   5.6624535E-04,   5.5887364E-04,   5.5115134E-04
     +,   5.4301479E-04,   5.3441164E-04,   5.2530057E-04
     +,   5.1565265E-04,   5.0545187E-04,   4.9469271E-04
     +,   4.8338127E-04,   4.7153456E-04,   4.5917949E-04
     +,   4.4635069E-04,   4.3309043E-04,   4.1944842E-04
     +,   4.0547911E-04,   3.9124023E-04,   3.7679190E-04
     +,   3.6219740E-04,   3.4751839E-04,   3.3281776E-04
     +,   3.1815481E-04,   3.0358849E-04,   2.8917287E-04
     +,   2.7495992E-04,   2.6099582E-04,   2.4732415E-04
     +,   2.3398199E-04,   2.2100347E-04,   2.0841650E-04
     +,   1.9624447E-04,   1.8450721E-04,   1.7321878E-04
     +,   1.6239050E-04,   1.5202849E-04,   1.4213672E-04
     +,   1.3271451E-04,   1.2375988E-04,   1.1526686E-04
     +,   1.0722853E-04,   9.9634955E-05,   9.2475646E-05
     +,   8.5737898E-05,   7.9408695E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_hatt90 = Yx/0.1245
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.7649260E-05,   8.2773025E-05
     +,   8.8115266E-05,   9.3669740E-05,   9.9428333E-05
     +,   1.0538087E-04,   1.1151502E-04,   1.1781655E-04
     +,   1.2426886E-04,   1.3085362E-04,   1.3755009E-04
     +,   1.4433570E-04,   1.5118594E-04,   1.5807456E-04
     +,   1.6497367E-04,   1.7185390E-04,   1.7868474E-04
     +,   1.8543469E-04,   1.9207140E-04,   1.9856216E-04
     +,   2.0487413E-04,   2.1097442E-04,   2.1683075E-04
     +,   2.2241200E-04,   2.2768727E-04,   2.3262804E-04
     +,   2.3720702E-04,   2.4139907E-04,   2.4518152E-04
     +,   2.4853420E-04,   2.5143978E-04,   2.5388398E-04
     +,   2.5585591E-04,   2.5734762E-04,   2.5835511E-04
     +,   2.5887761E-04,   2.5891783E-04,   2.5848221E-04
     +,   2.5758031E-04,   2.5622520E-04,   2.5443331E-04
     +,   2.5222366E-04,   2.4961843E-04,   2.4664210E-04
     +,   2.4332167E-04,   2.3968601E-04,   2.3576574E-04
     +,   2.3159284E-04,   2.2720036E-04,   2.2262227E-04
     +,   2.1789286E-04,   2.1304643E-04,   2.0811745E-04
     +,   2.0313938E-04,   1.9814576E-04,   1.9316837E-04
     +,   1.8823825E-04,   1.8338498E-04,   1.7863660E-04
     +,   1.7401937E-04,   1.6955780E-04,   1.6527442E-04
     +,   1.6119011E-04,   1.5732346E-04,   1.5369101E-04
     +,   1.5030779E-04,   1.4718638E-04,   1.4433802E-04
     +,   1.4177167E-04,   1.3949501E-04,   1.3751404E-04
     +,   1.3583322E-04,   1.3445574E-04,   1.3338368E-04
     +,   1.3261799E-04,   1.3215866E-04,   1.3200501E-04
     +,   1.3215560E-04,   1.3260850E-04,   1.3336123E-04
     +,   1.3441104E-04,   1.3575498E-04,   1.3738972E-04
     +,   1.3931193E-04,   1.4151800E-04,   1.4400444E-04
     +,   1.4676730E-04,   1.4980290E-04,   1.5310694E-04
     +,   1.5667517E-04,   1.6050304E-04,   1.6458536E-04
     +,   1.6891635E-04,   1.7348988E-04,   1.7829906E-04
     +,   1.8333558E-04,   1.8859081E-04,   1.9405414E-04
     +,   1.9971468E-04,   2.0555926E-04,   2.1157396E-04
     +,   2.1774287E-04,   2.2404913E-04,   2.3047383E-04
     +,   2.3699708E-04,   2.4359816E-04,   2.5025476E-04
     +,   2.5694384E-04,   2.6364237E-04,   2.7032761E-04
     +,   2.7697635E-04,   2.8356788E-04,   2.9008175E-04
     +,   2.9650127E-04,   3.0281194E-04,   3.0900419E-04
     +,   3.1507210E-04,   3.2101647E-04,   3.2684376E-04
     +,   3.3256816E-04,   3.3821200E-04,   3.4380588E-04
     +,   3.4939020E-04,   3.5501464E-04,   3.6074020E-04
     +,   3.6663731E-04,   3.7278791E-04,   3.7928359E-04
     +,   3.8622628E-04,   3.9372692E-04,   4.0190539E-04
     +,   4.1088733E-04,   4.2080414E-04,   4.3178894E-04
     +,   4.4397474E-04,   4.5749117E-04,   4.7245857E-04
     +,   4.8898440E-04,   5.0715887E-04,   5.2704912E-04
     +,   5.4869236E-04,   5.7209068E-04,   5.9720938E-04
     +,   6.2397117E-04,   6.5225147E-04,   6.8188360E-04
     +,   7.1265892E-04,   7.4432936E-04,   7.7661796E-04
     +,   8.0923282E-04,   8.4188068E-04,   8.7428227E-04
     +,   9.0619561E-04,   9.3744299E-04,   9.6793467E-04
     +,   9.9769316E-04,   1.0268814E-03,   1.0558293E-03
     +,   1.0850513E-03,   1.1152521E-03,   1.1473323E-03
     +,   1.1823624E-03,   1.2215390E-03,   1.2661181E-03
     +,   1.3173242E-03,   1.3762383E-03,   1.4436721E-03
     +,   1.5200566E-03,   1.6053711E-03,   1.6991044E-03
     +,   1.8002827E-03,   1.9075876E-03,   2.0195264E-03
     +,   2.1346663E-03,   2.2518728E-03,   2.3706283E-03
     +,   2.4913207E-03,   2.6155652E-03,   2.7465397E-03
     +,   2.8893233E-03,   3.0511383E-03,   3.2414242E-03
     +,   3.4716248E-03,   3.7545792E-03,   4.1033640E-03
     +,   4.5296126E-03,   5.0415294E-03,   5.6419889E-03
     +,   6.3271546E-03,   7.0860824E-03,   7.9018408E-03
     +,   8.7535530E-03,   9.6186353E-03,   1.0474577E-02
     +,   1.1299025E-02,   1.2068391E-02,   1.2756068E-02
     +,   1.3332826E-02,   1.3771052E-02,   1.4052483E-02
     +,   1.4176674E-02,   1.4164853E-02,   1.4055749E-02
     +,   1.3894022E-02,   1.3716197E-02,   1.3540558E-02
     +,   1.3364384E-02,   1.3168734E-02,   1.2927126E-02
     +,   1.2614727E-02,   1.2215520E-02,   1.1725912E-02
     +,   1.1154795E-02,   1.0520472E-02,   9.8460875E-03
     +,   9.1553545E-03,   8.4695192E-03,   7.8060613E-03
     +,   7.1784090E-03,   6.5959054E-03,   6.0635526E-03
     +,   5.5821026E-03,   5.1485794E-03,   4.7573731E-03
     +,   4.4017024E-03,   4.0751244E-03,   3.7725212E-03
     +,   3.4905083E-03,   3.2273375E-03,   2.9825070E-03
     +,   2.7562475E-03,   2.5490026E-03,   2.3610357E-03
     +,   2.1921955E-03,   2.0418316E-03,   1.9087673E-03
     +,   1.7914147E-03,   1.6879211E-03,   1.5963027E-03
     +,   1.5145791E-03,   1.4408886E-03,   1.3735717E-03
     +,   1.3112151E-03,   1.2526709E-03,   1.1970589E-03
     +,   1.1437535E-03,   1.0923488E-03,   1.0426152E-03
     +,   9.9445961E-04,   9.4788632E-04,   9.0294983E-04
     +,   8.5972610E-04,   8.1828999E-04,   7.7869633E-04
     +,   7.4096723E-04,   7.0509175E-04,   6.7102921E-04
     +,   6.3871167E-04,   6.0804834E-04,   5.7893462E-04
     +,   5.5126054E-04,   5.2491645E-04,   4.9979449E-04
     +,   4.7579530E-04,   4.5283226E-04,   4.3082907E-04
     +,   4.0972061E-04,   3.8945521E-04,   3.6999120E-04
     +,   3.5129423E-04,   3.3333720E-04,   3.1609941E-04
     +,   2.9956392E-04,   2.8371508E-04,   2.6853819E-04
     +,   2.5402076E-04,   2.4014781E-04,   2.2690554E-04
     +,   2.1427737E-04,   2.0224726E-04,   1.9079667E-04
     +,   1.7990747E-04,   1.6955950E-04,   1.5973333E-04
     +,   1.5040778E-04,   1.4156288E-04,   1.3317763E-04
     +,   1.2523141E-04,   1.1770461E-04,   1.1057714E-04
     +,   1.0383042E-04,   9.7445554E-05,   9.1405302E-05
     +,   8.5692242E-05,   8.0290520E-05,   7.5184325E-05
     +,   7.0359238E-05,   6.5800981E-05,   6.1496576E-05
     +,   5.7433143E-05,   5.3599040E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_hatt95 = Yx/0.133
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6913178E-06,   2.8401134E-06
     +,   2.9936152E-06,   3.1517286E-06,   3.3143426E-06
     +,   3.4813340E-06,   3.6525594E-06,   3.8278645E-06
     +,   4.0070795E-06,   4.1900307E-06,   4.3765240E-06
     +,   4.5663642E-06,   4.7593467E-06,   4.9552632E-06
     +,   5.1539078E-06,   5.3550721E-06,   5.5585569E-06
     +,   5.7641687E-06,   5.9717304E-06,   6.1810774E-06
     +,   6.3920706E-06,   6.6045950E-06,   6.8185655E-06
     +,   7.0339465E-06,   7.2507241E-06,   7.4689560E-06
     +,   7.6887436E-06,   7.9102583E-06,   8.1337412E-06
     +,   8.3595187E-06,   8.5880010E-06,   8.8197021E-06
     +,   9.0552458E-06,   9.2953715E-06,   9.5409559E-06
     +,   9.7930160E-06,   1.0052725E-05,   1.0321415E-05
     +,   1.0600623E-05,   1.0892042E-05,   1.1197602E-05
     +,   1.1519430E-05,   1.1859888E-05,   1.2221572E-05
     +,   1.2607325E-05,   1.3020236E-05,   1.3463654E-05
     +,   1.3941172E-05,   1.4456642E-05,   1.5014148E-05
     +,   1.5618001E-05,   1.6272723E-05,   1.6983000E-05
     +,   1.7753706E-05,   1.8589746E-05,   1.9496161E-05
     +,   2.0477941E-05,   2.1540021E-05,   2.2687205E-05
     +,   2.3924074E-05,   2.5254909E-05,   2.6683598E-05
     +,   2.8213482E-05,   2.9847388E-05,   3.1587482E-05
     +,   3.3434979E-05,   3.5390425E-05,   3.7453163E-05
     +,   3.9621737E-05,   4.1893290E-05,   4.4264085E-05
     +,   4.6728885E-05,   4.9281520E-05,   5.1914263E-05
     +,   5.4618416E-05,   5.7384193E-05,   6.0200466E-05
     +,   6.3055173E-05,   6.5935521E-05,   6.8828056E-05
     +,   7.1718481E-05,   7.4592448E-05,   7.7435136E-05
     +,   8.0232130E-05,   8.2968916E-05,   8.5631909E-05
     +,   8.8207853E-05,   9.0684895E-05,   9.3051982E-05
     +,   9.5299794E-05,   9.7420612E-05,   9.9408404E-05
     +,   1.0125911E-04,   1.0297096E-04,   1.0454440E-04
     +,   1.0598206E-04,   1.0728921E-04,   1.0847337E-04
     +,   1.0954479E-04,   1.1051595E-04,   1.1140203E-04
     +,   1.1222051E-04,   1.1299143E-04,   1.1373699E-04
     +,   1.1448187E-04,   1.1525287E-04,   1.1607909E-04
     +,   1.1699155E-04,   1.1802356E-04,   1.1921026E-04
     +,   1.2058871E-04,   1.2219792E-04,   1.2407835E-04
     +,   1.2627227E-04,   1.2882295E-04,   1.3177498E-04
     +,   1.3517324E-04,   1.3906304E-04,   1.4348877E-04
     +,   1.4849396E-04,   1.5412012E-04,   1.6040528E-04
     +,   1.6738339E-04,   1.7508367E-04,   1.8352932E-04
     +,   1.9273585E-04,   2.0271221E-04,   2.1345849E-04
     +,   2.2496852E-04,   2.3722828E-04,   2.5022033E-04
     +,   2.6392326E-04,   2.7831912E-04,   2.9339362E-04
     +,   3.0914537E-04,   3.2559098E-04,   3.4277042E-04
     +,   3.6075563E-04,   3.7965798E-04,   3.9963285E-04
     +,   4.2088202E-04,   4.4365542E-04,   4.6824917E-04
     +,   4.9499603E-04,   5.2424963E-04,   5.5637071E-04
     +,   5.9170224E-04,   6.3054019E-04,   6.7311147E-04
     +,   7.1955560E-04,   7.6991151E-04,   8.2411716E-04
     +,   8.8203489E-04,   9.4350340E-04,   1.0084076E-03
     +,   1.0767721E-03,   1.1488788E-03,   1.2253878E-03
     +,   1.3074150E-03,   1.3965454E-03,   1.4947614E-03
     +,   1.6042286E-03,   1.7269750E-03,   1.8646092E-03
     +,   2.0182298E-03,   2.1887920E-03,   2.3780768E-03
     +,   2.5902374E-03,   2.8334241E-03,   3.1206259E-03
     +,   3.4688686E-03,   3.8965319E-03,   4.4192714E-03
     +,   5.0458438E-03,   5.7756994E-03,   6.6007832E-03
     +,   7.5122765E-03,   8.5091814E-03,   9.6022738E-03
     +,   1.0818806E-02,   1.2233939E-02,   1.4025906E-02
     +,   1.6465900E-02,   1.9784383E-02,   2.4084857E-02
     +,   2.9467732E-02,   3.5915721E-02,   4.3063980E-02
     +,   5.1570542E-02,   6.2529869E-02,   7.3421732E-02
     +,   8.1946835E-02,   9.0050824E-02,   9.8928966E-02
     +,   0.1024276    ,   9.8764606E-02,   9.5878370E-02
     +,   9.2537433E-02,   8.6608022E-02,   7.6518431E-02
     +,   6.4902499E-02,   5.5773117E-02,   4.9446676E-02
     +,   4.4210959E-02,   3.8739420E-02,   3.3290852E-02
     +,   2.8458834E-02,   2.4364069E-02,   2.1138569E-02
     +,   1.8910067E-02,   1.7408948E-02,   1.6134469E-02
     +,   1.4782822E-02,   1.3327127E-02,   1.1835339E-02
     +,   1.0367011E-02,   8.9859348E-03,   7.7603408E-03
     +,   6.7262407E-03,   5.8682254E-03,   5.1385923E-03
     +,   4.4894945E-03,   3.8914531E-03,   3.3340068E-03
     +,   2.8179395E-03,   2.3478202E-03,   1.9278225E-03
     +,   1.5601078E-03,   1.2444876E-03,   9.7866671E-04
     +,   7.5872679E-04,   5.7972374E-04,   4.3629057E-04
     +,   3.2312557E-04,   2.3528082E-04,   1.6826599E-04
     +,   1.1809573E-04,   8.1289007E-05,   5.4854601E-05
     +,   3.6280177E-05,   2.3514989E-05,   1.4935658E-05
     +,   9.2960991E-06,   5.6695021E-06,   3.3877404E-06
     +,   1.9830964E-06,   1.1370512E-06,   6.3844988E-07
     +,   3.5098824E-07,   1.8889730E-07,   9.9514082E-08
     +,   5.1320875E-08,   2.5919393E-08,   1.2831681E-08
     +,   6.2387127E-09,   2.9902101E-09,   1.4232051E-09
     +,   6.8162642E-10,   3.3585071E-10,   1.7570211E-10
     +,   1.0089767E-10,   6.4734447E-11,   4.5962876E-11
     +,   3.5114019E-11,   2.8032549E-11,   2.2901724E-11
     +,   1.8913860E-11,   1.5690102E-11,   1.3033319E-11
     +,   1.0825165E-11,   8.9841693E-12,   7.4484030E-12
     +,   6.1679446E-12,   5.1013516E-12,   4.2139083E-12
     +,   3.4765064E-12,   2.8645179E-12,   2.3573027E-12
     +,   1.9374448E-12,   1.5903697E-12,   1.3038174E-12
     +,   1.0675550E-12,   8.7299823E-13,   7.1300252E-13
     +,   5.8159196E-13,   4.7380567E-13,   3.8550790E-13
     +,   3.1326835E-13,   2.5424598E-13,   2.0608247E-13
     +,   1.6683309E-13,   1.3488752E-13,   1.0892218E-13
     +,   8.7843415E-14,   7.0754980E-14,   5.6918452E-14
     +,   4.5730292E-14,   3.6694680E-14,   2.9407425E-14
     +,   2.3537423E-14,   1.8815458E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt100 = Yx/0.43022
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.3598416E-06,   8.4830926E-06
     +,   8.5958218E-06,   8.6975651E-06,   8.7879052E-06
     +,   8.8664683E-06,   8.9329242E-06,   8.9870018E-06
     +,   9.0284775E-06,   9.0571821E-06,   9.0730055E-06
     +,   9.0758913E-06,   9.0658423E-06,   9.0429185E-06
     +,   9.0072417E-06,   8.9589848E-06,   8.8983852E-06
     +,   8.8257311E-06,   8.7413664E-06,   8.6456857E-06
     +,   8.5391430E-06,   8.4222356E-06,   8.2955048E-06
     +,   8.1595408E-06,   8.0149812E-06,   7.8624907E-06
     +,   7.7027853E-06,   7.5366065E-06,   7.3647352E-06
     +,   7.1879845E-06,   7.0071933E-06,   6.8232289E-06
     +,   6.6369898E-06,   6.4494016E-06,   6.2614140E-06
     +,   6.0740072E-06,   5.8881860E-06,   5.7049929E-06
     +,   5.5254864E-06,   5.3507815E-06,   5.1820089E-06
     +,   5.0203544E-06,   4.8670436E-06,   4.7233543E-06
     +,   4.5906154E-06,   4.4702188E-06,   4.3636182E-06
     +,   4.2723409E-06,   4.1979879E-06,   4.1422377E-06
     +,   4.1068593E-06,   4.0937048E-06,   4.1047183E-06
     +,   4.1419389E-06,   4.2074957E-06,   4.3036111E-06
     +,   4.4325939E-06,   4.5968382E-06,   4.7988101E-06
     +,   5.0410454E-06,   5.3261274E-06,   5.6566855E-06
     +,   6.0353418E-06,   6.4647452E-06,   6.9475254E-06
     +,   7.4862064E-06,   8.0833015E-06,   8.7411336E-06
     +,   9.4619609E-06,   1.0247770E-05,   1.1100428E-05
     +,   1.2021447E-05,   1.3012164E-05,   1.4073470E-05
     +,   1.5205996E-05,   1.6410009E-05,   1.7685285E-05
     +,   1.9031168E-05,   2.0446647E-05,   2.1930269E-05
     +,   2.3479988E-05,   2.5093519E-05,   2.6767944E-05
     +,   2.8500161E-05,   3.0286488E-05,   3.2123167E-05
     +,   3.4005931E-05,   3.5930596E-05,   3.7892576E-05
     +,   3.9887505E-05,   4.1911040E-05,   4.3958924E-05
     +,   4.6027144E-05,   4.8112237E-05,   5.0211256E-05
     +,   5.2321680E-05,   5.4441996E-05,   5.6571283E-05
     +,   5.8709866E-05,   6.0858809E-05,   6.3020649E-05
     +,   6.5198823E-05,   6.7398323E-05,   6.9625174E-05
     +,   7.1886905E-05,   7.4192430E-05,   7.6551820E-05
     +,   7.8976409E-05,   8.1479018E-05,   8.4073719E-05
     +,   8.6775610E-05,   8.9601344E-05,   9.2568589E-05
     +,   9.5696771E-05,   9.9006487E-05,   1.0252049E-04
     +,   1.0626316E-04,   1.1026164E-04,   1.1454534E-04
     +,   1.1914699E-04,   1.2410285E-04,   1.2945244E-04
     +,   1.3523907E-04,   1.4150979E-04,   1.4831507E-04
     +,   1.5570686E-04,   1.6373897E-04,   1.7246357E-04
     +,   1.8193063E-04,   1.9218323E-04,   2.0325654E-04
     +,   2.1517203E-04,   2.2793689E-04,   2.4153844E-04
     +,   2.5594403E-04,   2.7109974E-04,   2.8692931E-04
     +,   3.0333802E-04,   3.2021879E-04,   3.3745871E-04
     +,   3.5494872E-04,   3.7259611E-04,   3.9034089E-04
     +,   4.0816874E-04,   4.2612251E-04,   4.4431697E-04
     +,   4.6294267E-04,   4.8226243E-04,   5.0260418E-04
     +,   5.2434183E-04,   5.4786698E-04,   5.7355431E-04
     +,   6.0172827E-04,   6.3263322E-04,   6.6641631E-04
     +,   7.0312375E-04,   7.4272451E-04,   7.8515674E-04
     +,   8.3038240E-04,   8.7844121E-04,   9.2949817E-04
     +,   9.8384963E-04,   1.0418710E-03,   1.1039426E-03
     +,   1.1703481E-03,   1.2412139E-03,   1.3165509E-03
     +,   1.3964915E-03,   1.4817419E-03,   1.5742024E-03
     +,   1.6775911E-03,   1.7978427E-03,   1.9430013E-03
     +,   2.1224730E-03,   2.3458344E-03,   2.6217666E-03
     +,   2.9576633E-03,   3.3599804E-03,   3.8343871E-03
     +,   4.3837461E-03,   5.0024772E-03,   5.6695673E-03
     +,   6.3479822E-03,   6.9997073E-03,   7.6171267E-03
     +,   8.2524437E-03,   9.0160174E-03,   1.0040110E-02
     +,   1.1461390E-02,   1.3468196E-02,   1.6301943E-02
     +,   2.0009356E-02,   2.4191387E-02,   2.8495049E-02
     +,   3.3347379E-02,   3.9525807E-02,   4.7382917E-02
     +,   5.6232642E-02,   6.5627977E-02,   7.6365776E-02
     +,   8.5663781E-02,   9.0677224E-02,   9.2542119E-02
     +,   9.5080964E-02,   0.1000396    ,   0.1031583    
     +,   9.9816464E-02,   8.9435823E-02,   7.5236142E-02
     +,   6.2079012E-02,   5.0978463E-02,   4.1647121E-02
     +,   3.4461681E-02,   2.9205246E-02,   2.4721930E-02
     +,   2.0977102E-02,   1.8428747E-02,   1.6681965E-02
     +,   1.5009718E-02,   1.3069542E-02,   1.0926813E-02
     +,   8.8035949E-03,   6.8937205E-03,   5.2959118E-03
     +,   4.0211026E-03,   3.0280487E-03,   2.2587329E-03
     +,   1.6611969E-03,   1.1976369E-03,   8.4225141E-04
     +,   5.7584402E-04,   3.8192249E-04,   2.4533729E-04
     +,   1.5242261E-04,   9.1460293E-05,   5.2930507E-05
     +,   2.9506458E-05,   1.5827782E-05,   8.1635144E-06
     +,   4.0460677E-06,   1.9262684E-06,   8.8073801E-07
     +,   3.8672167E-07,   1.6306991E-07,   6.6043647E-08
     +,   2.5701306E-08,   9.6196047E-09,   3.4703180E-09
     +,   1.2131774E-09,   4.1666878E-10,   1.4537101E-10
     +,   5.5293586E-11,   2.5383437E-11,   1.4830411E-11
     +,   1.0429430E-11,   8.0584489E-12,   6.4582432E-12
     +,   5.2372026E-12,   4.2592184E-12,   3.4635864E-12
     +,   2.8137859E-12,   2.2830206E-12,   1.8498777E-12
     +,   1.4968429E-12,   1.2095145E-12,   9.7598242E-13
     +,   7.8643808E-13,   6.3282046E-13,   5.0849884E-13
     +,   4.0802789E-13,   3.2694640E-13,   2.6160665E-13
     +,   2.0903169E-13,   1.6678644E-13,   1.3288932E-13
     +,   1.0573220E-13,   8.4004716E-14,   6.6647737E-14
     +,   5.2801466E-14,   4.1772514E-14,   3.2999926E-14
     +,   2.6032653E-14,   2.0506935E-14,   1.6131148E-14
     +,   1.2670826E-14,   9.9386247E-15,   7.7844361E-15
     +,   6.0883771E-15,   4.7550765E-15,   3.7084140E-15
     +,   2.8880082E-15,   2.2458615E-15,   1.7440076E-15
     +,   1.3523432E-15,   1.0471413E-15,   8.0965021E-16
     +,   6.2512937E-16,   4.8196376E-16,   3.7105559E-16
     +,   2.8525698E-16,   2.1898503E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt104 = Yx/0.4095
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.5212699E-06,   5.9705699E-06
     +,   6.4433484E-06,   6.9394955E-06,   7.4587565E-06
     +,   8.0007130E-06,   8.5647880E-06,   9.1502316E-06
     +,   9.7561142E-06,   1.0381356E-05,   1.1024670E-05
     +,   1.1684602E-05,   1.2359526E-05,   1.3047650E-05
     +,   1.3747013E-05,   1.4455507E-05,   1.5170883E-05
     +,   1.5890762E-05,   1.6612654E-05,   1.7333974E-05
     +,   1.8052060E-05,   1.8764194E-05,   1.9467614E-05
     +,   2.0159594E-05,   2.0837339E-05,   2.1498170E-05
     +,   2.2139431E-05,   2.2758555E-05,   2.3353092E-05
     +,   2.3920724E-05,   2.4459297E-05,   2.4966830E-05
     +,   2.5441537E-05,   2.5881867E-05,   2.6286480E-05
     +,   2.6654294E-05,   2.6984488E-05,   2.7276494E-05
     +,   2.7530050E-05,   2.7745122E-05,   2.7921989E-05
     +,   2.8061193E-05,   2.8163533E-05,   2.8230081E-05
     +,   2.8262151E-05,   2.8261322E-05,   2.8229344E-05
     +,   2.8168226E-05,   2.8080134E-05,   2.7967400E-05
     +,   2.7832544E-05,   2.7678174E-05,   2.7507022E-05
     +,   2.7321910E-05,   2.7125716E-05,   2.6921374E-05
     +,   2.6711852E-05,   2.6500109E-05,   2.6289112E-05
     +,   2.6081809E-05,   2.5881111E-05,   2.5689878E-05
     +,   2.5510937E-05,   2.5347033E-05,   2.5200850E-05
     +,   2.5075011E-05,   2.4972063E-05,   2.4894485E-05
     +,   2.4844683E-05,   2.4825003E-05,   2.4837718E-05
     +,   2.4885048E-05,   2.4969149E-05,   2.5092138E-05
     +,   2.5256082E-05,   2.5462994E-05,   2.5714849E-05
     +,   2.6013571E-05,   2.6361062E-05,   2.6759168E-05
     +,   2.7209659E-05,   2.7714297E-05,   2.8274691E-05
     +,   2.8892480E-05,   2.9569090E-05,   3.0305919E-05
     +,   3.1104148E-05,   3.1964890E-05,   3.2888955E-05
     +,   3.3877033E-05,   3.4929584E-05,   3.6046717E-05
     +,   3.7228234E-05,   3.8473685E-05,   3.9782281E-05
     +,   4.1152678E-05,   4.2583335E-05,   4.4072072E-05
     +,   4.5616442E-05,   4.7213336E-05,   4.8859361E-05
     +,   5.0550450E-05,   5.2282223E-05,   5.4049640E-05
     +,   5.5847344E-05,   5.7669553E-05,   5.9509934E-05
     +,   6.1361825E-05,   6.3218315E-05,   6.5072243E-05
     +,   6.6916153E-05,   6.8742658E-05,   7.0544178E-05
     +,   7.2313487E-05,   7.4043477E-05,   7.5727643E-05
     +,   7.7359975E-05,   7.8935547E-05,   8.0450438E-05
     +,   8.1902363E-05,   8.3290943E-05,   8.4618092E-05
     +,   8.5888612E-05,   8.7110951E-05,   8.8297907E-05
     +,   8.9467350E-05,   9.0643611E-05,   9.1858390E-05
     +,   9.3152586E-05,   9.4577568E-05,   9.6197538E-05
     +,   9.8091223E-05,   1.0035469E-04,   1.0310334E-04
     +,   1.0647488E-04,   1.1063157E-04,   1.1576173E-04
     +,   1.2208121E-04,   1.2983376E-04,   1.3928924E-04
     +,   1.5073895E-04,   1.6448944E-04,   1.8085339E-04
     +,   2.0013585E-04,   2.2261497E-04,   2.4852541E-04
     +,   2.7803477E-04,   3.1121873E-04,   3.4804057E-04
     +,   3.8833785E-04,   4.3181155E-04,   4.7802608E-04
     +,   5.2642799E-04,   5.7638536E-04,   6.2723615E-04
     +,   6.7835511E-04,   7.2924176E-04,   7.7961304E-04
     +,   8.2948746E-04,   8.7924878E-04,   9.2969043E-04
     +,   9.8199362E-04,   1.0376428E-03,   1.0982823E-03
     +,   1.1655107E-03,   1.2406472E-03,   1.3244991E-03
     +,   1.4172193E-03,   1.5182762E-03,   1.6265812E-03
     +,   1.7407531E-03,   1.8594972E-03,   1.9820028E-03
     +,   2.1081956E-03,   2.2387530E-03,   2.3748546E-03
     +,   2.5176127E-03,   2.6673810E-03,   2.8232662E-03
     +,   2.9831831E-03,   3.1448302E-03,   3.3076890E-03
     +,   3.4758796E-03,   3.6610956E-03,   3.8844056E-03
     +,   4.1751997E-03,   4.5658606E-03,   5.0829151E-03
     +,   5.7400679E-03,   6.5427735E-03,   7.5086411E-03
     +,   8.6867278E-03,   1.0142466E-02,   1.1905317E-02
     +,   1.3940466E-02,   1.6219545E-02,   1.8930295E-02
     +,   2.2641454E-02,   2.7806243E-02,   3.3915117E-02
     +,   4.0246576E-02,   4.7670506E-02,   5.8156971E-02
     +,   7.0705995E-02,   8.2036577E-02,   9.4907880E-02
     +,   0.1027213    ,   0.1006631    ,   0.1032308    
     +,   0.1051279    ,   0.1003138    ,   9.3354076E-02
     +,   8.3575487E-02,   7.2897173E-02,   6.1189272E-02
     +,   4.7858499E-02,   3.6289953E-02,   2.8504554E-02
     +,   2.3318497E-02,   1.9542027E-02,   1.6447822E-02
     +,   1.3601158E-02,   1.0895862E-02,   8.4214527E-03
     +,   6.3071656E-03,   4.6161325E-03,   3.3243792E-03
     +,   2.3629903E-03,   1.6591253E-03,   1.1511794E-03
     +,   7.8969664E-04,   5.3588790E-04,   3.6026165E-04
     +,   2.4085966E-04,   1.6132972E-04,   1.0940370E-04
     +,   7.5974371E-05,   5.4489159E-05,   4.0448864E-05
     +,   3.0929645E-05,   2.4136818E-05,   1.9026244E-05
     +,   1.5016330E-05,   1.1789809E-05,   9.1695356E-06
     +,   7.0468095E-06,   5.3437116E-06,   3.9957331E-06
     +,   2.9452872E-06,   2.1400358E-06,   1.5328444E-06
     +,   1.0824339E-06,   7.5368609E-07,   5.1751709E-07
     +,   3.5046654E-07,   2.3409397E-07,   1.5423809E-07
     +,   1.0024845E-07,   6.4276627E-08,   4.0654950E-08
     +,   2.5366365E-08,   1.5612768E-08,   9.4787609E-09
     +,   5.6759677E-09,   3.3522074E-09,   1.9524731E-09
     +,   1.1214096E-09,   6.3510502E-10,   3.5466022E-10
     +,   1.9527108E-10,   1.0600055E-10,   5.6733871E-11
     +,   2.9942906E-11,   1.5586386E-11,   8.0049292E-12
     +,   4.0592894E-12,   2.0347957E-12,   1.0103290E-12
     +,   4.9855589E-13,   2.4585244E-13,   1.2219946E-13
     +,   6.2004702E-14,   3.2654414E-14,   1.8172482E-14
     +,   1.0830788E-14,   6.9344195E-15,   4.7290315E-15
     +,   3.3831457E-15,   2.4993638E-15,   1.8829566E-15
     +,   1.4342796E-15,   1.0987072E-15,   8.4378320E-16
     +,   6.4849234E-16,   4.9829688E-16,   3.8259928E-16
     +,   2.9346682E-16,   2.2483312E-16,   1.7203635E-16
     +,   1.3146587E-16,   1.0033060E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt106 = Yx/0.398857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5361452E-06,   1.6514089E-06
     +,   1.7730773E-06,   1.9013139E-06,   2.0362718E-06
     +,   2.1780907E-06,   2.3268988E-06,   2.4828089E-06
     +,   2.6459149E-06,   2.8163049E-06,   2.9940377E-06
     +,   3.1791628E-06,   3.3717051E-06,   3.5716728E-06
     +,   3.7790564E-06,   3.9938241E-06,   4.2159263E-06
     +,   4.4452900E-06,   4.6818282E-06,   4.9254304E-06
     +,   5.1759703E-06,   5.4333022E-06,   5.6972599E-06
     +,   5.9676804E-06,   6.2443546E-06,   6.5270915E-06
     +,   6.8156724E-06,   7.1098748E-06,   7.4094692E-06
     +,   7.7142195E-06,   8.0238906E-06,   8.3382483E-06
     +,   8.6570590E-06,   8.9800997E-06,   9.3071567E-06
     +,   9.6380245E-06,   9.9725239E-06,   1.0310486E-05
     +,   1.0651795E-05,   1.0996319E-05,   1.1344011E-05
     +,   1.1694843E-05,   1.2048833E-05,   1.2406063E-05
     +,   1.2766670E-05,   1.3130873E-05,   1.3498965E-05
     +,   1.3871331E-05,   1.4248454E-05,   1.4630941E-05
     +,   1.5019506E-05,   1.5415026E-05,   1.5818505E-05
     +,   1.6231152E-05,   1.6654310E-05,   1.7089567E-05
     +,   1.7538701E-05,   1.8003722E-05,   1.8486877E-05
     +,   1.8990690E-05,   1.9517922E-05,   2.0071639E-05
     +,   2.0655138E-05,   2.1272035E-05,   2.1926237E-05
     +,   2.2621854E-05,   2.3363329E-05,   2.4155242E-05
     +,   2.5002482E-05,   2.5909989E-05,   2.6882964E-05
     +,   2.7926533E-05,   2.9045992E-05,   3.0246436E-05
     +,   3.1532982E-05,   3.2910539E-05,   3.4383665E-05
     +,   3.5956586E-05,   3.7633137E-05,   3.9416733E-05
     +,   4.1309944E-05,   4.3314980E-05,   4.5433026E-05
     +,   4.7664747E-05,   5.0009730E-05,   5.2466938E-05
     +,   5.5034183E-05,   5.7708628E-05,   6.0486273E-05
     +,   6.3362480E-05,   6.6331762E-05,   6.9387701E-05
     +,   7.2523093E-05,   7.5730335E-05,   7.9001235E-05
     +,   8.2326762E-05,   8.5698004E-05,   8.9105277E-05
     +,   9.2539121E-05,   9.5989548E-05,   9.9447025E-05
     +,   1.0290157E-04,   1.0634385E-04,   1.0976430E-04
     +,   1.1315400E-04,   1.1650443E-04,   1.1980720E-04
     +,   1.2305459E-04,   1.2623961E-04,   1.2935603E-04
     +,   1.3239817E-04,   1.3536167E-04,   1.3824298E-04
     +,   1.4104022E-04,   1.4375278E-04,   1.4638211E-04
     +,   1.4893155E-04,   1.5140706E-04,   1.5381712E-04
     +,   1.5617353E-04,   1.5849154E-04,   1.6079002E-04
     +,   1.6309196E-04,   1.6542488E-04,   1.6782076E-04
     +,   1.7031601E-04,   1.7295193E-04,   1.7577384E-04
     +,   1.7883145E-04,   1.8217754E-04,   1.8586818E-04
     +,   1.8996076E-04,   1.9451423E-04,   1.9958653E-04
     +,   2.0523464E-04,   2.1151283E-04,   2.1847099E-04
     +,   2.2615369E-04,   2.3459978E-04,   2.4384110E-04
     +,   2.5390132E-04,   2.6479518E-04,   2.7652981E-04
     +,   2.8910313E-04,   3.0250219E-04,   3.1670564E-04
     +,   3.3168224E-04,   3.4738888E-04,   3.6377148E-04
     +,   3.8076582E-04,   3.9829739E-04,   4.1628128E-04
     +,   4.3462706E-04,   4.5324498E-04,   4.7205394E-04
     +,   4.9099134E-04,   5.1003124E-04,   5.2920490E-04
     +,   5.4862350E-04,   5.6850171E-04,   5.8918790E-04
     +,   6.1118492E-04,   6.3516537E-04,   6.6197780E-04
     +,   6.9263554E-04,   7.2828459E-04,   7.7014731E-04
     +,   8.1945403E-04,   8.7737065E-04,   9.4493362E-04
     +,   1.0230226E-03,   1.1124063E-03,   1.2138836E-03
     +,   1.3284965E-03,   1.4577722E-03,   1.6039311E-03
     +,   1.7698515E-03,   1.9586647E-03,   2.1729453E-03
     +,   2.4136028E-03,   2.6787759E-03,   2.9632801E-03
     +,   3.2591529E-03,   3.5575419E-03,   3.8516121E-03
     +,   4.1396585E-03,   4.4270512E-03,   4.7256006E-03
     +,   5.0498294E-03,   5.4119895E-03,   5.8200266E-03
     +,   6.2820073E-03,   6.8163308E-03,   7.4609709E-03
     +,   8.2745450E-03,   9.3314275E-03,   1.0720496E-02
     +,   1.2538932E-02,   1.4833128E-02,   1.7490370E-02
     +,   2.0294443E-02,   2.3327101E-02,   2.7151108E-02
     +,   3.2065812E-02,   3.7769966E-02,   4.4765562E-02
     +,   5.4236103E-02,   6.6864438E-02,   8.0794588E-02
     +,   9.2761293E-02,   0.1044848    ,   0.1141363    
     +,   0.1123172    ,   0.1005280    ,   9.4964646E-02
     +,   9.0852901E-02,   7.9279594E-02,   6.4690948E-02
     +,   5.2452400E-02,   4.3140355E-02,   3.5627399E-02
     +,   2.9091083E-02,   2.2845857E-02,   1.6783105E-02
     +,   1.1510050E-02,   7.4978233E-03,   4.7156927E-03
     +,   2.8742272E-03,   1.6884129E-03,   9.4966096E-04
     +,   5.0876150E-04,   2.5830773E-04,   1.2371644E-04
     +,   5.5731431E-05,   2.3595725E-05,   9.3944482E-06
     +,   3.5198516E-06,   1.2410452E-06,   4.1134518E-07
     +,   1.2796667E-07,   3.7355623E-08,   1.0295710E-08
     +,   2.7544806E-09,   7.8315321E-10,   2.8724545E-10
     +,   1.5579757E-10,   1.1038852E-10,   8.6278026E-11
     +,   6.9153787E-11,   5.5701492E-11,   4.4877230E-11
     +,   3.6131226E-11,   2.9065094E-11,   2.3361122E-11
     +,   1.8760890E-11,   1.5054199E-11,   1.2070314E-11
     +,   9.6704571E-12,   7.7419087E-12,   6.1933245E-12
     +,   4.9509030E-12,   3.9549145E-12,   3.1570595E-12
     +,   2.5183742E-12,   2.0075092E-12,   1.5991632E-12
     +,   1.2729827E-12,   1.0126230E-12,   8.0495262E-13
     +,   6.3941680E-13,   5.0755250E-13,   4.0258752E-13
     +,   3.1909452E-13,   2.5272595E-13,   2.0000475E-13
     +,   1.5815802E-13,   1.2496487E-13,   9.8657329E-14
     +,   7.7821599E-14,   6.1333622E-14,   4.8295755E-14
     +,   3.7995232E-14,   2.9863664E-14,   2.3450236E-14
     +,   1.8396219E-14,   1.4417260E-14,   1.1287531E-14
     +,   8.8280222E-15,   6.8972389E-15,   5.3829261E-15
     +,   4.1965574E-15,   3.2680157E-15,   2.5420869E-15
     +,   1.9751360E-15,   1.5328702E-15,   1.1882294E-15
     +,   9.1998948E-16,   7.1144335E-16,   5.4950818E-16
     +,   4.2390627E-16,   3.2661125E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt108 = Yx/0.385285714285714
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9774136E-09,   3.5727774E-09
     +,   4.2814445E-09,   5.1239102E-09,   6.1241883E-09
     +,   7.3103781E-09,   8.7153174E-09,   1.0377346E-08
     +,   1.2341111E-08,   1.4658681E-08,   1.7390505E-08
     +,   2.0606741E-08,   2.4388713E-08,   2.8830490E-08
     +,   3.4040752E-08,   4.0144727E-08,   4.7286569E-08
     +,   5.5631773E-08,   6.5369981E-08,   7.6718024E-08
     +,   8.9923304E-08,   1.0526716E-07,   1.2306892E-07
     +,   1.4369091E-07,   1.6754008E-07,   1.9507679E-07
     +,   2.2681630E-07,   2.6333473E-07,   3.0527494E-07
     +,   3.5335046E-07,   4.0835124E-07,   4.7114818E-07
     +,   5.4269753E-07,   6.2404513E-07,   7.1632957E-07
     +,   8.2078532E-07,   9.3874331E-07,   1.0716302E-06
     +,   1.2209784E-06,   1.3883974E-06,   1.5756040E-06
     +,   1.7843875E-06,   2.0166142E-06,   2.2742138E-06
     +,   2.5591642E-06,   2.8734783E-06,   3.2191797E-06
     +,   3.5982862E-06,   4.0127793E-06,   4.4645803E-06
     +,   4.9555188E-06,   5.4872994E-06,   6.0614575E-06
     +,   6.6793727E-06,   7.3421206E-06,   8.0505779E-06
     +,   8.8052711E-06,   9.6063886E-06,   1.0453742E-05
     +,   1.1346723E-05,   1.2284281E-05,   1.3264908E-05
     +,   1.4286548E-05,   1.5346704E-05,   1.6442389E-05
     +,   1.7569977E-05,   1.8725483E-05,   1.9904288E-05
     +,   2.1101445E-05,   2.2311418E-05,   2.3528441E-05
     +,   2.4746241E-05,   2.5958423E-05,   2.7158201E-05
     +,   2.8338784E-05,   2.9493291E-05,   3.0614799E-05
     +,   3.1696487E-05,   3.2731798E-05,   3.3714470E-05
     +,   3.4638491E-05,   3.5498455E-05,   3.6289381E-05
     +,   3.7006987E-05,   3.7647631E-05,   3.8208469E-05
     +,   3.8687369E-05,   3.9083156E-05,   3.9395414E-05
     +,   3.9624701E-05,   3.9772436E-05,   3.9840932E-05
     +,   3.9833365E-05,   3.9753802E-05,   3.9607101E-05
     +,   3.9398903E-05,   3.9135575E-05,   3.8824182E-05
     +,   3.8472350E-05,   3.8088336E-05,   3.7680864E-05
     +,   3.7259153E-05,   3.6832800E-05,   3.6411824E-05
     +,   3.6006575E-05,   3.5627749E-05,   3.5286412E-05
     +,   3.4994009E-05,   3.4762357E-05,   3.4603752E-05
     +,   3.4531007E-05,   3.4557561E-05,   3.4697521E-05
     +,   3.4965826E-05,   3.5378263E-05,   3.5951671E-05
     +,   3.6703866E-05,   3.7653899E-05,   3.8821847E-05
     +,   4.0228988E-05,   4.1897740E-05,   4.3851331E-05
     +,   4.6113739E-05,   4.8709629E-05,   5.1663970E-05
     +,   5.5001339E-05,   5.8746336E-05,   6.2922329E-05
     +,   6.7552035E-05,   7.2656258E-05,   7.8254685E-05
     +,   8.4364576E-05,   9.1002054E-05,   9.8180572E-05
     +,   1.0591256E-04,   1.1420900E-04,   1.2307921E-04
     +,   1.3253139E-04,   1.4257370E-04,   1.5321354E-04
     +,   1.6445735E-04,   1.7631048E-04,   1.8877814E-04
     +,   2.0186420E-04,   2.1556902E-04,   2.2989168E-04
     +,   2.4482794E-04,   2.6036822E-04,   2.7649841E-04
     +,   2.9319982E-04,   3.1044852E-04,   3.2821391E-04
     +,   3.4646047E-04,   3.6515022E-04,   3.8424419E-04
     +,   4.0370462E-04,   4.2350127E-04,   4.4361895E-04
     +,   4.6406410E-04,   4.8487063E-04,   5.0611160E-04
     +,   5.2790227E-04,   5.5039994E-04,   5.7380198E-04
     +,   5.9833750E-04,   6.2425114E-04,   6.5178890E-04
     +,   6.8118854E-04,   7.1269419E-04,   7.4659602E-04
     +,   7.8331854E-04,   8.2356902E-04,   8.6854608E-04
     +,   9.2018093E-04,   9.8136510E-04,   1.0561075E-03
     +,   1.1494743E-03,   1.2672147E-03,   1.4149692E-03
     +,   1.5970545E-03,   1.8149223E-03,   2.0656241E-03
     +,   2.3408765E-03,   2.6273597E-03,   2.9087130E-03
     +,   3.1692702E-03,   3.3989004E-03,   3.5973450E-03
     +,   3.7762725E-03,   3.9579300E-03,   4.1709105E-03
     +,   4.4450876E-03,   4.8082294E-03,   5.2844808E-03
     +,   5.8915988E-03,   6.6323811E-03,   7.4809017E-03
     +,   8.3749769E-03,   9.2353569E-03,   1.0022490E-02
     +,   1.0803093E-02,   1.1760058E-02,   1.3102869E-02
     +,   1.4931927E-02,   1.7203253E-02,   1.9904379E-02
     +,   2.3296287E-02,   2.8048979E-02,   3.5158880E-02
     +,   4.4231687E-02,   5.2985221E-02,   6.2903509E-02
     +,   7.6707855E-02,   9.3112037E-02,   0.1105410    
     +,   0.1243174    ,   0.1298236    ,   0.1216299    
     +,   0.1191797    ,   0.1119014    ,   8.9899853E-02
     +,   6.9391944E-02,   5.2458193E-02,   3.7543304E-02
     +,   2.5487570E-02,   1.6587112E-02,   1.0339426E-02
     +,   6.1116572E-03,   3.3610940E-03,   1.6768968E-03
     +,   7.4550451E-04,   2.9392217E-04,   1.0292942E-04
     +,   3.2037366E-05,   8.8456245E-06,   2.1601338E-06
     +,   4.6593613E-07,   8.9063825E-08,   1.5392475E-08
     +,   2.6641962E-09,   6.6916661E-10,   3.4267536E-10
     +,   2.5323835E-10,   2.0146619E-10,   1.6162048E-10
     +,   1.2954635E-10,   1.0364103E-10,   8.2749745E-11
     +,   6.5935986E-11,   5.2433075E-11,   4.1611315E-11
     +,   3.2956270E-11,   2.6048826E-11,   2.0547800E-11
     +,   1.6175837E-11,   1.2708347E-11,   9.9640574E-12
     +,   7.7967181E-12,   6.0885385E-12,   4.7450034E-12
     +,   3.6905162E-12,   2.8646250E-12,   2.2190956E-12
     +,   1.7155708E-12,   1.3236517E-12,   1.0192212E-12
     +,   7.8322922E-13,   6.0067538E-13,   4.5975409E-13
     +,   3.5119116E-13,   2.6772551E-13,   2.0368952E-13
     +,   1.5466278E-13,   1.1720253E-13,   8.8637973E-14
     +,   6.6902342E-14,   5.0395987E-14,   3.7887157E-14
     +,   2.8426368E-14,   2.1285967E-14,   1.5907467E-14
     +,   1.1864579E-14,   8.8316187E-15,   6.5610583E-15
     +,   4.8645886E-15,   3.5996889E-15,   2.6584406E-15
     +,   1.9594322E-15,   1.4413944E-15,   1.0582207E-15
     +,   7.7539244E-16,   5.6703451E-16,   4.1385654E-16
     +,   3.0146374E-16,   2.1916648E-16,   1.5902261E-16
     +,   1.1515965E-16,   8.3231555E-17,   6.0038926E-17
     +,   4.3224214E-17,   3.1058485E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt110 = Yx/0.387
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0824867E-07,   8.8536825E-07
     +,   9.6844758E-07,   1.0578015E-06,   1.1537481E-06
     +,   1.2566068E-06,   1.3666981E-06,   1.4843414E-06
     +,   1.6098512E-06,   1.7435443E-06,   1.8857270E-06
     +,   2.0366992E-06,   2.1967533E-06,   2.3661710E-06
     +,   2.5452225E-06,   2.7341646E-06,   2.9332400E-06
     +,   3.1426748E-06,   3.3626779E-06,   3.5934393E-06
     +,   3.8351304E-06,   4.0879017E-06,   4.3518767E-06
     +,   4.6271766E-06,   4.9138666E-06,   5.2120240E-06
     +,   5.5216829E-06,   5.8428591E-06,   6.1755491E-06
     +,   6.5197228E-06,   6.8753338E-06,   7.2423118E-06
     +,   7.6205683E-06,   8.0099990E-06,   8.4104804E-06
     +,   8.8218749E-06,   9.2440287E-06,   9.6767735E-06
     +,   1.0119958E-05,   1.0573369E-05,   1.1036841E-05
     +,   1.1510174E-05,   1.1993167E-05,   1.2485628E-05
     +,   1.2987355E-05,   1.3498153E-05,   1.4017828E-05
     +,   1.4546195E-05,   1.5083067E-05,   1.5628269E-05
     +,   1.6181635E-05,   1.6742999E-05,   1.7312203E-05
     +,   1.7889130E-05,   1.8473602E-05,   1.9065530E-05
     +,   1.9664783E-05,   2.0271251E-05,   2.0884834E-05
     +,   2.1505439E-05,   2.2132972E-05,   2.2767372E-05
     +,   2.3408529E-05,   2.4056397E-05,   2.4710929E-05
     +,   2.5372017E-05,   2.6039650E-05,   2.6713727E-05
     +,   2.7394242E-05,   2.8081093E-05,   2.8774279E-05
     +,   2.9473702E-05,   3.0179350E-05,   3.0891144E-05
     +,   3.1609045E-05,   3.2333028E-05,   3.3063021E-05
     +,   3.3798948E-05,   3.4540775E-05,   3.5288471E-05
     +,   3.6041933E-05,   3.6801124E-05,   3.7565947E-05
     +,   3.8336351E-05,   3.9112208E-05,   3.9893450E-05
     +,   4.0679915E-05,   4.1471532E-05,   4.2268082E-05
     +,   4.3069416E-05,   4.3875374E-05,   4.4685694E-05
     +,   4.5500106E-05,   4.6318361E-05,   4.7140176E-05
     +,   4.7965157E-05,   4.8793027E-05,   4.9623319E-05
     +,   5.0455739E-05,   5.1289826E-05,   5.2125230E-05
     +,   5.2961535E-05,   5.3798485E-05,   5.4635726E-05
     +,   5.5473105E-05,   5.6310542E-05,   5.7148070E-05
     +,   5.7985879E-05,   5.8824418E-05,   5.9664406E-05
     +,   6.0506758E-05,   6.1352875E-05,   6.2204432E-05
     +,   6.3063657E-05,   6.3933192E-05,   6.4816377E-05
     +,   6.5717097E-05,   6.6639986E-05,   6.7590430E-05
     +,   6.8574613E-05,   6.9599759E-05,   7.0673974E-05
     +,   7.1806448E-05,   7.3007643E-05,   7.4289339E-05
     +,   7.5664670E-05,   7.7148616E-05,   7.8757810E-05
     +,   8.0511236E-05,   8.2430168E-05,   8.4539031E-05
     +,   8.6865373E-05,   8.9440946E-05,   9.2301845E-05
     +,   9.5489668E-05,   9.9052297E-05,   1.0304419E-04
     +,   1.0752746E-04,   1.1257303E-04,   1.1826054E-04
     +,   1.2467861E-04,   1.3192451E-04,   1.4010388E-04
     +,   1.4932908E-04,   1.5971540E-04,   1.7137933E-04
     +,   1.8443321E-04,   1.9897842E-04,   2.1509868E-04
     +,   2.3285406E-04,   2.5227162E-04,   2.7333628E-04
     +,   2.9598462E-04,   3.2010194E-04,   3.4551817E-04
     +,   3.7200787E-04,   3.9929777E-04,   4.2707974E-04
     +,   4.5502480E-04,   4.8280077E-04,   5.1010092E-04
     +,   5.3666643E-04,   5.6230760E-04,   5.8692653E-04
     +,   6.1053335E-04,   6.3325348E-04,   6.5532862E-04
     +,   6.7711726E-04,   6.9910014E-04,   7.2188769E-04
     +,   7.4624852E-04,   7.7315798E-04,   8.0386945E-04
     +,   8.3998102E-04,   8.8348024E-04,   9.3673170E-04
     +,   1.0023561E-03,   1.0829833E-03,   1.1809069E-03
     +,   1.2977300E-03,   1.4341021E-03,   1.5897142E-03
     +,   1.7636539E-03,   1.9550663E-03,   2.1638207E-03
     +,   2.3908208E-03,   2.6375637E-03,   2.9048410E-03
     +,   3.1908976E-03,   3.4898841E-03,   3.7917560E-03
     +,   4.0839976E-03,   4.3550981E-03,   4.5986776E-03
     +,   4.8168111E-03,   5.0216811E-03,   5.2356240E-03
     +,   5.4898220E-03,   5.8205090E-03,   6.2600216E-03
     +,   6.8218741E-03,   7.4863974E-03,   8.2026422E-03
     +,   8.9227390E-03,   9.6716024E-03,   1.0630531E-02
     +,   1.2163927E-02,   1.4664590E-02,   1.8262545E-02
     +,   2.2768991E-02,   2.7841974E-02,   3.3007238E-02
     +,   3.7957266E-02,   4.2954199E-02,   4.9187910E-02
     +,   5.9369817E-02,   7.4115969E-02,   8.8774569E-02
     +,   0.1064861    ,   0.1329629    ,   0.1468083    
     +,   0.1440788    ,   0.1382454    ,   0.1210483    
     +,   8.6887904E-02,   5.2555207E-02,   2.7948124E-02
     +,   1.2660030E-02,   4.7644321E-03,   1.4261779E-03
     +,   3.2279210E-04,   5.8297908E-05,   1.4934545E-05
     +,   1.0247102E-05,   9.9374183E-06,   9.9350736E-06
     +,   9.9319259E-06,   9.9128702E-06,   9.8775135E-06
     +,   9.8260180E-06,   9.7586317E-06,   9.6756876E-06
     +,   9.5775931E-06,   9.4648212E-06,   9.3379140E-06
     +,   9.1974762E-06,   9.0441781E-06,   8.8787347E-06
     +,   8.7019016E-06,   8.5144957E-06,   8.3173545E-06
     +,   8.1113385E-06,   7.8973471E-06,   7.6762972E-06
     +,   7.4490999E-06,   7.2166667E-06,   6.9799294E-06
     +,   6.7398037E-06,   6.4971800E-06,   6.2529275E-06
     +,   6.0079096E-06,   5.7629563E-06,   5.5188511E-06
     +,   5.2763403E-06,   5.0361541E-06,   4.7989543E-06
     +,   4.5653592E-06,   4.3359546E-06,   4.1112758E-06
     +,   3.8917947E-06,   3.6779331E-06,   3.4700777E-06
     +,   3.2685623E-06,   3.0736599E-06,   2.8855941E-06
     +,   2.7045635E-06,   2.5306931E-06,   2.3640910E-06
     +,   2.2048002E-06,   2.0528482E-06,   1.9082038E-06
     +,   1.7708228E-06,   1.6406118E-06,   1.5174663E-06
     +,   1.4012400E-06,   1.2917800E-06,   1.1889022E-06
     +,   1.0924055E-06,   1.0020842E-06,   9.1770841E-07
     +,   8.3905019E-07,   7.6586326E-07,   6.9790644E-07
     +,   6.3492644E-07,   5.7667637E-07,   5.2290295E-07
     +,   4.7336144E-07,   4.2780377E-07,   3.8599273E-07
     +,   3.4769118E-07,   3.1267345E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt112 = Yx/0.375285714285714
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4816721E-05,   1.4986851E-05
     +,   1.5143433E-05,   1.5286048E-05,   1.5414329E-05
     +,   1.5527954E-05,   1.5626663E-05,   1.5710239E-05
     +,   1.5778531E-05,   1.5831441E-05,   1.5868933E-05
     +,   1.5891037E-05,   1.5897842E-05,   1.5889507E-05
     +,   1.5866251E-05,   1.5828369E-05,   1.5776217E-05
     +,   1.5710220E-05,   1.5630871E-05,   1.5538735E-05
     +,   1.5434445E-05,   1.5318703E-05,   1.5192274E-05
     +,   1.5055994E-05,   1.4910775E-05,   1.4757575E-05
     +,   1.4597435E-05,   1.4431456E-05,   1.4260797E-05
     +,   1.4086689E-05,   1.3910411E-05,   1.3733312E-05
     +,   1.3556799E-05,   1.3382330E-05,   1.3211422E-05
     +,   1.3045643E-05,   1.2886614E-05,   1.2736011E-05
     +,   1.2595541E-05,   1.2466982E-05,   1.2352135E-05
     +,   1.2252845E-05,   1.2171007E-05,   1.2108542E-05
     +,   1.2067409E-05,   1.2049591E-05,   1.2057109E-05
     +,   1.2091993E-05,   1.2156315E-05,   1.2252139E-05
     +,   1.2381567E-05,   1.2546693E-05,   1.2749623E-05
     +,   1.2992483E-05,   1.3277367E-05,   1.3606392E-05
     +,   1.3981658E-05,   1.4405255E-05,   1.4879265E-05
     +,   1.5405751E-05,   1.5986758E-05,   1.6624323E-05
     +,   1.7320426E-05,   1.8077068E-05,   1.8896242E-05
     +,   1.9779838E-05,   2.0729827E-05,   2.1748037E-05
     +,   2.2836415E-05,   2.3996721E-05,   2.5230871E-05
     +,   2.6540562E-05,   2.7927668E-05,   2.9393828E-05
     +,   3.0940806E-05,   3.2570337E-05,   3.4284029E-05
     +,   3.6083413E-05,   3.7970131E-05,   3.9945757E-05
     +,   4.2011634E-05,   4.4169319E-05,   4.6420013E-05
     +,   4.8765181E-05,   5.1205901E-05,   5.3743483E-05
     +,   5.6378925E-05,   5.9113463E-05,   6.1947947E-05
     +,   6.4883461E-05,   6.7921123E-05,   7.1061768E-05
     +,   7.4306314E-05,   7.7655859E-05,   8.1111561E-05
     +,   8.4674248E-05,   8.8345252E-05,   9.2125425E-05
     +,   9.6016091E-05,   1.0001803E-04,   1.0413232E-04
     +,   1.0835940E-04,   1.1269984E-04,   1.1715331E-04
     +,   1.2171917E-04,   1.2639607E-04,   1.3118150E-04
     +,   1.3607176E-04,   1.4106213E-04,   1.4614643E-04
     +,   1.5131634E-04,   1.5656262E-04,   1.6187319E-04
     +,   1.6723516E-04,   1.7263285E-04,   1.7804980E-04
     +,   1.8346730E-04,   1.8886631E-04,   1.9422609E-04
     +,   1.9952632E-04,   2.0474683E-04,   2.0986813E-04
     +,   2.1487210E-04,   2.1974331E-04,   2.2446917E-04
     +,   2.2904019E-04,   2.3345156E-04,   2.3770274E-04
     +,   2.4179828E-04,   2.4574777E-04,   2.4956599E-04
     +,   2.5327277E-04,   2.5689253E-04,   2.6045367E-04
     +,   2.6398810E-04,   2.6753015E-04,   2.7111560E-04
     +,   2.7478058E-04,   2.7856100E-04,   2.8249118E-04
     +,   2.8660276E-04,   2.9092460E-04,   2.9548199E-04
     +,   3.0029702E-04,   3.0538772E-04,   3.1077015E-04
     +,   3.1645835E-04,   3.2246631E-04,   3.2880952E-04
     +,   3.3550817E-04,   3.4258948E-04,   3.5009073E-04
     +,   3.5806332E-04,   3.6657762E-04,   3.7572740E-04
     +,   3.8563472E-04,   3.9645695E-04,   4.0839278E-04
     +,   4.2169087E-04,   4.3665487E-04,   4.5365185E-04
     +,   4.7311894E-04,   4.9556198E-04,   5.2155479E-04
     +,   5.5173138E-04,   5.8676559E-04,   6.2733999E-04
     +,   6.7410670E-04,   7.2764285E-04,   7.8839413E-04
     +,   8.5661846E-04,   9.3234208E-04,   1.0153409E-03
     +,   1.1051319E-03,   1.2009831E-03,   1.3019834E-03
     +,   1.4071005E-03,   1.5152448E-03,   1.6253442E-03
     +,   1.7364023E-03,   1.8475109E-03,   1.9578559E-03
     +,   2.0667179E-03,   2.1734973E-03,   2.2777547E-03
     +,   2.3792905E-03,   2.4782799E-03,   2.5754045E-03
     +,   2.6719959E-03,   2.7701592E-03,   2.8729949E-03
     +,   2.9849650E-03,   3.1125436E-03,   3.2651839E-03
     +,   3.4564391E-03,   3.7047192E-03,   4.0329946E-03
     +,   4.4666338E-03,   5.0287214E-03,   5.7326709E-03
     +,   6.5733893E-03,   7.5208000E-03,   8.5216006E-03
     +,   9.5142461E-03,   1.0458576E-02,   1.1373505E-02
     +,   1.2362986E-02,   1.3602224E-02,   1.5280148E-02
     +,   1.7533561E-02,   2.0378146E-02,   2.3632277E-02
     +,   2.6984382E-02,   3.0350870E-02,   3.4240574E-02
     +,   3.9492048E-02,   4.7263678E-02,   5.8917716E-02
     +,   7.5551845E-02,   9.4950698E-02,   0.1124752    
     +,   0.1297597    ,   0.1444965    ,   0.1466163    
     +,   0.1288918    ,   9.6649833E-02,   5.8662049E-02
     +,   2.6684532E-02,   8.5098287E-03,   1.7876783E-03
     +,   2.3260215E-04,   1.7869763E-05,   7.9053268E-07
     +,   2.1777627E-08,   1.9823239E-09,   1.3869720E-09
     +,   1.1220024E-09,   9.0733959E-10,   7.3233797E-10
     +,   5.8992433E-10,   4.7424997E-10,   3.8048467E-10
     +,   3.0463521E-10,   2.4340235E-10,   1.9407149E-10
     +,   1.5441480E-10,   1.2260390E-10,   9.7140566E-11
     +,   7.6801794E-11,   6.0592621E-11,   4.7702325E-11
     +,   3.7473542E-11,   2.9374971E-11,   2.2977261E-11
     +,   1.7934196E-11,   1.3967679E-11,   1.0854914E-11
     +,   8.4176581E-12,   6.5134898E-12,   5.0290861E-12
     +,   3.8745426E-12,   2.9785850E-12,   2.2848310E-12
     +,   1.7488308E-12,   1.3356669E-12,   1.0178902E-12
     +,   7.7401930E-13,   5.8729172E-13,   4.4464272E-13
     +,   3.3590727E-13,   2.5320609E-13,   1.9044946E-13
     +,   1.4293526E-13,   1.0704073E-13,   7.9984515E-14
     +,   5.9637110E-14,   4.4368345E-14,   3.2937049E-14
     +,   2.4397368E-14,   1.8032506E-14,   1.3298891E-14
     +,   9.7865772E-15,   7.1861216E-15,   5.2651839E-15
     +,   3.8492968E-15,   2.8080673E-15,   2.0440237E-15
     +,   1.4846159E-15,   1.0759754E-15,   7.7811004E-16
     +,   5.6148904E-16,   4.0429052E-16,   2.9047581E-16
     +,   2.0824812E-16,   1.4897584E-16,   1.0634307E-16
     +,   7.5747708E-17,   5.3838063E-17,   3.8183924E-17
     +,   2.7023094E-17,   1.9083768E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt113 = Yx/0.354142857142857
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1589238E-07,   1.3039305E-07
     +,   1.4649393E-07,   1.6434302E-07,   1.8409848E-07
     +,   2.0592880E-07,   2.3001326E-07,   2.5654171E-07
     +,   2.8571495E-07,   3.1774587E-07,   3.5285737E-07
     +,   3.9128366E-07,   4.3326969E-07,   4.7907110E-07
     +,   5.2895382E-07,   5.8319370E-07,   6.4207552E-07
     +,   7.0589277E-07,   7.7494684E-07,   8.4954553E-07
     +,   9.3000335E-07,   1.0166385E-06,   1.1097713E-06
     +,   1.2097303E-06,   1.3168325E-06,   1.4314065E-06
     +,   1.5537698E-06,   1.6842371E-06,   1.8231149E-06
     +,   1.9707027E-06,   2.1272865E-06,   2.2931401E-06
     +,   2.4685207E-06,   2.6536679E-06,   2.8488005E-06
     +,   3.0541141E-06,   3.2697817E-06,   3.4959403E-06
     +,   3.7327186E-06,   3.9801826E-06,   4.2383954E-06
     +,   4.5073680E-06,   4.7870799E-06,   5.0774725E-06
     +,   5.3784493E-06,   5.6898725E-06,   6.0115672E-06
     +,   6.3433190E-06,   6.6848716E-06,   7.0359310E-06
     +,   7.3961664E-06,   7.7652085E-06,   8.1426497E-06
     +,   8.5280699E-06,   8.9209807E-06,   9.3209082E-06
     +,   9.7273314E-06,   1.0139714E-05,   1.0557502E-05
     +,   1.0980139E-05,   1.1407047E-05,   1.1837669E-05
     +,   1.2271419E-05,   1.2707751E-05,   1.3146137E-05
     +,   1.3586033E-05,   1.4026964E-05,   1.4468454E-05
     +,   1.4910106E-05,   1.5351516E-05,   1.5792390E-05
     +,   1.6232427E-05,   1.6671462E-05,   1.7109323E-05
     +,   1.7545977E-05,   1.7981458E-05,   1.8415851E-05
     +,   1.8849356E-05,   1.9282286E-05,   1.9715062E-05
     +,   2.0148173E-05,   2.0582293E-05,   2.1018153E-05
     +,   2.1456677E-05,   2.1898893E-05,   2.2346027E-05
     +,   2.2799413E-05,   2.3260640E-05,   2.3731414E-05
     +,   2.4213707E-05,   2.4709705E-05,   2.5221847E-05
     +,   2.5752788E-05,   2.6305539E-05,   2.6883419E-05
     +,   2.7490016E-05,   2.8129363E-05,   2.8805774E-05
     +,   2.9524075E-05,   3.0289386E-05,   3.1107375E-05
     +,   3.1984047E-05,   3.2925956E-05,   3.3939981E-05
     +,   3.5033550E-05,   3.6214475E-05,   3.7490929E-05
     +,   3.8871371E-05,   4.0364695E-05,   4.1980024E-05
     +,   4.3726508E-05,   4.5613571E-05,   4.7650439E-05
     +,   4.9846458E-05,   5.2210507E-05,   5.4751421E-05
     +,   5.7477297E-05,   6.0396022E-05,   6.3514395E-05
     +,   6.6838737E-05,   7.0374510E-05,   7.4125870E-05
     +,   7.8095909E-05,   8.2286759E-05,   8.6699285E-05
     +,   9.1332629E-05,   9.6185206E-05,   1.0125356E-04
     +,   1.0653365E-04,   1.1201981E-04,   1.1770650E-04
     +,   1.2358728E-04,   1.2965707E-04,   1.3591163E-04
     +,   1.4235037E-04,   1.4897737E-04,   1.5580321E-04
     +,   1.6284788E-04,   1.7014411E-04,   1.7774031E-04
     +,   1.8570310E-04,   1.9412070E-04,   2.0310590E-04
     +,   2.1279712E-04,   2.2335671E-04,   2.3497075E-04
     +,   2.4784304E-04,   2.6218657E-04,   2.7821271E-04
     +,   2.9611919E-04,   3.1607202E-04,   3.3818686E-04
     +,   3.6251193E-04,   3.8901207E-04,   4.1755399E-04
     +,   4.4789552E-04,   4.7968377E-04,   5.1246345E-04
     +,   5.4568809E-04,   5.7873904E-04,   6.1096274E-04
     +,   6.4170320E-04,   6.7034242E-04,   6.9634581E-04
     +,   7.1930839E-04,   7.3899428E-04,   7.5537589E-04
     +,   7.6867000E-04,   7.7936961E-04,   7.8826363E-04
     +,   7.9644751E-04,   8.0532132E-04,   8.1655785E-04
     +,   8.3204452E-04,   8.5378531E-04,   8.8377902E-04
     +,   9.2388532E-04,   9.7570528E-04,   1.0405300E-03
     +,   1.1193883E-03,   1.2131977E-03,   1.3229829E-03
     +,   1.4500997E-03,   1.5963411E-03,   1.7637875E-03
     +,   1.9543299E-03,   2.1689103E-03,   2.4065981E-03
     +,   2.6636808E-03,   2.9331378E-03,   3.2049974E-03
     +,   3.4679158E-03,   3.7122983E-03,   3.9347773E-03
     +,   4.1429470E-03,   4.3585794E-03,   4.6176128E-03
     +,   4.9656644E-03,   5.4481472E-03,   6.0943346E-03
     +,   6.8979380E-03,   7.8056040E-03,   8.7314183E-03
     +,   9.6024806E-03,   1.0407396E-02,   1.1203964E-02
     +,   1.2080642E-02,   1.3113295E-02,   1.4333474E-02
     +,   1.5700864E-02,   1.7214421E-02,   1.9248450E-02
     +,   2.2448678E-02,   2.6782541E-02,   3.1567801E-02
     +,   3.6876053E-02,   4.3105319E-02,   4.9825311E-02
     +,   5.6175649E-02,   6.2798895E-02,   7.4663825E-02
     +,   9.6165478E-02,   0.1220249    ,   0.1479157    
     +,   0.1595357    ,   0.1474092    ,   0.1076083    
     +,   4.9836069E-02,   1.2365558E-02,   1.4645824E-03
     +,   7.7430836E-05,   1.7562213E-06,   1.7203254E-08
     +,   5.5621374E-10,   3.9772752E-10,   3.2102709E-10
     +,   2.5889488E-10,   2.0852818E-10,   1.6773402E-10
     +,   1.3472683E-10,   1.0805167E-10,   8.6523642E-11
     +,   6.9174791E-11,   5.5214524E-11,   4.3998256E-11
     +,   3.5001491E-11,   2.7797193E-11,   2.2037741E-11
     +,   1.7441163E-11,   1.3779274E-11,   1.0867010E-11
     +,   8.5549762E-12,   6.7228098E-12,   5.2735845E-12
     +,   4.1293015E-12,   3.2274229E-12,   2.5179336E-12
     +,   1.9608380E-12,   1.5242017E-12,   1.1826062E-12
     +,   9.1587491E-13,   7.0799844E-13,   5.4628865E-13
     +,   4.2072758E-13,   3.2342529E-13,   2.4816244E-13
     +,   1.9005624E-13,   1.4528279E-13,   1.1084993E-13
     +,   8.4419051E-14,   6.4168905E-14,   4.8684557E-14
     +,   3.6867451E-14,   2.7866022E-14,   2.1022429E-14
     +,   1.5829740E-14,   1.1897056E-14,   8.9245814E-15
     +,   6.6820485E-15,   4.9935891E-15,   3.7246825E-15
     +,   2.7729819E-15,   2.0605216E-15,   1.5282292E-15
     +,   1.1312843E-15,   8.3586545E-16,   6.1642235E-16
     +,   4.5372405E-16,   3.3333981E-16,   2.4443020E-16
     +,   1.7889773E-16,   1.3068576E-16,   9.5287064E-17
     +,   6.9344873E-17,   5.0370604E-17,   3.6518648E-17
     +,   2.6426358E-17,   1.9086938E-17,   1.3760047E-17
     +,   9.9010475E-18,   7.1109806E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt114 = Yx/0.346645833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt1148(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.6887532E-07,   7.3000427E-07
     +,   7.9606696E-07,   8.6740062E-07,   9.4435933E-07
     +,   1.0273162E-06,   1.1166618E-06,   1.2128042E-06
     +,   1.3161698E-06,   1.4272067E-06,   1.5463776E-06
     +,   1.6741642E-06,   1.8110659E-06,   1.9575994E-06
     +,   2.1142973E-06,   2.2817089E-06,   2.4603958E-06
     +,   2.6509347E-06,   2.8539116E-06,   3.0699246E-06
     +,   3.2995763E-06,   3.5434775E-06,   3.8022345E-06
     +,   4.0764712E-06,   4.3667774E-06,   4.6737678E-06
     +,   4.9980254E-06,   5.3401241E-06,   5.7006177E-06
     +,   6.0800344E-06,   6.4788765E-06,   6.8976046E-06
     +,   7.3366473E-06,   7.7963814E-06,   8.2771348E-06
     +,   8.7791768E-06,   9.3027138E-06,   9.8478749E-06
     +,   1.0414748E-05,   1.1003274E-05,   1.1613380E-05
     +,   1.2244851E-05,   1.2897393E-05,   1.3570609E-05
     +,   1.4263987E-05,   1.4976918E-05,   1.5708665E-05
     +,   1.6458382E-05,   1.7225100E-05,   1.8007737E-05
     +,   1.8805082E-05,   1.9615805E-05,   2.0438449E-05
     +,   2.1271493E-05,   2.2113203E-05,   2.2961833E-05
     +,   2.3815486E-05,   2.4672172E-05,   2.5529811E-05
     +,   2.6386249E-05,   2.7239254E-05,   2.8086539E-05
     +,   2.8925722E-05,   2.9754443E-05,   3.0570314E-05
     +,   3.1370855E-05,   3.2153675E-05,   3.2916312E-05
     +,   3.3656426E-05,   3.4371606E-05,   3.5059613E-05
     +,   3.5718156E-05,   3.6345136E-05,   3.6938465E-05
     +,   3.7496218E-05,   3.8016595E-05,   3.8497881E-05
     +,   3.8938531E-05,   3.9337181E-05,   3.9692608E-05
     +,   4.0003772E-05,   4.0269828E-05,   4.0490082E-05
     +,   4.0664097E-05,   4.0791605E-05,   4.0872579E-05
     +,   4.0907187E-05,   4.0895851E-05,   4.0839222E-05
     +,   4.0738192E-05,   4.0593924E-05,   4.0407842E-05
     +,   4.0181705E-05,   3.9917526E-05,   3.9617702E-05
     +,   3.9285005E-05,   3.8922597E-05,   3.8534177E-05
     +,   3.8123886E-05,   3.7696595E-05,   3.7257785E-05
     +,   3.6813839E-05,   3.6372036E-05,   3.5940837E-05
     +,   3.5529960E-05,   3.5150624E-05,   3.4815876E-05
     +,   3.4540742E-05,   3.4342585E-05,   3.4241421E-05
     +,   3.4260265E-05,   3.4425506E-05,   3.4767188E-05
     +,   3.5319459E-05,   3.6120695E-05,   3.7213937E-05
     +,   3.8646798E-05,   4.0471743E-05,   4.2745603E-05
     +,   4.5529621E-05,   4.8888818E-05,   5.2890962E-05
     +,   5.7605641E-05,   6.3103442E-05,   6.9454116E-05
     +,   7.6724231E-05,   8.4976789E-05,   9.4267154E-05
     +,   1.0464330E-04,   1.1614108E-04,   1.2878518E-04
     +,   1.4258412E-04,   1.5753209E-04,   1.7360394E-04
     +,   1.9075790E-04,   2.0893347E-04,   2.2805009E-04
     +,   2.4800867E-04,   2.6869355E-04,   2.8997203E-04
     +,   3.1169518E-04,   3.3370013E-04,   3.5581418E-04
     +,   3.7785660E-04,   3.9963890E-04,   4.2097474E-04
     +,   4.4168215E-04,   4.6158856E-04,   4.8054199E-04
     +,   4.9841951E-04,   5.1513861E-04,   5.3066819E-04
     +,   5.4504268E-04,   5.5837625E-04,   5.7087303E-04
     +,   5.8283657E-04,   5.9467304E-04,   6.0689205E-04
     +,   6.2009488E-04,   6.3495507E-04,   6.5219624E-04
     +,   6.7255838E-04,   6.9676398E-04,   7.2548806E-04
     +,   7.5934123E-04,   7.9885690E-04,   8.4450137E-04
     +,   8.9668902E-04,   9.5581083E-04,   1.0222396E-03
     +,   1.0963033E-03,   1.1782196E-03,   1.2679835E-03
     +,   1.3651944E-03,   1.4688681E-03,   1.5773032E-03
     +,   1.6880115E-03,   1.7977904E-03,   1.9029904E-03
     +,   1.9999763E-03,   2.0857048E-03,   2.1584036E-03
     +,   2.2182690E-03,   2.2680860E-03,   2.3137124E-03
     +,   2.3643237E-03,   2.4322814E-03,   2.5323916E-03
     +,   2.6803697E-03,   2.8905014E-03,   3.1729580E-03
     +,   3.5314865E-03,   3.9623901E-03,   4.4555012E-03
     +,   4.9971812E-03,   5.5745216E-03,   6.1794864E-03
     +,   6.8114041E-03,   7.4762609E-03,   8.1814285E-03
     +,   8.9257825E-03,   9.6881306E-03,   1.0424050E-02
     +,   1.1086009E-02,   1.1673495E-02,   1.2289443E-02
     +,   1.3141872E-02,   1.4437662E-02,   1.6210446E-02
     +,   1.8239409E-02,   2.0200392E-02,   2.2001900E-02
     +,   2.4001267E-02,   2.6698433E-02,   2.9954685E-02
     +,   3.2898791E-02,   3.5298150E-02,   3.8235120E-02
     +,   4.4338372E-02,   5.7349741E-02,   7.4896298E-02
     +,   9.1698579E-02,   0.1079651    ,   0.1238180    
     +,   0.1405924    ,   0.1440204    ,   0.1143875    
     +,   6.0006689E-02,   1.7967809E-02,   2.7742274E-03
     +,   2.0672624E-04,   7.1183631E-06,   1.1167464E-07
     +,   2.2943045E-09,   1.3397823E-09,   1.1549439E-09
     +,   9.9613373E-10,   8.5820101E-10,   7.3853906E-10
     +,   6.3484612E-10,   5.4509236E-10,   4.6749826E-10
     +,   4.0049755E-10,   3.4271011E-10,   2.9292679E-10
     +,   2.5009117E-10,   2.1327826E-10,   1.8167765E-10
     +,   1.5458267E-10,   1.3137993E-10,   1.1153299E-10
     +,   9.4576208E-11,   8.0106290E-11,   6.7773544E-11
     +,   5.7274276E-11,   4.8346237E-11,   4.0763497E-11
     +,   3.4331173E-11,   2.8880974E-11,   2.4268247E-11
     +,   2.0369052E-11,   1.7077006E-11,   1.4300700E-11
     +,   1.1962080E-11,   9.9945538E-12,   8.3411472E-12
     +,   6.9533030E-12,   5.7897732E-12,   4.8154861E-12
     +,   4.0005855E-12,   3.3197800E-12,   2.7516986E-12
     +,   2.2782390E-12,   1.8840964E-12,   1.5563580E-12
     +,   1.2841713E-12,   1.0583714E-12,   8.7128785E-13
     +,   7.1645147E-13,   5.8846309E-13,   4.8278504E-13
     +,   3.9563578E-13,   3.2384607E-13,   2.6478269E-13
     +,   2.1624280E-13,   1.7640120E-13,   1.4373585E-13
     +,   1.1698506E-13,   9.5104839E-14,   7.7228195E-14
     +,   6.2640702E-14,   5.0750328E-14,   4.1070236E-14
     +,   3.3198392E-14,   2.6804896E-14,   2.1617827E-14
     +,   1.7414713E-14,   1.4012686E-14,   1.1262466E-14
     +,   9.0416168E-15,   7.2504631E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt1148 = Yx/0.338916666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7791918E-07,   4.0777400E-07
     +,   4.3961504E-07,   4.7354567E-07,   5.0967287E-07
     +,   5.4810744E-07,   5.8896450E-07,   6.3236416E-07
     +,   6.7842922E-07,   7.2729051E-07,   7.7908163E-07
     +,   8.3394258E-07,   8.9201995E-07,   9.5346661E-07
     +,   1.0184434E-06,   1.0871187E-06,   1.1596696E-06
     +,   1.2362843E-06,   1.3171609E-06,   1.4025087E-06
     +,   1.4925525E-06,   1.5875298E-06,   1.6876929E-06
     +,   1.7933202E-06,   1.9046962E-06,   2.0221405E-06
     +,   2.1459887E-06,   2.2766064E-06,   2.4143862E-06
     +,   2.5597549E-06,   2.7131728E-06,   2.8751399E-06
     +,   3.0461979E-06,   3.2269370E-06,   3.4179950E-06
     +,   3.6200695E-06,   3.8339158E-06,   4.0603563E-06
     +,   4.3002992E-06,   4.5547085E-06,   4.8246643E-06
     +,   5.1113261E-06,   5.4159705E-06,   5.7399811E-06
     +,   6.0848806E-06,   6.4523256E-06,   6.8441304E-06
     +,   7.2622724E-06,   7.7089162E-06,   8.1864282E-06
     +,   8.6973787E-06,   9.2445762E-06,   9.8310675E-06
     +,   1.0460201E-05,   1.1135528E-05,   1.1860968E-05
     +,   1.2640693E-05,   1.3479204E-05,   1.4381304E-05
     +,   1.5352109E-05,   1.6397036E-05,   1.7521801E-05
     +,   1.8732302E-05,   2.0034766E-05,   2.1435591E-05
     +,   2.2941160E-05,   2.4558110E-05,   2.6292815E-05
     +,   2.8151753E-05,   3.0140909E-05,   3.2266165E-05
     +,   3.4532604E-05,   3.6944955E-05,   3.9506838E-05
     +,   4.2221138E-05,   4.5089586E-05,   4.8112466E-05
     +,   5.1288564E-05,   5.4615277E-05,   5.8088244E-05
     +,   6.1700921E-05,   6.5445260E-05,   6.9310721E-05
     +,   7.3285199E-05,   7.7354031E-05,   8.1501123E-05
     +,   8.5707892E-05,   8.9954621E-05,   9.4219344E-05
     +,   9.8479301E-05,   1.0271055E-04,   1.0688822E-04
     +,   1.1098695E-04,   1.1498165E-04,   1.1884758E-04
     +,   1.2256045E-04,   1.2609760E-04,   1.2943755E-04
     +,   1.3256128E-04,   1.3545176E-04,   1.3809497E-04
     +,   1.4047971E-04,   1.4259829E-04,   1.4444620E-04
     +,   1.4602274E-04,   1.4733082E-04,   1.4837680E-04
     +,   1.4917071E-04,   1.4972607E-04,   1.5005941E-04
     +,   1.5019026E-04,   1.5014067E-04,   1.4993495E-04
     +,   1.4959923E-04,   1.4916096E-04,   1.4864873E-04
     +,   1.4809158E-04,   1.4751873E-04,   1.4695938E-04
     +,   1.4644217E-04,   1.4599509E-04,   1.4564535E-04
     +,   1.4541936E-04,   1.4534258E-04,   1.4544002E-04
     +,   1.4573608E-04,   1.4625538E-04,   1.4702280E-04
     +,   1.4806447E-04,   1.4940806E-04,   1.5108372E-04
     +,   1.5312464E-04,   1.5556802E-04,   1.5845541E-04
     +,   1.6183352E-04,   1.6575477E-04,   1.7027704E-04
     +,   1.7546372E-04,   1.8138392E-04,   1.8811093E-04
     +,   1.9572119E-04,   2.0429236E-04,   2.1390170E-04
     +,   2.2462376E-04,   2.3652555E-04,   2.4966599E-04
     +,   2.6409214E-04,   2.7983554E-04,   2.9691140E-04
     +,   3.1531937E-04,   3.3504420E-04,   3.5605743E-04
     +,   3.7832532E-04,   4.0181793E-04,   4.2651972E-04
     +,   4.5243950E-04,   4.7962612E-04,   5.0818210E-04
     +,   5.3827267E-04,   5.7012925E-04,   6.0405571E-04
     +,   6.4042240E-04,   6.7965279E-04,   7.2221516E-04
     +,   7.6861563E-04,   8.1939425E-04,   8.7513565E-04
     +,   9.3650509E-04,   1.0043121E-03,   1.0795866E-03
     +,   1.1636701E-03,   1.2583100E-03,   1.3657379E-03
     +,   1.4886683E-03,   1.6302028E-03,   1.7936225E-03
     +,   1.9819664E-03,   2.1974407E-03,   2.4406919E-03
     +,   2.7101191E-03,   3.0013621E-03,   3.3072771E-03
     +,   3.6186692E-03,   3.9257961E-03,   4.2204279E-03
     +,   4.4979644E-03,   4.7590607E-03,   5.0100689E-03
     +,   5.2619739E-03,   5.5278959E-03,   5.8198702E-03
     +,   6.1457329E-03,   6.5078856E-03,   6.9053713E-03
     +,   7.3386156E-03,   7.8123831E-03,   8.3308155E-03
     +,   8.8838255E-03,   9.4356034E-03,   9.9331718E-03
     +,   1.0341813E-02,   1.0687048E-02,   1.1065890E-02
     +,   1.1608301E-02,   1.2412811E-02,   1.3507789E-02
     +,   1.4873412E-02,   1.6505953E-02,   1.8459601E-02
     +,   2.0823415E-02,   2.3666162E-02,   2.6956193E-02
     +,   3.0429453E-02,   3.3660926E-02,   3.6424182E-02
     +,   3.8816027E-02,   4.1328195E-02,   4.4535711E-02
     +,   4.8069935E-02,   5.1605895E-02,   5.7650611E-02
     +,   6.8786755E-02,   8.0789745E-02,   9.0007864E-02
     +,   9.7201638E-02,   9.4469823E-02,   7.2548576E-02
     +,   4.0098958E-02,   1.5194166E-02,   3.8301460E-03
     +,   6.2556053E-04,   6.4507156E-05,   4.1039216E-06
     +,   1.6025884E-07,   5.6971703E-09,   1.7689050E-09
     +,   1.4267860E-09,   1.1818095E-09,   9.7796660E-10
     +,   8.0828017E-10,   6.6720007E-10,   5.5005434E-10
     +,   4.5291065E-10,   3.7245526E-10,   3.0590513E-10
     +,   2.5093178E-10,   2.0558179E-10,   1.6821862E-10
     +,   1.3747517E-10,   1.1221355E-10,   9.1482620E-11
     +,   7.4491656E-11,   6.0584329E-11,   4.9216159E-11
     +,   3.9934958E-11,   3.2367015E-11,   2.6203994E-11
     +,   2.1191410E-11,   1.7119341E-11,   1.3815176E-11
     +,   1.1137358E-11,   8.9697373E-12,   7.2170078E-12
     +,   5.8012978E-12,   4.6591099E-12,   3.7385390E-12
     +,   2.9973181E-12,   2.4011251E-12,   1.9220537E-12
     +,   1.5374400E-12,   1.2289265E-12,   9.8167590E-13
     +,   7.8369315E-13,   6.2527679E-13,   4.9861141E-13
     +,   3.9740989E-13,   3.1660235E-13,   2.5212251E-13
     +,   2.0069764E-13,   1.5970953E-13,   1.2705317E-13
     +,   1.0104883E-13,   8.0348454E-14,   6.3877201E-14
     +,   5.0774292E-14,   4.0354574E-14,   3.2070324E-14
     +,   2.5484873E-14,   2.0251118E-14,   1.6091839E-14
     +,   1.2787016E-14,   1.0161060E-14,   8.0747422E-15
     +,   6.4170568E-15,   5.1000184E-15,   4.0535062E-15
     +,   3.2219626E-15,   2.5611435E-15,   2.0359923E-15
     +,   1.6185902E-15,   1.2868236E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt116 = Yx/0.3031875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2356972E-06,   3.3900319E-06
     +,   3.5494022E-06,   3.7138575E-06,   3.8834451E-06
     +,   4.0582081E-06,   4.2381862E-06,   4.4234180E-06
     +,   4.6139326E-06,   4.8097700E-06,   5.0109570E-06
     +,   5.2175178E-06,   5.4294801E-06,   5.6468675E-06
     +,   5.8697010E-06,   6.0980046E-06,   6.3317962E-06
     +,   6.5710992E-06,   6.8159320E-06,   7.0663154E-06
     +,   7.3222759E-06,   7.5838334E-06,   7.8510066E-06
     +,   8.1238359E-06,   8.4023332E-06,   8.6865421E-06
     +,   8.9764908E-06,   9.2722139E-06,   9.5737514E-06
     +,   9.8811479E-06,   1.0194441E-05,   1.0513681E-05
     +,   1.0838920E-05,   1.1170206E-05,   1.1507598E-05
     +,   1.1851150E-05,   1.2200926E-05,   1.2556976E-05
     +,   1.2919382E-05,   1.3288182E-05,   1.3663457E-05
     +,   1.4045264E-05,   1.4433665E-05,   1.4828728E-05
     +,   1.5230507E-05,   1.5639069E-05,   1.6054462E-05
     +,   1.6476759E-05,   1.6906015E-05,   1.7342290E-05
     +,   1.7785645E-05,   1.8236156E-05,   1.8693885E-05
     +,   1.9158941E-05,   1.9631385E-05,   2.0111362E-05
     +,   2.0599004E-05,   2.1094476E-05,   2.1597974E-05
     +,   2.2109749E-05,   2.2630102E-05,   2.3159402E-05
     +,   2.3698052E-05,   2.4246596E-05,   2.4805660E-05
     +,   2.5375937E-05,   2.5958327E-05,   2.6553780E-05
     +,   2.7163487E-05,   2.7788734E-05,   2.8431068E-05
     +,   2.9092149E-05,   2.9773955E-05,   3.0478574E-05
     +,   3.1208430E-05,   3.1966159E-05,   3.2754622E-05
     +,   3.3576915E-05,   3.4436442E-05,   3.5336823E-05
     +,   3.6281843E-05,   3.7275644E-05,   3.8322352E-05
     +,   3.9426443E-05,   4.0592371E-05,   4.1824795E-05
     +,   4.3128268E-05,   4.4507513E-05,   4.5966972E-05
     +,   4.7511116E-05,   4.9144244E-05,   5.0870283E-05
     +,   5.2692845E-05,   5.4615324E-05,   5.6640638E-05
     +,   5.8771093E-05,   6.1008766E-05,   6.3354884E-05
     +,   6.5810425E-05,   6.8375528E-05,   7.1050134E-05
     +,   7.3833311E-05,   7.6724027E-05,   7.9720485E-05
     +,   8.2820916E-05,   8.6023232E-05,   8.9325098E-05
     +,   9.2724134E-05,   9.6218297E-05,   9.9805708E-05
     +,   1.0348456E-04,   1.0725384E-04,   1.1111267E-04
     +,   1.1506111E-04,   1.1909942E-04,   1.2322898E-04
     +,   1.2745113E-04,   1.3176855E-04,   1.3618366E-04
     +,   1.4069992E-04,   1.4532114E-04,   1.5005117E-04
     +,   1.5489424E-04,   1.5985518E-04,   1.6493941E-04
     +,   1.7015245E-04,   1.7550151E-04,   1.8099451E-04
     +,   1.8664220E-04,   1.9245716E-04,   1.9845649E-04
     +,   2.0466121E-04,   2.1109881E-04,   2.1780300E-04
     +,   2.2481639E-04,   2.3219120E-04,   2.3998955E-04
     +,   2.4828519E-04,   2.5716427E-04,   2.6672526E-04
     +,   2.7707816E-04,   2.8834329E-04,   3.0065098E-04
     +,   3.1413801E-04,   3.2894273E-04,   3.4520301E-04
     +,   3.6305023E-04,   3.8260134E-04,   4.0395389E-04
     +,   4.2718078E-04,   4.5232364E-04,   4.7938654E-04
     +,   5.0833559E-04,   5.3910242E-04,   5.7158980E-04
     +,   6.0568092E-04,   6.4126088E-04,   6.7824434E-04
     +,   7.1660621E-04,   7.5641501E-04,   7.9788262E-04
     +,   8.4140588E-04,   8.8761345E-04,   9.3742739E-04
     +,   9.9214027E-04,   1.0535020E-03,   1.1238211E-03
     +,   1.2060752E-03,   1.3039724E-03,   1.4219029E-03
     +,   1.5646842E-03,   1.7370621E-03,   1.9429306E-03
     +,   2.1843256E-03,   2.4603652E-03,   2.7665293E-03
     +,   3.0943989E-03,   3.4321458E-03,   3.7657476E-03
     +,   4.0806513E-03,   4.3634712E-03,   4.6033990E-03
     +,   4.7933310E-03,   4.9307942E-03,   5.0187712E-03
     +,   5.0665643E-03,   5.0902362E-03,   5.1121707E-03
     +,   5.1593622E-03,   5.2604969E-03,   5.4424871E-03
     +,   5.7273479E-03,   6.1302665E-03,   6.6586542E-03
     +,   7.3106182E-03,   8.0708088E-03,   8.9048957E-03
     +,   9.7593870E-03,   1.0573493E-02,   1.1300022E-02
     +,   1.1918345E-02,   1.2425642E-02,   1.2820484E-02
     +,   1.3119963E-02,   1.3425029E-02,   1.3969198E-02
     +,   1.5045661E-02,   1.6804393E-02,   1.9094061E-02
     +,   2.1551117E-02,   2.3860907E-02,   2.5905471E-02
     +,   2.7790666E-02,   2.9902665E-02,   3.2648262E-02
     +,   3.5775669E-02,   3.8534380E-02,   4.1539099E-02
     +,   4.7240142E-02,   5.5592407E-02,   6.2613338E-02
     +,   6.6128485E-02,   6.8024509E-02,   7.0315823E-02
     +,   7.2179787E-02,   6.8756595E-02,   5.4550190E-02
     +,   3.3031687E-02,   1.4601608E-02,   4.6217171E-03
     +,   1.0342789E-03,   1.6135861E-04,   1.7276179E-05
     +,   1.2520225E-06,   6.1791084E-08,   3.0190059E-09
     +,   9.5803454E-10,   7.8231177E-10,   6.6658939E-10
     +,   5.6839200E-10,   4.8464066E-10,   4.1319598E-10
     +,   3.5224337E-10,   3.0023536E-10,   2.5585570E-10
     +,   2.1798675E-10,   1.8567509E-10,   1.5810647E-10
     +,   1.3458673E-10,   1.1452549E-10,   9.7416970E-11
     +,   8.2829583E-11,   7.0395537E-11,   5.9800463E-11
     +,   5.0775165E-11,   4.3089650E-11,   3.6547893E-11
     +,   3.0982241E-11,   2.6249055E-11,   2.2225650E-11
     +,   1.8807468E-11,   1.5905079E-11,   1.3441960E-11
     +,   1.1352777E-11,   9.5819186E-12,   8.0817748E-12
     +,   6.8117101E-12,   5.7371937E-12,   4.8287355E-12
     +,   4.0611724E-12,   3.4130880E-12,   2.8662875E-12
     +,   2.4052854E-12,   2.0168947E-12,   1.6899056E-12
     +,   1.4148392E-12,   1.1836112E-12,   9.8939541E-13
     +,   8.2638513E-13,   6.8968204E-13,   5.7512431E-13
     +,   4.7920852E-13,   3.9895948E-13,   3.3187762E-13
     +,   2.7584483E-13,   2.2908292E-13,   1.9008868E-13
     +,   1.5759848E-13,   1.3055181E-13,   1.0805450E-13
     +,   8.9358073E-14,   7.3832867E-14,   6.0953026E-14
     +,   5.0276186E-14,   4.1433786E-14,   3.4116773E-14
     +,   2.8067445E-14,   2.3070370E-14,   1.8946448E-14
     +,   1.5545855E-14,   1.2744411E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt117 = Yx/0.282234042553192
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7433506E-06,   1.8576453E-06
     +,   1.9780221E-06,   2.1046992E-06,   2.2378977E-06
     +,   2.3778382E-06,   2.5247409E-06,   2.6788225E-06
     +,   2.8402992E-06,   3.0093886E-06,   3.1862987E-06
     +,   3.3712358E-06,   3.5644016E-06,   3.7659902E-06
     +,   3.9761908E-06,   4.1951848E-06,   4.4231433E-06
     +,   4.6602295E-06,   4.9065961E-06,   5.1623861E-06
     +,   5.4277289E-06,   5.7027401E-06,   5.9875206E-06
     +,   6.2821741E-06,   6.5867557E-06,   6.9013377E-06
     +,   7.2259618E-06,   7.5606522E-06,   7.9054225E-06
     +,   8.2602628E-06,   8.6251530E-06,   9.0000476E-06
     +,   9.3848930E-06,   9.7796146E-06,   1.0184119E-05
     +,   1.0598299E-05,   1.1022033E-05,   1.1455176E-05
     +,   1.1897602E-05,   1.2349115E-05,   1.2809560E-05
     +,   1.3278746E-05,   1.3756478E-05,   1.4242552E-05
     +,   1.4736763E-05,   1.5238892E-05,   1.5748721E-05
     +,   1.6266040E-05,   1.6790626E-05,   1.7322256E-05
     +,   1.7860722E-05,   1.8405819E-05,   1.8957326E-05
     +,   1.9515084E-05,   2.0078858E-05,   2.0648507E-05
     +,   2.1223857E-05,   2.1804750E-05,   2.2391037E-05
     +,   2.2982604E-05,   2.3579325E-05,   2.4181116E-05
     +,   2.4787862E-05,   2.5399517E-05,   2.6016054E-05
     +,   2.6637401E-05,   2.7263583E-05,   2.7894592E-05
     +,   2.8530485E-05,   2.9171302E-05,   2.9817180E-05
     +,   3.0468220E-05,   3.1124648E-05,   3.1786636E-05
     +,   3.2454482E-05,   3.3128592E-05,   3.3809330E-05
     +,   3.4497203E-05,   3.5192836E-05,   3.5896959E-05
     +,   3.6610341E-05,   3.7334026E-05,   3.8069058E-05
     +,   3.8816757E-05,   3.9578528E-05,   4.0356052E-05
     +,   4.1151088E-05,   4.1965730E-05,   4.2802159E-05
     +,   4.3662840E-05,   4.4550459E-05,   4.5467848E-05
     +,   4.6418012E-05,   4.7404232E-05,   4.8429909E-05
     +,   4.9498500E-05,   5.0613678E-05,   5.1779058E-05
     +,   5.2998399E-05,   5.4275322E-05,   5.5613491E-05
     +,   5.7016325E-05,   5.8487218E-05,   6.0029204E-05
     +,   6.1645209E-05,   6.3337888E-05,   6.5109554E-05
     +,   6.6962202E-05,   6.8897702E-05,   7.0917849E-05
     +,   7.3024043E-05,   7.5218071E-05,   7.7501660E-05
     +,   7.9877267E-05,   8.2347862E-05,   8.4917818E-05
     +,   8.7592714E-05,   9.0380548E-05,   9.3291717E-05
     +,   9.6340191E-05,   9.9544290E-05,   1.0292716E-04
     +,   1.0651814E-04,   1.1035407E-04,   1.1448008E-04
     +,   1.1895060E-04,   1.2383105E-04,   1.2919797E-04
     +,   1.3514061E-04,   1.4176009E-04,   1.4917049E-04
     +,   1.5749624E-04,   1.6687215E-04,   1.7743844E-04
     +,   1.8933872E-04,   2.0271476E-04,   2.1769878E-04
     +,   2.3440765E-04,   2.5293670E-04,   2.7335156E-04
     +,   2.9567943E-04,   3.1990500E-04,   3.4596844E-04
     +,   3.7376297E-04,   4.0313532E-04,   4.3389780E-04
     +,   4.6583766E-04,   4.9873115E-04,   5.3236540E-04
     +,   5.6656572E-04,   6.0121599E-04,   6.3628348E-04
     +,   6.7183783E-04,   7.0806779E-04,   7.4528047E-04
     +,   7.8388490E-04,   8.2436594E-04,   8.6724316E-04
     +,   9.1300876E-04,   9.6206000E-04,   1.0146417E-03
     +,   1.0707920E-03,   1.1303086E-03,   1.1927600E-03
     +,   1.2575386E-03,   1.3239448E-03,   1.3913163E-03
     +,   1.4591758E-03,   1.5273892E-03,   1.5962893E-03
     +,   1.6667505E-03,   1.7401943E-03,   1.8185164E-03
     +,   1.9038933E-03,   1.9984997E-03,   2.1041504E-03
     +,   2.2218667E-03,   2.3514600E-03,   2.4912343E-03
     +,   2.6379975E-03,   2.7874855E-03,   2.9353586E-03
     +,   3.0787317E-03,   3.2179225E-03,   3.3578966E-03
     +,   3.5088127E-03,   3.6852239E-03,   3.9039655E-03
     +,   4.1812453E-03,   4.5298440E-03,   4.9573276E-03
     +,   5.4654279E-03,   6.0504889E-03,   6.7047733E-03
     +,   7.4174921E-03,   8.1740730E-03,   8.9534083E-03
     +,   9.7277742E-03,   1.0472316E-02,   1.1182771E-02
     +,   1.1884790E-02,   1.2616471E-02,   1.3390667E-02
     +,   1.4173429E-02,   1.4906089E-02,   1.5550886E-02
     +,   1.6104313E-02,   1.6567457E-02,   1.6963432E-02
     +,   1.7466389E-02,   1.8494068E-02,   2.0576023E-02
     +,   2.4045520E-02,   2.8633598E-02,   3.3232316E-02
     +,   3.6617711E-02,   3.8568012E-02,   3.9629959E-02
     +,   4.0549569E-02,   4.2173207E-02,   4.5131318E-02
     +,   4.9760297E-02,   5.5132654E-02,   5.8807887E-02
     +,   5.8280770E-02,   5.1287081E-02,   3.7905484E-02
     +,   2.2584876E-02,   1.0599266E-02,   3.8447650E-03
     +,   1.0556206E-03,   2.1514924E-04,   3.2112806E-05
     +,   3.4925224E-06,   2.8447559E-07,   2.5376812E-08
     +,   9.3352730E-09,   7.7036697E-09,   6.7849584E-09
     +,   5.9838507E-09,   5.2722515E-09,   4.6405231E-09
     +,   4.0802948E-09,   3.5839862E-09,   3.1447536E-09
     +,   2.7564651E-09,   2.4135947E-09,   2.1111473E-09
     +,   1.8446396E-09,   1.6100761E-09,   1.4038491E-09
     +,   1.2227291E-09,   1.0638430E-09,   9.2461894E-10
     +,   8.0275714E-10,   6.9620815E-10,   6.0315403E-10
     +,   5.2197985E-10,   4.5124660E-10,   3.8967729E-10
     +,   3.3614722E-10,   2.8966052E-10,   2.4933447E-10
     +,   2.1439016E-10,   1.8414612E-10,   1.5799843E-10
     +,   1.3541679E-10,   1.1593754E-10,   9.9153782E-11
     +,   8.4708414E-11,   7.2289161E-11,   6.1624171E-11
     +,   5.2476298E-11,   4.4638137E-11,   3.7929569E-11
     +,   3.2194622E-11,   2.7297170E-11,   2.3119841E-11
     +,   1.9560541E-11,   1.6531420E-11,   1.3956230E-11
     +,   1.1769521E-11,   9.9146776E-12,   8.3431595E-12
     +,   7.0131158E-12,   5.8887799E-12,   4.9393493E-12
     +,   4.1384929E-12,   3.4637581E-12,   2.8958873E-12
     +,   2.4185096E-12,   2.0176337E-12,   1.6813960E-12
     +,   1.3996711E-12,   1.1638965E-12,   9.6678633E-13
     +,   8.0219468E-13,   6.6490086E-13,   5.5051135E-13
     +,   4.5530653E-13,   3.7616234E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt118 = Yx/0.241195652173913
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3724827E-06,   7.3630472E-06
     +,   7.3509527E-06,   7.3364795E-06,   7.3199249E-06
     +,   7.3016067E-06,   7.2818671E-06,   7.2610687E-06
     +,   7.2395933E-06,   7.2178377E-06,   7.1962245E-06
     +,   7.1751938E-06,   7.1552017E-06,   7.1367240E-06
     +,   7.1202503E-06,   7.1062923E-06,   7.0953702E-06
     +,   7.0880228E-06,   7.0847977E-06,   7.0862602E-06
     +,   7.0929814E-06,   7.1055415E-06,   7.1245295E-06
     +,   7.1505428E-06,   7.1841805E-06,   7.2260423E-06
     +,   7.2767320E-06,   7.3368519E-06,   7.4069962E-06
     +,   7.4877603E-06,   7.5797234E-06,   7.6834613E-06
     +,   7.7995319E-06,   7.9284755E-06,   8.0708196E-06
     +,   8.2270672E-06,   8.3976965E-06,   8.5831543E-06
     +,   8.7838698E-06,   9.0002241E-06,   9.2325718E-06
     +,   9.4812258E-06,   9.7464535E-06,   1.0028483E-05
     +,   1.0327495E-05,   1.0643616E-05,   1.0976918E-05
     +,   1.1327429E-05,   1.1695114E-05,   1.2079880E-05
     +,   1.2481578E-05,   1.2899997E-05,   1.3334867E-05
     +,   1.3785873E-05,   1.4252616E-05,   1.4734667E-05
     +,   1.5231539E-05,   1.5742691E-05,   1.6267544E-05
     +,   1.6805483E-05,   1.7355873E-05,   1.7918061E-05
     +,   1.8491355E-05,   1.9075129E-05,   1.9668767E-05
     +,   2.0271651E-05,   2.0883293E-05,   2.1503231E-05
     +,   2.2131180E-05,   2.2766935E-05,   2.3410543E-05
     +,   2.4062176E-05,   2.4722356E-05,   2.5391799E-05
     +,   2.6071633E-05,   2.6763373E-05,   2.7468919E-05
     +,   2.8190656E-05,   2.8931538E-05,   2.9695113E-05
     +,   3.0485475E-05,   3.1307489E-05,   3.2166619E-05
     +,   3.3069180E-05,   3.4022112E-05,   3.5033245E-05
     +,   3.6111047E-05,   3.7264828E-05,   3.8504462E-05
     +,   3.9840557E-05,   4.1284282E-05,   4.2847103E-05
     +,   4.4540837E-05,   4.6377460E-05,   4.8368958E-05
     +,   5.0526829E-05,   5.2862339E-05,   5.5385684E-05
     +,   5.8106358E-05,   6.1032195E-05,   6.4169821E-05
     +,   6.7523513E-05,   7.1095987E-05,   7.4887044E-05
     +,   7.8894256E-05,   8.3112624E-05,   8.7533961E-05
     +,   9.2147333E-05,   9.6939351E-05,   1.0189408E-04
     +,   1.0699277E-04,   1.1221545E-04,   1.1754001E-04
     +,   1.2294417E-04,   1.2840489E-04,   1.3390042E-04
     +,   1.3940998E-04,   1.4491590E-04,   1.5040347E-04
     +,   1.5586296E-04,   1.6129020E-04,   1.6668718E-04
     +,   1.7206316E-04,   1.7743588E-04,   1.8283159E-04
     +,   1.8828492E-04,   1.9384007E-04,   1.9954929E-04
     +,   2.0547367E-04,   2.1168073E-04,   2.1824504E-04
     +,   2.2524488E-04,   2.3276221E-04,   2.4087942E-04
     +,   2.4967844E-04,   2.5923888E-04,   2.6963578E-04
     +,   2.8093907E-04,   2.9321408E-04,   3.0652274E-04
     +,   3.2092404E-04,   3.3647972E-04,   3.5326040E-04
     +,   3.7135350E-04,   3.9087032E-04,   4.1196204E-04
     +,   4.3483076E-04,   4.5974320E-04,   4.8704635E-04
     +,   5.1718432E-04,   5.5070955E-04,   5.8828905E-04
     +,   6.3070527E-04,   6.7884789E-04,   7.3368032E-04
     +,   7.9618243E-04,   8.6726976E-04,   9.4768702E-04
     +,   1.0378684E-03,   1.1377807E-03,   1.2467970E-03
     +,   1.3635879E-03,   1.4860725E-03,   1.6114806E-03
     +,   1.7365279E-03,   1.8576853E-03,   1.9715319E-03
     +,   2.0751790E-03,   2.1666812E-03,   2.2453621E-03
     +,   2.3120414E-03,   2.3691275E-03,   2.4205695E-03
     +,   2.4716342E-03,   2.5285538E-03,   2.5980233E-03
     +,   2.6865778E-03,   2.7998888E-03,   2.9421563E-03
     +,   3.1157427E-03,   3.3211773E-03,   3.5575002E-03
     +,   3.8227788E-03,   4.1144523E-03,   4.4291457E-03
     +,   4.7621015E-03,   5.1066740E-03,   5.4545789E-03
     +,   5.7973112E-03,   6.1289691E-03,   6.4500612E-03
     +,   6.7708222E-03,   7.1120667E-03,   7.5012012E-03
     +,   7.9632830E-03,   8.5109733E-03,   9.1401422E-03
     +,   9.8344721E-03,   1.0575621E-02,   1.1353437E-02
     +,   1.2176901E-02,   1.3088548E-02,   1.4169556E-02
     +,   1.5500627E-02,   1.7066061E-02,   1.8686077E-02
     +,   2.0099161E-02,   2.1138376E-02,   2.1775929E-02
     +,   2.2028990E-02,   2.2001684E-02,   2.2084482E-02
     +,   2.2888407E-02,   2.4727687E-02,   2.7295645E-02
     +,   3.0138185E-02,   3.3122957E-02,   3.6105722E-02
     +,   3.8751230E-02,   4.0895719E-02,   4.2637281E-02
     +,   4.4243224E-02,   4.5750376E-02,   4.6315528E-02
     +,   4.4426449E-02,   3.8934138E-02,   3.0138534E-02
     +,   2.0036301E-02,   1.1179416E-02,   5.1327636E-03
     +,   1.9072384E-03,   5.6620251E-04,   1.3304589E-04
     +,   2.4592686E-05,   3.5666505E-06,   4.0976050E-07
     +,   4.2010054E-08,   8.1927487E-09,   5.2027556E-09
     +,   4.4737365E-09,   3.9338119E-09,   3.4605927E-09
     +,   3.0423082E-09,   2.6726634E-09,   2.3461968E-09
     +,   2.0580575E-09,   1.8039261E-09,   1.5799378E-09
     +,   1.3826533E-09,   1.2090282E-09,   1.0563351E-09
     +,   9.2215269E-10,   8.0433338E-10,   7.0097095E-10
     +,   6.1036159E-10,   5.3099730E-10,   4.6154561E-10
     +,   4.0082140E-10,   3.4777459E-10,   3.0147335E-10
     +,   2.6109848E-10,   2.2592493E-10,   1.9530942E-10
     +,   1.6868527E-10,   1.4555583E-10,   1.2548004E-10
     +,   1.0807125E-10,   9.2990116E-11,   7.9938195E-11
     +,   6.8653000E-11,   5.8904645E-11,   5.0492322E-11
     +,   4.3240283E-11,   3.6994310E-11,   3.1620068E-11
     +,   2.7000655E-11,   2.3033820E-11,   1.9630931E-11
     +,   1.6714534E-11,   1.4217713E-11,   1.2082086E-11
     +,   1.0257362E-11,   8.6997284E-12,   7.3715114E-12
     +,   6.2399751E-12,   5.2770223E-12,   4.4583356E-12
     +,   3.7629682E-12,   3.1729842E-12,   2.6728799E-12
     +,   2.2494144E-12,   1.8911817E-12,   1.5884568E-12
     +,   1.3328796E-12,   1.1173369E-12,   9.3572958E-13
     +,   7.8287778E-13,   6.5435157E-13,   5.4639279E-13
     +,   4.5579675E-13,   3.7985243E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt119 = Yx/0.233739130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5291755E-09,   1.8394986E-09
     +,   2.2089486E-09,   2.6479934E-09,   3.1687861E-09
     +,   3.7854222E-09,   4.5142072E-09,   5.3739613E-09
     +,   6.3863550E-09,   7.5763502E-09,   8.9725143E-09
     +,   1.0607578E-08,   1.2518924E-08,   1.4749144E-08
     +,   1.7346681E-08,   2.0366503E-08,   2.3870836E-08
     +,   2.7929996E-08,   3.2623234E-08,   3.8039680E-08
     +,   4.4279361E-08,   5.1454300E-08,   5.9689469E-08
     +,   6.9124823E-08,   7.9914876E-08,   9.2232298E-08
     +,   1.0626754E-07,   1.2223113E-07,   1.4035521E-07
     +,   1.6089484E-07,   1.8413019E-07,   2.1036760E-07
     +,   2.3994170E-07,   2.7321718E-07,   3.1059039E-07
     +,   3.5249124E-07,   3.9938470E-07,   4.5177222E-07
     +,   5.1019714E-07,   5.7523692E-07,   6.4751742E-07
     +,   7.2770393E-07,   8.1650768E-07,   9.1468576E-07
     +,   1.0230424E-06,   1.1424299E-06,   1.2737501E-06
     +,   1.4179533E-06,   1.5760412E-06,   1.7490653E-06
     +,   1.9381268E-06,   2.1443798E-06,   2.3690209E-06
     +,   2.6133150E-06,   2.8785462E-06,   3.1660734E-06
     +,   3.4772872E-06,   3.8136263E-06,   4.1765716E-06
     +,   4.5676438E-06,   4.9884020E-06,   5.4404491E-06
     +,   5.9253862E-06,   6.4448832E-06,   7.0006358E-06
     +,   7.5943062E-06,   8.2276447E-06,   8.9023333E-06
     +,   9.6201411E-06,   1.0382743E-05,   1.1191897E-05
     +,   1.2049246E-05,   1.2956510E-05,   1.3915256E-05
     +,   1.4927094E-05,   1.5993581E-05,   1.7116132E-05
     +,   1.8296072E-05,   1.9534707E-05,   2.0833235E-05
     +,   2.2192591E-05,   2.3613753E-05,   2.5097348E-05
     +,   2.6644013E-05,   2.8254008E-05,   2.9927565E-05
     +,   3.1664509E-05,   3.3464639E-05,   3.5327270E-05
     +,   3.7251641E-05,   3.9236766E-05,   4.1281222E-05
     +,   4.3383399E-05,   4.5541532E-05,   4.7753681E-05
     +,   5.0017537E-05,   5.2330906E-05,   5.4691289E-05
     +,   5.7096444E-05,   5.9543989E-05,   6.2032050E-05
     +,   6.4558786E-05,   6.7123219E-05,   6.9724716E-05
     +,   7.2363851E-05,   7.5042240E-05,   7.7762816E-05
     +,   8.0530030E-05,   8.3350504E-05,   8.6232991E-05
     +,   8.9188463E-05,   9.2230999E-05,   9.5377145E-05
     +,   9.8647070E-05,   1.0206372E-04,   1.0565380E-04
     +,   1.0944682E-04,   1.1347595E-04,   1.1777672E-04
     +,   1.2238766E-04,   1.2734938E-04,   1.3270392E-04
     +,   1.3849419E-04,   1.4476389E-04,   1.5155673E-04
     +,   1.5891512E-04,   1.6688147E-04,   1.7549605E-04
     +,   1.8479938E-04,   1.9483018E-04,   2.0562846E-04
     +,   2.1723376E-04,   2.2968923E-04,   2.4303909E-04
     +,   2.5733290E-04,   2.7262457E-04,   2.8897272E-04
     +,   3.0644002E-04,   3.2509561E-04,   3.4501255E-04
     +,   3.6626728E-04,   3.8894071E-04,   4.1312235E-04
     +,   4.3891181E-04,   4.6642375E-04,   4.9579929E-04
     +,   5.2721426E-04,   5.6088652E-04,   5.9708336E-04
     +,   6.3612644E-04,   6.7838031E-04,   7.2422769E-04
     +,   7.7403535E-04,   8.2810404E-04,   8.8659953E-04
     +,   9.4947428E-04,   1.0163978E-03,   1.0867039E-03
     +,   1.1593559E-03,   1.2329487E-03,   1.3057832E-03
     +,   1.3759659E-03,   1.4415738E-03,   1.5008579E-03
     +,   1.5524778E-03,   1.5957389E-03,   1.6308111E-03
     +,   1.6589341E-03,   1.6825638E-03,   1.7054453E-03
     +,   1.7326160E-03,   1.7703002E-03,   1.8256897E-03
     +,   1.9066028E-03,   2.0209744E-03,   2.1762471E-03
     +,   2.3786013E-03,   2.6321001E-03,   2.9378736E-03
     +,   3.2935019E-03,   3.6927403E-03,   4.1258098E-03
     +,   4.5804251E-03,   5.0436351E-03,   5.5042976E-03
     +,   5.9556453E-03,   6.3965940E-03,   6.8299603E-03
     +,   7.2570047E-03,   7.6710382E-03,   8.0555538E-03
     +,   8.3907731E-03,   8.6669521E-03,   8.8967346E-03
     +,   9.1188457E-03,   9.3913516E-03,   9.7777797E-03
     +,   1.0328124E-02,   1.1056784E-02,   1.1926167E-02
     +,   1.2852347E-02,   1.3734324E-02,   1.4483866E-02
     +,   1.5041300E-02,   1.5398113E-02,   1.5629217E-02
     +,   1.5879054E-02,   1.6294733E-02,   1.7014395E-02
     +,   1.8240089E-02,   2.0161761E-02,   2.2611460E-02
     +,   2.5028531E-02,   2.7186042E-02,   2.9460724E-02
     +,   3.1811383E-02,   3.3638768E-02,   3.5105847E-02
     +,   3.6858451E-02,   3.8782164E-02,   4.0408876E-02
     +,   4.1414279E-02,   4.1596439E-02,   4.0755972E-02
     +,   3.7963215E-02,   3.2107402E-02,   2.3698203E-02
     +,   1.4931690E-02,   7.9375124E-03,   3.5241656E-03
     +,   1.2922444E-03,   3.8712315E-04,   9.3955750E-05
     +,   1.8376770E-05,   2.8890995E-06,   3.6470973E-07
     +,   3.7001136E-08,   3.0615606E-09,   2.4471555E-10
     +,   4.9292456E-11,   3.1358735E-11,   2.4458605E-11
     +,   1.9296112E-11,   1.5215018E-11,   1.1984225E-11
     +,   9.4292343E-12,   7.4109573E-12,   5.8183332E-12
     +,   4.5629238E-12,   3.5744786E-12,   2.7970499E-12
     +,   2.1862475E-12,   1.7069057E-12,   1.3311586E-12
     +,   1.0369375E-12,   8.0680596E-13,   6.2701553E-13
     +,   4.8672031E-13,   3.7736489E-13,   2.9222520E-13
     +,   2.2601911E-13,   1.7459864E-13,   1.3470914E-13
     +,   1.0380135E-13,   7.9883969E-14,   6.1398776E-14
     +,   4.7129327E-14,   3.6128750E-14,   2.7659402E-14
     +,   2.1147096E-14,   1.6146140E-14,   1.2311006E-14
     +,   9.3739705E-15,   7.1277221E-15,   5.4120874E-15
     +,   4.1036303E-15,   3.1070494E-15,   2.3491356E-15
     +,   1.7735148E-15,   1.3369992E-15,   1.0064351E-15
     +,   7.5648470E-16,   5.6775914E-16,   4.2548193E-16
     +,   3.1837419E-16,   2.3787044E-16,   1.7745110E-16
     +,   1.3217432E-16,   9.8299146E-17,   7.2991966E-17
     +,   5.4116220E-17,   4.0058637E-17,   2.9606478E-17
     +,   2.1846803E-17,   1.6095502E-17,   1.1839318E-17
     +,   8.6948106E-18,   6.3752063E-18,   4.6669787E-18
     +,   3.4109243E-18,   2.4889201E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt120 = Yx/0.222478260869565
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.7849488E-06,   9.9492909E-06
     +,   1.0121247E-05,   1.0301701E-05,   1.0491624E-05
     +,   1.0692084E-05,   1.0904253E-05,   1.1129404E-05
     +,   1.1368931E-05,   1.1624355E-05,   1.1897321E-05
     +,   1.2189614E-05,   1.2503157E-05,   1.2840028E-05
     +,   1.3202458E-05,   1.3592840E-05,   1.4013725E-05
     +,   1.4467838E-05,   1.4958074E-05,   1.5487489E-05
     +,   1.6059323E-05,   1.6676959E-05,   1.7343955E-05
     +,   1.8064053E-05,   1.8841069E-05,   1.9679032E-05
     +,   2.0582040E-05,   2.1554319E-05,   2.2600163E-05
     +,   2.3723931E-05,   2.4930019E-05,   2.6222819E-05
     +,   2.7606698E-05,   2.9085959E-05,   3.0664789E-05
     +,   3.2347241E-05,   3.4137185E-05,   3.6038189E-05
     +,   3.8053691E-05,   4.0186569E-05,   4.2439548E-05
     +,   4.4814773E-05,   4.7313995E-05,   4.9938415E-05
     +,   5.2688702E-05,   5.5564979E-05,   5.8566748E-05
     +,   6.1692932E-05,   6.4941909E-05,   6.8311419E-05
     +,   7.1798742E-05,   7.5400705E-05,   7.9113692E-05
     +,   8.2934072E-05,   8.6857726E-05,   9.0880982E-05
     +,   9.5000214E-05,   9.9212331E-05,   1.0351495E-04
     +,   1.0790685E-04,   1.1238809E-04,   1.1696050E-04
     +,   1.2162774E-04,   1.2639629E-04,   1.3127550E-04
     +,   1.3627742E-04,   1.4141845E-04,   1.4671839E-04
     +,   1.5220197E-04,   1.5789806E-04,   1.6384112E-04
     +,   1.7007017E-04,   1.7663043E-04,   1.8357193E-04
     +,   1.9095078E-04,   1.9882905E-04,   2.0727402E-04
     +,   2.1635840E-04,   2.2616147E-04,   2.3676842E-04
     +,   2.4826950E-04,   2.6076339E-04,   2.7435456E-04
     +,   2.8915852E-04,   3.0530037E-04,   3.2292143E-04
     +,   3.4217918E-04,   3.6325731E-04,   3.8636746E-04
     +,   4.1176134E-04,   4.3973868E-04,   4.7065460E-04
     +,   5.0493155E-04,   5.4306810E-04,   5.8564416E-04
     +,   6.3331251E-04,   6.8679888E-04,   7.4686599E-04
     +,   8.1428804E-04,   8.8978029E-04,   9.7394874E-04
     +,   1.0671958E-03,   1.1696770E-03,   1.2812347E-03
     +,   1.4014313E-03,   1.5296290E-03,   1.6651630E-03
     +,   1.8076297E-03,   1.9572673E-03,   2.1153323E-03
     +,   2.2844176E-03,   2.4686167E-03,   2.6733223E-03
     +,   2.9047644E-03,   3.1692283E-03,   3.4724446E-03
     +,   3.8193753E-03,   4.2149755E-03,   4.6655461E-03
     +,   5.1801754E-03,   5.7704705E-03,   6.4472770E-03
     +,   7.2142957E-03,   8.0609284E-03,   8.9592505E-03
     +,   9.8708710E-03,   1.0765779E-02,   1.1646572E-02
     +,   1.2564957E-02,   1.3615976E-02,   1.4908482E-02
     +,   1.6524369E-02,   1.8485466E-02,   2.0733818E-02
     +,   2.3126213E-02,   2.5452051E-02,   2.7502667E-02
     +,   2.9182544E-02,   3.0572973E-02,   3.1880621E-02
     +,   3.3338077E-02,   3.5119902E-02,   3.7244391E-02
     +,   3.9580494E-02,   4.2121463E-02,   4.5065876E-02
     +,   4.8127439E-02,   5.0242197E-02,   5.0953310E-02
     +,   5.1348679E-02,   5.2495997E-02,   5.3773943E-02
     +,   5.4005396E-02,   5.3359032E-02,   5.2626107E-02
     +,   5.1642545E-02,   4.9488232E-02,   4.5703713E-02
     +,   4.0988125E-02,   3.6531352E-02,   3.2813106E-02
     +,   2.9513530E-02,   2.6326559E-02,   2.3363836E-02
     +,   2.0912325E-02,   1.9109575E-02,   1.7851369E-02
     +,   1.6896237E-02,   1.6022630E-02,   1.5121400E-02
     +,   1.4188159E-02,   1.3259106E-02,   1.2357174E-02
     +,   1.1480408E-02,   1.0619717E-02,   9.7770393E-03
     +,   8.9693163E-03,   8.2197972E-03,   7.5469683E-03
     +,   6.9582192E-03,   6.4502945E-03,   6.0135019E-03
     +,   5.6362101E-03,   5.3076902E-03,   5.0190375E-03
     +,   4.7628754E-03,   4.5325919E-03,   4.3218816E-03
     +,   4.1247816E-03,   3.9360672E-03,   3.7517806E-03
     +,   3.5696742E-03,   3.3893867E-03,   3.2122317E-03
     +,   3.0406443E-03,   2.8775483E-03,   2.7256748E-03
     +,   2.5870425E-03,   2.4626481E-03,   2.3524158E-03
     +,   2.2553441E-03,   2.1697623E-03,   2.0936248E-03
     +,   2.0248194E-03,   1.9613879E-03,   1.9016489E-03
     +,   1.8442622E-03,   1.7882144E-03,   1.7327594E-03
     +,   1.6773345E-03,   1.6214993E-03,   1.5648787E-03
     +,   1.5071305E-03,   1.4479421E-03,   1.3870404E-03
     +,   1.3242314E-03,   1.2594231E-03,   1.1926515E-03
     +,   1.1240982E-03,   1.0541022E-03,   9.8313484E-04
     +,   9.1178011E-04,   8.4070629E-04,   7.7062158E-04
     +,   7.0222450E-04,   6.3617452E-04,   5.7306088E-04
     +,   5.1337481E-04,   4.5748957E-04,   4.0565984E-04
     +,   3.5802685E-04,   3.1462248E-04,   2.7538088E-04
     +,   2.4015873E-04,   2.0875531E-04,   1.8092344E-04
     +,   1.5638921E-04,   1.3486753E-04,   1.1607114E-04
     +,   9.9718665E-05,   8.5542611E-05,   7.3294214E-05
     +,   6.2744431E-05,   5.3684496E-05,   4.5926688E-05
     +,   3.9303781E-05,   3.3667096E-05,   2.8884666E-05
     +,   2.4840187E-05,   2.1431688E-05,   1.8569270E-05
     +,   1.6174206E-05,   1.4177804E-05,   1.2520120E-05
     +,   1.1148898E-05,   1.0018859E-05,   9.0909598E-06
     +,   8.3316063E-06,   7.7119548E-06,   7.2074599E-06
     +,   6.7973324E-06,   6.4640340E-06,   6.1928413E-06
     +,   5.9714912E-06,   5.7898415E-06,   5.6395238E-06
     +,   5.5136943E-06,   5.4068032E-06,   5.3143663E-06
     +,   5.2327850E-06,   5.1591974E-06,   5.0913477E-06
     +,   5.0274684E-06,   4.9661880E-06,   4.9064492E-06
     +,   4.8474576E-06,   4.7886119E-06,   4.7294761E-06
     +,   4.6697323E-06,   4.6091668E-06,   4.5476322E-06
     +,   4.4850462E-06,   4.4213639E-06,   4.3565828E-06
     +,   4.2907141E-06,   4.2237980E-06,   4.1558837E-06
     +,   4.0870264E-06,   4.0172995E-06,   3.9467727E-06
     +,   3.8755247E-06,   3.8036305E-06,   3.7311752E-06
     +,   3.6582351E-06,   3.5848957E-06,   3.5112332E-06
     +,   3.4373327E-06,   3.3632680E-06,   3.2891217E-06
     +,   3.2149649E-06,   3.1408788E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt75 = Yx/0.41216
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4929529E-05,   1.5423553E-05
     +,   1.5924988E-05,   1.6433783E-05,   1.6949889E-05
     +,   1.7473294E-05,   1.8004002E-05,   1.8542047E-05
     +,   1.9087483E-05,   1.9640409E-05,   2.0200936E-05
     +,   2.0769203E-05,   2.1345386E-05,   2.1929682E-05
     +,   2.2522318E-05,   2.3123539E-05,   2.3733623E-05
     +,   2.4352861E-05,   2.4981564E-05,   2.5620060E-05
     +,   2.6268675E-05,   2.6927764E-05,   2.7597660E-05
     +,   2.8278737E-05,   2.8971315E-05,   2.9675764E-05
     +,   3.0392426E-05,   3.1121624E-05,   3.1863729E-05
     +,   3.2619075E-05,   3.3388034E-05,   3.4171007E-05
     +,   3.4968449E-05,   3.5780868E-05,   3.6608901E-05
     +,   3.7453294E-05,   3.8315018E-05,   3.9195253E-05
     +,   4.0095565E-05,   4.1017811E-05,   4.1964475E-05
     +,   4.2938544E-05,   4.3943808E-05,   4.4984896E-05
     +,   4.6067533E-05,   4.7198617E-05,   4.8386493E-05
     +,   4.9641123E-05,   5.0974275E-05,   5.2399773E-05
     +,   5.3933683E-05,   5.5594526E-05,   5.7403406E-05
     +,   5.9384278E-05,   6.1563711E-05,   6.3971383E-05
     +,   6.6639645E-05,   6.9603419E-05,   7.2900155E-05
     +,   7.6569158E-05,   8.0651327E-05,   8.5188381E-05
     +,   9.0221889E-05,   9.5792864E-05,   1.0194067E-04
     +,   1.0870122E-04,   1.1610720E-04,   1.2418575E-04
     +,   1.3295888E-04,   1.4244110E-04,   1.5264093E-04
     +,   1.6355848E-04,   1.7518824E-04,   1.8751722E-04
     +,   2.0052856E-04,   2.1420265E-04,   2.2851843E-04
     +,   2.4345693E-04,   2.5900584E-04,   2.7516170E-04
     +,   2.9193200E-04,   3.0934130E-04,   3.2742997E-04
     +,   3.4625939E-04,   3.6590773E-04,   3.8647279E-04
     +,   4.0806408E-04,   4.3080159E-04,   4.5480419E-04
     +,   4.8018491E-04,   5.0703861E-04,   5.3542969E-04
     +,   5.6538283E-04,   5.9687457E-04,   6.2982575E-04
     +,   6.6409068E-04,   6.9946604E-04,   7.3568273E-04
     +,   7.7242439E-04,   8.0932811E-04,   8.4601046E-04
     +,   8.8207662E-04,   9.1714907E-04,   9.5088169E-04
     +,   9.8298769E-04,   1.0132556E-03,   1.0415635E-03
     +,   1.0678973E-03,   1.0923631E-03,   1.1151903E-03
     +,   1.1367422E-03,   1.1575226E-03,   1.1781779E-03
     +,   1.1995116E-03,   1.2224872E-03,   1.2482466E-03
     +,   1.2781136E-03,   1.3136154E-03,   1.3564824E-03
     +,   1.4086735E-03,   1.4723934E-03,   1.5501322E-03
     +,   1.6447487E-03,   1.7596108E-03,   1.8987851E-03
     +,   2.0672653E-03,   2.2712620E-03,   2.5183847E-03
     +,   2.8177833E-03,   3.1799269E-03,   3.6160140E-03
     +,   4.1363598E-03,   4.7478694E-03,   5.4504736E-03
     +,   6.2349793E-03,   7.0853098E-03,   7.9887910E-03
     +,   8.9534689E-03,   1.0022054E-02,   1.1264695E-02
     +,   1.2743448E-02,   1.4472962E-02,   1.6420014E-02
     +,   1.8548675E-02,   2.0870926E-02,   2.3504233E-02
     +,   2.6772348E-02,   3.1187994E-02,   3.7002429E-02
     +,   4.3580182E-02,   4.9512450E-02,   5.3756230E-02
     +,   5.6615386E-02,   5.9070066E-02,   6.1491445E-02
     +,   6.3765287E-02,   6.5987259E-02,   6.8434760E-02
     +,   7.1137585E-02,   7.3386580E-02,   7.3931463E-02
     +,   7.0975259E-02,   6.4454518E-02,   5.8246873E-02
     +,   5.4469660E-02,   5.0887130E-02,   4.5939323E-02
     +,   4.0264618E-02,   3.4846459E-02,   3.0237552E-02
     +,   2.6526062E-02,   2.3578931E-02,   2.1280862E-02
     +,   1.9480702E-02,   1.7944114E-02,   1.6457047E-02
     +,   1.4930291E-02,   1.3407044E-02,   1.1992967E-02
     +,   1.0778948E-02,   9.8043606E-03,   9.0590734E-03
     +,   8.5011218E-03,   8.0744307E-03,   7.7228993E-03
     +,   7.4012289E-03,   7.0811589E-03,   6.7521036E-03
     +,   6.4168903E-03,   6.0849926E-03,   5.7660816E-03
     +,   5.4659466E-03,   5.1852632E-03,   4.9205767E-03
     +,   4.6665003E-03,   4.4179279E-03,   4.1715559E-03
     +,   3.9264071E-03,   3.6835650E-03,   3.4454935E-03
     +,   3.2152678E-03,   2.9958864E-03,   2.7897642E-03
     +,   2.5984568E-03,   2.4225533E-03,   2.2616463E-03
     +,   2.1144678E-03,   1.9791189E-03,   1.8533408E-03
     +,   1.7348141E-03,   1.6214534E-03,   1.5116346E-03
     +,   1.4043133E-03,   1.2990510E-03,   1.1959575E-03
     +,   1.0955747E-03,   9.9870679E-04,   9.0624864E-04
     +,   8.1904902E-04,   7.3780731E-04,   6.6298957E-04
     +,   5.9481047E-04,   5.3324812E-04,   4.7806845E-04
     +,   4.2887201E-04,   3.8515066E-04,   3.4634111E-04
     +,   3.1186515E-04,   2.8116134E-04,   2.5371319E-04
     +,   2.2906350E-04,   2.0681905E-04,   1.8664931E-04
     +,   1.6828356E-04,   1.5150552E-04,   1.3614155E-04
     +,   1.2205416E-04,   1.0913463E-04,   9.7295284E-05
     +,   8.6462562E-05,   7.6573328E-05,   6.7571971E-05
     +,   5.9406804E-05,   5.2027823E-05,   4.5386274E-05
     +,   3.9434370E-05,   3.4124536E-05,   2.9409135E-05
     +,   2.5241121E-05,   2.1574695E-05,   1.8364803E-05
     +,   1.5568015E-05,   1.3142954E-05,   1.1050347E-05
     +,   9.2531600E-06,   7.7169507E-06,   6.4100273E-06
     +,   5.3033637E-06,   4.3705431E-06,   3.5877943E-06
     +,   2.9339303E-06,   2.3901473E-06,   1.9398553E-06
     +,   1.5685565E-06,   1.2636956E-06,   1.0144054E-06
     +,   8.1137512E-07,   6.4668393E-07,   5.1361883E-07
     +,   4.0651634E-07,   3.2063511E-07,   2.5203070E-07
     +,   1.9743111E-07,   1.5413451E-07,   1.1992408E-07
     +,   9.2991506E-08,   7.1862637E-08,   5.5346561E-08
     +,   4.2480959E-08,   3.2494924E-08,   2.4770756E-08
     +,   1.8817598E-08,   1.4245319E-08,   1.0746328E-08
     +,   8.0780671E-09,   6.0507457E-09,   4.5159325E-09
     +,   3.3581806E-09,   2.4881253E-09,   1.8366646E-09
     +,   1.3507339E-09,   9.8962072E-10,   7.2230522E-10
     +,   5.2517346E-10,   3.8037246E-10,   2.7442096E-10
     +,   1.9720729E-10,   1.4115747E-10,   1.0063704E-10
     +,   7.1459914E-11,   5.0537831E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt80 = Yx/0.43456
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1800113E-05,   1.2297261E-05
     +,   1.2813222E-05,   1.3348727E-05,   1.3904521E-05
     +,   1.4481380E-05,   1.5080118E-05,   1.5701562E-05
     +,   1.6346561E-05,   1.7016035E-05,   1.7710883E-05
     +,   1.8432051E-05,   1.9180501E-05,   1.9957233E-05
     +,   2.0763260E-05,   2.1599621E-05,   2.2467369E-05
     +,   2.3367575E-05,   2.4301333E-05,   2.5269735E-05
     +,   2.6273892E-05,   2.7314903E-05,   2.8393879E-05
     +,   2.9511961E-05,   3.0670180E-05,   3.1869680E-05
     +,   3.3111486E-05,   3.4396657E-05,   3.5726174E-05
     +,   3.7101025E-05,   3.8522132E-05,   3.9990373E-05
     +,   4.1506581E-05,   4.3071541E-05,   4.4685952E-05
     +,   4.6350466E-05,   4.8065682E-05,   4.9832110E-05
     +,   5.1650313E-05,   5.3520576E-05,   5.5443361E-05
     +,   5.7418994E-05,   5.9447768E-05,   6.1529987E-05
     +,   6.3665946E-05,   6.5856017E-05,   6.8100569E-05
     +,   7.0400100E-05,   7.2755196E-05,   7.5166594E-05
     +,   7.7635246E-05,   8.0162266E-05,   8.2749015E-05
     +,   8.5397303E-05,   8.8108973E-05,   9.0886497E-05
     +,   9.3732502E-05,   9.6650154E-05,   9.9642893E-05
     +,   1.0271463E-04,   1.0586961E-04,   1.0911253E-04
     +,   1.1244814E-04,   1.1588176E-04,   1.1941898E-04
     +,   1.2306514E-04,   1.2682617E-04,   1.3070751E-04
     +,   1.3471508E-04,   1.3885407E-04,   1.4313012E-04
     +,   1.4754791E-04,   1.5211258E-04,   1.5682835E-04
     +,   1.6169947E-04,   1.6673021E-04,   1.7192427E-04
     +,   1.7728528E-04,   1.8281736E-04,   1.8852492E-04
     +,   1.9441235E-04,   2.0048540E-04,   2.0675012E-04
     +,   2.1321452E-04,   2.1988706E-04,   2.2677895E-04
     +,   2.3390229E-04,   2.4127237E-04,   2.4890588E-04
     +,   2.5682303E-04,   2.6504695E-04,   2.7360398E-04
     +,   2.8252392E-04,   2.9184233E-04,   3.0159965E-04
     +,   3.1184204E-04,   3.2262460E-04,   3.3401031E-04
     +,   3.4607458E-04,   3.5890416E-04,   3.7260258E-04
     +,   3.8728912E-04,   4.0310409E-04,   4.2020716E-04
     +,   4.3878143E-04,   4.5903237E-04,   4.8118510E-04
     +,   5.0548086E-04,   5.3217402E-04,   5.6152052E-04
     +,   5.9376319E-04,   6.2912190E-04,   6.6776632E-04
     +,   7.0980366E-04,   7.5524446E-04,   8.0399390E-04
     +,   8.5582165E-04,   9.1036584E-04,   9.6712512E-04
     +,   1.0254949E-03,   1.0848107E-03,   1.1444236E-03
     +,   1.2038136E-03,   1.2627388E-03,   1.3214052E-03
     +,   1.3806521E-03,   1.4421599E-03,   1.5086026E-03
     +,   1.5837707E-03,   1.6725493E-03,   1.7807637E-03
     +,   1.9147719E-03,   2.0808417E-03,   2.2842255E-03
     +,   2.5281333E-03,   2.8126505E-03,   3.1338946E-03
     +,   3.4837571E-03,   3.8505797E-03,   4.2210403E-03
     +,   4.5835809E-03,   4.9333614E-03,   5.2779219E-03
     +,   5.6415028E-03,   6.0653971E-03,   6.6031534E-03
     +,   7.3131165E-03,   8.2529280E-03,   9.4761066E-03
     +,   1.1024984E-02,   1.2925195E-02,   1.5196968E-02
     +,   1.7863708E-02,   2.0922016E-02,   2.4365146E-02
     +,   2.8347591E-02,   3.3136725E-02,   3.8652193E-02
     +,   4.4515815E-02,   5.0953567E-02,   5.8856279E-02
     +,   6.8161868E-02,   7.7130958E-02,   8.3659314E-02
     +,   8.6236998E-02,   8.5737564E-02,   8.4617801E-02
     +,   8.4691644E-02,   8.5066088E-02,   8.2648762E-02
     +,   7.8330129E-02,   7.3819168E-02,   6.8168454E-02
     +,   6.0240660E-02,   5.1488943E-02,   4.4130817E-02
     +,   3.8815513E-02,   3.5013076E-02,   3.1777889E-02
     +,   2.8444953E-02,   2.5051078E-02,   2.1955224E-02
     +,   1.9313704E-02,   1.7094748E-02,   1.5304268E-02
     +,   1.3983373E-02,   1.3081408E-02,   1.2433469E-02
     +,   1.1847809E-02,   1.1195751E-02,   1.0441656E-02
     +,   9.6207624E-03,   8.7973354E-03,   8.0295485E-03
     +,   7.3517454E-03,   6.7723924E-03,   6.2810942E-03
     +,   5.8579431E-03,   5.4812855E-03,   5.1328158E-03
     +,   4.7999616E-03,   4.4764439E-03,   4.1615167E-03
     +,   3.8583917E-03,   3.5722104E-03,   3.3080392E-03
     +,   3.0694243E-03,   2.8577007E-03,   2.6719202E-03
     +,   2.5092552E-03,   2.3656620E-03,   2.2365232E-03
     +,   2.1172059E-03,   2.0034576E-03,   1.8917090E-03
     +,   1.7792569E-03,   1.6643452E-03,   1.5461646E-03
     +,   1.4248007E-03,   1.3011202E-03,   1.1765806E-03
     +,   1.0530347E-03,   9.3252485E-04,   8.1706676E-04
     +,   7.0846424E-04,   6.0818222E-04,   5.1726814E-04
     +,   4.3630978E-04,   3.6544466E-04,   3.0441565E-04
     +,   2.5265102E-04,   2.0934521E-04,   1.7354694E-04
     +,   1.4424499E-04,   1.2043787E-04,   1.0117998E-04
     +,   8.5619373E-05,   7.3017312E-05,   6.2752479E-05
     +,   5.4316828E-05,   4.7306250E-05,   4.1406842E-05
     +,   3.6378973E-05,   3.2042444E-05,   2.8263359E-05
     +,   2.4942976E-05,   2.2008007E-05,   1.9403271E-05
     +,   1.7086455E-05,   1.5024305E-05,   1.3189417E-05
     +,   1.1558580E-05,   1.0111600E-05,   8.8304087E-06
     +,   7.6984761E-06,   6.7006517E-06,   5.8230671E-06
     +,   5.0529293E-06,   4.3784480E-06,   3.7888615E-06
     +,   3.2744124E-06,   2.8262691E-06,   2.4364540E-06
     +,   2.0978284E-06,   1.8040607E-06,   1.5494995E-06
     +,   1.3291517E-06,   1.1386318E-06,   9.7408315E-07
     +,   8.3211233E-07,   7.0975375E-07,   6.0442267E-07
     +,   5.1386303E-07,   4.3610143E-07,   3.6942009E-07
     +,   3.1232892E-07,   2.6352359E-07,   2.2187562E-07
     +,   1.8639757E-07,   1.5623604E-07,   1.3064512E-07
     +,   1.0898052E-07,   9.0680174E-08,   7.5259230E-08
     +,   6.2295882E-08,   5.1426984E-08,   4.2337888E-08
     +,   3.4757569E-08,   2.8453652E-08,   2.3225821E-08
     +,   1.8903338E-08,   1.5339792E-08,   1.2411006E-08
     +,   1.0011125E-08,   8.0508658E-09,   6.4546102E-09
     +,   5.1589804E-09,   4.1106434E-09,   3.2651837E-09
     +,   2.5855018E-09,   2.0409072E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt85 = Yx/0.47264
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3479468E-05,   1.3919648E-05
     +,   1.4376022E-05,   1.4849067E-05,   1.5339247E-05
     +,   1.5846990E-05,   1.6372696E-05,   1.6916718E-05
     +,   1.7479373E-05,   1.8060959E-05,   1.8661700E-05
     +,   1.9281786E-05,   1.9921359E-05,   2.0580510E-05
     +,   2.1259286E-05,   2.1957680E-05,   2.2675644E-05
     +,   2.3413078E-05,   2.4169834E-05,   2.4945743E-05
     +,   2.5740579E-05,   2.6554089E-05,   2.7385993E-05
     +,   2.8236025E-05,   2.9103821E-05,   2.9989113E-05
     +,   3.0891581E-05,   3.1810923E-05,   3.2746881E-05
     +,   3.3699209E-05,   3.4667730E-05,   3.5652327E-05
     +,   3.6652957E-05,   3.7669644E-05,   3.8702558E-05
     +,   3.9751962E-05,   4.0818264E-05,   4.1902011E-05
     +,   4.3003976E-05,   4.4125019E-05,   4.5266319E-05
     +,   4.6429184E-05,   4.7615224E-05,   4.8826259E-05
     +,   5.0064380E-05,   5.1331990E-05,   5.2631764E-05
     +,   5.3966676E-05,   5.5340002E-05,   5.6755347E-05
     +,   5.8216618E-05,   5.9727998E-05,   6.1294020E-05
     +,   6.2919455E-05,   6.4609259E-05,   6.6368775E-05
     +,   6.8203379E-05,   7.0118629E-05,   7.2120158E-05
     +,   7.4213589E-05,   7.6404554E-05,   7.8698475E-05
     +,   8.1100443E-05,   8.3615436E-05,   8.6247943E-05
     +,   8.9001689E-05,   9.1880131E-05,   9.4885479E-05
     +,   9.8019584E-05,   1.0128291E-04,   1.0467515E-04
     +,   1.0819457E-04,   1.1183855E-04,   1.1560282E-04
     +,   1.1948215E-04,   1.2346997E-04,   1.2755833E-04
     +,   1.3173792E-04,   1.3599862E-04,   1.4032931E-04
     +,   1.4471772E-04,   1.4915134E-04,   1.5361673E-04
     +,   1.5810083E-04,   1.6259015E-04,   1.6707207E-04
     +,   1.7153415E-04,   1.7596541E-04,   1.8035577E-04
     +,   1.8469716E-04,   1.8898328E-04,   1.9320977E-04
     +,   1.9737483E-04,   2.0147923E-04,   2.0552668E-04
     +,   2.0952320E-04,   2.1347828E-04,   2.1740363E-04
     +,   2.2131430E-04,   2.2522763E-04,   2.2916391E-04
     +,   2.3314498E-04,   2.3719572E-04,   2.4134186E-04
     +,   2.4561121E-04,   2.5003284E-04,   2.5463637E-04
     +,   2.5945195E-04,   2.6451034E-04,   2.6984239E-04
     +,   2.7547826E-04,   2.8144833E-04,   2.8778159E-04
     +,   2.9450702E-04,   3.0165212E-04,   3.0924447E-04
     +,   3.1730998E-04,   3.2587507E-04,   3.3496466E-04
     +,   3.4460452E-04,   3.5482101E-04,   3.6564097E-04
     +,   3.7709228E-04,   3.8920643E-04,   4.0201805E-04
     +,   4.1556644E-04,   4.2990036E-04,   4.4508110E-04
     +,   4.6119388E-04,   4.7835917E-04,   4.9676001E-04
     +,   5.1667175E-04,   5.3851539E-04,   5.6292134E-04
     +,   5.9082080E-04,   6.2355550E-04,   6.6300575E-04
     +,   7.1174063E-04,   7.7317888E-04,   8.5173739E-04
     +,   9.5294631E-04,   1.0834998E-03,   1.2511951E-03
     +,   1.4646512E-03,   1.7326737E-03,   2.0632274E-03
     +,   2.4617761E-03,   2.9290875E-03,   3.4589565E-03
     +,   4.0367581E-03,   4.6399673E-03,   5.2418695E-03
     +,   5.8187931E-03,   6.3594659E-03,   6.8738256E-03
     +,   7.3991227E-03,   8.0026574E-03,   8.7815998E-03
     +,   9.8595219E-03,   1.1377082E-02,   1.3469078E-02
     +,   1.6212637E-02,   1.9551022E-02,   2.3262963E-02
     +,   2.7100274E-02,   3.1096362E-02,   3.5698045E-02
     +,   4.1405678E-02,   4.8351184E-02,   5.6421362E-02
     +,   6.5875262E-02,   7.6984428E-02,   8.8497549E-02
     +,   9.8895386E-02,   0.1067005    ,   0.1077562    
     +,   0.1012640    ,   9.4743811E-02,   9.0302534E-02
     +,   8.3341412E-02,   7.3277824E-02,   6.1910473E-02
     +,   5.2370612E-02,   4.6478048E-02,   4.2001694E-02
     +,   3.7130378E-02,   3.2034643E-02,   2.7508093E-02
     +,   2.4020290E-02,   2.1379238E-02,   1.9154351E-02
     +,   1.7154686E-02,   1.5387886E-02,   1.3862853E-02
     +,   1.2552137E-02,   1.1430449E-02,   1.0479089E-02
     +,   9.6720764E-03,   8.9784898E-03,   8.3747441E-03
     +,   7.8482283E-03,   7.3901247E-03,   6.9880448E-03
     +,   6.6253566E-03,   6.2852860E-03,   5.9550717E-03
     +,   5.6277458E-03,   5.3016874E-03,   4.9789893E-03
     +,   4.6636653E-03,   4.3600486E-03,   4.0715276E-03
     +,   3.7996906E-03,   3.5440472E-03,   3.3022854E-03
     +,   3.0709635E-03,   2.8463355E-03,   2.6251667E-03
     +,   2.4053727E-03,   2.1863636E-03,   1.9690136E-03
     +,   1.7554188E-03,   1.5484769E-03,   1.3513650E-03
     +,   1.1670485E-03,   9.9791959E-04,   8.4558123E-04
     +,   7.1075046E-04,   5.9330469E-04,   4.9243419E-04
     +,   4.0683671E-04,   3.3490799E-04,   2.7491723E-04
     +,   2.2515343E-04,   1.8402615E-04,   1.5011191E-04
     +,   1.2218187E-04,   9.9201337E-05,   8.0310696E-05
     +,   6.4800850E-05,   5.2089777E-05,   4.1699324E-05
     +,   3.3233835E-05,   2.6363525E-05,   2.0812617E-05
     +,   1.6349868E-05,   1.2780642E-05,   9.9411718E-06
     +,   7.6943725E-06,   5.9261924E-06,   4.5419952E-06
     +,   3.4639861E-06,   2.6287510E-06,   1.9848883E-06
     +,   1.4910083E-06,   1.1140635E-06,   8.2784277E-07
     +,   6.1165110E-07,   4.4923218E-07,   3.2789586E-07
     +,   2.3778924E-07,   1.7129081E-07,   1.2253190E-07
     +,   8.7022187E-08,   6.1346569E-08,   4.2917684E-08
     +,   2.9790828E-08,   2.0514515E-08,   1.4012445E-08
     +,   9.4924717E-09,   6.3767911E-09,   4.2476245E-09
     +,   2.8053126E-09,   1.8368411E-09,   1.1922986E-09
     +,   7.6720919E-10,   4.8935800E-10,   3.0940192E-10
     +,   1.9390062E-10,   1.2044760E-10,   7.4158457E-11
     +,   4.5256035E-11,   2.7373305E-11,   1.6410704E-11
     +,   9.7512909E-12,   5.7431594E-12,   3.3526764E-12
     +,   1.9399361E-12,   1.1126781E-12,   6.3262579E-13
     +,   3.5659282E-13,   1.9929104E-13,   1.1045749E-13
     +,   6.0731212E-14,   3.3140506E-14,   1.7961349E-14
     +,   9.6796206E-15,   5.1958526E-15,   2.7855278E-15
     +,   1.4973517E-15,   8.1178335E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt90 = Yx/0.46662
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6158743E-06,   2.8102961E-06
     +,   3.0160943E-06,   3.2336970E-06,   3.4635302E-06
     +,   3.7060199E-06,   3.9615907E-06,   4.2306638E-06
     +,   4.5136489E-06,   4.8109659E-06,   5.1230131E-06
     +,   5.4501838E-06,   5.7928582E-06,   6.1514070E-06
     +,   6.5261861E-06,   6.9175326E-06,   7.3257656E-06
     +,   7.7511868E-06,   8.1940661E-06,   8.6546561E-06
     +,   9.1331722E-06,   9.6298045E-06,   1.0144692E-05
     +,   1.0677975E-05,   1.1229690E-05,   1.1799886E-05
     +,   1.2388531E-05,   1.2995543E-05,   1.3620792E-05
     +,   1.4264076E-05,   1.4925136E-05,   1.5603639E-05
     +,   1.6299186E-05,   1.7011303E-05,   1.7739425E-05
     +,   1.8482926E-05,   1.9241081E-05,   2.0013085E-05
     +,   2.0798081E-05,   2.1595053E-05,   2.2402988E-05
     +,   2.3220739E-05,   2.4047104E-05,   2.4880794E-05
     +,   2.5720468E-05,   2.6564721E-05,   2.7412105E-05
     +,   2.8261124E-05,   2.9110277E-05,   2.9958026E-05
     +,   3.0802858E-05,   3.1643285E-05,   3.2477841E-05
     +,   3.3305187E-05,   3.4123957E-05,   3.4933037E-05
     +,   3.5731344E-05,   3.6518031E-05,   3.7292404E-05
     +,   3.8054030E-05,   3.8802718E-05,   3.9538594E-05
     +,   4.0262043E-05,   4.0973900E-05,   4.1675394E-05
     +,   4.2368112E-05,   4.3054235E-05,   4.3736356E-05
     +,   4.4417771E-05,   4.5102286E-05,   4.5794477E-05
     +,   4.6499583E-05,   4.7223795E-05,   4.7974070E-05
     +,   4.8758477E-05,   4.9586175E-05,   5.0467534E-05
     +,   5.1414288E-05,   5.2439787E-05,   5.3559084E-05
     +,   5.4789052E-05,   5.6148805E-05,   5.7659625E-05
     +,   5.9345479E-05,   6.1232829E-05,   6.3351232E-05
     +,   6.5732929E-05,   6.8413421E-05,   7.1430855E-05
     +,   7.4826283E-05,   7.8643236E-05,   8.2926803E-05
     +,   8.7723172E-05,   9.3078932E-05,   9.9039811E-05
     +,   1.0564843E-04,   1.1294428E-04,   1.2096013E-04
     +,   1.2972206E-04,   1.3924553E-04,   1.4953584E-04
     +,   1.6058394E-04,   1.7236787E-04,   1.8484904E-04
     +,   1.9797464E-04,   2.1167702E-04,   2.2587416E-04
     +,   2.4047264E-04,   2.5537191E-04,   2.7046731E-04
     +,   2.8565340E-04,   3.0083285E-04,   3.1591830E-04
     +,   3.3084172E-04,   3.4555598E-04,   3.6004296E-04
     +,   3.7431321E-04,   3.8841131E-04,   4.0241162E-04
     +,   4.1641929E-04,   4.3056539E-04,   4.4499966E-04
     +,   4.5988514E-04,   4.7539154E-04,   4.9168809E-04
     +,   5.0893624E-04,   5.2729074E-04,   5.4689462E-04
     +,   5.6788506E-04,   5.9039553E-04,   6.1456527E-04
     +,   6.4054178E-04,   6.6849322E-04,   6.9860450E-04
     +,   7.3108403E-04,   7.6615938E-04,   8.0406806E-04
     +,   8.4505562E-04,   8.8937749E-04,   9.3730248E-04
     +,   9.8912627E-04,   1.0451983E-03,   1.1059545E-03
     +,   1.1719398E-03,   1.2437936E-03,   1.3222253E-03
     +,   1.4079026E-03,   1.5012810E-03,   1.6023989E-03
     +,   1.7106676E-03,   1.8247103E-03,   1.9423491E-03
     +,   2.0608341E-03,   2.1773742E-03,   2.2899951E-03
     +,   2.3987480E-03,   2.5073134E-03,   2.6249413E-03
     +,   2.7685917E-03,   2.9647865E-03,   3.2501956E-03
     +,   3.6691849E-03,   4.2663496E-03,   5.0729807E-03
     +,   6.0894853E-03,   7.2720186E-03,   8.5383104E-03
     +,   9.8049361E-03,   1.1042297E-02,   1.2303414E-02
     +,   1.3703447E-02,   1.5413030E-02,   1.7739836E-02
     +,   2.1157583E-02,   2.5980549E-02,   3.1968646E-02
     +,   3.8641125E-02,   4.5533702E-02,   5.2163519E-02
     +,   5.9340265E-02,   6.8016715E-02,   7.7713721E-02
     +,   8.8838004E-02,   9.6627012E-02,   9.7787336E-02
     +,   9.9320270E-02,   9.9492274E-02,   9.3571350E-02
     +,   8.3662353E-02,   7.3427998E-02,   6.3098878E-02
     +,   5.3247463E-02,   4.5152314E-02,   3.9433308E-02
     +,   3.5631802E-02,   3.2702703E-02,   2.9845197E-02
     +,   2.6732590E-02,   2.3536369E-02,   2.0616053E-02
     +,   1.8152304E-02,   1.6129842E-02,   1.4481073E-02
     +,   1.3131387E-02,   1.1993047E-02,   1.0991761E-02
     +,   1.0095697E-02,   9.3064019E-03,   8.6284615E-03
     +,   8.0493893E-03,   7.5377799E-03,   7.0520602E-03
     +,   6.5524718E-03,   6.0126046E-03,   5.4271952E-03
     +,   4.8125084E-03,   4.1988306E-03,   3.6187384E-03
     +,   3.0967833E-03,   2.6444993E-03,   2.2610603E-03
     +,   1.9377671E-03,   1.6631590E-03,   1.4267238E-03
     +,   1.2206008E-03,   1.0396842E-03,   8.8088430E-04
     +,   7.4219587E-04,   6.2199670E-04,   5.1868125E-04
     +,   4.3054941E-04,   3.5583336E-04,   2.9278619E-04
     +,   2.3977719E-04,   1.9535019E-04,   1.5823406E-04
     +,   1.2734237E-04,   1.0175299E-04,   8.0678590E-05
     +,   6.3440457E-05,   4.9450053E-05,   3.8194215E-05
     +,   2.9223260E-05,   2.2143688E-05,   1.6613933E-05
     +,   1.2340474E-05,   9.0735430E-06,   6.6032230E-06
     +,   4.7557887E-06,   3.3895906E-06,   2.3904984E-06
     +,   1.6680332E-06,   1.1515017E-06,   7.8638823E-07
     +,   5.3122727E-07,   3.5493804E-07,   2.3454305E-07
     +,   1.5327140E-07,   9.9044016E-08,   6.3282542E-08
     +,   3.9976292E-08,   2.4966711E-08,   1.5414393E-08
     +,   9.4073158E-09,   5.6750826E-09,   3.3839367E-09
     +,   1.9943323E-09,   1.1617254E-09,   6.6889555E-10
     +,   3.8070114E-10,   2.1420621E-10,   1.1918327E-10
     +,   6.5602704E-11,   3.5747162E-11,   1.9304423E-11
     +,   1.0351064E-11,   5.5270502E-12,   2.9528088E-12
     +,   1.5896297E-12,   8.7128704E-13,   4.9276490E-13
     +,   2.9187335E-13,   1.8330919E-13,   1.2271315E-13
     +,   8.7204949E-14,   6.5062789E-14,   5.0283657E-14
     +,   3.9774251E-14,   3.1911278E-14,   2.5810986E-14
     +,   2.0966715E-14,   1.7065405E-14,   1.3899203E-14
     +,   1.1319185E-14,   9.2132417E-15,   7.4933549E-15
     +,   6.0891403E-15,   4.9433004E-15,   4.0091187E-15
     +,   3.2481816E-15,   2.6289980E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_htt95 = Yx/0.44016
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7544580E-05,   1.7887429E-05
     +,   1.8234427E-05,   1.8585604E-05,   1.8940973E-05
     +,   1.9300554E-05,   1.9664363E-05,   2.0032410E-05
     +,   2.0404705E-05,   2.0781250E-05,   2.1162046E-05
     +,   2.1547094E-05,   2.1936379E-05,   2.2329890E-05
     +,   2.2727598E-05,   2.3129482E-05,   2.3535507E-05
     +,   2.3945633E-05,   2.4359819E-05,   2.4778001E-05
     +,   2.5200128E-05,   2.5626126E-05,   2.6055930E-05
     +,   2.6489473E-05,   2.6926649E-05,   2.7367390E-05
     +,   2.7811613E-05,   2.8259221E-05,   2.8710145E-05
     +,   2.9164303E-05,   2.9621619E-05,   3.0082043E-05
     +,   3.0545532E-05,   3.1012067E-05,   3.1481672E-05
     +,   3.1954387E-05,   3.2430307E-05,   3.2909578E-05
     +,   3.3392422E-05,   3.3879100E-05,   3.4370012E-05
     +,   3.4865650E-05,   3.5366600E-05,   3.5873607E-05
     +,   3.6387588E-05,   3.6909598E-05,   3.7440936E-05
     +,   3.7983122E-05,   3.8537892E-05,   3.9107304E-05
     +,   3.9693696E-05,   4.0299761E-05,   4.0928531E-05
     +,   4.1583469E-05,   4.2268402E-05,   4.2987678E-05
     +,   4.3746080E-05,   4.4548888E-05,   4.5401946E-05
     +,   4.6311605E-05,   4.7284811E-05,   4.8329079E-05
     +,   4.9452450E-05,   5.0663632E-05,   5.1971907E-05
     +,   5.3387030E-05,   5.4919448E-05,   5.6579964E-05
     +,   5.8380072E-05,   6.0331491E-05,   6.2446568E-05
     +,   6.4737760E-05,   6.7218032E-05,   6.9900263E-05
     +,   7.2797709E-05,   7.5923606E-05,   7.9290985E-05
     +,   8.2912622E-05,   8.6801250E-05,   9.0969173E-05
     +,   9.5427778E-05,   1.0018836E-04,   1.0526070E-04
     +,   1.1065441E-04,   1.1637714E-04,   1.2243616E-04
     +,   1.2883640E-04,   1.3558219E-04,   1.4267510E-04
     +,   1.5011558E-04,   1.5790193E-04,   1.6602976E-04
     +,   1.7449228E-04,   1.8328066E-04,   1.9238341E-04
     +,   2.0178537E-04,   2.1146964E-04,   2.2141522E-04
     +,   2.3159919E-04,   2.4199449E-04,   2.5257221E-04
     +,   2.6329933E-04,   2.7414170E-04,   2.8506084E-04
     +,   2.9601736E-04,   3.0696977E-04,   3.1787466E-04
     +,   3.2868786E-04,   3.3936507E-04,   3.4986268E-04
     +,   3.6013708E-04,   3.7014741E-04,   3.7985464E-04
     +,   3.8922389E-04,   3.9822399E-04,   4.0682990E-04
     +,   4.1502109E-04,   4.2278538E-04,   4.3011730E-04
     +,   4.3701986E-04,   4.4350486E-04,   4.4959266E-04
     +,   4.5531327E-04,   4.6070624E-04,   4.6581993E-04
     +,   4.7071121E-04,   4.7544562E-04,   4.8009533E-04
     +,   4.8473902E-04,   4.8945978E-04,   4.9434457E-04
     +,   4.9948104E-04,   5.0495740E-04,   5.1085814E-04
     +,   5.1726424E-04,   5.2424957E-04,   5.3187931E-04
     +,   5.4020662E-04,   5.4927252E-04,   5.5910373E-04
     +,   5.6970853E-04,   5.8107829E-04,   5.9318641E-04
     +,   6.0598640E-04,   6.1941141E-04,   6.3337683E-04
     +,   6.4778043E-04,   6.6250213E-04,   6.7740859E-04
     +,   6.9235550E-04,   7.0719159E-04,   7.2176219E-04
     +,   7.3591381E-04,   7.4950187E-04,   7.6239719E-04
     +,   7.7448966E-04,   7.8569876E-04,   7.9598109E-04
     +,   8.0533663E-04,   8.1381627E-04,   8.2153024E-04
     +,   8.2865387E-04,   8.3543453E-04,   8.4219506E-04
     +,   8.4934209E-04,   8.5736730E-04,   8.6685346E-04
     +,   8.7847561E-04,   8.9300709E-04,   9.1132103E-04
     +,   9.3439006E-04,   9.6328708E-04,   9.9918409E-04
     +,   1.0433554E-03,   1.0971804E-03,   1.1621874E-03
     +,   1.2401306E-03,   1.3331352E-03,   1.4439462E-03
     +,   1.5762810E-03,   1.7352129E-03,   1.9274626E-03
     +,   2.1614365E-03,   2.4467290E-03,   2.7929370E-03
     +,   3.2078710E-03,   3.6957520E-03,   4.2562680E-03
     +,   4.8851823E-03,   5.5766953E-03,   6.3269595E-03
     +,   7.1372320E-03,   8.0163293E-03,   8.9835329E-03
     +,   1.0072875E-02,   1.1339013E-02,   1.2863584E-02
     +,   1.4756976E-02,   1.7143250E-02,   2.0120747E-02
     +,   2.3715772E-02,   2.7838023E-02,   3.2196473E-02
     +,   3.6225092E-02,   3.9302606E-02,   4.1335620E-02
     +,   4.3015998E-02,   4.5116749E-02,   4.7615971E-02
     +,   5.0011616E-02,   5.2240230E-02,   5.4509830E-02
     +,   5.6592863E-02,   5.8084927E-02,   5.8935717E-02
     +,   5.9212949E-02,   5.8902219E-02,   5.8071882E-02
     +,   5.6646530E-02,   5.4179970E-02,   5.0293941E-02
     +,   4.5347780E-02,   4.0470622E-02,   3.6728706E-02
     +,   3.4272674E-02,   3.2428488E-02,   3.0543333E-02
     +,   2.8529920E-02,   2.6630253E-02,   2.4945201E-02
     +,   2.3347585E-02,   2.1718919E-02,   2.0101435E-02
     +,   1.8617071E-02,   1.7322268E-02,   1.6167752E-02
     +,   1.5066837E-02,   1.3973886E-02,   1.2906285E-02
     +,   1.1913988E-02,   1.1038357E-02,   1.0290192E-02
     +,   9.6509922E-03,   9.0866880E-03,   8.5625621E-03
     +,   8.0533931E-03,   7.5477283E-03,   7.0468918E-03
     +,   6.5606418E-03,   6.1014867E-03,   5.6797205E-03
     +,   5.3006723E-03,   4.9641440E-03,   4.6654521E-03
     +,   4.3972651E-03,   4.1514295E-03,   3.9203460E-03
     +,   3.6977411E-03,   3.4789715E-03,   3.2610702E-03
     +,   3.0426625E-03,   2.8237826E-03,   2.6056424E-03
     +,   2.3903530E-03,   2.1805943E-03,   1.9791918E-03
     +,   1.7887648E-03,   1.6114484E-03,   1.4486965E-03
     +,   1.3012040E-03,   1.1689658E-03,   1.0513983E-03
     +,   9.4748277E-04,   8.5592276E-04,   7.7529508E-04
     +,   7.0417614E-04,   6.4120180E-04,   5.8514171E-04
     +,   5.3490658E-04,   4.8957072E-04,   4.4835583E-04
     +,   4.1062970E-04,   3.7588037E-04,   3.4370951E-04
     +,   3.1380481E-04,   2.8593378E-04,   2.5992008E-04
     +,   2.3563438E-04,   2.1298356E-04,   1.9189593E-04
     +,   1.7231754E-04,   1.5420103E-04,   1.3750447E-04
     +,   1.2218318E-04,   1.0819137E-04,   9.5476586E-05
     +,   8.3982850E-05,   7.3647134E-05,   6.4403204E-05
     +,   5.6179622E-05,   4.8903428E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt100 = Yx/0.43022
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5957783E-05,   1.6550815E-05
     +,   1.7163497E-05,   1.7796432E-05,   1.8450242E-05
     +,   1.9125560E-05,   1.9823012E-05,   2.0543239E-05
     +,   2.1286862E-05,   2.2054544E-05,   2.2846902E-05
     +,   2.3664539E-05,   2.4508061E-05,   2.5378047E-05
     +,   2.6275055E-05,   2.7199598E-05,   2.8152181E-05
     +,   2.9133236E-05,   3.0143181E-05,   3.1182361E-05
     +,   3.2251071E-05,   3.3349555E-05,   3.4477973E-05
     +,   3.5636465E-05,   3.6825000E-05,   3.8043567E-05
     +,   3.9292048E-05,   4.0570227E-05,   4.1877800E-05
     +,   4.3214404E-05,   4.4579567E-05,   4.5972763E-05
     +,   4.7393354E-05,   4.8840619E-05,   5.0313793E-05
     +,   5.1812018E-05,   5.3334345E-05,   5.4879776E-05
     +,   5.6447330E-05,   5.8035810E-05,   5.9644128E-05
     +,   6.1271079E-05,   6.2915446E-05,   6.4575994E-05
     +,   6.6251443E-05,   6.7940535E-05,   6.9642032E-05
     +,   7.1354625E-05,   7.3077121E-05,   7.4808297E-05
     +,   7.6546916E-05,   7.8291872E-05,   8.0042024E-05
     +,   8.1796410E-05,   8.3553918E-05,   8.5313739E-05
     +,   8.7074994E-05,   8.8836932E-05,   9.0598907E-05
     +,   9.2360402E-05,   9.4120987E-05,   9.5880423E-05
     +,   9.7638556E-05,   9.9395496E-05,   1.0115151E-04
     +,   1.0290697E-04,   1.0466277E-04,   1.0641971E-04
     +,   1.0817920E-04,   1.0994266E-04,   1.1171220E-04
     +,   1.1348996E-04,   1.1527877E-04,   1.1708155E-04
     +,   1.1890196E-04,   1.2074396E-04,   1.2261207E-04
     +,   1.2451100E-04,   1.2644623E-04,   1.2842366E-04
     +,   1.3044947E-04,   1.3253035E-04,   1.3467320E-04
     +,   1.3688556E-04,   1.3917478E-04,   1.4154879E-04
     +,   1.4401521E-04,   1.4658202E-04,   1.4925672E-04
     +,   1.5204679E-04,   1.5495940E-04,   1.5800091E-04
     +,   1.6117723E-04,   1.6449353E-04,   1.6795416E-04
     +,   1.7156207E-04,   1.7531952E-04,   1.7922712E-04
     +,   1.8328444E-04,   1.8748916E-04,   1.9183813E-04
     +,   1.9632596E-04,   2.0094626E-04,   2.0569061E-04
     +,   2.1054946E-04,   2.1551181E-04,   2.2056505E-04
     +,   2.2569514E-04,   2.3088735E-04,   2.3612601E-04
     +,   2.4139385E-04,   2.4667400E-04,   2.5194799E-04
     +,   2.5719823E-04,   2.6240587E-04,   2.6755317E-04
     +,   2.7262169E-04,   2.7759437E-04,   2.8245352E-04
     +,   2.8718324E-04,   2.9176788E-04,   2.9619227E-04
     +,   3.0044265E-04,   3.0450578E-04,   3.0836975E-04
     +,   3.1202272E-04,   3.1545426E-04,   3.1865443E-04
     +,   3.2161397E-04,   3.2432418E-04,   3.2677679E-04
     +,   3.2896371E-04,   3.3087761E-04,   3.3251109E-04
     +,   3.3385665E-04,   3.3490764E-04,   3.3565695E-04
     +,   3.3609802E-04,   3.3622453E-04,   3.3603035E-04
     +,   3.3551001E-04,   3.3465866E-04,   3.3347253E-04
     +,   3.3194842E-04,   3.3008534E-04,   3.2788352E-04
     +,   3.2534494E-04,   3.2247469E-04,   3.1928049E-04
     +,   3.1577284E-04,   3.1196637E-04,   3.0787991E-04
     +,   3.0353709E-04,   2.9896674E-04,   2.9420387E-04
     +,   2.8929021E-04,   2.8427533E-04,   2.7921653E-04
     +,   2.7418046E-04,   2.6924431E-04,   2.6449590E-04
     +,   2.6003533E-04,   2.5597596E-04,   2.5244604E-04
     +,   2.4958872E-04,   2.4756463E-04,   2.4655351E-04
     +,   2.4675560E-04,   2.4839424E-04,   2.5171915E-04
     +,   2.5700976E-04,   2.6457873E-04,   2.7477817E-04
     +,   2.8800473E-04,   3.0470421E-04,   3.2537832E-04
     +,   3.5058969E-04,   3.8096236E-04,   4.1718324E-04
     +,   4.6000333E-04,   5.1023217E-04,   5.6872907E-04
     +,   6.3640013E-04,   7.1420026E-04,   8.0312736E-04
     +,   9.0421934E-04,   1.0185468E-03,   1.1472069E-03
     +,   1.2912701E-03,   1.4516814E-03,   1.6291634E-03
     +,   1.8240436E-03,   2.0360658E-03,   2.2642661E-03
     +,   2.5069385E-03,   2.7617156E-03,   3.0258668E-03
     +,   3.2968812E-03,   3.5733487E-03,   3.8561136E-03
     +,   4.1496200E-03,   4.4632349E-03,   4.8121009E-03
     +,   5.2170036E-03,   5.7031675E-03,   6.2982393E-03
     +,   7.0298887E-03,   7.9243304E-03,   9.0068681E-03
     +,   1.0303456E-02,   1.1837228E-02,   1.3614503E-02
     +,   1.5606978E-02,   1.7752934E-02,   1.9987362E-02
     +,   2.2270884E-02,   2.4591278E-02,   2.6986456E-02
     +,   2.9614922E-02,   3.2696240E-02,   3.6197349E-02
     +,   3.9672900E-02,   4.2701360E-02,   4.5406651E-02
     +,   4.8222400E-02,   5.1142510E-02,   5.3514991E-02
     +,   5.4674949E-02,   5.4689765E-02,   5.4392565E-02
     +,   5.4369379E-02,   5.4303158E-02,   5.3741697E-02
     +,   5.2576669E-02,   5.0883316E-02,   4.8964646E-02
     +,   4.7089882E-02,   4.5318421E-02,   4.3584246E-02
     +,   4.1626394E-02,   3.9204005E-02,   3.6378749E-02
     +,   3.3355758E-02,   3.0321630E-02,   2.7487565E-02
     +,   2.5006756E-02,   2.2833167E-02,   2.0800510E-02
     +,   1.8822754E-02,   1.6961822E-02,   1.5330189E-02
     +,   1.3974151E-02,   1.2844048E-02,   1.1845492E-02
     +,   1.0905920E-02,   1.0004935E-02,   9.1605177E-03
     +,   8.3961412E-03,   7.7171326E-03,   7.1076211E-03
     +,   6.5418123E-03,   5.9974282E-03,   5.4629920E-03
     +,   4.9378718E-03,   4.4280235E-03,   3.9411397E-03
     +,   3.4835511E-03,   3.0591404E-03,   2.6695433E-03
     +,   2.3149017E-03,   1.9946073E-03,   1.7077476E-03
     +,   1.4532206E-03,   1.2296843E-03,   1.0354969E-03
     +,   8.6867710E-04,   7.2687946E-04,   6.0752727E-04
     +,   5.0789438E-04,   4.2527524E-04,   3.5707510E-04
     +,   3.0092205E-04,   2.5470351E-04,   2.1660322E-04
     +,   1.8508830E-04,   1.5889856E-04,   1.3700929E-04
     +,   1.1860065E-04,   1.0302333E-04,   8.9762507E-05
     +,   7.8413184E-05,   6.8652844E-05,   6.0225055E-05
     +,   5.2921725E-05,   4.6573903E-05,   4.1041221E-05
     +,   3.6207297E-05,   3.1973650E-05,   2.8257491E-05
     +,   2.4988103E-05,   2.2105747E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt104 = Yx/0.4095
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3593180E-05,   1.3953646E-05
     +,   1.4318039E-05,   1.4686205E-05,   1.5057991E-05
     +,   1.5433236E-05,   1.5811775E-05,   1.6193451E-05
     +,   1.6578091E-05,   1.6965540E-05,   1.7355625E-05
     +,   1.7748189E-05,   1.8143066E-05,   1.8540099E-05
     +,   1.8939132E-05,   1.9340016E-05,   1.9742609E-05
     +,   2.0146776E-05,   2.0552392E-05,   2.0959333E-05
     +,   2.1367501E-05,   2.1776801E-05,   2.2187147E-05
     +,   2.2598502E-05,   2.3010787E-05,   2.3424000E-05
     +,   2.3838122E-05,   2.4253168E-05,   2.4669171E-05
     +,   2.5086207E-05,   2.5504349E-05,   2.5923720E-05
     +,   2.6344464E-05,   2.6766746E-05,   2.7190785E-05
     +,   2.7616810E-05,   2.8045104E-05,   2.8475950E-05
     +,   2.8909737E-05,   2.9346797E-05,   2.9787583E-05
     +,   3.0232546E-05,   3.0682168E-05,   3.1137006E-05
     +,   3.1597618E-05,   3.2064621E-05,   3.2538697E-05
     +,   3.3020511E-05,   3.3510816E-05,   3.4010383E-05
     +,   3.4520021E-05,   3.5040586E-05,   3.5572968E-05
     +,   3.6118108E-05,   3.6676960E-05,   3.7250531E-05
     +,   3.7839862E-05,   3.8446011E-05,   3.9070106E-05
     +,   3.9713294E-05,   4.0376744E-05,   4.1061685E-05
     +,   4.1769355E-05,   4.2501048E-05,   4.3258133E-05
     +,   4.4041943E-05,   4.4853932E-05,   4.5695520E-05
     +,   4.6568272E-05,   4.7473710E-05,   4.8413509E-05
     +,   4.9389299E-05,   5.0402887E-05,   5.1456027E-05
     +,   5.2550648E-05,   5.3688767E-05,   5.4872376E-05
     +,   5.6103603E-05,   5.7384663E-05,   5.8717949E-05
     +,   6.0105740E-05,   6.1550636E-05,   6.3055086E-05
     +,   6.4621861E-05,   6.6253531E-05,   6.7952991E-05
     +,   6.9722977E-05,   7.1566406E-05,   7.3486051E-05
     +,   7.5484801E-05,   7.7565535E-05,   7.9730919E-05
     +,   8.1983511E-05,   8.4325926E-05,   8.6760498E-05
     +,   8.9289199E-05,   9.1913978E-05,   9.4636198E-05
     +,   9.7457130E-05,   1.0037732E-04,   1.0339720E-04
     +,   1.0651629E-04,   1.0973390E-04,   1.1304831E-04
     +,   1.1645753E-04,   1.1995871E-04,   1.2354819E-04
     +,   1.2722140E-04,   1.3097329E-04,   1.3479794E-04
     +,   1.3868826E-04,   1.4263681E-04,   1.4663491E-04
     +,   1.5067347E-04,   1.5474227E-04,   1.5883090E-04
     +,   1.6292765E-04,   1.6702096E-04,   1.7109816E-04
     +,   1.7514666E-04,   1.7915346E-04,   1.8310528E-04
     +,   1.8698884E-04,   1.9079111E-04,   1.9449950E-04
     +,   1.9810139E-04,   2.0158512E-04,   2.0493958E-04
     +,   2.0815480E-04,   2.1122147E-04,   2.1413210E-04
     +,   2.1688004E-04,   2.1946068E-04,   2.2187043E-04
     +,   2.2410807E-04,   2.2617418E-04,   2.2807095E-04
     +,   2.2980270E-04,   2.3137585E-04,   2.3279883E-04
     +,   2.3408188E-04,   2.3523724E-04,   2.3627878E-04
     +,   2.3722208E-04,   2.3808399E-04,   2.3888265E-04
     +,   2.3963713E-04,   2.4036696E-04,   2.4109197E-04
     +,   2.4183225E-04,   2.4260713E-04,   2.4343532E-04
     +,   2.4433446E-04,   2.4532061E-04,   2.4640822E-04
     +,   2.4760957E-04,   2.4893455E-04,   2.5039088E-04
     +,   2.5198364E-04,   2.5371512E-04,   2.5558521E-04
     +,   2.5759186E-04,   2.5973070E-04,   2.6199577E-04
     +,   2.6438042E-04,   2.6687764E-04,   2.6948127E-04
     +,   2.7218644E-04,   2.7499237E-04,   2.7790252E-04
     +,   2.8092728E-04,   2.8408595E-04,   2.8741031E-04
     +,   2.9094744E-04,   2.9476304E-04,   2.9894782E-04
     +,   3.0362172E-04,   3.0894001E-04,   3.1510074E-04
     +,   3.2235347E-04,   3.3100633E-04,   3.4143505E-04
     +,   3.5409030E-04,   3.6950677E-04,   3.8830587E-04
     +,   4.1119475E-04,   4.3896015E-04,   4.7245430E-04
     +,   5.1256700E-04,   5.6018122E-04,   6.1612885E-04
     +,   6.8112568E-04,   7.5570261E-04,   8.4015279E-04
     +,   9.3450991E-04,   1.0385618E-03,   1.1519260E-03
     +,   1.2742163E-03,   1.4053002E-03,   1.5456020E-03
     +,   1.6964177E-03,   1.8601881E-03,   2.0406416E-03
     +,   2.2426751E-03,   2.4719809E-03,   2.7345226E-03
     +,   3.0359360E-03,   3.3811140E-03,   3.7741764E-03
     +,   4.2187325E-03,   4.7179386E-03,   5.2740094E-03
     +,   5.8877589E-03,   6.5598637E-03,   7.2960658E-03
     +,   8.1158308E-03,   9.0581663E-03,   1.0174743E-02
     +,   1.1506190E-02,   1.3052100E-02,   1.4756199E-02
     +,   1.6527927E-02,   1.8314917E-02,   2.0209359E-02
     +,   2.2484515E-02,   2.5424177E-02,   2.9016957E-02
     +,   3.2850932E-02,   3.6386222E-02,   3.9360348E-02
     +,   4.1938189E-02,   4.4438578E-02,   4.7014415E-02
     +,   4.9715169E-02,   5.2522276E-02,   5.5070724E-02
     +,   5.6759670E-02,   5.7439856E-02,   5.7692789E-02
     +,   5.7973273E-02,   5.7655264E-02,   5.5994868E-02
     +,   5.3591944E-02,   5.1317230E-02,   4.8870582E-02
     +,   4.5578551E-02,   4.1814923E-02,   3.8777795E-02
     +,   3.6922432E-02,   3.5527680E-02,   3.3790518E-02
     +,   3.1463746E-02,   2.8593980E-02,   2.5357543E-02
     +,   2.2135710E-02,   1.9378953E-02,   1.7310981E-02
     +,   1.5834112E-02,   1.4691260E-02,   1.3660525E-02
     +,   1.2627715E-02,   1.1559751E-02,   1.0458018E-02
     +,   9.3337568E-03,   8.2050795E-03,   7.1001630E-03
     +,   6.0560005E-03,   5.1098391E-03,   4.2881793E-03
     +,   3.6000798E-03,   3.0376716E-03,   2.5820970E-03
     +,   2.2108580E-03,   1.9034541E-03,   1.6440757E-03
     +,   1.4218031E-03,   1.2294404E-03,   1.0622062E-03
     +,   9.1661321E-04,   7.8988005E-04,   6.7959295E-04
     +,   5.8364804E-04,   5.0020101E-04,   4.2768160E-04
     +,   3.6474917E-04,   3.1027230E-04,   2.6327212E-04
     +,   2.2288939E-04,   1.8835701E-04,   1.5897138E-04
     +,   1.3408970E-04,   1.1311727E-04,   9.5513366E-05
     +,   8.0785911E-05,   6.8497007E-05,   5.8258636E-05
     +,   4.9734655E-05,   4.2635005E-05,   3.6714369E-05
     +,   3.1765761E-05,   2.7617352E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt106 = Yx/0.398857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4981349E-05,   4.6414520E-05
     +,   4.7855603E-05,   4.9301445E-05,   5.0748742E-05
     +,   5.2194056E-05,   5.3633848E-05,   5.5064440E-05
     +,   5.6482077E-05,   5.7882979E-05,   5.9263275E-05
     +,   6.0619055E-05,   6.1946448E-05,   6.3241547E-05
     +,   6.4500549E-05,   6.5719658E-05,   6.6895176E-05
     +,   6.8023561E-05,   6.9101356E-05,   7.0125257E-05
     +,   7.1092174E-05,   7.1999217E-05,   7.2843643E-05
     +,   7.3623058E-05,   7.4335250E-05,   7.4978285E-05
     +,   7.5550539E-05,   7.6050645E-05,   7.6477605E-05
     +,   7.6830685E-05,   7.7109507E-05,   7.7314005E-05
     +,   7.7444412E-05,   7.7501332E-05,   7.7485682E-05
     +,   7.7398676E-05,   7.7241872E-05,   7.7017132E-05
     +,   7.6726537E-05,   7.6372547E-05,   7.5957832E-05
     +,   7.5485324E-05,   7.4958189E-05,   7.4379735E-05
     +,   7.3753596E-05,   7.3083494E-05,   7.2373288E-05
     +,   7.1626979E-05,   7.0848713E-05,   7.0042668E-05
     +,   6.9213107E-05,   6.8364330E-05,   6.7500667E-05
     +,   6.6626410E-05,   6.5745873E-05,   6.4863249E-05
     +,   6.3982756E-05,   6.3108520E-05,   6.2244515E-05
     +,   6.1394639E-05,   6.0562699E-05,   5.9752314E-05
     +,   5.8966962E-05,   5.8210033E-05,   5.7484616E-05
     +,   5.6793790E-05,   5.6140332E-05,   5.5526951E-05
     +,   5.4956072E-05,   5.4430031E-05,   5.3950909E-05
     +,   5.3520696E-05,   5.3141132E-05,   5.2813877E-05
     +,   5.2540352E-05,   5.2321884E-05,   5.2159634E-05
     +,   5.2054664E-05,   5.2007901E-05,   5.2020147E-05
     +,   5.2092124E-05,   5.2224503E-05,   5.2417836E-05
     +,   5.2672658E-05,   5.2989442E-05,   5.3368654E-05
     +,   5.3810712E-05,   5.4316068E-05,   5.4885124E-05
     +,   5.5518354E-05,   5.6216260E-05,   5.6979334E-05
     +,   5.7808076E-05,   5.8703114E-05,   5.9665108E-05
     +,   6.0694649E-05,   6.1792511E-05,   6.2959312E-05
     +,   6.4195912E-05,   6.5502929E-05,   6.6881199E-05
     +,   6.8331312E-05,   6.9854010E-05,   7.1449715E-05
     +,   7.3118936E-05,   7.4862022E-05,   7.6679040E-05
     +,   7.8569792E-05,   8.0534031E-05,   8.2571176E-05
     +,   8.4680105E-05,   8.6859633E-05,   8.9107853E-05
     +,   9.1422771E-05,   9.3801515E-05,   9.6241041E-05
     +,   9.8737539E-05,   1.0128682E-04,   1.0388385E-04
     +,   1.0652325E-04,   1.0919904E-04,   1.1190442E-04
     +,   1.1463205E-04,   1.1737408E-04,   1.2012223E-04
     +,   1.2286738E-04,   1.2560030E-04,   1.2831096E-04
     +,   1.3098936E-04,   1.3362484E-04,   1.3620687E-04
     +,   1.3872457E-04,   1.4116724E-04,   1.4352413E-04
     +,   1.4578488E-04,   1.4793950E-04,   1.4997834E-04
     +,   1.5189250E-04,   1.5367393E-04,   1.5531555E-04
     +,   1.5681137E-04,   1.5815657E-04,   1.5934810E-04
     +,   1.6038434E-04,   1.6126552E-04,   1.6199384E-04
     +,   1.6257376E-04,   1.6301188E-04,   1.6331737E-04
     +,   1.6350186E-04,   1.6357978E-04,   1.6356837E-04
     +,   1.6348748E-04,   1.6336008E-04,   1.6321204E-04
     +,   1.6307195E-04,   1.6297145E-04,   1.6294468E-04
     +,   1.6302854E-04,   1.6326243E-04,   1.6368802E-04
     +,   1.6434923E-04,   1.6529186E-04,   1.6656361E-04
     +,   1.6821380E-04,   1.7029351E-04,   1.7285520E-04
     +,   1.7595279E-04,   1.7964205E-04,   1.8398033E-04
     +,   1.8902677E-04,   1.9484221E-04,   2.0148985E-04
     +,   2.0903524E-04,   2.1754501E-04,   2.2708843E-04
     +,   2.3773614E-04,   2.4955845E-04,   2.6262520E-04
     +,   2.7700514E-04,   2.9276402E-04,   3.0996196E-04
     +,   3.2865242E-04,   3.4888313E-04,   3.7069386E-04
     +,   3.9411584E-04,   4.1917420E-04,   4.4589274E-04
     +,   4.7429753E-04,   5.0442189E-04,   5.3631968E-04
     +,   5.7007646E-04,   6.0582219E-04,   6.4375188E-04
     +,   6.8415125E-04,   7.2742201E-04,   7.7410956E-04
     +,   8.2493969E-04,   8.8085799E-04,   9.4305992E-04
     +,   1.0130161E-03,   1.0924882E-03,   1.1835323E-03
     +,   1.2884752E-03,   1.4098583E-03,   1.5503995E-03
     +,   1.7129275E-03,   1.9003112E-03,   2.1154007E-03
     +,   2.3609530E-03,   2.6394823E-03,   2.9530223E-03
     +,   3.3029518E-03,   3.6899897E-03,   4.1145147E-03
     +,   4.5772525E-03,   5.0801262E-03,   5.6265085E-03
     +,   6.2201270E-03,   6.8625985E-03,   7.5508598E-03
     +,   8.2758460E-03,   9.0236282E-03,   9.7782454E-03
     +,   1.0524633E-02,   1.1251826E-02,   1.1960029E-02
     +,   1.2675525E-02,   1.3471897E-02,   1.4484123E-02
     +,   1.5888941E-02,   1.7832436E-02,   2.0342968E-02
     +,   2.3324283E-02,   2.6650285E-02,   3.0229622E-02
     +,   3.3960871E-02,   3.7731312E-02,   4.1479800E-02
     +,   4.5067325E-02,   4.8131302E-02,   5.0518028E-02
     +,   5.2819651E-02,   5.5668280E-02,   5.8410790E-02
     +,   5.9591226E-02,   5.8765326E-02,   5.6683183E-02
     +,   5.4249991E-02,   5.2339990E-02,   5.1534735E-02
     +,   5.1290337E-02,   5.0392210E-02,   4.8358325E-02
     +,   4.5547325E-02,   4.2398408E-02,   3.9205443E-02
     +,   3.6054742E-02,   3.2782767E-02,   2.9278524E-02
     +,   2.5719520E-02,   2.2409799E-02,   1.9521121E-02
     +,   1.7040608E-02,   1.4877199E-02,   1.2955774E-02
     +,   1.1237052E-02,   9.6994294E-03,   8.3255749E-03
     +,   7.1016797E-03,   6.0193250E-03,   5.0728219E-03
     +,   4.2545362E-03,   3.5528343E-03,   2.9536481E-03
     +,   2.4433136E-03,   2.0102549E-03,   1.6453036E-03
     +,   1.3407789E-03,   1.0896428E-03,   8.8489812E-04
     +,   7.1960618E-04,   5.8707694E-04,   4.8122206E-04
     +,   3.9674484E-04,   3.2924980E-04,   2.7518027E-04
     +,   2.3171582E-04,   1.9663658E-04,   1.6818594E-04
     +,   1.4497551E-04,   1.2589987E-04,   1.1008482E-04
     +,   9.6839867E-05,   8.5627835E-05,   7.6032869E-05
     +,   6.7738663E-05,   6.0504306E-05,   5.4148451E-05
     +,   4.8532351E-05,   4.3549815E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt108 = Yx/0.385285714285714
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6767780E-06,   2.7934559E-06
     +,   2.9135142E-06,   3.0369790E-06,   3.1638758E-06
     +,   3.2942287E-06,   3.4280638E-06,   3.5654054E-06
     +,   3.7062778E-06,   3.8507123E-06,   3.9987353E-06
     +,   4.1503772E-06,   4.3056716E-06,   4.4646558E-06
     +,   4.6273694E-06,   4.7938565E-06,   4.9641676E-06
     +,   5.1383586E-06,   5.3164890E-06,   5.4986281E-06
     +,   5.6848512E-06,   5.8752426E-06,   6.0698894E-06
     +,   6.2689041E-06,   6.4723827E-06,   6.6804569E-06
     +,   6.8932527E-06,   7.1109121E-06,   7.3335887E-06
     +,   7.5614444E-06,   7.7946534E-06,   8.0334030E-06
     +,   8.2778870E-06,   8.5283136E-06,   8.7849003E-06
     +,   9.0478707E-06,   9.3174622E-06,   9.5939149E-06
     +,   9.8774908E-06,   1.0168427E-05,   1.0467003E-05
     +,   1.0773477E-05,   1.1088112E-05,   1.1411178E-05
     +,   1.1742940E-05,   1.2083660E-05,   1.2433592E-05
     +,   1.2792985E-05,   1.3162082E-05,   1.3541107E-05
     +,   1.3930276E-05,   1.4329789E-05,   1.4739820E-05
     +,   1.5160549E-05,   1.5592095E-05,   1.6034599E-05
     +,   1.6488142E-05,   1.6952805E-05,   1.7428632E-05
     +,   1.7915649E-05,   1.8413850E-05,   1.8923220E-05
     +,   1.9443685E-05,   1.9975198E-05,   2.0517680E-05
     +,   2.1071004E-05,   2.1635095E-05,   2.2209788E-05
     +,   2.2795000E-05,   2.3390578E-05,   2.3996448E-05
     +,   2.4612480E-05,   2.5238645E-05,   2.5874855E-05
     +,   2.6521133E-05,   2.7177550E-05,   2.7844175E-05
     +,   2.8521154E-05,   2.9208742E-05,   2.9907265E-05
     +,   3.0617084E-05,   3.1338728E-05,   3.2072730E-05
     +,   3.2819829E-05,   3.3580760E-05,   3.4356472E-05
     +,   3.5147899E-05,   3.5956196E-05,   3.6782516E-05
     +,   3.7628164E-05,   3.8494545E-05,   3.9383056E-05
     +,   4.0295177E-05,   4.1232463E-05,   4.2196494E-05
     +,   4.3188778E-05,   4.4210898E-05,   4.5264253E-05
     +,   4.6350331E-05,   4.7470348E-05,   4.8625534E-05
     +,   4.9816801E-05,   5.1045030E-05,   5.2310701E-05
     +,   5.3614167E-05,   5.4955493E-05,   5.6334378E-05
     +,   5.7750127E-05,   5.9201826E-05,   6.0688199E-05
     +,   6.2207451E-05,   6.3757558E-05,   6.5335924E-05
     +,   6.6939800E-05,   6.8565845E-05,   7.0210554E-05
     +,   7.1869908E-05,   7.3539755E-05,   7.5215466E-05
     +,   7.6892393E-05,   7.8565616E-05,   8.0230020E-05
     +,   8.1880360E-05,   8.3511542E-05,   8.5118380E-05
     +,   8.6695720E-05,   8.8238703E-05,   8.9742491E-05
     +,   9.1202695E-05,   9.2615031E-05,   9.3975854E-05
     +,   9.5281670E-05,   9.6529664E-05,   9.7717377E-05
     +,   9.8842997E-05,   9.9905272E-05,   1.0090345E-04
     +,   1.0183754E-04,   1.0270802E-04,   1.0351621E-04
     +,   1.0426384E-04,   1.0495335E-04,   1.0558785E-04
     +,   1.0617112E-04,   1.0670735E-04,   1.0720148E-04
     +,   1.0765901E-04,   1.0808594E-04,   1.0848891E-04
     +,   1.0887511E-04,   1.0925226E-04,   1.0962871E-04
     +,   1.1001329E-04,   1.1041565E-04,   1.1084587E-04
     +,   1.1131484E-04,   1.1183420E-04,   1.1241635E-04
     +,   1.1307470E-04,   1.1382344E-04,   1.1467811E-04
     +,   1.1565544E-04,   1.1677343E-04,   1.1805186E-04
     +,   1.1951229E-04,   1.2117859E-04,   1.2307710E-04
     +,   1.2523736E-04,   1.2769272E-04,   1.3048136E-04
     +,   1.3364683E-04,   1.3723965E-04,   1.4131911E-04
     +,   1.4595466E-04,   1.5122762E-04,   1.5723392E-04
     +,   1.6408585E-04,   1.7191374E-04,   1.8086706E-04
     +,   1.9111644E-04,   2.0285248E-04,   2.1628331E-04
     +,   2.3163133E-04,   2.4912888E-04,   2.6900994E-04
     +,   2.9149928E-04,   3.1680151E-04,   3.4509168E-04
     +,   3.7650100E-04,   4.1110264E-04,   4.4890944E-04
     +,   4.8986619E-04,   5.3384731E-04,   5.8066618E-04
     +,   6.3009141E-04,   6.8186643E-04,   7.3573174E-04
     +,   7.9146272E-04,   8.4890687E-04,   9.0802007E-04
     +,   9.6889742E-04,   1.0318042E-03,   1.0972103E-03
     +,   1.1657963E-03,   1.2384590E-03,   1.3163147E-03
     +,   1.4006831E-03,   1.4930351E-03,   1.5949436E-03
     +,   1.7079978E-03,   1.8336872E-03,   1.9732742E-03
     +,   2.1277308E-03,   2.2977542E-03,   2.4839332E-03
     +,   2.6870368E-03,   2.9084606E-03,   3.1506203E-03
     +,   3.4170097E-03,   3.7116704E-03,   4.0379697E-03
     +,   4.3965643E-03,   4.7830804E-03,   5.1863817E-03
     +,   5.5885366E-03,   5.9676268E-03,   6.3042846E-03
     +,   6.5917801E-03,   6.8475143E-03,   7.1212710E-03
     +,   7.4941749E-03,   8.0653224E-03,   8.9288969E-03
     +,   1.0147403E-02,   1.1721981E-02,   1.3565415E-02
     +,   1.5508295E-02,   1.7380878E-02,   1.9153241E-02
     +,   2.1017361E-02,   2.3273759E-02,   2.6052812E-02
     +,   2.9170049E-02,   3.2310512E-02,   3.5287037E-02
     +,   3.8110666E-02,   4.0889177E-02,   4.3666124E-02
     +,   4.6438444E-02,   4.9386661E-02,   5.2853052E-02
     +,   5.6593657E-02,   5.9529837E-02,   6.1066613E-02
     +,   6.1671969E-02,   6.1604157E-02,   6.0414385E-02
     +,   5.7941828E-02,   5.5551562E-02,   5.4509293E-02
     +,   5.4367062E-02,   5.4014616E-02,   5.1753547E-02
     +,   4.6666566E-02,   4.0098939E-02,   3.3938147E-02
     +,   2.8960006E-02,   2.4973204E-02,   2.1566151E-02
     +,   1.8582804E-02,   1.5991716E-02,   1.3672037E-02
     +,   1.1497469E-02,   9.4579607E-03,   7.6274299E-03
     +,   6.0714390E-03,   4.8030051E-03,   3.7933434E-03
     +,   2.9970387E-03,   2.3696765E-03,   1.8744495E-03
     +,   1.4830341E-03,   1.1737908E-03,   9.2993770E-04
     +,   7.3810393E-04,   5.8761443E-04,   4.6994633E-04
     +,   3.7832346E-04,   3.0732554E-04,   2.5254651E-04
     +,   2.1039070E-04,   1.7791880E-04,   1.5277008E-04
     +,   1.3308240E-04,   1.1742932E-04,   1.0474149E-04
     +,   9.4238552E-05,   8.5358886E-05,   7.7705343E-05
     +,   7.0997026E-05,   6.5036467E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt110 = Yx/0.387
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0468071E-06,   8.1394655E-06
     +,   8.2306633E-06,   8.3205086E-06,   8.4091216E-06
     +,   8.4966359E-06,   8.5832044E-06,   8.6689861E-06
     +,   8.7541566E-06,   8.8389070E-06,   8.9234391E-06
     +,   9.0079684E-06,   9.0927224E-06,   9.1779448E-06
     +,   9.2638866E-06,   9.3508133E-06,   9.4390070E-06
     +,   9.5287551E-06,   9.6203594E-06,   9.7141383E-06
     +,   9.8104147E-06,   9.9095287E-06,   1.0011830E-05
     +,   1.0117682E-05,   1.0227453E-05,   1.0341536E-05
     +,   1.0460324E-05,   1.0584231E-05,   1.0713675E-05
     +,   1.0849095E-05,   1.0990935E-05,   1.1139658E-05
     +,   1.1295736E-05,   1.1459655E-05,   1.1631918E-05
     +,   1.1813033E-05,   1.2003526E-05,   1.2203933E-05
     +,   1.2414815E-05,   1.2636717E-05,   1.2870226E-05
     +,   1.3115920E-05,   1.3374394E-05,   1.3646248E-05
     +,   1.3932088E-05,   1.4232525E-05,   1.4548176E-05
     +,   1.4879657E-05,   1.5227572E-05,   1.5592534E-05
     +,   1.5975131E-05,   1.6375949E-05,   1.6795548E-05
     +,   1.7234488E-05,   1.7693257E-05,   1.8172361E-05
     +,   1.8672234E-05,   1.9193283E-05,   1.9735853E-05
     +,   2.0300244E-05,   2.0886688E-05,   2.1495352E-05
     +,   2.2126300E-05,   2.2779552E-05,   2.3455050E-05
     +,   2.4152561E-05,   2.4871857E-05,   2.5612500E-05
     +,   2.6374040E-05,   2.7155804E-05,   2.7957109E-05
     +,   2.8777034E-05,   2.9614637E-05,   3.0468749E-05
     +,   3.1338142E-05,   3.2221466E-05,   3.3117169E-05
     +,   3.4023593E-05,   3.4939007E-05,   3.5861554E-05
     +,   3.6789184E-05,   3.7719856E-05,   3.8651327E-05
     +,   3.9581351E-05,   4.0507533E-05,   4.1427491E-05
     +,   4.2338688E-05,   4.3238670E-05,   4.4124834E-05
     +,   4.4994667E-05,   4.5845645E-05,   4.6675221E-05
     +,   4.7480891E-05,   4.8260255E-05,   4.9010985E-05
     +,   4.9730788E-05,   5.0417540E-05,   5.1069161E-05
     +,   5.1683815E-05,   5.2259726E-05,   5.2795342E-05
     +,   5.3289245E-05,   5.3740248E-05,   5.4147342E-05
     +,   5.4509757E-05,   5.4826909E-05,   5.5098462E-05
     +,   5.5324308E-05,   5.5504563E-05,   5.5639612E-05
     +,   5.5730063E-05,   5.5776774E-05,   5.5780853E-05
     +,   5.5743618E-05,   5.5666664E-05,   5.5551824E-05
     +,   5.5401146E-05,   5.5216908E-05,   5.5001674E-05
     +,   5.4758140E-05,   5.4489286E-05,   5.4198284E-05
     +,   5.3888554E-05,   5.3563661E-05,   5.3227421E-05
     +,   5.2883861E-05,   5.2537140E-05,   5.2191681E-05
     +,   5.1852036E-05,   5.1522977E-05,   5.1209441E-05
     +,   5.0916522E-05,   5.0649491E-05,   5.0413761E-05
     +,   5.0214872E-05,   5.0058505E-05,   4.9950468E-05
     +,   4.9896618E-05,   4.9902916E-05,   4.9975348E-05
     +,   5.0119910E-05,   5.0342598E-05,   5.0649360E-05
     +,   5.1046027E-05,   5.1538307E-05,   5.2131756E-05
     +,   5.2831692E-05,   5.3643173E-05,   5.4570868E-05
     +,   5.5619214E-05,   5.6792192E-05,   5.8093334E-05
     +,   5.9525624E-05,   6.1091669E-05,   6.2793544E-05
     +,   6.4632732E-05,   6.6610104E-05,   6.8726215E-05
     +,   7.0981143E-05,   7.3374293E-05,   7.5904987E-05
     +,   7.8572208E-05,   8.1374688E-05,   8.4310988E-05
     +,   8.7379995E-05,   9.0580776E-05,   9.3912604E-05
     +,   9.7375203E-05,   1.0096929E-04,   1.0469642E-04
     +,   1.0855900E-04,   1.1256062E-04,   1.1670661E-04
     +,   1.2100377E-04,   1.2546043E-04,   1.3008731E-04
     +,   1.3489739E-04,   1.3990585E-04,   1.4513076E-04
     +,   1.5059367E-04,   1.5631982E-04,   1.6233852E-04
     +,   1.6868381E-04,   1.7539598E-04,   1.8252229E-04
     +,   1.9011753E-04,   1.9824608E-04,   2.0698445E-04
     +,   2.1642298E-04,   2.2666744E-04,   2.3784433E-04
     +,   2.5010321E-04,   2.6361915E-04,   2.7859758E-04
     +,   2.9527745E-04,   3.1393275E-04,   3.3487027E-04
     +,   3.5842819E-04,   3.8497022E-04,   4.1487397E-04
     +,   4.4851287E-04,   4.8623819E-04,   5.2835722E-04
     +,   5.7510776E-04,   6.2662718E-04,   6.8294251E-04
     +,   7.4395310E-04,   8.0942665E-04,   8.7901735E-04
     +,   9.5230696E-04,   1.0288564E-03,   1.1082777E-03
     +,   1.1903311E-03,   1.2750254E-03,   1.3627032E-03
     +,   1.4540826E-03,   1.5502588E-03,   1.6526252E-03
     +,   1.7626946E-03,   1.8818355E-03,   2.0110034E-03
     +,   2.1504513E-03,   2.2995565E-03,   2.4568427E-03
     +,   2.6203454E-03,   2.7883358E-03,   2.9605622E-03
     +,   3.1399790E-03,   3.3346715E-03,   3.5593372E-03
     +,   3.8352185E-03,   4.1874032E-03,   4.6391618E-03
     +,   5.2047991E-03,   5.8845305E-03,   6.6654207E-03
     +,   7.5292620E-03,   8.4645199E-03,   9.4771590E-03
     +,   1.0594680E-02,   1.1857760E-02,   1.3296402E-02
     +,   1.4900946E-02,   1.6620856E-02,   1.8413916E-02
     +,   2.0284293E-02,   2.2200014E-02,   2.3979412E-02
     +,   2.5474735E-02,   2.7007982E-02,   2.9315041E-02
     +,   3.2658566E-02,   3.6227629E-02,   3.8977228E-02
     +,   4.0883355E-02,   4.2900607E-02,   4.6260796E-02
     +,   5.1580023E-02,   5.7741404E-02,   6.2556498E-02
     +,   6.4262740E-02,   6.3773558E-02,   6.4893052E-02
     +,   6.9053538E-02,   7.2286814E-02,   7.0482261E-02
     +,   6.4232439E-02,   5.6857586E-02,   5.1028866E-02
     +,   4.6907462E-02,   4.2907670E-02,   3.7857663E-02
     +,   3.1723615E-02,   2.5357204E-02,   1.9733334E-02
     +,   1.5248231E-02,   1.1781390E-02,   9.0897130E-03
     +,   6.9862115E-03,   5.3411415E-03,   4.0600304E-03
     +,   3.0732246E-03,   2.3254065E-03,   1.7679216E-03
     +,   1.3563131E-03,   1.0521912E-03,   8.2507066E-04
     +,   6.5262325E-04,   5.1936478E-04,   4.1479210E-04
     +,   3.3179045E-04,   2.6541049E-04,   2.1210547E-04
     +,   1.6922248E-04,   1.3472179E-04,   1.0698770E-04
     +,   8.4728781E-05,   6.6898654E-05,   5.2651289E-05
     +,   4.1297430E-05,   3.2277901E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt112 = Yx/0.375285714285714
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9462219E-05,   1.9977098E-05
     +,   2.0496622E-05,   2.1020282E-05,   2.1547563E-05
     +,   2.2077929E-05,   2.2610833E-05,   2.3145696E-05
     +,   2.3681940E-05,   2.4218994E-05,   2.4756260E-05
     +,   2.5293130E-05,   2.5829015E-05,   2.6363317E-05
     +,   2.6895445E-05,   2.7424812E-05,   2.7950860E-05
     +,   2.8473021E-05,   2.8990771E-05,   2.9503592E-05
     +,   3.0010988E-05,   3.0512507E-05,   3.1007716E-05
     +,   3.1496242E-05,   3.1977710E-05,   3.2451819E-05
     +,   3.2918320E-05,   3.3376997E-05,   3.3827662E-05
     +,   3.4270241E-05,   3.4704673E-05,   3.5130968E-05
     +,   3.5549208E-05,   3.5959529E-05,   3.6362144E-05
     +,   3.6757323E-05,   3.7145415E-05,   3.7526846E-05
     +,   3.7902100E-05,   3.8271741E-05,   3.8636430E-05
     +,   3.8996852E-05,   3.9353825E-05,   3.9708182E-05
     +,   4.0060881E-05,   4.0412906E-05,   4.0765346E-05
     +,   4.1119329E-05,   4.1476062E-05,   4.1836822E-05
     +,   4.2202912E-05,   4.2575713E-05,   4.2956650E-05
     +,   4.3347198E-05,   4.3748823E-05,   4.4163095E-05
     +,   4.4591536E-05,   4.5035729E-05,   4.5497229E-05
     +,   4.5977620E-05,   4.6478450E-05,   4.7001260E-05
     +,   4.7547532E-05,   4.8118720E-05,   4.8716251E-05
     +,   4.9341394E-05,   4.9995440E-05,   5.0679500E-05
     +,   5.1394636E-05,   5.2141731E-05,   5.2921605E-05
     +,   5.3734821E-05,   5.4581920E-05,   5.5463108E-05
     +,   5.6378529E-05,   5.7328092E-05,   5.8311482E-05
     +,   5.9328107E-05,   6.0377242E-05,   6.1457889E-05
     +,   6.2568790E-05,   6.3708445E-05,   6.4875057E-05
     +,   6.6066692E-05,   6.7281006E-05,   6.8515561E-05
     +,   6.9767506E-05,   7.1033930E-05,   7.2311486E-05
     +,   7.3596799E-05,   7.4886266E-05,   7.6175958E-05
     +,   7.7461846E-05,   7.8739817E-05,   8.0005608E-05
     +,   8.1254766E-05,   8.2482911E-05,   8.3685445E-05
     +,   8.4857980E-05,   8.5995882E-05,   8.7094806E-05
     +,   8.8150300E-05,   8.9158202E-05,   9.0114321E-05
     +,   9.1014757E-05,   9.1855851E-05,   9.2634087E-05
     +,   9.3346272E-05,   9.3989504E-05,   9.4561263E-05
     +,   9.5059288E-05,   9.5481832E-05,   9.5827359E-05
     +,   9.6094918E-05,   9.6283889E-05,   9.6394157E-05
     +,   9.6425989E-05,   9.6380187E-05,   9.6257943E-05
     +,   9.6060969E-05,   9.5791387E-05,   9.5451818E-05
     +,   9.5045347E-05,   9.4575451E-05,   9.4046081E-05
     +,   9.3461626E-05,   9.2826856E-05,   9.2146976E-05
     +,   9.1427544E-05,   9.0674599E-05,   8.9894391E-05
     +,   8.9093708E-05,   8.8279550E-05,   8.7459332E-05
     +,   8.6640808E-05,   8.5831984E-05,   8.5041247E-05
     +,   8.4277388E-05,   8.3549356E-05,   8.2866514E-05
     +,   8.2238483E-05,   8.1675265E-05,   8.1187165E-05
     +,   8.0784710E-05,   8.0478814E-05,   8.0280639E-05
     +,   8.0201637E-05,   8.0253572E-05,   8.0448408E-05
     +,   8.0798338E-05,   8.1315819E-05,   8.2013365E-05
     +,   8.2903658E-05,   8.3999439E-05,   8.5313477E-05
     +,   8.6858417E-05,   8.8646702E-05,   9.0690599E-05
     +,   9.3002127E-05,   9.5592506E-05,   9.8472665E-05
     +,   1.0165276E-04,   1.0514190E-04,   1.0894819E-04
     +,   1.1307857E-04,   1.1753888E-04,   1.2233309E-04
     +,   1.2746334E-04,   1.3293049E-04,   1.3873339E-04
     +,   1.4486857E-04,   1.5133046E-04,   1.5811190E-04
     +,   1.6520388E-04,   1.7259469E-04,   1.8027224E-04
     +,   1.8822285E-04,   1.9643200E-04,   2.0488504E-04
     +,   2.1356864E-04,   2.2247116E-04,   2.3158311E-04
     +,   2.4089949E-04,   2.5042120E-04,   2.6015687E-04
     +,   2.7012438E-04,   2.8035327E-04,   2.9088967E-04
     +,   3.0179863E-04,   3.1316743E-04,   3.2511289E-04
     +,   3.3778712E-04,   3.5138233E-04,   3.6614027E-04
     +,   3.8235934E-04,   4.0040197E-04,   4.2069884E-04
     +,   4.4375187E-04,   4.7013766E-04,   5.0049898E-04
     +,   5.3553417E-04,   5.7597808E-04,   6.2258355E-04
     +,   6.7608588E-04,   7.3716242E-04,   8.0640014E-04
     +,   8.8424806E-04,   9.7096805E-04,   1.0665923E-03
     +,   1.1708953E-03,   1.2833527E-03,   1.4031167E-03
     +,   1.5290140E-03,   1.6595691E-03,   1.7930417E-03
     +,   1.9274838E-03,   2.0608525E-03,   2.1911524E-03
     +,   2.3165739E-03,   2.4356565E-03,   2.5474674E-03
     +,   2.6517326E-03,   2.7489443E-03,   2.8404307E-03
     +,   2.9283876E-03,   3.0158593E-03,   3.1066798E-03
     +,   3.2053990E-03,   3.3171466E-03,   3.4474088E-03
     +,   3.6016395E-03,   3.7847147E-03,   4.0002069E-03
     +,   4.2496151E-03,   4.5319814E-03,   4.8446218E-03
     +,   5.1855929E-03,   5.5584898E-03,   5.9790718E-03
     +,   6.4816400E-03,   7.1206312E-03,   7.9616839E-03
     +,   9.0589337E-03,   1.0424946E-02,   1.2012874E-02
     +,   1.3730861E-02,   1.5480015E-02,   1.7173983E-02
     +,   1.8721772E-02,   2.0035258E-02,   2.1129413E-02
     +,   2.2244936E-02,   2.3807921E-02,   2.6149262E-02
     +,   2.9190522E-02,   3.2467149E-02,   3.5606910E-02
     +,   3.8775083E-02,   4.2375371E-02,   4.6287917E-02
     +,   4.9935445E-02,   5.3367801E-02,   5.7470836E-02
     +,   6.2159564E-02,   6.5518752E-02,   6.6275403E-02
     +,   6.5306716E-02,   6.3431025E-02,   6.0724657E-02
     +,   5.7582352E-02,   5.4110888E-02,   5.0198328E-02
     +,   4.5832902E-02,   4.0635008E-02,   3.4436844E-02
     +,   2.7894367E-02,   2.1865893E-02,   1.6769337E-02
     +,   1.2621199E-02,   9.3194479E-03,   6.7748032E-03
     +,   4.8925946E-03,   3.5476089E-03,   2.6056222E-03
     +,   1.9503112E-03,   1.4923194E-03,   1.1665100E-03
     +,   9.2772377E-04,   7.4654631E-04,   6.0483237E-04
     +,   4.9165101E-04,   4.0018858E-04,   3.2589806E-04
     +,   2.6548342E-04,   2.1642902E-04,   1.7673183E-04
     +,   1.4476736E-04,   1.1918187E-04,   9.8835641E-05
     +,   8.2754406E-05,   7.0108967E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt113 = Yx/0.354142857142857
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8375011E-05,   2.9292192E-05
     +,   3.0199299E-05,   3.1093499E-05,   3.1971937E-05
     +,   3.2831762E-05,   3.3670141E-05,   3.4484274E-05
     +,   3.5271405E-05,   3.6028887E-05,   3.6754154E-05
     +,   3.7444715E-05,   3.8098256E-05,   3.8712587E-05
     +,   3.9285682E-05,   3.9815706E-05,   4.0301009E-05
     +,   4.0740139E-05,   4.1131876E-05,   4.1475221E-05
     +,   4.1769406E-05,   4.2013908E-05,   4.2208470E-05
     +,   4.2353062E-05,   4.2447897E-05,   4.2493470E-05
     +,   4.2490497E-05,   4.2439948E-05,   4.2343025E-05
     +,   4.2201165E-05,   4.2016032E-05,   4.1789473E-05
     +,   4.1523563E-05,   4.1220552E-05,   4.0882860E-05
     +,   4.0513056E-05,   4.0113879E-05,   3.9688162E-05
     +,   3.9238872E-05,   3.8769082E-05,   3.8281920E-05
     +,   3.7780588E-05,   3.7268372E-05,   3.6748545E-05
     +,   3.6224461E-05,   3.5699446E-05,   3.5176861E-05
     +,   3.4660054E-05,   3.4152345E-05,   3.3657045E-05
     +,   3.3177428E-05,   3.2716758E-05,   3.2278225E-05
     +,   3.1865005E-05,   3.1480220E-05,   3.1126958E-05
     +,   3.0808227E-05,   3.0527026E-05,   3.0286286E-05
     +,   3.0088893E-05,   2.9937662E-05,   2.9835384E-05
     +,   2.9784776E-05,   2.9788494E-05,   2.9849138E-05
     +,   2.9969231E-05,   3.0151219E-05,   3.0397452E-05
     +,   3.0710202E-05,   3.1091597E-05,   3.1543666E-05
     +,   3.2068248E-05,   3.2667082E-05,   3.3341632E-05
     +,   3.4093217E-05,   3.4922930E-05,   3.5831537E-05
     +,   3.6819514E-05,   3.7887057E-05,   3.9034046E-05
     +,   4.0259853E-05,   4.1563595E-05,   4.2943804E-05
     +,   4.4398708E-05,   4.5925877E-05,   4.7522575E-05
     +,   4.9185346E-05,   5.0910403E-05,   5.2693216E-05
     +,   5.4528860E-05,   5.6411907E-05,   5.8336285E-05
     +,   6.0295377E-05,   6.2282226E-05,   6.4289452E-05
     +,   6.6309010E-05,   6.8332774E-05,   7.0352027E-05
     +,   7.2358074E-05,   7.4341733E-05,   7.6293953E-05
     +,   7.8205376E-05,   8.0066900E-05,   8.1869286E-05
     +,   8.3603685E-05,   8.5261461E-05,   8.6834239E-05
     +,   8.8314067E-05,   8.9693596E-05,   9.0966067E-05
     +,   9.2125229E-05,   9.3165749E-05,   9.4082854E-05
     +,   9.4872790E-05,   9.5532545E-05,   9.6060117E-05
     +,   9.6454300E-05,   9.6714961E-05,   9.6842858E-05
     +,   9.6839700E-05,   9.6708121E-05,   9.6451688E-05
     +,   9.6074844E-05,   9.5582807E-05,   9.4981624E-05
     +,   9.4278097E-05,   9.3479655E-05,   9.2594324E-05
     +,   9.1630609E-05,   9.0597619E-05,   8.9504618E-05
     +,   8.8361354E-05,   8.7177621E-05,   8.5963526E-05
     +,   8.4729058E-05,   8.3484229E-05,   8.2239043E-05
     +,   8.1003302E-05,   7.9786558E-05,   7.8598052E-05
     +,   7.7446792E-05,   7.6341385E-05,   7.5289958E-05
     +,   7.4300202E-05,   7.3379379E-05,   7.2534182E-05
     +,   7.1770824E-05,   7.1094968E-05,   7.0511771E-05
     +,   7.0025824E-05,   6.9641181E-05,   6.9361406E-05
     +,   6.9189555E-05,   6.9128182E-05,   6.9179412E-05
     +,   6.9344926E-05,   6.9626018E-05,   7.0023649E-05
     +,   7.0538437E-05,   7.1170747E-05,   7.1920789E-05
     +,   7.2788578E-05,   7.3774070E-05,   7.4877156E-05
     +,   7.6097851E-05,   7.7436409E-05,   7.8893165E-05
     +,   8.0468868E-05,   8.2164821E-05,   8.3982959E-05
     +,   8.5925894E-05,   8.7997127E-05,   9.0201473E-05
     +,   9.2545124E-05,   9.5035648E-05,   9.7682765E-05
     +,   1.0049852E-04,   1.0349747E-04,   1.0669722E-04
     +,   1.1011928E-04,   1.1378937E-04,   1.1773784E-04
     +,   1.2200070E-04,   1.2662042E-04,   1.3164672E-04
     +,   1.3713691E-04,   1.4315690E-04,   1.4978247E-04
     +,   1.5709936E-04,   1.6520330E-04,   1.7420153E-04
     +,   1.8421264E-04,   1.9536595E-04,   2.0780246E-04
     +,   2.2167542E-04,   2.3715169E-04,   2.5441137E-04
     +,   2.7365194E-04,   2.9509369E-04,   3.1898511E-04
     +,   3.4560991E-04,   3.7529797E-04,   4.0843966E-04
     +,   4.4549676E-04,   4.8700770E-04,   5.3360168E-04
     +,   5.8599300E-04,   6.4496166E-04,   7.1132672E-04
     +,   7.8590092E-04,   8.6942199E-04,   9.6245989E-04
     +,   1.0653306E-03,   1.1780171E-03,   1.3000945E-03
     +,   1.4306935E-03,   1.5685405E-03,   1.7120696E-03
     +,   1.8596011E-03,   2.0095722E-03,   2.1608716E-03
     +,   2.3131107E-03,   2.4668491E-03,   2.6237131E-03
     +,   2.7863574E-03,   2.9582407E-03,   3.1432989E-03
     +,   3.3456266E-03,   3.5692451E-03,   3.8179983E-03
     +,   4.0954608E-03,   4.4047032E-03,   4.7477577E-03
     +,   5.1247398E-03,   5.5331751E-03,   5.9684366E-03
     +,   6.4256429E-03,   6.9025443E-03,   7.4015153E-03
     +,   7.9284357E-03,   8.4882630E-03,   9.0817669E-03
     +,   9.7101796E-03,   1.0389860E-02,   1.1166048E-02
     +,   1.2103741E-02,   1.3242953E-02,   1.4541660E-02
     +,   1.5864408E-02,   1.7057491E-02,   1.8072825E-02
     +,   1.9029656E-02,   2.0139243E-02,   2.1555813E-02
     +,   2.3302585E-02,   2.5310360E-02,   2.7465427E-02
     +,   2.9640010E-02,   3.1779416E-02,   3.4080088E-02
     +,   3.7159618E-02,   4.1713126E-02,   4.7519445E-02
     +,   5.3168707E-02,   5.7227980E-02,   5.9416927E-02
     +,   6.0715541E-02,   6.2064197E-02,   6.3241780E-02
     +,   6.4009443E-02,   6.4046092E-02,   6.1810855E-02
     +,   5.6458212E-02,   4.9319126E-02,   4.2267911E-02
     +,   3.6003236E-02,   3.0225169E-02,   2.4654808E-02
     +,   1.9413035E-02,   1.4806297E-02,   1.1076975E-02
     +,   8.2748001E-03,   6.2586572E-03,   4.8065782E-03
     +,   3.7239224E-03,   2.8842248E-03,   2.2177217E-03
     +,   1.6872522E-03,   1.2701426E-03,   9.4860554E-04
     +,   7.0622470E-04,   5.2725326E-04,   3.9720390E-04
     +,   3.0349058E-04,   2.3588375E-04,   1.8653342E-04
     +,   1.4975123E-04,   1.2160192E-04,   9.9479577E-05
     +,   8.1703554E-05,   6.7204441E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt114 = Yx/0.346645833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt1148(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0506379E-06,   4.1635153E-06
     +,   4.2778315E-06,   4.3935752E-06,   4.5107427E-06
     +,   4.6293367E-06,   4.7493581E-06,   4.8708193E-06
     +,   4.9937325E-06,   5.1181228E-06,   5.2440178E-06
     +,   5.3714521E-06,   5.5004693E-06,   5.6311255E-06
     +,   5.7634784E-06,   5.8976002E-06,   6.0335792E-06
     +,   6.1715032E-06,   6.3114817E-06,   6.4536334E-06
     +,   6.5980971E-06,   6.7450183E-06,   6.8945601E-06
     +,   7.0469150E-06,   7.2022699E-06,   7.3608535E-06
     +,   7.5229050E-06,   7.6886836E-06,   7.8584762E-06
     +,   8.0325872E-06,   8.2113556E-06,   8.3951354E-06
     +,   8.5843203E-06,   8.7793260E-06,   8.9805999E-06
     +,   9.1886259E-06,   9.4039196E-06,   9.6270223E-06
     +,   9.8585369E-06,   1.0099070E-05,   1.0349298E-05
     +,   1.0609924E-05,   1.0881692E-05,   1.1165392E-05
     +,   1.1461851E-05,   1.1771952E-05,   1.2096611E-05
     +,   1.2436793E-05,   1.2793508E-05,   1.3167808E-05
     +,   1.3560788E-05,   1.3973582E-05,   1.4407361E-05
     +,   1.4863358E-05,   1.5342790E-05,   1.5846957E-05
     +,   1.6377155E-05,   1.6934706E-05,   1.7520948E-05
     +,   1.8137232E-05,   1.8784909E-05,   1.9465333E-05
     +,   2.0179803E-05,   2.0929643E-05,   2.1716152E-05
     +,   2.2540502E-05,   2.3403920E-05,   2.4307448E-05
     +,   2.5252159E-05,   2.6238909E-05,   2.7268577E-05
     +,   2.8341783E-05,   2.9459143E-05,   3.0620969E-05
     +,   3.1827542E-05,   3.3078926E-05,   3.4374956E-05
     +,   3.5715217E-05,   3.7099162E-05,   3.8526046E-05
     +,   3.9994713E-05,   4.1503950E-05,   4.3052110E-05
     +,   4.4637454E-05,   4.6257810E-05,   4.7910904E-05
     +,   4.9594029E-05,   5.1304400E-05,   5.3038752E-05
     +,   5.4793778E-05,   5.6565896E-05,   5.8351230E-05
     +,   6.0145674E-05,   6.1945051E-05,   6.3745058E-05
     +,   6.5541040E-05,   6.7328539E-05,   6.9102716E-05
     +,   7.0858980E-05,   7.2592469E-05,   7.4298601E-05
     +,   7.5972646E-05,   7.7610181E-05,   7.9206751E-05
     +,   8.0758218E-05,   8.2260689E-05,   8.3710438E-05
     +,   8.5104053E-05,   8.6438551E-05,   8.7711371E-05
     +,   8.8920176E-05,   9.0063346E-05,   9.1139467E-05
     +,   9.2147900E-05,   9.3088311E-05,   9.3961076E-05
     +,   9.4767071E-05,   9.5507814E-05,   9.6185322E-05
     +,   9.6802331E-05,   9.7362128E-05,   9.7868586E-05
     +,   9.8326193E-05,   9.8740034E-05,   9.9115845E-05
     +,   9.9459765E-05,   9.9778634E-05,   1.0007968E-04
     +,   1.0037077E-04,   1.0066012E-04,   1.0095647E-04
     +,   1.0126893E-04,   1.0160697E-04,   1.0198041E-04
     +,   1.0239939E-04,   1.0287424E-04,   1.0341551E-04
     +,   1.0403393E-04,   1.0474021E-04,   1.0554534E-04
     +,   1.0646001E-04,   1.0749496E-04,   1.0866077E-04
     +,   1.0996783E-04,   1.1142608E-04,   1.1304519E-04
     +,   1.1483443E-04,   1.1680236E-04,   1.1895680E-04
     +,   1.2130503E-04,   1.2385350E-04,   1.2660747E-04
     +,   1.2957129E-04,   1.3274810E-04,   1.3614006E-04
     +,   1.3974770E-04,   1.4357004E-04,   1.4760507E-04
     +,   1.5184910E-04,   1.5629656E-04,   1.6094078E-04
     +,   1.6577357E-04,   1.7078497E-04,   1.7596371E-04
     +,   1.8129773E-04,   1.8677392E-04,   1.9237833E-04
     +,   1.9809675E-04,   2.0391542E-04,   2.0982137E-04
     +,   2.1580243E-04,   2.2184892E-04,   2.2795379E-04
     +,   2.3411440E-04,   2.4033154E-04,   2.4661244E-04
     +,   2.5297099E-04,   2.5942764E-04,   2.6601137E-04
     +,   2.7276014E-04,   2.7972134E-04,   2.8695064E-04
     +,   2.9451319E-04,   3.0248263E-04,   3.1094006E-04
     +,   3.1997138E-04,   3.2966613E-04,   3.4011519E-04
     +,   3.5140789E-04,   3.6362736E-04,   3.7684981E-04
     +,   3.9114067E-04,   4.0655027E-04,   4.2311393E-04
     +,   4.4085164E-04,   4.5976762E-04,   4.7985031E-04
     +,   5.0107815E-04,   5.2342552E-04,   5.4686924E-04
     +,   5.7139411E-04,   5.9700524E-04,   6.2374008E-04
     +,   6.5167673E-04,   6.8093947E-04,   7.1171334E-04
     +,   7.4424502E-04,   7.7884365E-04,   8.1588229E-04
     +,   8.5579790E-04,   8.9908903E-04,   9.4631431E-04
     +,   9.9810422E-04,   1.0551815E-03,   1.1183833E-03
     +,   1.1886891E-03,   1.2672554E-03,   1.3554319E-03
     +,   1.4547427E-03,   1.5668044E-03,   1.6932132E-03
     +,   1.8353376E-03,   1.9940631E-03,   2.1695697E-03
     +,   2.3612201E-03,   2.5676670E-03,   2.7873002E-03
     +,   3.0191576E-03,   3.2641990E-03,   3.5266900E-03
     +,   3.8153026E-03,   4.1433908E-03,   4.5278389E-03
     +,   4.9859756E-03,   5.5304249E-03,   6.1626486E-03
     +,   6.8666278E-03,   7.6060495E-03,   8.3294185E-03
     +,   8.9856349E-03,   9.5473854E-03,   1.0032138E-02
     +,   1.0506580E-02,   1.1065586E-02,   1.1790128E-02
     +,   1.2702613E-02,   1.3744150E-02,   1.4792718E-02
     +,   1.5723806E-02,   1.6488362E-02,   1.7160228E-02
     +,   1.7904451E-02,   1.8865662E-02,   2.0064965E-02
     +,   2.1429749E-02,   2.2936501E-02,   2.4659945E-02
     +,   2.6665175E-02,   2.9000105E-02,   3.1813700E-02
     +,   3.5186477E-02,   3.8917985E-02,   4.2919595E-02
     +,   4.7318216E-02,   5.1765170E-02,   5.5672128E-02
     +,   5.8965996E-02,   6.1536595E-02,   6.2659837E-02
     +,   6.1671302E-02,   5.8879811E-02,   5.5435441E-02
     +,   5.1941805E-02,   4.8182774E-02,   4.4044554E-02
     +,   3.9533202E-02,   3.4628209E-02,   2.9387884E-02
     +,   2.3923535E-02,   1.8492062E-02,   1.3555051E-02
     +,   9.5408745E-03,   6.5859808E-03,   4.5505473E-03
     +,   3.1930353E-03,   2.2976636E-03,   1.7061136E-03
     +,   1.3084778E-03,   1.0312253E-03,   8.2822994E-04
     +,   6.7259895E-04,   5.4925180E-04,   4.4963235E-04
     +,   3.6849690E-04,   3.0229150E-04,   2.4834505E-04
     +,   2.0452614E-04,   1.6906118E-04,   1.4046064E-04
     +,   1.1746243E-04,   9.9007266E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt1148 = Yx/0.338916666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1821288E-05,   3.2486791E-05
     +,   3.3155691E-05,   3.3828084E-05,   3.4504123E-05
     +,   3.5183995E-05,   3.5867939E-05,   3.6556241E-05
     +,   3.7249207E-05,   3.7947240E-05,   3.8650720E-05
     +,   3.9360104E-05,   4.0075858E-05,   4.0798484E-05
     +,   4.1528543E-05,   4.2266547E-05,   4.3013075E-05
     +,   4.3768698E-05,   4.4533983E-05,   4.5309484E-05
     +,   4.6095745E-05,   4.6893285E-05,   4.7702575E-05
     +,   4.8524085E-05,   4.9358165E-05,   5.0205159E-05
     +,   5.1065315E-05,   5.1938794E-05,   5.2825682E-05
     +,   5.3725948E-05,   5.4639462E-05,   5.5565964E-05
     +,   5.6505094E-05,   5.7456316E-05,   5.8419009E-05
     +,   5.9392380E-05,   6.0375507E-05,   6.1367267E-05
     +,   6.2366511E-05,   6.3371779E-05,   6.4381602E-05
     +,   6.5394292E-05,   6.6408073E-05,   6.7420973E-05
     +,   6.8430949E-05,   6.9435846E-05,   7.0433358E-05
     +,   7.1421149E-05,   7.2396761E-05,   7.3357718E-05
     +,   7.4301468E-05,   7.5225420E-05,   7.6127020E-05
     +,   7.7003722E-05,   7.7852943E-05,   7.8672230E-05
     +,   7.9459161E-05,   8.0211408E-05,   8.0926780E-05
     +,   8.1603161E-05,   8.2238636E-05,   8.2831408E-05
     +,   8.3379920E-05,   8.3882740E-05,   8.4338732E-05
     +,   8.4746869E-05,   8.5106454E-05,   8.5416992E-05
     +,   8.5678250E-05,   8.5890177E-05,   8.6053064E-05
     +,   8.6167391E-05,   8.6233900E-05,   8.6253596E-05
     +,   8.6227672E-05,   8.6157612E-05,   8.6045067E-05
     +,   8.5891872E-05,   8.5700092E-05,   8.5471955E-05
     +,   8.5209846E-05,   8.4916217E-05,   8.4593747E-05
     +,   8.4245134E-05,   8.3873150E-05,   8.3480656E-05
     +,   8.3070554E-05,   8.2645667E-05,   8.2208913E-05
     +,   8.1763130E-05,   8.1311126E-05,   8.0855592E-05
     +,   8.0399244E-05,   7.9944592E-05,   7.9494079E-05
     +,   7.9050013E-05,   7.8614583E-05,   7.8189834E-05
     +,   7.7777608E-05,   7.7379642E-05,   7.6997509E-05
     +,   7.6632590E-05,   7.6286073E-05,   7.5959084E-05
     +,   7.5652511E-05,   7.5367017E-05,   7.5103257E-05
     +,   7.4861673E-05,   7.4642543E-05,   7.4446019E-05
     +,   7.4272182E-05,   7.4120937E-05,   7.3992167E-05
     +,   7.3885582E-05,   7.3800882E-05,   7.3737676E-05
     +,   7.3695534E-05,   7.3673953E-05,   7.3672469E-05
     +,   7.3690586E-05,   7.3727766E-05,   7.3783573E-05
     +,   7.3857525E-05,   7.3949253E-05,   7.4058371E-05
     +,   7.4184682E-05,   7.4327960E-05,   7.4488169E-05
     +,   7.4665375E-05,   7.4859759E-05,   7.5071730E-05
     +,   7.5301803E-05,   7.5550706E-05,   7.5819429E-05
     +,   7.6109158E-05,   7.6421347E-05,   7.6757751E-05
     +,   7.7120414E-05,   7.7511744E-05,   7.7934477E-05
     +,   7.8391749E-05,   7.8887075E-05,   7.9424390E-05
     +,   8.0008213E-05,   8.0643331E-05,   8.1335202E-05
     +,   8.2089704E-05,   8.2913321E-05,   8.3812891E-05
     +,   8.4796018E-05,   8.5870779E-05,   8.7045744E-05
     +,   8.8330089E-05,   8.9733512E-05,   9.1266316E-05
     +,   9.2939226E-05,   9.4763447E-05,   9.6750795E-05
     +,   9.8913573E-05,   1.0126441E-04,   1.0381651E-04
     +,   1.0658360E-04,   1.0957971E-04,   1.1281922E-04
     +,   1.1631731E-04,   1.2008953E-04,   1.2415186E-04
     +,   1.2852054E-04,   1.3321282E-04,   1.3824648E-04
     +,   1.4363954E-04,   1.4941054E-04,   1.5557911E-04
     +,   1.6216528E-04,   1.6918906E-04,   1.7667169E-04
     +,   1.8463454E-04,   1.9309929E-04,   2.0208726E-04
     +,   2.1162099E-04,   2.2172276E-04,   2.3241453E-04
     +,   2.4371821E-04,   2.5565655E-04,   2.6825251E-04
     +,   2.8152901E-04,   2.9550979E-04,   3.1022122E-04
     +,   3.2569171E-04,   3.4195147E-04,   3.5903684E-04
     +,   3.7699012E-04,   3.9585994E-04,   4.1570482E-04
     +,   4.3659814E-04,   4.5862814E-04,   4.8190248E-04
     +,   5.0655217E-04,   5.3273881E-04,   5.6065735E-04
     +,   5.9053832E-04,   6.2265235E-04,   6.5731362E-04
     +,   6.9487636E-04,   7.3572726E-04,   7.8028324E-04
     +,   8.2897994E-04,   8.8225375E-04,   9.4053888E-04
     +,   1.0042628E-03,   1.0738561E-03,   1.1497668E-03
     +,   1.2325086E-03,   1.3227289E-03,   1.4212808E-03
     +,   1.5292870E-03,   1.6482035E-03,   1.7798212E-03
     +,   1.9261851E-03,   2.0893938E-03,   2.2713316E-03
     +,   2.4732943E-03,   2.6955910E-03,   2.9372647E-03
     +,   3.1960211E-03,   3.4684374E-03,   3.7504917E-03
     +,   4.0383488E-03,   4.3292032E-03,   4.6218596E-03
     +,   4.9168961E-03,   5.2164146E-03,   5.5235694E-03
     +,   5.8421325E-03,   6.1763758E-03,   6.5314239E-03
     +,   6.9138389E-03,   7.3326672E-03,   7.8011504E-03
     +,   8.3387215E-03,   8.9716967E-03,   9.7299237E-03
     +,   1.0637565E-02,   1.1699868E-02,   1.2892223E-02
     +,   1.4160082E-02,   1.5434037E-02,   1.6655438E-02
     +,   1.7800163E-02,   1.8885499E-02,   1.9951072E-02
     +,   2.1022905E-02,   2.2091143E-02,   2.3123367E-02
     +,   2.4093125E-02,   2.4990218E-02,   2.5835477E-02
     +,   2.6746886E-02,   2.7986750E-02,   2.9819611E-02
     +,   3.2213133E-02,   3.4771331E-02,   3.7129484E-02
     +,   3.9299216E-02,   4.1357327E-02,   4.2966370E-02
     +,   4.3672275E-02,   4.3662980E-02,   4.3729506E-02
     +,   4.4308040E-02,   4.4907223E-02,   4.4560634E-02
     +,   4.2611778E-02,   3.9115824E-02,   3.4693409E-02
     +,   3.0064851E-02,   2.5691431E-02,   2.1733709E-02
     +,   1.8181361E-02,   1.4982797E-02,   1.2115886E-02
     +,   9.6017569E-03,   7.4729132E-03,   5.7361145E-03
     +,   4.3608858E-03,   3.2944516E-03,   2.4798806E-03
     +,   1.8658877E-03,   1.4086544E-03,   1.0710371E-03
     +,   8.2228566E-04,   6.3791644E-04,   4.9949391E-04
     +,   3.9380023E-04,   3.1176207E-04,   2.4725610E-04
     +,   1.9613736E-04,   1.5549033E-04,   1.2316830E-04
     +,   9.7504031E-05,   7.7167264E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt116 = Yx/0.3031875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.2416373E-06,   4.4528038E-06
     +,   4.6721470E-06,   4.8998609E-06,   5.1361394E-06
     +,   5.3811759E-06,   5.6351564E-06,   5.8982737E-06
     +,   6.1707051E-06,   6.4526430E-06,   6.7442647E-06
     +,   7.0457431E-06,   7.3572505E-06,   7.6789547E-06
     +,   8.0110176E-06,   8.3535915E-06,   8.7068329E-06
     +,   9.0708745E-06,   9.4458646E-06,   9.8319197E-06
     +,   1.0229167E-05,   1.0637711E-05,   1.1057650E-05
     +,   1.1489090E-05,   1.1932082E-05,   1.2386714E-05
     +,   1.2853035E-05,   1.3331081E-05,   1.3820882E-05
     +,   1.4322452E-05,   1.4835784E-05,   1.5360860E-05
     +,   1.5897647E-05,   1.6446091E-05,   1.7006121E-05
     +,   1.7577649E-05,   1.8160577E-05,   1.8754767E-05
     +,   1.9360112E-05,   1.9976402E-05,   2.0603502E-05
     +,   2.1241205E-05,   2.1889304E-05,   2.2547565E-05
     +,   2.3215751E-05,   2.3893623E-05,   2.4580911E-05
     +,   2.5277346E-05,   2.5982645E-05,   2.6696538E-05
     +,   2.7418744E-05,   2.8148990E-05,   2.8887003E-05
     +,   2.9632572E-05,   3.0385418E-05,   3.1145373E-05
     +,   3.1912252E-05,   3.2685919E-05,   3.3466298E-05
     +,   3.4253357E-05,   3.5047127E-05,   3.5847730E-05
     +,   3.6655299E-05,   3.7470170E-05,   3.8292706E-05
     +,   3.9123366E-05,   3.9962808E-05,   4.0811730E-05
     +,   4.1671043E-05,   4.2541735E-05,   4.3425029E-05
     +,   4.4322223E-05,   4.5234901E-05,   4.6164663E-05
     +,   4.7113434E-05,   4.8083264E-05,   4.9076360E-05
     +,   5.0095092E-05,   5.1142044E-05,   5.2219992E-05
     +,   5.3331743E-05,   5.4480377E-05,   5.5668956E-05
     +,   5.6900801E-05,   5.8179103E-05,   5.9507300E-05
     +,   6.0888677E-05,   6.2326624E-05,   6.3824329E-05
     +,   6.5384993E-05,   6.7011679E-05,   6.8707152E-05
     +,   7.0473892E-05,   7.2314237E-05,   7.4230134E-05
     +,   7.6222961E-05,   7.8293881E-05,   8.0443286E-05
     +,   8.2671271E-05,   8.4977088E-05,   8.7359527E-05
     +,   8.9816465E-05,   9.2345377E-05,   9.4942552E-05
     +,   9.7603886E-05,   1.0032442E-04,   1.0309821E-04
     +,   1.0591859E-04,   1.0877822E-04,   1.1166908E-04
     +,   1.1458209E-04,   1.1750794E-04,   1.2043630E-04
     +,   1.2335669E-04,   1.2625771E-04,   1.2912801E-04
     +,   1.3195556E-04,   1.3472847E-04,   1.3743449E-04
     +,   1.4006157E-04,   1.4259777E-04,   1.4503130E-04
     +,   1.4735080E-04,   1.4954548E-04,   1.5160516E-04
     +,   1.5352028E-04,   1.5528228E-04,   1.5688334E-04
     +,   1.5831694E-04,   1.5957748E-04,   1.6066067E-04
     +,   1.6156350E-04,   1.6228421E-04,   1.6282243E-04
     +,   1.6317927E-04,   1.6335715E-04,   1.6335995E-04
     +,   1.6319286E-04,   1.6286256E-04,   1.6237692E-04
     +,   1.6174515E-04,   1.6097770E-04,   1.6008610E-04
     +,   1.5908286E-04,   1.5798159E-04,   1.5679662E-04
     +,   1.5554309E-04,   1.5423681E-04,   1.5289411E-04
     +,   1.5153171E-04,   1.5016664E-04,   1.4881618E-04
     +,   1.4749786E-04,   1.4622910E-04,   1.4502725E-04
     +,   1.4390986E-04,   1.4289412E-04,   1.4199718E-04
     +,   1.4123603E-04,   1.4062763E-04,   1.4018889E-04
     +,   1.3993670E-04,   1.3988817E-04,   1.4006069E-04
     +,   1.4047207E-04,   1.4114084E-04,   1.4208634E-04
     +,   1.4332890E-04,   1.4489028E-04,   1.4679378E-04
     +,   1.4906436E-04,   1.5172902E-04,   1.5481713E-04
     +,   1.5836045E-04,   1.6239319E-04,   1.6695265E-04
     +,   1.7207909E-04,   1.7781583E-04,   1.8420910E-04
     +,   1.9130915E-04,   1.9916968E-04,   2.0784767E-04
     +,   2.1740320E-04,   2.2790088E-04,   2.3940820E-04
     +,   2.5199537E-04,   2.6573424E-04,   2.8069885E-04
     +,   2.9696408E-04,   3.1460100E-04,   3.3367987E-04
     +,   3.5426591E-04,   3.7641689E-04,   4.0018215E-04
     +,   4.2560470E-04,   4.5272062E-04,   4.8156141E-04
     +,   5.1215937E-04,   5.4456317E-04,   5.7884667E-04
     +,   6.1512913E-04,   6.5360026E-04,   6.9455325E-04
     +,   7.3841633E-04,   7.8578596E-04,   8.3746464E-04
     +,   8.9448626E-04,   9.5811859E-04,   1.0298508E-03
     +,   1.1113477E-03,   1.2043521E-03,   1.3105451E-03
     +,   1.4313761E-03,   1.5678833E-03,   1.7205119E-03
     +,   1.8889811E-03,   2.0722654E-03,   2.2686988E-03
     +,   2.4761937E-03,   2.6925365E-03,   2.9157831E-03
     +,   3.1445439E-03,   3.3781163E-03,   3.6164422E-03
     +,   3.8598592E-03,   4.1086962E-03,   4.3628504E-03
     +,   4.6216529E-03,   4.8841117E-03,   5.1496900E-03
     +,   5.4195207E-03,   5.6979833E-03,   5.9940401E-03
     +,   6.3217664E-03,   6.6995164E-03,   7.1470663E-03
     +,   7.6802876E-03,   8.3038136E-03,   9.0039019E-03
     +,   9.7455923E-03,   1.0478499E-02,   1.1153195E-02
     +,   1.1742868E-02,   1.2258071E-02,   1.2743050E-02
     +,   1.3254977E-02,   1.3840574E-02,   1.4522882E-02
     +,   1.5295876E-02,   1.6122224E-02,   1.6946709E-02
     +,   1.7733257E-02,   1.8498601E-02,   1.9309936E-02
     +,   2.0273861E-02,   2.1551887E-02,   2.3332169E-02
     +,   2.5670931E-02,   2.8332947E-02,   3.0891115E-02
     +,   3.3048961E-02,   3.4791194E-02,   3.6167115E-02
     +,   3.7073959E-02,   3.7462771E-02,   3.7705798E-02
     +,   3.8405780E-02,   3.9619748E-02,   4.0573113E-02
     +,   4.0513813E-02,   3.9540585E-02,   3.8133584E-02
     +,   3.6255859E-02,   3.3481982E-02,   2.9767059E-02
     +,   2.5632460E-02,   2.1683866E-02,   1.8213689E-02
     +,   1.5218533E-02,   1.2599636E-02,   1.0289998E-02
     +,   8.2752183E-03,   6.5636672E-03,   5.1547820E-03
     +,   4.0247529E-03,   3.1323601E-03,   2.4318253E-03
     +,   1.8829572E-03,   1.4544294E-03,   1.1223069E-03
     +,   8.6754176E-04,   6.7406410E-04,   5.2816834E-04
     +,   4.1839367E-04,   3.3556449E-04,   2.7258895E-04
     +,   2.2416370E-04,   1.8638760E-04,   1.5643760E-04
     +,   1.3228352E-04,   1.1248377E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt117 = Yx/0.282234042553192
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8112505E-05,   1.8798217E-05
     +,   1.9512559E-05,   2.0256160E-05,   2.1029582E-05
     +,   2.1833281E-05,   2.2667668E-05,   2.3533023E-05
     +,   2.4429539E-05,   2.5357323E-05,   2.6316337E-05
     +,   2.7306418E-05,   2.8327282E-05,   2.9378509E-05
     +,   3.0459525E-05,   3.1569623E-05,   3.2707932E-05
     +,   3.3873446E-05,   3.5064968E-05,   3.6281173E-05
     +,   3.7520564E-05,   3.8781494E-05,   4.0062154E-05
     +,   4.1360629E-05,   4.2674736E-05,   4.4002318E-05
     +,   4.5340959E-05,   4.6688183E-05,   4.8041362E-05
     +,   4.9397804E-05,   5.0754687E-05,   5.2109153E-05
     +,   5.3458254E-05,   5.4799024E-05,   5.6128429E-05
     +,   5.7443445E-05,   5.8741072E-05,   6.0018279E-05
     +,   6.1272185E-05,   6.2499792E-05,   6.3698375E-05
     +,   6.4865169E-05,   6.5997607E-05,   6.7093184E-05
     +,   6.8149624E-05,   6.9164744E-05,   7.0136579E-05
     +,   7.1063339E-05,   7.1943505E-05,   7.2775671E-05
     +,   7.3558745E-05,   7.4291820E-05,   7.4974261E-05
     +,   7.5605698E-05,   7.6185941E-05,   7.6715121E-05
     +,   7.7193574E-05,   7.7621909E-05,   7.8000936E-05
     +,   7.8331759E-05,   7.8615682E-05,   7.8854195E-05
     +,   7.9049052E-05,   7.9202109E-05,   7.9315520E-05
     +,   7.9391502E-05,   7.9432473E-05,   7.9440964E-05
     +,   7.9419588E-05,   7.9371101E-05,   7.9298305E-05
     +,   7.9204059E-05,   7.9091275E-05,   7.8962803E-05
     +,   7.8821649E-05,   7.8670622E-05,   7.8512639E-05
     +,   7.8350487E-05,   7.8186931E-05,   7.8024575E-05
     +,   7.7866054E-05,   7.7713776E-05,   7.7570105E-05
     +,   7.7437304E-05,   7.7317425E-05,   7.7212440E-05
     +,   7.7124212E-05,   7.7054385E-05,   7.7004515E-05
     +,   7.6976008E-05,   7.6970136E-05,   7.6988043E-05
     +,   7.7030731E-05,   7.7099110E-05,   7.7193945E-05
     +,   7.7315904E-05,   7.7465607E-05,   7.7643541E-05
     +,   7.7850156E-05,   7.8085788E-05,   7.8350837E-05
     +,   7.8645549E-05,   7.8970224E-05,   7.9325109E-05
     +,   7.9710517E-05,   8.0126672E-05,   8.0573955E-05
     +,   8.1052633E-05,   8.1563099E-05,   8.2105798E-05
     +,   8.2681159E-05,   8.3289742E-05,   8.3932093E-05
     +,   8.4608866E-05,   8.5320673E-05,   8.6068307E-05
     +,   8.6852437E-05,   8.7673921E-05,   8.8533510E-05
     +,   8.9431975E-05,   9.0370173E-05,   9.1348818E-05
     +,   9.2368522E-05,   9.3430004E-05,   9.4533782E-05
     +,   9.5680218E-05,   9.6869677E-05,   9.8102151E-05
     +,   9.9377692E-05,   1.0069588E-04,   1.0205636E-04
     +,   1.0345822E-04,   1.0490054E-04,   1.0638198E-04
     +,   1.0790093E-04,   1.0945558E-04,   1.1104372E-04
     +,   1.1266280E-04,   1.1431007E-04,   1.1598258E-04
     +,   1.1767690E-04,   1.1938944E-04,   1.2111650E-04
     +,   1.2285421E-04,   1.2459837E-04,   1.2634489E-04
     +,   1.2808965E-04,   1.2982842E-04,   1.3155710E-04
     +,   1.3327181E-04,   1.3496888E-04,   1.3664503E-04
     +,   1.3829711E-04,   1.3992263E-04,   1.4151970E-04
     +,   1.4308690E-04,   1.4462358E-04,   1.4612985E-04
     +,   1.4760680E-04,   1.4905627E-04,   1.5048140E-04
     +,   1.5188630E-04,   1.5327633E-04,   1.5465806E-04
     +,   1.5603982E-04,   1.5743147E-04,   1.5884459E-04
     +,   1.6029275E-04,   1.6179221E-04,   1.6336176E-04
     +,   1.6502326E-04,   1.6680233E-04,   1.6872887E-04
     +,   1.7083804E-04,   1.7317057E-04,   1.7577395E-04
     +,   1.7870360E-04,   1.8202332E-04,   1.8580644E-04
     +,   1.9013660E-04,   1.9510873E-04,   2.0082839E-04
     +,   2.0741203E-04,   2.1498687E-04,   2.2368964E-04
     +,   2.3366325E-04,   2.4505524E-04,   2.5801509E-04
     +,   2.7268939E-04,   2.8921600E-04,   3.0772196E-04
     +,   3.2831778E-04,   3.5109077E-04,   3.7610266E-04
     +,   4.0338744E-04,   4.3294893E-04,   4.6475732E-04
     +,   4.9875176E-04,   5.3484476E-04,   5.7292345E-04
     +,   6.1285059E-04,   6.5447245E-04,   6.9762632E-04
     +,   7.4214622E-04,   7.8786229E-04,   8.3462388E-04
     +,   8.8230264E-04,   9.3081227E-04,   9.8013144E-04
     +,   1.0303435E-03,   1.0816705E-03,   1.1345206E-03
     +,   1.1895511E-03,   1.2477254E-03,   1.3103671E-03
     +,   1.3791920E-03,   1.4563212E-03,   1.5442402E-03
     +,   1.6456785E-03,   1.7633914E-03,   1.8998713E-03
     +,   2.0569498E-03,   2.2353912E-03,   2.4345668E-03
     +,   2.6523829E-03,   2.8854823E-03,   3.1298539E-03
     +,   3.3817659E-03,   3.6388463E-03,   3.9009911E-03
     +,   4.1708909E-03,   4.4541722E-03,   4.7591380E-03
     +,   5.0961976E-03,   5.4769036E-03,   5.9124217E-03
     +,   6.4109508E-03,   6.9745290E-03,   7.5967796E-03
     +,   8.2633393E-03,   8.9559434E-03,   9.6582817E-03
     +,   1.0360267E-02,   1.1057514E-02,   1.1747047E-02
     +,   1.2423982E-02,   1.3082814E-02,   1.3721551E-02
     +,   1.4342604E-02,   1.4949175E-02,   1.5547846E-02
     +,   1.6170466E-02,   1.6907670E-02,   1.7905107E-02
     +,   1.9276442E-02,   2.0970566E-02,   2.2724975E-02
     +,   2.4198478E-02,   2.5200993E-02,   2.5831390E-02
     +,   2.6420366E-02,   2.7315892E-02,   2.8619289E-02
     +,   3.0045886E-02,   3.1107016E-02,   3.1552073E-02
     +,   3.1625900E-02,   3.1795863E-02,   3.2223172E-02
     +,   3.2552190E-02,   3.2198131E-02,   3.0813117E-02
     +,   2.8535282E-02,   2.5860935E-02,   2.3280742E-02
     +,   2.0992139E-02,   1.8896161E-02,   1.6804144E-02
     +,   1.4626033E-02,   1.2414263E-02,   1.0295022E-02
     +,   8.3826473E-03,   6.7339437E-03,   5.3503080E-03
     +,   4.2027137E-03,   3.2569338E-03,   2.4852937E-03
     +,   1.8671541E-03,   1.3845376E-03,   1.0185470E-03
     +,   7.4882887E-04,   5.5477582E-04,   4.1741243E-04
     +,   3.2070052E-04,   2.5215559E-04,   2.0269763E-04
     +,   1.6611406E-04,   1.3832515E-04,   1.1671431E-04
     +,   9.9585348E-05,   8.5802152E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt118 = Yx/0.241195652173913
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7692031E-05,   1.8056515E-05
     +,   1.8423256E-05,   1.8792154E-05,   1.9163119E-05
     +,   1.9536048E-05,   1.9910844E-05,   2.0287409E-05
     +,   2.0665640E-05,   2.1045447E-05,   2.1426731E-05
     +,   2.1809386E-05,   2.2193311E-05,   2.2578412E-05
     +,   2.2964581E-05,   2.3351720E-05,   2.3739722E-05
     +,   2.4128485E-05,   2.4517902E-05,   2.4907873E-05
     +,   2.5298292E-05,   2.5689049E-05,   2.6080035E-05
     +,   2.6471165E-05,   2.6862297E-05,   2.7253354E-05
     +,   2.7644228E-05,   2.8034809E-05,   2.8424993E-05
     +,   2.8814684E-05,   2.9203791E-05,   2.9592220E-05
     +,   2.9979878E-05,   3.0366693E-05,   3.0752592E-05
     +,   3.1137504E-05,   3.1521366E-05,   3.1904150E-05
     +,   3.2285825E-05,   3.2666361E-05,   3.3045770E-05
     +,   3.3424058E-05,   3.3801272E-05,   3.4177476E-05
     +,   3.4552759E-05,   3.4927220E-05,   3.5301033E-05
     +,   3.5674344E-05,   3.6047382E-05,   3.6420392E-05
     +,   3.6793681E-05,   3.7167567E-05,   3.7542446E-05
     +,   3.7918751E-05,   3.8296945E-05,   3.8677594E-05
     +,   3.9061273E-05,   3.9448645E-05,   3.9840426E-05
     +,   4.0237395E-05,   4.0640389E-05,   4.1050327E-05
     +,   4.1468156E-05,   4.1894942E-05,   4.2331812E-05
     +,   4.2779917E-05,   4.3240518E-05,   4.3714896E-05
     +,   4.4204473E-05,   4.4710629E-05,   4.5234909E-05
     +,   4.5778812E-05,   4.6343983E-05,   4.6932029E-05
     +,   4.7544647E-05,   4.8183585E-05,   4.8850558E-05
     +,   4.9547336E-05,   5.0275718E-05,   5.1037521E-05
     +,   5.1834471E-05,   5.2668405E-05,   5.3541025E-05
     +,   5.4454125E-05,   5.5409324E-05,   5.6408302E-05
     +,   5.7452591E-05,   5.8543759E-05,   5.9683152E-05
     +,   6.0872164E-05,   6.2112049E-05,   6.3403895E-05
     +,   6.4748659E-05,   6.6147273E-05,   6.7600515E-05
     +,   6.9108894E-05,   7.0672933E-05,   7.2292823E-05
     +,   7.3968789E-05,   7.5700656E-05,   7.7488279E-05
     +,   7.9331126E-05,   8.1228703E-05,   8.3180072E-05
     +,   8.5184263E-05,   8.7240158E-05,   8.9346169E-05
     +,   9.1500668E-05,   9.3701798E-05,   9.5947566E-05
     +,   9.8235476E-05,   1.0056314E-04,   1.0292759E-04
     +,   1.0532596E-04,   1.0775478E-04,   1.1021068E-04
     +,   1.1268973E-04,   1.1518801E-04,   1.1770104E-04
     +,   1.2022431E-04,   1.2275310E-04,   1.2528217E-04
     +,   1.2780605E-04,   1.3031923E-04,   1.3281590E-04
     +,   1.3528975E-04,   1.3773458E-04,   1.4014365E-04
     +,   1.4251033E-04,   1.4482760E-04,   1.4708846E-04
     +,   1.4928554E-04,   1.5141186E-04,   1.5345997E-04
     +,   1.5542266E-04,   1.5729289E-04,   1.5906358E-04
     +,   1.6072793E-04,   1.6227952E-04,   1.6371235E-04
     +,   1.6502074E-04,   1.6619961E-04,   1.6724465E-04
     +,   1.6815230E-04,   1.6891980E-04,   1.6954538E-04
     +,   1.7002858E-04,   1.7036991E-04,   1.7057142E-04
     +,   1.7063662E-04,   1.7057064E-04,   1.7038037E-04
     +,   1.7007480E-04,   1.6966465E-04,   1.6916322E-04
     +,   1.6858611E-04,   1.6795147E-04,   1.6728035E-04
     +,   1.6659690E-04,   1.6592839E-04,   1.6530590E-04
     +,   1.6476422E-04,   1.6434256E-04,   1.6408486E-04
     +,   1.6403993E-04,   1.6426240E-04,   1.6481290E-04
     +,   1.6575870E-04,   1.6717400E-04,   1.6914094E-04
     +,   1.7174907E-04,   1.7509623E-04,   1.7928831E-04
     +,   1.8443908E-04,   1.9066858E-04,   1.9810327E-04
     +,   2.0687348E-04,   2.1711053E-04,   2.2894422E-04
     +,   2.4249924E-04,   2.5789108E-04,   2.7521944E-04
     +,   2.9456359E-04,   3.1597930E-04,   3.3949129E-04
     +,   3.6508837E-04,   3.9272022E-04,   4.2229731E-04
     +,   4.5368972E-04,   4.8672478E-04,   5.2119856E-04
     +,   5.5687974E-04,   5.9351709E-04,   6.3085457E-04
     +,   6.6864816E-04,   7.0668082E-04,   7.4477575E-04
     +,   7.8281638E-04,   8.2076446E-04,   8.5866707E-04
     +,   8.9666288E-04,   9.3498413E-04,   9.7395753E-04
     +,   1.0139885E-03,   1.0555488E-03,   1.0991727E-03
     +,   1.1454484E-03,   1.1950192E-03,   1.2486082E-03
     +,   1.3070521E-03,   1.3713407E-03,   1.4426599E-03
     +,   1.5224156E-03,   1.6122460E-03,   1.7139680E-03
     +,   1.8294712E-03,   1.9605693E-03,   2.1088223E-03
     +,   2.2753149E-03,   2.4604669E-03,   2.6639136E-03
     +,   2.8844539E-03,   3.1200489E-03,   3.3679407E-03
     +,   3.6248555E-03,   3.8872014E-03,   4.1513457E-03
     +,   4.4139898E-03,   4.6726228E-03,   4.9259774E-03
     +,   5.1743975E-03,   5.4200571E-03,   5.6669302E-03
     +,   5.9205159E-03,   6.1875624E-03,   6.4760763E-03
     +,   6.7955442E-03,   7.1574221E-03,   7.5757108E-03
     +,   8.0669438E-03,   8.6486246E-03,   9.3345251E-03
     +,   1.0126397E-02,   1.1003807E-02,   1.1918864E-02
     +,   1.2805340E-02,   1.3606862E-02,   1.4314426E-02
     +,   1.4986940E-02,   1.5727881E-02,   1.6614534E-02
     +,   1.7622996E-02,   1.8621910E-02,   1.9468017E-02
     +,   2.0136194E-02,   2.0758741E-02,   2.1531148E-02
     +,   2.2583131E-02,   2.3922773E-02,   2.5433861E-02
     +,   2.6868230E-02,   2.7900888E-02,   2.8328249E-02
     +,   2.8261546E-02,   2.8069973E-02,   2.8094161E-02
     +,   2.8414473E-02,   2.8853340E-02,   2.9120121E-02
     +,   2.8933795E-02,   2.8096082E-02,   2.6564250E-02
     +,   2.4492303E-02,   2.2165824E-02,   1.9855935E-02
     +,   1.7708225E-02,   1.5736109E-02,   1.3885840E-02
     +,   1.2102633E-02,   1.0365649E-02,   8.6912774E-03
     +,   7.1196174E-03,   5.6952951E-03,   4.4531459E-03
     +,   3.4104809E-03,   2.5666575E-03,   1.9062990E-03
     +,   1.4047978E-03,   1.0336961E-03,   7.6478708E-04
     +,   5.7286775E-04,   4.3695702E-04,   3.4062969E-04
     +,   2.7163982E-04,   2.2127926E-04,   1.8358105E-04
     +,   1.5459189E-04,   1.3173737E-04,   1.1335225E-04
     +,   9.8337681E-05,   8.5945889E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt119 = Yx/0.233739130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3168580E-06,   7.5777780E-06
     +,   7.8517551E-06,   8.1394510E-06,   8.4415360E-06
     +,   8.7586941E-06,   9.0916174E-06,   9.4410025E-06
     +,   9.8075425E-06,   1.0191949E-05,   1.0594908E-05
     +,   1.1017108E-05,   1.1459228E-05,   1.1921927E-05
     +,   1.2405845E-05,   1.2911607E-05,   1.3439800E-05
     +,   1.3990980E-05,   1.4565664E-05,   1.5164330E-05
     +,   1.5787407E-05,   1.6435268E-05,   1.7108217E-05
     +,   1.7806540E-05,   1.8530371E-05,   1.9279852E-05
     +,   2.0055009E-05,   2.0855781E-05,   2.1682024E-05
     +,   2.2533501E-05,   2.3409879E-05,   2.4310724E-05
     +,   2.5235493E-05,   2.6183543E-05,   2.7154118E-05
     +,   2.8146356E-05,   2.9159270E-05,   3.0191753E-05
     +,   3.1242645E-05,   3.2310578E-05,   3.3394150E-05
     +,   3.4491815E-05,   3.5601930E-05,   3.6722744E-05
     +,   3.7852416E-05,   3.8989005E-05,   4.0130479E-05
     +,   4.1274743E-05,   4.2419622E-05,   4.3562872E-05
     +,   4.4702203E-05,   4.5835270E-05,   4.6959689E-05
     +,   4.8073132E-05,   4.9173108E-05,   5.0257277E-05
     +,   5.1323244E-05,   5.2368654E-05,   5.3391192E-05
     +,   5.4388616E-05,   5.5358749E-05,   5.6299523E-05
     +,   5.7208905E-05,   5.8085061E-05,   5.8926300E-05
     +,   5.9730992E-05,   6.0497783E-05,   6.1225393E-05
     +,   6.1912848E-05,   6.2559287E-05,   6.3164160E-05
     +,   6.3727100E-05,   6.4248037E-05,   6.4727130E-05
     +,   6.5164837E-05,   6.5561937E-05,   6.5919477E-05
     +,   6.6238819E-05,   6.6521650E-05,   6.6770037E-05
     +,   6.6986300E-05,   6.7173169E-05,   6.7333684E-05
     +,   6.7471265E-05,   6.7589652E-05,   6.7692941E-05
     +,   6.7785593E-05,   6.7872381E-05,   6.7958441E-05
     +,   6.8049223E-05,   6.8150439E-05,   6.8268171E-05
     +,   6.8408721E-05,   6.8578658E-05,   6.8784801E-05
     +,   6.9034133E-05,   6.9333808E-05,   6.9691152E-05
     +,   7.0113536E-05,   7.0608367E-05,   7.1183145E-05
     +,   7.1845177E-05,   7.2601826E-05,   7.3460120E-05
     +,   7.4427007E-05,   7.5509080E-05,   7.6712626E-05
     +,   7.8043391E-05,   7.9506710E-05,   8.1107428E-05
     +,   8.2849561E-05,   8.4736632E-05,   8.6771128E-05
     +,   8.8954934E-05,   9.1288835E-05,   9.3772760E-05
     +,   9.6405471E-05,   9.9184850E-05,   1.0210738E-04
     +,   1.0516857E-04,   1.0836284E-04,   1.1168313E-04
     +,   1.1512126E-04,   1.1866794E-04,   1.2231288E-04
     +,   1.2604411E-04,   1.2984930E-04,   1.3371445E-04
     +,   1.3762516E-04,   1.4156576E-04,   1.4552033E-04
     +,   1.4947185E-04,   1.5340339E-04,   1.5729730E-04
     +,   1.6113606E-04,   1.6490230E-04,   1.6857860E-04
     +,   1.7214815E-04,   1.7559483E-04,   1.7890353E-04
     +,   1.8205987E-04,   1.8505094E-04,   1.8786530E-04
     +,   1.9049337E-04,   1.9292708E-04,   1.9516086E-04
     +,   1.9719108E-04,   1.9901668E-04,   2.0063910E-04
     +,   2.0206260E-04,   2.0329429E-04,   2.0434412E-04
     +,   2.0522511E-04,   2.0595368E-04,   2.0654929E-04
     +,   2.0703478E-04,   2.0743649E-04,   2.0778405E-04
     +,   2.0811106E-04,   2.0845454E-04,   2.0885562E-04
     +,   2.0935929E-04,   2.1001490E-04,   2.1087610E-04
     +,   2.1200140E-04,   2.1345427E-04,   2.1530334E-04
     +,   2.1762266E-04,   2.2049247E-04,   2.2399853E-04
     +,   2.2823311E-04,   2.3329414E-04,   2.3928599E-04
     +,   2.4631893E-04,   2.5450820E-04,   2.6397401E-04
     +,   2.7484086E-04,   2.8723522E-04,   3.0128469E-04
     +,   3.1711737E-04,   3.3485974E-04,   3.5463239E-04
     +,   3.7654836E-04,   4.0071274E-04,   4.2721763E-04
     +,   4.5613703E-04,   4.8752417E-04,   5.2141037E-04
     +,   5.5780006E-04,   5.9666293E-04,   6.3793885E-04
     +,   6.8153278E-04,   7.2731444E-04,   7.7512104E-04
     +,   8.2476705E-04,   8.7604992E-04,   9.2875696E-04
     +,   9.8268013E-04,   1.0376344E-03,   1.0934626E-03
     +,   1.1500445E-03,   1.2072959E-03,   1.2651742E-03
     +,   1.3236586E-03,   1.3827196E-03,   1.4423144E-03
     +,   1.5023523E-03,   1.5626781E-03,   1.6230915E-03
     +,   1.6833816E-03,   1.7434033E-03,   1.8031887E-03
     +,   1.8630978E-03,   1.9239861E-03,   1.9873348E-03
     +,   2.0553183E-03,   2.1307827E-03,   2.2170458E-03
     +,   2.3175471E-03,   2.4353385E-03,   2.5725409E-03
     +,   2.7298396E-03,   2.9062186E-03,   3.0990841E-03
     +,   3.3048715E-03,   3.5200678E-03,   3.7424341E-03
     +,   3.9721061E-03,   4.2120903E-03,   4.4677900E-03
     +,   4.7454955E-03,   5.0502452E-03,   5.3837905E-03
     +,   5.7434221E-03,   6.1225179E-03,   6.5128431E-03
     +,   6.9078733E-03,   7.3058750E-03,   7.7113085E-03
     +,   8.1334766E-03,   8.5825669E-03,   9.0649258E-03
     +,   9.5806411E-03,   1.0125262E-02,   1.0694054E-02
     +,   1.1284161E-02,   1.1891318E-02,   1.2503193E-02
     +,   1.3097340E-02,   1.3649226E-02,   1.4148888E-02
     +,   1.4617415E-02,   1.5114847E-02,   1.5731635E-02
     +,   1.6559636E-02,   1.7650886E-02,   1.8984083E-02
     +,   2.0457203E-02,   2.1908812E-02,   2.3162499E-02
     +,   2.4093866E-02,   2.4712116E-02,   2.5202148E-02
     +,   2.5837982E-02,   2.6755877E-02,   2.7770393E-02
     +,   2.8469298E-02,   2.8541861E-02,   2.7995486E-02
     +,   2.7056849E-02,   2.5940960E-02,   2.4741318E-02
     +,   2.3454251E-02,   2.2025339E-02,   2.0385839E-02
     +,   1.8499253E-02,   1.6402455E-02,   1.4207622E-02
     +,   1.2060576E-02,   1.0088929E-02,   8.3688153E-03
     +,   6.9210432E-03,   5.7253316E-03,   4.7410852E-03
     +,   3.9245561E-03,   3.2396708E-03,   2.6611616E-03
     +,   2.1729067E-03,   1.7641531E-03,   1.4260079E-03
     +,   1.1496765E-03,   9.2597480E-04,   7.4586377E-04
     +,   6.0104951E-04,   4.8448073E-04,   3.9044139E-04
     +,   3.1445877E-04,   2.5303889E-04,   2.0343850E-04
     +,   1.6344886E-04,   1.3127027E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt120 = Yx/0.222478260869565
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1966017E-05,   4.4478202E-05
     +,   4.7146095E-05,   4.9977782E-05,   5.2981533E-05
     +,   5.6165885E-05,   5.9539503E-05,   6.3111285E-05
     +,   6.6890148E-05,   7.0885377E-05,   7.5106094E-05
     +,   7.9561614E-05,   8.4261170E-05,   8.9214074E-05
     +,   9.4429495E-05,   9.9916564E-05,   1.0568424E-04
     +,   1.1174128E-04,   1.1809632E-04,   1.2475763E-04
     +,   1.3173344E-04,   1.3903157E-04,   1.4665966E-04
     +,   1.5462546E-04,   1.6293609E-04,   1.7159931E-04
     +,   1.8062277E-04,   1.9001454E-04,   1.9978335E-04
     +,   2.0993901E-04,   2.2049264E-04,   2.3145725E-04
     +,   2.4284841E-04,   2.5468445E-04,   2.6698766E-04
     +,   2.7978493E-04,   2.9310890E-04,   3.0699841E-04
     +,   3.2150111E-04,   3.3667232E-04,   3.5257926E-04
     +,   3.6930060E-04,   3.8692859E-04,   4.0557151E-04
     +,   4.2535420E-04,   4.4642121E-04,   4.6893806E-04
     +,   4.9309293E-04,   5.1909906E-04,   5.4719637E-04
     +,   5.7765224E-04,   6.1076309E-04,   6.4685487E-04
     +,   6.8628433E-04,   7.2943134E-04,   7.7670411E-04
     +,   8.2852796E-04,   8.8534027E-04,   9.4758515E-04
     +,   1.0157023E-03,   1.0901254E-03,   1.1712821E-03
     +,   1.2595962E-03,   1.3555244E-03,   1.4595828E-03
     +,   1.5723947E-03,   1.6947720E-03,   1.8277606E-03
     +,   1.9727254E-03,   2.1313615E-03,   2.3057351E-03
     +,   2.4982155E-03,   2.7114619E-03,   2.9483158E-03
     +,   3.2118058E-03,   3.5051613E-03,   3.8319174E-03
     +,   4.1960855E-03,   4.6024318E-03,   5.0565354E-03
     +,   5.5646249E-03,   6.1332327E-03,   6.7684371E-03
     +,   7.4755927E-03,   8.2597136E-03,   9.1273552E-03
     +,   1.0088714E-02,   1.1159097E-02,   1.2357308E-02
     +,   1.3702050E-02,   1.5208686E-02,   1.6889598E-02
     +,   1.8759878E-02,   2.0844806E-02,   2.3182688E-02
     +,   2.5813630E-02,   2.8746305E-02,   3.1905834E-02
     +,   3.5098996E-02,   3.8046531E-02,   4.0503696E-02
     +,   4.2405874E-02,   4.3923408E-02,   4.5337718E-02
     +,   4.6789117E-02,   4.8085477E-02,   4.8776694E-02
     +,   4.8487090E-02,   4.7224537E-02,   4.5374114E-02
     +,   4.3390185E-02,   4.1498415E-02,   3.9663833E-02
     +,   3.7771117E-02,   3.5789616E-02,   3.3788428E-02
     +,   3.1855073E-02,   3.0023595E-02,   2.8265044E-02
     +,   2.6521398E-02,   2.4749566E-02,   2.2947539E-02
     +,   2.1153657E-02,   1.9427165E-02,   1.7825974E-02
     +,   1.6392551E-02,   1.5149250E-02,   1.4098575E-02
     +,   1.3224313E-02,   1.2494655E-02,   1.1868178E-02
     +,   1.1302993E-02,   1.0765557E-02,   1.0236619E-02
     +,   9.7121242E-03,   9.1999369E-03,   8.7142140E-03
     +,   8.2696332E-03,   7.8771897E-03,   7.5421170E-03
     +,   7.2636479E-03,   7.0360317E-03,   6.8500522E-03
     +,   6.6946726E-03,   6.5584052E-03,   6.4303786E-03
     +,   6.3011446E-03,   6.1632218E-03,   6.0113575E-03
     +,   5.8426391E-03,   5.6563308E-03,   5.4535805E-03
     +,   5.2369628E-03,   5.0099334E-03,   4.7763451E-03
     +,   4.5400285E-03,   4.3044323E-03,   4.0724045E-03
     +,   3.8461268E-03,   3.6271696E-03,   3.4165357E-03
     +,   3.2148350E-03,   3.0224333E-03,   2.8395751E-03
     +,   2.6664482E-03,   2.5032603E-03,   2.3502493E-03
     +,   2.2076657E-03,   2.0757357E-03,   1.9546277E-03
     +,   1.8444448E-03,   1.7451782E-03,   1.6567101E-03
     +,   1.5788113E-03,   1.5111717E-03,   1.4533955E-03
     +,   1.4050347E-03,   1.3656165E-03,   1.3346553E-03
     +,   1.3116647E-03,   1.2961748E-03,   1.2877381E-03
     +,   1.2859291E-03,   1.2903406E-03,   1.3005785E-03
     +,   1.3162553E-03,   1.3369763E-03,   1.3623341E-03
     +,   1.3918903E-03,   1.4251712E-03,   1.4616600E-03
     +,   1.5007907E-03,   1.5419407E-03,   1.5844411E-03
     +,   1.6275727E-03,   1.6705864E-03,   1.7127042E-03
     +,   1.7531425E-03,   1.7911340E-03,   1.8259468E-03
     +,   1.8568992E-03,   1.8833952E-03,   1.9049344E-03
     +,   1.9211387E-03,   1.9317544E-03,   1.9366709E-03
     +,   1.9359214E-03,   1.9296757E-03,   1.9182407E-03
     +,   1.9020368E-03,   1.8815860E-03,   1.8574885E-03
     +,   1.8303955E-03,   1.8009869E-03,   1.7699362E-03
     +,   1.7378982E-03,   1.7054824E-03,   1.6732246E-03
     +,   1.6415832E-03,   1.6109289E-03,   1.5815330E-03
     +,   1.5535671E-03,   1.5271109E-03,   1.5021593E-03
     +,   1.4786250E-03,   1.4563578E-03,   1.4351559E-03
     +,   1.4147829E-03,   1.3949743E-03,   1.3754618E-03
     +,   1.3559764E-03,   1.3362671E-03,   1.3161025E-03
     +,   1.2952825E-03,   1.2736425E-03,   1.2510556E-03
     +,   1.2274332E-03,   1.2027245E-03,   1.1769182E-03
     +,   1.1500319E-03,   1.1221148E-03,   1.0932432E-03
     +,   1.0635105E-03,   1.0330301E-03,   1.0019206E-03
     +,   9.7031484E-04,   9.3834597E-04,   9.0614706E-04
     +,   8.7384775E-04,   8.4157829E-04,   8.0945581E-04
     +,   7.7759364E-04,   7.4609549E-04,   7.1505789E-04
     +,   6.8456697E-04,   6.5469783E-04,   6.2551926E-04
     +,   5.9709168E-04,   5.6946330E-04,   5.4267677E-04
     +,   5.1676610E-04,   4.9175974E-04,   4.6767583E-04
     +,   4.4452664E-04,   4.2231986E-04,   4.0105480E-04
     +,   3.8072560E-04,   3.6132190E-04,   3.4282953E-04
     +,   3.2522742E-04,   3.0849199E-04,   2.9259664E-04
     +,   2.7751244E-04,   2.6320718E-04,   2.4964687E-04
     +,   2.3679802E-04,   2.2462472E-04,   2.1309219E-04
     +,   2.0216478E-04,   1.9180868E-04,   1.8198989E-04
     +,   1.7267682E-04,   1.6383821E-04,   1.5544544E-04
     +,   1.4747075E-04,   1.3988923E-04,   1.3267696E-04
     +,   1.2581196E-04,   1.1927476E-04,   1.1304674E-04
     +,   1.0711170E-04,   1.0145418E-04,   9.6060881E-05
     +,   9.0919100E-05,   8.6017841E-05,   8.1346494E-05
     +,   7.6895951E-05,   7.2657269E-05,   6.8622612E-05
     +,   6.4784217E-05,   6.1135237E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt75 = Yx/0.41216
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.9353904E-05,   9.2207476E-05
     +,   9.5060997E-05,   9.7911980E-05,   1.0075841E-04
     +,   1.0359878E-04,   1.0643219E-04,   1.0925847E-04
     +,   1.1207803E-04,   1.1489222E-04,   1.1770315E-04
     +,   1.2051380E-04,   1.2332817E-04,   1.2615111E-04
     +,   1.2898857E-04,   1.3184754E-04,   1.3473605E-04
     +,   1.3766310E-04,   1.4063885E-04,   1.4367449E-04
     +,   1.4678220E-04,   1.4997509E-04,   1.5326735E-04
     +,   1.5667402E-04,   1.6021069E-04,   1.6389391E-04
     +,   1.6774099E-04,   1.7176934E-04,   1.7599705E-04
     +,   1.8044248E-04,   1.8512391E-04,   1.9005983E-04
     +,   1.9526841E-04,   2.0076758E-04,   2.0657478E-04
     +,   2.1270677E-04,   2.1917952E-04,   2.2600793E-04
     +,   2.3320635E-04,   2.4078680E-04,   2.4876095E-04
     +,   2.5713831E-04,   2.6592697E-04,   2.7513312E-04
     +,   2.8476166E-04,   2.9481479E-04,   3.0529383E-04
     +,   3.1619775E-04,   3.2752412E-04,   3.3926961E-04
     +,   3.5142954E-04,   3.6399890E-04,   3.7697254E-04
     +,   3.9034736E-04,   4.0412019E-04,   4.1829323E-04
     +,   4.3287160E-04,   4.4786723E-04,   4.6329934E-04
     +,   4.7919783E-04,   4.9560424E-04,   5.1257509E-04
     +,   5.3018244E-04,   5.4852007E-04,   5.6770304E-04
     +,   5.8786874E-04,   6.0918409E-04,   6.3183979E-04
     +,   6.5605890E-04,   6.8209117E-04,   7.1021757E-04
     +,   7.4074534E-04,   7.7401270E-04,   8.1038085E-04
     +,   8.5024076E-04,   8.9401129E-04,   9.4213418E-04
     +,   9.9508103E-04,   1.0533567E-03,   1.1174983E-03
     +,   1.1880717E-03,   1.2656838E-03,   1.3509678E-03
     +,   1.4445991E-03,   1.5472835E-03,   1.6597935E-03
     +,   1.7829743E-03,   1.9178250E-03,   2.0655389E-03
     +,   2.2276293E-03,   2.4060172E-03,   2.6030878E-03
     +,   2.8217006E-03,   3.0651037E-03,   3.3366636E-03
     +,   3.6393725E-03,   3.9753146E-03,   4.3448457E-03
     +,   4.7460473E-03,   5.1742615E-03,   5.6224582E-03
     +,   6.0823136E-03,   6.5466906E-03,   7.0132557E-03
     +,   7.4893208E-03,   7.9969512E-03,   8.5767498E-03
     +,   9.2877848E-03,   1.0201039E-02,   1.1385313E-02
     +,   1.2888974E-02,   1.4725395E-02,   1.6868260E-02
     +,   1.9260174E-02,   2.1827588E-02,   2.4496855E-02
     +,   2.7204467E-02,   2.9901680E-02,   3.2556374E-02
     +,   3.5164207E-02,   3.7763570E-02,   4.0414222E-02
     +,   4.3109458E-02,   4.5691028E-02,   4.7874544E-02
     +,   4.9379900E-02,   5.0054748E-02,   4.9938902E-02
     +,   4.9281411E-02,   4.8454925E-02,   4.7757417E-02
     +,   4.7249839E-02,   4.6751220E-02,   4.5950022E-02
     +,   4.4588134E-02,   4.2670507E-02,   4.0509392E-02
     +,   3.8481027E-02,   3.6714084E-02,   3.5046127E-02
     +,   3.3253454E-02,   3.1263966E-02,   2.9162446E-02
     +,   2.7070811E-02,   2.5068639E-02,   2.3197642E-02
     +,   2.1489915E-02,   1.9970002E-02,   1.8640066E-02
     +,   1.7473176E-02,   1.6422197E-02,   1.5434084E-02
     +,   1.4462325E-02,   1.3475279E-02,   1.2461154E-02
     +,   1.1428365E-02,   1.0400531E-02,   9.4080875E-03
     +,   8.4795896E-03,   7.6351608E-03,   6.8834950E-03
     +,   6.2223915E-03,   5.6419116E-03,   5.1283892E-03
     +,   4.6682162E-03,   4.2505083E-03,   3.8682767E-03
     +,   3.5181579E-03,   3.1993696E-03,   2.9124615E-03
     +,   2.6581604E-03,   2.4366023E-03,   2.2470048E-03
     +,   2.0877123E-03,   1.9564615E-03,   1.8506520E-03
     +,   1.7676742E-03,   1.7051348E-03,   1.6609693E-03
     +,   1.6334913E-03,   1.6213767E-03,   1.6235952E-03
     +,   1.6393278E-03,   1.6678688E-03,   1.7085366E-03
     +,   1.7605841E-03,   1.8231334E-03,   1.8951242E-03
     +,   1.9752777E-03,   2.0620781E-03,   2.1537812E-03
     +,   2.2484416E-03,   2.3439345E-03,   2.4380223E-03
     +,   2.5284239E-03,   2.6128832E-03,   2.6892563E-03
     +,   2.7555944E-03,   2.8102361E-03,   2.8518799E-03
     +,   2.8796457E-03,   2.8931168E-03,   2.8923717E-03
     +,   2.8779677E-03,   2.8509116E-03,   2.8126040E-03
     +,   2.7647458E-03,   2.7092514E-03,   2.6481298E-03
     +,   2.5833689E-03,   2.5168329E-03,   2.4501702E-03
     +,   2.3847488E-03,   2.3215914E-03,   2.2613758E-03
     +,   2.2044370E-03,   2.1507973E-03,   2.1002085E-03
     +,   2.0522226E-03,   2.0062602E-03,   1.9616676E-03
     +,   1.9177921E-03,   1.8740260E-03,   1.8298537E-03
     +,   1.7848712E-03,   1.7388040E-03,   1.6915130E-03
     +,   1.6429814E-03,   1.5932980E-03,   1.5426360E-03
     +,   1.4912374E-03,   1.4393813E-03,   1.3873632E-03
     +,   1.3354758E-03,   1.2840007E-03,   1.2331882E-03
     +,   1.1832494E-03,   1.1343654E-03,   1.0866738E-03
     +,   1.0402743E-03,   9.9523342E-04,   9.5159351E-04
     +,   9.0937287E-04,   8.6857175E-04,   8.2917890E-04
     +,   7.9117826E-04,   7.5455086E-04,   7.1927352E-04
     +,   6.8532635E-04,   6.5269257E-04,   6.2135630E-04
     +,   5.9130177E-04,   5.6251785E-04,   5.3499214E-04
     +,   5.0870958E-04,   4.8365374E-04,   4.5980536E-04
     +,   4.3714241E-04,   4.1563637E-04,   3.9525426E-04
     +,   3.7596017E-04,   3.5771381E-04,   3.4046976E-04
     +,   3.2417962E-04,   3.0879444E-04,   2.9426193E-04
     +,   2.8052938E-04,   2.6754531E-04,   2.5525840E-04
     +,   2.4361906E-04,   2.3257927E-04,   2.2209430E-04
     +,   2.1212257E-04,   2.0262501E-04,   1.9356585E-04
     +,   1.8491344E-04,   1.7663850E-04,   1.6871575E-04
     +,   1.6112204E-04,   1.5383791E-04,   1.4684559E-04
     +,   1.4013036E-04,   1.3367858E-04,   1.2747936E-04
     +,   1.2152242E-04,   1.1579945E-04,   1.1030255E-04
     +,   1.0502466E-04,   9.9959980E-05,   9.5102376E-05
     +,   9.0446774E-05,   8.5987725E-05,   8.1720355E-05
     +,   7.7639481E-05,   7.3740426E-05,   7.0017879E-05
     +,   6.6467044E-05,   6.3082611E-05,   5.9859540E-05
     +,   5.6792418E-05,   5.3876094E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt80 = Yx/0.43456
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.7927060E-05,   6.9638576E-05
     +,   7.1365605E-05,   7.3107956E-05,   7.4865580E-05
     +,   7.6638440E-05,   7.8426674E-05,   8.0230478E-05
     +,   8.2050181E-05,   8.3886211E-05,   8.5739201E-05
     +,   8.7609718E-05,   8.9498652E-05,   9.1406895E-05
     +,   9.3335533E-05,   9.5285664E-05,   9.7258649E-05
     +,   9.9255878E-05,   1.0127884E-04,   1.0332916E-04
     +,   1.0540856E-04,   1.0751886E-04,   1.0966187E-04
     +,   1.1183966E-04,   1.1405410E-04,   1.1630743E-04
     +,   1.1860166E-04,   1.2093902E-04,   1.2332165E-04
     +,   1.2575185E-04,   1.2823186E-04,   1.3076392E-04
     +,   1.3335043E-04,   1.3599373E-04,   1.3869620E-04
     +,   1.4146029E-04,   1.4428854E-04,   1.4718356E-04
     +,   1.5014819E-04,   1.5318507E-04,   1.5629752E-04
     +,   1.5948869E-04,   1.6276211E-04,   1.6612165E-04
     +,   1.6957155E-04,   1.7311629E-04,   1.7676121E-04
     +,   1.8051178E-04,   1.8437445E-04,   1.8835628E-04
     +,   1.9246506E-04,   1.9670966E-04,   2.0109983E-04
     +,   2.0564665E-04,   2.1036214E-04,   2.1526020E-04
     +,   2.2035594E-04,   2.2566640E-04,   2.3121040E-04
     +,   2.3700898E-04,   2.4308542E-04,   2.4946581E-04
     +,   2.5617841E-04,   2.6325515E-04,   2.7073114E-04
     +,   2.7864493E-04,   2.8703912E-04,   2.9595985E-04
     +,   3.0545879E-04,   3.1559094E-04,   3.2641736E-04
     +,   3.3800330E-04,   3.5042007E-04,   3.6374311E-04
     +,   3.7805451E-04,   3.9344214E-04,   4.0999739E-04
     +,   4.2781787E-04,   4.4700646E-04,   4.6767222E-04
     +,   4.8992684E-04,   5.1389082E-04,   5.3968799E-04
     +,   5.6745339E-04,   5.9732870E-04,   6.2947185E-04
     +,   6.6405482E-04,   7.0127554E-04,   7.4135576E-04
     +,   7.8455469E-04,   8.3117333E-04,   8.8155438E-04
     +,   9.3609007E-04,   9.9522376E-04,   1.0594461E-03
     +,   1.1292766E-03,   1.2052705E-03,   1.2879814E-03
     +,   1.3779654E-03,   1.4757442E-03,   1.5818183E-03
     +,   1.6966414E-03,   1.8206610E-03,   1.9543197E-03
     +,   2.0981329E-03,   2.2527582E-03,   2.4190680E-03
     +,   2.5982845E-03,   2.7920869E-03,   3.0027251E-03
     +,   3.2330586E-03,   3.4866130E-03,   3.7674482E-03
     +,   4.0799896E-03,   4.4286489E-03,   4.8174523E-03
     +,   5.2495915E-03,   5.7272934E-03,   6.2518213E-03
     +,   6.8240082E-03,   7.4446518E-03,   8.1144795E-03
     +,   8.8330302E-03,   9.5966160E-03,   1.0396102E-02
     +,   1.1217111E-02,   1.2045308E-02,   1.2876944E-02
     +,   1.3731774E-02,   1.4660493E-02,   1.5739869E-02
     +,   1.7053725E-02,   1.8669762E-02,   2.0623432E-02
     +,   2.2916665E-02,   2.5522487E-02,   2.8385654E-02
     +,   3.1419776E-02,   3.4516517E-02,   3.7583526E-02
     +,   4.0604748E-02,   4.3664929E-02,   4.6873886E-02
     +,   5.0218936E-02,   5.3485036E-02,   5.6329839E-02
     +,   5.8429528E-02,   5.9574720E-02,   5.9700944E-02
     +,   5.8900360E-02,   5.7414271E-02,   5.5563726E-02
     +,   5.3617168E-02,   5.1676389E-02,   4.9663752E-02
     +,   4.7410138E-02,   4.4781260E-02,   4.1761436E-02
     +,   3.8459800E-02,   3.5065882E-02,   3.1781849E-02
     +,   2.8742883E-02,   2.5966743E-02,   2.3380948E-02
     +,   2.0905342E-02,   1.8516442E-02,   1.6250735E-02
     +,   1.4168251E-02,   1.2317308E-02,   1.0719735E-02
     +,   9.3729012E-03,   8.2575371E-03,   7.3456126E-03
     +,   6.6062487E-03,   6.0098665E-03,   5.5306479E-03
     +,   5.1478548E-03,   4.8457622E-03,   4.6127881E-03
     +,   4.4404650E-03,   4.3225870E-03,   4.2545884E-03
     +,   4.2330888E-03,   4.2554694E-03,   4.3194275E-03
     +,   4.4224109E-03,   4.5610918E-03,   4.7309413E-03
     +,   4.9259262E-03,   5.1384307E-03,   5.3595072E-03
     +,   5.5792839E-03,   5.7875565E-03,   5.9744935E-03
     +,   6.1313454E-03,   6.2510236E-03,   6.3284906E-03
     +,   6.3610668E-03,   6.3484451E-03,   6.2925704E-03
     +,   6.1973860E-03,   6.0684606E-03,   5.9125163E-03
     +,   5.7369466E-03,   5.5493154E-03,   5.3568124E-03
     +,   5.1658764E-03,   4.9818102E-03,   4.8085772E-03
     +,   4.6487246E-03,   4.5034038E-03,   4.3726009E-03
     +,   4.2553418E-03,   4.1499790E-03,   4.0544905E-03
     +,   3.9667217E-03,   3.8845630E-03,   3.8061005E-03
     +,   3.7296636E-03,   3.6538821E-03,   3.5776596E-03
     +,   3.5001705E-03,   3.4208281E-03,   3.3392869E-03
     +,   3.2553733E-03,   3.1691059E-03,   3.0806654E-03
     +,   2.9903692E-03,   2.8986416E-03,   2.8059809E-03
     +,   2.7129373E-03,   2.6200714E-03,   2.5279105E-03
     +,   2.4369229E-03,   2.3475112E-03,   2.2599730E-03
     +,   2.1745125E-03,   2.0912467E-03,   2.0102134E-03
     +,   1.9313820E-03,   1.8546797E-03,   1.7800218E-03
     +,   1.7073182E-03,   1.6364836E-03,   1.5674616E-03
     +,   1.5002228E-03,   1.4347687E-03,   1.3711182E-03
     +,   1.3093114E-03,   1.2494032E-03,   1.1914431E-03
     +,   1.1354756E-03,   1.0815385E-03,   1.0296487E-03
     +,   9.7980269E-04,   9.3197625E-04,   8.8612898E-04
     +,   8.4220292E-04,   8.0012524E-04,   7.5981225E-04
     +,   7.2117843E-04,   6.8413594E-04,   6.4859557E-04
     +,   6.1447307E-04,   5.8169459E-04,   5.5019080E-04
     +,   5.1990047E-04,   4.9077475E-04,   4.6277291E-04
     +,   4.3586016E-04,   4.1000944E-04,   3.8520104E-04
     +,   3.6141952E-04,   3.3865171E-04,   3.1688609E-04
     +,   2.9611416E-04,   2.7632486E-04,   2.5750860E-04
     +,   2.3965146E-04,   2.2274003E-04,   2.0675610E-04
     +,   1.9168091E-04,   1.7749092E-04,   1.6416213E-04
     +,   1.5166635E-04,   1.3997479E-04,   1.2905577E-04
     +,   1.1887618E-04,   1.0940276E-04,   1.0060029E-04
     +,   9.2434246E-05,   8.4869112E-05,   7.7870405E-05
     +,   7.1403476E-05,   6.5435102E-05,   5.9932318E-05
     +,   5.4864002E-05,   5.0199640E-05,   4.5910674E-05
     +,   4.1969422E-05,   3.8350245E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt85 = Yx/0.47264
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8597377E-05,   2.9982604E-05
     +,   3.1438845E-05,   3.2968626E-05,   3.4574394E-05
     +,   3.6258458E-05,   3.8023001E-05,   3.9870029E-05
     +,   4.1801319E-05,   4.3818509E-05,   4.5922909E-05
     +,   4.8115584E-05,   5.0397262E-05,   5.2768362E-05
     +,   5.5228953E-05,   5.7778710E-05,   6.0416914E-05
     +,   6.3142434E-05,   6.5953674E-05,   6.8848633E-05
     +,   7.1824841E-05,   7.4879332E-05,   7.8008692E-05
     +,   8.1209218E-05,   8.4476422E-05,   8.7805733E-05
     +,   9.1191978E-05,   9.4629664E-05,   9.8112941E-05
     +,   1.0163564E-04,   1.0519145E-04,   1.0877370E-04
     +,   1.1237566E-04,   1.1599052E-04,   1.1961144E-04
     +,   1.2323167E-04,   1.2684462E-04,   1.3044380E-04
     +,   1.3402342E-04,   1.3757759E-04,   1.4110129E-04
     +,   1.4459001E-04,   1.4803994E-04,   1.5144801E-04
     +,   1.5481209E-04,   1.5813093E-04,   1.6140456E-04
     +,   1.6463375E-04,   1.6782082E-04,   1.7096910E-04
     +,   1.7408338E-04,   1.7716968E-04,   1.8023528E-04
     +,   1.8328913E-04,   1.8634106E-04,   1.8940255E-04
     +,   1.9248624E-04,   1.9560585E-04,   1.9877646E-04
     +,   2.0201386E-04,   2.0533490E-04,   2.0875709E-04
     +,   2.1229836E-04,   2.1597731E-04,   2.1981269E-04
     +,   2.2382296E-04,   2.2802681E-04,   2.3244198E-04
     +,   2.3708616E-04,   2.4197543E-04,   2.4712572E-04
     +,   2.5255061E-04,   2.5826340E-04,   2.6427471E-04
     +,   2.7059423E-04,   2.7722973E-04,   2.8418674E-04
     +,   2.9146884E-04,   2.9907865E-04,   3.0701669E-04
     +,   3.1528162E-04,   3.2387165E-04,   3.3278330E-04
     +,   3.4201381E-04,   3.5155925E-04,   3.6141736E-04
     +,   3.7158668E-04,   3.8206839E-04,   3.9286556E-04
     +,   4.0398628E-04,   4.1544248E-04,   4.2725139E-04
     +,   4.3943623E-04,   4.5202751E-04,   4.6506355E-04
     +,   4.7858895E-04,   4.9265806E-04,   5.0733151E-04
     +,   5.2267953E-04,   5.3877779E-04,   5.5571110E-04
     +,   5.7356822E-04,   5.9244712E-04,   6.1244913E-04
     +,   6.3368538E-04,   6.5627630E-04,   6.8035437E-04
     +,   7.0606970E-04,   7.3360035E-04,   7.6316053E-04
     +,   7.9501083E-04,   8.2948100E-04,   8.6697866E-04
     +,   9.0802152E-04,   9.5324381E-04,   1.0034285E-03
     +,   1.0595117E-03,   1.1226052E-03,   1.1939796E-03
     +,   1.2750629E-03,   1.3674098E-03,   1.4726392E-03
     +,   1.5923801E-03,   1.7282037E-03,   1.8815524E-03
     +,   2.0536839E-03,   2.2457298E-03,   2.4587533E-03
     +,   2.6940003E-03,   2.9531678E-03,   3.2388140E-03
     +,   3.5546350E-03,   3.9057133E-03,   4.2983480E-03
     +,   4.7396640E-03,   5.2367076E-03,   5.7951915E-03
     +,   6.4181392E-03,   7.1048383E-03,   7.8504886E-03
     +,   8.6471215E-03,   9.4861938E-03,   1.0361987E-02
     +,   1.1274057E-02,   1.2226803E-02,   1.3225277E-02
     +,   1.4268307E-02,   1.5343518E-02,   1.6430311E-02
     +,   1.7514205E-02,   1.8610356E-02,   1.9782476E-02
     +,   2.1138122E-02,   2.2789998E-02,   2.4800526E-02
     +,   2.7145622E-02,   2.9721478E-02,   3.2388825E-02
     +,   3.5027452E-02,   3.7565514E-02,   3.9963778E-02
     +,   4.2187478E-02,   4.4223350E-02,   4.6098609E-02
     +,   4.7799289E-02,   4.9143057E-02,   4.9795534E-02
     +,   4.9445119E-02,   4.7937289E-02,   4.5293849E-02
     +,   4.1711587E-02,   3.7547622E-02,   3.3222977E-02
     +,   2.9105678E-02,   2.5482589E-02,   2.2583336E-02
     +,   2.0561563E-02,   1.9439261E-02,   1.9097481E-02
     +,   1.9343318E-02,   1.9996246E-02,   2.0924397E-02
     +,   2.2018461E-02,   2.3148058E-02,   2.4153765E-02
     +,   2.4886698E-02,   2.5261134E-02,   2.5277523E-02
     +,   2.5002906E-02,   2.4529135E-02,   2.3937665E-02
     +,   2.3284758E-02,   2.2601757E-02,   2.1897743E-02
     +,   2.1161992E-02,   2.0367270E-02,   1.9482601E-02
     +,   1.8491535E-02,   1.7407872E-02,   1.6277663E-02
     +,   1.5165394E-02,   1.4131853E-02,   1.3215419E-02
     +,   1.2425167E-02,   1.1745609E-02,   1.1147805E-02
     +,   1.0601108E-02,   1.0081432E-02,   9.5747625E-03
     +,   9.0770451E-03,   8.5917767E-03,   8.1265364E-03
     +,   7.6895398E-03,   7.2867465E-03,   6.9203330E-03
     +,   6.5884786E-03,   6.2863524E-03,   6.0077370E-03
     +,   5.7467371E-03,   5.4990216E-03,   5.2622985E-03
     +,   5.0362074E-03,   4.8218034E-03,   4.6208203E-03
     +,   4.4349697E-03,   4.2654676E-03,   4.1127489E-03
     +,   3.9763320E-03,   3.8548911E-03,   3.7464090E-03
     +,   3.6483931E-03,   3.5581065E-03,   3.4727890E-03
     +,   3.3898652E-03,   3.3071488E-03,   3.2229351E-03
     +,   3.1361273E-03,   3.0462500E-03,   2.9534283E-03
     +,   2.8583037E-03,   2.7619076E-03,   2.6655300E-03
     +,   2.5705402E-03,   2.4782317E-03,   2.3896990E-03
     +,   2.3057386E-03,   2.2267948E-03,   2.1529312E-03
     +,   2.0838680E-03,   2.0190347E-03,   1.9576347E-03
     +,   1.8987324E-03,   1.8413474E-03,   1.7845260E-03
     +,   1.7274052E-03,   1.6692706E-03,   1.6095894E-03
     +,   1.5480305E-03,   1.4844511E-03,   1.4188999E-03
     +,   1.3515928E-03,   1.2828829E-03,   1.2132197E-03
     +,   1.1431261E-03,   1.0731657E-03,   1.0039040E-03
     +,   9.3588745E-04,   8.6962606E-04,   8.0557296E-04
     +,   7.4411044E-04,   6.8554521E-04,   6.3011335E-04
     +,   5.7797297E-04,   5.2920944E-04,   4.8384495E-04
     +,   4.4184833E-04,   4.0313686E-04,   3.6759442E-04
     +,   3.3507068E-04,   3.0539974E-04,   2.7839813E-04
     +,   2.5387938E-04,   2.3165281E-04,   2.1153361E-04
     +,   1.9334089E-04,   1.7690490E-04,   1.6206453E-04
     +,   1.4867008E-04,   1.3658436E-04,   1.2568012E-04
     +,   1.1584242E-04,   1.0696534E-04,   9.8953780E-05
     +,   9.1720329E-05,   8.5186803E-05,   7.9281373E-05
     +,   7.3939773E-05,   6.9103087E-05,   6.4718552E-05
     +,   6.0737926E-05,   5.7118126E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt90 = Yx/0.46662
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2262284E-05,   3.3082339E-05
     +,   3.3909891E-05,   3.4744662E-05,   3.5586432E-05
     +,   3.6435020E-05,   3.7290254E-05,   3.8152015E-05
     +,   3.9020222E-05,   3.9894901E-05,   4.0776067E-05
     +,   4.1663821E-05,   4.2558338E-05,   4.3459870E-05
     +,   4.4368709E-05,   4.5285291E-05,   4.6210080E-05
     +,   4.7143665E-05,   4.8086717E-05,   4.9039991E-05
     +,   5.0004361E-05,   5.0980801E-05,   5.1970361E-05
     +,   5.2974272E-05,   5.3993743E-05,   5.5030221E-05
     +,   5.6085166E-05,   5.7160207E-05,   5.8257050E-05
     +,   5.9377493E-05,   6.0523485E-05,   6.1697050E-05
     +,   6.2900304E-05,   6.4135478E-05,   6.5404944E-05
     +,   6.6711167E-05,   6.8056674E-05,   6.9444148E-05
     +,   7.0876456E-05,   7.2356444E-05,   7.3887226E-05
     +,   7.5472060E-05,   7.7114317E-05,   7.8817531E-05
     +,   8.0585560E-05,   8.2422404E-05,   8.4332300E-05
     +,   8.6319858E-05,   8.8389941E-05,   9.0547815E-05
     +,   9.2799070E-05,   9.5149793E-05,   9.7606477E-05
     +,   1.0017630E-04,   1.0286671E-04,   1.0568592E-04
     +,   1.0864268E-04,   1.1174643E-04,   1.1500714E-04
     +,   1.1843547E-04,   1.2204272E-04,   1.2584083E-04
     +,   1.2984197E-04,   1.3405921E-04,   1.3850600E-04
     +,   1.4319560E-04,   1.4814199E-04,   1.5335857E-04
     +,   1.5885915E-04,   1.6465652E-04,   1.7076332E-04
     +,   1.7719070E-04,   1.8394935E-04,   1.9104754E-04
     +,   1.9849253E-04,   2.0628938E-04,   2.1444021E-04
     +,   2.2294454E-04,   2.3179899E-04,   2.4099759E-04
     +,   2.5052935E-04,   2.6038112E-04,   2.7053466E-04
     +,   2.8096899E-04,   2.9165816E-04,   3.0257361E-04
     +,   3.1368202E-04,   3.2494808E-04,   3.3633210E-04
     +,   3.4779322E-04,   3.5928874E-04,   3.7077381E-04
     +,   3.8220367E-04,   3.9353466E-04,   4.0472514E-04
     +,   4.1573439E-04,   4.2652796E-04,   4.3707396E-04
     +,   4.4734919E-04,   4.5733654E-04,   4.6702917E-04
     +,   4.7642965E-04,   4.8555344E-04,   4.9442821E-04
     +,   5.0309737E-04,   5.1161950E-04,   5.2007142E-04
     +,   5.2854698E-04,   5.3716247E-04,   5.4605340E-04
     +,   5.5537734E-04,   5.6531583E-04,   5.7607226E-04
     +,   5.8787432E-04,   6.0097018E-04,   6.1563082E-04
     +,   6.3214329E-04,   6.5081316E-04,   6.7195238E-04
     +,   6.9587975E-04,   7.2291330E-04,   7.5335713E-04
     +,   7.8749639E-04,   8.2558882E-04,   8.6785457E-04
     +,   9.1446063E-04,   9.6552400E-04,   1.0210949E-03
     +,   1.0811627E-03,   1.1456469E-03,   1.2144132E-03
     +,   1.2872707E-03,   1.3640041E-03,   1.4443764E-03
     +,   1.5281776E-03,   1.6152520E-03,   1.7055392E-03
     +,   1.7991241E-03,   1.8963027E-03,   1.9976296E-03
     +,   2.1039681E-03,   2.2165440E-03,   2.3369754E-03
     +,   2.4672714E-03,   2.6097782E-03,   2.7671005E-03
     +,   2.9419500E-03,   3.1368986E-03,   3.3541066E-03
     +,   3.5950060E-03,   3.8599274E-03,   4.1477550E-03
     +,   4.4556535E-03,   4.7789584E-03,   5.1112073E-03
     +,   5.4444186E-03,   5.7696491E-03,   6.0777594E-03
     +,   6.3602421E-03,   6.6099688E-03,   6.8217758E-03
     +,   6.9926488E-03,   7.1215713E-03,   7.2092507E-03
     +,   7.2579454E-03,   7.2716135E-03,   7.2564739E-03
     +,   7.2217509E-03,   7.1801650E-03,   7.1478789E-03
     +,   7.1436944E-03,   7.1881195E-03,   7.3027699E-03
     +,   7.5105778E-03,   7.8363530E-03,   8.3072232E-03
     +,   8.9527909E-03,   9.8060733E-03,   1.0907298E-02
     +,   1.2309922E-02,   1.4081643E-02,   1.6287308E-02
     +,   1.8945072E-02,   2.1978037E-02,   2.5230255E-02
     +,   2.8611459E-02,   3.2274090E-02,   3.6529504E-02
     +,   4.1390073E-02,   4.6221562E-02,   5.0111059E-02
     +,   5.2653130E-02,   5.4193452E-02,   5.5246826E-02
     +,   5.5798799E-02,   5.5323381E-02,   5.3588800E-02
     +,   5.1222119E-02,   4.9144257E-02,   4.7645982E-02
     +,   4.6322819E-02,   4.4677969E-02,   4.2549204E-02
     +,   4.0112145E-02,   3.7664108E-02,   3.5403665E-02
     +,   3.3356618E-02,   3.1454749E-02,   2.9635102E-02
     +,   2.7862174E-02,   2.6110414E-02,   2.4367820E-02
     +,   2.2652527E-02,   2.1005159E-02,   1.9459743E-02
     +,   1.8024130E-02,   1.6686747E-02,   1.5437555E-02
     +,   1.4280465E-02,   1.3228215E-02,   1.2288427E-02
     +,   1.1455175E-02,   1.0711242E-02,   1.0036970E-02
     +,   9.4184680E-03,   8.8501815E-03,   8.3319917E-03
     +,   7.8641390E-03,   7.4436162E-03,   7.0638228E-03
     +,   6.7166919E-03,   6.3955258E-03,   6.0969261E-03
     +,   5.8210115E-03,   5.5701691E-03,   5.3470111E-03
     +,   5.1525496E-03,   4.9851416E-03,   4.8403111E-03
     +,   4.7114259E-03,   4.5908168E-03,   4.4710487E-03
     +,   4.3459088E-03,   4.2110821E-03,   4.0643923E-03
     +,   3.9056942E-03,   3.7364673E-03,   3.5592620E-03
     +,   3.3771687E-03,   3.1933223E-03,   3.0105172E-03
     +,   2.8309955E-03,   2.6563753E-03,   2.4876769E-03
     +,   2.3254163E-03,   2.1697578E-03,   2.0206582E-03
     +,   1.8779867E-03,   1.7415949E-03,   1.6113806E-03
     +,   1.4873132E-03,   1.3694261E-03,   1.2577890E-03
     +,   1.1524885E-03,   1.0536163E-03,   9.6122362E-04
     +,   8.7531726E-04,   7.9584908E-04,   7.2270731E-04
     +,   6.5571128E-04,   5.9462176E-04,   5.3915282E-04
     +,   4.8897637E-04,   4.4373094E-04,   4.0303703E-04
     +,   3.6651330E-04,   3.3377486E-04,   3.0445316E-04
     +,   2.7819362E-04,   2.5466760E-04,   2.3356910E-04
     +,   2.1462278E-04,   1.9757825E-04,   1.8221494E-04
     +,   1.6833576E-04,   1.5576967E-04,   1.4436584E-04
     +,   1.3399322E-04,   1.2453858E-04,   1.1590243E-04
     +,   1.0799904E-04,   1.0075277E-04,   9.4097981E-05
     +,   8.7976172E-05,   8.2336344E-05,   7.7132441E-05
     +,   7.2324045E-05,   6.7874367E-05,   6.3751031E-05
     +,   5.9924339E-05,   5.6368146E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_htt95 = Yx/0.44016
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0698293E-06,   3.3464150E-06
     +,   3.6421450E-06,   3.9577376E-06,   4.2938723E-06
     +,   4.6511873E-06,   5.0302706E-06,   5.4316502E-06
     +,   5.8557803E-06,   6.3030639E-06,   6.7737960E-06
     +,   7.2681901E-06,   7.7863560E-06,   8.3282994E-06
     +,   8.8939069E-06,   9.4829447E-06,   1.0095052E-05
     +,   1.0729725E-05,   1.1386326E-05,   1.2064069E-05
     +,   1.2762016E-05,   1.3479082E-05,   1.4214016E-05
     +,   1.4965456E-05,   1.5731803E-05,   1.6511400E-05
     +,   1.7302382E-05,   1.8102761E-05,   1.8910410E-05
     +,   1.9723078E-05,   2.0538384E-05,   2.1353844E-05
     +,   2.2166883E-05,   2.2974829E-05,   2.3774955E-05
     +,   2.4564470E-05,   2.5340554E-05,   2.6100355E-05
     +,   2.6841073E-05,   2.7559843E-05,   2.8253915E-05
     +,   2.8920571E-05,   2.9557186E-05,   3.0161225E-05
     +,   3.0730294E-05,   3.1262141E-05,   3.1754684E-05
     +,   3.2206033E-05,   3.2614498E-05,   3.2978623E-05
     +,   3.3297194E-05,   3.3569253E-05,   3.3794131E-05
     +,   3.3971450E-05,   3.4101107E-05,   3.4183344E-05
     +,   3.4218694E-05,   3.4208038E-05,   3.4152577E-05
     +,   3.4053843E-05,   3.3913693E-05,   3.3734330E-05
     +,   3.3518270E-05,   3.3268341E-05,   3.2987678E-05
     +,   3.2679716E-05,   3.2348154E-05,   3.1996977E-05
     +,   3.1630363E-05,   3.1252792E-05,   3.0868836E-05
     +,   3.0483319E-05,   3.0101159E-05,   2.9727413E-05
     +,   2.9367187E-05,   2.9025638E-05,   2.8707949E-05
     +,   2.8419268E-05,   2.8164666E-05,   2.7949111E-05
     +,   2.7777452E-05,   2.7654327E-05,   2.7584185E-05
     +,   2.7571199E-05,   2.7619260E-05,   2.7731932E-05
     +,   2.7912414E-05,   2.8163526E-05,   2.8487646E-05
     +,   2.8886730E-05,   2.9362280E-05,   2.9915278E-05
     +,   3.0546205E-05,   3.1255076E-05,   3.2041389E-05
     +,   3.2904067E-05,   3.3841618E-05,   3.4851939E-05
     +,   3.5932564E-05,   3.7080426E-05,   3.8292168E-05
     +,   3.9563849E-05,   4.0891315E-05,   4.2269898E-05
     +,   4.3694759E-05,   4.5160788E-05,   4.6662579E-05
     +,   4.8194524E-05,   4.9751015E-05,   5.1326366E-05
     +,   5.2914704E-05,   5.4510376E-05,   5.6107605E-05
     +,   5.7700920E-05,   5.9284772E-05,   6.0854029E-05
     +,   6.2403546E-05,   6.3928637E-05,   6.5424669E-05
     +,   6.6887427E-05,   6.8312998E-05,   6.9697657E-05
     +,   7.1037983E-05,   7.2330935E-05,   7.3573741E-05
     +,   7.4763841E-05,   7.5899021E-05,   7.6977296E-05
     +,   7.7997000E-05,   7.8956684E-05,   7.9855279E-05
     +,   8.0691971E-05,   8.1466387E-05,   8.2178522E-05
     +,   8.2828868E-05,   8.3418548E-05,   8.3949279E-05
     +,   8.4423547E-05,   8.4844745E-05,   8.5217194E-05
     +,   8.5546271E-05,   8.5838452E-05,   8.6101405E-05
     +,   8.6344044E-05,   8.6576445E-05,   8.6809916E-05
     +,   8.7056964E-05,   8.7331115E-05,   8.7647051E-05
     +,   8.8020395E-05,   8.8467663E-05,   8.9006156E-05
     +,   8.9653724E-05,   9.0428584E-05,   9.1348949E-05
     +,   9.2432216E-05,   9.3694231E-05,   9.5148258E-05
     +,   9.6803582E-05,   9.8663782E-05,   1.0072557E-04
     +,   1.0297771E-04,   1.0540036E-04,   1.0796623E-04
     +,   1.1064376E-04,   1.1340191E-04,   1.1621819E-04
     +,   1.1908927E-04,   1.2204444E-04,   1.2516019E-04
     +,   1.2857559E-04,   1.3250798E-04,   1.3726855E-04
     +,   1.4327785E-04,   1.5108353E-04,   1.6138672E-04
     +,   1.7507526E-04,   1.9326757E-04,   2.1736418E-04
     +,   2.4909628E-04,   2.9054866E-04,   3.4412893E-04
     +,   4.1246429E-04,   4.9820740E-04,   6.0373876E-04
     +,   7.3079288E-04,   8.8007114E-04,   1.0509051E-03
     +,   1.2410012E-03,   1.4463114E-03,   1.6611128E-03
     +,   1.8781699E-03,   2.0890101E-03,   2.2843494E-03
     +,   2.4546357E-03,   2.5907336E-03,   2.6847695E-03
     +,   2.7310897E-03,   2.7271349E-03,   2.6740157E-03
     +,   2.5766119E-03,   2.4430675E-03,   2.2837105E-03
     +,   2.1096596E-03,   1.9313932E-03,   1.7575518E-03
     +,   1.5942567E-03,   1.4449717E-03,   1.3107870E-03
     +,   1.1910028E-03,   1.0838188E-03,   9.8696654E-04
     +,   8.9817989E-04,   8.1550324E-04,   7.3745701E-04
     +,   6.6308706E-04,   5.9192406E-04,   5.2389910E-04
     +,   4.5923929E-04,   3.9835824E-04,   3.4172923E-04
     +,   2.8979455E-04,   2.4289318E-04,   2.0120959E-04
     +,   1.6475316E-04,   1.3336801E-04,   1.0675979E-04
     +,   8.4529136E-05,   6.6210385E-05,   5.1310832E-05
     +,   3.9342172E-05,   2.9841854E-05,   2.2387374E-05
     +,   1.6604776E-05,   1.2171112E-05,   8.8118431E-06
     +,   6.2978734E-06,   4.4408189E-06,   3.0876390E-06
     +,   2.1156027E-06,   1.4277342E-06,   9.4854079E-07
     +,   6.2011071E-07,   3.9875374E-07,   2.5211477E-07
     +,   1.5668158E-07,   9.5686516E-08,   5.7409668E-08
     +,   3.3831761E-08,   1.9579788E-08,   1.1126660E-08
     +,   6.2077192E-09,   3.3999705E-09,   1.8279686E-09
     +,   9.6467179E-10,   4.9966964E-10,   2.5402935E-10
     +,   1.2676617E-10,   6.2095870E-11,   2.9861634E-11
     +,   1.4101844E-11,   6.5425447E-12,   2.9842207E-12
     +,   1.3398155E-12,   5.9332644E-13,   2.6003635E-13
     +,   1.1341169E-13,   4.9657137E-14,   2.2114592E-14
     +,   1.0191902E-14,   4.9536748E-15,   2.5763835E-15
     +,   1.4390613E-15,   8.5580551E-16,   5.3336103E-16
     +,   3.4274026E-16,   2.2419165E-16,   1.4799158E-16
     +,   9.8061957E-17,   6.5027070E-17,   4.3079570E-17
     +,   2.8487022E-17,   1.8793209E-17,   1.2366239E-17
     +,   8.1149355E-18,   5.3104073E-18,   3.4653131E-18
     +,   2.2548253E-18,   1.4630002E-18,   9.4649935E-19
     +,   6.1059040E-19,   3.9275042E-19,   2.5190077E-19
     +,   1.6109249E-19,   1.0272174E-19,   6.5309593E-20
     +,   4.1402881E-20,   2.6170190E-20,   1.6493794E-20
     +,   1.0364661E-20,   6.4941930E-21
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt100 = Yx/0.016
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1213344E-05,   1.1403635E-05
     +,   1.1597970E-05,   1.1796836E-05,   1.2000753E-05
     +,   1.2210277E-05,   1.2425991E-05,   1.2648522E-05
     +,   1.2878520E-05,   1.3116681E-05,   1.3363721E-05
     +,   1.3620397E-05,   1.3887485E-05,   1.4165797E-05
     +,   1.4456165E-05,   1.4759453E-05,   1.5076534E-05
     +,   1.5408314E-05,   1.5755704E-05,   1.6119631E-05
     +,   1.6501035E-05,   1.6900856E-05,   1.7320030E-05
     +,   1.7759521E-05,   1.8220229E-05,   1.8703102E-05
     +,   1.9209037E-05,   1.9738918E-05,   2.0293597E-05
     +,   2.0873897E-05,   2.1480606E-05,   2.2114460E-05
     +,   2.2776150E-05,   2.3466317E-05,   2.4185525E-05
     +,   2.4934279E-05,   2.5713014E-05,   2.6522064E-05
     +,   2.7361724E-05,   2.8232122E-05,   2.9133358E-05
     +,   3.0065403E-05,   3.1028092E-05,   3.2021191E-05
     +,   3.3044307E-05,   3.4096938E-05,   3.5178462E-05
     +,   3.6288104E-05,   3.7424958E-05,   3.8587983E-05
     +,   3.9775990E-05,   4.0987648E-05,   4.2221458E-05
     +,   4.3475855E-05,   4.4748980E-05,   4.6038978E-05
     +,   4.7343750E-05,   4.8661117E-05,   4.9988714E-05
     +,   5.1324085E-05,   5.2664618E-05,   5.4007614E-05
     +,   5.5350189E-05,   5.6689452E-05,   5.8022422E-05
     +,   5.9345926E-05,   6.0656879E-05,   6.1951992E-05
     +,   6.3228115E-05,   6.4481916E-05,   6.5710206E-05
     +,   6.6909677E-05,   6.8077265E-05,   6.9209716E-05
     +,   7.0304093E-05,   7.1357492E-05,   7.2367111E-05
     +,   7.3330259E-05,   7.4244585E-05,   7.5107855E-05
     +,   7.5918040E-05,   7.6673452E-05,   7.7372606E-05
     +,   7.8014382E-05,   7.8597877E-05,   7.9122699E-05
     +,   7.9588688E-05,   7.9996120E-05,   8.0345621E-05
     +,   8.0638296E-05,   8.0875601E-05,   8.1059414E-05
     +,   8.1192084E-05,   8.1276332E-05,   8.1315338E-05
     +,   8.1312661E-05,   8.1272265E-05,   8.1198501E-05
     +,   8.1096092E-05,   8.0970050E-05,   8.0825761E-05
     +,   8.0668826E-05,   8.0505073E-05,   8.0340564E-05
     +,   8.0181475E-05,   8.0034049E-05,   7.9904603E-05
     +,   7.9799429E-05,   7.9724727E-05,   7.9686542E-05
     +,   7.9690741E-05,   7.9742895E-05,   7.9848265E-05
     +,   8.0011712E-05,   8.0237616E-05,   8.0529877E-05
     +,   8.0891768E-05,   8.1326012E-05,   8.1834558E-05
     +,   8.2418694E-05,   8.3078958E-05,   8.3815044E-05
     +,   8.4625826E-05,   8.5509353E-05,   8.6462867E-05
     +,   8.7482622E-05,   8.8564113E-05,   8.9701869E-05
     +,   9.0889720E-05,   9.2120485E-05,   9.3386363E-05
     +,   9.4678573E-05,   9.5987867E-05,   9.7304051E-05
     +,   9.8616467E-05,   9.9913901E-05,   1.0118454E-04
     +,   1.0241613E-04,   1.0359623E-04,   1.0471202E-04
     +,   1.0575055E-04,   1.0669880E-04,   1.0754385E-04
     +,   1.0827299E-04,   1.0887374E-04,   1.0933410E-04
     +,   1.0964265E-04,   1.0978870E-04,   1.0976243E-04
     +,   1.0955503E-04,   1.0915882E-04,   1.0856750E-04
     +,   1.0777624E-04,   1.0678176E-04,   1.0558259E-04
     +,   1.0417924E-04,   1.0257435E-04,   1.0077297E-04
     +,   9.8782621E-05,   9.6614094E-05,   9.4281429E-05
     +,   9.1802591E-05,   8.9200563E-05,   8.6503969E-05
     +,   8.3748215E-05,   8.0977050E-05,   7.8244389E-05
     +,   7.5616415E-05,   7.3173418E-05,   7.1012757E-05
     +,   6.9251531E-05,   6.8029141E-05,   6.7509944E-05
     +,   6.7885725E-05,   6.9377587E-05,   7.2237301E-05
     +,   7.6747900E-05,   8.3222760E-05,   9.2003655E-05
     +,   1.0345819E-04,   1.1797460E-04,   1.3595377E-04
     +,   1.5780031E-04,   1.8391277E-04,   2.1466876E-04
     +,   2.5040528E-04,   2.9140015E-04,   3.3785246E-04
     +,   3.8985611E-04,   4.4736807E-04,   5.1019358E-04
     +,   5.7795795E-04,   6.5008353E-04,   7.2578178E-04
     +,   8.0405688E-04,   8.8371133E-04,   9.6336310E-04
     +,   1.0414871E-03,   1.1164700E-03,   1.1866636E-03
     +,   1.2504470E-03,   1.3063005E-03,   1.3528761E-03
     +,   1.3890518E-03,   1.4139758E-03,   1.4271077E-03
     +,   1.4282289E-03,   1.4174435E-03,   1.3951623E-03
     +,   1.3620729E-03,   1.3190960E-03,   1.2673469E-03
     +,   1.2080823E-03,   1.1426477E-03,   1.0724344E-03
     +,   9.9884102E-04,   9.2323386E-04,   8.4690860E-04
     +,   7.7106734E-04,   6.9680298E-04,   6.2506832E-04
     +,   5.5666792E-04,   4.9225515E-04,   4.3232259E-04
     +,   3.7719976E-04,   3.2706439E-04,   2.8195692E-04
     +,   2.4179164E-04,   2.0637414E-04,   1.7542590E-04
     +,   1.4860883E-04,   1.2554420E-04,   1.0583255E-04
     +,   8.9073757E-05,   7.4883035E-05,   6.2898922E-05
     +,   5.2793002E-05,   4.4274526E-05,   3.7090911E-05
     +,   3.1026419E-05,   2.5900114E-05,   2.1562297E-05
     +,   1.7889699E-05,   1.4780919E-05,   1.2152600E-05
     +,   9.9358531E-06,   8.0729087E-06,   6.5145587E-06
     +,   5.2184228E-06,   4.1476324E-06,   3.2695889E-06
     +,   2.5554539E-06,   1.9797253E-06,   1.5198626E-06
     +,   1.1560506E-06,   8.7105894E-07,   6.5007328E-07
     +,   4.8048321E-07,   3.5168367E-07,   2.5488765E-07
     +,   1.8291405E-07,   1.2996662E-07,   9.1428525E-08
     +,   6.3676559E-08,   4.3906073E-08,   2.9971197E-08
     +,   2.0253781E-08,   1.3549743E-08,   8.9739025E-09
     +,   5.8836762E-09,   3.8187919E-09,   2.4536830E-09
     +,   1.5607495E-09,   9.8280217E-10,   6.1265376E-10
     +,   3.7809364E-10,   2.3100286E-10,   1.3973293E-10
     +,   8.3686690E-11,   4.9630106E-11,   2.9148444E-11
     +,   1.6958306E-11,   9.7766491E-12,   5.5886610E-12
     +,   3.1704656E-12,   1.7877061E-12,   1.0042415E-12
     +,   5.6408177E-13,   3.1861417E-13,   1.8245586E-13
     +,   1.0711815E-13,   6.5332654E-14,   4.1934914E-14
     +,   2.8567806E-14,   2.0671541E-14,   1.5776046E-14
     +,   1.2552267E-14,   1.0286202E-14,   8.5939649E-15
     +,   7.2665118E-15,   6.1875854E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt104 = Yx/0.01204
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1248253E-06,   3.3212832E-06
     +,   3.5268451E-06,   3.7417221E-06,   3.9661254E-06
     +,   4.2002598E-06,   4.4443291E-06,   4.6985306E-06
     +,   4.9630567E-06,   5.2381074E-06,   5.5238697E-06
     +,   5.8205355E-06,   6.1282940E-06,   6.4473352E-06
     +,   6.7778478E-06,   7.1200261E-06,   7.4740638E-06
     +,   7.8401608E-06,   8.2185170E-06,   8.6093441E-06
     +,   9.0128515E-06,   9.4292582E-06,   9.8587807E-06
     +,   1.0301674E-05,   1.0758139E-05,   1.1228442E-05
     +,   1.1712820E-05,   1.2211519E-05,   1.2724790E-05
     +,   1.3252878E-05,   1.3796026E-05,   1.4354475E-05
     +,   1.4928452E-05,   1.5518166E-05,   1.6123815E-05
     +,   1.6745571E-05,   1.7383572E-05,   1.8037916E-05
     +,   1.8708704E-05,   1.9395904E-05,   2.0099511E-05
     +,   2.0819418E-05,   2.1555446E-05,   2.2307349E-05
     +,   2.3074790E-05,   2.3857339E-05,   2.4654461E-05
     +,   2.5465515E-05,   2.6289748E-05,   2.7126276E-05
     +,   2.7974100E-05,   2.8832064E-05,   2.9698893E-05
     +,   3.0573196E-05,   3.1453364E-05,   3.2337732E-05
     +,   3.3224431E-05,   3.4111472E-05,   3.4996734E-05
     +,   3.5877958E-05,   3.6752746E-05,   3.7618622E-05
     +,   3.8472917E-05,   3.9312978E-05,   4.0136019E-05
     +,   4.0939143E-05,   4.1719490E-05,   4.2474083E-05
     +,   4.3200012E-05,   4.3894303E-05,   4.4554083E-05
     +,   4.5176468E-05,   4.5758730E-05,   4.6298159E-05
     +,   4.6792247E-05,   4.7238631E-05,   4.7635105E-05
     +,   4.7979698E-05,   4.8270678E-05,   4.8506590E-05
     +,   4.8686226E-05,   4.8808768E-05,   4.8873670E-05
     +,   4.8880800E-05,   4.8830414E-05,   4.8723155E-05
     +,   4.8560123E-05,   4.8342848E-05,   4.8073336E-05
     +,   4.7754089E-05,   4.7388046E-05,   4.6978705E-05
     +,   4.6530055E-05,   4.6046549E-05,   4.5533161E-05
     +,   4.4995395E-05,   4.4439174E-05,   4.3870954E-05
     +,   4.3297561E-05,   4.2726304E-05,   4.2164804E-05
     +,   4.1621075E-05,   4.1103358E-05,   4.0620180E-05
     +,   4.0180195E-05,   3.9792136E-05,   3.9464780E-05
     +,   3.9206818E-05,   3.9026756E-05,   3.8932820E-05
     +,   3.8932882E-05,   3.9034298E-05,   3.9243812E-05
     +,   3.9567483E-05,   4.0010465E-05,   4.0577037E-05
     +,   4.1270323E-05,   4.2092372E-05,   4.3043878E-05
     +,   4.4124263E-05,   4.5331577E-05,   4.6662335E-05
     +,   4.8111557E-05,   4.9672901E-05,   5.1338586E-05
     +,   5.3099280E-05,   5.4944605E-05,   5.6862766E-05
     +,   5.8841208E-05,   6.0866310E-05,   6.2924162E-05
     +,   6.5000211E-05,   6.7080218E-05,   6.9149886E-05
     +,   7.1195762E-05,   7.3205396E-05,   7.5167482E-05
     +,   7.7072378E-05,   7.8912548E-05,   8.0682796E-05
     +,   8.2380262E-05,   8.4004940E-05,   8.5559812E-05
     +,   8.7050816E-05,   8.8486748E-05,   8.9879395E-05
     +,   9.1243215E-05,   9.2594964E-05,   9.3953386E-05
     +,   9.5338728E-05,   9.6772150E-05,   9.8274912E-05
     +,   9.9867670E-05,   1.0156980E-04,   1.0339839E-04
     +,   1.0536726E-04,   1.0748613E-04,   1.0975995E-04
     +,   1.1218787E-04,   1.1476247E-04,   1.1746958E-04
     +,   1.2028783E-04,   1.2318848E-04,   1.2613606E-04
     +,   1.2908939E-04,   1.3200296E-04,   1.3482875E-04
     +,   1.3751928E-04,   1.4003116E-04,   1.4232891E-04
     +,   1.4438907E-04,   1.4620506E-04,   1.4779123E-04
     +,   1.4918632E-04,   1.5045541E-04,   1.5169039E-04
     +,   1.5300828E-04,   1.5454656E-04,   1.5645751E-04
     +,   1.5890029E-04,   1.6203329E-04,   1.6600838E-04
     +,   1.7096933E-04,   1.7705746E-04,   1.8442664E-04
     +,   1.9326949E-04,   2.0385675E-04,   2.1658793E-04
     +,   2.3204833E-04,   2.5106425E-04,   2.7475163E-04
     +,   3.0453640E-04,   3.4213407E-04,   3.8947898E-04
     +,   4.4859413E-04,   5.2139146E-04,   6.0941360E-04
     +,   7.1354897E-04,   8.3375117E-04,   9.6879044E-04
     +,   1.1160785E-03,   1.2716381E-03,   1.4302239E-03
     +,   1.5855768E-03,   1.7308150E-03,   1.8589675E-03
     +,   1.9635125E-03,   2.0389087E-03,   2.0810696E-03
     +,   2.0876969E-03,   2.0584445E-03,   1.9949139E-03
     +,   1.9004862E-03,   1.7799907E-03,   1.6392838E-03
     +,   1.4847871E-03,   1.3229952E-03,   1.1600242E-03
     +,   1.0012641E-03,   8.5113622E-04,   7.1292598E-04
     +,   5.8877241E-04,   4.7974766E-04,   3.8599208E-04
     +,   3.0690175E-04,   2.4134555E-04,   1.8787068E-04
     +,   1.4487264E-04,   1.1073521E-04,   8.3934370E-05
     +,   6.3101623E-05,   4.7051264E-05,   3.4785480E-05
     +,   2.5485037E-05,   1.8489634E-05,   1.3272373E-05
     +,   9.4173902E-06,   6.5986442E-06,   4.5615006E-06
     +,   3.1080413E-06,   2.0855368E-06,   1.3771299E-06
     +,   8.9427289E-07,   5.7074448E-07,   3.5781841E-07
     +,   2.2026813E-07,   1.3309358E-07,   7.8911484E-08
     +,   4.5896783E-08,   2.6182230E-08,   1.4646437E-08
     +,   8.0332034E-09,   4.3195403E-09,   2.2769455E-09
     +,   1.1765235E-09,   5.9588423E-10,   2.9583602E-10
     +,   1.4398173E-10,   6.8703730E-11,   3.2149543E-11
     +,   1.4760514E-11,   6.6545654E-12,   2.9499602E-12
     +,   1.2888619E-12,   5.5726425E-13,   2.4004754E-13
     +,   1.0413945E-13,   4.6243720E-14,   2.1465731E-14
     +,   1.0640342E-14,   5.7073940E-15,   3.3081516E-15
     +,   2.0425683E-15,   1.3180525E-15,   8.7423949E-16
     +,   5.8919802E-16,   4.0067792E-16,   2.7391926E-16
     +,   1.8791802E-16,   1.2929189E-16,   8.9210609E-17
     +,   6.1751878E-17,   4.2900846E-17,   2.9930002E-17
     +,   2.0979310E-17,   1.4782350E-17,   1.0474598E-17
     +,   7.4662306E-18,   5.3546325E-18,   3.8640096E-18
     +,   2.8054718E-18,   2.0489876E-18,   1.5049271E-18
     +,   1.1111039E-18,   8.2426821E-19,   6.1408627E-19
     +,   4.5922023E-19,   3.4451747E-19,   2.5917127E-19
     +,   1.9540482E-19,   1.4759618E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt106 = Yx/0.01232
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1062694E-35,   7.6580587E-35
     +,   1.8768704E-34,   4.5726886E-34,   1.1074937E-33
     +,   2.6664886E-33,   6.3821269E-33,   1.5185183E-32
     +,   3.5916607E-32,   8.4451928E-32,   1.9740112E-31
     +,   4.5868951E-31,   1.0595437E-30,   2.4330162E-30
     +,   5.5539561E-30,   1.2603500E-29,   2.8431950E-29
     +,   6.3760595E-29,   1.4214461E-28,   3.1501868E-28
     +,   6.9402566E-28,   1.5200127E-27,   3.3093724E-27
     +,   7.1629194E-27,   1.5411988E-26,   3.2966238E-26
     +,   7.0100238E-26,   1.4818739E-25,   3.1141941E-25
     +,   6.5062343E-25,   1.3513380E-24,   2.7903266E-24
     +,   5.7280736E-24,   1.1690460E-23,   2.3720959E-23
     +,   4.7854193E-23,   9.5984853E-23,   1.9142343E-22
     +,   3.7959689E-22,   7.4848718E-22,   1.4676275E-21
     +,   2.8617632E-21,   5.5496606E-21,   1.0703957E-20
     +,   2.0535415E-20,   3.9190199E-20,   7.4406796E-20
     +,   1.4055934E-19,   2.6421938E-19,   4.9429604E-19
     +,   9.2043127E-19,   1.7062334E-18,   3.1491655E-18
     +,   5.7882460E-18,   1.0596175E-17,   1.9323591E-17
     +,   3.5110141E-17,   6.3569902E-17,   1.1471199E-16
     +,   2.0633015E-16,   3.6996615E-16,   6.6137264E-16
     +,   1.1787667E-15,   2.0947214E-15,   3.7114582E-15
     +,   6.5560880E-15,   1.1545382E-14,   2.0265951E-14
     +,   3.5454553E-14,   6.1805914E-14,   1.0734175E-13
     +,   1.8568404E-13,   3.1986105E-13,   5.4853664E-13
     +,   9.3627937E-13,   1.5902203E-12,   2.6868609E-12
     +,   4.5149665E-12,   7.5437981E-12,   1.2530292E-11
     +,   2.0685204E-11,   3.3932204E-11,   5.5299685E-11
     +,   8.9521814E-11,   1.4392859E-10,   2.2978719E-10
     +,   3.6424405E-10,   5.7320043E-10,   8.9537611E-10
     +,   1.3881959E-09,   2.1360336E-09,   3.2616256E-09
     +,   4.9418571E-09,   7.4293718E-09,   1.1081490E-08
     +,   1.6398079E-08,   2.4072744E-08,   3.5056203E-08
     +,   5.0641233E-08,   7.2563317E-08,   1.0313337E-07
     +,   1.4538777E-07,   2.0328309E-07,   2.8190274E-07
     +,   3.8771987E-07,   5.2887560E-07,   7.1547367E-07
     +,   9.5990538E-07,   1.2771919E-06,   1.6852963E-06
     +,   2.2053441E-06,   2.8619424E-06,   3.6831509E-06
     +,   4.7006406E-06,   5.9492868E-06,   7.4670429E-06
     +,   9.2939717E-06,   1.1471735E-05,   1.4041926E-05
     +,   1.7045046E-05,   2.0518613E-05,   2.4494904E-05
     +,   2.8998948E-05,   3.4046603E-05,   3.9642146E-05
     +,   4.5775527E-05,   5.2421903E-05,   5.9538637E-05
     +,   6.7066190E-05,   7.4926102E-05,   8.3023559E-05
     +,   9.1246788E-05,   9.9471421E-05,   1.0756146E-04
     +,   1.1537492E-04,   1.2276735E-04,   1.2959611E-04
     +,   1.3572589E-04,   1.4103380E-04,   1.4541345E-04
     +,   1.4877849E-04,   1.5106633E-04,   1.5224026E-04
     +,   1.5229029E-04,   1.5123321E-04,   1.4911147E-04
     +,   1.4599085E-04,   1.4195780E-04,   1.3711549E-04
     +,   1.3157929E-04,   1.2547242E-04,   1.1892198E-04
     +,   1.1205439E-04,   1.0499098E-04,   9.7845194E-05
     +,   9.0720372E-05,   8.3707484E-05,   7.6883414E-05
     +,   7.0311035E-05,   6.4039938E-05,   5.8105867E-05
     +,   5.2532469E-05,   4.7333026E-05,   4.2511569E-05
     +,   3.8064241E-05,   3.3981272E-05,   3.0248681E-05
     +,   2.6849297E-05,   2.3763743E-05,   2.0971642E-05
     +,   1.8452571E-05,   1.6186405E-05,   1.4153709E-05
     +,   1.2336355E-05,   1.0718125E-05,   9.2849978E-06
     +,   8.0262917E-06,   6.9361663E-06,   6.0156653E-06
     +,   5.2757186E-06,   4.7413059E-06,   4.4565386E-06
     +,   4.4904218E-06,   4.9429486E-06,   5.9506315E-06
     +,   7.6901160E-06,   1.0378696E-05,   1.4270482E-05
     +,   1.9646410E-05,   2.6796790E-05,   3.5999776E-05
     +,   4.7496476E-05,   6.1471706E-05,   7.8055375E-05
     +,   9.7359436E-05,   1.1955767E-04,   1.4500365E-04
     +,   1.7436183E-04,   2.0870368E-04,   2.4952364E-04
     +,   2.9868909E-04,   3.5843055E-04,   4.3154787E-04
     +,   5.2195578E-04,   6.3545612E-04,   7.8025076E-04
     +,   9.6630264E-04,   1.2028684E-03,   1.4943839E-03
     +,   1.8360394E-03,   2.2110154E-03,   2.5909708E-03
     +,   2.9399735E-03,   3.2205761E-03,   3.4002981E-03
     +,   3.4573381E-03,   3.3846409E-03,   3.1912921E-03
     +,   2.9004940E-03,   2.5443768E-03,   2.1571650E-03
     +,   1.7693088E-03,   1.4042007E-03,   1.0775088E-03
     +,   7.9809688E-04,   5.6935201E-04,   3.9029901E-04
     +,   2.5655670E-04,   1.6141140E-04,   9.7043085E-05
     +,   5.5677625E-05,   3.0445244E-05,   1.5845035E-05
     +,   7.8377152E-06,   3.6796514E-06,   1.6372250E-06
     +,   6.8939494E-07,   2.7435479E-07,   1.0306500E-07
     +,   3.6505067E-08,   1.2177943E-08,   3.8228549E-09
     +,   1.1283935E-09,   3.1294578E-10,   8.1494762E-11
     +,   1.9917481E-11,   4.5668551E-12,   9.8200528E-13
     +,   1.9797921E-13,   3.7431626E-14,   6.6442404E-15
     +,   1.1123626E-15,   1.7881773E-16,   2.9432734E-17
     +,   5.9309958E-18,   1.8288715E-18,   8.1273814E-19
     +,   4.1793929E-19,   2.2247229E-19,   1.1878199E-19
     +,   6.3159414E-20,   3.3397398E-20,   1.7556606E-20
     +,   9.1747303E-21,   4.7663456E-21,   2.4615290E-21
     +,   1.2636978E-21,   6.4492921E-22,   3.2720221E-22
     +,   1.6502544E-22,   8.2737568E-23,   4.1236808E-23
     +,   2.0431696E-23,   1.0063583E-23,   4.9274209E-24
     +,   2.3984213E-24,   1.1605089E-24,   5.5822830E-25
     +,   2.6692696E-25,   1.2688542E-25,   5.9958384E-26
     +,   2.8166106E-26,   1.3152883E-26,   6.1059814E-27
     +,   2.8177805E-27,   1.2926999E-27,   5.8954492E-28
     +,   2.6727297E-28,   1.2045695E-28,   5.3966712E-29
     +,   2.4035901E-29,   1.0641684E-29,   4.6838620E-30
     +,   2.0493290E-30,   8.9137351E-31,   3.8541168E-31
     +,   1.6566488E-31,   7.0786947E-32,   3.0068822E-32
     +,   1.2696728E-32,   5.3298207E-33
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt108 = Yx/0.0123846153846154
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9126394E-06,   8.3706091E-06
     +,   8.8456118E-06,   9.3375811E-06,   9.8463925E-06
     +,   1.0371861E-05,   1.0913738E-05,   1.1471716E-05
     +,   1.2045407E-05,   1.2634380E-05,   1.3238121E-05
     +,   1.3856040E-05,   1.4487488E-05,   1.5131743E-05
     +,   1.5788006E-05,   1.6455420E-05,   1.7133052E-05
     +,   1.7819904E-05,   1.8514918E-05,   1.9216965E-05
     +,   1.9924861E-05,   2.0637362E-05,   2.1353166E-05
     +,   2.2070964E-05,   2.2789314E-05,   2.3506831E-05
     +,   2.4222036E-05,   2.4933439E-05,   2.5639514E-05
     +,   2.6338743E-05,   2.7029566E-05,   2.7710441E-05
     +,   2.8379814E-05,   2.9036155E-05,   2.9677929E-05
     +,   3.0303645E-05,   3.0911822E-05,   3.1501022E-05
     +,   3.2069878E-05,   3.2617008E-05,   3.3141161E-05
     +,   3.3641099E-05,   3.4115663E-05,   3.4563778E-05
     +,   3.4984441E-05,   3.5376732E-05,   3.5739817E-05
     +,   3.6072968E-05,   3.6375539E-05,   3.6646983E-05
     +,   3.6886864E-05,   3.7094840E-05,   3.7270675E-05
     +,   3.7414251E-05,   3.7525522E-05,   3.7604579E-05
     +,   3.7651600E-05,   3.7666865E-05,   3.7650760E-05
     +,   3.7603753E-05,   3.7526417E-05,   3.7419417E-05
     +,   3.7283491E-05,   3.7119469E-05,   3.6928228E-05
     +,   3.6710760E-05,   3.6468085E-05,   3.6201302E-05
     +,   3.5911537E-05,   3.5600006E-05,   3.5267905E-05
     +,   3.4916528E-05,   3.4547134E-05,   3.4161065E-05
     +,   3.3759632E-05,   3.3344160E-05,   3.2915988E-05
     +,   3.2476484E-05,   3.2026957E-05,   3.1568707E-05
     +,   3.1103067E-05,   3.0631283E-05,   3.0154650E-05
     +,   2.9674356E-05,   2.9191637E-05,   2.8707616E-05
     +,   2.8223460E-05,   2.7740229E-05,   2.7259006E-05
     +,   2.6780785E-05,   2.6306529E-05,   2.5837187E-05
     +,   2.5373669E-05,   2.4916813E-05,   2.4467421E-05
     +,   2.4026309E-05,   2.3594188E-05,   2.3171799E-05
     +,   2.2759788E-05,   2.2358834E-05,   2.1969527E-05
     +,   2.1592476E-05,   2.1228225E-05,   2.0877331E-05
     +,   2.0540301E-05,   2.0217614E-05,   1.9909750E-05
     +,   1.9617168E-05,   1.9340288E-05,   1.9079507E-05
     +,   1.8835226E-05,   1.8607796E-05,   1.8397572E-05
     +,   1.8204853E-05,   1.8029948E-05,   1.7873099E-05
     +,   1.7734548E-05,   1.7614479E-05,   1.7513054E-05
     +,   1.7430384E-05,   1.7366539E-05,   1.7321539E-05
     +,   1.7295351E-05,   1.7287883E-05,   1.7298980E-05
     +,   1.7328424E-05,   1.7375931E-05,   1.7441129E-05
     +,   1.7523591E-05,   1.7622780E-05,   1.7738113E-05
     +,   1.7868888E-05,   1.8014342E-05,   1.8173600E-05
     +,   1.8345723E-05,   1.8529679E-05,   1.8724339E-05
     +,   1.8928493E-05,   1.9140858E-05,   1.9360084E-05
     +,   1.9584724E-05,   1.9813273E-05,   2.0044179E-05
     +,   2.0275835E-05,   2.0506573E-05,   2.0734706E-05
     +,   2.0958525E-05,   2.1176294E-05,   2.1386271E-05
     +,   2.1586739E-05,   2.1775992E-05,   2.1952352E-05
     +,   2.2114185E-05,   2.2259936E-05,   2.2388120E-05
     +,   2.2497354E-05,   2.2586377E-05,   2.2654089E-05
     +,   2.2699604E-05,   2.2722268E-05,   2.2721788E-05
     +,   2.2698290E-05,   2.2652484E-05,   2.2585826E-05
     +,   2.2500762E-05,   2.2400995E-05,   2.2291870E-05
     +,   2.2180779E-05,   2.2077642E-05,   2.1995467E-05
     +,   2.1950926E-05,   2.1964950E-05,   2.2063314E-05
     +,   2.2277169E-05,   2.2643449E-05,   2.3205226E-05
     +,   2.4011866E-05,   2.5119049E-05,   2.6588579E-05
     +,   2.8488354E-05,   3.0892039E-05,   3.3878587E-05
     +,   3.7532096E-05,   4.1941967E-05,   4.7202837E-05
     +,   5.3414671E-05,   6.0683673E-05,   6.9124661E-05
     +,   7.8863603E-05,   9.0040885E-05,   1.0282029E-04
     +,   1.1739777E-04,   1.3401386E-04,   1.5297046E-04
     +,   1.7465196E-04,   1.9954516E-04,   2.2825759E-04
     +,   2.6153328E-04,   3.0026140E-04,   3.4546544E-04
     +,   3.9826959E-04,   4.5984375E-04,   5.3132081E-04
     +,   6.1367726E-04,   7.0758007E-04,   8.1324141E-04
     +,   9.3025010E-04,   1.0574184E-03,   1.1926866E-03
     +,   1.3330951E-03,   1.4748215E-03,   1.6133097E-03
     +,   1.7435062E-03,   1.8601744E-03,   1.9582326E-03
     +,   2.0331191E-03,   2.0811381E-03,   2.0997424E-03
     +,   2.0877132E-03,   2.0452510E-03,   1.9739452E-03
     +,   1.8766418E-03,   1.7572391E-03,   1.6204072E-03
     +,   1.4712719E-03,   1.3150970E-03,   1.1569995E-03
     +,   1.0016715E-03,   8.5315655E-04,   7.1471295E-04
     +,   5.8874005E-04,   4.7675360E-04,   3.7942638E-04
     +,   2.9669612E-04,   2.2790328E-04,   1.7192688E-04
     +,   1.2735031E-04,   9.2607770E-05,   6.6104018E-05
     +,   4.6311710E-05,   3.1842403E-05,   2.1487267E-05
     +,   1.4231998E-05,   9.2545661E-06,   5.9106233E-06
     +,   3.7104389E-06,   2.2922825E-06,   1.3963861E-06
     +,   8.4134490E-07,   5.0380856E-07,   3.0197916E-07
     +,   1.8301132E-07,   1.1360220E-07,   7.3259955E-08
     +,   4.9670078E-08,   3.5602763E-08,   2.6904596E-08
     +,   2.1235957E-08,   1.7301344E-08,   1.4392426E-08
     +,   1.2123682E-08,   1.0283316E-08,   8.7515950E-09
     +,   7.4572286E-09,   6.3545711E-09,   5.4115774E-09
     +,   4.6040234E-09,   3.9124974E-09,   3.3207859E-09
     +,   2.8150335E-09,   2.3832982E-09,   2.0152731E-09
     +,   1.7020026E-09,   1.4357094E-09,   1.2096547E-09
     +,   1.0180367E-09,   8.5581897E-10,   7.1868195E-10
     +,   6.0289007E-10,   5.0525234E-10,   4.2301887E-10
     +,   3.5384695E-10,   2.9572658E-10,   2.4695046E-10
     +,   2.0605809E-10,   1.7181359E-10,   1.4316383E-10
     +,   1.1921727E-10,   9.9221131E-11,   8.2537005E-11
     +,   6.8628381E-11,   5.7041500E-11,   4.7396084E-11
     +,   3.9371281E-11,   3.2699034E-11,   2.7153843E-11
     +,   2.2547591E-11,   1.8722496E-11,   1.5547201E-11
     +,   1.2911800E-11,   1.0724960E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt110 = Yx/0.01176
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6751034E-14,   3.8684943E-14
     +,   5.5758302E-14,   8.0101812E-14,   1.1469437E-13
     +,   1.6368470E-13,   2.3283063E-13,   3.3009451E-13
     +,   4.6644465E-13,   6.5694721E-13,   9.2220415E-13
     +,   1.2902972E-12,   1.7993621E-12,   2.5010033E-12
     +,   3.4647738E-12,   4.7841288E-12,   6.5840961E-12
     +,   9.0314188E-12,   1.2347583E-11,   1.6825734E-11
     +,   2.2852423E-11,   3.0935459E-11,   4.1739279E-11
     +,   5.6131159E-11,   7.5235894E-11,   1.0051106E-10
     +,   1.3383486E-10,   1.7761954E-10,   2.3495156E-10
     +,   3.0976477E-10,   4.0705392E-10,   5.3313587E-10
     +,   6.9596917E-10,   9.0554136E-10,   1.1743378E-09
     +,   1.5179027E-09,   1.9555142E-09,   2.5109730E-09
     +,   3.2136085E-09,   4.0992720E-09,   5.2118110E-09
     +,   6.6044445E-09,   8.3416056E-09,   1.0500982E-08
     +,   1.3175775E-08,   1.6477394E-08,   2.0538428E-08
     +,   2.5515954E-08,   3.1595320E-08,   3.8994202E-08
     +,   4.7967049E-08,   5.8810173E-08,   7.1866531E-08
     +,   8.7532563E-08,   1.0626159E-07,   1.2857315E-07
     +,   1.5505665E-07,   1.8637895E-07,   2.2329002E-07
     +,   2.6662937E-07,   3.1733126E-07,   3.7643090E-07
     +,   4.4506280E-07,   5.2447342E-07,   6.1601872E-07
     +,   7.2115512E-07,   8.4145637E-07,   9.7858492E-07
     +,   1.1343153E-06,   1.3104878E-06,   1.5090392E-06
     +,   1.7319378E-06,   1.9812171E-06,   2.2588956E-06
     +,   2.5670040E-06,   2.9075331E-06,   3.2823814E-06
     +,   3.6933295E-06,   4.1420271E-06,   4.6299447E-06
     +,   5.1582592E-06,   5.7279376E-06,   6.3395446E-06
     +,   6.9933521E-06,   7.6891356E-06,   8.4263056E-06
     +,   9.2036853E-06,   1.0019677E-05,   1.0872029E-05
     +,   1.1758007E-05,   1.2674303E-05,   1.3616971E-05
     +,   1.4581499E-05,   1.5562884E-05,   1.6555601E-05
     +,   1.7553561E-05,   1.8550363E-05,   1.9539120E-05
     +,   2.0512780E-05,   2.1463944E-05,   2.2385218E-05
     +,   2.3269053E-05,   2.4108083E-05,   2.4895020E-05
     +,   2.5622907E-05,   2.6285175E-05,   2.6875683E-05
     +,   2.7388864E-05,   2.7819844E-05,   2.8164481E-05
     +,   2.8419394E-05,   2.8582099E-05,   2.8650988E-05
     +,   2.8625380E-05,   2.8505527E-05,   2.8292607E-05
     +,   2.7988732E-05,   2.7596843E-05,   2.7120774E-05
     +,   2.6565071E-05,   2.5934969E-05,   2.5236362E-05
     +,   2.4475667E-05,   2.3659672E-05,   2.2795490E-05
     +,   2.1890537E-05,   2.0952230E-05,   1.9988125E-05
     +,   1.9005587E-05,   1.8011928E-05,   1.7014087E-05
     +,   1.6018810E-05,   1.5032332E-05,   1.4060579E-05
     +,   1.3108911E-05,   1.2182179E-05,   1.1284784E-05
     +,   1.0420611E-05,   9.5929699E-06,   8.8047009E-06
     +,   8.0582422E-06,   7.3556234E-06,   6.6984840E-06
     +,   6.0881771E-06,   5.5259061E-06,   5.0126810E-06
     +,   4.5494635E-06,   4.1372809E-06,   3.7772738E-06
     +,   3.4707571E-06,   3.2193341E-06,   3.0249771E-06
     +,   2.8900622E-06,   2.8174079E-06,   2.8103241E-06
     +,   2.8726083E-06,   3.0085139E-06,   3.2227131E-06
     +,   3.5202227E-06,   3.9062461E-06,   4.3860800E-06
     +,   4.9649229E-06,   5.6476119E-06,   6.4384062E-06
     +,   7.3407982E-06,   8.3572204E-06,   9.4887173E-06
     +,   1.0734786E-05,   1.2093302E-05,   1.3560410E-05
     +,   1.5130454E-05,   1.6796339E-05,   1.8550081E-05
     +,   2.0383453E-05,   2.2288803E-05,   2.4260737E-05
     +,   2.6297492E-05,   2.8402570E-05,   3.0586551E-05
     +,   3.2868735E-05,   3.5277928E-05,   3.7852198E-05
     +,   4.0637595E-05,   4.3685210E-05,   4.7046029E-05
     +,   5.0763778E-05,   5.4866665E-05,   5.9358434E-05
     +,   6.4209249E-05,   6.9348083E-05,   7.4660122E-05
     +,   7.9988662E-05,   8.5145679E-05,   8.9934954E-05
     +,   9.4192095E-05,   9.7845375E-05,   1.0100348E-04
     +,   1.0407002E-04,   1.0787432E-04,   1.1379326E-04
     +,   1.2382427E-04,   1.4056868E-04,   1.6711019E-04
     +,   2.0682468E-04,   2.6320998E-04,   3.3984936E-04
     +,   4.4047117E-04,   5.6888832E-04,   7.2848122E-04
     +,   9.2100323E-04,   1.1449249E-03,   1.3940735E-03
     +,   1.6574800E-03,   1.9207476E-03,   2.1684295E-03
     +,   2.3864782E-03,   2.5639280E-03,   2.6932880E-03
     +,   2.7696041E-03,   2.7887351E-03,   2.7459941E-03
     +,   2.6365144E-03,   2.4579831E-03,   2.2146180E-03
     +,   1.9199126E-03,   1.5960556E-03,   1.2697233E-03
     +,   9.6599397E-04,   7.0312148E-04,   4.9015734E-04
     +,   3.2761172E-04,   2.1003882E-04,   1.2908193E-04
     +,   7.5897209E-05,   4.2571934E-05,   2.2699849E-05
     +,   1.1464518E-05,   5.4668890E-06,   2.4554520E-06
     +,   1.0374641E-06,   4.1259963E-07,   1.5510676E-07
     +,   5.5763220E-08,   1.9703421E-08,   7.2317077E-09
     +,   2.9951939E-09,   1.4892858E-09,   8.7303587E-10
     +,   5.6322108E-10,   3.7794545E-10,   2.5638947E-10
     +,   1.7384659E-10,   1.1736072E-10,   7.8783140E-11
     +,   5.2569425E-11,   3.4863723E-11,   2.2979936E-11
     +,   1.5054355E-11,   9.8018390E-12,   6.3427484E-12
     +,   4.0792439E-12,   2.6074715E-12,   1.6564963E-12
     +,   1.0458915E-12,   6.5632862E-13,   4.0934267E-13
     +,   2.5373364E-13,   1.5631451E-13,   9.5710732E-14
     +,   5.8244249E-14,   3.5226467E-14,   2.1174687E-14
     +,   1.2650377E-14,   7.5114153E-15,   4.4326517E-15
     +,   2.5998294E-15,   1.5154811E-15,   8.7800047E-16
     +,   5.0554907E-16,   2.8931408E-16,   1.6455121E-16
     +,   9.3018888E-17,   5.2259448E-17,   2.9180897E-17
     +,   1.6194037E-17,   8.9320658E-18,   4.8964410E-18
     +,   2.6676686E-18,   1.4445142E-18,   7.7738496E-19
     +,   4.1580586E-19,   2.2103848E-19,   1.1678431E-19
     +,   6.1323300E-20,   3.2004119E-20,   1.6599970E-20
     +,   8.5575898E-21,   4.3844656E-21,   2.2326701E-21
     +,   1.1299308E-21,   5.6835790E-22
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt112 = Yx/0.0107916666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3713113E-05,   3.4443274E-05
     +,   3.5158693E-05,   3.5857924E-05,   3.6539554E-05
     +,   3.7202200E-05,   3.7844511E-05,   3.8465176E-05
     +,   3.9062928E-05,   3.9636561E-05,   4.0184917E-05
     +,   4.0706902E-05,   4.1201485E-05,   4.1667688E-05
     +,   4.2104632E-05,   4.2511496E-05,   4.2887550E-05
     +,   4.3232129E-05,   4.3544664E-05,   4.3824672E-05
     +,   4.4071745E-05,   4.4285589E-05,   4.4465964E-05
     +,   4.4612752E-05,   4.4725904E-05,   4.4805467E-05
     +,   4.4851578E-05,   4.4864453E-05,   4.4844408E-05
     +,   4.4791817E-05,   4.4707169E-05,   4.4590986E-05
     +,   4.4443910E-05,   4.4266624E-05,   4.4059900E-05
     +,   4.3824555E-05,   4.3561475E-05,   4.3271615E-05
     +,   4.2955940E-05,   4.2615520E-05,   4.2251413E-05
     +,   4.1864754E-05,   4.1456686E-05,   4.1028383E-05
     +,   4.0581061E-05,   4.0115927E-05,   3.9634226E-05
     +,   3.9137190E-05,   3.8626069E-05,   3.8102116E-05
     +,   3.7566555E-05,   3.7020633E-05,   3.6465568E-05
     +,   3.5902536E-05,   3.5332760E-05,   3.4757362E-05
     +,   3.4177487E-05,   3.3594235E-05,   3.3008666E-05
     +,   3.2421816E-05,   3.1834683E-05,   3.1248201E-05
     +,   3.0663323E-05,   3.0080893E-05,   2.9501725E-05
     +,   2.8926634E-05,   2.8356309E-05,   2.7791488E-05
     +,   2.7232771E-05,   2.6680793E-05,   2.6136056E-05
     +,   2.5599100E-05,   2.5070356E-05,   2.4550254E-05
     +,   2.4039144E-05,   2.3537334E-05,   2.3045113E-05
     +,   2.2562739E-05,   2.2090386E-05,   2.1628195E-05
     +,   2.1176316E-05,   2.0734804E-05,   2.0303736E-05
     +,   1.9883099E-05,   1.9472904E-05,   1.9073079E-05
     +,   1.8683580E-05,   1.8304283E-05,   1.7935092E-05
     +,   1.7575849E-05,   1.7226381E-05,   1.6886514E-05
     +,   1.6556063E-05,   1.6234804E-05,   1.5922495E-05
     +,   1.5618918E-05,   1.5323802E-05,   1.5036913E-05
     +,   1.4757968E-05,   1.4486707E-05,   1.4222841E-05
     +,   1.3966112E-05,   1.3716219E-05,   1.3472900E-05
     +,   1.3235865E-05,   1.3004828E-05,   1.2779524E-05
     +,   1.2559685E-05,   1.2345040E-05,   1.2135313E-05
     +,   1.1930265E-05,   1.1729631E-05,   1.1533179E-05
     +,   1.1340661E-05,   1.1151865E-05,   1.0966556E-05
     +,   1.0784535E-05,   1.0605590E-05,   1.0429540E-05
     +,   1.0256196E-05,   1.0085379E-05,   9.9169329E-06
     +,   9.7507063E-06,   9.5865535E-06,   9.4243314E-06
     +,   9.2639293E-06,   9.1052198E-06,   8.9481082E-06
     +,   8.7924864E-06,   8.6382788E-06,   8.4853973E-06
     +,   8.3337800E-06,   8.1833559E-06,   8.0340806E-06
     +,   7.8859011E-06,   7.7387795E-06,   7.5926841E-06
     +,   7.4475952E-06,   7.3034903E-06,   7.1603517E-06
     +,   7.0181763E-06,   6.8769687E-06,   6.7367250E-06
     +,   6.5974500E-06,   6.4591636E-06,   6.3218777E-06
     +,   6.1856072E-06,   6.0503780E-06,   5.9162198E-06
     +,   5.7831571E-06,   5.6512145E-06,   5.5204268E-06
     +,   5.3908329E-06,   5.2624632E-06,   5.1353481E-06
     +,   5.0095268E-06,   4.8850429E-06,   4.7619274E-06
     +,   4.6402124E-06,   4.5199445E-06,   4.4011558E-06
     +,   4.2838801E-06,   4.1681583E-06,   4.0540353E-06
     +,   3.9415504E-06,   3.8307489E-06,   3.7216973E-06
     +,   3.6144827E-06,   3.5092210E-06,   3.4060834E-06
     +,   3.3053443E-06,   3.2074242E-06,   3.1129632E-06
     +,   3.0229482E-06,   2.9388973E-06,   2.8630925E-06
     +,   2.7989399E-06,   2.7514695E-06,   2.7279962E-06
     +,   2.7390256E-06,   2.7994568E-06,   2.9301318E-06
     +,   3.1598170E-06,   3.5277076E-06,   4.0865152E-06
     +,   4.9061146E-06,   6.0779116E-06,   7.7199438E-06
     +,   9.9825520E-06,   1.3054195E-05,   1.7168286E-05
     +,   2.2609524E-05,   2.9719367E-05,   3.8901013E-05
     +,   5.0623363E-05,   6.5421555E-05,   8.3893246E-05
     +,   1.0669198E-04,   1.3451707E-04,   1.6809464E-04
     +,   2.0815060E-04,   2.5538009E-04,   3.1041278E-04
     +,   3.7376711E-04,   4.4579356E-04,   5.2663533E-04
     +,   6.1617186E-04,   7.1396423E-04,   8.1921782E-04
     +,   9.3076157E-04,   1.0470290E-03,   1.1660556E-03
     +,   1.2855144E-03,   1.4027803E-03,   1.5149990E-03
     +,   1.6191823E-03,   1.7123366E-03,   1.7916062E-03
     +,   1.8544033E-03,   1.8985408E-03,   1.9223710E-03
     +,   1.9248733E-03,   1.9057302E-03,   1.8653593E-03
     +,   1.8049021E-03,   1.7261682E-03,   1.6315544E-03
     +,   1.5239200E-03,   1.4064281E-03,   1.2823944E-03
     +,   1.1551344E-03,   1.0278060E-03,   9.0326858E-04
     +,   7.8399084E-04,   6.7198969E-04,   5.6877016E-04
     +,   4.7533560E-04,   3.9221736E-04,   3.1951600E-04
     +,   2.5696313E-04,   2.0400262E-04,   1.5987136E-04
     +,   1.2366942E-04,   9.4426359E-05,   7.1162154E-05
     +,   5.2933159E-05,   3.8862814E-05,   2.8162611E-05
     +,   2.0144618E-05,   1.4224574E-05,   9.9167601E-06
     +,   6.8271961E-06,   4.6431628E-06,   3.1212151E-06
     +,   2.0755117E-06,   1.3669745E-06,   8.9344542E-07
     +,   5.8117394E-07,   3.7784719E-07,   2.4701743E-07
     +,   1.6372130E-07,   1.1113551E-07,   7.8107853E-08
     +,   5.7367938E-08,   4.4252225E-08,   3.5813152E-08
     +,   3.0217656E-08,   2.6342731E-08,   2.3509859E-08
     +,   2.1314372E-08,   1.9517822E-08,   1.7981039E-08
     +,   1.6623064E-08,   1.5396578E-08,   1.4273549E-08
     +,   1.3236926E-08,   1.2275589E-08,   1.1381962E-08
     +,   1.0550253E-08,   9.7758912E-09,   9.0548475E-09
     +,   8.3836227E-09,   7.7589428E-09,   7.1778272E-09
     +,   6.6374404E-09,   6.1351697E-09,   5.6685163E-09
     +,   5.2351403E-09,   4.8328710E-09,   4.4596202E-09
     +,   4.1134682E-09,   3.7925774E-09,   3.4952523E-09
     +,   3.2198699E-09,   2.9649427E-09,   2.7290377E-09
     +,   2.5108533E-09,   2.3091284E-09,   2.1227209E-09
     +,   1.9505357E-09,   1.7915653E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt113 = Yx/0.01176
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6099715E-21,   2.7390834E-21
     +,   4.6424502E-21,   7.8386422E-21,   1.3185179E-20
     +,   2.2094516E-20,   3.6883706E-20,   6.1339178E-20
     +,   1.0162241E-19,   1.6772496E-19,   2.7577770E-19
     +,   4.5172400E-19,   7.3712081E-19,   1.1982754E-18
     +,   1.9405639E-18,   3.1307740E-18,   5.0318621E-18
     +,   8.0567036E-18,   1.2851073E-17,   2.0420772E-17
     +,   3.2326533E-17,   5.0979853E-17,   8.0091630E-17
     +,   1.2535304E-16,   1.9544679E-16,   3.0358338E-16
     +,   4.6976521E-16,   7.2416140E-16,   1.1120986E-15
     +,   1.7013863E-15,   2.5930802E-15,   3.9371392E-15
     +,   5.9552481E-15,   8.9736830E-15,   1.3470851E-14
     +,   2.0145181E-14,   3.0012349E-14,   4.4543047E-14
     +,   6.5859353E-14,   9.7006936E-14,   1.4234539E-13
     +,   2.0808310E-13,   3.0302822E-13,   4.3962566E-13
     +,   6.3538226E-13,   9.1483104E-13,   1.3121992E-12
     +,   1.8750448E-12,   2.6691722E-12,   3.7852551E-12
     +,   5.3476988E-12,   7.5264751E-12,   1.0552796E-11
     +,   1.4740164E-11,   2.0510944E-11,   2.8433160E-11
     +,   3.9266142E-11,   5.4021329E-11,   7.4040038E-11
     +,   1.0109323E-10,   1.3750918E-10,   1.8633646E-10
     +,   2.5154442E-10,   3.3828776E-10,   4.5322815E-10
     +,   6.0492128E-10,   8.0434048E-10,   1.0654492E-09
     +,   1.4060021E-09,   1.8483796E-09,   2.4207865E-09
     +,   3.1584555E-09,   4.1053894E-09,   5.3160334E-09
     +,   6.8577064E-09,   8.8131706E-09,   1.1283523E-08
     +,   1.4391728E-08,   1.8286951E-08,   2.3149081E-08
     +,   2.9193375E-08,   3.6677523E-08,   4.5906638E-08
     +,   5.7242389E-08,   7.1108545E-08,   8.8002359E-08
     +,   1.0850012E-07,   1.3327157E-07,   1.6308383E-07
     +,   1.9881750E-07,   2.4147550E-07,   2.9218978E-07
     +,   3.5223260E-07,   4.2303017E-07,   5.0616791E-07
     +,   6.0338812E-07,   7.1661316E-07,   8.4792350E-07
     +,   9.9958481E-07,   1.1740104E-06,   1.3737932E-06
     +,   1.6016476E-06,   1.8604437E-06,   2.1531280E-06
     +,   2.4827511E-06,   2.8524180E-06,   3.2652217E-06
     +,   3.7242162E-06,   4.2324095E-06,   4.7926810E-06
     +,   5.4076750E-06,   6.0798684E-06,   6.8113527E-06
     +,   7.6039523E-06,   8.4589701E-06,   9.3773433E-06
     +,   1.0359360E-05,   1.1404864E-05,   1.2512939E-05
     +,   1.3682124E-05,   1.4910295E-05,   1.6194552E-05
     +,   1.7531303E-05,   1.8916364E-05,   2.0344889E-05
     +,   2.1811260E-05,   2.3309487E-05,   2.4832834E-05
     +,   2.6374326E-05,   2.7926366E-05,   2.9481283E-05
     +,   3.1030973E-05,   3.2567383E-05,   3.4082223E-05
     +,   3.5567391E-05,   3.7014910E-05,   3.8416900E-05
     +,   3.9765764E-05,   4.1054333E-05,   4.2275824E-05
     +,   4.3423814E-05,   4.4492346E-05,   4.5476059E-05
     +,   4.6370082E-05,   4.7170000E-05,   4.7872003E-05
     +,   4.8472826E-05,   4.8969658E-05,   4.9360227E-05
     +,   4.9642807E-05,   4.9816161E-05,   4.9879513E-05
     +,   4.9832637E-05,   4.9675786E-05,   4.9409726E-05
     +,   4.9035774E-05,   4.8555834E-05,   4.7972386E-05
     +,   4.7288551E-05,   4.6508278E-05,   4.5636243E-05
     +,   4.4678040E-05,   4.3640386E-05,   4.2531239E-05
     +,   4.1359919E-05,   4.0137387E-05,   3.8876642E-05
     +,   3.7592978E-05,   3.6304249E-05,   3.5031379E-05
     +,   3.3798868E-05,   3.2635136E-05,   3.1572836E-05
     +,   3.0649266E-05,   2.9906592E-05,   2.9391646E-05
     +,   2.9155661E-05,   2.9253562E-05,   2.9742649E-05
     +,   3.0680887E-05,   3.2124542E-05,   3.4125049E-05
     +,   3.6725422E-05,   3.9956398E-05,   4.3832177E-05
     +,   4.8345908E-05,   5.3466243E-05,   5.9135382E-05
     +,   6.5268177E-05,   7.1753464E-05,   7.8460624E-05
     +,   8.5248183E-05,   9.1976399E-05,   9.8524004E-05
     +,   1.0480631E-04,   1.1079059E-04,   1.1650570E-04
     +,   1.2204175E-04,   1.2753582E-04,   1.3314285E-04
     +,   1.3899854E-04,   1.4518791E-04,   1.5173870E-04
     +,   1.5866176E-04,   1.6605538E-04,   1.7427656E-04
     +,   1.8414976E-04,   1.9715686E-04,   2.1553024E-04
     +,   2.4217159E-04,   2.8036660E-04,   3.3335362E-04
     +,   4.0393826E-04,   4.9443153E-04,   6.0715975E-04
     +,   7.4559584E-04,   9.1571116E-04,   1.1264806E-03
     +,   1.3879803E-03,   1.7059091E-03,   2.0732330E-03
     +,   2.4621584E-03,   2.8219104E-03,   3.0868629E-03
     +,   3.1946970E-03,   3.1080290E-03,   2.8296215E-03
     +,   2.4033827E-03,   1.9003729E-03,   1.3966686E-03
     +,   9.5290638E-04,   6.0289784E-04,   3.5336334E-04
     +,   1.9166103E-04,   9.6108641E-05,   4.4511904E-05
     +,   1.9022429E-05,   7.4954010E-06,   2.7215494E-06
     +,   9.1037799E-07,   2.8071159E-07,   8.0003616E-08
     +,   2.1250079E-08,   5.3852975E-09,   1.3855612E-09
     +,   4.1124928E-10,   1.6095748E-10,   8.1823763E-11
     +,   4.7840249E-11,   2.9565295E-11,   1.8705284E-11
     +,   1.2006606E-11,   7.8006065E-12,   5.1240700E-12
     +,   3.3989970E-12,   2.2734334E-12,   1.5307053E-12
     +,   1.0357304E-12,   7.0314300E-13,   4.7824689E-13
     +,   3.2549050E-13,   2.2144417E-13,   1.5047525E-13
     +,   1.0205930E-13,   6.9058603E-14,   4.6600205E-14
     +,   3.1349702E-14,   2.1021638E-14,   1.4048307E-14
     +,   9.3551807E-15,   6.2073759E-15,   4.1036743E-15
     +,   2.7029287E-15,   1.7736783E-15,   1.1595247E-15
     +,   7.5518615E-16,   4.8998325E-16,   3.1671753E-16
     +,   2.0394472E-16,   1.3083157E-16,   8.3610185E-17
     +,   5.3231048E-17,   3.3761026E-17,   2.1331676E-17
     +,   1.3427044E-17,   8.4196390E-18,   5.2596763E-18
     +,   3.2731719E-18,   2.0292564E-18,   1.2532859E-18
     +,   7.7111917E-19,   4.7264723E-19,   2.8861030E-19
     +,   1.7556238E-19,   1.0639210E-19,   6.4228920E-20
     +,   3.8628853E-20,   2.3143974E-20,   1.3814037E-20
     +,   8.2139108E-21,   4.8656133E-21
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt114 = Yx/0.009625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt1148(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.7763034E-06,   8.0967029E-06
     +,   8.4249023E-06,   8.7607941E-06,   9.1042566E-06
     +,   9.4551497E-06,   9.8133078E-06,   1.0178553E-05
     +,   1.0550672E-05,   1.0929454E-05,   1.1314650E-05
     +,   1.1705993E-05,   1.2103196E-05,   1.2505952E-05
     +,   1.2913932E-05,   1.3326786E-05,   1.3744141E-05
     +,   1.4165613E-05,   1.4590786E-05,   1.5019233E-05
     +,   1.5450512E-05,   1.5884156E-05,   1.6319684E-05
     +,   1.6756620E-05,   1.7194432E-05,   1.7632627E-05
     +,   1.8070665E-05,   1.8508021E-05,   1.8944154E-05
     +,   1.9378525E-05,   1.9810597E-05,   2.0239830E-05
     +,   2.0665691E-05,   2.1087671E-05,   2.1505255E-05
     +,   2.1917955E-05,   2.2325305E-05,   2.2726847E-05
     +,   2.3122191E-05,   2.3510931E-05,   2.3892739E-05
     +,   2.4267310E-05,   2.4634393E-05,   2.4993786E-05
     +,   2.5345342E-05,   2.5688985E-05,   2.6024700E-05
     +,   2.6352534E-05,   2.6672629E-05,   2.6985195E-05
     +,   2.7290527E-05,   2.7589005E-05,   2.7881102E-05
     +,   2.8167407E-05,   2.8448560E-05,   2.8725337E-05
     +,   2.8998606E-05,   2.9269329E-05,   2.9538573E-05
     +,   2.9807499E-05,   3.0077374E-05,   3.0349562E-05
     +,   3.0625495E-05,   3.0906733E-05,   3.1194897E-05
     +,   3.1491665E-05,   3.1798823E-05,   3.2118176E-05
     +,   3.2451619E-05,   3.2801032E-05,   3.3168395E-05
     +,   3.3555629E-05,   3.3964712E-05,   3.4397570E-05
     +,   3.4856123E-05,   3.5342269E-05,   3.5857793E-05
     +,   3.6404417E-05,   3.6983805E-05,   3.7597507E-05
     +,   3.8246893E-05,   3.8933278E-05,   3.9657720E-05
     +,   4.0421204E-05,   4.1224444E-05,   4.2068055E-05
     +,   4.2952317E-05,   4.3877440E-05,   4.4843284E-05
     +,   4.5849541E-05,   4.6895741E-05,   4.7981073E-05
     +,   4.9104514E-05,   5.0264898E-05,   5.1460851E-05
     +,   5.2690688E-05,   5.3952735E-05,   5.5244956E-05
     +,   5.6565379E-05,   5.7911740E-05,   5.9281869E-05
     +,   6.0673370E-05,   6.2084015E-05,   6.3511405E-05
     +,   6.4953339E-05,   6.6407687E-05,   6.7872388E-05
     +,   6.9345486E-05,   7.0825365E-05,   7.2310599E-05
     +,   7.3799863E-05,   7.5292352E-05,   7.6787299E-05
     +,   7.8284480E-05,   7.9783757E-05,   8.1285543E-05
     +,   8.2790357E-05,   8.4299172E-05,   8.5813066E-05
     +,   8.7333494E-05,   8.8862114E-05,   9.0400645E-05
     +,   9.1950867E-05,   9.3514776E-05,   9.5094205E-05
     +,   9.6690805E-05,   9.8306256E-05,   9.9941703E-05
     +,   1.0159815E-04,   1.0327602E-04,   1.0497534E-04
     +,   1.0669538E-04,   1.0843491E-04,   1.1019183E-04
     +,   1.1196333E-04,   1.1374582E-04,   1.1553474E-04
     +,   1.1732462E-04,   1.1910922E-04,   1.2088146E-04
     +,   1.2263325E-04,   1.2435573E-04,   1.2603939E-04
     +,   1.2767401E-04,   1.2924867E-04,   1.3075209E-04
     +,   1.3217253E-04,   1.3349798E-04,   1.3471623E-04
     +,   1.3581515E-04,   1.3678274E-04,   1.3760716E-04
     +,   1.3827698E-04,   1.3878137E-04,   1.3911013E-04
     +,   1.3925375E-04,   1.3920378E-04,   1.3895270E-04
     +,   1.3849408E-04,   1.3782278E-04,   1.3693486E-04
     +,   1.3582775E-04,   1.3450038E-04,   1.3295314E-04
     +,   1.3118786E-04,   1.2920787E-04,   1.2701827E-04
     +,   1.2462570E-04,   1.2203829E-04,   1.1926582E-04
     +,   1.1631988E-04,   1.1321379E-04,   1.0996246E-04
     +,   1.0658251E-04,   1.0309277E-04,   9.9513825E-05
     +,   9.5868229E-05,   9.2181035E-05,   8.8479806E-05
     +,   8.4794439E-05,   8.1157799E-05,   7.7606150E-05
     +,   7.4179414E-05,   7.0921429E-05,   6.7880639E-05
     +,   6.5111293E-05,   6.2674000E-05,   6.0636929E-05
     +,   5.9077571E-05,   5.8084810E-05,   5.7760972E-05
     +,   5.8224865E-05,   5.9614831E-05,   6.2092120E-05
     +,   6.5844601E-05,   7.1090166E-05,   7.8078992E-05
     +,   8.7095170E-05,   9.8457393E-05,   1.1251619E-04
     +,   1.2964735E-04,   1.5024310E-04,   1.7470021E-04
     +,   2.0340143E-04,   2.3668997E-04,   2.7484872E-04
     +,   3.1806855E-04,   3.6641478E-04,   4.1979706E-04
     +,   4.7794651E-04,   5.4038811E-04,   6.0642126E-04
     +,   6.7511736E-04,   7.4533129E-04,   8.1571657E-04
     +,   8.8475441E-04,   9.5080840E-04,   1.0121856E-03
     +,   1.0672022E-03,   1.1142527E-03,   1.1518970E-03
     +,   1.1789241E-03,   1.1944150E-03,   1.1977949E-03
     +,   1.1888669E-03,   1.1678203E-03,   1.1352277E-03
     +,   1.0920183E-03,   1.0394257E-03,   9.7893050E-04
     +,   9.1219234E-04,   8.4097026E-04,   7.6703826E-04
     +,   6.9211540E-04,   6.1780773E-04,   5.4553978E-04
     +,   4.7652167E-04,   4.1172895E-04,   3.5188679E-04
     +,   2.9747060E-04,   2.4872602E-04,   2.0569621E-04
     +,   1.6824889E-04,   1.3610897E-04,   1.0889735E-04
     +,   8.6166387E-05,   6.7428504E-05,   5.2182218E-05
     +,   3.9935854E-05,   3.0224910E-05,   2.2621274E-05
     +,   1.6742026E-05,   1.2252777E-05,   8.8673723E-06
     +,   6.3456823E-06,   4.4902795E-06,   3.1418028E-06
     +,   2.1736753E-06,   1.4869956E-06,   1.0058042E-06
     +,   6.7267592E-07,   4.4482383E-07,   2.9083719E-07
     +,   1.8800975E-07,   1.2016770E-07,   7.5938395E-08
     +,   4.7445070E-08,   2.9307573E-08,   1.7899076E-08
     +,   1.0807711E-08,   6.4517738E-09,   3.8077737E-09
     +,   2.2218536E-09,   1.2817489E-09,   7.3101225E-10
     +,   4.1218934E-10,   2.2977584E-10,   1.2663896E-10
     +,   6.9004205E-11,   3.7175513E-11,   1.9802110E-11
     +,   1.0430052E-11,   5.4326257E-12,   2.7988237E-12
     +,   1.4265477E-12,   7.1971785E-13,   3.5968740E-13
     +,   1.7828583E-13,   8.7837256E-14,   4.3163996E-14
     +,   2.1279922E-14,   1.0620717E-14,   5.4388883E-15
     +,   2.9081025E-15,   1.6538548E-15,   1.0136089E-15
     +,   6.7063357E-16,   4.7412182E-16,   3.5228881E-16
     +,   2.7063740E-16,   2.1224999E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt1148 = Yx/0.00991666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9836245E-06,   8.2047100E-06
     +,   8.4267640E-06,   8.6495647E-06,   8.8728948E-06
     +,   9.0965314E-06,   9.3202543E-06,   9.5438390E-06
     +,   9.7670609E-06,   9.9897134E-06,   1.0211575E-05
     +,   1.0432435E-05,   1.0652090E-05,   1.0870341E-05
     +,   1.1086996E-05,   1.1301879E-05,   1.1514811E-05
     +,   1.1725638E-05,   1.1934204E-05,   1.2140381E-05
     +,   1.2344044E-05,   1.2545086E-05,   1.2743416E-05
     +,   1.2938968E-05,   1.3131675E-05,   1.3321507E-05
     +,   1.3508442E-05,   1.3692485E-05,   1.3873653E-05
     +,   1.4051986E-05,   1.4227549E-05,   1.4400424E-05
     +,   1.4570713E-05,   1.4738535E-05,   1.4904044E-05
     +,   1.5067395E-05,   1.5228777E-05,   1.5388390E-05
     +,   1.5546464E-05,   1.5703223E-05,   1.5858937E-05
     +,   1.6013875E-05,   1.6168326E-05,   1.6322587E-05
     +,   1.6476979E-05,   1.6631826E-05,   1.6787459E-05
     +,   1.6944228E-05,   1.7102491E-05,   1.7262604E-05
     +,   1.7424934E-05,   1.7589849E-05,   1.7757724E-05
     +,   1.7928936E-05,   1.8103861E-05,   1.8282873E-05
     +,   1.8466351E-05,   1.8654671E-05,   1.8848203E-05
     +,   1.9047322E-05,   1.9252393E-05,   1.9463792E-05
     +,   1.9681869E-05,   1.9906998E-05,   2.0139549E-05
     +,   2.0379861E-05,   2.0628317E-05,   2.0885258E-05
     +,   2.1151067E-05,   2.1426093E-05,   2.1710714E-05
     +,   2.2005293E-05,   2.2310229E-05,   2.2625882E-05
     +,   2.2952650E-05,   2.3290953E-05,   2.3641182E-05
     +,   2.4003746E-05,   2.4379078E-05,   2.4767627E-05
     +,   2.5169806E-05,   2.5586092E-05,   2.6016913E-05
     +,   2.6462743E-05,   2.6924015E-05,   2.7401216E-05
     +,   2.7894761E-05,   2.8405118E-05,   2.8932680E-05
     +,   2.9477862E-05,   3.0041059E-05,   3.0622603E-05
     +,   3.1222778E-05,   3.1841861E-05,   3.2480071E-05
     +,   3.3137527E-05,   3.3814329E-05,   3.4510427E-05
     +,   3.5225799E-05,   3.5960195E-05,   3.6713391E-05
     +,   3.7484933E-05,   3.8274382E-05,   3.9081060E-05
     +,   3.9904244E-05,   4.0743100E-05,   4.1596613E-05
     +,   4.2463627E-05,   4.3342938E-05,   4.4233224E-05
     +,   4.5132958E-05,   4.6040641E-05,   4.6954552E-05
     +,   4.7873036E-05,   4.8794263E-05,   4.9716455E-05
     +,   5.0637736E-05,   5.1556352E-05,   5.2470430E-05
     +,   5.3378306E-05,   5.4278375E-05,   5.5169119E-05
     +,   5.6049161E-05,   5.6917379E-05,   5.7772904E-05
     +,   5.8615002E-05,   5.9443384E-05,   6.0257957E-05
     +,   6.1059101E-05,   6.1847473E-05,   6.2624240E-05
     +,   6.3390922E-05,   6.4149572E-05,   6.4902626E-05
     +,   6.5653061E-05,   6.6404318E-05,   6.7160283E-05
     +,   6.7925263E-05,   6.8704030E-05,   6.9501795E-05
     +,   7.0324015E-05,   7.1176430E-05,   7.2065042E-05
     +,   7.2995957E-05,   7.3975207E-05,   7.5008764E-05
     +,   7.6102398E-05,   7.7261422E-05,   7.8490521E-05
     +,   7.9793783E-05,   8.1174425E-05,   8.2634477E-05
     +,   8.4174753E-05,   8.5794803E-05,   8.7492634E-05
     +,   8.9264569E-05,   9.1105205E-05,   9.3007533E-05
     +,   9.4962867E-05,   9.6960663E-05,   9.8989047E-05
     +,   1.0103485E-04,   1.0308370E-04,   1.0512042E-04
     +,   1.0712956E-04,   1.0909560E-04,   1.1100336E-04
     +,   1.1283850E-04,   1.1458802E-04,   1.1624068E-04
     +,   1.1778725E-04,   1.1922094E-04,   1.2053786E-04
     +,   1.2173702E-04,   1.2282043E-04,   1.2379349E-04
     +,   1.2466464E-04,   1.2544541E-04,   1.2615038E-04
     +,   1.2679705E-04,   1.2740570E-04,   1.2799940E-04
     +,   1.2860408E-04,   1.2924876E-04,   1.2996608E-04
     +,   1.3079276E-04,   1.3177078E-04,   1.3294864E-04
     +,   1.3438294E-04,   1.3614014E-04,   1.3829916E-04
     +,   1.4095359E-04,   1.4421370E-04,   1.4820920E-04
     +,   1.5309091E-04,   1.5903222E-04,   1.6622836E-04
     +,   1.7489567E-04,   1.8526867E-04,   1.9759494E-04
     +,   2.1212634E-04,   2.2910934E-04,   2.4877369E-04
     +,   2.7131673E-04,   2.9688401E-04,   3.2555606E-04
     +,   3.5732827E-04,   3.9209175E-04,   4.2962012E-04
     +,   4.6956158E-04,   5.1143055E-04,   5.5460568E-04
     +,   5.9833919E-04,   6.4177625E-04,   6.8397372E-04
     +,   7.2392792E-04,   7.6061412E-04,   7.9302827E-04
     +,   8.2022662E-04,   8.4136566E-04,   8.5574691E-04
     +,   8.6284673E-04,   8.6234324E-04,   8.5413444E-04
     +,   8.3834375E-04,   8.1531407E-04,   7.8559516E-04
     +,   7.4991758E-04,   7.0915709E-04,   6.6429633E-04
     +,   6.1638613E-04,   5.6650006E-04,   5.1568862E-04
     +,   4.6494458E-04,   4.1517642E-04,   3.6717305E-04
     +,   3.2159142E-04,   2.7895081E-04,   2.3962678E-04
     +,   2.0385392E-04,   1.7173952E-04,   1.4327993E-04
     +,   1.1837558E-04,   9.6848467E-05,   7.8463789E-05
     +,   6.2949155E-05,   5.0009592E-05,   3.9341598E-05
     +,   3.0646272E-05,   2.3639212E-05,   1.8055522E-05
     +,   1.3655269E-05,   1.0225929E-05,   7.5825892E-06
     +,   5.5671858E-06,   4.0471396E-06,   2.9130936E-06
     +,   2.0761304E-06,   1.4650063E-06,   1.0235258E-06
     +,   7.0799911E-07,   4.8488846E-07,   3.2878816E-07
     +,   2.2072162E-07,   1.4670155E-07,   9.6532844E-08
     +,   6.2886180E-08,   4.0558024E-08,   2.5896535E-08
     +,   1.6369661E-08,   1.0243798E-08,   6.3461316E-09
     +,   3.8921448E-09,   2.3631652E-09,   1.4204261E-09
     +,   8.4524543E-10,   4.9794580E-10,   2.9043493E-10
     +,   1.6772526E-10,   9.5916615E-11,   5.4324482E-11
     +,   3.0481839E-11,   1.6951423E-11,   9.3499843E-12
     +,   5.1205793E-12,   2.7893714E-12,   1.5154808E-12
     +,   8.2464661E-13,   4.5226949E-13,   2.5221494E-13
     +,   1.4467245E-13,   8.6459878E-14,   5.4451049E-14
     +,   3.6357127E-14,   2.5699120E-14,   1.9073827E-14
     +,   1.4696706E-14,   1.1625797E-14,   9.3573441E-15
     +,   7.6139631E-15,   6.2367142E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt116 = Yx/0.00795454545454546
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.4929723E-07,   6.0959042E-07
     +,   6.7564071E-07,   7.4789676E-07,   8.2683209E-07
     +,   9.1294334E-07,   1.0067524E-06,   1.1088047E-06
     +,   1.2196685E-06,   1.3399397E-06,   1.4702335E-06
     +,   1.6111885E-06,   1.7634637E-06,   1.9277386E-06
     +,   2.1047108E-06,   2.2950958E-06,   2.4996211E-06
     +,   2.7190317E-06,   2.9540781E-06,   3.2055186E-06
     +,   3.4741206E-06,   3.7606474E-06,   4.0658570E-06
     +,   4.3905206E-06,   4.7353642E-06,   5.1011357E-06
     +,   5.4885427E-06,   5.8982714E-06,   6.3309813E-06
     +,   6.7872979E-06,   7.2678076E-06,   7.7730483E-06
     +,   8.3035093E-06,   8.8596262E-06,   9.4417692E-06
     +,   1.0050241E-05,   1.0685271E-05,   1.1347004E-05
     +,   1.2035540E-05,   1.2750815E-05,   1.3492748E-05
     +,   1.4261118E-05,   1.5055615E-05,   1.5875819E-05
     +,   1.6721206E-05,   1.7591141E-05,   1.8484881E-05
     +,   1.9401563E-05,   2.0340212E-05,   2.1299753E-05
     +,   2.2278982E-05,   2.3276600E-05,   2.4291177E-05
     +,   2.5321253E-05,   2.6365160E-05,   2.7421238E-05
     +,   2.8487695E-05,   2.9562672E-05,   3.0644242E-05
     +,   3.1730407E-05,   3.2819142E-05,   3.3908385E-05
     +,   3.4995985E-05,   3.6079855E-05,   3.7157904E-05
     +,   3.8227943E-05,   3.9287963E-05,   4.0335824E-05
     +,   4.1369582E-05,   4.2387215E-05,   4.3386899E-05
     +,   4.4366781E-05,   4.5325207E-05,   4.6260528E-05
     +,   4.7171296E-05,   4.8056168E-05,   4.8913913E-05
     +,   4.9743430E-05,   5.0543822E-05,   5.1314353E-05
     +,   5.2054380E-05,   5.2763517E-05,   5.3441479E-05
     +,   5.4088214E-05,   5.4703789E-05,   5.5288525E-05
     +,   5.5842822E-05,   5.6367364E-05,   5.6862908E-05
     +,   5.7330457E-05,   5.7771169E-05,   5.8186310E-05
     +,   5.8577338E-05,   5.8945854E-05,   5.9293627E-05
     +,   5.9622504E-05,   5.9934478E-05,   6.0231650E-05
     +,   6.0516217E-05,   6.0790429E-05,   6.1056657E-05
     +,   6.1317267E-05,   6.1574719E-05,   6.1831430E-05
     +,   6.2089872E-05,   6.2352468E-05,   6.2621599E-05
     +,   6.2899584E-05,   6.3188672E-05,   6.3491010E-05
     +,   6.3808598E-05,   6.4143336E-05,   6.4496890E-05
     +,   6.4870786E-05,   6.5266329E-05,   6.5684624E-05
     +,   6.6126500E-05,   6.6592584E-05,   6.7083209E-05
     +,   6.7598463E-05,   6.8138201E-05,   6.8701971E-05
     +,   6.9289083E-05,   6.9898633E-05,   7.0529495E-05
     +,   7.1180315E-05,   7.1849616E-05,   7.2535717E-05
     +,   7.3236915E-05,   7.3951363E-05,   7.4677249E-05
     +,   7.5412754E-05,   7.6156146E-05,   7.6905744E-05
     +,   7.7660101E-05,   7.8417906E-05,   7.9178069E-05
     +,   7.9939753E-05,   8.0702390E-05,   8.1465761E-05
     +,   8.2229817E-05,   8.2994811E-05,   8.3761326E-05
     +,   8.4530082E-05,   8.5301966E-05,   8.6077991E-05
     +,   8.6859203E-05,   8.7646586E-05,   8.8440887E-05
     +,   8.9242705E-05,   9.0052257E-05,   9.0869209E-05
     +,   9.1692651E-05,   9.2520997E-05,   9.3351933E-05
     +,   9.4182178E-05,   9.5007556E-05,   9.5822979E-05
     +,   9.6622440E-05,   9.7399003E-05,   9.8144868E-05
     +,   9.8851735E-05,   9.9510660E-05,   1.0011251E-04
     +,   1.0064825E-04,   1.0110922E-04,   1.0148755E-04
     +,   1.0177661E-04,   1.0197151E-04,   1.0206960E-04
     +,   1.0207094E-04,   1.0197891E-04,   1.0180063E-04
     +,   1.0154749E-04,   1.0123544E-04,   1.0088553E-04
     +,   1.0052387E-04,   1.0018200E-04,   9.9896810E-05
     +,   9.9710196E-05,   9.9669007E-05,   9.9824494E-05
     +,   1.0023165E-04,   1.0094853E-04,   1.0203552E-04
     +,   1.0355423E-04,   1.0556655E-04,   1.0813382E-04
     +,   1.1131584E-04,   1.1516947E-04,   1.1974851E-04
     +,   1.2510266E-04,   1.3127636E-04,   1.3830868E-04
     +,   1.4623311E-04,   1.5507691E-04,   1.6486003E-04
     +,   1.7559492E-04,   1.8728687E-04,   1.9993258E-04
     +,   2.1351820E-04,   2.2801894E-04,   2.4339852E-04
     +,   2.5960660E-04,   2.7657545E-04,   2.9422084E-04
     +,   3.1243890E-04,   3.3110339E-04,   3.5006489E-04
     +,   3.6915188E-04,   3.8816978E-04,   4.0689990E-04
     +,   4.2510382E-04,   4.4252694E-04,   4.5890216E-04
     +,   4.7395419E-04,   4.8740790E-04,   4.9899571E-04
     +,   5.0846511E-04,   5.1558606E-04,   5.2016095E-04
     +,   5.2203046E-04,   5.2108080E-04,   5.1724922E-04
     +,   5.1052769E-04,   5.0096388E-04,   4.8866268E-04
     +,   4.7378356E-04,   4.5653511E-04,   4.3717073E-04
     +,   4.1598134E-04,   3.9328725E-04,   3.6942618E-04
     +,   3.4474538E-04,   3.1959411E-04,   2.9430987E-04
     +,   2.6921197E-04,   2.4459625E-04,   2.2072697E-04
     +,   1.9783112E-04,   1.7609687E-04,   1.5567374E-04
     +,   1.3667101E-04,   1.1915780E-04,   1.0316737E-04
     +,   8.8701192E-05,   7.5731812E-05,   6.4206644E-05
     +,   5.4053737E-05,   4.5187124E-05,   3.7509333E-05
     +,   3.0916624E-05,   2.5302963E-05,   2.0562526E-05
     +,   1.6592079E-05,   1.3293460E-05,   1.0575197E-05
     +,   8.3531932E-06,   6.5512581E-06,   5.1015154E-06
     +,   3.9443671E-06,   3.0280364E-06,   2.3080493E-06
     +,   1.7467219E-06,   1.3125126E-06,   9.7921748E-07
     +,   7.2534590E-07,   5.3346304E-07,   3.8954738E-07
     +,   2.8242795E-07,   2.0330157E-07,   1.4529921E-07
     +,   1.0310491E-07,   7.2641257E-08,   5.0812400E-08
     +,   3.5289663E-08,   2.4333593E-08,   1.6659255E-08
     +,   1.1323586E-08,   7.6419173E-09,   5.1203375E-09
     +,   3.4063070E-09,   2.2498099E-09,   1.4753541E-09
     +,   9.6055497E-10,   6.2092009E-10,   3.9850176E-10
     +,   2.5392130E-10,   1.6064039E-10,   1.0089821E-10
     +,   6.2921390E-11,   3.8956997E-11,   2.3947398E-11
     +,   1.4615125E-11,   8.8558882E-12,   5.3276060E-12
     +,   3.1821243E-12,   1.8869979E-12,   1.1109911E-12
     +,   6.4940853E-13,   3.7688578E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt117 = Yx/0.00665
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6251543E-06,   1.7556279E-06
     +,   1.8945930E-06,   2.0424254E-06,   2.1995008E-06
     +,   2.3661967E-06,   2.5428901E-06,   2.7299534E-06
     +,   2.9277544E-06,   3.1366628E-06,   3.3570325E-06
     +,   3.5892099E-06,   3.8335315E-06,   4.0903196E-06
     +,   4.3598825E-06,   4.6425098E-06,   4.9384716E-06
     +,   5.2480191E-06,   5.5713767E-06,   5.9087442E-06
     +,   6.2602935E-06,   6.6261669E-06,   7.0064671E-06
     +,   7.4012860E-06,   7.8106414E-06,   8.2345496E-06
     +,   8.6729651E-06,   9.1258080E-06,   9.5929518E-06
     +,   1.0074227E-05,   1.0569416E-05,   1.1078254E-05
     +,   1.1600428E-05,   1.2135571E-05,   1.2683275E-05
     +,   1.3243069E-05,   1.3814439E-05,   1.4396801E-05
     +,   1.4989568E-05,   1.5592024E-05,   1.6203479E-05
     +,   1.6823147E-05,   1.7450204E-05,   1.8083780E-05
     +,   1.8722958E-05,   1.9366771E-05,   2.0014220E-05
     +,   2.0664258E-05,   2.1315798E-05,   2.1967731E-05
     +,   2.2618902E-05,   2.3268136E-05,   2.3914221E-05
     +,   2.4555966E-05,   2.5192094E-05,   2.5821386E-05
     +,   2.6442574E-05,   2.7054406E-05,   2.7655622E-05
     +,   2.8244976E-05,   2.8821240E-05,   2.9383209E-05
     +,   2.9929677E-05,   3.0459503E-05,   3.0971598E-05
     +,   3.1464850E-05,   3.1938282E-05,   3.2390901E-05
     +,   3.2821845E-05,   3.3230255E-05,   3.3615419E-05
     +,   3.3976645E-05,   3.4313391E-05,   3.4625158E-05
     +,   3.4911580E-05,   3.5172401E-05,   3.5407465E-05
     +,   3.5616729E-05,   3.5800291E-05,   3.5958379E-05
     +,   3.6091329E-05,   3.6199643E-05,   3.6283924E-05
     +,   3.6344944E-05,   3.6383604E-05,   3.6400957E-05
     +,   3.6398178E-05,   3.6376601E-05,   3.6337686E-05
     +,   3.6283043E-05,   3.6214395E-05,   3.6133610E-05
     +,   3.6042667E-05,   3.5943664E-05,   3.5838792E-05
     +,   3.5730358E-05,   3.5620749E-05,   3.5512414E-05
     +,   3.5407873E-05,   3.5309702E-05,   3.5220488E-05
     +,   3.5142857E-05,   3.5079418E-05,   3.5032765E-05
     +,   3.5005443E-05,   3.4999954E-05,   3.5018718E-05
     +,   3.5064029E-05,   3.5138077E-05,   3.5242909E-05
     +,   3.5380377E-05,   3.5552162E-05,   3.5759724E-05
     +,   3.6004276E-05,   3.6286776E-05,   3.6607915E-05
     +,   3.6968057E-05,   3.7367292E-05,   3.7805323E-05
     +,   3.8281560E-05,   3.8795060E-05,   3.9344475E-05
     +,   3.9928109E-05,   4.0543920E-05,   4.1189534E-05
     +,   4.1862142E-05,   4.2558706E-05,   4.3275784E-05
     +,   4.4009736E-05,   4.4756587E-05,   4.5512235E-05
     +,   4.6272311E-05,   4.7032441E-05,   4.7788089E-05
     +,   4.8534792E-05,   4.9268168E-05,   4.9983944E-05
     +,   5.0678067E-05,   5.1346848E-05,   5.1986983E-05
     +,   5.2595613E-05,   5.3170443E-05,   5.3709849E-05
     +,   5.4212924E-05,   5.4679491E-05,   5.5110268E-05
     +,   5.5506869E-05,   5.5871784E-05,   5.6208482E-05
     +,   5.6521374E-05,   5.6815832E-05,   5.7098096E-05
     +,   5.7375306E-05,   5.7655379E-05,   5.7947000E-05
     +,   5.8259455E-05,   5.8602585E-05,   5.8986658E-05
     +,   5.9422309E-05,   5.9920301E-05,   6.0491591E-05
     +,   6.1147090E-05,   6.1897590E-05,   6.2753665E-05
     +,   6.3725667E-05,   6.4823558E-05,   6.6056811E-05
     +,   6.7434397E-05,   6.8964735E-05,   7.0655587E-05
     +,   7.2513874E-05,   7.4545649E-05,   7.6756151E-05
     +,   7.9149533E-05,   8.1728576E-05,   8.4494968E-05
     +,   8.7449043E-05,   9.0589529E-05,   9.3913608E-05
     +,   9.7417273E-05,   1.0109537E-04,   1.0494152E-04
     +,   1.0894886E-04,   1.1311105E-04,   1.1742286E-04
     +,   1.2188103E-04,   1.2648600E-04,   1.3124387E-04
     +,   1.3616808E-04,   1.4128095E-04,   1.4661699E-04
     +,   1.5222475E-04,   1.5816846E-04,   1.6453052E-04
     +,   1.7141299E-04,   1.7893857E-04,   1.8724934E-04
     +,   1.9650599E-04,   2.0688571E-04,   2.1857725E-04
     +,   2.3177393E-04,   2.4666605E-04,   2.6343239E-04
     +,   2.8222785E-04,   3.0316933E-04,   3.2632527E-04
     +,   3.5170166E-04,   3.7922678E-04,   4.0874197E-04
     +,   4.3999491E-04,   4.7263334E-04,   5.0620188E-04
     +,   5.4014893E-04,   5.7383807E-04,   6.0656189E-04
     +,   6.3756033E-04,   6.6604832E-04,   6.9124746E-04
     +,   7.1241363E-04,   7.2886870E-04,   7.4003416E-04
     +,   7.4545766E-04,   7.4483425E-04,   7.3802593E-04
     +,   7.2506838E-04,   7.0617202E-04,   6.8171625E-04
     +,   6.5223326E-04,   6.1838329E-04,   5.8092771E-04
     +,   5.4069946E-04,   4.9856701E-04,   4.5539741E-04
     +,   4.1202619E-04,   3.6923369E-04,   3.2771251E-04
     +,   2.8805438E-04,   2.5074105E-04,   2.1613656E-04
     +,   1.8448551E-04,   1.5592220E-04,   1.3048229E-04
     +,   1.0811380E-04,   8.8691173E-05,   7.2033348E-05
     +,   5.7920421E-05,   4.6107016E-05,   3.6335096E-05
     +,   2.8346305E-05,   2.1891510E-05,   1.6736027E-05
     +,   1.2665282E-05,   9.4876768E-06,   7.0353408E-06
     +,   5.1639322E-06,   3.7517684E-06,   2.6980538E-06
     +,   1.9205454E-06,   1.3531590E-06,   9.4365731E-07
     +,   6.5136197E-07,   4.4501556E-07,   3.0092968E-07
     +,   2.0141123E-07,   1.3342600E-07,   8.7484061E-08
     +,   5.6772954E-08,   3.6465718E-08,   2.3182805E-08
     +,   1.4587528E-08,   9.0850847E-09,   5.6004201E-09
     +,   3.4172218E-09,   2.0639266E-09,   1.2339457E-09
     +,   7.3033490E-10,   4.2795559E-10,   2.4831340E-10
     +,   1.4269062E-10,   8.1231112E-11,   4.5829077E-11
     +,   2.5640219E-11,   1.4236938E-11,   7.8554810E-12
     +,   4.3145509E-12,   2.3648355E-12,   1.2979545E-12
     +,   7.1666148E-13,   4.0045102E-13,   2.2802474E-13
     +,   1.3329646E-13,   8.0509811E-14,   5.0448608E-14
     +,   3.2814280E-14,   2.2091869E-14,   1.5310578E-14
     +,   1.0853103E-14,   7.8202325E-15,   5.6981168E-15
     +,   4.1815065E-15,   3.0815243E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt118 = Yx/0.007
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0597443E-05,   1.0821481E-05
     +,   1.1044130E-05,   1.1265186E-05,   1.1484454E-05
     +,   1.1701755E-05,   1.1916917E-05,   1.2129786E-05
     +,   1.2340221E-05,   1.2548111E-05,   1.2753354E-05
     +,   1.2955869E-05,   1.3155606E-05,   1.3352535E-05
     +,   1.3546658E-05,   1.3738002E-05,   1.3926629E-05
     +,   1.4112631E-05,   1.4296133E-05,   1.4477302E-05
     +,   1.4656329E-05,   1.4833462E-05,   1.5008967E-05
     +,   1.5183173E-05,   1.5356425E-05,   1.5529133E-05
     +,   1.5701737E-05,   1.5874717E-05,   1.6048603E-05
     +,   1.6223958E-05,   1.6401387E-05,   1.6581536E-05
     +,   1.6765094E-05,   1.6952774E-05,   1.7145328E-05
     +,   1.7343540E-05,   1.7548226E-05,   1.7760205E-05
     +,   1.7980354E-05,   1.8209517E-05,   1.8448598E-05
     +,   1.8698474E-05,   1.8960036E-05,   1.9234163E-05
     +,   1.9521725E-05,   1.9823578E-05,   2.0140542E-05
     +,   2.0473413E-05,   2.0822945E-05,   2.1189840E-05
     +,   2.1574751E-05,   2.1978258E-05,   2.2400876E-05
     +,   2.2843056E-05,   2.3305118E-05,   2.3787336E-05
     +,   2.4289853E-05,   2.4812713E-05,   2.5355846E-05
     +,   2.5919046E-05,   2.6502001E-05,   2.7104261E-05
     +,   2.7725204E-05,   2.8364115E-05,   2.9020144E-05
     +,   2.9692228E-05,   3.0379246E-05,   3.1079842E-05
     +,   3.1792613E-05,   3.2515924E-05,   3.3248070E-05
     +,   3.3987166E-05,   3.4731260E-05,   3.5478188E-05
     +,   3.6225767E-05,   3.6971709E-05,   3.7713569E-05
     +,   3.8448838E-05,   3.9175004E-05,   3.9889484E-05
     +,   4.0589603E-05,   4.1272750E-05,   4.1936244E-05
     +,   4.2577489E-05,   4.3193842E-05,   4.3782813E-05
     +,   4.4341894E-05,   4.4868761E-05,   4.5361125E-05
     +,   4.5816891E-05,   4.6234127E-05,   4.6611036E-05
     +,   4.6946043E-05,   4.7237805E-05,   4.7485235E-05
     +,   4.7687474E-05,   4.7843965E-05,   4.7954440E-05
     +,   4.8018966E-05,   4.8037935E-05,   4.8012102E-05
     +,   4.7942569E-05,   4.7830828E-05,   4.7678797E-05
     +,   4.7488764E-05,   4.7263435E-05,   4.7005949E-05
     +,   4.6719913E-05,   4.6409303E-05,   4.6078581E-05
     +,   4.5732668E-05,   4.5376881E-05,   4.5017030E-05
     +,   4.4659311E-05,   4.4310411E-05,   4.3977358E-05
     +,   4.3667671E-05,   4.3389184E-05,   4.3150139E-05
     +,   4.2959095E-05,   4.2824937E-05,   4.2756797E-05
     +,   4.2764059E-05,   4.2856263E-05,   4.3043081E-05
     +,   4.3334217E-05,   4.3739376E-05,   4.4268105E-05
     +,   4.4929799E-05,   4.5733465E-05,   4.6687775E-05
     +,   4.7800717E-05,   4.9079717E-05,   5.0531209E-05
     +,   5.2160729E-05,   5.3972708E-05,   5.5970097E-05
     +,   5.8154350E-05,   6.0525388E-05,   6.3081352E-05
     +,   6.5818225E-05,   6.8729867E-05,   7.1808085E-05
     +,   7.5042408E-05,   7.8419602E-05,   8.1924336E-05
     +,   8.5538886E-05,   8.9242894E-05,   9.3013681E-05
     +,   9.6826734E-05,   1.0065556E-04,   1.0447168E-04
     +,   1.0824532E-04,   1.1194585E-04,   1.1554200E-04
     +,   1.1900215E-04,   1.2229498E-04,   1.2539022E-04
     +,   1.2825897E-04,   1.3087406E-04,   1.3321108E-04
     +,   1.3524867E-04,   1.3696893E-04,   1.3835810E-04
     +,   1.3940716E-04,   1.4011192E-04,   1.4047355E-04
     +,   1.4049876E-04,   1.4020002E-04,   1.3959571E-04
     +,   1.3871001E-04,   1.3757296E-04,   1.3622020E-04
     +,   1.3469273E-04,   1.3303680E-04,   1.3130324E-04
     +,   1.2954717E-04,   1.2782768E-04,   1.2620713E-04
     +,   1.2475054E-04,   1.2352511E-04,   1.2259977E-04
     +,   1.2204430E-04,   1.2192869E-04,   1.2232261E-04
     +,   1.2329455E-04,   1.2491085E-04,   1.2723514E-04
     +,   1.3032727E-04,   1.3424191E-04,   1.3902798E-04
     +,   1.4472728E-04,   1.5137266E-04,   1.5898691E-04
     +,   1.6758189E-04,   1.7715683E-04,   1.8769618E-04
     +,   1.9916885E-04,   2.1152785E-04,   2.2470887E-04
     +,   2.3862884E-04,   2.5318612E-04,   2.6826208E-04
     +,   2.8372070E-04,   2.9940810E-04,   3.1515729E-04
     +,   3.3078910E-04,   3.4611332E-04,   3.6093354E-04
     +,   3.7505123E-04,   3.8826859E-04,   4.0039187E-04
     +,   4.1123657E-04,   4.2063210E-04,   4.2842448E-04
     +,   4.3448017E-04,   4.3868931E-04,   4.4096910E-04
     +,   4.4126480E-04,   4.3955163E-04,   4.3583501E-04
     +,   4.3015051E-04,   4.2256311E-04,   4.1316581E-04
     +,   4.0207626E-04,   3.8943463E-04,   3.7540082E-04
     +,   3.6015038E-04,   3.4386956E-04,   3.2675194E-04
     +,   3.0899546E-04,   2.9079791E-04,   2.7235143E-04
     +,   2.5384070E-04,   2.3544137E-04,   2.1731420E-04
     +,   1.9960468E-04,   1.8244260E-04,   1.6593968E-04
     +,   1.5018816E-04,   1.3526170E-04,   1.2121676E-04
     +,   1.0809215E-04,   9.5909374E-05,   8.4674837E-05
     +,   7.4382093E-05,   6.5012609E-05,   5.6536956E-05
     +,   4.8917358E-05,   4.2110023E-05,   3.6065299E-05
     +,   3.0730163E-05,   2.6049860E-05,   2.1968748E-05
     +,   1.8431214E-05,   1.5382977E-05,   1.2772006E-05
     +,   1.0548838E-05,   8.6669479E-06,   7.0832598E-06
     +,   5.7583802E-06,   4.6565387E-06,   3.7455127E-06
     +,   2.9966368E-06,   2.3846833E-06,   1.8875195E-06
     +,   1.4859546E-06,   1.1635102E-06,   9.0611309E-07
     +,   7.0183137E-07,   5.4064429E-07,   4.1420643E-07
     +,   3.1560725E-07,   2.3916246E-07,   1.8023782E-07
     +,   1.3508554E-07,   1.0068607E-07,   7.4633043E-08
     +,   5.5015068E-08,   4.0329759E-08,   2.9400208E-08
     +,   2.1313811E-08,   1.5365472E-08,   1.1015662E-08
     +,   7.8531324E-09,   5.5673572E-09,   3.9248396E-09
     +,   2.7514035E-09,   1.9180211E-09,   1.3295576E-09
     +,   9.1648061E-10,   6.2818872E-10,   4.2817000E-10
     +,   2.9019456E-10,   1.9557744E-10,   1.3106685E-10
     +,   8.7341641E-11,   5.7875139E-11,   3.8134391E-11
     +,   2.4985243E-11,   1.6278123E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt119 = Yx/0.0063
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4698658E-05,   1.4863560E-05
     +,   1.5022013E-05,   1.5173772E-05,   1.5318601E-05
     +,   1.5456275E-05,   1.5586575E-05,   1.5709295E-05
     +,   1.5824236E-05,   1.5931222E-05,   1.6030073E-05
     +,   1.6120634E-05,   1.6202755E-05,   1.6276301E-05
     +,   1.6341155E-05,   1.6397213E-05,   1.6444374E-05
     +,   1.6482569E-05,   1.6511729E-05,   1.6531809E-05
     +,   1.6542777E-05,   1.6544614E-05,   1.6537319E-05
     +,   1.6520900E-05,   1.6495389E-05,   1.6460830E-05
     +,   1.6417274E-05,   1.6364802E-05,   1.6303495E-05
     +,   1.6233460E-05,   1.6154811E-05,   1.6067675E-05
     +,   1.5972206E-05,   1.5868551E-05,   1.5756885E-05
     +,   1.5637394E-05,   1.5510268E-05,   1.5375719E-05
     +,   1.5233963E-05,   1.5085236E-05,   1.4929770E-05
     +,   1.4767821E-05,   1.4599648E-05,   1.4425522E-05
     +,   1.4245724E-05,   1.4060535E-05,   1.3870257E-05
     +,   1.3675194E-05,   1.3475654E-05,   1.3271957E-05
     +,   1.3064430E-05,   1.2853406E-05,   1.2639228E-05
     +,   1.2422229E-05,   1.2202783E-05,   1.1981238E-05
     +,   1.1757962E-05,   1.1533333E-05,   1.1307733E-05
     +,   1.1081554E-05,   1.0855195E-05,   1.0629062E-05
     +,   1.0403583E-05,   1.0179183E-05,   9.9562913E-06
     +,   9.7353777E-06,   9.5168916E-06,   9.3013314E-06
     +,   9.0891754E-06,   8.8809502E-06,   8.6771734E-06
     +,   8.4784033E-06,   8.2851966E-06,   8.0981572E-06
     +,   7.9178872E-06,   7.7450204E-06,   7.5802177E-06
     +,   7.4241725E-06,   7.2775888E-06,   7.1412037E-06
     +,   7.0157912E-06,   6.9021380E-06,   6.8010754E-06
     +,   6.7134488E-06,   6.6401462E-06,   6.5820700E-06
     +,   6.5401637E-06,   6.5153849E-06,   6.5087279E-06
     +,   6.5212048E-06,   6.5538507E-06,   6.6077264E-06
     +,   6.6839020E-06,   6.7834694E-06,   6.9075359E-06
     +,   7.0572078E-06,   7.2336125E-06,   7.4378586E-06
     +,   7.6710767E-06,   7.9343617E-06,   8.2288334E-06
     +,   8.5555503E-06,   8.9155938E-06,   9.3099743E-06
     +,   9.7396978E-06,   1.0205736E-05,   1.0708985E-05
     +,   1.1250278E-05,   1.1830421E-05,   1.2450155E-05
     +,   1.3110077E-05,   1.3810784E-05,   1.4552682E-05
     +,   1.5336162E-05,   1.6161403E-05,   1.7028549E-05
     +,   1.7937506E-05,   1.8888124E-05,   1.9879979E-05
     +,   2.0912559E-05,   2.1985157E-05,   2.3096798E-05
     +,   2.4246281E-05,   2.5432248E-05,   2.6653097E-05
     +,   2.7906855E-05,   2.9191431E-05,   3.0504303E-05
     +,   3.1842817E-05,   3.3203865E-05,   3.4584216E-05
     +,   3.5980149E-05,   3.7387847E-05,   3.8802995E-05
     +,   4.0221152E-05,   4.1637595E-05,   4.3047268E-05
     +,   4.4444881E-05,   4.5825043E-05,   4.7182199E-05
     +,   4.8510581E-05,   4.9804345E-05,   5.1057727E-05
     +,   5.2264968E-05,   5.3420328E-05,   5.4518328E-05
     +,   5.5553763E-05,   5.6521654E-05,   5.7417477E-05
     +,   5.8237252E-05,   5.8977606E-05,   5.9635779E-05
     +,   6.0209823E-05,   6.0698698E-05,   6.1102321E-05
     +,   6.1421641E-05,   6.1658764E-05,   6.1817031E-05
     +,   6.1901061E-05,   6.1916850E-05,   6.1871797E-05
     +,   6.1774808E-05,   6.1636259E-05,   6.1468090E-05
     +,   6.1283768E-05,   6.1098326E-05,   6.0928371E-05
     +,   6.0791990E-05,   6.0708808E-05,   6.0699855E-05
     +,   6.0787570E-05,   6.0995710E-05,   6.1349223E-05
     +,   6.1874212E-05,   6.2597712E-05,   6.3547661E-05
     +,   6.4752683E-05,   6.6241846E-05,   6.8044457E-05
     +,   7.0189919E-05,   7.2707444E-05,   7.5625503E-05
     +,   7.8971541E-05,   8.2771840E-05,   8.7050918E-05
     +,   9.1830705E-05,   9.7130185E-05,   1.0296518E-04
     +,   1.0934747E-04,   1.1628349E-04,   1.2377482E-04
     +,   1.3181710E-04,   1.4039860E-04,   1.4950027E-04
     +,   1.5909568E-04,   1.6915008E-04,   1.7961937E-04
     +,   1.9045039E-04,   2.0158166E-04,   2.1294280E-04
     +,   2.2445410E-04,   2.3602764E-04,   2.4756903E-04
     +,   2.5897735E-04,   2.7014545E-04,   2.8096346E-04
     +,   2.9131916E-04,   3.0109909E-04,   3.1019145E-04
     +,   3.1848799E-04,   3.2588586E-04,   3.3228891E-04
     +,   3.3761017E-04,   3.4177405E-04,   3.4471726E-04
     +,   3.4639024E-04,   3.4675861E-04,   3.4580400E-04
     +,   3.4352415E-04,   3.3993367E-04,   3.3506332E-04
     +,   3.2895966E-04,   3.2168429E-04,   3.1331307E-04
     +,   3.0393351E-04,   2.9364377E-04,   2.8255131E-04
     +,   2.7077060E-04,   2.5841987E-04,   2.4561994E-04
     +,   2.3249281E-04,   2.1915903E-04,   2.0573469E-04
     +,   1.9233070E-04,   1.7905259E-04,   1.6599642E-04
     +,   1.5324932E-04,   1.4088923E-04,   1.2898375E-04
     +,   1.1758893E-04,   1.0675003E-04,   9.6502576E-05
     +,   8.6871718E-05,   7.7872341E-05,   6.9510410E-05
     +,   6.1784296E-05,   5.4684984E-05,   4.8196631E-05
     +,   4.2298077E-05,   3.6964277E-05,   3.2166092E-05
     +,   2.7871840E-05,   2.4048333E-05,   2.0661286E-05
     +,   1.7675824E-05,   1.5057350E-05,   1.2772181E-05
     +,   1.0787743E-05,   9.0728136E-06,   7.5979360E-06
     +,   6.3356761E-06,   5.2606065E-06,   4.3493114E-06
     +,   3.5804994E-06,   2.9350099E-06,   2.3956013E-06
     +,   1.9469501E-06,   1.5755509E-06,   1.2695485E-06
     +,   1.0185955E-06,   8.1374014E-07,   6.4729630E-07
     +,   5.1269205E-07,   4.0433551E-07,   3.1750804E-07
     +,   2.4825661E-07,   1.9327361E-07,   1.4982216E-07
     +,   1.1563865E-07,   8.8870991E-08,   6.8004674E-08
     +,   5.1813860E-08,   3.9307238E-08,   2.9691069E-08
     +,   2.2330424E-08,   1.6722192E-08,   1.2468363E-08
     +,   9.2563726E-09,   6.8421784E-09,   5.0357163E-09
     +,   3.6901937E-09,   2.6924554E-09,   1.9559925E-09
     +,   1.4148014E-09,   1.0189245E-09,   7.3062784E-10
     +,   5.2163579E-10,   3.7080428E-10,   2.6244473E-10
     +,   1.8494224E-10,   1.2976234E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt120 = Yx/0.00452941176470588
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6625952E-05,   3.8217077E-05
     +,   3.9842958E-05,   4.1501717E-05,   4.3191227E-05
     +,   4.4909142E-05,   4.6652898E-05,   4.8419683E-05
     +,   5.0206465E-05,   5.2010088E-05,   5.3827076E-05
     +,   5.5653840E-05,   5.7486606E-05,   5.9321479E-05
     +,   6.1154424E-05,   6.2981358E-05,   6.4798121E-05
     +,   6.6600609E-05,   6.8384725E-05,   7.0146540E-05
     +,   7.1882219E-05,   7.3588242E-05,   7.5261312E-05
     +,   7.6898650E-05,   7.8497760E-05,   8.0056780E-05
     +,   8.1574450E-05,   8.3050138E-05,   8.4484003E-05
     +,   8.5877007E-05,   8.7230910E-05,   8.8548499E-05
     +,   8.9833360E-05,   9.1090144E-05,   9.2324364E-05
     +,   9.3542505E-05,   9.4751929E-05,   9.5960808E-05
     +,   9.7178083E-05,   9.8413271E-05,   9.9676457E-05
     +,   1.0097808E-04,   1.0232871E-04,   1.0373906E-04
     +,   1.0521959E-04,   1.0678051E-04,   1.0843150E-04
     +,   1.1018170E-04,   1.1203935E-04,   1.1401211E-04
     +,   1.1610680E-04,   1.1832958E-04,   1.2068619E-04
     +,   1.2318257E-04,   1.2582488E-04,   1.2862084E-04
     +,   1.3158040E-04,   1.3471692E-04,   1.3804884E-04
     +,   1.4160115E-04,   1.4540754E-04,   1.4951227E-04
     +,   1.5397205E-04,   1.5885879E-04,   1.6426103E-04
     +,   1.7028493E-04,   1.7705625E-04,   1.8471874E-04
     +,   1.9343453E-04,   2.0337995E-04,   2.1474318E-04
     +,   2.2771585E-04,   2.4248809E-04,   2.5923600E-04
     +,   2.7811356E-04,   2.9923944E-04,   3.2268293E-04
     +,   3.4845248E-04,   3.7648628E-04,   4.0664189E-04
     +,   4.3868626E-04,   4.7230077E-04,   5.0707557E-04
     +,   5.4252456E-04,   5.7808979E-04,   6.1316759E-04
     +,   6.4712117E-04,   6.7931379E-04,   7.0912624E-04
     +,   7.3599012E-04,   7.5940782E-04,   7.7897252E-04
     +,   7.9438358E-04,   8.0545794E-04,   8.1212941E-04
     +,   8.1444450E-04,   8.1255357E-04,   8.0669456E-04
     +,   7.9717522E-04,   7.8435388E-04,   7.6862040E-04
     +,   7.5037958E-04,   7.3003641E-04,   7.0799142E-04
     +,   6.8463123E-04,   6.6033035E-04,   6.3545653E-04
     +,   6.1037403E-04,   5.8544846E-04,   5.6105416E-04
     +,   5.3757947E-04,   5.1542348E-04,   4.9499871E-04
     +,   4.7671987E-04,   4.6100008E-04,   4.4823310E-04
     +,   4.3878451E-04,   4.3297315E-04,   4.3105776E-04
     +,   4.3322207E-04,   4.3956441E-04,   4.5008739E-04
     +,   4.6469277E-04,   4.8318141E-04,   5.0525559E-04
     +,   5.3052354E-04,   5.5851531E-04,   5.8869115E-04
     +,   6.2046421E-04,   6.5321219E-04,   6.8630395E-04
     +,   7.1910914E-04,   7.5102324E-04,   7.8147341E-04
     +,   8.0993638E-04,   8.3594373E-04,   8.5908337E-04
     +,   8.7900547E-04,   8.9542178E-04,   9.0810389E-04
     +,   9.1687840E-04,   9.2162797E-04,   9.2229032E-04
     +,   9.1885665E-04,   9.1137213E-04,   8.9993852E-04
     +,   8.8471314E-04,   8.6591108E-04,   8.4380351E-04
     +,   8.1871287E-04,   7.9100759E-04,   7.6109736E-04
     +,   7.2941981E-04,   6.9642765E-04,   6.6257647E-04
     +,   6.2831410E-04,   5.9406535E-04,   5.6021794E-04
     +,   5.2711653E-04,   4.9505767E-04,   4.6427999E-04
     +,   4.3496667E-04,   4.0724778E-04,   3.8120250E-04
     +,   3.5686285E-04,   3.3422213E-04,   3.1324371E-04
     +,   2.9386635E-04,   2.7601077E-04,   2.5958708E-04
     +,   2.4450116E-04,   2.3065794E-04,   2.1796394E-04
     +,   2.0633044E-04,   1.9567601E-04,   1.8592461E-04
     +,   1.7700718E-04,   1.6886125E-04,   1.6142969E-04
     +,   1.5465962E-04,   1.4850176E-04,   1.4291017E-04
     +,   1.3784126E-04,   1.3325246E-04,   1.2910276E-04
     +,   1.2535240E-04,   1.2196264E-04,   1.1889551E-04
     +,   1.1611429E-04,   1.1358389E-04,   1.1127049E-04
     +,   1.0914206E-04,   1.0716871E-04,   1.0532263E-04
     +,   1.0357815E-04,   1.0191189E-04,   1.0030295E-04
     +,   9.8732795E-05,   9.7184995E-05,   9.5645330E-05
     +,   9.4101859E-05,   9.2544535E-05,   9.0965063E-05
     +,   8.9356909E-05,   8.7715198E-05,   8.6036365E-05
     +,   8.4318177E-05,   8.2559593E-05,   8.0760699E-05
     +,   7.8922400E-05,   7.7046367E-05,   7.5135198E-05
     +,   7.3192045E-05,   7.1220515E-05,   6.9224618E-05
     +,   6.7208879E-05,   6.5178065E-05,   6.3137064E-05
     +,   6.1090832E-05,   5.9044611E-05,   5.7003428E-05
     +,   5.4972246E-05,   5.2956038E-05,   5.0959607E-05
     +,   4.8987396E-05,   4.7043624E-05,   4.5132321E-05
     +,   4.3257223E-05,   4.1421601E-05,   3.9628383E-05
     +,   3.7880229E-05,   3.6179481E-05,   3.4527959E-05
     +,   3.2927139E-05,   3.1378306E-05,   2.9882251E-05
     +,   2.8439432E-05,   2.7050117E-05,   2.5714271E-05
     +,   2.4431509E-05,   2.3201221E-05,   2.2022661E-05
     +,   2.0894888E-05,   1.9816733E-05,   1.8786885E-05
     +,   1.7803988E-05,   1.6866599E-05,   1.5973137E-05
     +,   1.5121977E-05,   1.4311550E-05,   1.3540185E-05
     +,   1.2806227E-05,   1.2108072E-05,   1.1444149E-05
     +,   1.0812872E-05,   1.0212706E-05,   9.6422036E-06
     +,   9.0999702E-06,   8.5846332E-06,   8.0948867E-06
     +,   7.6295119E-06,   7.1873578E-06,   6.7672995E-06
     +,   6.3682751E-06,   5.9893209E-06,   5.6294907E-06
     +,   5.2878881E-06,   4.9636969E-06,   4.6561377E-06
     +,   4.3644582E-06,   4.0879499E-06,   3.8259554E-06
     +,   3.5778517E-06,   3.3430310E-06,   3.1209136E-06
     +,   2.9109681E-06,   2.7126598E-06,   2.5254990E-06
     +,   2.3489922E-06,   2.1826866E-06,   2.0261241E-06
     +,   1.8788817E-06,   1.7405301E-06,   1.6106728E-06
     +,   1.4889077E-06,   1.3748606E-06,   1.2681563E-06
     +,   1.1684316E-06,   1.0753436E-06,   9.8854673E-07
     +,   9.0771834E-07,   8.3253417E-07,   7.6269112E-07
     +,   6.9788632E-07,   6.3783642E-07,   5.8225953E-07
     +,   5.3089195E-07,   4.8347385E-07,   4.3976112E-07
     +,   3.9951490E-07,   3.6251168E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt75 = Yx/0.0175
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1881827E-05,   4.4242348E-05
     +,   4.6669542E-05,   4.9160422E-05,   5.1711610E-05
     +,   5.4319335E-05,   5.6979483E-05,   5.9687496E-05
     +,   6.2438463E-05,   6.5227207E-05,   6.8048073E-05
     +,   7.0895119E-05,   7.3762072E-05,   7.6642391E-05
     +,   7.9529207E-05,   8.2415478E-05,   8.5293854E-05
     +,   8.8156870E-05,   9.0996902E-05,   9.3806186E-05
     +,   9.6576958E-05,   9.9301345E-05,   1.0197156E-04
     +,   1.0458002E-04,   1.0711899E-04,   1.0958126E-04
     +,   1.1195969E-04,   1.1424756E-04,   1.1643844E-04
     +,   1.1852647E-04,   1.2050632E-04,   1.2237323E-04
     +,   1.2412309E-04,   1.2575275E-04,   1.2725964E-04
     +,   1.2864234E-04,   1.2990025E-04,   1.3103394E-04
     +,   1.3204518E-04,   1.3293680E-04,   1.3371299E-04
     +,   1.3437925E-04,   1.3494246E-04,   1.3541088E-04
     +,   1.3579418E-04,   1.3610342E-04,   1.3635108E-04
     +,   1.3655101E-04,   1.3671824E-04,   1.3686912E-04
     +,   1.3702092E-04,   1.3719198E-04,   1.3740124E-04
     +,   1.3766828E-04,   1.3801294E-04,   1.3845517E-04
     +,   1.3901478E-04,   1.3971094E-04,   1.4056238E-04
     +,   1.4158657E-04,   1.4279989E-04,   1.4421718E-04
     +,   1.4585156E-04,   1.4771448E-04,   1.4981537E-04
     +,   1.5216153E-04,   1.5475854E-04,   1.5760983E-04
     +,   1.6071729E-04,   1.6408082E-04,   1.6769947E-04
     +,   1.7157051E-04,   1.7569089E-04,   1.8005642E-04
     +,   1.8466292E-04,   1.8950601E-04,   1.9458095E-04
     +,   1.9988297E-04,   2.0540741E-04,   2.1114977E-04
     +,   2.1710413E-04,   2.2326483E-04,   2.2962419E-04
     +,   2.3617358E-04,   2.4290153E-04,   2.4979471E-04
     +,   2.5683574E-04,   2.6400480E-04,   2.7127744E-04
     +,   2.7862599E-04,   2.8601900E-04,   2.9342112E-04
     +,   3.0079379E-04,   3.0809650E-04,   3.1528703E-04
     +,   3.2232146E-04,   3.2915728E-04,   3.3575203E-04
     +,   3.4206692E-04,   3.4806554E-04,   3.5371698E-04
     +,   3.5899528E-04,   3.6388196E-04,   3.6836535E-04
     +,   3.7244288E-04,   3.7612146E-04,   3.7941794E-04
     +,   3.8235998E-04,   3.8498780E-04,   3.8735374E-04
     +,   3.8952261E-04,   3.9157289E-04,   3.9359549E-04
     +,   3.9569355E-04,   3.9798082E-04,   4.0057916E-04
     +,   4.0361594E-04,   4.0721925E-04,   4.1151379E-04
     +,   4.1661458E-04,   4.2262141E-04,   4.2961235E-04
     +,   4.3763797E-04,   4.4671717E-04,   4.5683415E-04
     +,   4.6793564E-04,   4.7993416E-04,   4.9271027E-04
     +,   5.0612201E-04,   5.2001100E-04,   5.3421780E-04
     +,   5.4859207E-04,   5.6300848E-04,   5.7737704E-04
     +,   5.9165666E-04,   6.0586148E-04,   6.2006293E-04
     +,   6.3438830E-04,   6.4901536E-04,   6.6415861E-04
     +,   6.8004965E-04,   6.9691788E-04,   7.1496912E-04
     +,   7.3435949E-04,   7.5517362E-04,   7.7740796E-04
     +,   8.0095761E-04,   8.2560646E-04,   8.5102883E-04
     +,   8.7679963E-04,   9.0240547E-04,   9.2726416E-04
     +,   9.5075031E-04,   9.7222422E-04,   9.9105970E-04
     +,   1.0066709E-03,   1.0185402E-03,   1.0262423E-03
     +,   1.0294608E-03,   1.0280032E-03,   1.0218065E-03
     +,   1.0109416E-03,   9.9560735E-04,   9.7612257E-04
     +,   9.5290941E-04,   9.2647533E-04,   8.9739094E-04
     +,   8.6626806E-04,   8.3372887E-04,   8.0038351E-04
     +,   7.6681020E-04,   7.3353125E-04,   7.0099410E-04
     +,   6.6956331E-04,   6.3951628E-04,   6.1103376E-04
     +,   5.8420910E-04,   5.5905612E-04,   5.3551898E-04
     +,   5.1348464E-04,   4.9280067E-04,   4.7329100E-04
     +,   4.5477078E-04,   4.3705790E-04,   4.1998571E-04
     +,   4.0341224E-04,   3.8722527E-04,   3.7134290E-04
     +,   3.5571554E-04,   3.4032454E-04,   3.2517550E-04
     +,   3.1029372E-04,   2.9572091E-04,   2.8150660E-04
     +,   2.6770265E-04,   2.5435907E-04,   2.4152074E-04
     +,   2.2922418E-04,   2.1749467E-04,   2.0634614E-04
     +,   1.9578279E-04,   1.8579848E-04,   1.7637796E-04
     +,   1.6749906E-04,   1.5913554E-04,   1.5125690E-04
     +,   1.4383126E-04,   1.3682706E-04,   1.3021356E-04
     +,   1.2396141E-04,   1.1804351E-04,   1.1243578E-04
     +,   1.0711655E-04,   1.0206643E-04,   9.7268188E-05
     +,   9.2706803E-05,   8.8368943E-05,   8.4242158E-05
     +,   8.0315069E-05,   7.6577351E-05,   7.3018913E-05
     +,   6.9630012E-05,   6.6401459E-05,   6.3324253E-05
     +,   6.0389440E-05,   5.7588335E-05,   5.4912696E-05
     +,   5.2354553E-05,   4.9906168E-05,   4.7560203E-05
     +,   4.5309916E-05,   4.3149055E-05,   4.1071715E-05
     +,   3.9072551E-05,   3.7146921E-05,   3.5290541E-05
     +,   3.3499637E-05,   3.1771062E-05,   3.0102114E-05
     +,   2.8490436E-05,   2.6934065E-05,   2.5431515E-05
     +,   2.3981591E-05,   2.2583279E-05,   2.1235781E-05
     +,   1.9938578E-05,   1.8691273E-05,   1.7493488E-05
     +,   1.6344893E-05,   1.5245296E-05,   1.4194379E-05
     +,   1.3191795E-05,   1.2237190E-05,   1.1330136E-05
     +,   1.0470042E-05,   9.6562189E-06,   8.8879151E-06
     +,   8.1642675E-06,   7.4842424E-06,   6.8467039E-06
     +,   6.2504487E-06,   5.6941803E-06,   5.1764687E-06
     +,   4.6958176E-06,   4.2507122E-06,   3.8395387E-06
     +,   3.4606501E-06,   3.1124018E-06,   2.7931303E-06
     +,   2.5011523E-06,   2.2347983E-06,   1.9924407E-06
     +,   1.7724797E-06,   1.5733393E-06,   1.3934966E-06
     +,   1.2314990E-06,   1.0859317E-06,   9.5546250E-07
     +,   8.3880974E-07,   7.3477554E-07,   6.4221945E-07
     +,   5.6008355E-07,   4.8736990E-07,   4.2316026E-07
     +,   3.6659540E-07,   3.1689035E-07,   2.7331839E-07
     +,   2.3521451E-07,   2.0197574E-07,   1.7304914E-07
     +,   1.4793794E-07,   1.2619009E-07,   1.0740151E-07
     +,   9.1207596E-08,   7.7284369E-08,   6.5341332E-08
     +,   5.5121898E-08,   4.6397673E-08,   3.8968025E-08
     +,   3.2655517E-08,   2.7305209E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt80 = Yx/0.01825
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9040341E-05,   1.9450938E-05
     +,   1.9869391E-05,   2.0296617E-05,   2.0733665E-05
     +,   2.1181686E-05,   2.1641974E-05,   2.2115959E-05
     +,   2.2605180E-05,   2.3111363E-05,   2.3636316E-05
     +,   2.4182005E-05,   2.4750530E-05,   2.5344098E-05
     +,   2.5965031E-05,   2.6615759E-05,   2.7298791E-05
     +,   2.8016702E-05,   2.8772120E-05,   2.9567682E-05
     +,   3.0406036E-05,   3.1289779E-05,   3.2221444E-05
     +,   3.3203494E-05,   3.4238172E-05,   3.5327623E-05
     +,   3.6473710E-05,   3.7678048E-05,   3.8941937E-05
     +,   4.0266310E-05,   4.1651696E-05,   4.3098182E-05
     +,   4.4605364E-05,   4.6172307E-05,   4.7797512E-05
     +,   4.9478873E-05,   5.1213676E-05,   5.2998508E-05
     +,   5.4829441E-05,   5.6701658E-05,   5.8609890E-05
     +,   6.0548078E-05,   6.2509556E-05,   6.4487074E-05
     +,   6.6472785E-05,   6.8458299E-05,   7.0434820E-05
     +,   7.2393072E-05,   7.4323514E-05,   7.6216347E-05
     +,   7.8061625E-05,   7.9849342E-05,   8.1569546E-05
     +,   8.3212522E-05,   8.4768690E-05,   8.6229033E-05
     +,   8.7584958E-05,   8.8828470E-05,   8.9952395E-05
     +,   9.0950358E-05,   9.1816924E-05,   9.2547736E-05
     +,   9.3139504E-05,   9.3590257E-05,   9.3899194E-05
     +,   9.4066956E-05,   9.4095507E-05,   9.3988288E-05
     +,   9.3750234E-05,   9.3387818E-05,   9.2908987E-05
     +,   9.2323389E-05,   9.1642185E-05,   9.0878282E-05
     +,   9.0046218E-05,   8.9162248E-05,   8.8244436E-05
     +,   8.7312728E-05,   8.6388827E-05,   8.5496358E-05
     +,   8.4660933E-05,   8.3909996E-05,   8.3272935E-05
     +,   8.2780891E-05,   8.2466715E-05,   8.2364706E-05
     +,   8.2510225E-05,   8.2939550E-05,   8.3689207E-05
     +,   8.4795414E-05,   8.6293672E-05,   8.8217603E-05
     +,   9.0598478E-05,   9.3464354E-05,   9.6839460E-05
     +,   1.0074283E-04,   1.0518861E-04,   1.1018464E-04
     +,   1.1573334E-04,   1.2183034E-04,   1.2846646E-04
     +,   1.3562661E-04,   1.4329261E-04,   1.5144247E-04
     +,   1.6005375E-04,   1.6910443E-04,   1.7857409E-04
     +,   1.8844586E-04,   1.9870877E-04,   2.0935819E-04
     +,   2.2039510E-04,   2.3182874E-04,   2.4367282E-04
     +,   2.5594715E-04,   2.6867219E-04,   2.8186940E-04
     +,   2.9555423E-04,   3.0973571E-04,   3.2440855E-04
     +,   3.3955183E-04,   3.5512386E-04,   3.7105702E-04
     +,   3.8725583E-04,   4.0359679E-04,   4.1992575E-04
     +,   4.3605809E-04,   4.5178537E-04,   4.6687521E-04
     +,   4.8108399E-04,   4.9416116E-04,   5.0586561E-04
     +,   5.1597646E-04,   5.2431237E-04,   5.3074805E-04
     +,   5.3523702E-04,   5.3783349E-04,   5.3871510E-04
     +,   5.3820747E-04,   5.3680671E-04,   5.3519674E-04
     +,   5.3426210E-04,   5.3508830E-04,   5.3894793E-04
     +,   5.4726680E-04,   5.6156592E-04,   5.8338081E-04
     +,   6.1415473E-04,   6.5510813E-04,   7.0710218E-04
     +,   7.7050255E-04,   8.4505690E-04,   9.2979922E-04
     +,   1.0230128E-03,   1.1222570E-03,   1.2244487E-03
     +,   1.3260078E-03,   1.4230666E-03,   1.5117258E-03
     +,   1.5882951E-03,   1.6495381E-03,   1.6928923E-03
     +,   1.7166132E-03,   1.7198598E-03,   1.7027194E-03
     +,   1.6661567E-03,   1.6119098E-03,   1.5423602E-03
     +,   1.4603693E-03,   1.3690990E-03,   1.2718475E-03
     +,   1.1718984E-03,   1.0723673E-03,   9.7606942E-04
     +,   8.8542019E-04,   8.0236269E-04,   7.2829670E-04
     +,   6.6406379E-04,   6.0996122E-04,   5.6577491E-04
     +,   5.3084717E-04,   5.0417025E-04,   4.8449269E-04
     +,   4.7042567E-04,   4.6054818E-04,   4.5350182E-04
     +,   4.4806415E-04,   4.4320046E-04,   4.3809289E-04
     +,   4.3214805E-04,   4.2498737E-04,   4.1642177E-04
     +,   4.0641922E-04,   3.9506835E-04,   3.8254168E-04
     +,   3.6906006E-04,   3.5486463E-04,   3.4019598E-04
     +,   3.2527657E-04,   3.1030012E-04,   2.9542772E-04
     +,   2.8078773E-04,   2.6647744E-04,   2.5256554E-04
     +,   2.3909795E-04,   2.2610415E-04,   2.1359848E-04
     +,   2.0158601E-04,   1.9006562E-04,   1.7903189E-04
     +,   1.6847569E-04,   1.5838623E-04,   1.4875224E-04
     +,   1.3956164E-04,   1.3080124E-04,   1.2245758E-04
     +,   1.1451761E-04,   1.0696811E-04,   9.9795529E-05
     +,   9.2986491E-05,   8.6528715E-05,   8.0409605E-05
     +,   7.4617114E-05,   6.9140042E-05,   6.3967622E-05
     +,   5.9089161E-05,   5.4494340E-05,   5.0173410E-05
     +,   4.6116755E-05,   4.2314590E-05,   3.8757204E-05
     +,   3.5435103E-05,   3.2338732E-05,   2.9458264E-05
     +,   2.6783862E-05,   2.4305928E-05,   2.2014596E-05
     +,   1.9900079E-05,   1.7952812E-05,   1.6163343E-05
     +,   1.4522281E-05,   1.3020442E-05,   1.1649011E-05
     +,   1.0399417E-05,   9.2633027E-06,   8.2326469E-06
     +,   7.2998228E-06,   6.4575365E-06,   5.6987760E-06
     +,   5.0168969E-06,   4.4056633E-06,   3.8591243E-06
     +,   3.3716781E-06,   2.9380979E-06,   2.5534785E-06
     +,   2.2132151E-06,   1.9130248E-06,   1.6489499E-06
     +,   1.4173252E-06,   1.2147540E-06,   1.0381152E-06
     +,   8.8456136E-07,   7.5148984E-07,   6.3652402E-07
     +,   5.3750989E-07,   4.5251201E-07,   3.7977887E-07
     +,   3.1774147E-07,   2.6500283E-07,   2.2031931E-07
     +,   1.8258579E-07,   1.5082779E-07,   1.2419068E-07
     +,   1.0192583E-07,   8.3378900E-08,   6.7981951E-08
     +,   5.5245341E-08,   4.4745523E-08,   3.6120579E-08
     +,   2.9060224E-08,   2.3301476E-08,   1.8620712E-08
     +,   1.4829941E-08,   1.1770683E-08,   9.3107815E-09
     +,   7.3397510E-09,   5.7662302E-09,   4.5145088E-09
     +,   3.5223355E-09,   2.7387790E-09,   2.1221682E-09
     +,   1.6387193E-09,   1.2610193E-09,   9.6702135E-10
     +,   7.3899198E-10,   5.6277905E-10,   4.2709281E-10
     +,   3.2299696E-10,   2.4342103E-10,   1.8281376E-10
     +,   1.3681725E-10,   1.0203788E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt85 = Yx/0.01775
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1634020E-06,   9.7567590E-06
     +,   1.0374341E-05,   1.1016091E-05,   1.1681888E-05
     +,   1.2371554E-05,   1.3084856E-05,   1.3821514E-05
     +,   1.4581193E-05,   1.5363559E-05,   1.6168226E-05
     +,   1.6994800E-05,   1.7842889E-05,   1.8712119E-05
     +,   1.9602132E-05,   2.0512616E-05,   2.1443317E-05
     +,   2.2394039E-05,   2.3364675E-05,   2.4355217E-05
     +,   2.5365762E-05,   2.6396532E-05,   2.7447857E-05
     +,   2.8520280E-05,   2.9614372E-05,   3.0730956E-05
     +,   3.1870946E-05,   3.3035412E-05,   3.4225563E-05
     +,   3.5442725E-05,   3.6688332E-05,   3.7963906E-05
     +,   3.9271043E-05,   4.0611358E-05,   4.1986466E-05
     +,   4.3397955E-05,   4.4847329E-05,   4.6335954E-05
     +,   4.7865105E-05,   4.9435686E-05,   5.1048493E-05
     +,   5.2703912E-05,   5.4401979E-05,   5.6142297E-05
     +,   5.7924019E-05,   5.9745777E-05,   6.1605650E-05
     +,   6.3501138E-05,   6.5429114E-05,   6.7385823E-05
     +,   6.9366863E-05,   7.1367169E-05,   7.3381008E-05
     +,   7.5402160E-05,   7.7423538E-05,   7.9437748E-05
     +,   8.1436709E-05,   8.3411949E-05,   8.5354579E-05
     +,   8.7255386E-05,   8.9104913E-05,   9.0893649E-05
     +,   9.2611823E-05,   9.4249961E-05,   9.5798678E-05
     +,   9.7248754E-05,   9.8591561E-05,   9.9818739E-05
     +,   1.0092276E-04,   1.0189660E-04,   1.0273422E-04
     +,   1.0343034E-04,   1.0398075E-04,   1.0438229E-04
     +,   1.0463292E-04,   1.0473179E-04,   1.0467928E-04
     +,   1.0447705E-04,   1.0412803E-04,   1.0363643E-04
     +,   1.0300783E-04,   1.0224900E-04,   1.0136809E-04
     +,   1.0037432E-04,   9.9278273E-05,   9.8091507E-05
     +,   9.6826741E-05,   9.5497606E-05,   9.4118725E-05
     +,   9.2705472E-05,   9.1273891E-05,   8.9840723E-05
     +,   8.8423207E-05,   8.7038832E-05,   8.5705309E-05
     +,   8.4440551E-05,   8.3262195E-05,   8.2187813E-05
     +,   8.1234335E-05,   8.0418249E-05,   7.9755097E-05
     +,   7.9259451E-05,   7.8944628E-05,   7.8822559E-05
     +,   7.8903526E-05,   7.9196092E-05,   7.9706813E-05
     +,   8.0440244E-05,   8.1398895E-05,   8.2583181E-05
     +,   8.3991443E-05,   8.5620319E-05,   8.7464730E-05
     +,   8.9518529E-05,   9.1774651E-05,   9.4226067E-05
     +,   9.6865857E-05,   9.9688739E-05,   1.0269076E-04
     +,   1.0587097E-04,   1.0923162E-04,   1.1277844E-04
     +,   1.1652126E-04,   1.2047419E-04,   1.2465517E-04
     +,   1.2908502E-04,   1.3378714E-04,   1.3878508E-04
     +,   1.4410188E-04,   1.4975657E-04,   1.5576309E-04
     +,   1.6212632E-04,   1.6884111E-04,   1.7588824E-04
     +,   1.8323382E-04,   1.9082752E-04,   1.9860113E-04
     +,   2.0646954E-04,   2.1433266E-04,   2.2207784E-04
     +,   2.2958372E-04,   2.3672670E-04,   2.4338883E-04
     +,   2.4946651E-04,   2.5488020E-04,   2.5958644E-04
     +,   2.6358888E-04,   2.6694886E-04,   2.6979559E-04
     +,   2.7233575E-04,   2.7486132E-04,   2.7775907E-04
     +,   2.8152353E-04,   2.8677681E-04,   2.9429881E-04
     +,   3.0506949E-04,   3.2032316E-04,   3.4160769E-04
     +,   3.7083103E-04,   4.1026762E-04,   4.6250512E-04
     +,   5.3028599E-04,   6.1622105E-04,   7.2238949E-04
     +,   8.4986084E-04,   9.9819701E-04,   1.1650476E-03
     +,   1.3459874E-03,   1.5346926E-03,   1.7234600E-03
     +,   1.9040623E-03,   2.0688174E-03,   2.2116522E-03
     +,   2.3288846E-03,   2.4195681E-03,   2.4853384E-03
     +,   2.5297047E-03,   2.5570223E-03,   2.5713672E-03
     +,   2.5755728E-03,   2.5706484E-03,   2.5556765E-03
     +,   2.5281974E-03,   2.4849277E-03,   2.4226548E-03
     +,   2.3390860E-03,   2.2334931E-03,   2.1070179E-03
     +,   1.9626562E-03,   1.8049409E-03,   1.6393671E-03
     +,   1.4717589E-03,   1.3076572E-03,   1.1517915E-03
     +,   1.0077319E-03,   8.7775750E-04,   7.6290069E-04
     +,   6.6311110E-04,   5.7750993E-04,   5.0468638E-04
     +,   4.4296923E-04,   3.9063962E-04,   3.4608529E-04
     +,   3.0789591E-04,   2.7490151E-04,   2.4616180E-04
     +,   2.2094137E-04,   1.9867127E-04,   1.7890694E-04
     +,   1.6129299E-04,   1.4553910E-04,   1.3140371E-04
     +,   1.1868274E-04,   1.0720363E-04,   9.6822972E-05
     +,   8.7424633E-05,   7.8915626E-05,   7.1221759E-05
     +,   6.4283362E-05,   5.8051141E-05,   5.2480093E-05
     +,   4.7526639E-05,   4.3146301E-05,   3.9291976E-05
     +,   3.5913490E-05,   3.2958687E-05,   3.0374806E-05
     +,   2.8109800E-05,   2.6113818E-05,   2.4340725E-05
     +,   2.2749304E-05,   2.1303689E-05,   1.9973682E-05
     +,   1.8734712E-05,   1.7567652E-05,   1.6458049E-05
     +,   1.5395592E-05,   1.4373483E-05,   1.3387670E-05
     +,   1.2436138E-05,   1.1518393E-05,   1.0635024E-05
     +,   9.7872289E-06,   8.9764326E-06,   8.2041061E-06
     +,   7.4716254E-06,   6.7801006E-06,   6.1302485E-06
     +,   5.5224114E-06,   4.9565979E-06,   4.4323692E-06
     +,   3.9489378E-06,   3.5052244E-06,   3.0998640E-06
     +,   2.7312271E-06,   2.3975001E-06,   2.0967500E-06
     +,   1.8269359E-06,   1.5859395E-06,   1.3716215E-06
     +,   1.1818662E-06,   1.0145902E-06,   8.6775952E-07
     +,   7.3942147E-07,   6.2773069E-07,   5.3093453E-07
     +,   4.4739619E-07,   3.7560366E-07,   3.1416354E-07
     +,   2.6179919E-07,   2.1735245E-07,   1.7978221E-07
     +,   1.4815556E-07,   1.2163972E-07,   9.9498386E-08
     +,   8.1086021E-08,   6.5835330E-08,   5.3255143E-08
     +,   4.2918746E-08,   3.4460538E-08,   2.7566381E-08
     +,   2.1969861E-08,   1.7444460E-08,   1.3799941E-08
     +,   1.0876264E-08,   8.5402805E-09,   6.6811423E-09
     +,   5.2072906E-09,   4.0435513E-09,   3.1282159E-09
     +,   2.4111253E-09,   1.8515074E-09,   1.4165166E-09
     +,   1.0796926E-09,   8.1991464E-10,   6.2032457E-10
     +,   4.6758469E-10,   3.5114214E-10,   2.6272209E-10
     +,   1.9583576E-10,   1.4543787E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt90 = Yx/0.0205172413793103
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6054771E-06,   3.7972543E-06
     +,   3.9951292E-06,   4.1990043E-06,   4.4087556E-06
     +,   4.6242367E-06,   4.8452744E-06,   5.0716694E-06
     +,   5.3031931E-06,   5.5396044E-06,   5.7806174E-06
     +,   6.0259285E-06,   6.2752079E-06,   6.5280969E-06
     +,   6.7842129E-06,   7.0431465E-06,   7.3044653E-06
     +,   7.5677103E-06,   7.8324056E-06,   8.0980499E-06
     +,   8.3641198E-06,   8.6300815E-06,   8.8953739E-06
     +,   9.1594429E-06,   9.4216875E-06,   9.6815293E-06
     +,   9.9383706E-06,   1.0191605E-05,   1.0440628E-05
     +,   1.0684839E-05,   1.0923638E-05,   1.1156439E-05
     +,   1.1382661E-05,   1.1601745E-05,   1.1813151E-05
     +,   1.2016364E-05,   1.2210900E-05,   1.2396308E-05
     +,   1.2572187E-05,   1.2738168E-05,   1.2893950E-05
     +,   1.3039289E-05,   1.3174003E-05,   1.3297994E-05
     +,   1.3411244E-05,   1.3513833E-05,   1.3605941E-05
     +,   1.3687865E-05,   1.3760027E-05,   1.3822985E-05
     +,   1.3877445E-05,   1.3924274E-05,   1.3964517E-05
     +,   1.3999403E-05,   1.4030361E-05,   1.4059035E-05
     +,   1.4087291E-05,   1.4117234E-05,   1.4151226E-05
     +,   1.4191872E-05,   1.4242056E-05,   1.4304927E-05
     +,   1.4383909E-05,   1.4482708E-05,   1.4605304E-05
     +,   1.4755929E-05,   1.4939097E-05,   1.5159525E-05
     +,   1.5422202E-05,   1.5732257E-05,   1.6095039E-05
     +,   1.6515971E-05,   1.7000622E-05,   1.7554548E-05
     +,   1.8183333E-05,   1.8892522E-05,   1.9687481E-05
     +,   2.0573387E-05,   2.1555228E-05,   2.2637692E-05
     +,   2.3824972E-05,   2.5120980E-05,   2.6528969E-05
     +,   2.8051811E-05,   2.9691573E-05,   3.1449905E-05
     +,   3.3327560E-05,   3.5324847E-05,   3.7441107E-05
     +,   3.9675218E-05,   4.2025436E-05,   4.4489261E-05
     +,   4.7063651E-05,   4.9745304E-05,   5.2530610E-05
     +,   5.5415501E-05,   5.8396236E-05,   6.1468854E-05
     +,   6.4630076E-05,   6.7876768E-05,   7.1206865E-05
     +,   7.4618802E-05,   7.8112484E-05,   8.1688580E-05
     +,   8.5349362E-05,   8.9098452E-05,   9.2940521E-05
     +,   9.6881406E-05,   1.0092815E-04,   1.0508842E-04
     +,   1.0936969E-04,   1.1377959E-04,   1.1832414E-04
     +,   1.2300807E-04,   1.2783287E-04,   1.3279705E-04
     +,   1.3789399E-04,   1.4311245E-04,   1.4843448E-04
     +,   1.5383602E-04,   1.5928631E-04,   1.6474737E-04
     +,   1.7017499E-04,   1.7552009E-04,   1.8072950E-04
     +,   1.8574785E-04,   1.9052086E-04,   1.9499740E-04
     +,   1.9913366E-04,   2.0289604E-04,   2.0626598E-04
     +,   2.0924282E-04,   2.1184832E-04,   2.1412957E-04
     +,   2.1616196E-04,   2.1805154E-04,   2.1993549E-04
     +,   2.2198293E-04,   2.2439330E-04,   2.2739373E-04
     +,   2.3123431E-04,   2.3618154E-04,   2.4250950E-04
     +,   2.5048837E-04,   2.6036892E-04,   2.7236665E-04
     +,   2.8664150E-04,   3.0327507E-04,   3.2224937E-04
     +,   3.4342820E-04,   3.6654028E-04,   3.9116980E-04
     +,   4.1676013E-04,   4.4263166E-04,   4.6801244E-04
     +,   4.9208396E-04,   5.1404559E-04,   5.3319015E-04
     +,   5.4897985E-04,   5.6112150E-04,   5.6963379E-04
     +,   5.7488767E-04,   5.7761860E-04,   5.7890132E-04
     +,   5.8008876E-04,   5.8271229E-04,   5.8836257E-04
     +,   5.9856480E-04,   6.1467325E-04,   6.3780637E-04
     +,   6.6883367E-04,   7.0842105E-04,   7.5711182E-04
     +,   8.1540545E-04,   8.8377768E-04,   9.6262881E-04
     +,   1.0520996E-03,   1.1517827E-03,   1.2603931E-03
     +,   1.3754810E-03,   1.4932724E-03,   1.6087324E-03
     +,   1.7159224E-03,   1.8086086E-03,   1.8810234E-03
     +,   1.9286526E-03,   1.9488966E-03,   1.9414311E-03
     +,   1.9081918E-03,   1.8530014E-03,   1.7808978E-03
     +,   1.6973406E-03,   1.6074729E-03,   1.5155653E-03
     +,   1.4247462E-03,   1.3370254E-03,   1.2535393E-03
     +,   1.1748793E-03,   1.1014064E-03,   1.0334665E-03
     +,   9.7146002E-04,   9.1577385E-04,   8.6663652E-04
     +,   8.2397275E-04,   7.8730501E-04,   7.5572490E-04
     +,   7.2796503E-04,   7.0254004E-04,   6.7791645E-04
     +,   6.5268803E-04,   6.2572234E-04,   5.9625594E-04
     +,   5.6393276E-04,   5.2878668E-04,   4.9118599E-04
     +,   4.5175236E-04,   4.1126451E-04,   3.7056219E-04
     +,   3.3046945E-04,   2.9173575E-04,   2.5498678E-04
     +,   2.2070571E-04,   1.8922953E-04,   1.6075288E-04
     +,   1.3534195E-04,   1.1295739E-04,   9.3477822E-05
     +,   7.6720295E-05,   6.2459876E-05,   5.0448925E-05
     +,   4.0432267E-05,   3.2157535E-05,   2.5383331E-05
     +,   1.9885758E-05,   1.5462287E-05,   1.1932346E-05
     +,   9.1382290E-06,   6.9444218E-06,   5.2358223E-06
     +,   3.9158163E-06,   2.9043495E-06,   2.1358078E-06
     +,   1.5568738E-06,   1.1246034E-06,   8.0477605E-07
     +,   5.7038039E-07,   4.0027308E-07,   2.7805652E-07
     +,   1.9115396E-07,   1.3002258E-07,   8.7486960E-08
     +,   5.8219481E-08,   3.8311100E-08,   2.4925976E-08
     +,   1.6031944E-08,   1.0192204E-08,   6.4041124E-09
     +,   3.9767412E-09,   2.4402429E-09,   1.4795868E-09
     +,   8.8640434E-10,   5.2467908E-10,   3.0683273E-10
     +,   1.7726977E-10,   1.0118004E-10,   5.7051211E-11
     +,   3.1778163E-11,   1.7485917E-11,   9.5048873E-12
     +,   5.1037980E-12,   2.7071687E-12,   1.4184797E-12
     +,   7.3422513E-13,   3.7543032E-13,   1.8963855E-13
     +,   9.4637460E-14,   4.6661165E-14,   2.2734952E-14
     +,   1.0948916E-14,   5.2144742E-15,   2.4577993E-15
     +,   1.1482086E-15,   5.3297282E-16,   2.4690076E-16
     +,   1.1499458E-16,   5.4501938E-17,   2.6755137E-17
     +,   1.3908056E-17,   7.8148070E-18,   4.7916571E-18
     +,   3.1848712E-18,   2.2530404E-18,   1.6616973E-18
     +,   1.2565631E-18,   9.6340206E-19,   7.4385199E-19
     +,   5.7620507E-19,   4.4686701E-19,   3.4659793E-19
     +,   2.6870132E-19,   2.0815787E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_htt95 = Yx/0.018
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5423240E-05,   3.6970658E-05
     +,   3.8563463E-05,   4.0201125E-05,   4.1882991E-05
     +,   4.3608263E-05,   4.5376004E-05,   4.7185109E-05
     +,   4.9034330E-05,   5.0922368E-05,   5.2847652E-05
     +,   5.4808581E-05,   5.6803368E-05,   5.8830108E-05
     +,   6.0886825E-05,   6.2971376E-05,   6.5081593E-05
     +,   6.7215173E-05,   6.9369795E-05,   7.1543080E-05
     +,   7.3732605E-05,   7.5935925E-05,   7.8150653E-05
     +,   8.0374499E-05,   8.2605024E-05,   8.4840140E-05
     +,   8.7077715E-05,   8.9315778E-05,   9.1552596E-05
     +,   9.3786592E-05,   9.6016454E-05,   9.8241107E-05
     +,   1.0045983E-04,   1.0267217E-04,   1.0487804E-04
     +,   1.0707777E-04,   1.0927206E-04,   1.1146200E-04
     +,   1.1364932E-04,   1.1583591E-04,   1.1802437E-04
     +,   1.2021774E-04,   1.2241946E-04,   1.2463352E-04
     +,   1.2686434E-04,   1.2911686E-04,   1.3139643E-04
     +,   1.3370880E-04,   1.3606017E-04,   1.3845693E-04
     +,   1.4090598E-04,   1.4341433E-04,   1.4598925E-04
     +,   1.4863820E-04,   1.5136851E-04,   1.5418779E-04
     +,   1.5710344E-04,   1.6012261E-04,   1.6325245E-04
     +,   1.6649980E-04,   1.6987095E-04,   1.7337187E-04
     +,   1.7700784E-04,   1.8078375E-04,   1.8470401E-04
     +,   1.8877156E-04,   1.9298933E-04,   1.9735876E-04
     +,   2.0188108E-04,   2.0655566E-04,   2.1138164E-04
     +,   2.1635676E-04,   2.2147782E-04,   2.2674036E-04
     +,   2.3213898E-04,   2.3766758E-04,   2.4331834E-04
     +,   2.4908243E-04,   2.5495049E-04,   2.6091209E-04
     +,   2.6695547E-04,   2.7306864E-04,   2.7923813E-04
     +,   2.8545063E-04,   2.9169171E-04,   2.9794683E-04
     +,   3.0420098E-04,   3.1043941E-04,   3.1664703E-04
     +,   3.2280941E-04,   3.2891289E-04,   3.3494388E-04
     +,   3.4088991E-04,   3.4674015E-04,   3.5248525E-04
     +,   3.5811702E-04,   3.6362998E-04,   3.6902024E-04
     +,   3.7428670E-04,   3.7943080E-04,   3.8445697E-04
     +,   3.8937165E-04,   3.9418589E-04,   3.9891226E-04
     +,   4.0356687E-04,   4.0816935E-04,   4.1274147E-04
     +,   4.1730743E-04,   4.2189416E-04,   4.2653055E-04
     +,   4.3124685E-04,   4.3607477E-04,   4.4104576E-04
     +,   4.4619237E-04,   4.5154616E-04,   4.5713724E-04
     +,   4.6299424E-04,   4.6914385E-04,   4.7560869E-04
     +,   4.8240880E-04,   4.8956007E-04,   4.9707334E-04
     +,   5.0495495E-04,   5.1320595E-04,   5.2182196E-04
     +,   5.3079211E-04,   5.4010120E-04,   5.4972671E-04
     +,   5.5964175E-04,   5.6981231E-04,   5.8020139E-04
     +,   5.9076486E-04,   6.0145615E-04,   6.1222294E-04
     +,   6.2301190E-04,   6.3376658E-04,   6.4442930E-04
     +,   6.5494183E-04,   6.6524837E-04,   6.7529530E-04
     +,   6.8503345E-04,   6.9441926E-04,   7.0341816E-04
     +,   7.1200600E-04,   7.2017015E-04,   7.2791323E-04
     +,   7.3525583E-04,   7.4223668E-04,   7.4891606E-04
     +,   7.5537781E-04,   7.6173048E-04,   7.6810725E-04
     +,   7.7466626E-04,   7.8159064E-04,   7.8908587E-04
     +,   7.9737743E-04,   8.0670213E-04,   8.1730873E-04
     +,   8.2944578E-04,   8.4335438E-04,   8.5925811E-04
     +,   8.7735819E-04,   8.9782127E-04,   9.2077343E-04
     +,   9.4630400E-04,   9.7446557E-04,   1.0052858E-03
     +,   1.0387870E-03,   1.0750188E-03,   1.1140918E-03
     +,   1.1562164E-03,   1.2017476E-03,   1.2512176E-03
     +,   1.3053552E-03,   1.3650700E-03,   1.4314309E-03
     +,   1.5056030E-03,   1.5887660E-03,   1.6820447E-03
     +,   1.7864729E-03,   1.9030093E-03,   2.0326013E-03
     +,   2.1763332E-03,   2.3355929E-03,   2.5121765E-03
     +,   2.7082481E-03,   2.9261289E-03,   3.1678593E-03
     +,   3.4345984E-03,   3.7259401E-03,   4.0395181E-03
     +,   4.3709432E-03,   4.7143083E-03,   5.0633922E-03
     +,   5.4133465E-03,   5.7624397E-03,   6.1134417E-03
     +,   6.4739408E-03,   6.8553155E-03,   7.2702803E-03
     +,   7.7298852E-03,   8.2411971E-03,   8.8065946E-03
     +,   9.4249099E-03,   1.0093295E-02,   1.0808449E-02
     +,   1.1565990E-02,   1.2358632E-02,   1.3174964E-02
     +,   1.3999146E-02,   1.4810367E-02,   1.5580332E-02
     +,   1.6269598E-02,   1.6827622E-02,   1.7201187E-02
     +,   1.7351134E-02,   1.7268958E-02,   1.6982073E-02
     +,   1.6543003E-02,   1.6009437E-02,   1.5427709E-02
     +,   1.4827719E-02,   1.4227442E-02,   1.3638948E-02
     +,   1.3070087E-02,   1.2523025E-02,   1.1993431E-02
     +,   1.1473567E-02,   1.0958119E-02,   1.0449433E-02
     +,   9.9583194E-03,   9.4998945E-03,   9.0863593E-03
     +,   8.7208245E-03,   8.3947619E-03,   8.0901943E-03
     +,   7.7852570E-03,   7.4605066E-03,   7.1036490E-03
     +,   6.7115901E-03,   6.2897964E-03,   5.8499174E-03
     +,   5.4066190E-03,   4.9745422E-03,   4.5660241E-03
     +,   4.1898028E-03,   3.8505637E-03,   3.5492731E-03
     +,   3.2840469E-03,   3.0511953E-03,   2.8462019E-03
     +,   2.6645130E-03,   2.5020770E-03,   2.3555548E-03
     +,   2.2223406E-03,   2.1004481E-03,   1.9883588E-03
     +,   1.8848408E-03,   1.7888263E-03,   1.6993493E-03
     +,   1.6155250E-03,   1.5365591E-03,   1.4617607E-03
     +,   1.3905722E-03,   1.3225845E-03,   1.2575190E-03
     +,   1.1952143E-03,   1.1356035E-03,   1.0786756E-03
     +,   1.0244398E-03,   9.7290450E-04,   9.2406076E-04
     +,   8.7786745E-04,   8.3424489E-04,   7.9307985E-04
     +,   7.5423595E-04,   7.1755302E-04,   6.8286574E-04
     +,   6.5000303E-04,   6.1880483E-04,   5.8911933E-04
     +,   5.6081411E-04,   5.3377106E-04,   5.0789485E-04
     +,   4.8310307E-04,   4.5933385E-04,   4.3653575E-04
     +,   4.1466966E-04,   3.9370701E-04,   3.7362269E-04
     +,   3.5439871E-04,   3.3601720E-04,   3.1846348E-04
     +,   3.0172066E-04,   2.8577284E-04,   2.7060110E-04
     +,   2.5618632E-04,   2.4250594E-04,   2.2953724E-04
     +,   2.1725411E-04,   2.0563063E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt100 = Yx/0.172931818181818
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.2127893E-05,   4.3185133E-05
     +,   4.4254986E-05,   4.5337256E-05,   4.6431731E-05
     +,   4.7538157E-05,   4.8656264E-05,   4.9785718E-05
     +,   5.0926104E-05,   5.2077070E-05,   5.3238062E-05
     +,   5.4408571E-05,   5.5587963E-05,   5.6775578E-05
     +,   5.7970650E-05,   5.9172398E-05,   6.0379873E-05
     +,   6.1592153E-05,   6.2808154E-05,   6.4026746E-05
     +,   6.5246721E-05,   6.6466775E-05,   6.7685527E-05
     +,   6.8901572E-05,   7.0113310E-05,   7.1319228E-05
     +,   7.2517614E-05,   7.3706746E-05,   7.4884862E-05
     +,   7.6050150E-05,   7.7200704E-05,   7.8334670E-05
     +,   7.9450132E-05,   8.0545164E-05,   8.1617836E-05
     +,   8.2666287E-05,   8.3688647E-05,   8.4683052E-05
     +,   8.5647836E-05,   8.6581225E-05,   8.7481712E-05
     +,   8.8347799E-05,   8.9178146E-05,   8.9971574E-05
     +,   9.0727059E-05,   9.1443784E-05,   9.2121067E-05
     +,   9.2758550E-05,   9.3356022E-05,   9.3913615E-05
     +,   9.4431649E-05,   9.4910778E-05,   9.5351948E-05
     +,   9.5756433E-05,   9.6125819E-05,   9.6462027E-05
     +,   9.6767333E-05,   9.7044358E-05,   9.7296070E-05
     +,   9.7525786E-05,   9.7737182E-05,   9.7934280E-05
     +,   9.8121476E-05,   9.8303404E-05,   9.8485070E-05
     +,   9.8671793E-05,   9.8869124E-05,   9.9082856E-05
     +,   9.9319033E-05,   9.9583849E-05,   9.9883684E-05
     +,   1.0022493E-04,   1.0061421E-04,   1.0105802E-04
     +,   1.0156288E-04,   1.0213523E-04,   1.0278139E-04
     +,   1.0350742E-04,   1.0431922E-04,   1.0522233E-04
     +,   1.0622194E-04,   1.0732286E-04,   1.0852930E-04
     +,   1.0984513E-04,   1.1127343E-04,   1.1281684E-04
     +,   1.1447716E-04,   1.1625564E-04,   1.1815254E-04
     +,   1.2016758E-04,   1.2229962E-04,   1.2454663E-04
     +,   1.2690564E-04,   1.2937315E-04,   1.3194472E-04
     +,   1.3461497E-04,   1.3737798E-04,   1.4022691E-04
     +,   1.4315444E-04,   1.4615231E-04,   1.4921222E-04
     +,   1.5232479E-04,   1.5548083E-04,   1.5867034E-04
     +,   1.6188362E-04,   1.6511064E-04,   1.6834142E-04
     +,   1.7156613E-04,   1.7477536E-04,   1.7796026E-04
     +,   1.8111225E-04,   1.8422380E-04,   1.8728779E-04
     +,   1.9029877E-04,   1.9325172E-04,   1.9614358E-04
     +,   1.9897208E-04,   2.0173677E-04,   2.0443893E-04
     +,   2.0708139E-04,   2.0966899E-04,   2.1220815E-04
     +,   2.1470748E-04,   2.1717767E-04,   2.1963136E-04
     +,   2.2208306E-04,   2.2454960E-04,   2.2704943E-04
     +,   2.2960342E-04,   2.3223351E-04,   2.3496400E-04
     +,   2.3782015E-04,   2.4082910E-04,   2.4401836E-04
     +,   2.4741678E-04,   2.5105345E-04,   2.5495756E-04
     +,   2.5915765E-04,   2.6368193E-04,   2.6855728E-04
     +,   2.7380843E-04,   2.7945751E-04,   2.8552441E-04
     +,   2.9202492E-04,   2.9897038E-04,   3.0636779E-04
     +,   3.1421884E-04,   3.2251902E-04,   3.3125802E-04
     +,   3.4041901E-04,   3.4997924E-04,   3.5990935E-04
     +,   3.7017363E-04,   3.8073212E-04,   3.9154096E-04
     +,   4.0255228E-04,   4.1371680E-04,   4.2498688E-04
     +,   4.3631790E-04,   4.4766886E-04,   4.5900786E-04
     +,   4.7031467E-04,   4.8158065E-04,   4.9281493E-04
     +,   5.0404517E-04,   5.1532168E-04,   5.2671693E-04
     +,   5.3832843E-04,   5.5028102E-04,   5.6272588E-04
     +,   5.7584053E-04,   5.8982742E-04,   6.0491491E-04
     +,   6.2135234E-04,   6.3940755E-04,   6.5936288E-04
     +,   6.8151031E-04,   7.0614228E-04,   7.3354569E-04
     +,   7.6399482E-04,   7.9774129E-04,   8.3500560E-04
     +,   8.7597530E-04,   9.2080730E-04,   9.6963497E-04
     +,   1.0225822E-03,   1.0797897E-03,   1.1414542E-03
     +,   1.2078626E-03,   1.2794216E-03,   1.3567004E-03
     +,   1.4404346E-03,   1.5315209E-03,   1.6309909E-03
     +,   1.7399869E-03,   1.8597353E-03,   1.9915320E-03
     +,   2.1368021E-03,   2.2972035E-03,   2.4747169E-03
     +,   2.6717081E-03,   2.8908676E-03,   3.1349934E-03
     +,   3.4065528E-03,   3.7071742E-03,   4.0373635E-03
     +,   4.3964731E-03,   4.7831647E-03,   5.1960666E-03
     +,   5.6341277E-03,   6.0959230E-03,   6.5779812E-03
     +,   7.0732455E-03,   7.5715147E-03,   8.0636907E-03
     +,   8.5493475E-03,   9.0444414E-03,   9.5837656E-03
     +,   1.0214233E-02,   1.0980119E-02,   1.1906462E-02
     +,   1.2987738E-02,   1.4184788E-02,   1.5427341E-02
     +,   1.6618906E-02,   1.7649157E-02,   1.8423097E-02
     +,   1.8903874E-02,   1.9141832E-02,   1.9256309E-02
     +,   1.9370137E-02,   1.9538511E-02,   1.9724941E-02
     +,   1.9838037E-02,   1.9796338E-02,   1.9571891E-02
     +,   1.9188887E-02,   1.8688353E-02,   1.8093696E-02
     +,   1.7403465E-02,   1.6611969E-02,   1.5732698E-02
     +,   1.4801499E-02,   1.3858745E-02,   1.2930330E-02
     +,   1.2025092E-02,   1.1146465E-02,   1.0304262E-02
     +,   9.5154541E-03,   8.7956097E-03,   8.1497841E-03
     +,   7.5702453E-03,   7.0411484E-03,   6.5459134E-03
     +,   6.0728928E-03,   5.6174132E-03,   5.1806779E-03
     +,   4.7670361E-03,   4.3813284E-03,   4.0270831E-03
     +,   3.7057253E-03,   3.4165897E-03,   3.1574315E-03
     +,   2.9251683E-03,   2.7165262E-03,   2.5284025E-03
     +,   2.3580459E-03,   2.2030289E-03,   2.0611221E-03
     +,   1.9301913E-03,   1.8081906E-03,   1.6932316E-03
     +,   1.5836797E-03,   1.4782564E-03,   1.3761150E-03
     +,   1.2768592E-03,   1.1804663E-03,   1.0872232E-03
     +,   9.9758327E-04,   9.1207906E-04,   8.3120132E-04
     +,   7.5535366E-04,   6.8479287E-04,   6.1963708E-04
     +,   5.5985362E-04,   5.0529954E-04,   4.5573417E-04
     +,   4.1085569E-04,   3.7033181E-04,   3.3381113E-04
     +,   3.0095200E-04,   2.7142340E-04,   2.4492078E-04
     +,   2.2116094E-04,   1.9988995E-04,   1.8087475E-04
     +,   1.6390704E-04,   1.4879537E-04,   1.3536694E-04
     +,   1.2346169E-04,   1.1293376E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt104 = Yx/0.182318181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8492963E-05,   1.9017456E-05
     +,   1.9558740E-05,   2.0117510E-05,   2.0694502E-05
     +,   2.1290509E-05,   2.1906370E-05,   2.2542985E-05
     +,   2.3201306E-05,   2.3882363E-05,   2.4587234E-05
     +,   2.5317075E-05,   2.6073109E-05,   2.6856611E-05
     +,   2.7668941E-05,   2.8511544E-05,   2.9385905E-05
     +,   3.0293602E-05,   3.1236268E-05,   3.2215612E-05
     +,   3.3233373E-05,   3.4291388E-05,   3.5391484E-05
     +,   3.6535628E-05,   3.7725684E-05,   3.8963655E-05
     +,   4.0251503E-05,   4.1591215E-05,   4.2984699E-05
     +,   4.4433924E-05,   4.5940753E-05,   4.7507012E-05
     +,   4.9134433E-05,   5.0824670E-05,   5.2579235E-05
     +,   5.4399530E-05,   5.6286779E-05,   5.8242003E-05
     +,   6.0266160E-05,   6.2359723E-05,   6.4523236E-05
     +,   6.6756809E-05,   6.9060261E-05,   7.1433235E-05
     +,   7.3874951E-05,   7.6384407E-05,   7.8960220E-05
     +,   8.1600665E-05,   8.4303712E-05,   8.7066990E-05
     +,   8.9887697E-05,   9.2762784E-05,   9.5688760E-05
     +,   9.8662036E-05,   1.0167832E-04,   1.0473338E-04
     +,   1.0782253E-04,   1.1094085E-04,   1.1408314E-04
     +,   1.1724405E-04,   1.2041802E-04,   1.2359937E-04
     +,   1.2678216E-04,   1.2996056E-04,   1.3312875E-04
     +,   1.3628045E-04,   1.3941004E-04,   1.4251142E-04
     +,   1.4557893E-04,   1.4860681E-04,   1.5158972E-04
     +,   1.5452228E-04,   1.5739960E-04,   1.6021666E-04
     +,   1.6296914E-04,   1.6565296E-04,   1.6826417E-04
     +,   1.7079921E-04,   1.7325500E-04,   1.7562890E-04
     +,   1.7791838E-04,   1.8012160E-04,   1.8223682E-04
     +,   1.8426299E-04,   1.8619906E-04,   1.8804478E-04
     +,   1.8979983E-04,   1.9146467E-04,   1.9303978E-04
     +,   1.9452606E-04,   1.9592476E-04,   1.9723740E-04
     +,   1.9846560E-04,   1.9961152E-04,   2.0067734E-04
     +,   2.0166555E-04,   2.0257883E-04,   2.0341996E-04
     +,   2.0419195E-04,   2.0489785E-04,   2.0554100E-04
     +,   2.0612472E-04,   2.0665250E-04,   2.0712774E-04
     +,   2.0755416E-04,   2.0793529E-04,   2.0827474E-04
     +,   2.0857620E-04,   2.0884335E-04,   2.0907966E-04
     +,   2.0928879E-04,   2.0947427E-04,   2.0963946E-04
     +,   2.0978769E-04,   2.0992217E-04,   2.1004594E-04
     +,   2.1016195E-04,   2.1027283E-04,   2.1038124E-04
     +,   2.1048939E-04,   2.1059951E-04,   2.1071339E-04
     +,   2.1083269E-04,   2.1095891E-04,   2.1109323E-04
     +,   2.1123656E-04,   2.1138978E-04,   2.1155350E-04
     +,   2.1172817E-04,   2.1191422E-04,   2.1211206E-04
     +,   2.1232202E-04,   2.1254460E-04,   2.1278062E-04
     +,   2.1303086E-04,   2.1329673E-04,   2.1358006E-04
     +,   2.1388312E-04,   2.1420926E-04,   2.1456218E-04
     +,   2.1494685E-04,   2.1536910E-04,   2.1583622E-04
     +,   2.1635661E-04,   2.1693995E-04,   2.1759761E-04
     +,   2.1834252E-04,   2.1918914E-04,   2.2015351E-04
     +,   2.2125352E-04,   2.2250875E-04,   2.2394017E-04
     +,   2.2557029E-04,   2.2742338E-04,   2.2952473E-04
     +,   2.3190070E-04,   2.3457836E-04,   2.3758545E-04
     +,   2.4095016E-04,   2.4469986E-04,   2.4886167E-04
     +,   2.5346200E-04,   2.5852522E-04,   2.6407375E-04
     +,   2.7012810E-04,   2.7670601E-04,   2.8382204E-04
     +,   2.9148723E-04,   2.9970999E-04,   3.0849632E-04
     +,   3.1784869E-04,   3.2776804E-04,   3.3825508E-04
     +,   3.4931119E-04,   3.6093916E-04,   3.7314740E-04
     +,   3.8595113E-04,   3.9937481E-04,   4.1345597E-04
     +,   4.2825073E-04,   4.4383685E-04,   4.6031849E-04
     +,   4.7783295E-04,   4.9655879E-04,   5.1672221E-04
     +,   5.3860468E-04,   5.6255114E-04,   5.8898045E-04
     +,   6.1838911E-04,   6.5135350E-04,   6.8853446E-04
     +,   7.3067029E-04,   7.7856245E-04,   8.3305751E-04
     +,   8.9502538E-04,   9.6532638E-04,   1.0447677E-03
     +,   1.1340696E-03,   1.2338456E-03,   1.3445794E-03
     +,   1.4666280E-03,   1.6002581E-03,   1.7457217E-03
     +,   1.9033436E-03,   2.0735993E-03,   2.2572530E-03
     +,   2.4554105E-03,   2.6695482E-03,   2.9015134E-03
     +,   3.1535272E-03,   3.4281886E-03,   3.7285634E-03
     +,   4.0584500E-03,   4.4227140E-03,   4.8274430E-03
     +,   5.2795629E-03,   5.7854927E-03,   6.3486854E-03
     +,   6.9662952E-03,   7.6260925E-03,   8.3053950E-03
     +,   8.9729074E-03,   9.5940586E-03,   1.0138981E-02
     +,   1.0591276E-02,   1.0955914E-02,   1.1264699E-02
     +,   1.1577736E-02,   1.1977424E-02,   1.2550783E-02
     +,   1.3359335E-02,   1.4405189E-02,   1.5612440E-02
     +,   1.6842108E-02,   1.7943425E-02,   1.8821957E-02
     +,   1.9488512E-02,   2.0055497E-02,   2.0668343E-02
     +,   2.1401100E-02,   2.2184620E-02,   2.2826303E-02
     +,   2.3111627E-02,   2.2909552E-02,   2.2210117E-02
     +,   2.1095851E-02,   1.9698467E-02,   1.8175678E-02
     +,   1.6697085E-02,   1.5412675E-02,   1.4405169E-02
     +,   1.3658660E-02,   1.3071810E-02,   1.2512428E-02
     +,   1.1881202E-02,   1.1147954E-02,   1.0345802E-02
     +,   9.5364675E-03,   8.7734200E-03,   8.0830622E-03
     +,   7.4664922E-03,   6.9120368E-03,   6.4070756E-03
     +,   5.9432387E-03,   5.5156997E-03,   5.1201512E-03
     +,   4.7508553E-03,   4.4006607E-03,   4.0623983E-03
     +,   3.7305381E-03,   3.4023437E-03,   3.0781298E-03
     +,   2.7606990E-03,   2.4543621E-03,   2.1639022E-03
     +,   1.8936952E-03,   1.6470347E-03,   1.4259008E-03
     +,   1.2308657E-03,   1.0613186E-03,   9.1568992E-04
     +,   7.9181202E-04,   6.8717933E-04,   5.9922738E-04
     +,   5.2548485E-04,   4.6370868E-04,   4.1192069E-04
     +,   3.6842725E-04,   3.3180753E-04,   3.0087368E-04
     +,   2.7464554E-04,   2.5230879E-04,   2.3319194E-04
     +,   2.1673481E-04,   2.0247402E-04,   1.9002169E-04
     +,   1.7905667E-04,   1.6931092E-04,   1.6056368E-04
     +,   1.5263211E-04,   1.4536767E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt106 = Yx/0.188522727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5164729E-05,   3.5949241E-05
     +,   3.6739766E-05,   3.7536189E-05,   3.8338389E-05
     +,   3.9146278E-05,   3.9959799E-05,   4.0778872E-05
     +,   4.1603438E-05,   4.2433516E-05,   4.3269069E-05
     +,   4.4110122E-05,   4.4956694E-05,   4.5808836E-05
     +,   4.6666635E-05,   4.7530182E-05,   4.8399579E-05
     +,   4.9274982E-05,   5.0156574E-05,   5.1044532E-05
     +,   5.1939056E-05,   5.2840413E-05,   5.3748860E-05
     +,   5.4664728E-05,   5.5588316E-05,   5.6520010E-05
     +,   5.7460195E-05,   5.8409300E-05,   5.9367798E-05
     +,   6.0336170E-05,   6.1314968E-05,   6.2304753E-05
     +,   6.3306172E-05,   6.4319844E-05,   6.5346496E-05
     +,   6.6386878E-05,   6.7441761E-05,   6.8511974E-05
     +,   6.9598456E-05,   7.0702088E-05,   7.1823873E-05
     +,   7.2964875E-05,   7.4126161E-05,   7.5308897E-05
     +,   7.6514261E-05,   7.7743513E-05,   7.8997931E-05
     +,   8.0278878E-05,   8.1587750E-05,   8.2925981E-05
     +,   8.4295069E-05,   8.5696520E-05,   8.7131877E-05
     +,   8.8602763E-05,   9.0110727E-05,   9.1657406E-05
     +,   9.3244445E-05,   9.4873416E-05,   9.6545955E-05
     +,   9.8263619E-05,   1.0002791E-04,   1.0184040E-04
     +,   1.0370233E-04,   1.0561511E-04,   1.0758002E-04
     +,   1.0959803E-04,   1.1167019E-04,   1.1379718E-04
     +,   1.1597973E-04,   1.1821806E-04,   1.2051256E-04
     +,   1.2286290E-04,   1.2526894E-04,   1.2772984E-04
     +,   1.3024475E-04,   1.3281245E-04,   1.3543112E-04
     +,   1.3809871E-04,   1.4081286E-04,   1.4357085E-04
     +,   1.4636919E-04,   1.4920441E-04,   1.5207226E-04
     +,   1.5496828E-04,   1.5788729E-04,   1.6082410E-04
     +,   1.6377264E-04,   1.6672678E-04,   1.6967973E-04
     +,   1.7262441E-04,   1.7555359E-04,   1.7845936E-04
     +,   1.8133373E-04,   1.8416846E-04,   1.8695513E-04
     +,   1.8968502E-04,   1.9234949E-04,   1.9493968E-04
     +,   1.9744701E-04,   1.9986265E-04,   2.0217820E-04
     +,   2.0438529E-04,   2.0647605E-04,   2.0844275E-04
     +,   2.1027823E-04,   2.1197592E-04,   2.1352974E-04
     +,   2.1493417E-04,   2.1618469E-04,   2.1727744E-04
     +,   2.1820943E-04,   2.1897866E-04,   2.1958417E-04
     +,   2.2002609E-04,   2.2030558E-04,   2.2042511E-04
     +,   2.2038841E-04,   2.2020024E-04,   2.1986701E-04
     +,   2.1939629E-04,   2.1879699E-04,   2.1807950E-04
     +,   2.1725563E-04,   2.1633848E-04,   2.1534256E-04
     +,   2.1428378E-04,   2.1317923E-04,   2.1204767E-04
     +,   2.1090846E-04,   2.0978253E-04,   2.0869177E-04
     +,   2.0765881E-04,   2.0670729E-04,   2.0586136E-04
     +,   2.0514567E-04,   2.0458494E-04,   2.0420423E-04
     +,   2.0402830E-04,   2.0408127E-04,   2.0438693E-04
     +,   2.0496773E-04,   2.0584515E-04,   2.0703892E-04
     +,   2.0856704E-04,   2.1044527E-04,   2.1268726E-04
     +,   2.1530389E-04,   2.1830310E-04,   2.2168983E-04
     +,   2.2546602E-04,   2.2963034E-04,   2.3417802E-04
     +,   2.3910090E-04,   2.4438792E-04,   2.5002484E-04
     +,   2.5599418E-04,   2.6227575E-04,   2.6884733E-04
     +,   2.7568446E-04,   2.8276039E-04,   2.9004773E-04
     +,   2.9751778E-04,   3.0514150E-04,   3.1288937E-04
     +,   3.2073312E-04,   3.2864531E-04,   3.3660021E-04
     +,   3.4457448E-04,   3.5254861E-04,   3.6050813E-04
     +,   3.6844390E-04,   3.7635476E-04,   3.8424993E-04
     +,   3.9215086E-04,   4.0009408E-04,   4.0813562E-04
     +,   4.1635387E-04,   4.2485361E-04,   4.3377018E-04
     +,   4.4327389E-04,   4.5357287E-04,   4.6491603E-04
     +,   4.7759220E-04,   4.9193273E-04,   5.0830678E-04
     +,   5.2711641E-04,   5.4878858E-04,   5.7376811E-04
     +,   6.0250488E-04,   6.3543889E-04,   6.7299133E-04
     +,   7.1555231E-04,   7.6346606E-04,   8.1702729E-04
     +,   8.7647908E-04,   9.4201416E-04,   1.0137761E-03
     +,   1.0918728E-03,   1.1764029E-03,   1.2674694E-03
     +,   1.3651979E-03,   1.4697638E-03,   1.5814112E-03
     +,   1.7004538E-03,   1.8272412E-03,   1.9621472E-03
     +,   2.1055045E-03,   2.2575329E-03,   2.4183041E-03
     +,   2.5877550E-03,   2.7657612E-03,   2.9522718E-03
     +,   3.1475432E-03,   3.3523580E-03,   3.5681247E-03
     +,   3.7967581E-03,   4.0402799E-03,   4.3001454E-03
     +,   4.5763506E-03,   4.8665544E-03,   5.1656147E-03
     +,   5.4657082E-03,   5.7573309E-03,   6.0312422E-03
     +,   6.2811030E-03,   6.5062265E-03,   6.7137117E-03
     +,   6.9193598E-03,   7.1470439E-03,   7.4266093E-03
     +,   7.7905003E-03,   8.2687400E-03,   8.8818101E-03
     +,   9.6323863E-03,   1.0499650E-02,   1.1442184E-02
     +,   1.2411389E-02,   1.3370532E-02,   1.4308890E-02
     +,   1.5242177E-02,   1.6200235E-02,   1.7211024E-02
     +,   1.8289214E-02,   1.9429302E-02,   2.0596519E-02
     +,   2.1714235E-02,   2.2661032E-02,   2.3297271E-02
     +,   2.3524994E-02,   2.3350103E-02,   2.2896834E-02
     +,   2.2351833E-02,   2.1871924E-02,   2.1517204E-02
     +,   2.1241825E-02,   2.0929374E-02,   2.0440474E-02
     +,   1.9659506E-02,   1.8536549E-02,   1.7113023E-02
     +,   1.5513160E-02,   1.3899465E-02,   1.2415215E-02
     +,   1.1144582E-02,   1.0104898E-02,   9.2644338E-03
     +,   8.5692918E-03,   7.9654008E-03,   7.4102446E-03
     +,   6.8762386E-03,   6.3491100E-03,   5.8244467E-03
     +,   5.3040814E-03,   4.7932751E-03,   4.2988439E-03
     +,   3.8278792E-03,   3.3866426E-03,   2.9798909E-03
     +,   2.6102872E-03,   2.2784451E-03,   1.9831923E-03
     +,   1.7222243E-03,   1.4926423E-03,   1.2914761E-03
     +,   1.1158835E-03,   9.6328778E-04,   8.3131070E-04
     +,   7.1774080E-04,   6.2049378E-04,   5.3757493E-04
     +,   4.6711278E-04,   4.0736055E-04,   3.5674061E-04
     +,   3.1384529E-04,   2.7745802E-04,   2.4653639E-04
     +,   2.2020967E-04,   1.9775033E-04,   1.7855955E-04
     +,   1.6213865E-04,   1.4807477E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt108 = Yx/0.198955555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2406133E-05,   3.3065215E-05
     +,   3.3734104E-05,   3.4413522E-05,   3.5104222E-05
     +,   3.5807032E-05,   3.6522822E-05,   3.7252506E-05
     +,   3.7997044E-05,   3.8757469E-05,   3.9534811E-05
     +,   4.0330171E-05,   4.1144631E-05,   4.1979347E-05
     +,   4.2835472E-05,   4.3714143E-05,   4.4616540E-05
     +,   4.5543806E-05,   4.6497069E-05,   4.7477439E-05
     +,   4.8485970E-05,   4.9523685E-05,   5.0591541E-05
     +,   5.1690433E-05,   5.2821131E-05,   5.3984382E-05
     +,   5.5180761E-05,   5.6410739E-05,   5.7674712E-05
     +,   5.8972841E-05,   6.0305232E-05,   6.1671744E-05
     +,   6.3072155E-05,   6.4505999E-05,   6.5972636E-05
     +,   6.7471257E-05,   6.9000838E-05,   7.0560163E-05
     +,   7.2147886E-05,   7.3762298E-05,   7.5401666E-05
     +,   7.7063938E-05,   7.8746918E-05,   8.0448255E-05
     +,   8.2165359E-05,   8.3895480E-05,   8.5635809E-05
     +,   8.7383240E-05,   8.9134650E-05,   9.0886781E-05
     +,   9.2636255E-05,   9.4379640E-05,   9.6113421E-05
     +,   9.7834112E-05,   9.9538083E-05,   1.0122186E-04
     +,   1.0288193E-04,   1.0451481E-04,   1.0611708E-04
     +,   1.0768548E-04,   1.0921676E-04,   1.1070794E-04
     +,   1.1215601E-04,   1.1355826E-04,   1.1491223E-04
     +,   1.1621543E-04,   1.1746581E-04,   1.1866136E-04
     +,   1.1980047E-04,   1.2088162E-04,   1.2190367E-04
     +,   1.2286556E-04,   1.2376663E-04,   1.2460645E-04
     +,   1.2538474E-04,   1.2610163E-04,   1.2675727E-04
     +,   1.2735224E-04,   1.2788716E-04,   1.2836306E-04
     +,   1.2878106E-04,   1.2914250E-04,   1.2944889E-04
     +,   1.2970192E-04,   1.2990346E-04,   1.3005553E-04
     +,   1.3016023E-04,   1.3022000E-04,   1.3023711E-04
     +,   1.3021416E-04,   1.3015381E-04,   1.3005886E-04
     +,   1.2993214E-04,   1.2977670E-04,   1.2959560E-04
     +,   1.2939202E-04,   1.2916932E-04,   1.2893083E-04
     +,   1.2868016E-04,   1.2842097E-04,   1.2815703E-04
     +,   1.2789224E-04,   1.2763060E-04,   1.2737633E-04
     +,   1.2713386E-04,   1.2690744E-04,   1.2670187E-04
     +,   1.2652185E-04,   1.2637231E-04,   1.2625830E-04
     +,   1.2618497E-04,   1.2615779E-04,   1.2618204E-04
     +,   1.2626336E-04,   1.2640738E-04,   1.2661984E-04
     +,   1.2690641E-04,   1.2727296E-04,   1.2772514E-04
     +,   1.2826876E-04,   1.2890947E-04,   1.2965269E-04
     +,   1.3050387E-04,   1.3146813E-04,   1.3255046E-04
     +,   1.3375534E-04,   1.3508718E-04,   1.3654974E-04
     +,   1.3814653E-04,   1.3988042E-04,   1.4175380E-04
     +,   1.4376838E-04,   1.4592533E-04,   1.4822494E-04
     +,   1.5066682E-04,   1.5325000E-04,   1.5597227E-04
     +,   1.5883062E-04,   1.6182131E-04,   1.6493960E-04
     +,   1.6817961E-04,   1.7153451E-04,   1.7499650E-04
     +,   1.7855695E-04,   1.8220577E-04,   1.8593225E-04
     +,   1.8972480E-04,   1.9357043E-04,   1.9745567E-04
     +,   2.0136610E-04,   2.0528669E-04,   2.0920159E-04
     +,   2.1309435E-04,   2.1694841E-04,   2.2074673E-04
     +,   2.2447214E-04,   2.2810722E-04,   2.3163522E-04
     +,   2.3503983E-04,   2.3830468E-04,   2.4141495E-04
     +,   2.4435658E-04,   2.4711696E-04,   2.4968464E-04
     +,   2.5205067E-04,   2.5420796E-04,   2.5615207E-04
     +,   2.5788098E-04,   2.5939633E-04,   2.6070318E-04
     +,   2.6181046E-04,   2.6273166E-04,   2.6348504E-04
     +,   2.6409433E-04,   2.6458930E-04,   2.6500577E-04
     +,   2.6538695E-04,   2.6578392E-04,   2.6625555E-04
     +,   2.6687005E-04,   2.6770483E-04,   2.6884759E-04
     +,   2.7039662E-04,   2.7246083E-04,   2.7516144E-04
     +,   2.7863032E-04,   2.8301147E-04,   2.8846067E-04
     +,   2.9514529E-04,   3.0324340E-04,   3.1294397E-04
     +,   3.2444572E-04,   3.3795499E-04,   3.5368485E-04
     +,   3.7185481E-04,   3.9268692E-04,   4.1640442E-04
     +,   4.4322913E-04,   4.7338431E-04,   5.0709362E-04
     +,   5.4458255E-04,   5.8608683E-04,   6.3186680E-04
     +,   6.8221969E-04,   7.3749479E-04,   7.9812558E-04
     +,   8.6464715E-04,   9.3770976E-04,   1.0180916E-03
     +,   1.1067025E-03,   1.2045569E-03,   1.3127349E-03
     +,   1.4323380E-03,   1.5644465E-03,   1.7100743E-03
     +,   1.8701329E-03,   2.0454512E-03,   2.2368126E-03
     +,   2.4449960E-03,   2.6707868E-03,   2.9150369E-03
     +,   3.1786151E-03,   3.4623072E-03,   3.7666901E-03
     +,   4.0918724E-03,   4.4370182E-03,   4.7996393E-03
     +,   5.1748916E-03,   5.5552614E-03,   5.9312927E-03
     +,   6.2938049E-03,   6.6374703E-03,   6.9642398E-03
     +,   7.2849174E-03,   7.6179616E-03,   7.9865921E-03
     +,   8.4166592E-03,   8.9364219E-03,   9.5762480E-03
     +,   1.0363664E-02,   1.1311626E-02,   1.2404602E-02
     +,   1.3593568E-02,   1.4809475E-02,   1.5994301E-02
     +,   1.7133482E-02,   1.8265113E-02,   1.9453302E-02
     +,   2.0741861E-02,   2.2120759E-02,   2.3519449E-02
     +,   2.4813952E-02,   2.5843777E-02,   2.6458129E-02
     +,   2.6586538E-02,   2.6278378E-02,   2.5667092E-02
     +,   2.4889726E-02,   2.4031684E-02,   2.3121685E-02
     +,   2.2151364E-02,   2.1094183E-02,   1.9925619E-02
     +,   1.8647499E-02,   1.7302144E-02,   1.5959380E-02
     +,   1.4683582E-02,   1.3505249E-02,   1.2414833E-02
     +,   1.1379065E-02,   1.0365375E-02,   9.3598971E-03
     +,   8.3711771E-03,   7.4222051E-03,   6.5381676E-03
     +,   5.7373843E-03,   5.0275926E-03,   4.4071693E-03
     +,   3.8680830E-03,   3.3993802E-03,   2.9896235E-03
     +,   2.6286677E-03,   2.3082730E-03,   2.0222845E-03
     +,   1.7662641E-03,   1.5371216E-03,   1.3326505E-03
     +,   1.1512013E-03,   9.9142489E-04,   8.5202319E-04
     +,   7.3165278E-04,   6.2880397E-04,   5.4182106E-04
     +,   4.6891018E-04,   4.0823041E-04,   3.5795712E-04
     +,   3.1637592E-04,   2.8192910E-04,   2.5326302E-04
     +,   2.2923376E-04,   2.0890888E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt110 = Yx/0.199577777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8281360E-05,   1.8747302E-05
     +,   1.9220666E-05,   1.9701369E-05,   2.0189325E-05
     +,   2.0684431E-05,   2.1186590E-05,   2.1695685E-05
     +,   2.2211587E-05,   2.2734195E-05,   2.3263365E-05
     +,   2.3798977E-05,   2.4340885E-05,   2.4888966E-05
     +,   2.5443076E-05,   2.6003103E-05,   2.6568914E-05
     +,   2.7140390E-05,   2.7717429E-05,   2.8299935E-05
     +,   2.8887831E-05,   2.9481043E-05,   3.0079538E-05
     +,   3.0683299E-05,   3.1292300E-05,   3.1906620E-05
     +,   3.2526288E-05,   3.3151417E-05,   3.3782148E-05
     +,   3.4418648E-05,   3.5061148E-05,   3.5709905E-05
     +,   3.6365251E-05,   3.7027537E-05,   3.7697206E-05
     +,   3.8374728E-05,   3.9060651E-05,   3.9755560E-05
     +,   4.0460138E-05,   4.1175077E-05,   4.1901189E-05
     +,   4.2639309E-05,   4.3390359E-05,   4.4155280E-05
     +,   4.4935110E-05,   4.5730943E-05,   4.6543886E-05
     +,   4.7375150E-05,   4.8225931E-05,   4.9097514E-05
     +,   4.9991169E-05,   5.0908231E-05,   5.1850024E-05
     +,   5.2817933E-05,   5.3813234E-05,   5.4837328E-05
     +,   5.5891516E-05,   5.6977085E-05,   5.8095276E-05
     +,   5.9247319E-05,   6.0434322E-05,   6.1657403E-05
     +,   6.2917432E-05,   6.4215397E-05,   6.5552071E-05
     +,   6.6928071E-05,   6.8343994E-05,   6.9800160E-05
     +,   7.1296905E-05,   7.2834227E-05,   7.4412157E-05
     +,   7.6030381E-05,   7.7688586E-05,   7.9386053E-05
     +,   8.1122103E-05,   8.2895815E-05,   8.4706044E-05
     +,   8.6551343E-05,   8.8430344E-05,   9.0341404E-05
     +,   9.2282586E-05,   9.4251991E-05,   9.6247342E-05
     +,   9.8266501E-05,   1.0030683E-04,   1.0236597E-04
     +,   1.0444105E-04,   1.0652951E-04,   1.0862835E-04
     +,   1.1073465E-04,   1.1284563E-04,   1.1495822E-04
     +,   1.1706930E-04,   1.1917599E-04,   1.2127540E-04
     +,   1.2336447E-04,   1.2544052E-04,   1.2750064E-04
     +,   1.2954239E-04,   1.3156299E-04,   1.3356032E-04
     +,   1.3553207E-04,   1.3747641E-04,   1.3939143E-04
     +,   1.4127568E-04,   1.4312803E-04,   1.4494744E-04
     +,   1.4673317E-04,   1.4848505E-04,   1.5020309E-04
     +,   1.5188768E-04,   1.5353972E-04,   1.5516026E-04
     +,   1.5675109E-04,   1.5831420E-04,   1.5985218E-04
     +,   1.6136798E-04,   1.6286504E-04,   1.6434721E-04
     +,   1.6581900E-04,   1.6728519E-04,   1.6875110E-04
     +,   1.7022229E-04,   1.7170505E-04,   1.7320586E-04
     +,   1.7473144E-04,   1.7628913E-04,   1.7788631E-04
     +,   1.7953057E-04,   1.8122977E-04,   1.8299188E-04
     +,   1.8482463E-04,   1.8673620E-04,   1.8873415E-04
     +,   1.9082615E-04,   1.9301951E-04,   1.9532122E-04
     +,   1.9773762E-04,   2.0027476E-04,   2.0293820E-04
     +,   2.0573237E-04,   2.0866118E-04,   2.1172767E-04
     +,   2.1493420E-04,   2.1828183E-04,   2.2177078E-04
     +,   2.2540046E-04,   2.2916887E-04,   2.3307295E-04
     +,   2.3710875E-04,   2.4127154E-04,   2.4555507E-04
     +,   2.4995222E-04,   2.5445523E-04,   2.5905561E-04
     +,   2.6374374E-04,   2.6850970E-04,   2.7334303E-04
     +,   2.7823332E-04,   2.8316953E-04,   2.8814113E-04
     +,   2.9313815E-04,   2.9815061E-04,   3.0316954E-04
     +,   3.0818739E-04,   3.1319793E-04,   3.1819637E-04
     +,   3.2317959E-04,   3.2814738E-04,   3.3310198E-04
     +,   3.3804777E-04,   3.4299243E-04,   3.4794709E-04
     +,   3.5292623E-04,   3.5794722E-04,   3.6303172E-04
     +,   3.6820487E-04,   3.7349519E-04,   3.7893493E-04
     +,   3.8455977E-04,   3.9040932E-04,   3.9652572E-04
     +,   4.0295444E-04,   4.0974421E-04,   4.1694663E-04
     +,   4.2461522E-04,   4.3280661E-04,   4.4158011E-04
     +,   4.5099773E-04,   4.6112353E-04,   4.7202522E-04
     +,   4.8377505E-04,   4.9644907E-04,   5.1013031E-04
     +,   5.2491116E-04,   5.4089597E-04,   5.5820402E-04
     +,   5.7697494E-04,   5.9737562E-04,   6.1960478E-04
     +,   6.4389739E-04,   6.7053211E-04,   6.9983507E-04
     +,   7.3218113E-04,   7.6798530E-04,   8.0770371E-04
     +,   8.5181370E-04,   9.0079324E-04,   9.5509499E-04
     +,   1.0151211E-03,   1.0811887E-03,   1.1534975E-03
     +,   1.2321139E-03,   1.3169701E-03,   1.4078749E-03
     +,   1.5045444E-03,   1.6066716E-03,   1.7140087E-03
     +,   1.8264625E-03,   1.9441725E-03,   2.0676055E-03
     +,   2.1975602E-03,   2.3351230E-03,   2.4815428E-03
     +,   2.6380322E-03,   2.8055187E-03,   2.9844022E-03
     +,   3.1744714E-03,   3.3750003E-03,   3.5850662E-03
     +,   3.8040895E-03,   4.0324684E-03,   4.2722151E-03
     +,   4.5273411E-03,   4.8039802E-03,   5.1103048E-03
     +,   5.4561291E-03,   5.8521763E-03,   6.3087526E-03
     +,   6.8333177E-03,   7.4266749E-03,   8.0790464E-03
     +,   8.7692458E-03,   9.4706723E-03,   1.0164402E-02
     +,   1.0853019E-02,   1.1564219E-02,   1.2337759E-02
     +,   1.3203540E-02,   1.4169953E-02,   1.5233465E-02
     +,   1.6396085E-02,   1.7662328E-02,   1.9007390E-02
     +,   2.0346586E-02,   2.1546517E-02,   2.2486616E-02
     +,   2.3142505E-02,   2.3652092E-02,   2.4308689E-02
     +,   2.5416825E-02,   2.7041623E-02,   2.8855499E-02
     +,   3.0284140E-02,   3.0870436E-02,   3.0536449E-02
     +,   2.9537911E-02,   2.8202889E-02,   2.6698319E-02
     +,   2.4990968E-02,   2.2983532E-02,   2.0666759E-02
     +,   1.8157648E-02,   1.5632596E-02,   1.3249106E-02
     +,   1.1113464E-02,   9.2828777E-03,   7.7735507E-03
     +,   6.5639769E-03,   5.6037274E-03,   4.8299897E-03
     +,   4.1857958E-03,   3.6300742E-03,   3.1385985E-03
     +,   2.6992271E-03,   2.3066804E-03,   1.9586615E-03
     +,   1.6537961E-03,   1.3905704E-03,   1.1667553E-03
     +,   9.7931339E-04,   8.2443870E-04,   6.9788075E-04
     +,   5.9523940E-04,   5.1231269E-04,   4.4529987E-04
     +,   3.9095143E-04,   3.4658343E-04,   3.1005699E-04
     +,   2.7969171E-04,   2.5418887E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt112 = Yx/0.209066666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.3066707E-06,   8.7973831E-06
     +,   9.3089757E-06,   9.8417104E-06,   1.0395805E-05
     +,   1.0971429E-05,   1.1568709E-05,   1.2187719E-05
     +,   1.2828474E-05,   1.3490959E-05,   1.4175082E-05
     +,   1.4880704E-05,   1.5607626E-05,   1.6355592E-05
     +,   1.7124299E-05,   1.7913379E-05,   1.8722414E-05
     +,   1.9550927E-05,   2.0398398E-05,   2.1264248E-05
     +,   2.2147862E-05,   2.3048577E-05,   2.3965671E-05
     +,   2.4898458E-05,   2.5846097E-05,   2.6807840E-05
     +,   2.7782859E-05,   2.8770308E-05,   2.9769350E-05
     +,   3.0779131E-05,   3.1798791E-05,   3.2827502E-05
     +,   3.3864417E-05,   3.4908724E-05,   3.5959645E-05
     +,   3.7016409E-05,   3.8078288E-05,   3.9144597E-05
     +,   4.0214734E-05,   4.1288058E-05,   4.2364092E-05
     +,   4.3442335E-05,   4.4522385E-05,   4.5603898E-05
     +,   4.6686586E-05,   4.7770249E-05,   4.8854745E-05
     +,   4.9939998E-05,   5.1026018E-05,   5.2112857E-05
     +,   5.3200652E-05,   5.4289601E-05,   5.5379940E-05
     +,   5.6472029E-05,   5.7566165E-05,   5.8662801E-05
     +,   5.9762377E-05,   6.0865365E-05,   6.1972285E-05
     +,   6.3083658E-05,   6.4200038E-05,   6.5321969E-05
     +,   6.6449924E-05,   6.7584537E-05,   6.8726309E-05
     +,   6.9875648E-05,   7.1033086E-05,   7.2198949E-05
     +,   7.3373682E-05,   7.4557465E-05,   7.5750628E-05
     +,   7.6953227E-05,   7.8165431E-05,   7.9387130E-05
     +,   8.0618258E-05,   8.1858678E-05,   8.3108032E-05
     +,   8.4365878E-05,   8.5631771E-05,   8.6905151E-05
     +,   8.8185174E-05,   8.9471148E-05,   9.0762049E-05
     +,   9.2056936E-05,   9.3354596E-05,   9.4653878E-05
     +,   9.5953379E-05,   9.7251832E-05,   9.8547629E-05
     +,   9.9839242E-05,   1.0112514E-04,   1.0240360E-04
     +,   1.0367281E-04,   1.0493112E-04,   1.0617675E-04
     +,   1.0740779E-04,   1.0862255E-04,   1.0981914E-04
     +,   1.1099585E-04,   1.1215088E-04,   1.1328253E-04
     +,   1.1438911E-04,   1.1546913E-04,   1.1652094E-04
     +,   1.1754317E-04,   1.1853457E-04,   1.1949382E-04
     +,   1.2041985E-04,   1.2131169E-04,   1.2216860E-04
     +,   1.2298973E-04,   1.2377468E-04,   1.2452297E-04
     +,   1.2523450E-04,   1.2590906E-04,   1.2654685E-04
     +,   1.2714807E-04,   1.2771323E-04,   1.2824274E-04
     +,   1.2873751E-04,   1.2919832E-04,   1.2962626E-04
     +,   1.3002241E-04,   1.3038809E-04,   1.3072467E-04
     +,   1.3103367E-04,   1.3131667E-04,   1.3157532E-04
     +,   1.3181135E-04,   1.3202662E-04,   1.3222292E-04
     +,   1.3240216E-04,   1.3256622E-04,   1.3271703E-04
     +,   1.3285656E-04,   1.3298674E-04,   1.3310954E-04
     +,   1.3322690E-04,   1.3334081E-04,   1.3345332E-04
     +,   1.3356638E-04,   1.3368212E-04,   1.3380266E-04
     +,   1.3393020E-04,   1.3406704E-04,   1.3421565E-04
     +,   1.3437861E-04,   1.3455877E-04,   1.3475907E-04
     +,   1.3498287E-04,   1.3523376E-04,   1.3551555E-04
     +,   1.3583257E-04,   1.3618948E-04,   1.3659138E-04
     +,   1.3704372E-04,   1.3755252E-04,   1.3812413E-04
     +,   1.3876548E-04,   1.3948383E-04,   1.4028697E-04
     +,   1.4118303E-04,   1.4218051E-04,   1.4328813E-04
     +,   1.4451504E-04,   1.4587049E-04,   1.4736404E-04
     +,   1.4900509E-04,   1.5080340E-04,   1.5276871E-04
     +,   1.5491089E-04,   1.5723973E-04,   1.5976552E-04
     +,   1.6249879E-04,   1.6545044E-04,   1.6863244E-04
     +,   1.7205781E-04,   1.7574101E-04,   1.7969840E-04
     +,   1.8394936E-04,   1.8851654E-04,   1.9342650E-04
     +,   1.9871067E-04,   2.0440712E-04,   2.1056083E-04
     +,   2.1722486E-04,   2.2446187E-04,   2.3234583E-04
     +,   2.4096298E-04,   2.5041224E-04,   2.6080769E-04
     +,   2.7227896E-04,   2.8497021E-04,   2.9904078E-04
     +,   3.1466465E-04,   3.3202802E-04,   3.5132468E-04
     +,   3.7275301E-04,   3.9651271E-04,   4.2279850E-04
     +,   4.5179325E-04,   4.8366611E-04,   5.1857135E-04
     +,   5.5665028E-04,   5.9802999E-04,   6.4284168E-04
     +,   6.9122802E-04,   7.4335927E-04,   7.9945067E-04
     +,   8.5978123E-04,   9.2470186E-04,   9.9463155E-04
     +,   1.0700471E-03,   1.1514673E-03,   1.2394066E-03
     +,   1.3343261E-03,   1.4365867E-03,   1.5464143E-03
     +,   1.6638691E-03,   1.7888257E-03,   1.9210147E-03
     +,   2.0600467E-03,   2.2054417E-03,   2.3566608E-03
     +,   2.5131197E-03,   2.6741517E-03,   2.8389620E-03
     +,   3.0066434E-03,   3.1762833E-03,   3.3471894E-03
     +,   3.5192519E-03,   3.6934135E-03,   3.8721329E-03
     +,   4.0596221E-03,   4.2617815E-03,   4.4857450E-03
     +,   4.7389548E-03,   5.0278609E-03,   5.3564259E-03
     +,   5.7247253E-03,   6.1280606E-03,   6.5574534E-03
     +,   7.0023453E-03,   7.4554682E-03,   7.9180952E-03
     +,   8.4022619E-03,   8.9268060E-03,   9.5078787E-03
     +,   1.0150330E-02,   1.0847663E-02,   1.1592012E-02
     +,   1.2384693E-02,   1.3234590E-02,   1.4143505E-02
     +,   1.5093153E-02,   1.6049078E-02,   1.6979074E-02
     +,   1.7870715E-02,   1.8742351E-02,   1.9652100E-02
     +,   2.0689385E-02,   2.1924982E-02,   2.3349611E-02
     +,   2.4875117E-02,   2.6395191E-02,   2.7809303E-02
     +,   2.8972296E-02,   2.9678363E-02,   2.9768160E-02
     +,   2.9256810E-02,   2.8306125E-02,   2.7056037E-02
     +,   2.5517214E-02,   2.3628153E-02,   2.1375822E-02
     +,   1.8852146E-02,   1.6222835E-02,   1.3661978E-02
     +,   1.1304280E-02,   9.2340317E-03,   7.4907378E-03
     +,   6.0752183E-03,   4.9546501E-03,   4.0755924E-03
     +,   3.3810812E-03,   2.8240990E-03,   2.3714772E-03
     +,   2.0011654E-03,   1.6975815E-03,   1.4482599E-03
     +,   1.2426213E-03,   1.0717345E-03,   9.2843233E-04
     +,   8.0716057E-04,   7.0372346E-04,   6.1491388E-04
     +,   5.3825241E-04,   4.7176506E-04,   4.1387958E-04
     +,   3.6332625E-04,   3.1909207E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt113 = Yx/0.199733333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7021903E-05,   1.7612663E-05
     +,   1.8229286E-05,   1.8872566E-05,   1.9543299E-05
     +,   2.0242251E-05,   2.0970161E-05,   2.1727748E-05
     +,   2.2515691E-05,   2.3334658E-05,   2.4185247E-05
     +,   2.5068031E-05,   2.5983529E-05,   2.6932206E-05
     +,   2.7914481E-05,   2.8930699E-05,   2.9981160E-05
     +,   3.1066083E-05,   3.2185610E-05,   3.3339824E-05
     +,   3.4528723E-05,   3.5752208E-05,   3.7010090E-05
     +,   3.8302176E-05,   3.9628012E-05,   4.0987212E-05
     +,   4.2379212E-05,   4.3803335E-05,   4.5258847E-05
     +,   4.6744866E-05,   4.8260434E-05,   4.9804461E-05
     +,   5.1375773E-05,   5.2973053E-05,   5.4594893E-05
     +,   5.6239769E-05,   5.7906054E-05,   5.9591974E-05
     +,   6.1295759E-05,   6.3015344E-05,   6.4748754E-05
     +,   6.6493783E-05,   6.8248213E-05,   7.0009643E-05
     +,   7.1775692E-05,   7.3543793E-05,   7.5311378E-05
     +,   7.7075769E-05,   7.8834244E-05,   8.0583981E-05
     +,   8.2322214E-05,   8.4046042E-05,   8.5752559E-05
     +,   8.7438952E-05,   8.9102170E-05,   9.0739435E-05
     +,   9.2347800E-05,   9.3924449E-05,   9.5466559E-05
     +,   9.6971402E-05,   9.8436365E-05,   9.9858815E-05
     +,   1.0123628E-04,   1.0256646E-04,   1.0384716E-04
     +,   1.0507629E-04,   1.0625207E-04,   1.0737267E-04
     +,   1.0843670E-04,   1.0944284E-04,   1.1039009E-04
     +,   1.1127759E-04,   1.1210487E-04,   1.1287162E-04
     +,   1.1357789E-04,   1.1422399E-04,   1.1481055E-04
     +,   1.1533851E-04,   1.1580912E-04,   1.1622404E-04
     +,   1.1658516E-04,   1.1689478E-04,   1.1715553E-04
     +,   1.1737035E-04,   1.1754259E-04,   1.1767590E-04
     +,   1.1777427E-04,   1.1784204E-04,   1.1788384E-04
     +,   1.1790462E-04,   1.1790967E-04,   1.1790456E-04
     +,   1.1789506E-04,   1.1788728E-04,   1.1788746E-04
     +,   1.1790216E-04,   1.1793806E-04,   1.1800196E-04
     +,   1.1810083E-04,   1.1824168E-04,   1.1843164E-04
     +,   1.1867777E-04,   1.1898712E-04,   1.1936666E-04
     +,   1.1982321E-04,   1.2036347E-04,   1.2099386E-04
     +,   1.2172044E-04,   1.2254903E-04,   1.2348502E-04
     +,   1.2453318E-04,   1.2569793E-04,   1.2698291E-04
     +,   1.2839123E-04,   1.2992507E-04,   1.3158601E-04
     +,   1.3337452E-04,   1.3529035E-04,   1.3733204E-04
     +,   1.3949724E-04,   1.4178254E-04,   1.4418317E-04
     +,   1.4669332E-04,   1.4930595E-04,   1.5201299E-04
     +,   1.5480487E-04,   1.5767118E-04,   1.6059991E-04
     +,   1.6357843E-04,   1.6659260E-04,   1.6962778E-04
     +,   1.7266782E-04,   1.7569658E-04,   1.7869650E-04
     +,   1.8165002E-04,   1.8453921E-04,   1.8734572E-04
     +,   1.9005132E-04,   1.9263805E-04,   1.9508861E-04
     +,   1.9738579E-04,   1.9951363E-04,   2.0145730E-04
     +,   2.0320319E-04,   2.0473915E-04,   2.0605489E-04
     +,   2.0714229E-04,   2.0799517E-04,   2.0860959E-04
     +,   2.0898467E-04,   2.0912186E-04,   2.0902551E-04
     +,   2.0870313E-04,   2.0816512E-04,   2.0742491E-04
     +,   2.0649936E-04,   2.0540843E-04,   2.0417504E-04
     +,   2.0282558E-04,   2.0138909E-04,   1.9989791E-04
     +,   1.9838700E-04,   1.9689403E-04,   1.9545959E-04
     +,   1.9412626E-04,   1.9293904E-04,   1.9194494E-04
     +,   1.9119320E-04,   1.9073454E-04,   1.9062139E-04
     +,   1.9090796E-04,   1.9164974E-04,   1.9290359E-04
     +,   1.9472776E-04,   1.9718154E-04,   2.0032535E-04
     +,   2.0422068E-04,   2.0892925E-04,   2.1451339E-04
     +,   2.2103569E-04,   2.2855865E-04,   2.3714348E-04
     +,   2.4685040E-04,   2.5773814E-04,   2.6986428E-04
     +,   2.8328295E-04,   2.9804639E-04,   3.1420548E-04
     +,   3.3180972E-04,   3.5090625E-04,   3.7154404E-04
     +,   3.9377381E-04,   4.1764753E-04,   4.4322098E-04
     +,   4.7055676E-04,   4.9972330E-04,   5.3079281E-04
     +,   5.6384224E-04,   5.9895375E-04,   6.3620938E-04
     +,   6.7568512E-04,   7.1744644E-04,   7.6154567E-04
     +,   8.0801267E-04,   8.5684081E-04,   9.0799324E-04
     +,   9.6139178E-04,   1.0169178E-03,   1.0744217E-03
     +,   1.1337497E-03,   1.1947784E-03,   1.2574558E-03
     +,   1.3218834E-03,   1.3883980E-03,   1.4576640E-03
     +,   1.5307491E-03,   1.6091892E-03,   1.6950088E-03
     +,   1.7906586E-03,   1.8988842E-03,   2.0225225E-03
     +,   2.1642102E-03,   2.3260554E-03,   2.5093118E-03
     +,   2.7141294E-03,   2.9393893E-03,   3.1826801E-03
     +,   3.4404672E-03,   3.7084341E-03,   3.9818683E-03
     +,   4.2561134E-03,   4.5269812E-03,   4.7911536E-03
     +,   5.0464384E-03,   5.2920408E-03,   5.5288663E-03
     +,   5.7596969E-03,   5.9891716E-03,   6.2234332E-03
     +,   6.4693629E-03,   6.7333435E-03,   7.0197824E-03
     +,   7.3297773E-03,   7.6602306E-03,   8.0041569E-03
     +,   8.3526485E-03,   8.6988378E-03,   9.0429410E-03
     +,   9.3964748E-03,   9.7837085E-03,   1.0239288E-02
     +,   1.0800948E-02,   1.1496457E-02,   1.2325617E-02
     +,   1.3244833E-02,   1.4171469E-02,   1.5021684E-02
     +,   1.5771324E-02,   1.6497662E-02,   1.7357551E-02
     +,   1.8501196E-02,   1.9975036E-02,   2.1684302E-02
     +,   2.3441184E-02,   2.5058901E-02,   2.6422545E-02
     +,   2.7496168E-02,   2.8285790E-02,   2.8800357E-02
     +,   2.9037043E-02,   2.8986219E-02,   2.8636189E-02
     +,   2.7964996E-02,   2.6936905E-02,   2.5529366E-02
     +,   2.3774253E-02,   2.1764699E-02,   1.9611700E-02
     +,   1.7393220E-02,   1.5147673E-02,   1.2906939E-02
     +,   1.0729277E-02,   8.7001212E-03,   6.9078924E-03
     +,   5.4143863E-03,   4.2384919E-03,   3.3563338E-03
     +,   2.7150824E-03,   2.2516921E-03,   1.9085498E-03
     +,   1.6420631E-03,   1.4237582E-03,   1.2372524E-03
     +,   1.0739377E-03,   9.2952349E-04,   8.0174883E-04
     +,   6.8923208E-04,   5.9088215E-04,   5.0568598E-04
     +,   4.3258705E-04,   3.7047424E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt114 = Yx/0.212955555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt1148(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2083743E-05,   3.2875483E-05
     +,   3.3682609E-05,   3.4505676E-05,   3.5345245E-05
     +,   3.6201938E-05,   3.7076425E-05,   3.7969396E-05
     +,   3.8881579E-05,   3.9813811E-05,   4.0766878E-05
     +,   4.1741689E-05,   4.2739139E-05,   4.3760214E-05
     +,   4.4805915E-05,   4.5877281E-05,   4.6975412E-05
     +,   4.8101410E-05,   4.9256447E-05,   5.0441686E-05
     +,   5.1658339E-05,   5.2907602E-05,   5.4190681E-05
     +,   5.5508855E-05,   5.6863220E-05,   5.8255053E-05
     +,   5.9685452E-05,   6.1155522E-05,   6.2666302E-05
     +,   6.4218737E-05,   6.5813721E-05,   6.7451998E-05
     +,   6.9134214E-05,   7.0860842E-05,   7.2632269E-05
     +,   7.4448602E-05,   7.6309829E-05,   7.8215679E-05
     +,   8.0165788E-05,   8.2159262E-05,   8.4195257E-05
     +,   8.6272477E-05,   8.8389344E-05,   9.0544039E-05
     +,   9.2734415E-05,   9.4957984E-05,   9.7211967E-05
     +,   9.9493242E-05,   1.0179837E-04,   1.0412362E-04
     +,   1.0646490E-04,   1.0881786E-04,   1.1117781E-04
     +,   1.1353997E-04,   1.1589899E-04,   1.1824962E-04
     +,   1.2058623E-04,   1.2290305E-04,   1.2519426E-04
     +,   1.2745382E-04,   1.2967581E-04,   1.3185416E-04
     +,   1.3398280E-04,   1.3605588E-04,   1.3806768E-04
     +,   1.4001242E-04,   1.4188487E-04,   1.4367975E-04
     +,   1.4539230E-04,   1.4701803E-04,   1.4855291E-04
     +,   1.4999321E-04,   1.5133590E-04,   1.5257817E-04
     +,   1.5371795E-04,   1.5475368E-04,   1.5568432E-04
     +,   1.5650946E-04,   1.5722925E-04,   1.5784461E-04
     +,   1.5835672E-04,   1.5876768E-04,   1.5908008E-04
     +,   1.5929695E-04,   1.5942191E-04,   1.5945922E-04
     +,   1.5941339E-04,   1.5928948E-04,   1.5909303E-04
     +,   1.5882975E-04,   1.5850573E-04,   1.5812734E-04
     +,   1.5770106E-04,   1.5723360E-04,   1.5673165E-04
     +,   1.5620211E-04,   1.5565162E-04,   1.5508701E-04
     +,   1.5451488E-04,   1.5394157E-04,   1.5337337E-04
     +,   1.5281633E-04,   1.5227607E-04,   1.5175811E-04
     +,   1.5126751E-04,   1.5080902E-04,   1.5038704E-04
     +,   1.5000561E-04,   1.4966838E-04,   1.4937868E-04
     +,   1.4913939E-04,   1.4895306E-04,   1.4882199E-04
     +,   1.4874805E-04,   1.4873283E-04,   1.4877769E-04
     +,   1.4888373E-04,   1.4905179E-04,   1.4928261E-04
     +,   1.4957668E-04,   1.4993429E-04,   1.5035577E-04
     +,   1.5084130E-04,   1.5139108E-04,   1.5200513E-04
     +,   1.5268363E-04,   1.5342647E-04,   1.5423396E-04
     +,   1.5510619E-04,   1.5604320E-04,   1.5704536E-04
     +,   1.5811283E-04,   1.5924597E-04,   1.6044502E-04
     +,   1.6171052E-04,   1.6304289E-04,   1.6444265E-04
     +,   1.6591039E-04,   1.6744688E-04,   1.6905300E-04
     +,   1.7072973E-04,   1.7247835E-04,   1.7430035E-04
     +,   1.7619783E-04,   1.7817305E-04,   1.8022905E-04
     +,   1.8236968E-04,   1.8459938E-04,   1.8692379E-04
     +,   1.8934990E-04,   1.9188614E-04,   1.9454227E-04
     +,   1.9733018E-04,   2.0026375E-04,   2.0335907E-04
     +,   2.0663462E-04,   2.1011145E-04,   2.1381317E-04
     +,   2.1776640E-04,   2.2199986E-04,   2.2654532E-04
     +,   2.3143689E-04,   2.3671053E-04,   2.4240377E-04
     +,   2.4855576E-04,   2.5520663E-04,   2.6239539E-04
     +,   2.7016082E-04,   2.7854022E-04,   2.8756834E-04
     +,   2.9727590E-04,   3.0768904E-04,   3.1882917E-04
     +,   3.3071154E-04,   3.4334339E-04,   3.5672527E-04
     +,   3.7085058E-04,   3.8570267E-04,   4.0125725E-04
     +,   4.1748284E-04,   4.3434155E-04,   4.5178685E-04
     +,   4.6976787E-04,   4.8823038E-04,   5.0711777E-04
     +,   5.2637310E-04,   5.4593955E-04,   5.6576612E-04
     +,   5.8580836E-04,   6.0602807E-04,   6.2640017E-04
     +,   6.4691395E-04,   6.6757324E-04,   6.8840024E-04
     +,   7.0944004E-04,   7.3076179E-04,   7.5245835E-04
     +,   7.7465136E-04,   7.9749385E-04,   8.2116958E-04
     +,   8.4589556E-04,   8.7192358E-04,   8.9954253E-04
     +,   9.2908059E-04,   9.6090330E-04,   9.9541992E-04
     +,   1.0330859E-03,   1.0744012E-03,   1.1199103E-03
     +,   1.1702087E-03,   1.2259335E-03,   1.2877526E-03
     +,   1.3563473E-03,   1.4324023E-03,   1.5165776E-03
     +,   1.6094825E-03,   1.7116758E-03,   1.8236785E-03
     +,   1.9460110E-03,   2.0792305E-03,   2.2240344E-03
     +,   2.3812987E-03,   2.5520695E-03,   2.7374856E-03
     +,   2.9385823E-03,   3.1559614E-03,   3.3894116E-03
     +,   3.6376000E-03,   3.8979736E-03,   4.1669658E-03
     +,   4.4406094E-03,   4.7155810E-03,   4.9903509E-03
     +,   5.2661845E-03,   5.5474634E-03,   5.8412901E-03
     +,   6.1560422E-03,   6.4992723E-03,   6.8754330E-03
     +,   7.2839269E-03,   7.7177333E-03,   8.1631159E-03
     +,   8.6008636E-03,   9.0097459E-03,   9.3727158E-03
     +,   9.6855816E-03,   9.9654384E-03,   1.0254838E-02
     +,   1.0616660E-02,   1.1118678E-02,   1.1811337E-02
     +,   1.2707652E-02,   1.3774708E-02,   1.4941288E-02
     +,   1.6116606E-02,   1.7210452E-02,   1.8147198E-02
     +,   1.8875308E-02,   1.9378329E-02,   1.9689819E-02
     +,   1.9901294E-02,   2.0143200E-02,   2.0531366E-02
     +,   2.1107251E-02,   2.1821678E-02,   2.2583202E-02
     +,   2.3328448E-02,   2.4047306E-02,   2.4745081E-02
     +,   2.5388399E-02,   2.5885552E-02,   2.6108667E-02
     +,   2.5932573E-02,   2.5269955E-02,   2.4092799E-02
     +,   2.2438833E-02,   2.0402575E-02,   1.8118436E-02
     +,   1.5738627E-02,   1.3410811E-02,   1.1255734E-02
     +,   9.3524233E-03,   7.7330959E-03,   6.3904892E-03
     +,   5.2918480E-03,   4.3948330E-03,   3.6589359E-03
     +,   3.0512346E-03,   2.5471270E-03,   2.1283394E-03
     +,   1.7807862E-03,   1.4928055E-03,   1.2543924E-03
     +,   1.0568006E-03,   8.9253392E-04,   7.5527938E-04
     +,   6.3990994E-04,   5.4233451E-04,   4.5937730E-04
     +,   3.8857726E-04,   3.2804074E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt1148 = Yx/0.214666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0331163E-05,   3.0951163E-05
     +,   3.1580348E-05,   3.2219064E-05,   3.2867669E-05
     +,   3.3526529E-05,   3.4196022E-05,   3.4876542E-05
     +,   3.5568468E-05,   3.6272231E-05,   3.6988218E-05
     +,   3.7716844E-05,   3.8458489E-05,   3.9213584E-05
     +,   3.9982504E-05,   4.0765630E-05,   4.1563329E-05
     +,   4.2375948E-05,   4.3203810E-05,   4.4047221E-05
     +,   4.4906446E-05,   4.5781719E-05,   4.6673220E-05
     +,   4.7581161E-05,   4.8505568E-05,   4.9446571E-05
     +,   5.0404131E-05,   5.1378192E-05,   5.2368636E-05
     +,   5.3375268E-05,   5.4397824E-05,   5.5435958E-05
     +,   5.6489243E-05,   5.7557194E-05,   5.8639202E-05
     +,   5.9734597E-05,   6.0842609E-05,   6.1962353E-05
     +,   6.3092935E-05,   6.4233223E-05,   6.5382119E-05
     +,   6.6538392E-05,   6.7700683E-05,   6.8867586E-05
     +,   7.0037575E-05,   7.1209033E-05,   7.2380295E-05
     +,   7.3549592E-05,   7.4715092E-05,   7.5874879E-05
     +,   7.7026976E-05,   7.8169374E-05,   7.9299993E-05
     +,   8.0416707E-05,   8.1517370E-05,   8.2599858E-05
     +,   8.3661973E-05,   8.4701518E-05,   8.5716361E-05
     +,   8.6704342E-05,   8.7663335E-05,   8.8591289E-05
     +,   8.9486181E-05,   9.0346046E-05,   9.1169073E-05
     +,   9.1953429E-05,   9.2697512E-05,   9.3399693E-05
     +,   9.4058661E-05,   9.4673043E-05,   9.5241776E-05
     +,   9.5763848E-05,   9.6238531E-05,   9.6665179E-05
     +,   9.7043434E-05,   9.7373093E-05,   9.7654200E-05
     +,   9.7886958E-05,   9.8071941E-05,   9.8209857E-05
     +,   9.8301731E-05,   9.8348806E-05,   9.8352670E-05
     +,   9.8315126E-05,   9.8238364E-05,   9.8124794E-05
     +,   9.7977172E-05,   9.7798569E-05,   9.7592383E-05
     +,   9.7362426E-05,   9.7112752E-05,   9.6847827E-05
     +,   9.6572476E-05,   9.6291915E-05,   9.6011696E-05
     +,   9.5737763E-05,   9.5476440E-05,   9.5234464E-05
     +,   9.5018891E-05,   9.4837167E-05,   9.4697083E-05
     +,   9.4606810E-05,   9.4574774E-05,   9.4609735E-05
     +,   9.4720672E-05,   9.4916846E-05,   9.5207630E-05
     +,   9.5602503E-05,   9.6111042E-05,   9.6742777E-05
     +,   9.7507094E-05,   9.8413257E-05,   9.9470155E-05
     +,   1.0068642E-04,   1.0206996E-04,   1.0362831E-04
     +,   1.0536795E-04,   1.0729484E-04,   1.0941354E-04
     +,   1.1172782E-04,   1.1424006E-04,   1.1695117E-04
     +,   1.1986052E-04,   1.2296611E-04,   1.2626415E-04
     +,   1.2974881E-04,   1.3341288E-04,   1.3724680E-04
     +,   1.4123956E-04,   1.4537781E-04,   1.4964682E-04
     +,   1.5402958E-04,   1.5850799E-04,   1.6306173E-04
     +,   1.6766960E-04,   1.7230920E-04,   1.7695686E-04
     +,   1.8158808E-04,   1.8617840E-04,   1.9070308E-04
     +,   1.9513743E-04,   1.9945719E-04,   2.0363930E-04
     +,   2.0766206E-04,   2.1150484E-04,   2.1514964E-04
     +,   2.1858064E-04,   2.2178459E-04,   2.2475133E-04
     +,   2.2747427E-04,   2.2995050E-04,   2.3218076E-04
     +,   2.3416980E-04,   2.3592712E-04,   2.3746633E-04
     +,   2.3880550E-04,   2.3996718E-04,   2.4097862E-04
     +,   2.4187157E-04,   2.4268164E-04,   2.4344928E-04
     +,   2.4421868E-04,   2.4503769E-04,   2.4595804E-04
     +,   2.4703454E-04,   2.4832512E-04,   2.4989014E-04
     +,   2.5179249E-04,   2.5409664E-04,   2.5686913E-04
     +,   2.6017669E-04,   2.6408726E-04,   2.6866869E-04
     +,   2.7398852E-04,   2.8011302E-04,   2.8710728E-04
     +,   2.9503476E-04,   3.0395616E-04,   3.1392887E-04
     +,   3.2500864E-04,   3.3724803E-04,   3.5069624E-04
     +,   3.6540057E-04,   3.8140715E-04,   3.9876305E-04
     +,   4.1751485E-04,   4.3771215E-04,   4.5940961E-04
     +,   4.8266814E-04,   5.0755276E-04,   5.3413736E-04
     +,   5.6250131E-04,   5.9272739E-04,   6.2489806E-04
     +,   6.5909821E-04,   6.9540407E-04,   7.3388446E-04
     +,   7.7459693E-04,   8.1759604E-04,   8.6293445E-04
     +,   9.1067323E-04,   9.6090039E-04,   1.0137588E-03
     +,   1.0694695E-03,   1.1283627E-03,   1.1909161E-03
     +,   1.2577898E-03,   1.3298440E-03,   1.4081633E-03
     +,   1.4940616E-03,   1.5890627E-03,   1.6948362E-03
     +,   1.8131263E-03,   1.9456435E-03,   2.0939133E-03
     +,   2.2591134E-03,   2.4419455E-03,   2.6425403E-03
     +,   2.8604500E-03,   3.0946727E-03,   3.3438308E-03
     +,   3.6062994E-03,   3.8802605E-03,   4.1636759E-03
     +,   4.4540702E-03,   4.7481530E-03,   5.0414470E-03
     +,   5.3281104E-03,   5.6012208E-03,   5.8535072E-03
     +,   6.0786563E-03,   6.2730447E-03,   6.4375084E-03
     +,   6.5787663E-03,   6.7100963E-03,   6.8508713E-03
     +,   7.0247254E-03,   7.2562103E-03,   7.5664492E-03
     +,   7.9682563E-03,   8.4620798E-03,   9.0338523E-03
     +,   9.6559906E-03,   1.0291934E-02,   1.0903110E-02
     +,   1.1457162E-02,   1.1935429E-02,   1.2338299E-02
     +,   1.2687344E-02,   1.3022196E-02,   1.3389818E-02
     +,   1.3826519E-02,   1.4339732E-02,   1.4904577E-02
     +,   1.5485008E-02,   1.6070582E-02,   1.6698949E-02
     +,   1.7436074E-02,   1.8319454E-02,   1.9310487E-02
     +,   2.0306295E-02,   2.1212053E-02,   2.2011392E-02
     +,   2.2763170E-02,   2.3523536E-02,   2.4274604E-02
     +,   2.4933178E-02,   2.5420753E-02,   2.5708245E-02
     +,   2.5795139E-02,   2.5666296E-02,   2.5282761E-02
     +,   2.4605459E-02,   2.3616299E-02,   2.2319697E-02
     +,   2.0737799E-02,   1.8913409E-02,   1.6919049E-02
     +,   1.4857042E-02,   1.2843852E-02,   1.0981384E-02
     +,   9.3325609E-03,   7.9126637E-03,   6.7011318E-03
     +,   5.6621996E-03,   4.7631026E-03,   3.9816066E-03
     +,   3.3050389E-03,   2.7255879E-03,   2.2359691E-03
     +,   1.8276321E-03,   1.4905792E-03,   1.2143496E-03
     +,   9.8891405E-04,   8.0541917E-04,   6.5639865E-04
     +,   5.3576048E-04,   4.3852295E-04,   3.6058045E-04
     +,   2.9845536E-04,   2.4917413E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt116 = Yx/0.224622222222222
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4763717E-05,   1.5361709E-05
     +,   1.6005120E-05,   1.6696860E-05,   1.7439921E-05
     +,   1.8237337E-05,   1.9092184E-05,   2.0007552E-05
     +,   2.0986545E-05,   2.2032280E-05,   2.3147808E-05
     +,   2.4336156E-05,   2.5600248E-05,   2.6942957E-05
     +,   2.8366996E-05,   2.9874953E-05,   3.1469241E-05
     +,   3.3152086E-05,   3.4925451E-05,   3.6791087E-05
     +,   3.8750473E-05,   4.0804734E-05,   4.2954653E-05
     +,   4.5200810E-05,   4.7543115E-05,   4.9981369E-05
     +,   5.2514748E-05,   5.5142064E-05,   5.7861642E-05
     +,   6.0671322E-05,   6.3568477E-05,   6.6549976E-05
     +,   6.9612128E-05,   7.2750860E-05,   7.5961485E-05
     +,   7.9238860E-05,   8.2577419E-05,   8.5970969E-05
     +,   8.9413159E-05,   9.2896815E-05,   9.6414777E-05
     +,   9.9959267E-05,   1.0352229E-04,   1.0709547E-04
     +,   1.1067034E-04,   1.1423812E-04,   1.1778992E-04
     +,   1.2131682E-04,   1.2480981E-04,   1.2825993E-04
     +,   1.3165834E-04,   1.3499630E-04,   1.3826526E-04
     +,   1.4145713E-04,   1.4456379E-04,   1.4757794E-04
     +,   1.5049240E-04,   1.5330069E-04,   1.5599669E-04
     +,   1.5857507E-04,   1.6103103E-04,   1.6336057E-04
     +,   1.6556017E-04,   1.6762741E-04,   1.6956033E-04
     +,   1.7135797E-04,   1.7302005E-04,   1.7454712E-04
     +,   1.7594069E-04,   1.7720279E-04,   1.7833644E-04
     +,   1.7934536E-04,   1.8023407E-04,   1.8100762E-04
     +,   1.8167190E-04,   1.8223333E-04,   1.8269893E-04
     +,   1.8307618E-04,   1.8337296E-04,   1.8359763E-04
     +,   1.8375881E-04,   1.8386530E-04,   1.8392605E-04
     +,   1.8395016E-04,   1.8394667E-04,   1.8392445E-04
     +,   1.8389239E-04,   1.8385894E-04,   1.8383229E-04
     +,   1.8382032E-04,   1.8383023E-04,   1.8386883E-04
     +,   1.8394220E-04,   1.8405593E-04,   1.8421464E-04
     +,   1.8442236E-04,   1.8468220E-04,   1.8499652E-04
     +,   1.8536666E-04,   1.8579322E-04,   1.8627578E-04
     +,   1.8681305E-04,   1.8740290E-04,   1.8804228E-04
     +,   1.8872727E-04,   1.8945322E-04,   1.9021463E-04
     +,   1.9100527E-04,   1.9181837E-04,   1.9264650E-04
     +,   1.9348168E-04,   1.9431567E-04,   1.9513963E-04
     +,   1.9594490E-04,   1.9672212E-04,   1.9746236E-04
     +,   1.9815656E-04,   1.9879588E-04,   1.9937180E-04
     +,   1.9987614E-04,   2.0030129E-04,   2.0064026E-04
     +,   2.0088683E-04,   2.0103552E-04,   2.0108196E-04
     +,   2.0102279E-04,   2.0085578E-04,   2.0057993E-04
     +,   2.0019565E-04,   1.9970487E-04,   1.9911089E-04
     +,   1.9841870E-04,   1.9763487E-04,   1.9676788E-04
     +,   1.9582792E-04,   1.9482680E-04,   1.9377851E-04
     +,   1.9269888E-04,   1.9160542E-04,   1.9051765E-04
     +,   1.8945699E-04,   1.8844685E-04,   1.8751189E-04
     +,   1.8667906E-04,   1.8597634E-04,   1.8543346E-04
     +,   1.8508127E-04,   1.8495157E-04,   1.8507698E-04
     +,   1.8549057E-04,   1.8622578E-04,   1.8731557E-04
     +,   1.8879256E-04,   1.9068815E-04,   1.9303264E-04
     +,   1.9585417E-04,   1.9917841E-04,   2.0302839E-04
     +,   2.0742383E-04,   2.1238020E-04,   2.1790891E-04
     +,   2.2401713E-04,   2.3070611E-04,   2.3797188E-04
     +,   2.4580539E-04,   2.5419172E-04,   2.6310980E-04
     +,   2.7253272E-04,   2.8242913E-04,   2.9276227E-04
     +,   3.0349058E-04,   3.1456852E-04,   3.2594852E-04
     +,   3.3758185E-04,   3.4941750E-04,   3.6140729E-04
     +,   3.7350616E-04,   3.8567264E-04,   3.9787256E-04
     +,   4.1008199E-04,   4.2228861E-04,   4.3449426E-04
     +,   4.4671877E-04,   4.5900373E-04,   4.7141549E-04
     +,   4.8404906E-04,   4.9703370E-04,   5.1053858E-04
     +,   5.2477850E-04,   5.4001895E-04,   5.5658520E-04
     +,   5.7486963E-04,   5.9533399E-04,   6.1851571E-04
     +,   6.4502837E-04,   6.7556032E-04,   7.1085617E-04
     +,   7.5170380E-04,   7.9890643E-04,   8.5324823E-04
     +,   9.1544300E-04,   9.8609191E-04,   1.0656373E-03
     +,   1.1543218E-03,   1.2521446E-03,   1.3588701E-03
     +,   1.4740264E-03,   1.5969283E-03,   1.7267279E-03
     +,   1.8624825E-03,   2.0032078E-03,   2.1479130E-03
     +,   2.2956564E-03,   2.4455858E-03,   2.5969632E-03
     +,   2.7492067E-03,   2.9019781E-03,   3.0553073E-03
     +,   3.2097222E-03,   3.3663474E-03,   3.5270064E-03
     +,   3.6941387E-03,   3.8705831E-03,   4.0591746E-03
     +,   4.2622457E-03,   4.4810534E-03,   4.7152811E-03
     +,   4.9627447E-03,   5.2193850E-03,   5.4794401E-03
     +,   5.7358979E-03,   5.9811110E-03,   6.2077953E-03
     +,   6.4102681E-03,   6.5863086E-03,   6.7393887E-03
     +,   6.8807648E-03,   7.0304549E-03,   7.2158719E-03
     +,   7.4673705E-03,   7.8110816E-03,   8.2613602E-03
     +,   8.8161109E-03,   9.4579440E-03,   1.0161516E-02
     +,   1.0903861E-02,   1.1673259E-02,   1.2471536E-02
     +,   1.3308056E-02,   1.4186951E-02,   1.5093884E-02
     +,   1.5989678E-02,   1.6819030E-02,   1.7534342E-02
     +,   1.8122159E-02,   1.8612957E-02,   1.9063152E-02
     +,   1.9520469E-02,   1.9996936E-02,   2.0470781E-02
     +,   2.0911887E-02,   2.1309569E-02,   2.1682633E-02
     +,   2.2067320E-02,   2.2490185E-02,   2.2938130E-02
     +,   2.3342516E-02,   2.3592137E-02,   2.3576763E-02
     +,   2.3238584E-02,   2.2598846E-02,   2.1741625E-02
     +,   2.0764863E-02,   1.9730076E-02,   1.8640114E-02
     +,   1.7455053E-02,   1.6132055E-02,   1.4664241E-02
     +,   1.3096096E-02,   1.1510986E-02,   1.0000374E-02
     +,   8.6345077E-03,   7.4465629E-03,   6.4347577E-03
     +,   5.5750362E-03,   4.8365830E-03,   4.1926028E-03
     +,   3.6250073E-03,   3.1239013E-03,   2.6843199E-03
     +,   2.3029798E-03,   1.9759699E-03,   1.6980335E-03
     +,   1.4627880E-03,   1.2635731E-03,   1.0941561E-03
     +,   9.4926666E-04,   8.2468946E-04,   7.1720453E-04
     +,   6.2432821E-04,   5.4410752E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt117 = Yx/0.223239130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9024983E-05,   1.9769324E-05
     +,   2.0538100E-05,   2.1331953E-05,   2.2151542E-05
     +,   2.2997574E-05,   2.3870754E-05,   2.4771853E-05
     +,   2.5701631E-05,   2.6660933E-05,   2.7650594E-05
     +,   2.8671488E-05,   2.9724521E-05,   3.0810625E-05
     +,   3.1930758E-05,   3.3085889E-05,   3.4277036E-05
     +,   3.5505182E-05,   3.6771362E-05,   3.8076578E-05
     +,   3.9421851E-05,   4.0808158E-05,   4.2236457E-05
     +,   4.3707725E-05,   4.5222801E-05,   4.6782530E-05
     +,   4.8387679E-05,   5.0038892E-05,   5.1736748E-05
     +,   5.3481715E-05,   5.5274111E-05,   5.7114150E-05
     +,   5.9001832E-05,   6.0937029E-05,   6.2919433E-05
     +,   6.4948516E-05,   6.7023575E-05,   6.9143578E-05
     +,   7.1307528E-05,   7.3513809E-05,   7.5760923E-05
     +,   7.8046949E-05,   8.0369704E-05,   8.2726881E-05
     +,   8.5115818E-05,   8.7533677E-05,   8.9977424E-05
     +,   9.2443763E-05,   9.4929266E-05,   9.7430326E-05
     +,   9.9943129E-05,   1.0246381E-04,   1.0498839E-04
     +,   1.0751290E-04,   1.1003315E-04,   1.1254523E-04
     +,   1.1504503E-04,   1.1752870E-04,   1.1999236E-04
     +,   1.2243244E-04,   1.2484542E-04,   1.2722818E-04
     +,   1.2957766E-04,   1.3189128E-04,   1.3416675E-04
     +,   1.3640203E-04,   1.3859563E-04,   1.4074626E-04
     +,   1.4285324E-04,   1.4491614E-04,   1.4693510E-04
     +,   1.4891052E-04,   1.5084338E-04,   1.5273484E-04
     +,   1.5458661E-04,   1.5640077E-04,   1.5817958E-04
     +,   1.5992550E-04,   1.6164138E-04,   1.6333035E-04
     +,   1.6499532E-04,   1.6663964E-04,   1.6826642E-04
     +,   1.6987881E-04,   1.7147994E-04,   1.7307261E-04
     +,   1.7465948E-04,   1.7624308E-04,   1.7782526E-04
     +,   1.7940787E-04,   1.8099209E-04,   1.8257872E-04
     +,   1.8416802E-04,   1.8575977E-04,   1.8735325E-04
     +,   1.8894701E-04,   1.9053940E-04,   1.9212774E-04
     +,   1.9370936E-04,   1.9528072E-04,   1.9683789E-04
     +,   1.9837661E-04,   1.9989233E-04,   2.0137988E-04
     +,   2.0283429E-04,   2.0425017E-04,   2.0562210E-04
     +,   2.0694472E-04,   2.0821280E-04,   2.0942128E-04
     +,   2.1056554E-04,   2.1164121E-04,   2.1264452E-04
     +,   2.1357244E-04,   2.1442243E-04,   2.1519314E-04
     +,   2.1588372E-04,   2.1649475E-04,   2.1702777E-04
     +,   2.1748547E-04,   2.1787192E-04,   2.1819249E-04
     +,   2.1845401E-04,   2.1866465E-04,   2.1883422E-04
     +,   2.1897384E-04,   2.1909646E-04,   2.1921624E-04
     +,   2.1934905E-04,   2.1951196E-04,   2.1972366E-04
     +,   2.2000411E-04,   2.2037429E-04,   2.2085644E-04
     +,   2.2147363E-04,   2.2224983E-04,   2.2320924E-04
     +,   2.2437664E-04,   2.2577694E-04,   2.2743476E-04
     +,   2.2937416E-04,   2.3161850E-04,   2.3419003E-04
     +,   2.3710968E-04,   2.4039608E-04,   2.4406624E-04
     +,   2.4813414E-04,   2.5261115E-04,   2.5750499E-04
     +,   2.6281978E-04,   2.6855641E-04,   2.7471047E-04
     +,   2.8127374E-04,   2.8823281E-04,   2.9557059E-04
     +,   3.0326363E-04,   3.1128468E-04,   3.1960144E-04
     +,   3.2817796E-04,   3.3697285E-04,   3.4594230E-04
     +,   3.5503949E-04,   3.6421506E-04,   3.7341772E-04
     +,   3.8259762E-04,   3.9170519E-04,   4.0069324E-04
     +,   4.0951843E-04,   4.1814358E-04,   4.2653942E-04
     +,   4.3468509E-04,   4.4257133E-04,   4.5020232E-04
     +,   4.5759798E-04,   4.6479347E-04,   4.7184393E-04
     +,   4.7882329E-04,   4.8582666E-04,   4.9296964E-04
     +,   5.0039031E-04,   5.0824805E-04,   5.1672244E-04
     +,   5.2601303E-04,   5.3633860E-04,   5.4793590E-04
     +,   5.6105765E-04,   5.7597167E-04,   5.9296162E-04
     +,   6.1232556E-04,   6.3437392E-04,   6.5943238E-04
     +,   6.8784069E-04,   7.1994954E-04,   7.5612159E-04
     +,   7.9672958E-04,   8.4215333E-04,   8.9277077E-04
     +,   9.4895560E-04,   1.0110734E-03,   1.0794735E-03
     +,   1.1544768E-03,   1.2363758E-03,   1.3254297E-03
     +,   1.4218609E-03,   1.5258316E-03,   1.6374579E-03
     +,   1.7567844E-03,   1.8837563E-03,   2.0182021E-03
     +,   2.1598057E-03,   2.3080609E-03,   2.4622118E-03
     +,   2.6212411E-03,   2.7838575E-03,   2.9485126E-03
     +,   3.1134496E-03,   3.2768508E-03,   3.4370266E-03
     +,   3.5926285E-03,   3.7429056E-03,   3.8879570E-03
     +,   4.0289182E-03,   4.1680466E-03,   4.3086698E-03
     +,   4.4549704E-03,   4.6115811E-03,   4.7830511E-03
     +,   4.9733710E-03,   5.1856386E-03,   5.4221251E-03
     +,   5.6846975E-03,   5.9755812E-03,   6.2981443E-03
     +,   6.6572679E-03,   7.0588640E-03,   7.5085461E-03
     +,   8.0093043E-03,   8.5586049E-03,   9.1456128E-03
     +,   9.7496267E-03,   1.0341174E-02,   1.0887180E-02
     +,   1.1360061E-02,   1.1748542E-02,   1.2064699E-02
     +,   1.2342946E-02,   1.2628981E-02,   1.2962831E-02
     +,   1.3364920E-02,   1.3833568E-02,   1.4354958E-02
     +,   1.4917355E-02,   1.5516547E-02,   1.6147640E-02
     +,   1.6791191E-02,   1.7410353E-02,   1.7968258E-02
     +,   1.8457223E-02,   1.8915461E-02,   1.9411201E-02
     +,   1.9998470E-02,   2.0676494E-02,   2.1387005E-02
     +,   2.2052372E-02,   2.2617342E-02,   2.3056811E-02
     +,   2.3347329E-02,   2.3441451E-02,   2.3276137E-02
     +,   2.2810496E-02,   2.2057828E-02,   2.1083308E-02
     +,   1.9970343E-02,   1.8783081E-02,   1.7549822E-02
     +,   1.6271748E-02,   1.4942768E-02,   1.3567352E-02
     +,   1.2167003E-02,   1.0777894E-02,   9.4422670E-03
     +,   8.1994804E-03,   7.0787505E-03,   6.0960958E-03
     +,   5.2540367E-03,   4.5440537E-03,   3.9498219E-03
     +,   3.4511727E-03,   3.0278559E-03,   2.6622904E-03
     +,   2.3412749E-03,   2.0560992E-03,   1.8017944E-03
     +,   1.5757350E-03,   1.3764106E-03,   1.2024434E-03
     +,   1.0521474E-03,   9.2337909E-04,   8.1368303E-04
     +,   7.2045287E-04,   6.4115995E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt118 = Yx/0.226586956521739
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6584437E-05,   2.7356566E-05
     +,   2.8142789E-05,   2.8942959E-05,   2.9756891E-05
     +,   3.0584390E-05,   3.1425225E-05,   3.2279175E-05
     +,   3.3145963E-05,   3.4025343E-05,   3.4917000E-05
     +,   3.5820634E-05,   3.6735910E-05,   3.7662467E-05
     +,   3.8599934E-05,   3.9547951E-05,   4.0506089E-05
     +,   4.1473926E-05,   4.2451029E-05,   4.3436950E-05
     +,   4.4431199E-05,   4.5433299E-05,   4.6442743E-05
     +,   4.7459049E-05,   4.8481630E-05,   4.9510018E-05
     +,   5.0543629E-05,   5.1581923E-05,   5.2624324E-05
     +,   5.3670276E-05,   5.4719207E-05,   5.5770543E-05
     +,   5.6823712E-05,   5.7878140E-05,   5.8933285E-05
     +,   5.9988535E-05,   6.1043385E-05,   6.2097257E-05
     +,   6.3149673E-05,   6.4200045E-05,   6.5247936E-05
     +,   6.6292836E-05,   6.7334309E-05,   6.8371897E-05
     +,   6.9405200E-05,   7.0433853E-05,   7.1457463E-05
     +,   7.2475763E-05,   7.3488423E-05,   7.4495212E-05
     +,   7.5495904E-05,   7.6490331E-05,   7.7478326E-05
     +,   7.8459838E-05,   7.9434736E-05,   8.0403064E-05
     +,   8.1364800E-05,   8.2320017E-05,   8.3268824E-05
     +,   8.4211330E-05,   8.5147723E-05,   8.6078224E-05
     +,   8.7003085E-05,   8.7922555E-05,   8.8837049E-05
     +,   8.9746820E-05,   9.0652306E-05,   9.1553899E-05
     +,   9.2452159E-05,   9.3347444E-05,   9.4240342E-05
     +,   9.5131363E-05,   9.6021155E-05,   9.6910262E-05
     +,   9.7799391E-05,   9.8689234E-05,   9.9580546E-05
     +,   1.0047404E-04,   1.0137064E-04,   1.0227128E-04
     +,   1.0317684E-04,   1.0408847E-04,   1.0500723E-04
     +,   1.0593446E-04,   1.0687142E-04,   1.0781969E-04
     +,   1.0878082E-04,   1.0975661E-04,   1.1074902E-04
     +,   1.1176011E-04,   1.1279230E-04,   1.1384810E-04
     +,   1.1493024E-04,   1.1604173E-04,   1.1718591E-04
     +,   1.1836620E-04,   1.1958650E-04,   1.2085074E-04
     +,   1.2216343E-04,   1.2352901E-04,   1.2495246E-04
     +,   1.2643886E-04,   1.2799360E-04,   1.2962213E-04
     +,   1.3133025E-04,   1.3312387E-04,   1.3500896E-04
     +,   1.3699140E-04,   1.3907722E-04,   1.4127251E-04
     +,   1.4358285E-04,   1.4601396E-04,   1.4857092E-04
     +,   1.5125886E-04,   1.5408201E-04,   1.5704447E-04
     +,   1.6014930E-04,   1.6339929E-04,   1.6679600E-04
     +,   1.7034053E-04,   1.7403296E-04,   1.7787219E-04
     +,   1.8185620E-04,   1.8598205E-04,   1.9024582E-04
     +,   1.9464208E-04,   1.9916493E-04,   2.0380685E-04
     +,   2.0855993E-04,   2.1341477E-04,   2.1836181E-04
     +,   2.2338997E-04,   2.2848856E-04,   2.3364530E-04
     +,   2.3884836E-04,   2.4408581E-04,   2.4934503E-04
     +,   2.5461378E-04,   2.5988018E-04,   2.6513316E-04
     +,   2.7036131E-04,   2.7555434E-04,   2.8070301E-04
     +,   2.8579877E-04,   2.9083368E-04,   2.9580109E-04
     +,   3.0069577E-04,   3.0551260E-04,   3.1024811E-04
     +,   3.1489969E-04,   3.1946585E-04,   3.2394589E-04
     +,   3.2833969E-04,   3.3264875E-04,   3.3687532E-04
     +,   3.4102236E-04,   3.4509433E-04,   3.4909672E-04
     +,   3.5303796E-04,   3.5692760E-04,   3.6077845E-04
     +,   3.6460711E-04,   3.6843432E-04,   3.7228627E-04
     +,   3.7619620E-04,   3.8020511E-04,   3.8436326E-04
     +,   3.8873163E-04,   3.9338385E-04,   3.9840717E-04
     +,   4.0390374E-04,   4.0999122E-04,   4.1680472E-04
     +,   4.2449619E-04,   4.3323380E-04,   4.4320081E-04
     +,   4.5459523E-04,   4.6762489E-04,   4.8250388E-04
     +,   4.9944944E-04,   5.1867490E-04,   5.4038182E-04
     +,   5.6475255E-04,   5.9194450E-04,   6.2207971E-04
     +,   6.5523462E-04,   6.9143286E-04,   7.3064101E-04
     +,   7.7276182E-04,   8.1762311E-04,   8.6498808E-04
     +,   9.1454969E-04,   9.6593349E-04,   1.0187078E-03
     +,   1.0723986E-03,   1.1265015E-03,   1.1804984E-03
     +,   1.2338817E-03,   1.2861834E-03,   1.3370012E-03
     +,   1.3860235E-03,   1.4330671E-03,   1.4781140E-03
     +,   1.5213342E-03,   1.5631218E-03,   1.6041280E-03
     +,   1.6452819E-03,   1.6878077E-03,   1.7332372E-03
     +,   1.7834011E-03,   1.8404011E-03,   1.9065377E-03
     +,   1.9842046E-03,   2.0757467E-03,   2.1832318E-03
     +,   2.3082010E-03,   2.4513868E-03,   2.6124818E-03
     +,   2.7899481E-03,   2.9809782E-03,   3.1817178E-03
     +,   3.3876966E-03,   3.5944921E-03,   3.7986171E-03
     +,   3.9984351E-03,   4.1948715E-03,   4.3917578E-03
     +,   4.5956257E-03,   4.8148585E-03,   5.0582010E-03
     +,   5.3330450E-03,   5.6437911E-03,   5.9908940E-03
     +,   6.3707791E-03,   6.7767221E-03,   7.2005969E-03
     +,   7.6348116E-03,   8.0741094E-03,   8.5172011E-03
     +,   8.9680562E-03,   9.4365031E-03,   9.9375714E-03
     +,   1.0488085E-02,   1.1099927E-02,   1.1771304E-02
     +,   1.2479937E-02,   1.3184422E-02,   1.3836370E-02
     +,   1.4399898E-02,   1.4867879E-02,   1.5264261E-02
     +,   1.5630189E-02,   1.6003815E-02,   1.6408710E-02
     +,   1.6856730E-02,   1.7356902E-02,   1.7916508E-02
     +,   1.8529737E-02,   1.9163791E-02,   1.9756991E-02
     +,   2.0236632E-02,   2.0551017E-02,   2.0699352E-02
     +,   2.0739816E-02,   2.0768331E-02,   2.0876842E-02
     +,   2.1113612E-02,   2.1460846E-02,   2.1834925E-02
     +,   2.2106888E-02,   2.2137832E-02,   2.1818843E-02
     +,   2.1101905E-02,   2.0011432E-02,   1.8632855E-02
     +,   1.7083356E-02,   1.5476911E-02,   1.3899774E-02
     +,   1.2404203E-02,   1.1017788E-02,   9.7548161E-03
     +,   8.6221742E-03,   7.6181944E-03,   6.7313462E-03
     +,   5.9422078E-03,   5.2297865E-03,   4.5776065E-03
     +,   3.9770938E-03,   3.4269572E-03,   2.9299040E-03
     +,   2.4892048E-03,   2.1061257E-03,   1.7791168E-03
     +,   1.5039804E-03,   1.2748467E-03,   1.0850719E-03
     +,   9.2810183E-04,   7.9794088E-04,   6.8946142E-04
     +,   5.9842784E-04,   5.2147068E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt119 = Yx/0.222630434782609
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5133579E-05,   6.6728106E-05
     +,   6.8318033E-05,   6.9901515E-05,   7.1476759E-05
     +,   7.3041949E-05,   7.4595388E-05,   7.6135322E-05
     +,   7.7660086E-05,   7.9168109E-05,   8.0657817E-05
     +,   8.2127757E-05,   8.3576480E-05,   8.5002692E-05
     +,   8.6405125E-05,   8.7782631E-05,   8.9134155E-05
     +,   9.0458714E-05,   9.1755399E-05,   9.3023482E-05
     +,   9.4262279E-05,   9.5471230E-05,   9.6649819E-05
     +,   9.7797769E-05,   9.8914745E-05,   1.0000066E-04
     +,   1.0105544E-04,   1.0207912E-04,   1.0307191E-04
     +,   1.0403396E-04,   1.0496566E-04,   1.0586744E-04
     +,   1.0673976E-04,   1.0758326E-04,   1.0839856E-04
     +,   1.0918640E-04,   1.0994754E-04,   1.1068288E-04
     +,   1.1139329E-04,   1.1207969E-04,   1.1274312E-04
     +,   1.1338458E-04,   1.1400513E-04,   1.1460585E-04
     +,   1.1518787E-04,   1.1575222E-04,   1.1630008E-04
     +,   1.1683261E-04,   1.1735089E-04,   1.1785605E-04
     +,   1.1834922E-04,   1.1883149E-04,   1.1930396E-04
     +,   1.1976769E-04,   1.2022374E-04,   1.2067312E-04
     +,   1.2111682E-04,   1.2155584E-04,   1.2199108E-04
     +,   1.2242347E-04,   1.2285385E-04,   1.2328305E-04
     +,   1.2371187E-04,   1.2414106E-04,   1.2457139E-04
     +,   1.2500347E-04,   1.2543793E-04,   1.2587538E-04
     +,   1.2631637E-04,   1.2676137E-04,   1.2721089E-04
     +,   1.2766529E-04,   1.2812502E-04,   1.2859034E-04
     +,   1.2906150E-04,   1.2953889E-04,   1.3002257E-04
     +,   1.3051281E-04,   1.3100970E-04,   1.3151338E-04
     +,   1.3202381E-04,   1.3254120E-04,   1.3306546E-04
     +,   1.3359674E-04,   1.3413494E-04,   1.3468016E-04
     +,   1.3523240E-04,   1.3579179E-04,   1.3635843E-04
     +,   1.3693247E-04,   1.3751420E-04,   1.3810392E-04
     +,   1.3870207E-04,   1.3930927E-04,   1.3992617E-04
     +,   1.4055368E-04,   1.4119290E-04,   1.4184504E-04
     +,   1.4251180E-04,   1.4319476E-04,   1.4389609E-04
     +,   1.4461819E-04,   1.4536375E-04,   1.4613573E-04
     +,   1.4693754E-04,   1.4777301E-04,   1.4864623E-04
     +,   1.4956163E-04,   1.5052414E-04,   1.5153912E-04
     +,   1.5261197E-04,   1.5374881E-04,   1.5495576E-04
     +,   1.5623943E-04,   1.5760647E-04,   1.5906394E-04
     +,   1.6061874E-04,   1.6227803E-04,   1.6404883E-04
     +,   1.6593808E-04,   1.6795265E-04,   1.7009889E-04
     +,   1.7238288E-04,   1.7481018E-04,   1.7738593E-04
     +,   1.8011409E-04,   1.8299841E-04,   1.8604120E-04
     +,   1.8924418E-04,   1.9260762E-04,   1.9613102E-04
     +,   1.9981212E-04,   2.0364790E-04,   2.0763364E-04
     +,   2.1176357E-04,   2.1603062E-04,   2.2042607E-04
     +,   2.2494026E-04,   2.2956231E-04,   2.3428073E-04
     +,   2.3908238E-04,   2.4395391E-04,   2.4888132E-04
     +,   2.5385077E-04,   2.5884743E-04,   2.6385766E-04
     +,   2.6886805E-04,   2.7386573E-04,   2.7883938E-04
     +,   2.8377899E-04,   2.8867691E-04,   2.9352689E-04
     +,   2.9832573E-04,   3.0307312E-04,   3.0777202E-04
     +,   3.1242828E-04,   3.1705177E-04,   3.2165617E-04
     +,   3.2625941E-04,   3.3088270E-04,   3.3555180E-04
     +,   3.4029648E-04,   3.4515024E-04,   3.5014929E-04
     +,   3.5533396E-04,   3.6074713E-04,   3.6643347E-04
     +,   3.7243898E-04,   3.7881074E-04,   3.8559618E-04
     +,   3.9284091E-04,   4.0058876E-04,   4.0888146E-04
     +,   4.1775615E-04,   4.2724525E-04,   4.3737513E-04
     +,   4.4816636E-04,   4.5963060E-04,   4.7177219E-04
     +,   4.8458666E-04,   4.9806258E-04,   5.1217794E-04
     +,   5.2690471E-04,   5.4220745E-04,   5.5804866E-04
     +,   5.7438615E-04,   5.9118023E-04,   6.0839660E-04
     +,   6.2601251E-04,   6.4401922E-04,   6.6243322E-04
     +,   6.8130251E-04,   7.0071220E-04,   7.2079804E-04
     +,   7.4175303E-04,   7.6384057E-04,   7.8739790E-04
     +,   8.1284804E-04,   8.4070489E-04,   8.7157538E-04
     +,   9.0615422E-04,   9.4521762E-04,   9.8960893E-04
     +,   1.0402172E-03,   1.0979384E-03,   1.1636508E-03
     +,   1.2381742E-03,   1.3222283E-03,   1.4164099E-03
     +,   1.5211857E-03,   1.6368914E-03,   1.7637493E-03
     +,   1.9019097E-03,   2.0515041E-03,   2.2126662E-03
     +,   2.3855292E-03,   2.5701763E-03,   2.7665822E-03
     +,   2.9744480E-03,   3.1930397E-03,   3.4211131E-03
     +,   3.6568474E-03,   3.8979377E-03,   4.1418360E-03
     +,   4.3861265E-03,   4.6289214E-03,   4.8692096E-03
     +,   5.1070722E-03,   5.3437473E-03,   5.5814302E-03
     +,   5.8229771E-03,   6.0716751E-03,   6.3310373E-03
     +,   6.6047106E-03,   6.8962355E-03,   7.2087673E-03
     +,   7.5441566E-03,   7.9017449E-03,   8.2770791E-03
     +,   8.6616650E-03,   9.0446081E-03,   9.4169201E-03
     +,   9.7777788E-03,   1.0139898E-02,   1.0530079E-02
     +,   1.0981597E-02,   1.1519151E-02,   1.2142325E-02
     +,   1.2817037E-02,   1.3483220E-02,   1.4078707E-02
     +,   1.4568874E-02,   1.4966382E-02,   1.5329050E-02
     +,   1.5735850E-02,   1.6253235E-02,   1.6909029E-02
     +,   1.7685689E-02,   1.8533556E-02,   1.9393686E-02
     +,   2.0218033E-02,   2.0980110E-02,   2.1676309E-02
     +,   2.2320176E-02,   2.2928935E-02,   2.3501731E-02
     +,   2.3997488E-02,   2.4331657E-02,   2.4403993E-02
     +,   2.4145225E-02,   2.3549518E-02,   2.2669984E-02
     +,   2.1585353E-02,   2.0366207E-02,   1.9062435E-02
     +,   1.7709356E-02,   1.6337508E-02,   1.4976509E-02
     +,   1.3651335E-02,   1.2378344E-02,   1.1164117E-02
     +,   1.0009058E-02,   8.9122849E-03,   7.8760572E-03
     +,   6.9067581E-03,   6.0131573E-03,   5.2029253E-03
     +,   4.4799778E-03,   3.8436630E-03,   3.2894174E-03
     +,   2.8105720E-03,   2.3996276E-03,   2.0491951E-03
     +,   1.7521591E-03,   1.5017932E-03,   1.2916973E-03
     +,   1.1159565E-03,   9.6921343E-04,   8.4679981E-04
     +,   7.4471143E-04,   6.5957825E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt120 = Yx/0.227347826086957
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.9700181E-05,   9.1591151E-05
     +,   9.3488532E-05,   9.5394964E-05,   9.7314027E-05
     +,   9.9249992E-05,   1.0120819E-04,   1.0319499E-04
     +,   1.0521785E-04,   1.0728573E-04,   1.0940880E-04
     +,   1.1159894E-04,   1.1386965E-04,   1.1623625E-04
     +,   1.1871615E-04,   1.2132878E-04,   1.2409598E-04
     +,   1.2704203E-04,   1.3019392E-04,   1.3358137E-04
     +,   1.3723725E-04,   1.4119768E-04,   1.4550205E-04
     +,   1.5019382E-04,   1.5531978E-04,   1.6093113E-04
     +,   1.6708329E-04,   1.7383586E-04,   1.8125300E-04
     +,   1.8940316E-04,   1.9835928E-04,   2.0819815E-04
     +,   2.1900023E-04,   2.3084925E-04,   2.4383113E-04
     +,   2.5803345E-04,   2.7354402E-04,   2.9044962E-04
     +,   3.0883608E-04,   3.2878443E-04,   3.5037313E-04
     +,   3.7367424E-04,   3.9875513E-04,   4.2567673E-04
     +,   4.5449586E-04,   4.8526493E-04,   5.1803415E-04
     +,   5.5285514E-04,   5.8978150E-04,   6.2887417E-04
     +,   6.7020400E-04,   7.1385421E-04,   7.5992336E-04
     +,   8.0852909E-04,   8.5980236E-04,   9.1389433E-04
     +,   9.7096566E-04,   1.0311856E-03,   1.0947227E-03
     +,   1.1617370E-03,   1.2323705E-03,   1.3067374E-03
     +,   1.3849119E-03,   1.4669400E-03,   1.5528316E-03
     +,   1.6425736E-03,   1.7361663E-03,   1.8336384E-03
     +,   1.9351135E-03,   2.0408258E-03,   2.1511940E-03
     +,   2.2668284E-03,   2.3885753E-03,   2.5174916E-03
     +,   2.6548672E-03,   2.8022069E-03,   2.9612039E-03
     +,   3.1337810E-03,   3.3221212E-03,   3.5287186E-03
     +,   3.7563557E-03,   4.0081041E-03,   4.2870482E-03
     +,   4.5959982E-03,   4.9369270E-03,   5.3104861E-03
     +,   5.7155355E-03,   6.1492794E-03,   6.6075684E-03
     +,   7.0860181E-03,   7.5811408E-03,   8.0912085E-03
     +,   8.6165909E-03,   9.1589652E-03,   9.7198924E-03
     +,   1.0298965E-02,   1.0892752E-02,   1.1494277E-02
     +,   1.2093756E-02,   1.2679138E-02,   1.3236559E-02
     +,   1.3749664E-02,   1.4198944E-02,   1.4561551E-02
     +,   1.4813122E-02,   1.4931465E-02,   1.4901452E-02
     +,   1.4719312E-02,   1.4394687E-02,   1.3949252E-02
     +,   1.3412785E-02,   1.2817563E-02,   1.2193185E-02
     +,   1.1563000E-02,   1.0942727E-02,   1.0340790E-02
     +,   9.7601162E-03,   9.2000030E-03,   8.6582927E-03
     +,   8.1327893E-03,   7.6224846E-03,   7.1281535E-03
     +,   6.6523128E-03,   6.1988500E-03,   5.7722530E-03
     +,   5.3768391E-03,   5.0159101E-03,   4.6914751E-03
     +,   4.4040792E-03,   4.1530984E-03,   3.9370079E-03
     +,   3.7537739E-03,   3.6010116E-03,   3.4761077E-03
     +,   3.3761780E-03,   3.2980181E-03,   3.2381080E-03
     +,   3.1926944E-03,   3.1579367E-03,   3.1301405E-03
     +,   3.1059938E-03,   3.0827618E-03,   3.0583995E-03
     +,   3.0316145E-03,   3.0018315E-03,   2.9690885E-03
     +,   2.9338957E-03,   2.8970775E-03,   2.8596283E-03
     +,   2.8225549E-03,   2.7867714E-03,   2.7530224E-03
     +,   2.7218077E-03,   2.6933760E-03,   2.6677060E-03
     +,   2.6445366E-03,   2.6233855E-03,   2.6036110E-03
     +,   2.5844432E-03,   2.5650591E-03,   2.5446219E-03
     +,   2.5223331E-03,   2.4974861E-03,   2.4694845E-03
     +,   2.4378828E-03,   2.4023890E-03,   2.3628718E-03
     +,   2.3193604E-03,   2.2720222E-03,   2.2211501E-03
     +,   2.1671427E-03,   2.1104822E-03,   2.0517001E-03
     +,   1.9913621E-03,   1.9300543E-03,   1.8683473E-03
     +,   1.8067955E-03,   1.7459269E-03,   1.6862197E-03
     +,   1.6281109E-03,   1.5719761E-03,   1.5181467E-03
     +,   1.4668982E-03,   1.4184474E-03,   1.3729626E-03
     +,   1.3305675E-03,   1.2913453E-03,   1.2553355E-03
     +,   1.2225513E-03,   1.1929760E-03,   1.1665763E-03
     +,   1.1432953E-03,   1.1230692E-03,   1.1058231E-03
     +,   1.0914705E-03,   1.0799241E-03,   1.0710864E-03
     +,   1.0648561E-03,   1.0611220E-03,   1.0597656E-03
     +,   1.0606577E-03,   1.0636571E-03,   1.0686115E-03
     +,   1.0753522E-03,   1.0836992E-03,   1.0934591E-03
     +,   1.1044282E-03,   1.1163898E-03,   1.1291243E-03
     +,   1.1424051E-03,   1.1560089E-03,   1.1697115E-03
     +,   1.1832976E-03,   1.1965617E-03,   1.2093105E-03
     +,   1.2213681E-03,   1.2325738E-03,   1.2427868E-03
     +,   1.2518858E-03,   1.2597681E-03,   1.2663525E-03
     +,   1.2715710E-03,   1.2753762E-03,   1.2777320E-03
     +,   1.2786160E-03,   1.2780164E-03,   1.2759296E-03
     +,   1.2723601E-03,   1.2673159E-03,   1.2608103E-03
     +,   1.2528613E-03,   1.2434885E-03,   1.2327160E-03
     +,   1.2205695E-03,   1.2070807E-03,   1.1922844E-03
     +,   1.1762197E-03,   1.1589306E-03,   1.1404695E-03
     +,   1.1208901E-03,   1.1002555E-03,   1.0786336E-03
     +,   1.0560980E-03,   1.0327267E-03,   1.0086009E-03
     +,   9.8380737E-04,   9.5843419E-04,   9.3256996E-04
     +,   9.0630335E-04,   8.7972486E-04,   8.5292140E-04
     +,   8.2597631E-04,   7.9897291E-04,   7.7199115E-04
     +,   7.4510393E-04,   7.1838166E-04,   6.9189089E-04
     +,   6.6569407E-04,   6.3984771E-04,   6.1440340E-04
     +,   5.8941083E-04,   5.6491367E-04,   5.4095127E-04
     +,   5.1755860E-04,   4.9476750E-04,   4.7260566E-04
     +,   4.5109473E-04,   4.3025473E-04,   4.1010184E-04
     +,   3.9064660E-04,   3.7189628E-04,   3.5385534E-04
     +,   3.3652488E-04,   3.1990136E-04,   3.0397828E-04
     +,   2.8874722E-04,   2.7419571E-04,   2.6031016E-04
     +,   2.4707342E-04,   2.3446798E-04,   2.2247327E-04
     +,   2.1106923E-04,   2.0023287E-04,   1.8994235E-04
     +,   1.8017419E-04,   1.7090591E-04,   1.6211429E-04
     +,   1.5377645E-04,   1.4587081E-04,   1.3837549E-04
     +,   1.3127018E-04,   1.2453456E-04,   1.1815011E-04
     +,   1.1209826E-04,   1.0636223E-04,   1.0092553E-04
     +,   9.5773183E-05,   9.0890448E-05,   8.6264015E-05
     +,   8.1880848E-05,   7.7729186E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt75 = Yx/0.178022727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7231690E-05,   4.8423262E-05
     +,   4.9650156E-05,   5.0914554E-05,   5.2218697E-05
     +,   5.3564992E-05,   5.4955901E-05,   5.6394045E-05
     +,   5.7882091E-05,   5.9422924E-05,   6.1019447E-05
     +,   6.2674684E-05,   6.4391774E-05,   6.6173976E-05
     +,   6.8024616E-05,   6.9947171E-05,   7.1945266E-05
     +,   7.4022588E-05,   7.6183002E-05,   7.8430516E-05
     +,   8.0769394E-05,   8.3204002E-05,   8.5738982E-05
     +,   8.8379296E-05,   9.1130169E-05,   9.3997187E-05
     +,   9.6986383E-05,   1.0010415E-04,   1.0335750E-04
     +,   1.0675383E-04,   1.1030133E-04,   1.1400872E-04
     +,   1.1788541E-04,   1.2194156E-04,   1.2618800E-04
     +,   1.3063630E-04,   1.3529882E-04,   1.4018832E-04
     +,   1.4531866E-04,   1.5070356E-04,   1.5635777E-04
     +,   1.6229597E-04,   1.6853304E-04,   1.7508383E-04
     +,   1.8196295E-04,   1.8918472E-04,   1.9676262E-04
     +,   2.0470977E-04,   2.1303813E-04,   2.2175885E-04
     +,   2.3088217E-04,   2.4041730E-04,   2.5037269E-04
     +,   2.6075676E-04,   2.7157678E-04,   2.8284127E-04
     +,   2.9455897E-04,   3.0674023E-04,   3.1939740E-04
     +,   3.3254575E-04,   3.4620403E-04,   3.6039532E-04
     +,   3.7514689E-04,   3.9049255E-04,   4.0647213E-04
     +,   4.2313070E-04,   4.4052239E-04,   4.5870704E-04
     +,   4.7775620E-04,   4.9774902E-04,   5.1877991E-04
     +,   5.4095616E-04,   5.6440639E-04,   5.8927876E-04
     +,   6.1575149E-04,   6.4403279E-04,   6.7436352E-04
     +,   7.0701871E-04,   7.4230961E-04,   7.8057637E-04
     +,   8.2217588E-04,   8.6748274E-04,   9.1686333E-04
     +,   9.7067782E-04,   1.0292568E-03,   1.0929151E-03
     +,   1.1619426E-03,   1.2366428E-03,   1.3173476E-03
     +,   1.4044862E-03,   1.4986375E-03,   1.6005923E-03
     +,   1.7114186E-03,   1.8325225E-03,   1.9656671E-03
     +,   2.1129542E-03,   2.2768299E-03,   2.4599982E-03
     +,   2.6654298E-03,   2.8963003E-03,   3.1560757E-03
     +,   3.4484556E-03,   3.7774236E-03,   4.1469652E-03
     +,   4.5606601E-03,   5.0208247E-03,   5.5273171E-03
     +,   6.0762595E-03,   6.6588442E-03,   7.2607324E-03
     +,   7.8622997E-03,   8.4404340E-03,   8.9712590E-03
     +,   9.4341822E-03,   9.8158848E-03,   1.0113958E-02
     +,   1.0338495E-02,   1.0511152E-02,   1.0661050E-02
     +,   1.0818006E-02,   1.1004420E-02,   1.1228136E-02
     +,   1.1478620E-02,   1.1728200E-02,   1.1938481E-02
     +,   1.2070164E-02,   1.2093219E-02,   1.1993869E-02
     +,   1.1776459E-02,   1.1459874E-02,   1.1070685E-02
     +,   1.0635850E-02,   1.0177271E-02,   9.7098732E-03
     +,   9.2423158E-03,   8.7793330E-03,   8.3243577E-03
     +,   7.8811720E-03,   7.4546793E-03,   7.0510451E-03
     +,   6.6771335E-03,   6.3397815E-03,   6.0447282E-03
     +,   5.7955626E-03,   5.5928291E-03,   5.4334896E-03
     +,   5.3111678E-03,   5.2170372E-03,   5.1411693E-03
     +,   5.0740358E-03,   5.0077983E-03,   4.9370429E-03
     +,   4.8589269E-03,   4.7728196E-03,   4.6795644E-03
     +,   4.5807580E-03,   4.4780509E-03,   4.3727034E-03
     +,   4.2654304E-03,   4.1564736E-03,   4.0457291E-03
     +,   3.9330069E-03,   3.8182223E-03,   3.7015262E-03
     +,   3.5833374E-03,   3.4643349E-03,   3.3454041E-03
     +,   3.2275405E-03,   3.1117706E-03,   2.9990994E-03
     +,   2.8904770E-03,   2.7867695E-03,   2.6887376E-03
     +,   2.5970440E-03,   2.5122608E-03,   2.4348369E-03
     +,   2.3651174E-03,   2.3033265E-03,   2.2495815E-03
     +,   2.2038748E-03,   2.1660908E-03,   2.1360251E-03
     +,   2.1133830E-03,   2.0978004E-03,   2.0888515E-03
     +,   2.0860580E-03,   2.0888853E-03,   2.0967468E-03
     +,   2.1089863E-03,   2.1248776E-03,   2.1436119E-03
     +,   2.1642977E-03,   2.1859605E-03,   2.2075607E-03
     +,   2.2280223E-03,   2.2462590E-03,   2.2612193E-03
     +,   2.2719330E-03,   2.2775594E-03,   2.2774234E-03
     +,   2.2710559E-03,   2.2582095E-03,   2.2388774E-03
     +,   2.2132704E-03,   2.1818203E-03,   2.1451307E-03
     +,   2.1039480E-03,   2.0591072E-03,   2.0115022E-03
     +,   1.9620175E-03,   1.9115051E-03,   1.8607492E-03
     +,   1.8104394E-03,   1.7611549E-03,   1.7133537E-03
     +,   1.6673827E-03,   1.6234787E-03,   1.5817747E-03
     +,   1.5423177E-03,   1.5050862E-03,   1.4699963E-03
     +,   1.4369240E-03,   1.4057127E-03,   1.3761838E-03
     +,   1.3481473E-03,   1.3214089E-03,   1.2957738E-03
     +,   1.2710560E-03,   1.2470778E-03,   1.2236721E-03
     +,   1.2006898E-03,   1.1779994E-03,   1.1554821E-03
     +,   1.1330399E-03,   1.1105931E-03,   1.0880765E-03
     +,   1.0654415E-03,   1.0426537E-03,   1.0196920E-03
     +,   9.9654531E-04,   9.7321178E-04,   9.4969769E-04
     +,   9.2601829E-04,   9.0219104E-04,   8.7823981E-04
     +,   8.5419364E-04,   8.3008507E-04,   8.0595014E-04
     +,   7.8182615E-04,   7.5775699E-04,   7.3378620E-04
     +,   7.0995843E-04,   6.8632216E-04,   6.6292495E-04
     +,   6.3981337E-04,   6.1703188E-04,   5.9462449E-04
     +,   5.7263160E-04,   5.5108865E-04,   5.3002668E-04
     +,   5.0947245E-04,   4.8944814E-04,   4.6996851E-04
     +,   4.5104310E-04,   4.3267905E-04,   4.1487592E-04
     +,   3.9762960E-04,   3.8093343E-04,   3.6477772E-04
     +,   3.4914978E-04,   3.3403467E-04,   3.1941809E-04
     +,   3.0528480E-04,   2.9161907E-04,   2.7840544E-04
     +,   2.6563072E-04,   2.5328112E-04,   2.4134557E-04
     +,   2.2981284E-04,   2.1867441E-04,   2.0792164E-04
     +,   1.9754829E-04,   1.8754782E-04,   1.7791582E-04
     +,   1.6864714E-04,   1.5973829E-04,   1.5118510E-04
     +,   1.4298350E-04,   1.3512993E-04,   1.2761964E-04
     +,   1.2044847E-04,   1.1361068E-04,   1.0710106E-04
     +,   1.0091268E-04,   9.5038951E-05,   8.9471796E-05
     +,   8.4203297E-05,   7.9224228E-05,   7.4525487E-05
     +,   7.0096918E-05,   6.5928543E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt80 = Yx/0.163545454545455
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1434672E-04,   1.1682339E-04
     +,   1.1924173E-04,   1.2159725E-04,   1.2388594E-04
     +,   1.2610396E-04,   1.2824773E-04,   1.3031423E-04
     +,   1.3230061E-04,   1.3420454E-04,   1.3602391E-04
     +,   1.3775715E-04,   1.3940308E-04,   1.4096091E-04
     +,   1.4243029E-04,   1.4381127E-04,   1.4510435E-04
     +,   1.4631040E-04,   1.4743075E-04,   1.4846702E-04
     +,   1.4942131E-04,   1.5029608E-04,   1.5109405E-04
     +,   1.5181831E-04,   1.5247226E-04,   1.5305958E-04
     +,   1.5358413E-04,   1.5405023E-04,   1.5446213E-04
     +,   1.5482445E-04,   1.5514203E-04,   1.5541977E-04
     +,   1.5566281E-04,   1.5587638E-04,   1.5606594E-04
     +,   1.5623703E-04,   1.5639537E-04,   1.5654688E-04
     +,   1.5669769E-04,   1.5685409E-04,   1.5702263E-04
     +,   1.5721018E-04,   1.5742402E-04,   1.5767159E-04
     +,   1.5796100E-04,   1.5830083E-04,   1.5870016E-04
     +,   1.5916882E-04,   1.5971728E-04,   1.6035707E-04
     +,   1.6110037E-04,   1.6196062E-04,   1.6295223E-04
     +,   1.6409106E-04,   1.6539401E-04,   1.6687972E-04
     +,   1.6856827E-04,   1.7048155E-04,   1.7264306E-04
     +,   1.7507837E-04,   1.7781508E-04,   1.8088293E-04
     +,   1.8431361E-04,   1.8814160E-04,   1.9240359E-04
     +,   1.9713849E-04,   2.0238802E-04,   2.0819597E-04
     +,   2.1460916E-04,   2.2167552E-04,   2.2944644E-04
     +,   2.3797380E-04,   2.4731219E-04,   2.5751590E-04
     +,   2.6864064E-04,   2.8074189E-04,   2.9387357E-04
     +,   3.0808765E-04,   3.2343395E-04,   3.3995876E-04
     +,   3.5770179E-04,   3.7669879E-04,   3.9697599E-04
     +,   4.1855362E-04,   4.4143962E-04,   4.6563440E-04
     +,   4.9112341E-04,   5.1788316E-04,   5.4587272E-04
     +,   5.7504029E-04,   6.0531951E-04,   6.3662726E-04
     +,   6.6886522E-04,   7.0192345E-04,   7.3567830E-04
     +,   7.6999184E-04,   8.0472301E-04,   8.3972223E-04
     +,   8.7484723E-04,   9.0996333E-04,   9.4496354E-04
     +,   9.7977230E-04,   1.0143731E-03,   1.0488192E-03
     +,   1.0832617E-03,   1.1179706E-03,   1.1533551E-03
     +,   1.1899844E-03,   1.2286042E-03,   1.2701364E-03
     +,   1.3156650E-03,   1.3664188E-03,   1.4237068E-03
     +,   1.4888716E-03,   1.5631856E-03,   1.6477942E-03
     +,   1.7436220E-03,   1.8513649E-03,   1.9714874E-03
     +,   2.1043420E-03,   2.2503270E-03,   2.4100884E-03
     +,   2.5847489E-03,   2.7760731E-03,   2.9864653E-03
     +,   3.2187530E-03,   3.4758148E-03,   3.7599152E-03
     +,   4.0721088E-03,   4.4116103E-03,   4.7756345E-03
     +,   5.1595164E-03,   5.5574877E-03,   5.9635630E-03
     +,   6.3727181E-03,   6.7815604E-03,   7.1884007E-03
     +,   7.5926208E-03,   7.9933163E-03,   8.3878646E-03
     +,   8.7706679E-03,   9.1331117E-03,   9.4646439E-03
     +,   9.7548803E-03,   9.9962261E-03,   1.0185990E-02
     +,   1.0327094E-02,   1.0426871E-02,   1.0494291E-02
     +,   1.0536254E-02,   1.0554575E-02,   1.0544523E-02
     +,   1.0495994E-02,   1.0396744E-02,   1.0236642E-02
     +,   1.0011731E-02,   9.7264703E-03,   9.3935961E-03
     +,   9.0318788E-03,   8.6624585E-03,   8.3049042E-03
     +,   7.9741180E-03,   7.6786689E-03,   7.4206842E-03
     +,   7.1968897E-03,   7.0005814E-03,   6.8236869E-03
     +,   6.6584847E-03,   6.4987889E-03,   6.3404865E-03
     +,   6.1814524E-03,   6.0211127E-03,   5.8597540E-03
     +,   5.6979386E-03,   5.5360496E-03,   5.3740526E-03
     +,   5.2115172E-03,   5.0478680E-03,   4.8826840E-03
     +,   4.7160084E-03,   4.5485692E-03,   4.3818667E-03
     +,   4.2180689E-03,   4.0597632E-03,   3.9096610E-03
     +,   3.7702778E-03,   3.6436543E-03,   3.5311712E-03
     +,   3.4334750E-03,   3.3505009E-03,   3.2815617E-03
     +,   3.2254665E-03,   3.1807134E-03,   3.1456216E-03
     +,   3.1184657E-03,   3.0975917E-03,   3.0815005E-03
     +,   3.0688867E-03,   3.0586580E-03,   3.0499375E-03
     +,   3.0420152E-03,   3.0343300E-03,   3.0263923E-03
     +,   3.0177594E-03,   3.0079852E-03,   2.9965991E-03
     +,   2.9830884E-03,   2.9669085E-03,   2.9475123E-03
     +,   2.9243536E-03,   2.8969462E-03,   2.8648910E-03
     +,   2.8279063E-03,   2.7858559E-03,   2.7387701E-03
     +,   2.6868547E-03,   2.6304866E-03,   2.5701975E-03
     +,   2.5066570E-03,   2.4406416E-03,   2.3729929E-03
     +,   2.3045784E-03,   2.2362536E-03,   2.1688133E-03
     +,   2.1029585E-03,   2.0392642E-03,   1.9781741E-03
     +,   1.9199764E-03,   1.8648133E-03,   1.8126846E-03
     +,   1.7634850E-03,   1.7170109E-03,   1.6729952E-03
     +,   1.6311384E-03,   1.5911312E-03,   1.5526757E-03
     +,   1.5155039E-03,   1.4793901E-03,   1.4441530E-03
     +,   1.4096547E-03,   1.3758012E-03,   1.3425304E-03
     +,   1.3098083E-03,   1.2776157E-03,   1.2459401E-03
     +,   1.2147728E-03,   1.1841019E-03,   1.1539077E-03
     +,   1.1241604E-03,   1.0948287E-03,   1.0658719E-03
     +,   1.0372484E-03,   1.0089178E-03,   9.8084437E-04
     +,   9.5299893E-04,   9.2535757E-04,   8.9791109E-04
     +,   8.7065942E-04,   8.4361108E-04,   8.1678404E-04
     +,   7.9020608E-04,   7.6390954E-04,   7.3793094E-04
     +,   7.1230711E-04,   6.8707805E-04,   6.6227920E-04
     +,   6.3794304E-04,   6.1409862E-04,   5.9077004E-04
     +,   5.6797377E-04,   5.4572069E-04,   5.2401720E-04
     +,   5.0286471E-04,   4.8225827E-04,   4.6218946E-04
     +,   4.4264857E-04,   4.2362165E-04,   4.0509555E-04
     +,   3.8705472E-04,   3.6948681E-04,   3.5237739E-04
     +,   3.3571658E-04,   3.1949405E-04,   3.0370423E-04
     +,   2.8834119E-04,   2.7340403E-04,   2.5889216E-04
     +,   2.4480693E-04,   2.3115326E-04,   2.1793494E-04
     +,   2.0515879E-04,   1.9283028E-04,   1.8095650E-04
     +,   1.6954282E-04,   1.5859510E-04,   1.4811692E-04
     +,   1.3811170E-04,   1.2858017E-04,   1.1952239E-04
     +,   1.1093538E-04,   1.0281544E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt85 = Yx/0.159046511627907
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.8086945E-05,   8.1372440E-05
     +,   8.4753941E-05,   8.8230045E-05,   9.1798916E-05
     +,   9.5458396E-05,   9.9205834E-05,   1.0303823E-04
     +,   1.0695204E-04,   1.1094364E-04,   1.1500867E-04
     +,   1.1914261E-04,   1.2334048E-04,   1.2759698E-04
     +,   1.3190665E-04,   1.3626362E-04,   1.4066193E-04
     +,   1.4509536E-04,   1.4955761E-04,   1.5404228E-04
     +,   1.5854312E-04,   1.6305373E-04,   1.6756792E-04
     +,   1.7207976E-04,   1.7658329E-04,   1.8107313E-04
     +,   1.8554412E-04,   1.8999141E-04,   1.9441072E-04
     +,   1.9879815E-04,   2.0315043E-04,   2.0746468E-04
     +,   2.1173857E-04,   2.1597036E-04,   2.2015889E-04
     +,   2.2430338E-04,   2.2840366E-04,   2.3245983E-04
     +,   2.3647264E-04,   2.4044272E-04,   2.4437153E-04
     +,   2.4825986E-04,   2.5210943E-04,   2.5592127E-04
     +,   2.5969654E-04,   2.6343600E-04,   2.6714025E-04
     +,   2.7080908E-04,   2.7444202E-04,   2.7803783E-04
     +,   2.8159452E-04,   2.8510918E-04,   2.8857810E-04
     +,   2.9199698E-04,   2.9536002E-04,   2.9866092E-04
     +,   3.0189246E-04,   3.0504636E-04,   3.0811387E-04
     +,   3.1108531E-04,   3.1395062E-04,   3.1669924E-04
     +,   3.1932027E-04,   3.2180306E-04,   3.2413672E-04
     +,   3.2631072E-04,   3.2831504E-04,   3.3014073E-04
     +,   3.3177919E-04,   3.3322338E-04,   3.3446739E-04
     +,   3.3550686E-04,   3.3633935E-04,   3.3696415E-04
     +,   3.3738240E-04,   3.3759794E-04,   3.3761642E-04
     +,   3.3744602E-04,   3.3709744E-04,   3.3658397E-04
     +,   3.3592139E-04,   3.3512813E-04,   3.3422557E-04
     +,   3.3323743E-04,   3.3219054E-04,   3.3111413E-04
     +,   3.3004073E-04,   3.2900527E-04,   3.2804598E-04
     +,   3.2720380E-04,   3.2652274E-04,   3.2605021E-04
     +,   3.2583674E-04,   3.2593653E-04,   3.2640735E-04
     +,   3.2731125E-04,   3.2871438E-04,   3.3068782E-04
     +,   3.3330763E-04,   3.3665591E-04,   3.4082055E-04
     +,   3.4589611E-04,   3.5198423E-04,   3.5919363E-04
     +,   3.6763988E-04,   3.7744603E-04,   3.8874085E-04
     +,   4.0165760E-04,   4.1633344E-04,   4.3290819E-04
     +,   4.5151700E-04,   4.7229428E-04,   4.9536425E-04
     +,   5.2084343E-04,   5.4883247E-04,   5.7942083E-04
     +,   6.1267836E-04,   6.4866559E-04,   6.8742689E-04
     +,   7.2900479E-04,   7.7344541E-04,   8.2080608E-04
     +,   8.7116909E-04,   9.2466245E-04,   9.8146906E-04
     +,   1.0418351E-03,   1.1060869E-03,   1.1746172E-03
     +,   1.2478889E-03,   1.3263862E-03,   1.4105927E-03
     +,   1.5009065E-03,   1.5976045E-03,   1.7007461E-03
     +,   1.8101545E-03,   1.9254053E-03,   2.0458696E-03
     +,   2.1708545E-03,   2.2998115E-03,   2.4326101E-03
     +,   2.5698091E-03,   2.7129450E-03,   2.8647119E-03
     +,   3.0289756E-03,   3.2105602E-03,   3.4148504E-03
     +,   3.6471433E-03,   3.9118277E-03,   4.2115841E-03
     +,   4.5467135E-03,   4.9147210E-03,   5.3103212E-03
     +,   5.7260771E-03,   6.1534890E-03,   6.5844022E-03
     +,   7.0123547E-03,   7.4335355E-03,   7.8468816E-03
     +,   8.2530091E-03,   8.6521516E-03,   9.0418104E-03
     +,   9.4144233E-03,   9.7563155E-03,   1.0048187E-02
     +,   1.0267506E-02,   1.0392227E-02,   1.0405109E-02
     +,   1.0297689E-02,   1.0072910E-02,   9.7457031E-03
     +,   9.3414392E-03,   8.8925548E-03,   8.4340833E-03
     +,   7.9991221E-03,   7.6151807E-03,   7.3016416E-03
     +,   7.0688478E-03,   6.9182282E-03,   6.8433182E-03
     +,   6.8312981E-03,   6.8650297E-03,   6.9252676E-03
     +,   6.9929725E-03,   7.0515363E-03,   7.0883404E-03
     +,   7.0956037E-03,   7.0703425E-03,   7.0135393E-03
     +,   6.9289091E-03,   6.8215081E-03,   6.6965488E-03
     +,   6.5585715E-03,   6.4110821E-03,   6.2566036E-03
     +,   6.0969270E-03,   5.9334678E-03,   5.7676812E-03
     +,   5.6010839E-03,   5.4352949E-03,   5.2718343E-03
     +,   5.1119830E-03,   4.9566291E-03,   4.8062881E-03
     +,   4.6612062E-03,   4.5215641E-03,   4.3875836E-03
     +,   4.2596292E-03,   4.1381824E-03,   4.0237559E-03
     +,   3.9167609E-03,   3.8174163E-03,   3.7257234E-03
     +,   3.6414822E-03,   3.5643580E-03,   3.4939907E-03
     +,   3.4300617E-03,   3.3723307E-03,   3.3206164E-03
     +,   3.2747111E-03,   3.2342935E-03,   3.1988064E-03
     +,   3.1673503E-03,   3.1386542E-03,   3.1110710E-03
     +,   3.0826482E-03,   3.0512733E-03,   3.0148320E-03
     +,   2.9714042E-03,   2.9194281E-03,   2.8578595E-03
     +,   2.7862515E-03,   2.7047968E-03,   2.6142772E-03
     +,   2.5159908E-03,   2.4116351E-03,   2.3031465E-03
     +,   2.1925515E-03,   2.0818443E-03,   1.9728639E-03
     +,   1.8672036E-03,   1.7661700E-03,   1.6707646E-03
     +,   1.5816850E-03,   1.4993426E-03,   1.4239016E-03
     +,   1.3553260E-03,   1.2934140E-03,   1.2378327E-03
     +,   1.1881581E-03,   1.1439044E-03,   1.1045408E-03
     +,   1.0695138E-03,   1.0382670E-03,   1.0102448E-03
     +,   9.8490925E-04,   9.6174394E-04,   9.4026735E-04
     +,   9.2003646E-04,   9.0064836E-04,   8.8174798E-04
     +,   8.6302956E-04,   8.4423821E-04,   8.2516734E-04
     +,   8.0565811E-04,   7.8559964E-04,   7.6492247E-04
     +,   7.4359548E-04,   7.2162342E-04,   6.9904246E-04
     +,   6.7591085E-04,   6.5230933E-04,   6.2833651E-04
     +,   6.0410093E-04,   5.7971926E-04,   5.5531121E-04
     +,   5.3099950E-04,   5.0690043E-04,   4.8312912E-04
     +,   4.5978930E-04,   4.3697897E-04,   4.1478212E-04
     +,   3.9327459E-04,   3.7251707E-04,   3.5256101E-04
     +,   3.3344305E-04,   3.1519076E-04,   2.9781883E-04
     +,   2.8133197E-04,   2.6572720E-04,   2.5099129E-04
     +,   2.3710585E-04,   2.2404468E-04,   2.1177855E-04
     +,   2.0027255E-04,   1.8949062E-04,   1.7939328E-04
     +,   1.6994141E-04,   1.6109433E-04,   1.5281267E-04
     +,   1.4505693E-04,   1.3778989E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt90 = Yx/0.152372093023256
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7971724E-05,   4.9993552E-05
     +,   5.2079558E-05,   5.4229782E-05,   5.6444056E-05
     +,   5.8722031E-05,   6.1063140E-05,   6.3466585E-05
     +,   6.5931279E-05,   6.8456080E-05,   7.1039423E-05
     +,   7.3679555E-05,   7.6374468E-05,   7.9121877E-05
     +,   8.1919294E-05,   8.4763931E-05,   8.7652799E-05
     +,   9.0582624E-05,   9.3549919E-05,   9.6551041E-05
     +,   9.9582066E-05,   1.0263902E-04,   1.0571753E-04
     +,   1.0881347E-04,   1.1192220E-04,   1.1503930E-04
     +,   1.1816020E-04,   1.2128027E-04,   1.2439497E-04
     +,   1.2749981E-04,   1.3059036E-04,   1.3366231E-04
     +,   1.3671153E-04,   1.3973411E-04,   1.4272633E-04
     +,   1.4568472E-04,   1.4860615E-04,   1.5148771E-04
     +,   1.5432702E-04,   1.5712174E-04,   1.5987029E-04
     +,   1.6257119E-04,   1.6522348E-04,   1.6782650E-04
     +,   1.7038005E-04,   1.7288433E-04,   1.7533985E-04
     +,   1.7774747E-04,   1.8010839E-04,   1.8242408E-04
     +,   1.8469633E-04,   1.8692709E-04,   1.8911838E-04
     +,   1.9127266E-04,   1.9339206E-04,   1.9547911E-04
     +,   1.9753608E-04,   1.9956530E-04,   2.0156888E-04
     +,   2.0354884E-04,   2.0550699E-04,   2.0744497E-04
     +,   2.0936393E-04,   2.1126500E-04,   2.1314887E-04
     +,   2.1501583E-04,   2.1686616E-04,   2.1869953E-04
     +,   2.2051555E-04,   2.2231347E-04,   2.2409274E-04
     +,   2.2585220E-04,   2.2759126E-04,   2.2930896E-04
     +,   2.3100489E-04,   2.3267891E-04,   2.3433135E-04
     +,   2.3596315E-04,   2.3757621E-04,   2.3917327E-04
     +,   2.4075819E-04,   2.4233652E-04,   2.4391482E-04
     +,   2.4550146E-04,   2.4710671E-04,   2.4874267E-04
     +,   2.5042368E-04,   2.5216592E-04,   2.5398794E-04
     +,   2.5591062E-04,   2.5795714E-04,   2.6015259E-04
     +,   2.6252455E-04,   2.6510240E-04,   2.6791776E-04
     +,   2.7100387E-04,   2.7439554E-04,   2.7812898E-04
     +,   2.8224193E-04,   2.8677232E-04,   2.9175964E-04
     +,   2.9724310E-04,   3.0326276E-04,   3.0985806E-04
     +,   3.1706863E-04,   3.2493382E-04,   3.3349163E-04
     +,   3.4277930E-04,   3.5283301E-04,   3.6368778E-04
     +,   3.7537562E-04,   3.8792731E-04,   4.0136953E-04
     +,   4.1572712E-04,   4.3101815E-04,   4.4725821E-04
     +,   4.6445426E-04,   4.8260833E-04,   5.0171214E-04
     +,   5.2175007E-04,   5.4269587E-04,   5.6451221E-04
     +,   5.8715104E-04,   6.1055436E-04,   6.3465553E-04
     +,   6.5937883E-04,   6.8464677E-04,   7.1037794E-04
     +,   7.3650095E-04,   7.6295069E-04,   7.8968657E-04
     +,   8.1669260E-04,   8.4399281E-04,   8.7165734E-04
     +,   8.9981838E-04,   9.2867628E-04,   9.5851277E-04
     +,   9.8969834E-04,   1.0227013E-03,   1.0580939E-03
     +,   1.0965453E-03,   1.1388169E-03,   1.1857470E-03
     +,   1.2382197E-03,   1.2971144E-03,   1.3632539E-03
     +,   1.4373307E-03,   1.5198083E-03,   1.6108409E-03
     +,   1.7101893E-03,   1.8171442E-03,   1.9304861E-03
     +,   2.0484806E-03,   2.1689581E-03,   2.2893960E-03
     +,   2.4070907E-03,   2.5193573E-03,   2.6237711E-03
     +,   2.7183986E-03,   2.8019906E-03,   2.8741898E-03
     +,   2.9356179E-03,   2.9879420E-03,   3.0338229E-03
     +,   3.0768155E-03,   3.1211346E-03,   3.1713753E-03
     +,   3.2321119E-03,   3.3074936E-03,   3.4008361E-03
     +,   3.5142957E-03,   3.6488005E-03,   3.8042553E-03
     +,   3.9801514E-03,   4.1764476E-03,   4.3947170E-03
     +,   4.6390118E-03,   4.9162637E-03,   5.2357339E-03
     +,   5.6074983E-03,   6.0401103E-03,   6.5382719E-03
     +,   7.1014068E-03,   7.7239149E-03,   8.3969226E-03
     +,   9.1106575E-03,   9.8556001E-03,   1.0621410E-02
     +,   1.1393180E-02,   1.2147561E-02,   1.2851824E-02
     +,   1.3467578E-02,   1.3959053E-02,   1.4302326E-02
     +,   1.4490855E-02,   1.4534188E-02,   1.4450569E-02
     +,   1.4258165E-02,   1.3969586E-02,   1.3592940E-02
     +,   1.3137507E-02,   1.2619530E-02,   1.2063641E-02
     +,   1.1499541E-02,   1.0955888E-02,   1.0455134E-02
     +,   1.0011504E-02,   9.6311802E-03,   9.3132593E-03
     +,   9.0501430E-03,   8.8278186E-03,   8.6270189E-03
     +,   8.4258337E-03,   8.2036546E-03,   7.9451622E-03
     +,   7.6430775E-03,   7.2989226E-03,   6.9217272E-03
     +,   6.5253456E-03,   6.1253239E-03,   5.7358542E-03
     +,   5.3677587E-03,   5.0276243E-03,   4.7179786E-03
     +,   4.4382159E-03,   4.1859457E-03,   3.9582471E-03
     +,   3.7525061E-03,   3.5668423E-03,   3.4000871E-03
     +,   3.2515209E-03,   3.1204855E-03,   3.0060385E-03
     +,   2.9067798E-03,   2.8208308E-03,   2.7459268E-03
     +,   2.6796339E-03,   2.6195683E-03,   2.5635969E-03
     +,   2.5099665E-03,   2.4573784E-03,   2.4049713E-03
     +,   2.3522656E-03,   2.2990652E-03,   2.2453605E-03
     +,   2.1912404E-03,   2.1368219E-03,   2.0822037E-03
     +,   2.0274478E-03,   1.9725889E-03,   1.9176279E-03
     +,   1.8625548E-03,   1.8073631E-03,   1.7520565E-03
     +,   1.6966462E-03,   1.6411553E-03,   1.5856181E-03
     +,   1.5300715E-03,   1.4745467E-03,   1.4190726E-03
     +,   1.3636800E-03,   1.3083998E-03,   1.2532639E-03
     +,   1.1983167E-03,   1.1436202E-03,   1.0892538E-03
     +,   1.0353151E-03,   9.8192913E-04,   9.2923857E-04
     +,   8.7739964E-04,   8.2657865E-04,   7.7694957E-04
     +,   7.2868360E-04,   6.8194000E-04,   6.3686451E-04
     +,   5.9358747E-04,   5.5221084E-04,   5.1281758E-04
     +,   4.7545906E-04,   4.4016581E-04,   4.0693977E-04
     +,   3.7576442E-04,   3.4659950E-04,   3.1939169E-04
     +,   2.9407028E-04,   2.7055759E-04,   2.4876549E-04
     +,   2.2860133E-04,   2.0997216E-04,   1.9278160E-04
     +,   1.7693722E-04,   1.6234667E-04,   1.4892359E-04
     +,   1.3658355E-04,   1.2524870E-04,   1.1484447E-04
     +,   1.0530248E-04,   9.6557793E-05,   8.8551169E-05
     +,   8.1226448E-05,   7.4532538E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_htt95 = Yx/0.163767441860465
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5287690E-06,   1.6705892E-06
     +,   1.8225916E-06,   1.9851927E-06,   2.1587955E-06
     +,   2.3437856E-06,   2.5405268E-06,   2.7493584E-06
     +,   2.9705861E-06,   3.2044943E-06,   3.4513187E-06
     +,   3.7112595E-06,   3.9844695E-06,   4.2710544E-06
     +,   4.5710685E-06,   4.8845109E-06,   5.2113196E-06
     +,   5.5513742E-06,   5.9044892E-06,   6.2704148E-06
     +,   6.6488310E-06,   7.0393507E-06,   7.4415148E-06
     +,   7.8548173E-06,   8.2786391E-06,   8.7123417E-06
     +,   9.1551965E-06,   9.6064177E-06,   1.0065160E-05
     +,   1.0530531E-05,   1.1001585E-05,   1.1477336E-05
     +,   1.1956763E-05,   1.2438822E-05,   1.2922444E-05
     +,   1.3406557E-05,   1.3890091E-05,   1.4371984E-05
     +,   1.4851224E-05,   1.5326796E-05,   1.5797783E-05
     +,   1.6263313E-05,   1.6722599E-05,   1.7174953E-05
     +,   1.7619805E-05,   1.8056719E-05,   1.8485391E-05
     +,   1.8905697E-05,   1.9317678E-05,   1.9721574E-05
     +,   2.0117826E-05,   2.0507103E-05,   2.0890280E-05
     +,   2.1268512E-05,   2.1643140E-05,   2.2015794E-05
     +,   2.2388336E-05,   2.2762881E-05,   2.3141756E-05
     +,   2.3527542E-05,   2.3923008E-05,   2.4331135E-05
     +,   2.4755031E-05,   2.5197975E-05,   2.5663343E-05
     +,   2.6154537E-05,   2.6675043E-05,   2.7228240E-05
     +,   2.7817512E-05,   2.8446035E-05,   2.9116896E-05
     +,   2.9832852E-05,   3.0596468E-05,   3.1409869E-05
     +,   3.2274889E-05,   3.3192915E-05,   3.4164841E-05
     +,   3.5191024E-05,   3.6271387E-05,   3.7405323E-05
     +,   3.8591563E-05,   3.9828465E-05,   4.1113704E-05
     +,   4.2444608E-05,   4.3817901E-05,   4.5230056E-05
     +,   4.6677007E-05,   4.8154558E-05,   4.9658105E-05
     +,   5.1183015E-05,   5.2724579E-05,   5.4277934E-05
     +,   5.5838314E-05,   5.7401143E-05,   5.8962036E-05
     +,   6.0516672E-05,   6.2061212E-05,   6.3591913E-05
     +,   6.5105582E-05,   6.6599081E-05,   6.8069850E-05
     +,   6.9515438E-05,   7.0933784E-05,   7.2322946E-05
     +,   7.3681280E-05,   7.5007250E-05,   7.6299388E-05
     +,   7.7556251E-05,   7.8776568E-05,   7.9959020E-05
     +,   8.1102291E-05,   8.2205319E-05,   8.3267070E-05
     +,   8.4286985E-05,   8.5264895E-05,   8.6201529E-05
     +,   8.7098495E-05,   8.7959001E-05,   8.8788009E-05
     +,   8.9592846E-05,   9.0383764E-05,   9.1174523E-05
     +,   9.1982991E-05,   9.2831928E-05,   9.3749681E-05
     +,   9.4770738E-05,   9.5936542E-05,   9.7295917E-05
     +,   9.8905824E-05,   1.0083133E-04,   1.0314618E-04
     +,   1.0593228E-04,   1.0927984E-04,   1.1328580E-04
     +,   1.1805331E-04,   1.2368982E-04,   1.3030418E-04
     +,   1.3800403E-04,   1.4689265E-04,   1.5706493E-04
     +,   1.6860222E-04,   1.8156845E-04,   1.9600739E-04
     +,   2.1193892E-04,   2.2935570E-04,   2.4822640E-04
     +,   2.6849672E-04,   2.9009249E-04,   3.1292718E-04
     +,   3.3691083E-04,   3.6195695E-04,   3.8798543E-04
     +,   4.1492633E-04,   4.4271757E-04,   4.7129355E-04
     +,   5.0056638E-04,   5.3040619E-04,   5.6062406E-04
     +,   5.9095601E-04,   6.2106573E-04,   6.5058330E-04
     +,   6.7917421E-04,   7.0665329E-04,   7.3314400E-04
     +,   7.5925997E-04,   7.8627624E-04,   8.1623840E-04
     +,   8.5196306E-04,   8.9687045E-04,   9.5463503E-04
     +,   1.0286726E-03,   1.1215459E-03,   1.2343869E-03
     +,   1.3664166E-03,   1.5146302E-03,   1.6738120E-03
     +,   1.8369821E-03,   1.9965863E-03,   2.1466590E-03
     +,   2.2861625E-03,   2.4241030E-03,   2.5874386E-03
     +,   2.8298211E-03,   3.2323971E-03,   3.8910145E-03
     +,   4.9091736E-03,   6.4256904E-03,   8.6533604E-03
     +,   1.1839206E-02,   1.6064230E-02,   2.0883886E-02
     +,   2.5207447E-02,   2.8305583E-02,   3.1007532E-02
     +,   3.5070226E-02,   4.1224241E-02,   4.6485867E-02
     +,   4.6919830E-02,   4.3829538E-02,   4.0109396E-02
     +,   3.5915520E-02,   3.1014677E-02,   2.5957504E-02
     +,   2.1056121E-02,   1.6696928E-02,   1.3327706E-02
     +,   1.0943878E-02,   9.2767179E-03,   8.0809211E-03
     +,   7.1634278E-03,   6.3688192E-03,   5.5984971E-03
     +,   4.8235389E-03,   4.0700575E-03,   3.3844796E-03
     +,   2.8009345E-03,   2.3275698E-03,   1.9511168E-03
     +,   1.6489739E-03,   1.3996451E-03,   1.1878270E-03
     +,   1.0047969E-03,   8.4628840E-04,   7.1001379E-04
     +,   5.9402757E-04,   4.9609301E-04,   4.1370108E-04
     +,   3.4433280E-04,   2.8571920E-04,   2.3599058E-04
     +,   1.9369842E-04,   1.5775046E-04,   1.2731427E-04
     +,   1.0172796E-04,   8.0429258E-05,   6.2904328E-05
     +,   4.8667425E-05,   3.7255282E-05,   2.8229357E-05
     +,   2.1183079E-05,   1.5750282E-05,   1.1610391E-05
     +,   8.4897883E-06,   6.1606725E-06,   4.4379490E-06
     +,   3.1743336E-06,   2.2546087E-06,   1.5900081E-06
     +,   1.1131237E-06,   7.7335341E-07,   5.3300090E-07
     +,   3.6424618E-07,   2.4670575E-07,   1.6553115E-07
     +,   1.0997383E-07,   7.2312218E-08,   4.7041031E-08
     +,   3.0264363E-08,   1.9249851E-08,   1.2101299E-08
     +,   7.5169444E-09,   4.6128230E-09,   2.7958862E-09
     +,   1.6734771E-09,   9.8905772E-10,   5.7711952E-10
     +,   3.3242931E-10,   1.8901337E-10,   1.0607702E-10
     +,   5.8755792E-11,   3.2118152E-11,   1.7326461E-11
     +,   9.2240937E-12,   4.8458720E-12,   2.5121006E-12
     +,   1.2850908E-12,   6.4869930E-13,   3.2313930E-13
     +,   1.5884211E-13,   7.7057467E-14,   3.6893801E-14
     +,   1.7436615E-14,   8.1360835E-15,   3.7496200E-15
     +,   1.7076300E-15,   7.6919332E-16,   3.4316309E-16
     +,   1.5195726E-16,   6.7018497E-17,   2.9590077E-17
     +,   1.3179353E-17,   5.9831533E-18,   2.8041818E-18
     +,   1.3744813E-18,   7.1137228E-19,   3.8973819E-19
     +,   2.2484868E-19,   1.3516130E-19,   8.3657118E-20
     +,   5.2760862E-20,   3.3643798E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz100 = Yx/0.158720930232558
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0214272E-09,   2.4702513E-09
     +,   3.0153446E-09,   3.6766303E-09,   4.4779926E-09
     +,   5.4480274E-09,   6.6209171E-09,   8.0374667E-09
     +,   9.7462944E-09,   1.1805321E-08,   1.4283275E-08
     +,   1.7261682E-08,   2.0837041E-08,   2.5123342E-08
     +,   3.0254959E-08,   3.6389984E-08,   4.3713985E-08
     +,   5.2444232E-08,   6.2834594E-08,   7.5180942E-08
     +,   8.9827054E-08,   1.0717153E-07,   1.2767465E-07
     +,   1.5186849E-07,   1.8036143E-07,   2.1385357E-07
     +,   2.5314213E-07,   2.9913485E-07,   3.5286081E-07
     +,   4.1548245E-07,   4.8830805E-07,   5.7280420E-07
     +,   6.7060819E-07,   7.8353958E-07,   9.1361284E-07
     +,   1.0630464E-06,   1.2342726E-06,   1.4299407E-06
     +,   1.6529385E-06,   1.9063550E-06,   2.1935318E-06
     +,   2.5180107E-06,   2.8835450E-06,   3.2940802E-06
     +,   3.7537272E-06,   4.2667352E-06,   4.8374554E-06
     +,   5.4702987E-06,   6.1696792E-06,   6.9399584E-06
     +,   7.7853801E-06,   8.7099888E-06,   9.7175434E-06
     +,   1.0811505E-05,   1.1994753E-05,   1.3269756E-05
     +,   1.4638256E-05,   1.6101270E-05,   1.7658986E-05
     +,   1.9310657E-05,   2.1054540E-05,   2.2887838E-05
     +,   2.4806493E-05,   2.6805423E-05,   2.8878345E-05
     +,   3.1017575E-05,   3.3214503E-05,   3.5459114E-05
     +,   3.7740589E-05,   4.0046853E-05,   4.2365285E-05
     +,   4.4682289E-05,   4.6984071E-05,   4.9256214E-05
     +,   5.1484509E-05,   5.3654920E-05,   5.5753746E-05
     +,   5.7768051E-05,   5.9686092E-05,   6.1497478E-05
     +,   6.3193271E-05,   6.4766726E-05,   6.6213091E-05
     +,   6.7530207E-05,   6.8718495E-05,   6.9781287E-05
     +,   7.0724789E-05,   7.1558352E-05,   7.2294235E-05
     +,   7.2947798E-05,   7.3537180E-05,   7.4083109E-05
     +,   7.4608637E-05,   7.5138727E-05,   7.5699820E-05
     +,   7.6319135E-05,   7.7024197E-05,   7.7842029E-05
     +,   7.8798490E-05,   7.9917358E-05,   8.1219696E-05
     +,   8.2722843E-05,   8.4439976E-05,   8.6379019E-05
     +,   8.8542438E-05,   9.0926558E-05,   9.3521230E-05
     +,   9.6309624E-05,   9.9268582E-05,   1.0236865E-04
     +,   1.0557425E-04,   1.0884519E-04,   1.1213642E-04
     +,   1.1540035E-04,   1.1858696E-04,   1.2164610E-04
     +,   1.2452825E-04,   1.2718675E-04,   1.2957864E-04
     +,   1.3166666E-04,   1.3342053E-04,   1.3481812E-04
     +,   1.3584655E-04,   1.3650332E-04,   1.3679681E-04
     +,   1.3674660E-04,   1.3638381E-04,   1.3575095E-04
     +,   1.3490132E-04,   1.3389875E-04,   1.3281626E-04
     +,   1.3173514E-04,   1.3074343E-04,   1.2993439E-04
     +,   1.2940433E-04,   1.2925101E-04,   1.2957094E-04
     +,   1.3045716E-04,   1.3199662E-04,   1.3426770E-04
     +,   1.3733737E-04,   1.4125845E-04,   1.4606769E-04
     +,   1.5178337E-04,   1.5840305E-04,   1.6590311E-04
     +,   1.7423811E-04,   1.8334029E-04,   1.9312128E-04
     +,   2.0347536E-04,   2.1428229E-04,   2.2541177E-04
     +,   2.3673009E-04,   2.4810838E-04,   2.5943076E-04
     +,   2.7060261E-04,   2.8156149E-04,   2.9228794E-04
     +,   3.0281398E-04,   3.1322974E-04,   3.2369207E-04
     +,   3.3442563E-04,   3.4572199E-04,   3.5793433E-04
     +,   3.7146796E-04,   3.8676406E-04,   4.0427770E-04
     +,   4.2445297E-04,   4.4769631E-04,   4.7434564E-04
     +,   5.0464144E-04,   5.3870783E-04,   5.7654857E-04
     +,   6.1805721E-04,   6.6305348E-04,   7.1135745E-04
     +,   7.6288584E-04,   8.1776141E-04,   8.7643950E-04
     +,   9.3980401E-04,   1.0092026E-03,   1.0863818E-03
     +,   1.1733037E-03,   1.2718684E-03,   1.3836725E-03
     +,   1.5101770E-03,   1.6539143E-03,   1.8212587E-03
     +,   2.0265335E-03,   2.2959476E-03,   2.6696213E-03
     +,   3.2021601E-03,   3.9643086E-03,   5.0394651E-03
     +,   6.4921603E-03,   8.3030919E-03,   1.0338809E-02
     +,   1.2461238E-02,   1.4764485E-02,   1.7705947E-02
     +,   2.1872589E-02,   2.7270690E-02,   3.2817643E-02
     +,   3.7731688E-02,   4.2544916E-02,   4.6736803E-02
     +,   4.7884148E-02,   4.5058057E-02,   4.0521640E-02
     +,   3.5820119E-02,   2.9733216E-02,   2.2910243E-02
     +,   1.7378123E-02,   1.3669325E-02,   1.1189711E-02
     +,   9.2239100E-03,   7.4739759E-03,   6.0031759E-03
     +,   4.8754597E-03,   4.0248162E-03,   3.3473470E-03
     +,   2.7800661E-03,   2.2995200E-03,   1.8947634E-03
     +,   1.5539107E-03,   1.2644721E-03,   1.0167587E-03
     +,   8.0495916E-04,   6.2600680E-04,   4.7784724E-04
     +,   3.5818396E-04,   2.6399217E-04,   1.9163823E-04
     +,   1.3726953E-04,   9.7197226E-05,   6.8143774E-05
     +,   4.7369362E-05,   3.2685879E-05,   2.2405531E-05
     +,   1.5263051E-05,   1.0332292E-05,   6.9476509E-06
     +,   4.6369441E-06,   3.0684162E-06,   2.0106556E-06
     +,   1.3029245E-06,   8.3379757E-07,   5.2621544E-07
     +,   3.2708672E-07,   2.0001471E-07,   1.2019933E-07
     +,   7.0922695E-08,   4.1057238E-08,   2.3305173E-08
     +,   1.2964227E-08,   7.0646347E-09,   3.7701144E-09
     +,   1.9699113E-09,   1.0075779E-09,   5.0440840E-10
     +,   2.4712940E-10,   1.1849097E-10,   5.5594630E-11
     +,   2.5523585E-11,   1.1466369E-11,   5.0404581E-12
     +,   2.1680335E-12,   9.1250250E-13,   3.7584993E-13
     +,   1.5151170E-13,   5.9788925E-14,   2.3108246E-14
     +,   8.7566071E-15,   3.2600299E-15,   1.1975551E-15
     +,   4.3799430E-16,   1.6233078E-16,   6.2938863E-17
     +,   2.6733108E-17,   1.2990848E-17,   7.2916302E-18
     +,   4.5824507E-18,   3.0838974E-18,   2.1482488E-18
     +,   1.5192352E-18,   1.0804588E-18,   7.6941776E-19
     +,   5.4761993E-19,   3.8925158E-19,   2.7622916E-19
     +,   1.9568131E-19,   1.3836921E-19,   9.7665221E-20
     +,   6.8807837E-20,   4.8388221E-20,   3.3965193E-20
     +,   2.3797640E-20,   1.6642751E-20,   1.1617622E-20
     +,   8.0947160E-21,   5.6297331E-21
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz104 = Yx/0.150418604651163
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7122612E-13,   2.4215677E-13
     +,   3.4134113E-13,   4.7956528E-13,   6.7154458E-13
     +,   9.3727771E-13,   1.3038542E-12,   1.8078271E-12
     +,   2.4983338E-12,   3.4412210E-12,   4.7243594E-12
     +,   6.4645732E-12,   8.8166714E-12,   1.1984952E-11
     +,   1.6238141E-11,   2.1928237E-11,   2.9514731E-11
     +,   3.9595108E-11,   5.2943518E-11,   7.0558899E-11
     +,   9.3725888E-11,   1.2408964E-10,   1.6374883E-10
     +,   2.1537432E-10,   2.8234157E-10,   3.6891551E-10
     +,   4.8045118E-10,   6.2365085E-10,   8.0687157E-10
     +,   1.0404927E-09,   1.3373480E-09,   1.7132579E-09
     +,   2.1876294E-09,   2.7841922E-09,   3.5318248E-09
     +,   4.4655528E-09,   5.6276690E-09,   7.0690209E-09
     +,   8.8506233E-09,   1.1045059E-08,   1.3738791E-08
     +,   1.7034012E-08,   2.1051186E-08,   2.5931680E-08
     +,   3.1840806E-08,   3.8971013E-08,   4.7545523E-08
     +,   5.7822220E-08,   7.0097883E-08,   8.4712894E-08
     +,   1.0205630E-07,   1.2257097E-07,   1.4675945E-07
     +,   1.7519264E-07,   2.0851164E-07,   2.4744287E-07
     +,   2.9280113E-07,   3.4550237E-07,   4.0657488E-07
     +,   4.7717270E-07,   5.5859107E-07,   6.5228704E-07
     +,   7.5989226E-07,   8.8325277E-07,   1.0244541E-06
     +,   1.1858390E-06,   1.3700833E-06,   1.5801983E-06
     +,   1.8196339E-06,   2.0922810E-06,   2.4026003E-06
     +,   2.7556184E-06,   3.1570855E-06,   3.6134509E-06
     +,   4.1320263E-06,   4.7210174E-06,   5.3895401E-06
     +,   6.1476699E-06,   7.0065257E-06,   7.9782103E-06
     +,   9.0756439E-06,   1.0312699E-05,   1.1703753E-05
     +,   1.3263799E-05,   1.5007803E-05,   1.6950766E-05
     +,   1.9106859E-05,   2.1489474E-05,   2.4110101E-05
     +,   2.6978327E-05,   3.0101019E-05,   3.3481509E-05
     +,   3.7119193E-05,   4.1009233E-05,   4.5141911E-05
     +,   4.9501839E-05,   5.4068703E-05,   5.8816084E-05
     +,   6.3712658E-05,   6.8721383E-05,   7.3801231E-05
     +,   7.8906589E-05,   8.3989406E-05,   8.8999048E-05
     +,   9.3884555E-05,   9.8595425E-05,   1.0308268E-04
     +,   1.0730053E-04,   1.1120787E-04,   1.1476925E-04
     +,   1.1795547E-04,   1.2074524E-04,   1.2312492E-04
     +,   1.2508959E-04,   1.2664251E-04,   1.2779528E-04
     +,   1.2856715E-04,   1.2898429E-04,   1.2907898E-04
     +,   1.2888838E-04,   1.2845331E-04,   1.2781704E-04
     +,   1.2702393E-04,   1.2611815E-04,   1.2514253E-04
     +,   1.2413759E-04,   1.2314042E-04,   1.2218436E-04
     +,   1.2129804E-04,   1.2050550E-04,   1.1982575E-04
     +,   1.1927301E-04,   1.1885685E-04,   1.1858270E-04
     +,   1.1845209E-04,   1.1846333E-04,   1.1861204E-04
     +,   1.1889169E-04,   1.1929415E-04,   1.1981023E-04
     +,   1.2042999E-04,   1.2114312E-04,   1.2193932E-04
     +,   1.2280828E-04,   1.2373977E-04,   1.2472381E-04
     +,   1.2575052E-04,   1.2681029E-04,   1.2789364E-04
     +,   1.2899164E-04,   1.3009645E-04,   1.3120161E-04
     +,   1.3230357E-04,   1.3340315E-04,   1.3450770E-04
     +,   1.3563375E-04,   1.3681030E-04,   1.3808293E-04
     +,   1.3951784E-04,   1.4120572E-04,   1.4326590E-04
     +,   1.4584887E-04,   1.4913679E-04,   1.5334199E-04
     +,   1.5870221E-04,   1.6547197E-04,   1.7390976E-04
     +,   1.8426352E-04,   1.9675508E-04,   2.1156557E-04
     +,   2.2882551E-04,   2.4861572E-04,   2.7098440E-04
     +,   2.9597949E-04,   3.2369973E-04,   3.5437249E-04
     +,   3.8843931E-04,   4.2664472E-04,   4.7011900E-04
     +,   5.2042690E-04,   5.7954498E-04,   6.4972893E-04
     +,   7.3324185E-04,   8.3194108E-04,   9.4678043E-04
     +,   1.0774265E-03,   1.2222943E-03,   1.3792537E-03
     +,   1.5469930E-03,   1.7266633E-03,   1.9231025E-03
     +,   2.1448168E-03,   2.4025931E-03,   2.7078784E-03
     +,   3.0739054E-03,   3.5225821E-03,   4.0933820E-03
     +,   4.8381868E-03,   5.7930732E-03,   6.9780122E-03
     +,   8.5192369E-03,   1.0772537E-02,   1.4025444E-02
     +,   1.7993333E-02,   2.2064749E-02,   2.6138106E-02
     +,   3.0600172E-02,   3.5114568E-02,   3.9687216E-02
     +,   4.3774895E-02,   4.4058740E-02,   3.9810590E-02
     +,   3.3982385E-02,   2.8336041E-02,   2.3056230E-02
     +,   1.8644096E-02,   1.5034888E-02,   1.2247641E-02
     +,   1.0391227E-02,   9.1266399E-03,   8.0205817E-03
     +,   6.8690092E-03,   5.6672646E-03,   4.4928943E-03
     +,   3.4289693E-03,   2.5289678E-03,   1.8096870E-03
     +,   1.2608313E-03,   8.5845630E-04,   5.7426339E-04
     +,   3.8034338E-04,   2.5173437E-04,   1.6800997E-04
     +,   1.1386289E-04,   7.8679419E-05,   5.5510820E-05
     +,   3.9963434E-05,   2.9291492E-05,   2.1775599E-05
     +,   1.6335514E-05,   1.2294160E-05,   9.2288847E-06
     +,   6.8744353E-06,   5.0597200E-06,   3.6680042E-06
     +,   2.6131745E-06,   1.8267760E-06,   1.2518389E-06
     +,   8.4040340E-07,   5.5253270E-07,   3.5568260E-07
     +,   2.2415342E-07,   1.3828834E-07,   8.3517413E-08
     +,   4.9374890E-08,   2.8573432E-08,   1.6186471E-08
     +,   8.9760341E-09,   4.8725055E-09,   2.5891047E-09
     +,   1.3467529E-09,   6.8577777E-10,   3.4185058E-10
     +,   1.6682165E-10,   7.9703300E-11,   3.7285612E-11
     +,   1.7080668E-11,   7.6647629E-12,   3.3708676E-12
     +,   1.4540617E-12,   6.1609360E-13,   2.5708079E-13
     +,   1.0613181E-13,   4.3690854E-14,   1.8170161E-14
     +,   7.7863792E-15,   3.5255987E-15,   1.7271611E-15
     +,   9.2530970E-16,   5.3777513E-16,   3.3205216E-16
     +,   2.1299809E-16,   1.3951179E-16,   9.2287648E-17
     +,   6.1267713E-17,   4.0684107E-17,   2.6975601E-17
     +,   1.7844049E-17,   1.1771274E-17,   7.7422385E-18
     +,   5.0768508E-18,   3.3187663E-18,   2.1628070E-18
     +,   1.4050905E-18,   9.1000300E-19,   5.8752147E-19
     +,   3.7814342E-19,   2.4262215E-19,   1.5518782E-19
     +,   9.8952243E-20,   6.2899221E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz106 = Yx/0.135666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7351894E-09,   3.3241920E-09
     +,   4.0314037E-09,   4.8786624E-09,   5.8914638E-09
     +,   7.0995010E-09,   8.5372482E-09,   1.0244690E-08
     +,   1.2267982E-08,   1.4660499E-08,   1.7483570E-08
     +,   2.0807613E-08,   2.4713341E-08,   2.9292988E-08
     +,   3.4651823E-08,   4.0909626E-08,   4.8202455E-08
     +,   5.6684520E-08,   6.6530390E-08,   7.7936960E-08
     +,   9.1126232E-08,   1.0634793E-07,   1.2388190E-07
     +,   1.4404311E-07,   1.6718135E-07,   1.9368980E-07
     +,   2.2400505E-07,   2.5861297E-07,   2.9805346E-07
     +,   3.4292478E-07,   3.9388868E-07,   4.5167664E-07
     +,   5.1709469E-07,   5.9102979E-07,   6.7445649E-07
     +,   7.6844293E-07,   8.7415748E-07,   9.9287433E-07
     +,   1.1259890E-06,   1.2750045E-06,   1.4415662E-06
     +,   1.6274440E-06,   1.8345517E-06,   2.0649491E-06
     +,   2.3208479E-06,   2.6046150E-06,   2.9187779E-06
     +,   3.2660282E-06,   3.6492197E-06,   4.0713735E-06
     +,   4.5356733E-06,   5.0454682E-06,   5.6042559E-06
     +,   6.2157237E-06,   6.8836425E-06,   7.6119923E-06
     +,   8.4048434E-06,   9.2663913E-06,   1.0200944E-05
     +,   1.1212897E-05,   1.2306727E-05,   1.3486983E-05
     +,   1.4758187E-05,   1.6124957E-05,   1.7591934E-05
     +,   1.9163566E-05,   2.0844434E-05,   2.2638818E-05
     +,   2.4551067E-05,   2.6585094E-05,   2.8744849E-05
     +,   3.1033655E-05,   3.3454788E-05,   3.6010715E-05
     +,   3.8703591E-05,   4.1534950E-05,   4.4505323E-05
     +,   4.7614347E-05,   5.0860817E-05,   5.4242366E-05
     +,   5.7754958E-05,   6.1393570E-05,   6.5151056E-05
     +,   6.9019065E-05,   7.2986870E-05,   7.7042314E-05
     +,   8.1170692E-05,   8.5355787E-05,   8.9578840E-05
     +,   9.3819486E-05,   9.8055541E-05,   1.0226282E-04
     +,   1.0641567E-04,   1.1048757E-04,   1.1445113E-04
     +,   1.1827815E-04,   1.2194093E-04,   1.2541181E-04
     +,   1.2866463E-04,   1.3167436E-04,   1.3441844E-04
     +,   1.3687661E-04,   1.3903210E-04,   1.4087133E-04
     +,   1.4238511E-04,   1.4356832E-04,   1.4442053E-04
     +,   1.4494591E-04,   1.4515351E-04,   1.4505698E-04
     +,   1.4467462E-04,   1.4402879E-04,   1.4314597E-04
     +,   1.4205574E-04,   1.4079083E-04,   1.3938599E-04
     +,   1.3787772E-04,   1.3630325E-04,   1.3470023E-04
     +,   1.3310558E-04,   1.3155515E-04,   1.3008303E-04
     +,   1.2872102E-04,   1.2749799E-04,   1.2643953E-04
     +,   1.2556782E-04,   1.2490124E-04,   1.2445428E-04
     +,   1.2423760E-04,   1.2425816E-04,   1.2451937E-04
     +,   1.2502144E-04,   1.2576174E-04,   1.2673525E-04
     +,   1.2793524E-04,   1.2935376E-04,   1.3098218E-04
     +,   1.3281201E-04,   1.3483540E-04,   1.3704601E-04
     +,   1.3943920E-04,   1.4201268E-04,   1.4476724E-04
     +,   1.4770668E-04,   1.5083772E-04,   1.5417056E-04
     +,   1.5771837E-04,   1.6149646E-04,   1.6552205E-04
     +,   1.6981347E-04,   1.7438902E-04,   1.7926531E-04
     +,   1.8445645E-04,   1.8997288E-04,   1.9581959E-04
     +,   2.0199496E-04,   2.0848974E-04,   2.1528678E-04
     +,   2.2236040E-04,   2.2967585E-04,   2.3719080E-04
     +,   2.4485658E-04,   2.5261822E-04,   2.6041805E-04
     +,   2.6819832E-04,   2.7590376E-04,   2.8348455E-04
     +,   2.9090064E-04,   2.9812605E-04,   3.0515224E-04
     +,   3.1199242E-04,   3.1868558E-04,   3.2530102E-04
     +,   3.3194089E-04,   3.3874274E-04,   3.4588194E-04
     +,   3.5357234E-04,   3.6206518E-04,   3.7164972E-04
     +,   3.8265373E-04,   3.9544702E-04,   4.1044992E-04
     +,   4.2815373E-04,   4.4915784E-04,   4.7422040E-04
     +,   5.0432584E-04,   5.4075860E-04,   5.8516749E-04
     +,   6.3959241E-04,   7.0643920E-04,   7.8843749E-04
     +,   8.8860519E-04,   1.0103148E-03,   1.1575520E-03
     +,   1.3353551E-03,   1.5502103E-03,   1.8099725E-03
     +,   2.1230134E-03,   2.4972227E-03,   2.9413144E-03
     +,   3.4709850E-03,   4.1177939E-03,   4.9341130E-03
     +,   5.9947744E-03,   7.4088164E-03,   9.3321316E-03
     +,   1.1900144E-02,   1.5033145E-02,   1.8354841E-02
     +,   2.1617612E-02,   2.5447477E-02,   3.1137381E-02
     +,   3.8179100E-02,   4.2506780E-02,   4.1489959E-02
     +,   3.8319111E-02,   3.6229149E-02,   3.4149628E-02
     +,   2.9778421E-02,   2.3444910E-02,   1.7385447E-02
     +,   1.2743067E-02,   9.3159210E-03,   6.6901129E-03
     +,   4.6527721E-03,   3.1091534E-03,   1.9919053E-03
     +,   1.2327603E-03,   7.5076608E-04,   4.5971249E-04
     +,   2.8734573E-04,   1.8483227E-04,   1.2317731E-04
     +,   8.5698455E-05,   6.2533160E-05,   4.7732108E-05
     +,   3.7775375E-05,   3.0676645E-05,   2.5374391E-05
     +,   2.1319773E-05,   1.8217999E-05,   1.5883457E-05
     +,   1.4170814E-05,   1.2950380E-05,   1.2104571E-05
     +,   1.1530932E-05,   1.1145082E-05,   1.0881556E-05
     +,   1.0692402E-05,   1.0544338E-05,   1.0415432E-05
     +,   1.0291963E-05,   1.0165826E-05,   1.0032551E-05
     +,   9.8899000E-06,   9.7369511E-06,   9.5735622E-06
     +,   9.3999997E-06,   9.2167547E-06,   9.0244394E-06
     +,   8.8237475E-06,   8.6154168E-06,   8.4001922E-06
     +,   8.1788321E-06,   7.9521296E-06,   7.7208497E-06
     +,   7.4857580E-06,   7.2476296E-06,   7.0072274E-06
     +,   6.7652823E-06,   6.5225086E-06,   6.2796130E-06
     +,   6.0372772E-06,   5.7961406E-06,   5.5568116E-06
     +,   5.3198883E-06,   5.0859053E-06,   4.8553907E-06
     +,   4.6288055E-06,   4.4066028E-06,   4.1891662E-06
     +,   3.9768711E-06,   3.7700261E-06,   3.5689250E-06
     +,   3.3737983E-06,   3.1848665E-06,   3.0022914E-06
     +,   2.8262014E-06,   2.6567075E-06,   2.4938654E-06
     +,   2.3377215E-06,   2.1882706E-06,   2.0455013E-06
     +,   1.9093566E-06,   1.7797738E-06,   1.6566514E-06
     +,   1.5398839E-06,   1.4293324E-06,   1.3248573E-06
     +,   1.2262907E-06,   1.1334656E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz108 = Yx/0.126333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8476300E-06,   3.0264521E-06
     +,   3.2123289E-06,   3.4052296E-06,   3.6051035E-06
     +,   3.8118797E-06,   4.0254690E-06,   4.2457641E-06
     +,   4.4726403E-06,   4.7059657E-06,   4.9455916E-06
     +,   5.1913607E-06,   5.4431125E-06,   5.7006837E-06
     +,   5.9639151E-06,   6.2326517E-06,   6.5067511E-06
     +,   6.7860869E-06,   7.0705523E-06,   7.3600677E-06
     +,   7.6545812E-06,   7.9540787E-06,   8.2585802E-06
     +,   8.5681713E-06,   8.8829456E-06,   9.2030896E-06
     +,   9.5288215E-06,   9.8604223E-06,   1.0198225E-05
     +,   1.0542627E-05,   1.0894078E-05,   1.1253077E-05
     +,   1.1620184E-05,   1.1995992E-05,   1.2381140E-05
     +,   1.2776292E-05,   1.3182133E-05,   1.3599352E-05
     +,   1.4028655E-05,   1.4470688E-05,   1.4926110E-05
     +,   1.5395493E-05,   1.5879361E-05,   1.6378142E-05
     +,   1.6892156E-05,   1.7421607E-05,   1.7966542E-05
     +,   1.8526858E-05,   1.9102259E-05,   1.9692259E-05
     +,   2.0296155E-05,   2.0913010E-05,   2.1541657E-05
     +,   2.2180704E-05,   2.2828446E-05,   2.3482991E-05
     +,   2.4142159E-05,   2.4803516E-05,   2.5464407E-05
     +,   2.6121937E-05,   2.6773016E-05,   2.7414349E-05
     +,   2.8042468E-05,   2.8653807E-05,   2.9244695E-05
     +,   2.9811339E-05,   3.0349996E-05,   3.0856867E-05
     +,   3.1328280E-05,   3.1760585E-05,   3.2150358E-05
     +,   3.2494303E-05,   3.2789427E-05,   3.3032960E-05
     +,   3.3222499E-05,   3.3356006E-05,   3.3431843E-05
     +,   3.3448814E-05,   3.3406217E-05,   3.3303848E-05
     +,   3.3142023E-05,   3.2921631E-05,   3.2644126E-05
     +,   3.2311527E-05,   3.1926484E-05,   3.1492182E-05
     +,   3.1012467E-05,   3.0491708E-05,   2.9934919E-05
     +,   2.9347644E-05,   2.8735973E-05,   2.8106579E-05
     +,   2.7466653E-05,   2.6823862E-05,   2.6186328E-05
     +,   2.5562698E-05,   2.4961966E-05,   2.4393596E-05
     +,   2.3867336E-05,   2.3393346E-05,   2.2982003E-05
     +,   2.2644008E-05,   2.2390232E-05,   2.2231741E-05
     +,   2.2179691E-05,   2.2245336E-05,   2.2439935E-05
     +,   2.2774680E-05,   2.3260667E-05,   2.3908849E-05
     +,   2.4729867E-05,   2.5734182E-05,   2.6931790E-05
     +,   2.8332444E-05,   2.9945330E-05,   3.1779433E-05
     +,   3.3843164E-05,   3.6144862E-05,   3.8692440E-05
     +,   4.1494022E-05,   4.4558004E-05,   4.7893125E-05
     +,   5.1509069E-05,   5.5416993E-05,   5.9630067E-05
     +,   6.4163360E-05,   6.9035530E-05,   7.4268035E-05
     +,   7.9887075E-05,   8.5922264E-05,   9.2408583E-05
     +,   9.9384379E-05,   1.0689286E-04,   1.1497909E-04
     +,   1.2369057E-04,   1.3307444E-04,   1.4317452E-04
     +,   1.5402870E-04,   1.6566624E-04,   1.7810326E-04
     +,   1.9133805E-04,   2.0534737E-04,   2.2008384E-04
     +,   2.3547167E-04,   2.5140299E-04,   2.6773923E-04
     +,   2.8431031E-04,   3.0091472E-04,   3.1732491E-04
     +,   3.3329378E-04,   3.4856022E-04,   3.6285783E-04
     +,   3.7592615E-04,   3.8752207E-04,   3.9743097E-04
     +,   4.0547721E-04,   4.1153576E-04,   4.1554205E-04
     +,   4.1749861E-04,   4.1748027E-04,   4.1563806E-04
     +,   4.1219784E-04,   4.0745895E-04,   4.0178784E-04
     +,   3.9561081E-04,   3.8940291E-04,   3.8367839E-04
     +,   3.7897506E-04,   3.7584090E-04,   3.7481796E-04
     +,   3.7642563E-04,   3.8114196E-04,   3.8938396E-04
     +,   4.0148557E-04,   4.1767294E-04,   4.3804108E-04
     +,   4.6253006E-04,   4.9090001E-04,   5.2271731E-04
     +,   5.5735372E-04,   5.9399620E-04,   6.3167844E-04
     +,   6.6934165E-04,   7.0592383E-04,   7.4046769E-04
     +,   7.7224831E-04,   8.0091419E-04,   8.2661549E-04
     +,   8.5008971E-04,   8.7268872E-04,   8.9630712E-04
     +,   9.2320138E-04,   9.5569610E-04,   9.9586509E-04
     +,   1.0453077E-03,   1.1052326E-03,   1.1770359E-03
     +,   1.2634303E-03,   1.3697407E-03,   1.5044848E-03
     +,   1.6784332E-03,   1.9025597E-03,   2.1872935E-03
     +,   2.5454834E-03,   2.9973818E-03,   3.5706852E-03
     +,   4.2906622E-03,   5.1718974E-03,   6.2438929E-03
     +,   7.6320497E-03,   9.6281264E-03,   1.2594043E-02
     +,   1.6735241E-02,   2.2104042E-02,   2.8715551E-02
     +,   3.6152799E-02,   4.2699128E-02,   4.5909889E-02
     +,   4.5684412E-02,   4.2985875E-02,   3.7208971E-02
     +,   2.9481856E-02,   2.2427926E-02,   1.6887765E-02
     +,   1.2234665E-02,   8.1590218E-03,   4.9307640E-03
     +,   2.7458631E-03,   1.4677380E-03,   7.9414295E-04
     +,   4.5255196E-04,   2.7354120E-04,   1.7372884E-04
     +,   1.1578990E-04,   8.1505059E-05,   6.0596529E-05
     +,   4.7170921E-05,   3.8128048E-05,   3.1945096E-05
     +,   2.7814445E-05,   2.5191930E-05,   2.3636572E-05
     +,   2.2785140E-05,   2.2359571E-05,   2.2166389E-05
     +,   2.2083110E-05,   2.2038819E-05,   2.1995837E-05
     +,   2.1935808E-05,   2.1850647E-05,   2.1737324E-05
     +,   2.1595111E-05,   2.1424334E-05,   2.1225769E-05
     +,   2.1000418E-05,   2.0749401E-05,   2.0473955E-05
     +,   2.0175406E-05,   1.9855110E-05,   1.9514471E-05
     +,   1.9154964E-05,   1.8778101E-05,   1.8385379E-05
     +,   1.7978316E-05,   1.7558465E-05,   1.7127339E-05
     +,   1.6686430E-05,   1.6237243E-05,   1.5781254E-05
     +,   1.5319865E-05,   1.4854450E-05,   1.4386356E-05
     +,   1.3916884E-05,   1.3447248E-05,   1.2978608E-05
     +,   1.2512100E-05,   1.2048743E-05,   1.1589551E-05
     +,   1.1135412E-05,   1.0687207E-05,   1.0245692E-05
     +,   9.8116152E-06,   9.3856024E-06,   8.9682753E-06
     +,   8.5601323E-06,   8.1616690E-06,   7.7732784E-06
     +,   7.3953011E-06,   7.0280576E-06,   6.6717694E-06
     +,   6.3266521E-06,   5.9928316E-06,   5.6704284E-06
     +,   5.3594827E-06,   5.0600338E-06,   4.7720428E-06
     +,   4.4954763E-06,   4.2302313E-06,   3.9762090E-06
     +,   3.7332511E-06,   3.5012069E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz110 = Yx/0.120878048780488
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0029453E-07,   1.1242980E-07
     +,   1.2585744E-07,   1.4069235E-07,   1.5705693E-07
     +,   1.7508128E-07,   1.9490348E-07,   2.1666952E-07
     +,   2.4053358E-07,   2.6665913E-07,   2.9521689E-07
     +,   3.2638698E-07,   3.6035786E-07,   3.9732689E-07
     +,   4.3750049E-07,   4.8109422E-07,   5.2833275E-07
     +,   5.7945022E-07,   6.3469128E-07,   6.9431047E-07
     +,   7.5857389E-07,   8.2775847E-07,   9.0215411E-07
     +,   9.8206920E-07,   1.0678197E-06,   1.1597476E-06
     +,   1.2582119E-06,   1.3635937E-06,   1.4763037E-06
     +,   1.5967818E-06,   1.7255036E-06,   1.8629860E-06
     +,   2.0097941E-06,   2.1665446E-06,   2.3339169E-06
     +,   2.5126585E-06,   2.7035974E-06,   2.9076430E-06
     +,   3.1258153E-06,   3.3592187E-06,   3.6090983E-06
     +,   3.8768112E-06,   4.1638523E-06,   4.4718631E-06
     +,   4.8026354E-06,   5.1581164E-06,   5.5404175E-06
     +,   5.9518106E-06,   6.3947264E-06,   6.8717509E-06
     +,   7.3856218E-06,   7.9392039E-06,   8.5354759E-06
     +,   9.1775428E-06,   9.8685141E-06,   1.0611602E-05
     +,   1.1409988E-05,   1.2266813E-05,   1.3185144E-05
     +,   1.4167918E-05,   1.5217895E-05,   1.6337633E-05
     +,   1.7529337E-05,   1.8795001E-05,   2.0136256E-05
     +,   2.1554235E-05,   2.3049834E-05,   2.4623316E-05
     +,   2.6274740E-05,   2.8003527E-05,   2.9808927E-05
     +,   3.1689633E-05,   3.3644268E-05,   3.5671015E-05
     +,   3.7768139E-05,   3.9933857E-05,   4.2166408E-05
     +,   4.4464206E-05,   4.6826179E-05,   4.9251728E-05
     +,   5.1740630E-05,   5.4293654E-05,   5.6912020E-05
     +,   5.9598133E-05,   6.2354877E-05,   6.5186352E-05
     +,   6.8097012E-05,   7.1092378E-05,   7.4178060E-05
     +,   7.7360237E-05,   8.0645113E-05,   8.4038351E-05
     +,   8.7544904E-05,   9.1168979E-05,   9.4913281E-05
     +,   9.8778270E-05,   1.0276262E-04,   1.0686181E-04
     +,   1.1106875E-04,   1.1537256E-04,   1.1975929E-04
     +,   1.2421065E-04,   1.2870526E-04,   1.3321733E-04
     +,   1.3771799E-04,   1.4217518E-04,   1.4655353E-04
     +,   1.5081535E-04,   1.5492155E-04,   1.5883184E-04
     +,   1.6250522E-04,   1.6590173E-04,   1.6898211E-04
     +,   1.7170983E-04,   1.7405083E-04,   1.7597515E-04
     +,   1.7745687E-04,   1.7847541E-04,   1.7901557E-04
     +,   1.7906803E-04,   1.7862984E-04,   1.7770415E-04
     +,   1.7630061E-04,   1.7443504E-04,   1.7212896E-04
     +,   1.6940993E-04,   1.6631003E-04,   1.6286650E-04
     +,   1.5911993E-04,   1.5511474E-04,   1.5089739E-04
     +,   1.4651670E-04,   1.4202204E-04,   1.3746391E-04
     +,   1.3289208E-04,   1.2835544E-04,   1.2390182E-04
     +,   1.1957715E-04,   1.1542469E-04,   1.1148502E-04
     +,   1.0779600E-04,   1.0439227E-04,   1.0130490E-04
     +,   9.8561628E-05,   9.6186974E-05,   9.4201961E-05
     +,   9.2624359E-05,   9.1469024E-05,   9.0747861E-05
     +,   9.0469985E-05,   9.0642054E-05,   9.1268317E-05
     +,   9.2350849E-05,   9.3889583E-05,   9.5882417E-05
     +,   9.8325087E-05,   1.0121103E-04,   1.0453154E-04
     +,   1.0827542E-04,   1.1242850E-04,   1.1697389E-04
     +,   1.2189163E-04,   1.2715827E-04,   1.3274691E-04
     +,   1.3862790E-04,   1.4476884E-04,   1.5113443E-04
     +,   1.5768805E-04,   1.6439313E-04,   1.7121437E-04
     +,   1.7811925E-04,   1.8508107E-04,   1.9208250E-04
     +,   1.9911905E-04,   2.0620327E-04,   2.1337150E-04
     +,   2.2069005E-04,   2.2826175E-04,   2.3623399E-04
     +,   2.4480620E-04,   2.5423529E-04,   2.6483840E-04
     +,   2.7699332E-04,   2.9113595E-04,   3.0775266E-04
     +,   3.2736987E-04,   3.5054606E-04,   3.7786979E-04
     +,   4.0996433E-04,   4.4750189E-04,   4.9124449E-04
     +,   5.4208795E-04,   6.0111017E-04,   6.6961313E-04
     +,   7.4913201E-04,   8.4137288E-04,   9.4804663E-04
     +,   1.0705893E-03,   1.2097578E-03,   1.3651159E-03
     +,   1.5345718E-03,   1.7142397E-03,   1.8989972E-03
     +,   2.0840054E-03,   2.2670159E-03,   2.4502629E-03
     +,   2.6399749E-03,   2.8449267E-03,   3.0851427E-03
     +,   3.4266093E-03,   4.0309182E-03,   5.1577520E-03
     +,   7.0595010E-03,   9.8210257E-03,   1.3358621E-02
     +,   1.7610855E-02,   2.2354703E-02,   2.6945226E-02
     +,   3.1715199E-02,   3.8737215E-02,   4.7995303E-02
     +,   5.5149689E-02,   5.5295140E-02,   4.7210239E-02
     +,   3.4702685E-02,   2.2749271E-02,   1.3587243E-02
     +,   7.4010948E-03,   3.7379812E-03,   1.8405137E-03
     +,   9.5031917E-04,   5.5086688E-04,   3.6357981E-04
     +,   2.5992753E-04,   1.9067236E-04,   1.4088136E-04
     +,   1.0601915E-04,   8.2970706E-05,   6.8500798E-05
     +,   5.9749273E-05,   5.4575943E-05,   5.1516610E-05
     +,   4.9612947E-05,   4.8265181E-05,   4.7124020E-05
     +,   4.6006877E-05,   4.4833028E-05,   4.3577558E-05
     +,   4.2242751E-05,   4.0842500E-05,   3.9394447E-05
     +,   3.7916532E-05,   3.6425634E-05,   3.4936853E-05
     +,   3.3463093E-05,   3.2015072E-05,   3.0601434E-05
     +,   2.9228717E-05,   2.7901426E-05,   2.6622341E-05
     +,   2.5392828E-05,   2.4212984E-05,   2.3081826E-05
     +,   2.1997634E-05,   2.0958261E-05,   1.9961150E-05
     +,   1.9003604E-05,   1.8082996E-05,   1.7196824E-05
     +,   1.6342736E-05,   1.5518641E-05,   1.4722798E-05
     +,   1.3953771E-05,   1.3210357E-05,   1.2491642E-05
     +,   1.1797019E-05,   1.1125997E-05,   1.0478338E-05
     +,   9.8538549E-06,   9.2525261E-06,   8.6743066E-06
     +,   8.1192557E-06,   7.5873509E-06,   7.0786182E-06
     +,   6.5929730E-06,   6.1303399E-06,   5.6905319E-06
     +,   5.2732921E-06,   4.8783363E-06,   4.5052543E-06
     +,   4.1536182E-06,   3.8228859E-06,   3.5125047E-06
     +,   3.2218245E-06,   2.9501905E-06,   2.6968748E-06
     +,   2.4611497E-06,   2.2422350E-06,   2.0393629E-06
     +,   1.8517286E-06,   1.6785494E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz112 = Yx/0.121390243902439
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3502436E-08,   1.5859642E-08
     +,   1.8594255E-08,   2.1760636E-08,   2.5419968E-08
     +,   2.9641035E-08,   3.4500854E-08,   4.0085737E-08
     +,   4.6491859E-08,   5.3826767E-08,   6.2209828E-08
     +,   7.1773670E-08,   8.2665423E-08,   9.5047888E-08
     +,   1.0910107E-07,   1.2502360E-07,   1.4303440E-07
     +,   1.6337466E-07,   1.8630973E-07,   2.1213097E-07
     +,   2.4115843E-07,   2.7374327E-07,   3.1027005E-07
     +,   3.5116327E-07,   3.9688277E-07,   4.4793822E-07
     +,   5.0488484E-07,   5.6833181E-07,   6.3894686E-07
     +,   7.1746285E-07,   8.0468152E-07,   9.0148365E-07
     +,   1.0088351E-06,   1.1277939E-06,   1.2595225E-06
     +,   1.4052941E-06,   1.5665056E-06,   1.7446827E-06
     +,   1.9415102E-06,   2.1588064E-06,   2.3985813E-06
     +,   2.6630144E-06,   2.9544794E-06,   3.2755549E-06
     +,   3.6290355E-06,   4.0179389E-06,   4.4455137E-06
     +,   4.9152436E-06,   5.4308543E-06,   5.9963045E-06
     +,   6.6157841E-06,   7.2937041E-06,   8.0346654E-06
     +,   8.8434990E-06,   9.7250986E-06,   1.0684569E-05
     +,   1.1727029E-05,   1.2857626E-05,   1.4081468E-05
     +,   1.5403548E-05,   1.6828679E-05,   1.8361421E-05
     +,   2.0005878E-05,   2.1765833E-05,   2.3644507E-05
     +,   2.5644320E-05,   2.7767182E-05,   3.0013902E-05
     +,   3.2384622E-05,   3.4878216E-05,   3.7492755E-05
     +,   4.0224877E-05,   4.3070377E-05,   4.6023531E-05
     +,   4.9077702E-05,   5.2225110E-05,   5.5456690E-05
     +,   5.8762362E-05,   6.2131374E-05,   6.5552194E-05
     +,   6.9012349E-05,   7.2499453E-05,   7.6000339E-05
     +,   7.9502366E-05,   8.2992607E-05,   8.6459004E-05
     +,   8.9889727E-05,   9.3274226E-05,   9.6602518E-05
     +,   9.9866171E-05,   1.0305808E-04,   1.0617235E-04
     +,   1.0920451E-04,   1.1215188E-04,   1.1501305E-04
     +,   1.1778785E-04,   1.2047754E-04,   1.2308410E-04
     +,   1.2561062E-04,   1.2806043E-04,   1.3043742E-04
     +,   1.3274510E-04,   1.3498699E-04,   1.3716564E-04
     +,   1.3928293E-04,   1.4133957E-04,   1.4333476E-04
     +,   1.4526625E-04,   1.4713019E-04,   1.4892123E-04
     +,   1.5063211E-04,   1.5225440E-04,   1.5377809E-04
     +,   1.5519233E-04,   1.5648530E-04,   1.5764494E-04
     +,   1.5865894E-04,   1.5951555E-04,   1.6020366E-04
     +,   1.6071355E-04,   1.6103689E-04,   1.6116744E-04
     +,   1.6110120E-04,   1.6083670E-04,   1.6037525E-04
     +,   1.5972096E-04,   1.5888090E-04,   1.5786506E-04
     +,   1.5668612E-04,   1.5535955E-04,   1.5390321E-04
     +,   1.5233719E-04,   1.5068351E-04,   1.4896583E-04
     +,   1.4720915E-04,   1.4543952E-04,   1.4368401E-04
     +,   1.4197020E-04,   1.4032617E-04,   1.3878048E-04
     +,   1.3736212E-04,   1.3610069E-04,   1.3502629E-04
     +,   1.3416985E-04,   1.3356346E-04,   1.3324049E-04
     +,   1.3323607E-04,   1.3358718E-04,   1.3433286E-04
     +,   1.3551457E-04,   1.3717594E-04,   1.3936273E-04
     +,   1.4212205E-04,   1.4550236E-04,   1.4955210E-04
     +,   1.5431782E-04,   1.5984316E-04,   1.6616660E-04
     +,   1.7331947E-04,   1.8132178E-04,   1.9018135E-04
     +,   1.9989003E-04,   2.1042048E-04,   2.2172401E-04
     +,   2.3372970E-04,   2.4634294E-04,   2.5944426E-04
     +,   2.7289195E-04,   2.8652578E-04,   3.0017114E-04
     +,   3.1364523E-04,   3.2676631E-04,   3.3936562E-04
     +,   3.5129863E-04,   3.6245660E-04,   3.7278314E-04
     +,   3.8228460E-04,   3.9104125E-04,   3.9921328E-04
     +,   4.0704448E-04,   4.1485697E-04,   4.2303946E-04
     +,   4.3203076E-04,   4.4229851E-04,   4.5431417E-04
     +,   4.6853113E-04,   4.8537148E-04,   5.0522987E-04
     +,   5.2849477E-04,   5.5559701E-04,   5.8709393E-04
     +,   6.2377536E-04,   6.6677917E-04,   7.1770395E-04
     +,   7.7866309E-04,   8.5223356E-04,   9.4125746E-04
     +,   1.0485051E-03,   1.1762653E-03,   1.3259726E-03
     +,   1.4979967E-03,   1.6916164E-03,   1.9049631E-03
     +,   2.1345513E-03,   2.3744670E-03,   2.6167387E-03
     +,   2.8560739E-03,   3.1023936E-03,   3.3986876E-03
     +,   3.8304676E-03,   4.5080106E-03,   5.5193710E-03
     +,   6.8837106E-03,   8.5338075E-03,   1.0314718E-02
     +,   1.2040877E-02,   1.3765112E-02,   1.6027583E-02
     +,   1.9436313E-02,   2.4177181E-02,   3.0696440E-02
     +,   3.9623775E-02,   4.9149130E-02,   5.4176245E-02
     +,   5.0548084E-02,   3.9396770E-02,   2.5764564E-02
     +,   1.4160309E-02,   6.4996555E-03,   2.5218085E-03
     +,   9.1367605E-04,   3.9724362E-04,   2.4007120E-04
     +,   1.6588136E-04,   1.0843560E-04,   6.2864332E-05
     +,   3.1885113E-05,   1.4144235E-05,   5.4999828E-06
     +,   1.8784777E-06,   5.6424511E-07,   1.4925908E-07
     +,   3.4940268E-08,   7.4007529E-09,   1.5593693E-09
     +,   4.3353507E-10,   2.0745408E-10,   1.3947647E-10
     +,   1.0290998E-10,   7.7207928E-11,   5.8052594E-11
     +,   4.3638596E-11,   3.2776792E-11,   2.4591893E-11
     +,   1.8427026E-11,   1.3787397E-11,   1.0299703E-11
     +,   7.6814570E-12,   5.7187610E-12,   4.2498214E-12
     +,   3.1523558E-12,   2.3339141E-12,   1.7246631E-12
     +,   1.2719781E-12,   9.3629889E-13,   6.8785814E-13
     +,   5.0434006E-13,   3.6905407E-13,   2.6952553E-13
     +,   1.9644705E-13,   1.4289630E-13,   1.0373566E-13
     +,   7.5156962E-14,   5.4342175E-14,   3.9212608E-14
     +,   2.8238459E-14,   2.0294172E-14,   1.4555396E-14
     +,   1.0418041E-14,   7.4415614E-15,   5.3045235E-15
     +,   3.7734420E-15,   2.6787163E-15,   1.8976613E-15
     +,   1.3415304E-15,   9.4640961E-16,   6.6626230E-16
     +,   4.6804759E-16,   3.2811089E-16,   2.2952123E-16
     +,   1.6021485E-16,   1.1159519E-16,   7.7563958E-17
     +,   5.3793544E-17,   3.7227505E-17,   2.5706686E-17
     +,   1.7712665E-17,   1.2177659E-17,   8.3539749E-18
     +,   5.7181834E-18,   3.9053881E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz113 = Yx/0.11490243902439
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9893669E-10,   9.7480968E-10
     +,   1.1870712E-09,   1.4427279E-09,   1.7500168E-09
     +,   2.1186148E-09,   2.5598417E-09,   3.0869334E-09
     +,   3.7152941E-09,   4.4628710E-09,   5.3504436E-09
     +,   6.4020726E-09,   7.6455233E-09,   9.1127710E-09
     +,   1.0840536E-08,   1.2870918E-08,   1.5252011E-08
     +,   1.8038648E-08,   2.1293241E-08,   2.5086527E-08
     +,   2.9498619E-08,   3.4619895E-08,   4.0552031E-08
     +,   4.7409618E-08,   5.5320243E-08,   6.4427212E-08
     +,   7.4889762E-08,   8.6884917E-08,   1.0060884E-07
     +,   1.1627829E-07,   1.3413231E-07,   1.5443331E-07
     +,   1.7746919E-07,   2.0355436E-07,   2.3303144E-07
     +,   2.6627262E-07,   3.0368099E-07,   3.4569129E-07
     +,   3.9277410E-07,   4.4542921E-07,   5.0419675E-07
     +,   5.6964933E-07,   6.4239549E-07,   7.2308023E-07
     +,   8.1238369E-07,   9.1102055E-07,   1.0197390E-06
     +,   1.1393194E-06,   1.2705719E-06,   1.4143345E-06
     +,   1.5714696E-06,   1.7428607E-06,   1.9294050E-06
     +,   2.1320257E-06,   2.3516288E-06,   2.5891484E-06
     +,   2.8454976E-06,   3.1215832E-06,   3.4182938E-06
     +,   3.7364921E-06,   4.0770065E-06,   4.4406306E-06
     +,   4.8280813E-06,   5.2400487E-06,   5.6771555E-06
     +,   6.1399073E-06,   6.6287821E-06,   7.1441013E-06
     +,   7.6861534E-06,   8.2550459E-06,   8.8508441E-06
     +,   9.4734160E-06,   1.0122584E-05,   1.0797949E-05
     +,   1.1499053E-05,   1.2225291E-05,   1.2975886E-05
     +,   1.3749917E-05,   1.4546379E-05,   1.5364138E-05
     +,   1.6201866E-05,   1.7058217E-05,   1.7931625E-05
     +,   1.8820556E-05,   1.9723257E-05,   2.0638037E-05
     +,   2.1563028E-05,   2.2496437E-05,   2.3436342E-05
     +,   2.4380897E-05,   2.5328291E-05,   2.6276675E-05
     +,   2.7224271E-05,   2.8169436E-05,   2.9110630E-05
     +,   3.0046338E-05,   3.0975301E-05,   3.1896303E-05
     +,   3.2808402E-05,   3.3710734E-05,   3.4602726E-05
     +,   3.5483899E-05,   3.6354086E-05,   3.7213198E-05
     +,   3.8061447E-05,   3.8899219E-05,   3.9727023E-05
     +,   4.0545539E-05,   4.1355644E-05,   4.2158346E-05
     +,   4.2954660E-05,   4.3745793E-05,   4.4532910E-05
     +,   4.5317287E-05,   4.6100136E-05,   4.6882738E-05
     +,   4.7666294E-05,   4.8452086E-05,   4.9241298E-05
     +,   5.0035247E-05,   5.0835355E-05,   5.1643125E-05
     +,   5.2460364E-05,   5.3289281E-05,   5.4132648E-05
     +,   5.4993827E-05,   5.5877161E-05,   5.6788020E-05
     +,   5.7733148E-05,   5.8720725E-05,   5.9760790E-05
     +,   6.0865110E-05,   6.2047700E-05,   6.3324558E-05
     +,   6.4713953E-05,   6.6236331E-05,   6.7914007E-05
     +,   6.9771042E-05,   7.1833179E-05,   7.4127209E-05
     +,   7.6680641E-05,   7.9521291E-05,   8.2677267E-05
     +,   8.6176398E-05,   9.0046116E-05,   9.4313895E-05
     +,   9.9007491E-05,   1.0415511E-04,   1.0978612E-04
     +,   1.1593244E-04,   1.2262883E-04,   1.2991289E-04
     +,   1.3782538E-04,   1.4641006E-04,   1.5571176E-04
     +,   1.6577280E-04,   1.7662978E-04,   1.8830891E-04
     +,   2.0081957E-04,   2.1414581E-04,   2.2824197E-04
     +,   2.4302500E-04,   2.5836803E-04,   2.7409822E-04
     +,   2.8999793E-04,   3.0580646E-04,   3.2122715E-04
     +,   3.3593888E-04,   3.4961282E-04,   3.6192866E-04
     +,   3.7259495E-04,   3.8137112E-04,   3.8808933E-04
     +,   3.9267444E-04,   3.9516226E-04,   3.9571829E-04
     +,   3.9465138E-04,   3.9242851E-04,   3.8968478E-04
     +,   3.8723141E-04,   3.8605733E-04,   3.8732085E-04
     +,   3.9232630E-04,   4.0248188E-04,   4.1923532E-04
     +,   4.4398490E-04,   4.7797617E-04,   5.2219629E-04
     +,   5.7727157E-04,   6.4338179E-04,   7.2021782E-04
     +,   8.0695533E-04,   9.0225070E-04,   1.0042707E-03
     +,   1.1107586E-03,   1.2191515E-03,   1.3268299E-03
     +,   1.4315987E-03,   1.5324785E-03,   1.6307657E-03
     +,   1.7311351E-03,   1.8422345E-03,   1.9759692E-03
     +,   2.1448517E-03,   2.3575635E-03,   2.6143829E-03
     +,   2.9053241E-03,   3.2139649E-03,   3.5267200E-03
     +,   3.8421480E-03,   4.1754562E-03,   4.5652739E-03
     +,   5.0936518E-03,   5.8925487E-03,   7.0827687E-03
     +,   8.7107681E-03,   1.0850096E-02,   1.3642605E-02
     +,   1.6921423E-02,   2.0236790E-02,   2.3776129E-02
     +,   2.8628729E-02,   3.5499167E-02,   4.4900797E-02
     +,   5.5278540E-02,   5.7581078E-02,   4.4629253E-02
     +,   2.4321329E-02,   9.5898723E-03,   3.2918344E-03
     +,   1.3655340E-03,   7.6221919E-04,   5.3348526E-04
     +,   4.4168471E-04,   3.9039881E-04,   3.4443810E-04
     +,   2.9939969E-04,   2.5783622E-04,   2.2107654E-04
     +,   1.8901391E-04,   1.6113045E-04,   1.3694732E-04
     +,   1.1606277E-04,   9.8098913E-05,   8.2676685E-05
     +,   6.9424379E-05,   5.8002042E-05,   4.8124944E-05
     +,   3.9574694E-05,   3.2193606E-05,   2.5866259E-05
     +,   2.0501087E-05,   1.6015114E-05,   1.2324071E-05
     +,   9.3390399E-06,   6.9677844E-06,   5.1180546E-06
     +,   3.7011318E-06,   2.6350701E-06,   1.8471131E-06
     +,   1.2748771E-06,   8.6645969E-07,   5.7990189E-07
     +,   3.8221305E-07,   2.4810564E-07,   1.5862200E-07
     +,   9.9884694E-08,   6.1953564E-08,   3.7851969E-08
     +,   2.2780908E-08,   1.3505710E-08,   7.8875804E-09
     +,   4.5379975E-09,   2.5720348E-09,   1.4360697E-09
     +,   7.8991297E-10,   4.2802623E-10,   2.2848934E-10
     +,   1.2015609E-10,   6.2248054E-11,   3.1767585E-11
     +,   1.5971162E-11,   7.9096885E-12,   3.8589618E-12
     +,   1.8545855E-12,   8.7802909E-13,   4.0949340E-13
     +,   1.8813026E-13,   8.5148448E-14,   3.7966839E-14
     +,   1.6680550E-14,   7.2218546E-15,   3.0823366E-15
     +,   1.2975341E-15,   5.3927247E-16,   2.2164294E-16
     +,   9.0357484E-17,   3.6722220E-17,   1.5007270E-17
     +,   6.2515726E-18,   2.7070151E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz114 = Yx/0.11319512195122
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz1148(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3787244E-08,   2.7795092E-08
     +,   3.2425785E-08,   3.7766970E-08,   4.3917201E-08
     +,   5.0987008E-08,   5.9100078E-08,   6.8394627E-08
     +,   7.9024403E-08,   9.1161183E-08,   1.0499490E-07
     +,   1.2073633E-07,   1.3861832E-07,   1.5889778E-07
     +,   1.8185753E-07,   2.0780826E-07,   2.3709038E-07
     +,   2.7007630E-07,   3.0717266E-07,   3.4882189E-07
     +,   3.9550500E-07,   4.4774342E-07,   5.0610015E-07
     +,   5.7118712E-07,   6.4365588E-07,   7.2421358E-07
     +,   8.1361492E-07,   9.1266679E-07,   1.0222304E-06
     +,   1.1432231E-06,   1.2766177E-06,   1.4234444E-06
     +,   1.5847920E-06,   1.7618064E-06,   1.9556928E-06
     +,   2.1677129E-06,   2.3991852E-06,   2.6514790E-06
     +,   2.9260323E-06,   3.2243045E-06,   3.5478324E-06
     +,   3.8981780E-06,   4.2769461E-06,   4.6857735E-06
     +,   5.1263260E-06,   5.6002868E-06,   6.1093542E-06
     +,   6.6552275E-06,   7.2395997E-06,   7.8641488E-06
     +,   8.5305273E-06,   9.2403443E-06,   9.9951440E-06
     +,   1.0796460E-05,   1.1645647E-05,   1.2544064E-05
     +,   1.3492897E-05,   1.4493226E-05,   1.5545971E-05
     +,   1.6651909E-05,   1.7811619E-05,   1.9025510E-05
     +,   2.0293699E-05,   2.1616164E-05,   2.2992645E-05
     +,   2.4422474E-05,   2.5904903E-05,   2.7438680E-05
     +,   2.9022458E-05,   3.0654366E-05,   3.2332420E-05
     +,   3.4054094E-05,   3.5816731E-05,   3.7617145E-05
     +,   3.9451956E-05,   4.1317464E-05,   4.3209558E-05
     +,   4.5123805E-05,   4.7055571E-05,   4.9000002E-05
     +,   5.0951781E-05,   5.2905649E-05,   5.4855853E-05
     +,   5.6796813E-05,   5.8722511E-05,   6.0627146E-05
     +,   6.2504660E-05,   6.4349217E-05,   6.6154840E-05
     +,   6.7915869E-05,   6.9626825E-05,   7.1282368E-05
     +,   7.2877512E-05,   7.4407762E-05,   7.5869117E-05
     +,   7.7257995E-05,   7.8571706E-05,   7.9808160E-05
     +,   8.0966332E-05,   8.2046157E-05,   8.3048893E-05
     +,   8.3977080E-05,   8.4834988E-05,   8.5628606E-05
     +,   8.6366083E-05,   8.7057895E-05,   8.7717068E-05
     +,   8.8359557E-05,   8.9004534E-05,   8.9674621E-05
     +,   9.0396024E-05,   9.1198963E-05,   9.2117480E-05
     +,   9.3189708E-05,   9.4457537E-05,   9.5966549E-05
     +,   9.7765231E-05,   9.9904704E-05,   1.0243740E-04
     +,   1.0541626E-04,   1.0889328E-04,   1.1291769E-04
     +,   1.1753418E-04,   1.2278132E-04,   1.2868927E-04
     +,   1.3527719E-04,   1.4255228E-04,   1.5050660E-04
     +,   1.5911707E-04,   1.6834232E-04,   1.7812403E-04
     +,   1.8838455E-04,   1.9902975E-04,   2.0994736E-04
     +,   2.2101135E-04,   2.3208327E-04,   2.4301460E-04
     +,   2.5365103E-04,   2.6383714E-04,   2.7341992E-04
     +,   2.8225270E-04,   2.9019971E-04,   2.9714094E-04
     +,   3.0297466E-04,   3.0762042E-04,   3.1102190E-04
     +,   3.1314819E-04,   3.1399401E-04,   3.1358024E-04
     +,   3.1195270E-04,   3.0918026E-04,   3.0535334E-04
     +,   3.0058061E-04,   2.9498624E-04,   2.8870677E-04
     +,   2.8188841E-04,   2.7468419E-04,   2.6725038E-04
     +,   2.5974508E-04,   2.5232698E-04,   2.4515242E-04
     +,   2.3837565E-04,   2.3214823E-04,   2.2661907E-04
     +,   2.2193337E-04,   2.1823432E-04,   2.1566317E-04
     +,   2.1435965E-04,   2.1446221E-04,   2.1610899E-04
     +,   2.1943734E-04,   2.2458403E-04,   2.3168538E-04
     +,   2.4087664E-04,   2.5228999E-04,   2.6605546E-04
     +,   2.8229906E-04,   3.0114030E-04,   3.2269134E-04
     +,   3.4705727E-04,   3.7433335E-04,   4.0460215E-04
     +,   4.3793375E-04,   4.7438761E-04,   5.1401352E-04
     +,   5.5684987E-04,   6.0293108E-04,   6.5229164E-04
     +,   7.0496404E-04,   7.6096383E-04,   8.2028907E-04
     +,   8.8291359E-04,   9.4881828E-04,   1.0181138E-03
     +,   1.0912973E-03,   1.1696600E-03,   1.2558301E-03
     +,   1.3543167E-03,   1.4718057E-03,   1.6168201E-03
     +,   1.7983851E-03,   2.0235539E-03,   2.2941511E-03
     +,   2.6038061E-03,   2.9370056E-03,   3.2718845E-03
     +,   3.5866792E-03,   3.8678928E-03,   4.1170474E-03
     +,   4.3542483E-03,   4.6189264E-03,   4.9677799E-03
     +,   5.4668821E-03,   6.1786450E-03,   7.1527781E-03
     +,   8.4216772E-03,   9.9990657E-03,   1.1932374E-02
     +,   1.4390456E-02,   1.7555857E-02,   2.1394702E-02
     +,   2.5829004E-02,   3.1116746E-02,   3.7425492E-02
     +,   4.3222964E-02,   4.4560172E-02,   3.8282845E-02
     +,   2.6254354E-02,   1.4143506E-02,   6.1115599E-03
     +,   2.3552459E-03,   1.0330811E-03,   6.1910512E-04
     +,   4.5684678E-04,   3.6320291E-04,   2.9769339E-04
     +,   2.5090261E-04,   2.1974102E-04,   2.0096853E-04
     +,   1.9016986E-04,   1.8315083E-04,   1.7712080E-04
     +,   1.7079055E-04,   1.6385836E-04,   1.5647146E-04
     +,   1.4889234E-04,   1.4134856E-04,   1.3398804E-04
     +,   1.2688273E-04,   1.2004919E-04,   1.1347045E-04
     +,   1.0711626E-04,   1.0095727E-04,   9.4972071E-05
     +,   8.9149464E-05,   8.3488121E-05,   7.7994577E-05
     +,   7.2679912E-05,   6.7556874E-05,   6.2638326E-05
     +,   5.7936246E-05,   5.3460652E-05,   4.9218925E-05
     +,   4.5216075E-05,   4.1455030E-05,   3.7935966E-05
     +,   3.4656849E-05,   3.1613679E-05,   2.8800525E-05
     +,   2.6209473E-05,   2.3831160E-05,   2.1655111E-05
     +,   1.9669877E-05,   1.7863202E-05,   1.6222462E-05
     +,   1.4735071E-05,   1.3388359E-05,   1.2170157E-05
     +,   1.1068626E-05,   1.0072704E-05,   9.1719057E-06
     +,   8.3566465E-06,   7.6180445E-06,   6.9481243E-06
     +,   6.3396133E-06,   5.7860852E-06,   5.2817645E-06
     +,   4.8215470E-06,   4.4009721E-06,   4.0160662E-06
     +,   3.6633905E-06,   3.3398862E-06,   3.0429107E-06
     +,   2.7701021E-06,   2.5194165E-06,   2.2890115E-06
     +,   2.0772804E-06,   1.8827589E-06,   1.7041542E-06
     +,   1.5402750E-06,   1.3900541E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz1148 = Yx/0.10605
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0020243E-08,   1.1667692E-08
     +,   1.3576058E-08,   1.5784728E-08,   1.8338651E-08
     +,   2.1289068E-08,   2.4694208E-08,   2.8620295E-08
     +,   3.3142200E-08,   3.8345014E-08,   4.4324555E-08
     +,   5.1188948E-08,   5.9059868E-08,   6.8074002E-08
     +,   7.8384474E-08,   9.0162551E-08,   1.0359941E-07
     +,   1.1890776E-07,   1.3632410E-07,   1.5611040E-07
     +,   1.7855622E-07,   2.0398107E-07,   2.3273573E-07
     +,   2.6520726E-07,   3.0181528E-07,   3.4302167E-07
     +,   3.8932683E-07,   4.4127390E-07,   4.9945072E-07
     +,   5.6449130E-07,   6.3707716E-07,   7.1793824E-07
     +,   8.0785492E-07,   9.0765712E-07,   1.0182256E-06
     +,   1.1404907E-06,   1.2754317E-06,   1.4240737E-06
     +,   1.5874963E-06,   1.7668042E-06,   1.9631600E-06
     +,   2.1777505E-06,   2.4117944E-06,   2.6665350E-06
     +,   2.9432315E-06,   3.2431556E-06,   3.5675762E-06
     +,   3.9177598E-06,   4.2949505E-06,   4.7003678E-06
     +,   5.1351903E-06,   5.6005483E-06,   6.0975017E-06
     +,   6.6270632E-06,   7.1901072E-06,   7.7874629E-06
     +,   8.4198182E-06,   9.0877429E-06,   9.7916736E-06
     +,   1.0531903E-05,   1.1308568E-05,   1.2121656E-05
     +,   1.2970935E-05,   1.3856055E-05,   1.4776503E-05
     +,   1.5731488E-05,   1.6720158E-05,   1.7741360E-05
     +,   1.8793902E-05,   1.9876281E-05,   2.0986981E-05
     +,   2.2124201E-05,   2.3286144E-05,   2.4470757E-05
     +,   2.5675992E-05,   2.6899743E-05,   2.8139759E-05
     +,   2.9393770E-05,   3.0659572E-05,   3.1934989E-05
     +,   3.3217784E-05,   3.4505956E-05,   3.5797468E-05
     +,   3.7090555E-05,   3.8383507E-05,   3.9674931E-05
     +,   4.0963540E-05,   4.2248455E-05,   4.3528922E-05
     +,   4.4804623E-05,   4.6075595E-05,   4.7342150E-05
     +,   4.8605016E-05,   4.9865434E-05,   5.1125091E-05
     +,   5.2386051E-05,   5.3651063E-05,   5.4923326E-05
     +,   5.6206776E-05,   5.7505869E-05,   5.8825939E-05
     +,   6.0172930E-05,   6.1553852E-05,   6.2976389E-05
     +,   6.4449399E-05,   6.5982807E-05,   6.7587520E-05
     +,   6.9275658E-05,   7.1060676E-05,   7.2957242E-05
     +,   7.4981086E-05,   7.7149394E-05,   7.9480167E-05
     +,   8.1992635E-05,   8.4706480E-05,   8.7642220E-05
     +,   9.0820140E-05,   9.4260708E-05,   9.7983269E-05
     +,   1.0200626E-04,   1.0634641E-04,   1.1101781E-04
     +,   1.1603162E-04,   1.2139569E-04,   1.2711389E-04
     +,   1.3318499E-04,   1.3960360E-04,   1.4635839E-04
     +,   1.5343358E-04,   1.6080738E-04,   1.6845396E-04
     +,   1.7634213E-04,   1.8443771E-04,   1.9270269E-04
     +,   2.0109759E-04,   2.0958204E-04,   2.1811537E-04
     +,   2.2665826E-04,   2.3517458E-04,   2.4363204E-04
     +,   2.5200268E-04,   2.6026438E-04,   2.6840245E-04
     +,   2.7640906E-04,   2.8428380E-04,   2.9203435E-04
     +,   2.9967664E-04,   3.0723339E-04,   3.1473464E-04
     +,   3.2221718E-04,   3.2972373E-04,   3.3730170E-04
     +,   3.4500280E-04,   3.5288336E-04,   3.6100394E-04
     +,   3.6942869E-04,   3.7822704E-04,   3.8747618E-04
     +,   3.9726141E-04,   4.0767892E-04,   4.1883820E-04
     +,   4.3086355E-04,   4.4389348E-04,   4.5807901E-04
     +,   4.7357986E-04,   4.9055653E-04,   5.0915591E-04
     +,   5.2949722E-04,   5.5165472E-04,   5.7563483E-04
     +,   6.0135464E-04,   6.2862301E-04,   6.5712899E-04
     +,   6.8643154E-04,   7.1596057E-04,   7.4503385E-04
     +,   7.7288051E-04,   7.9867494E-04,   8.2158425E-04
     +,   8.4082171E-04,   8.5570040E-04,   8.6568261E-04
     +,   8.7043288E-04,   8.6985546E-04,   8.6412363E-04
     +,   8.5370563E-04,   8.3938142E-04,   8.2226121E-04
     +,   8.0380385E-04,   7.8583957E-04,   7.7057804E-04
     +,   7.6060143E-04,   7.5881364E-04,   7.6833169E-04
     +,   7.9232670E-04,   8.3384797E-04,   8.9570304E-04
     +,   9.8049326E-04,   1.0908560E-03,   1.2298226E-03
     +,   1.4009950E-03,   1.6082471E-03,   1.8548275E-03
     +,   2.1423325E-03,   2.4705112E-03,   2.8386239E-03
     +,   3.2474033E-03,   3.6996771E-03,   4.1985703E-03
     +,   4.7440059E-03,   5.3286580E-03,   5.9354524E-03
     +,   6.5447907E-03,   7.1628420E-03,   7.8613563E-03
     +,   8.7880176E-03,   1.0113646E-02,   1.1925958E-02
     +,   1.4122072E-02,   1.6430596E-02,   1.8673550E-02
     +,   2.1012357E-02,   2.3732536E-02,   2.6682990E-02
     +,   2.8940976E-02,   2.9034814E-02,   2.5845874E-02
     +,   1.9775383E-02,   1.2840318E-02,   7.1994169E-03
     +,   3.7126667E-03,   1.9718464E-03,   1.2053618E-03
     +,   8.7125006E-04,   7.0960319E-04,   6.1324862E-04
     +,   5.3934311E-04,   4.7343565E-04,   4.1340198E-04
     +,   3.6041439E-04,   3.1493985E-04,   2.7614777E-04
     +,   2.4262244E-04,   2.1304010E-04,   1.8643969E-04
     +,   1.6221427E-04,   1.4001645E-04,   1.1967534E-04
     +,   1.0113746E-04,   8.4416213E-05,   6.9540925E-05
     +,   5.6520792E-05,   4.5322282E-05,   3.5860689E-05
     +,   2.8005074E-05,   2.1591837E-05,   1.6440064E-05
     +,   1.2364825E-05,   9.1879947E-06,   6.7461201E-06
     +,   4.8946986E-06,   3.5095879E-06,   2.4867975E-06
     +,   1.7412625E-06,   1.2048209E-06,   8.2374436E-07
     +,   5.5647996E-07,   3.7143391E-07,   2.4494983E-07
     +,   1.5959348E-07,   1.0272408E-07,   6.5318808E-08
     +,   4.1029917E-08,   2.5458448E-08,   1.5602737E-08
     +,   9.4448085E-09,   5.6462937E-09,   3.3334449E-09
     +,   1.9432533E-09,   1.1185377E-09,   6.3562516E-10
     +,   3.5658246E-10,   1.9745802E-10,   1.0792775E-10
     +,   5.8223329E-11,   3.1001170E-11,   1.6292436E-11
     +,   8.4521608E-12,   4.3297588E-12,   2.1912064E-12
     +,   1.0966161E-12,   5.4358997E-13,   2.6765393E-13
     +,   1.3152034E-13,   6.4994735E-14,   3.2683115E-14
     +,   1.7000177E-14,   9.3232747E-15,   5.4810935E-15
     +,   3.4775780E-15,   2.3665281E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz116 = Yx/0.0913589743589744
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.8399096E-06,   5.9961631E-06
     +,   6.1549663E-06,   6.3164262E-06,   6.4806609E-06
     +,   6.6478033E-06,   6.8179988E-06,   6.9914058E-06
     +,   7.1681961E-06,   7.3485612E-06,   7.5327011E-06
     +,   7.7208288E-06,   7.9131751E-06,   8.1099788E-06
     +,   8.3114955E-06,   8.5179909E-06,   8.7297412E-06
     +,   8.9470304E-06,   9.1701568E-06,   9.3994204E-06
     +,   9.6351287E-06,   9.8775936E-06,   1.0127127E-05
     +,   1.0384052E-05,   1.0648667E-05,   1.0921294E-05
     +,   1.1202230E-05,   1.1491769E-05,   1.1790195E-05
     +,   1.2097774E-05,   1.2414761E-05,   1.2741389E-05
     +,   1.3077868E-05,   1.3424393E-05,   1.3781119E-05
     +,   1.4148182E-05,   1.4525688E-05,   1.4913699E-05
     +,   1.5312275E-05,   1.5721387E-05,   1.6141030E-05
     +,   1.6571126E-05,   1.7011569E-05,   1.7462227E-05
     +,   1.7922930E-05,   1.8393474E-05,   1.8873636E-05
     +,   1.9363168E-05,   1.9861804E-05,   2.0369267E-05
     +,   2.0885273E-05,   2.1409547E-05,   2.1941818E-05
     +,   2.2481874E-05,   2.3029475E-05,   2.3584485E-05
     +,   2.4146810E-05,   2.4716421E-05,   2.5293395E-05
     +,   2.5877909E-05,   2.6470259E-05,   2.7070895E-05
     +,   2.7680375E-05,   2.8299481E-05,   2.8929173E-05
     +,   2.9570563E-05,   3.0225048E-05,   3.0894145E-05
     +,   3.1579719E-05,   3.2283770E-05,   3.3008622E-05
     +,   3.3756776E-05,   3.4531040E-05,   3.5334397E-05
     +,   3.6170128E-05,   3.7041751E-05,   3.7952945E-05
     +,   3.8907634E-05,   3.9910006E-05,   4.0964474E-05
     +,   4.2075586E-05,   4.3248281E-05,   4.4487631E-05
     +,   4.5799214E-05,   4.7188794E-05,   4.8662885E-05
     +,   5.0228347E-05,   5.1893068E-05,   5.3665677E-05
     +,   5.5556153E-05,   5.7575908E-05,   5.9738017E-05
     +,   6.2057639E-05,   6.4552441E-05,   6.7242967E-05
     +,   7.0152637E-05,   7.3308736E-05,   7.6741868E-05
     +,   8.0487123E-05,   8.4583065E-05,   8.9072819E-05
     +,   9.4002615E-05,   9.9422505E-05,   1.0538431E-04
     +,   1.1194171E-04,   1.1914851E-04,   1.2705621E-04
     +,   1.3571265E-04,   1.4516001E-04,   1.5543214E-04
     +,   1.6655038E-04,   1.7852349E-04,   1.9134204E-04
     +,   2.0497870E-04,   2.1938306E-04,   2.3448326E-04
     +,   2.5018124E-04,   2.6635636E-04,   2.8286219E-04
     +,   2.9953133E-04,   3.1617688E-04,   3.3259473E-04
     +,   3.4856951E-04,   3.6388080E-04,   3.7830850E-04
     +,   3.9163779E-04,   4.0366902E-04,   4.1422105E-04
     +,   4.2314042E-04,   4.3030450E-04,   4.3562823E-04
     +,   4.3906496E-04,   4.4061083E-04,   4.4030367E-04
     +,   4.3822278E-04,   4.3448596E-04,   4.2924585E-04
     +,   4.2268552E-04,   4.1501172E-04,   4.0644853E-04
     +,   3.9723126E-04,   3.8759966E-04,   3.7779100E-04
     +,   3.6803394E-04,   3.5854563E-04,   3.4952557E-04
     +,   3.4115391E-04,   3.3359040E-04,   3.2697289E-04
     +,   3.2141828E-04,   3.1702375E-04,   3.1386895E-04
     +,   3.1201838E-04,   3.1152341E-04,   3.1242540E-04
     +,   3.1475723E-04,   3.1854495E-04,   3.2380916E-04
     +,   3.3056492E-04,   3.3882054E-04,   3.4857748E-04
     +,   3.5982858E-04,   3.7255499E-04,   3.8672501E-04
     +,   4.0229326E-04,   4.1919996E-04,   4.3736940E-04
     +,   4.5671358E-04,   4.7713460E-04,   4.9852941E-04
     +,   5.2079192E-04,   5.4381823E-04,   5.6751329E-04
     +,   5.9179112E-04,   6.1657367E-04,   6.4179691E-04
     +,   6.6740706E-04,   6.9336471E-04,   7.1965135E-04
     +,   7.4628915E-04,   7.7336235E-04,   8.0104807E-04
     +,   8.2965661E-04,   8.5966912E-04,   8.9175964E-04
     +,   9.2679559E-04,   9.6580898E-04,   1.0099302E-03
     +,   1.0602800E-03,   1.1178373E-03,   1.1833181E-03
     +,   1.2570849E-03,   1.3391257E-03,   1.4291719E-03
     +,   1.5269702E-03,   1.6326741E-03,   1.7473062E-03
     +,   1.8731864E-03,   2.0141888E-03,   2.1757192E-03
     +,   2.3644485E-03,   2.5879461E-03,   2.8543975E-03
     +,   3.1723462E-03,   3.5500100E-03,   3.9932490E-03
     +,   4.5009437E-03,   5.0582471E-03,   5.6312419E-03
     +,   6.1691497E-03,   6.6192294E-03,   6.9538835E-03
     +,   7.2008572E-03,   7.4610715E-03,   7.8975717E-03
     +,   8.6878063E-03,   9.9520124E-03,   1.1694201E-02
     +,   1.3792401E-02,   1.6043544E-02,   1.8225651E-02
     +,   2.0120854E-02,   2.1482445E-02,   2.2003215E-02
     +,   2.1372873E-02,   1.9441761E-02,   1.6384736E-02
     +,   1.2714804E-02,   9.0966588E-03,   6.0729622E-03
     +,   3.8834962E-03,   2.4710128E-03,   1.6209118E-03
     +,   1.1102776E-03,   7.8458077E-04,   5.6173932E-04
     +,   4.0459671E-04,   2.9518452E-04,   2.2149053E-04
     +,   1.7351525E-04,   1.4302747E-04,   1.2383428E-04
     +,   1.1166791E-04,   1.0376735E-04,   9.8399621E-05
     +,   9.4475348E-05,   9.1298403E-05,   8.8423702E-05
     +,   8.5579057E-05,   8.2616301E-05,   7.9474317E-05
     +,   7.6149365E-05,   7.2671523E-05,   6.9087102E-05
     +,   6.5446744E-05,   6.1798659E-05,   5.8185251E-05
     +,   5.4641310E-05,   5.1193540E-05,   4.7861431E-05
     +,   4.4658402E-05,   4.1592662E-05,   3.8668230E-05
     +,   3.5886176E-05,   3.3245800E-05,   3.0744843E-05
     +,   2.8380298E-05,   2.6148973E-05,   2.4047498E-05
     +,   2.2072338E-05,   2.0219981E-05,   1.8486990E-05
     +,   1.6869832E-05,   1.5364723E-05,   1.3967681E-05
     +,   1.2674639E-05,   1.1481097E-05,   1.0382495E-05
     +,   9.3739118E-06,   8.4504100E-06,   7.6068168E-06
     +,   6.8380377E-06,   6.1388901E-06,   5.5043647E-06
     +,   4.9294908E-06,   4.4095550E-06,   3.9399965E-06
     +,   3.5164962E-06,   3.1350360E-06,   2.7918093E-06
     +,   2.4833305E-06,   2.2063391E-06,   1.9578749E-06
     +,   1.7351962E-06,   1.5358278E-06,   1.3574929E-06
     +,   1.1981446E-06,   1.0559042E-06,   9.2908959E-07
     +,   8.1615906E-07,   7.1573101E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz117 = Yx/0.0872307692307692
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3846321E-07,   1.5218963E-07
     +,   1.6710072E-07,   1.8327978E-07,   2.0081413E-07
     +,   2.1979470E-07,   2.4031667E-07,   2.6247895E-07
     +,   2.8638379E-07,   3.1213875E-07,   3.3985356E-07
     +,   3.6964175E-07,   4.0162050E-07,   4.3591001E-07
     +,   4.7263342E-07,   5.1191671E-07,   5.5388801E-07
     +,   5.9867801E-07,   6.4641881E-07,   6.9724399E-07
     +,   7.5128918E-07,   8.0868938E-07,   8.6957976E-07
     +,   9.3409926E-07,   1.0023798E-06,   1.0745589E-06
     +,   1.1507691E-06,   1.2311432E-06,   1.3158113E-06
     +,   1.4049029E-06,   1.4985438E-06,   1.5968599E-06
     +,   1.6999743E-06,   1.8080090E-06,   1.9210856E-06
     +,   2.0393270E-06,   2.1628564E-06,   2.2918011E-06
     +,   2.4263013E-06,   2.5664924E-06,   2.7125388E-06
     +,   2.8646152E-06,   3.0229212E-06,   3.1876896E-06
     +,   3.3591955E-06,   3.5377634E-06,   3.7237839E-06
     +,   3.9177257E-06,   4.1201542E-06,   4.3317527E-06
     +,   4.5533416E-06,   4.7859089E-06,   5.0306312E-06
     +,   5.2889332E-06,   5.5624660E-06,   5.8532169E-06
     +,   6.1634992E-06,   6.4960186E-06,   6.8539107E-06
     +,   7.2407952E-06,   7.6608112E-06,   8.1186836E-06
     +,   8.6197133E-06,   9.1698839E-06,   9.7758630E-06
     +,   1.0444955E-05,   1.1185243E-05,   1.2005406E-05
     +,   1.2914881E-05,   1.3923619E-05,   1.5042216E-05
     +,   1.6281576E-05,   1.7653065E-05,   1.9168014E-05
     +,   2.0837875E-05,   2.2673834E-05,   2.4686471E-05
     +,   2.6885560E-05,   2.9279934E-05,   3.1877047E-05
     +,   3.4682387E-05,   3.7699723E-05,   4.0930066E-05
     +,   4.4372169E-05,   4.8021324E-05,   5.1870109E-05
     +,   5.5907130E-05,   6.0118011E-05,   6.4484135E-05
     +,   6.8983703E-05,   7.3591400E-05,   7.8278259E-05
     +,   8.3012266E-05,   8.7759057E-05,   9.2482078E-05
     +,   9.7142642E-05,   1.0170180E-04,   1.0611967E-04
     +,   1.1035751E-04,   1.1437733E-04,   1.1814381E-04
     +,   1.2162407E-04,   1.2478951E-04,   1.2761551E-04
     +,   1.3008284E-04,   1.3217815E-04,   1.3389390E-04
     +,   1.3522923E-04,   1.3619006E-04,   1.3678907E-04
     +,   1.3704560E-04,   1.3698543E-04,   1.3664064E-04
     +,   1.3604872E-04,   1.3525247E-04,   1.3429899E-04
     +,   1.3323918E-04,   1.3212694E-04,   1.3101849E-04
     +,   1.2997161E-04,   1.2904509E-04,   1.2829831E-04
     +,   1.2779061E-04,   1.2758120E-04,   1.2772900E-04
     +,   1.2829255E-04,   1.2933025E-04,   1.3090036E-04
     +,   1.3306151E-04,   1.3587250E-04,   1.3939296E-04
     +,   1.4368244E-04,   1.4880100E-04,   1.5480739E-04
     +,   1.6175886E-04,   1.6970893E-04,   1.7870469E-04
     +,   1.8878419E-04,   1.9997367E-04,   2.1228346E-04
     +,   2.2570272E-04,   2.4019639E-04,   2.5570201E-04
     +,   2.7212556E-04,   2.8933771E-04,   3.0717524E-04
     +,   3.2544014E-04,   3.4390052E-04,   3.6229519E-04
     +,   3.8034123E-04,   3.9774075E-04,   4.1418822E-04
     +,   4.2938389E-04,   4.4304488E-04,   4.5491676E-04
     +,   4.6478340E-04,   4.7247889E-04,   4.7789648E-04
     +,   4.8099371E-04,   4.8179665E-04,   4.8040145E-04
     +,   4.7697214E-04,   4.7173607E-04,   4.6497819E-04
     +,   4.5703159E-04,   4.4826782E-04,   4.3908809E-04
     +,   4.2991340E-04,   4.2117466E-04,   4.1330766E-04
     +,   4.0674783E-04,   4.0192905E-04,   3.9928398E-04
     +,   3.9924934E-04,   4.0227314E-04,   4.0882389E-04
     +,   4.1940389E-04,   4.3455834E-04,   4.5488501E-04
     +,   4.8103975E-04,   5.1373028E-04,   5.5369246E-04
     +,   6.0165185E-04,   6.5826008E-04,   7.2399701E-04
     +,   7.9904002E-04,   8.8311126E-04,   9.7531953E-04
     +,   1.0740149E-03,   1.1767022E-03,   1.2801321E-03
     +,   1.3805656E-03,   1.4743194E-03,   1.5585707E-03
     +,   1.6323316E-03,   1.6973267E-03,   1.7585042E-03
     +,   1.8237989E-03,   1.9029777E-03,   2.0056299E-03
     +,   2.1388407E-03,   2.3054450E-03,   2.5037872E-03
     +,   2.7296341E-03,   2.9802208E-03,   3.2598360E-03
     +,   3.5850508E-03,   3.9865258E-03,   4.5026550E-03
     +,   5.1620575E-03,   5.9604254E-03,   6.8486384E-03
     +,   7.7482364E-03,   8.5908091E-03,   9.3598366E-03
     +,   1.0113141E-02,   1.0964921E-02,   1.2014788E-02
     +,   1.3263395E-02,   1.4605427E-02,   1.5919872E-02
     +,   1.7131897E-02,   1.8131394E-02,   1.8644568E-02
     +,   1.8271022E-02,   1.6720681E-02,   1.4050929E-02
     +,   1.0707492E-02,   7.3436033E-03,   4.5353356E-03
     +,   2.5652337E-03,   1.3946225E-03,   7.9904363E-04
     +,   5.3357176E-04,   4.2390049E-04,   3.7570379E-04
     +,   3.4736894E-04,   3.2311375E-04,   2.9782660E-04
     +,   2.7066091E-04,   2.4254342E-04,   2.1499838E-04
     +,   1.8946429E-04,   1.6693650E-04,   1.4787157E-04
     +,   1.3225600E-04,   1.1974678E-04,   1.0982093E-04
     +,   1.0190043E-04,   9.5437608E-05,   8.9963083E-05
     +,   8.5107189E-05,   8.0601239E-05,   7.6266042E-05
     +,   7.1994953E-05,   6.7736146E-05,   6.3476095E-05
     +,   5.9225567E-05,   5.5008750E-05,   5.0855968E-05
     +,   4.6798985E-05,   4.2867618E-05,   3.9087703E-05
     +,   3.5480614E-05,   3.2063286E-05,   2.8847649E-05
     +,   2.5841289E-05,   2.3048087E-05,   2.0468437E-05
     +,   1.8099585E-05,   1.5936343E-05,   1.3971628E-05
     +,   1.2196740E-05,   1.0601641E-05,   9.1754500E-06
     +,   7.9068532E-06,   6.7840642E-06,   5.7953876E-06
     +,   4.9291079E-06,   4.1739186E-06,   3.5188193E-06
     +,   2.9534206E-06,   2.4678436E-06,   2.0529285E-06
     +,   1.7001402E-06,   1.4016906E-06,   1.1504607E-06
     +,   9.4002502E-07,   7.6464750E-07,   6.1920173E-07
     +,   4.9918373E-07,   4.0062920E-07,   3.2010203E-07
     +,   2.5462197E-07,   2.0163968E-07,   1.5897452E-07
     +,   1.2478516E-07,   9.7517038E-08,   7.5874141E-08
     +,   5.8776212E-08,   4.5333252E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz118 = Yx/0.0775384615384615
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9965539E-06,   4.1386479E-06
     +,   4.2835709E-06,   4.4312910E-06,   4.5817724E-06
     +,   4.7349795E-06,   4.8908714E-06,   5.0494077E-06
     +,   5.2105438E-06,   5.3742410E-06,   5.5404516E-06
     +,   5.7091338E-06,   5.8802425E-06,   6.0537345E-06
     +,   6.2295703E-06,   6.4077085E-06,   6.5881136E-06
     +,   6.7707538E-06,   6.9555986E-06,   7.1426257E-06
     +,   7.3318183E-06,   7.5231633E-06,   7.7166560E-06
     +,   7.9123129E-06,   8.1101352E-06,   8.3101586E-06
     +,   8.5124193E-06,   8.7169701E-06,   8.9238738E-06
     +,   9.1332122E-06,   9.3450826E-06,   9.5596006E-06
     +,   9.7768998E-06,   9.9971312E-06,   1.0220471E-05
     +,   1.0447114E-05,   1.0677277E-05,   1.0911197E-05
     +,   1.1149155E-05,   1.1391421E-05,   1.1638322E-05
     +,   1.1890197E-05,   1.2147413E-05,   1.2410357E-05
     +,   1.2679448E-05,   1.2955133E-05,   1.3237874E-05
     +,   1.3528160E-05,   1.3826507E-05,   1.4133456E-05
     +,   1.4449557E-05,   1.4775392E-05,   1.5111556E-05
     +,   1.5458678E-05,   1.5817366E-05,   1.6188285E-05
     +,   1.6572105E-05,   1.6969496E-05,   1.7381155E-05
     +,   1.7807801E-05,   1.8250155E-05,   1.8708983E-05
     +,   1.9185025E-05,   1.9679106E-05,   2.0192068E-05
     +,   2.0724743E-05,   2.1278089E-05,   2.1853031E-05
     +,   2.2450640E-05,   2.3072000E-05,   2.3718347E-05
     +,   2.4390962E-05,   2.5091331E-05,   2.5820978E-05
     +,   2.6581705E-05,   2.7375469E-05,   2.8204424E-05
     +,   2.9070938E-05,   2.9977720E-05,   3.0927764E-05
     +,   3.1924323E-05,   3.2971100E-05,   3.4072084E-05
     +,   3.5231795E-05,   3.6455032E-05,   3.7747239E-05
     +,   3.9114173E-05,   4.0562281E-05,   4.2098331E-05
     +,   4.3729840E-05,   4.5464876E-05,   4.7311984E-05
     +,   4.9280359E-05,   5.1379946E-05,   5.3621399E-05
     +,   5.6015884E-05,   5.8575650E-05,   6.1313447E-05
     +,   6.4243301E-05,   6.7379849E-05,   7.0739217E-05
     +,   7.4338233E-05,   7.8195510E-05,   8.2330473E-05
     +,   8.6764368E-05,   9.1519862E-05,   9.6620832E-05
     +,   1.0209242E-04,   1.0796140E-04,   1.1425545E-04
     +,   1.2100235E-04,   1.2823076E-04,   1.3596797E-04
     +,   1.4424106E-04,   1.5307378E-04,   1.6248779E-04
     +,   1.7249945E-04,   1.8312059E-04,   1.9435505E-04
     +,   2.0619966E-04,   2.1864221E-04,   2.3165952E-04
     +,   2.4521735E-04,   2.5927080E-04,   2.7376370E-04
     +,   2.8862670E-04,   3.0378174E-04,   3.1913930E-04
     +,   3.3460368E-04,   3.5007112E-04,   3.6543602E-04
     +,   3.8058974E-04,   3.9542734E-04,   4.0984631E-04
     +,   4.2375273E-04,   4.3706258E-04,   4.4970296E-04
     +,   4.6161481E-04,   4.7275468E-04,   4.8309541E-04
     +,   4.9262424E-04,   5.0134398E-04,   5.0927274E-04
     +,   5.1644078E-04,   5.2288943E-04,   5.2866910E-04
     +,   5.3383689E-04,   5.3845468E-04,   5.4258603E-04
     +,   5.4629531E-04,   5.4964476E-04,   5.5269292E-04
     +,   5.5549282E-04,   5.5809080E-04,   5.6052546E-04
     +,   5.6282594E-04,   5.6501257E-04,   5.6709728E-04
     +,   5.6908454E-04,   5.7097297E-04,   5.7276047E-04
     +,   5.7444844E-04,   5.7604752E-04,   5.7758566E-04
     +,   5.7911593E-04,   5.8072357E-04,   5.8253366E-04
     +,   5.8471458E-04,   5.8747985E-04,   5.9108407E-04
     +,   5.9581356E-04,   6.0196960E-04,   6.0984801E-04
     +,   6.1971060E-04,   6.3175528E-04,   6.4608583E-04
     +,   6.6268636E-04,   6.8140315E-04,   7.0194062E-04
     +,   7.2387862E-04,   7.4670470E-04,   7.6986692E-04
     +,   7.9284556E-04,   8.1523263E-04,   8.3680701E-04
     +,   8.5759372E-04,   8.7789382E-04,   8.9827791E-04
     +,   9.1952767E-04,   9.4253919E-04,   9.6820819E-04
     +,   9.9732075E-04,   1.0304903E-03,   1.0681982E-03
     +,   1.1109649E-03,   1.1596589E-03,   1.2159172E-03
     +,   1.2825839E-03,   1.3640622E-03,   1.4664133E-03
     +,   1.5971141E-03,   1.7644602E-03,   1.9766514E-03
     +,   2.2406273E-03,   2.5608651E-03,   2.9386252E-03
     +,   3.3719742E-03,   3.8568513E-03,   4.3889037E-03
     +,   4.9652238E-03,   5.5853296E-03,   6.2516690E-03
     +,   6.9695762E-03,   7.7449861E-03,   8.5786674E-03
     +,   9.4609056E-03,   1.0375740E-02,   1.1318345E-02
     +,   1.2312211E-02,   1.3398198E-02,   1.4576844E-02
     +,   1.5725702E-02,   1.6561616E-02,   1.6714657E-02
     +,   1.5901709E-02,   1.4094220E-02,   1.1562083E-02
     +,   8.7630469E-03,   6.1551984E-03,   4.0452136E-03
     +,   2.5366526E-03,   1.5702524E-03,   1.0061235E-03
     +,   6.9735380E-04,   5.3035386E-04,   4.3374376E-04
     +,   3.6985980E-04,   3.2182777E-04,   2.8317460E-04
     +,   2.5159374E-04,   2.2597609E-04,   2.0533772E-04
     +,   1.8861846E-04,   1.7477435E-04,   1.6290431E-04
     +,   1.5232161E-04,   1.4256481E-04,   1.3336724E-04
     +,   1.2460754E-04,   1.1625710E-04,   1.0833304E-04
     +,   1.0086675E-04,   9.3885035E-05,   8.7400789E-05
     +,   8.1410901E-05,   7.5898621E-05,   7.0837290E-05
     +,   6.6193403E-05,   6.1929211E-05,   5.8005502E-05
     +,   5.4383523E-05,   5.1026058E-05,   4.7898204E-05
     +,   4.4968441E-05,   4.2209351E-05,   3.9597344E-05
     +,   3.7113041E-05,   3.4741275E-05,   3.2470620E-05
     +,   3.0292806E-05,   2.8202379E-05,   2.6196305E-05
     +,   2.4273244E-05,   2.2432949E-05,   2.0675941E-05
     +,   1.9003286E-05,   1.7415878E-05,   1.5914657E-05
     +,   1.4499993E-05,   1.3171975E-05,   1.1929981E-05
     +,   1.0772997E-05,   9.6993035E-06,   8.7068038E-06
     +,   7.7928116E-06,   6.9543539E-06,   6.1880382E-06
     +,   5.4902180E-06,   4.8571187E-06,   4.2847564E-06
     +,   3.7691605E-06,   3.3062800E-06,   2.8921704E-06
     +,   2.5229151E-06,   2.1947667E-06,   1.9040813E-06
     +,   1.6474273E-06,   1.4215240E-06,   1.2233221E-06
     +,   1.0499505E-06,   8.9877102E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz119 = Yx/0.0727631578947368
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0486255E-06,   9.3941399E-06
     +,   9.7462835E-06,   1.0104963E-05,   1.0470089E-05
     +,   1.0841586E-05,   1.1219388E-05,   1.1603446E-05
     +,   1.1993718E-05,   1.2390209E-05,   1.2792922E-05
     +,   1.3201898E-05,   1.3617203E-05,   1.4038940E-05
     +,   1.4467246E-05,   1.4902294E-05,   1.5344300E-05
     +,   1.5793519E-05,   1.6250255E-05,   1.6714854E-05
     +,   1.7187716E-05,   1.7669287E-05,   1.8160048E-05
     +,   1.8660570E-05,   1.9171419E-05,   1.9693258E-05
     +,   2.0226771E-05,   2.0772695E-05,   2.1331811E-05
     +,   2.1904933E-05,   2.2492919E-05,   2.3096658E-05
     +,   2.3717070E-05,   2.4355093E-05,   2.5011675E-05
     +,   2.5687794E-05,   2.6384414E-05,   2.7102496E-05
     +,   2.7843027E-05,   2.8606903E-05,   2.9395080E-05
     +,   3.0208415E-05,   3.1047766E-05,   3.1913914E-05
     +,   3.2807609E-05,   3.3729535E-05,   3.4680284E-05
     +,   3.5660429E-05,   3.6670401E-05,   3.7710612E-05
     +,   3.8781345E-05,   3.9882820E-05,   4.1015159E-05
     +,   4.2178464E-05,   4.3372609E-05,   4.4597567E-05
     +,   4.5853125E-05,   4.7139034E-05,   4.8454996E-05
     +,   4.9800659E-05,   5.1175644E-05,   5.2579566E-05
     +,   5.4011958E-05,   5.5472465E-05,   5.6960773E-05
     +,   5.8476508E-05,   6.0019520E-05,   6.1589591E-05
     +,   6.3186846E-05,   6.4811349E-05,   6.6463581E-05
     +,   6.8144021E-05,   6.9853668E-05,   7.1593568E-05
     +,   7.3365263E-05,   7.5170719E-05,   7.7012162E-05
     +,   7.8892350E-05,   8.0814541E-05,   8.2782622E-05
     +,   8.4800820E-05,   8.6874206E-05,   8.9008172E-05
     +,   9.1209011E-05,   9.3483330E-05,   9.5838572E-05
     +,   9.8282515E-05,   1.0082366E-04,   1.0347056E-04
     +,   1.0623244E-04,   1.0911862E-04,   1.1213830E-04
     +,   1.1530052E-04,   1.1861419E-04,   1.2208757E-04
     +,   1.2572786E-04,   1.2954162E-04,   1.3353353E-04
     +,   1.3770710E-04,   1.4206351E-04,   1.4660222E-04
     +,   1.5131976E-04,   1.5621046E-04,   1.6126552E-04
     +,   1.6647344E-04,   1.7181995E-04,   1.7728725E-04
     +,   1.8285502E-04,   1.8850030E-04,   1.9419794E-04
     +,   1.9992024E-04,   2.0563854E-04,   2.1132236E-04
     +,   2.1694163E-04,   2.2246575E-04,   2.2786562E-04
     +,   2.3311320E-04,   2.3818341E-04,   2.4305355E-04
     +,   2.4770529E-04,   2.5212439E-04,   2.5630128E-04
     +,   2.6023161E-04,   2.6391677E-04,   2.6736376E-04
     +,   2.7058480E-04,   2.7359798E-04,   2.7642591E-04
     +,   2.7909633E-04,   2.8164030E-04,   2.8409241E-04
     +,   2.8648932E-04,   2.8886905E-04,   2.9126962E-04
     +,   2.9372863E-04,   2.9628180E-04,   2.9896179E-04
     +,   3.0179764E-04,   3.0481399E-04,   3.0802994E-04
     +,   3.1145898E-04,   3.1510813E-04,   3.1897757E-04
     +,   3.2306174E-04,   3.2734772E-04,   3.3181653E-04
     +,   3.3644421E-04,   3.4120094E-04,   3.4605272E-04
     +,   3.5096292E-04,   3.5589293E-04,   3.6080362E-04
     +,   3.6565631E-04,   3.7041627E-04,   3.7505326E-04
     +,   3.7954393E-04,   3.8387423E-04,   3.8804210E-04
     +,   3.9205948E-04,   3.9595418E-04,   3.9977254E-04
     +,   4.0358011E-04,   4.0746201E-04,   4.1152223E-04
     +,   4.1588207E-04,   4.2067561E-04,   4.2604370E-04
     +,   4.3212660E-04,   4.3905622E-04,   4.4694610E-04
     +,   4.5588301E-04,   4.6592148E-04,   4.7708451E-04
     +,   4.8937026E-04,   5.0276768E-04,   5.1728764E-04
     +,   5.3300353E-04,   5.5009936E-04,   5.6892767E-04
     +,   5.9006101E-04,   6.1432860E-04,   6.4282044E-04
     +,   6.7685440E-04,   7.1789167E-04,   7.6739461E-04
     +,   8.2663976E-04,   8.9650956E-04,   9.7730034E-04
     +,   1.0685739E-03,   1.1690923E-03,   1.2769081E-03
     +,   1.3895661E-03,   1.5044162E-03,   1.6190351E-03
     +,   1.7316531E-03,   1.8415196E-03,   1.9491505E-03
     +,   2.0564282E-03,   2.1665175E-03,   2.2835890E-03
     +,   2.4124046E-03,   2.5578158E-03,   2.7242263E-03
     +,   2.9150133E-03,   3.1320120E-03,   3.3753449E-03
     +,   3.6437777E-03,   3.9359131E-03,   4.2520799E-03
     +,   4.5963395E-03,   4.9776421E-03,   5.4098074E-03
     +,   5.9104185E-03,   6.4993058E-03,   7.1965419E-03
     +,   8.0187032E-03,   8.9708846E-03,   1.0033340E-02
     +,   1.1146761E-02,   1.2206063E-02,   1.3072667E-02
     +,   1.3603867E-02,   1.3688046E-02,   1.3270078E-02
     +,   1.2360190E-02,   1.1030133E-02,   9.4029577E-03
     +,   7.6367576E-03,   5.8997264E-03,   4.3392796E-03
     +,   3.0544018E-03,   2.0823658E-03,   1.4046459E-03
     +,   9.6697256E-04,   7.0280343E-04,   5.5120757E-04
     +,   4.6577048E-04,   4.1567630E-04,   3.8260850E-04
     +,   3.5666666E-04,   3.3299217E-04,   3.0953225E-04
     +,   2.8572077E-04,   2.6172277E-04,   2.3799874E-04
     +,   2.1504860E-04,   1.9327484E-04,   1.7293335E-04
     +,   1.5414452E-04,   1.3693284E-04,   1.2126562E-04
     +,   1.0708873E-04,   9.4345793E-05,   8.2982908E-05
     +,   7.2945193E-05,   6.4171778E-05,   5.6590816E-05
     +,   5.0116261E-05,   4.4648183E-05,   4.0076688E-05
     +,   3.6286976E-05,   3.3164197E-05,   3.0598079E-05
     +,   2.8487017E-05,   2.6740647E-05,   2.5280748E-05
     +,   2.4041687E-05,   2.2969924E-05,   2.2022812E-05
     +,   2.1167194E-05,   2.0377978E-05,   1.9636745E-05
     +,   1.8930346E-05,   1.8249699E-05,   1.7588836E-05
     +,   1.6944174E-05,   1.6313681E-05,   1.5696560E-05
     +,   1.5092683E-05,   1.4502472E-05,   1.3926527E-05
     +,   1.3365619E-05,   1.2820453E-05,   1.2291730E-05
     +,   1.1779976E-05,   1.1285641E-05,   1.0808985E-05
     +,   1.0350118E-05,   9.9090630E-06,   9.4856496E-06
     +,   9.0796484E-06,   8.6906721E-06,   8.3183022E-06
     +,   7.9619977E-06,   7.6212118E-06,   7.2953071E-06
     +,   6.9836638E-06,   6.6855991E-06,   6.4004689E-06
     +,   6.1275923E-06,   5.8663359E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz120 = Yx/0.0676052631578947
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5643703E-06,   2.7282806E-06
     +,   2.9016499E-06,   3.0849567E-06,   3.2786977E-06
     +,   3.4833815E-06,   3.6995325E-06,   3.9276870E-06
     +,   4.1683870E-06,   4.4221979E-06,   4.6896776E-06
     +,   4.9713922E-06,   5.2679097E-06,   5.5797977E-06
     +,   5.9076137E-06,   6.2519116E-06,   6.6132270E-06
     +,   6.9920825E-06,   7.3889719E-06,   7.8043695E-06
     +,   8.2387087E-06,   8.6923910E-06,   9.1657639E-06
     +,   9.6591584E-06,   1.0172793E-05,   1.0706887E-05
     +,   1.1261560E-05,   1.1836870E-05,   1.2432801E-05
     +,   1.3049259E-05,   1.3686069E-05,   1.4342974E-05
     +,   1.5019631E-05,   1.5715610E-05,   1.6430406E-05
     +,   1.7163424E-05,   1.7913995E-05,   1.8681370E-05
     +,   1.9464789E-05,   2.0263351E-05,   2.1076212E-05
     +,   2.1902448E-05,   2.2741153E-05,   2.3591421E-05
     +,   2.4452409E-05,   2.5323327E-05,   2.6203483E-05
     +,   2.7092317E-05,   2.7989416E-05,   2.8894576E-05
     +,   2.9807819E-05,   3.0729432E-05,   3.1660002E-05
     +,   3.2600514E-05,   3.3552231E-05,   3.4516946E-05
     +,   3.5496851E-05,   3.6494632E-05,   3.7513506E-05
     +,   3.8557253E-05,   3.9630220E-05,   4.0737414E-05
     +,   4.1884396E-05,   4.3077536E-05,   4.4323897E-05
     +,   4.5631255E-05,   4.7008361E-05,   4.8464713E-05
     +,   5.0011022E-05,   5.1658928E-05,   5.3421554E-05
     +,   5.5313198E-05,   5.7350018E-05,   5.9549733E-05
     +,   6.1932224E-05,   6.4519663E-05,   6.7336536E-05
     +,   7.0409995E-05,   7.3770309E-05,   7.7451034E-05
     +,   8.1488790E-05,   8.5924643E-05,   9.0803340E-05
     +,   9.6175347E-05,   1.0209625E-04,   1.0862968E-04
     +,   1.1584705E-04,   1.2383157E-04,   1.3267853E-04
     +,   1.4249957E-04,   1.5342457E-04,   1.6560234E-04
     +,   1.7920155E-04,   1.9441018E-04,   2.1142948E-04
     +,   2.3046350E-04,   2.5170998E-04,   2.7534060E-04
     +,   3.0149327E-04,   3.3026576E-04,   3.6174920E-04
     +,   3.9609926E-04,   4.3369996E-04,   4.7540956E-04
     +,   5.2292756E-04,   5.7921646E-04,   6.4889202E-04
     +,   7.3842373E-04,   8.5592887E-04,   1.0103550E-03
     +,   1.2099937E-03,   1.4606462E-03,   1.7639565E-03
     +,   2.1170876E-03,   2.5144236E-03,   2.9519359E-03
     +,   3.4331512E-03,   3.9754203E-03,   4.6134186E-03
     +,   5.3961179E-03,   6.3707530E-03,   7.5503364E-03
     +,   8.8757817E-03,   1.0203988E-02,   1.1354962E-02
     +,   1.2207919E-02,   1.2775356E-02,   1.3177266E-02
     +,   1.3524766E-02,   1.3820073E-02,   1.3973018E-02
     +,   1.3913492E-02,   1.3684207E-02,   1.3429237E-02
     +,   1.3299585E-02,   1.3353226E-02,   1.3512551E-02
     +,   1.3605698E-02,   1.3474789E-02,   1.3080268E-02
     +,   1.2520714E-02,   1.1957406E-02,   1.1513608E-02
     +,   1.1221152E-02,   1.1028170E-02,   1.0838779E-02
     +,   1.0555415E-02,   1.0110340E-02,   9.4837639E-03
     +,   8.7083615E-03,   7.8581572E-03,   7.0227669E-03
     +,   6.2770224E-03,   5.6613362E-03,   5.1803775E-03
     +,   4.8150728E-03,   4.5375228E-03,   4.3212459E-03
     +,   4.1450309E-03,   3.9924635E-03,   3.8501217E-03
     +,   3.7066001E-03,   3.5526941E-03,   3.3822202E-03
     +,   3.1927645E-03,   2.9858092E-03,   2.7661829E-03
     +,   2.5409625E-03,   2.3182116E-03,   2.1058714E-03
     +,   1.9109258E-03,   1.7388901E-03,   1.5935894E-03
     +,   1.4771859E-03,   1.3903528E-03,   1.3324815E-03
     +,   1.3019382E-03,   1.2962599E-03,   1.3122899E-03
     +,   1.3462731E-03,   1.3939221E-03,   1.4505028E-03
     +,   1.5109784E-03,   1.5702192E-03,   1.6232695E-03
     +,   1.6656506E-03,   1.6936683E-03,   1.7046675E-03
     +,   1.6971906E-03,   1.6710396E-03,   1.6271987E-03
     +,   1.5676656E-03,   1.4951952E-03,   1.4130003E-03
     +,   1.3244376E-03,   1.2327387E-03,   1.1407996E-03
     +,   1.0510240E-03,   9.6524449E-04,   8.8471884E-04
     +,   8.1017782E-04,   7.4189558E-04,   6.7978265E-04
     +,   6.2349351E-04,   5.7252485E-04,   5.2628812E-04
     +,   4.8418008E-04,   4.4563453E-04,   4.1014902E-04
     +,   3.7730089E-04,   3.4675439E-04,   3.1825810E-04
     +,   2.9163313E-04,   2.6675747E-04,   2.4355260E-04
     +,   2.2197026E-04,   2.0197705E-04,   1.8354283E-04
     +,   1.6663353E-04,   1.5120739E-04,   1.3720896E-04
     +,   1.2457003E-04,   1.1321131E-04,   1.0304381E-04
     +,   9.3970688E-05,   8.5891523E-05,   7.8705554E-05
     +,   7.2313866E-05,   6.6621236E-05,   6.1538674E-05
     +,   5.6984682E-05,   5.2885855E-05,   4.9176939E-05
     +,   4.5801058E-05,   4.2709864E-05,   3.9862207E-05
     +,   3.7223854E-05,   3.4766927E-05,   3.2468881E-05
     +,   3.0311583E-05,   2.8280714E-05,   2.6365198E-05
     +,   2.4556426E-05,   2.2847553E-05,   2.1233220E-05
     +,   1.9709185E-05,   1.8271920E-05,   1.6918255E-05
     +,   1.5645297E-05,   1.4450397E-05,   1.3330796E-05
     +,   1.2283705E-05,   1.1306327E-05,   1.0395772E-05
     +,   9.5489950E-06,   8.7628923E-06,   8.0343643E-06
     +,   7.3602801E-06,   6.7374654E-06,   6.1627852E-06
     +,   5.6331955E-06,   5.1457291E-06,   4.6974787E-06
     +,   4.2856568E-06,   3.9076376E-06,   3.5608898E-06
     +,   3.2430239E-06,   2.9518144E-06,   2.6851749E-06
     +,   2.4411390E-06,   2.2178829E-06,   2.0137293E-06
     +,   1.8271254E-06,   1.6566256E-06,   1.5009001E-06
     +,   1.3587397E-06,   1.2290137E-06,   1.1107026E-06
     +,   1.0028522E-06,   9.0460372E-07,   8.1515367E-07
     +,   7.3377743E-07,   6.5979810E-07,   5.9260333E-07
     +,   5.3162188E-07,   4.7633557E-07,   4.2626198E-07
     +,   3.8095726E-07,   3.4001670E-07,   3.0306168E-07
     +,   2.6974828E-07,   2.3975485E-07,   2.1278890E-07
     +,   1.8857710E-07,   1.6687109E-07,   1.4743888E-07
     +,   1.3006989E-07,   1.1456833E-07,   1.0075606E-07
     +,   8.8467942E-08,   7.7554596E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz75 = Yx/0.124
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1589624E-07,   4.5554228E-07
     +,   4.9840094E-07,   5.4467284E-07,   5.9456539E-07
     +,   6.4829271E-07,   7.0607496E-07,   7.6813728E-07
     +,   8.3470940E-07,   9.0602805E-07,   9.8233090E-07
     +,   1.0638594E-06,   1.1508569E-06,   1.2435678E-06
     +,   1.3422375E-06,   1.4471088E-06,   1.5584243E-06
     +,   1.6764204E-06,   1.8013325E-06,   1.9333861E-06
     +,   2.0728021E-06,   2.2197889E-06,   2.3745454E-06
     +,   2.5372660E-06,   2.7081137E-06,   2.8872539E-06
     +,   3.0748240E-06,   3.2709447E-06,   3.4757165E-06
     +,   3.6892161E-06,   3.9114966E-06,   4.1425847E-06
     +,   4.3824798E-06,   4.6311516E-06,   4.8885395E-06
     +,   5.1545521E-06,   5.4290613E-06,   5.7119023E-06
     +,   6.0028956E-06,   6.3017874E-06,   6.6083262E-06
     +,   6.9222006E-06,   7.2430685E-06,   7.5705502E-06
     +,   7.9042311E-06,   8.2436627E-06,   8.5883594E-06
     +,   8.9378054E-06,   9.2914552E-06,   9.6487383E-06
     +,   1.0009058E-05,   1.0371807E-05,   1.0736346E-05
     +,   1.1102065E-05,   1.1468304E-05,   1.1834457E-05
     +,   1.2199907E-05,   1.2564078E-05,   1.2926424E-05
     +,   1.3286462E-05,   1.3643770E-05,   1.3998020E-05
     +,   1.4348963E-05,   1.4696512E-05,   1.5040722E-05
     +,   1.5381805E-05,   1.5720223E-05,   1.6056654E-05
     +,   1.6392114E-05,   1.6727940E-05,   1.7065926E-05
     +,   1.7408336E-05,   1.7758081E-05,   1.8118755E-05
     +,   1.8494844E-05,   1.8891884E-05,   1.9316627E-05
     +,   1.9777286E-05,   2.0283842E-05,   2.0848320E-05
     +,   2.1485030E-05,   2.2211052E-05,   2.3046403E-05
     +,   2.4014555E-05,   2.5142523E-05,   2.6461326E-05
     +,   2.8005903E-05,   2.9815430E-05,   3.1932890E-05
     +,   3.4405184E-05,   3.7282618E-05,   4.0618081E-05
     +,   4.4466531E-05,   4.8884463E-05,   5.3929005E-05
     +,   5.9656653E-05,   6.6124092E-05,   7.3386771E-05
     +,   8.1501137E-05,   9.0524307E-05,   1.0051865E-04
     +,   1.1155321E-04,   1.2371113E-04,   1.3709326E-04
     +,   1.5182800E-04,   1.6807849E-04,   1.8604947E-04
     +,   2.0599533E-04,   2.2822697E-04,   2.5311287E-04
     +,   2.8107475E-04,   3.1258780E-04,   3.4816435E-04
     +,   3.8835389E-04,   4.3372883E-04,   4.8490067E-04
     +,   5.4252631E-04,   6.0735265E-04,   6.8023888E-04
     +,   7.6220208E-04,   8.5442484E-04,   9.5824682E-04
     +,   1.0752002E-03,   1.2071789E-03,   1.3568937E-03
     +,   1.5287406E-03,   1.7301383E-03,   1.9727915E-03
     +,   2.2732571E-03,   2.6516423E-03,   3.1282434E-03
     +,   3.7185531E-03,   4.4293529E-03,   5.2582310E-03
     +,   6.1969324E-03,   7.2303568E-03,   8.3234617E-03
     +,   9.4166193E-03,   1.0482888E-02,   1.1633749E-02
     +,   1.3097451E-02,   1.4972837E-02,   1.7098112E-02
     +,   1.9335009E-02,   2.1735312E-02,   2.4139093E-02
     +,   2.6057938E-02,   2.7244193E-02,   2.7816219E-02
     +,   2.7857503E-02,   2.7492598E-02,   2.7103694E-02
     +,   2.6876794E-02,   2.6343962E-02,   2.4922915E-02
     +,   2.2616295E-02,   1.9893482E-02,   1.7304339E-02
     +,   1.5175262E-02,   1.3441572E-02,   1.1861198E-02
     +,   1.0345742E-02,   8.9944806E-03,   7.9119653E-03
     +,   7.0930659E-03,   6.4556813E-03,   5.9184795E-03
     +,   5.4340614E-03,   4.9796263E-03,   4.5431391E-03
     +,   4.1207573E-03,   3.7180034E-03,   3.3468667E-03
     +,   3.0195233E-03,   2.7430786E-03,   2.5177973E-03
     +,   2.3384639E-03,   2.1968575E-03,   2.0839521E-03
     +,   1.9913698E-03,   1.9121646E-03,   1.8411480E-03
     +,   1.7748943E-03,   1.7115340E-03,   1.6504022E-03
     +,   1.5915941E-03,   1.5355238E-03,   1.4825517E-03
     +,   1.4327394E-03,   1.3857482E-03,   1.3408372E-03
     +,   1.2969825E-03,   1.2530433E-03,   1.2079474E-03
     +,   1.1608569E-03,   1.1112947E-03,   1.0592142E-03
     +,   1.0049918E-03,   9.4936532E-04,   8.9333043E-04
     +,   8.3801599E-04,   7.8454794E-04,   7.3392864E-04
     +,   6.8695232E-04,   6.4415415E-04,   6.0578436E-04
     +,   5.7182560E-04,   5.4203375E-04,   5.1598792E-04
     +,   4.9314846E-04,   4.7291763E-04,   4.5469197E-04
     +,   4.3790243E-04,   4.2204277E-04,   4.0668948E-04
     +,   3.9151005E-04,   3.7626302E-04,   3.6078974E-04
     +,   3.4500685E-04,   3.2889476E-04,   3.1248288E-04
     +,   2.9583790E-04,   2.7905439E-04,   2.6224306E-04
     +,   2.4552154E-04,   2.2900851E-04,   2.1281875E-04
     +,   1.9705860E-04,   1.8182113E-04,   1.6718595E-04
     +,   1.5321867E-04,   1.3996962E-04,   1.2747338E-04
     +,   1.1575054E-04,   1.0480986E-04,   9.4647417E-05
     +,   8.5249558E-05,   7.6594923E-05,   6.8655507E-05
     +,   6.1397695E-05,   5.4784352E-05,   4.8776601E-05
     +,   4.3334316E-05,   3.8416831E-05,   3.3984117E-05
     +,   2.9997664E-05,   2.6420510E-05,   2.3217353E-05
     +,   2.0355061E-05,   1.7802933E-05,   1.5532201E-05
     +,   1.3516264E-05,   1.1730725E-05,   1.0153127E-05
     +,   8.7627304E-06,   7.5405401E-06,   6.4692404E-06
     +,   5.5329679E-06,   4.7171684E-06,   4.0085670E-06
     +,   3.3951201E-06,   2.8658649E-06,   2.4108228E-06
     +,   2.0209748E-06,   1.6882216E-06,   1.4052486E-06
     +,   1.1655098E-06,   9.6318468E-07,   7.9309990E-07
     +,   6.5067030E-07,   5.3186363E-07,   4.3315637E-07
     +,   3.5147499E-07,   2.8414789E-07,   2.2887113E-07
     +,   1.8367081E-07,   1.4685395E-07,   1.1698626E-07
     +,   9.2850115E-08,   7.3423621E-08,   5.7848201E-08
     +,   4.5410061E-08,   3.5515416E-08,   2.7675275E-08
     +,   2.1486731E-08,   1.6621106E-08,   1.2810199E-08
     +,   9.8368069E-09,   7.5259416E-09,   5.7367608E-09
     +,   4.3568917E-09,   3.2967127E-09,   2.4853293E-09
     +,   1.8666968E-09,   1.3968662E-09,   1.0413921E-09
     +,   7.7349160E-10,   5.7235405E-10,   4.2193532E-10
     +,   3.0987293E-10,   2.2671577E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz80 = Yx/0.15806976744186
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0571089E-07,   1.1887154E-07
     +,   1.3346852E-07,   1.4963135E-07,   1.6749773E-07
     +,   1.8721386E-07,   2.0893437E-07,   2.3282232E-07
     +,   2.5904876E-07,   2.8779425E-07,   3.1924623E-07
     +,   3.5360014E-07,   3.9105910E-07,   4.3183280E-07
     +,   4.7613753E-07,   5.2419495E-07,   5.7623157E-07
     +,   6.3247762E-07,   6.9316678E-07,   7.5853410E-07
     +,   8.2881434E-07,   9.0424243E-07,   9.8504904E-07
     +,   1.0714664E-06,   1.1637112E-06,   1.2620033E-06
     +,   1.3665467E-06,   1.4775376E-06,   1.5951576E-06
     +,   1.7195758E-06,   1.8509432E-06,   1.9893944E-06
     +,   2.1350434E-06,   2.2879847E-06,   2.4482906E-06
     +,   2.6160108E-06,   2.7911703E-06,   2.9737703E-06
     +,   3.1637971E-06,   3.3611977E-06,   3.5659168E-06
     +,   3.7778686E-06,   3.9969541E-06,   4.2230613E-06
     +,   4.4560716E-06,   4.6958626E-06,   4.9423165E-06
     +,   5.1953266E-06,   5.4548086E-06,   5.7207080E-06
     +,   5.9930121E-06,   6.2717654E-06,   6.5570762E-06
     +,   6.8491577E-06,   7.1482914E-06,   7.4549143E-06
     +,   7.7695795E-06,   8.0930122E-06,   8.4261101E-06
     +,   8.7699764E-06,   9.1259353E-06,   9.4955631E-06
     +,   9.8806686E-06,   1.0283373E-05,   1.0706092E-05
     +,   1.1151508E-05,   1.1622672E-05,   1.2122887E-05
     +,   1.2655835E-05,   1.3225428E-05,   1.3835929E-05
     +,   1.4491777E-05,   1.5197706E-05,   1.5958529E-05
     +,   1.6779226E-05,   1.7664823E-05,   1.8620245E-05
     +,   1.9650264E-05,   2.0759486E-05,   2.1952161E-05
     +,   2.3231971E-05,   2.4602183E-05,   2.6065169E-05
     +,   2.7622682E-05,   2.9275358E-05,   3.1023013E-05
     +,   3.2864154E-05,   3.4796343E-05,   3.6815720E-05
     +,   3.8917395E-05,   4.1095336E-05,   4.3342294E-05
     +,   4.5649984E-05,   4.8009504E-05,   5.0411261E-05
     +,   5.2845102E-05,   5.5301080E-05,   5.7769172E-05
     +,   6.0240272E-05,   6.2706022E-05,   6.5159824E-05
     +,   6.7596731E-05,   7.0014714E-05,   7.2414536E-05
     +,   7.4801232E-05,   7.7184879E-05,   7.9581740E-05
     +,   8.2016508E-05,   8.4525105E-05,   8.7158354E-05
     +,   8.9986985E-05,   9.3109302E-05,   9.6659525E-05
     +,   1.0081985E-04,   1.0583278E-04,   1.1201663E-04
     +,   1.1977814E-04,   1.2962568E-04,   1.4217208E-04
     +,   1.5813154E-04,   1.7829800E-04,   2.0350322E-04
     +,   2.3455350E-04,   2.7214672E-04,   3.1676824E-04
     +,   3.6857728E-04,   4.2732194E-04,   4.9226399E-04
     +,   5.6219305E-04,   6.3548540E-04,   7.1028952E-04
     +,   7.8475464E-04,   8.5735525E-04,   9.2719350E-04
     +,   9.9431083E-04,   1.0599295E-03,   1.1266812E-03
     +,   1.1988984E-03,   1.2830331E-03,   1.3881611E-03
     +,   1.5263994E-03,   1.7130806E-03,   1.9668278E-03
     +,   2.3097519E-03,   2.7673196E-03,   3.3669681E-03
     +,   4.1365325E-03,   5.1073343E-03,   6.3200933E-03
     +,   7.8131771E-03,   9.5813358E-03,   1.1559751E-02
     +,   1.3703771E-02,   1.6061021E-02,   1.8646007E-02
     +,   2.1324402E-02,   2.4014406E-02,   2.6663223E-02
     +,   2.9005747E-02,   3.1108394E-02,   3.3486515E-02
     +,   3.5694573E-02,   3.6141776E-02,   3.4468602E-02
     +,   3.2071058E-02,   2.9930748E-02,   2.8019710E-02
     +,   2.6012581E-02,   2.3534937E-02,   2.0627504E-02
     +,   1.7888870E-02,   1.5794436E-02,   1.4283763E-02
     +,   1.3014562E-02,   1.1760478E-02,   1.0501354E-02
     +,   9.2730662E-03,   8.0827903E-03,   6.9419392E-03
     +,   5.8906158E-03,   4.9738558E-03,   4.2150365E-03
     +,   3.6126375E-03,   3.1504743E-03,   2.8073753E-03
     +,   2.5623259E-03,   2.3960357E-03,   2.2906982E-03
     +,   2.2293311E-03,   2.1957539E-03,   2.1753802E-03
     +,   2.1563086E-03,   2.1300437E-03,   2.0915864E-03
     +,   2.0389890E-03,   1.9726579E-03,   1.8946213E-03
     +,   1.8078906E-03,   1.7159311E-03,   1.6222465E-03
     +,   1.5300489E-03,   1.4419823E-03,   1.3599207E-03
     +,   1.2848699E-03,   1.2169675E-03,   1.1555667E-03
     +,   1.0994279E-03,   1.0469659E-03,   9.9650433E-04
     +,   9.4651408E-04,   8.9580426E-04,   8.4364071E-04
     +,   7.8977941E-04,   7.3442725E-04,   6.7815807E-04
     +,   6.2179309E-04,   5.6626747E-04,   5.1250361E-04
     +,   4.6131905E-04,   4.1336313E-04,   3.6907499E-04
     +,   3.2868402E-04,   2.9223211E-04,   2.5960369E-04
     +,   2.3056559E-04,   2.0481099E-04,   1.8199945E-04
     +,   1.6178402E-04,   1.4383317E-04,   1.2784656E-04
     +,   1.1356294E-04,   1.0076074E-04,   8.9255329E-05
     +,   7.8895799E-05,   6.9560272E-05,   6.1148210E-05
     +,   5.3576408E-05,   4.6774730E-05,   4.0681956E-05
     +,   3.5242592E-05,   3.0405421E-05,   2.6122447E-05
     +,   2.2347740E-05,   1.9036830E-05,   1.6146962E-05
     +,   1.3637294E-05,   1.1468836E-05,   9.6045305E-06
     +,   8.0096515E-06,   6.6520597E-06,   5.5020155E-06
     +,   4.5323982E-06,   3.7187485E-06,   3.0391298E-06
     +,   2.4739904E-06,   2.0061025E-06,   1.6204198E-06
     +,   1.3038592E-06,   1.0451107E-06,   8.3448435E-07
     +,   6.6373804E-07,   5.2588706E-07,   4.1504046E-07
     +,   3.2626579E-07,   2.5546078E-07,   1.9921566E-07
     +,   1.5471846E-07,   1.1966242E-07,   9.2160953E-08
     +,   7.0676890E-08,   5.3965426E-08,   4.1023771E-08
     +,   3.1046365E-08,   2.3388772E-08,   1.7538492E-08
     +,   1.3090122E-08,   9.7235704E-09,   7.1881909E-09
     +,   5.2879887E-09,   3.8709960E-09,   2.8195768E-09
     +,   2.0434343E-09,   1.4734101E-09,   1.0569682E-09
     +,   7.5430895E-10,   5.3552257E-10,   3.7820519E-10
     +,   2.6569250E-10,   1.8566532E-10,   1.2905040E-10
     +,   8.9220603E-11,   6.1351833E-11,   4.1961289E-11
     +,   2.8543680E-11,   1.9311431E-11,   1.2994105E-11
     +,   8.6958002E-12,   5.7874721E-12,   3.8308050E-12
     +,   2.5217268E-12,   1.6509039E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz85 = Yx/0.172931818181818
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0674165E-08,   2.4097211E-08
     +,   2.8037409E-08,   3.2564280E-08,   3.7755374E-08
     +,   4.3696833E-08,   5.0484292E-08,   5.8223499E-08
     +,   6.7031053E-08,   7.7035722E-08,   8.8378499E-08
     +,   1.0121387E-07,   1.1571074E-07,   1.3205303E-07
     +,   1.5044074E-07,   1.7109025E-07,   1.9423599E-07
     +,   2.2012989E-07,   2.4904341E-07,   2.8126692E-07
     +,   3.1711093E-07,   3.5690599E-07,   4.0100269E-07
     +,   4.4977480E-07,   5.0361155E-07,   5.6292794E-07
     +,   6.2815587E-07,   6.9974652E-07,   7.7817054E-07
     +,   8.6391520E-07,   9.5748396E-07,   1.0593951E-06
     +,   1.1701788E-06,   1.2903768E-06,   1.4205373E-06
     +,   1.5612160E-06,   1.7129703E-06,   1.8763541E-06
     +,   2.0519285E-06,   2.2402269E-06,   2.4417939E-06
     +,   2.6571436E-06,   2.8867751E-06,   3.1311652E-06
     +,   3.3907575E-06,   3.6659692E-06,   3.9571755E-06
     +,   4.2647148E-06,   4.5888733E-06,   4.9298919E-06
     +,   5.2879577E-06,   5.6631989E-06,   6.0556749E-06
     +,   6.4654096E-06,   6.8923150E-06,   7.3362780E-06
     +,   7.7970926E-06,   8.2744882E-06,   8.7681219E-06
     +,   9.2775826E-06,   9.8023966E-06,   1.0342026E-05
     +,   1.0895841E-05,   1.1463204E-05,   1.2043426E-05
     +,   1.2635723E-05,   1.3239357E-05,   1.3853491E-05
     +,   1.4477369E-05,   1.5110155E-05,   1.5751131E-05
     +,   1.6399543E-05,   1.7054788E-05,   1.7716280E-05
     +,   1.8383615E-05,   1.9056539E-05,   1.9734945E-05
     +,   2.0418938E-05,   2.1108921E-05,   2.1805577E-05
     +,   2.2509861E-05,   2.3223154E-05,   2.3947148E-05
     +,   2.4684035E-05,   2.5436373E-05,   2.6207255E-05
     +,   2.7000160E-05,   2.7819156E-05,   2.8668645E-05
     +,   2.9553576E-05,   3.0479312E-05,   3.1451538E-05
     +,   3.2476251E-05,   3.3559791E-05,   3.4708683E-05
     +,   3.5929501E-05,   3.7229056E-05,   3.8614035E-05
     +,   4.0091370E-05,   4.1667899E-05,   4.3350843E-05
     +,   4.5147634E-05,   4.7066609E-05,   4.9117018E-05
     +,   5.1310009E-05,   5.3659347E-05,   5.6182154E-05
     +,   5.8900459E-05,   6.1842780E-05,   6.5045919E-05
     +,   6.8556568E-05,   7.2434217E-05,   7.6752563E-05
     +,   8.1602528E-05,   8.7092696E-05,   9.3351657E-05
     +,   1.0052613E-04,   1.0878085E-04,   1.1829263E-04
     +,   1.2924566E-04,   1.4182192E-04,   1.5618798E-04
     +,   1.7248110E-04,   1.9079402E-04,   2.1115692E-04
     +,   2.3351893E-04,   2.5773898E-04,   2.8357116E-04
     +,   3.1066878E-04,   3.3858421E-04,   3.6679234E-04
     +,   3.9470999E-04,   4.2173962E-04,   4.4730600E-04
     +,   4.7091299E-04,   4.9219246E-04,   5.1095401E-04
     +,   5.2723259E-04,   5.4132752E-04,   5.5382628E-04
     +,   5.6561490E-04,   5.7787256E-04,   5.9204502E-04
     +,   6.0979946E-04,   6.3296652E-04,   6.6348229E-04
     +,   7.0333917E-04,   7.5455417E-04,   8.1915408E-04
     +,   8.9916226E-04,   9.9655497E-04,   1.1132271E-03
     +,   1.2511236E-03,   1.4127948E-03,   1.6025711E-03
     +,   1.8282718E-03,   2.1031462E-03,   2.4484994E-03
     +,   2.8995934E-03,   3.5157017E-03,   4.3807141E-03
     +,   5.5643083E-03,   7.0512318E-03,   8.7454244E-03
     +,   1.0627904E-02,   1.2865014E-02,   1.5612167E-02
     +,   1.8787496E-02,   2.2300845E-02,   2.6672091E-02
     +,   3.2701656E-02,   3.9136220E-02,   4.2708844E-02
     +,   4.2881932E-02,   4.2092014E-02,   4.1068096E-02
     +,   3.9117150E-02,   3.5832476E-02,   3.2245051E-02
     +,   2.9974075E-02,   2.8266670E-02,   2.5537666E-02
     +,   2.1753011E-02,   1.7867835E-02,   1.4545050E-02
     +,   1.1864542E-02,   9.7394949E-03,   8.1526795E-03
     +,   7.0696259E-03,   6.3656103E-03,   5.8733481E-03
     +,   5.4564299E-03,   5.0440100E-03,   4.6244785E-03
     +,   4.2182915E-03,   3.8520996E-03,   3.5454344E-03
     +,   3.3081817E-03,   3.1420388E-03,   3.0415840E-03
     +,   2.9943315E-03,   2.9812166E-03,   2.9785889E-03
     +,   2.9617532E-03,   2.9092587E-03,   2.8067648E-03
     +,   2.6494118E-03,   2.4420551E-03,   2.1973604E-03
     +,   1.9324283E-03,   1.6650696E-03,   1.4107067E-03
     +,   1.1804585E-03,   9.8057103E-04,   8.1293157E-04
     +,   6.7615695E-04,   5.6681072E-04,   4.8049813E-04
     +,   4.1269706E-04,   3.5928164E-04,   3.1677232E-04
     +,   2.8241571E-04,   2.5413450E-04,   2.3041008E-04
     +,   2.1015014E-04,   1.9256916E-04,   1.7709230E-04
     +,   1.6328554E-04,   1.5081109E-04,   1.3940243E-04
     +,   1.2885012E-04,   1.1899196E-04,   1.0970636E-04
     +,   1.0090695E-04,   9.2537790E-05,   8.4565370E-05
     +,   7.6974073E-05,   6.9760979E-05,   6.2930805E-05
     +,   5.6491630E-05,   5.0452443E-05,   4.4821245E-05
     +,   3.9603081E-05,   3.4798813E-05,   3.0405068E-05
     +,   2.6414344E-05,   2.2814933E-05,   1.9591056E-05
     +,   1.6723761E-05,   1.4191747E-05,   1.1971506E-05
     +,   1.0038297E-05,   8.3668929E-06,   6.9319981E-06
     +,   5.7086850E-06,   4.6729556E-06,   3.8021258E-06
     +,   3.0749882E-06,   2.4719523E-06,   1.9752160E-06
     +,   1.5688163E-06,   1.2385641E-06,   9.7197164E-07
     +,   7.5818923E-07,   5.8789686E-07,   4.5313243E-07
     +,   3.4717667E-07,   2.6441455E-07,   2.0018840E-07
     +,   1.5066506E-07,   1.1272169E-07,   8.3836497E-08
     +,   6.1986796E-08,   4.5562501E-08,   3.3293460E-08
     +,   2.4186219E-08,   1.7467517E-08,   1.2541890E-08
     +,   8.9528083E-09,   6.3538166E-09,   4.4831627E-09
     +,   3.1450145E-09,   2.1935325E-09,   1.5211156E-09
     +,   1.0487473E-09,   7.1892536E-10,   4.9000243E-10
     +,   3.3205594E-10,   2.2373599E-10,   1.4988651E-10
     +,   9.9839748E-11,   6.6122309E-11,   4.3541941E-11
     +,   2.8508305E-11,   1.8558759E-11,   1.2012353E-11
     +,   7.7306980E-12,   4.9466052E-12,   3.1470456E-12
     +,   1.9906308E-12,   1.2519326E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz90 = Yx/0.181522727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.9235158E-08,   5.8127188E-08
     +,   6.8479267E-08,   8.0504059E-08,   9.4440431E-08
     +,   1.1055588E-07,   1.2914937E-07,   1.5055373E-07
     +,   1.7513834E-07,   2.0331323E-07,   2.3553018E-07
     +,   2.7228634E-07,   3.1412765E-07,   3.6165088E-07
     +,   4.1550672E-07,   4.7640245E-07,   5.4510366E-07
     +,   6.2243686E-07,   7.0929099E-07,   8.0661795E-07
     +,   9.1543518E-07,   1.0368229E-06,   1.1719235E-06
     +,   1.3219513E-06,   1.4881632E-06,   1.6718913E-06
     +,   1.8745095E-06,   2.0974405E-06,   2.3421494E-06
     +,   2.6101318E-06,   2.9029077E-06,   3.2220082E-06
     +,   3.5689650E-06,   3.9452962E-06,   4.3524901E-06
     +,   4.7919893E-06,   5.2651731E-06,   5.7733282E-06
     +,   6.3176740E-06,   6.8992372E-06,   7.5189655E-06
     +,   8.1775970E-06,   8.8756833E-06,   9.6135518E-06
     +,   1.0391296E-05,   1.1208742E-05,   1.2065422E-05
     +,   1.2960570E-05,   1.3893079E-05,   1.4861513E-05
     +,   1.5864071E-05,   1.6898583E-05,   1.7962484E-05
     +,   1.9052906E-05,   2.0166468E-05,   2.1299555E-05
     +,   2.2448108E-05,   2.3607739E-05,   2.4773744E-05
     +,   2.5941117E-05,   2.7104577E-05,   2.8258646E-05
     +,   2.9397585E-05,   3.0515597E-05,   3.1606833E-05
     +,   3.2665259E-05,   3.3685068E-05,   3.4660363E-05
     +,   3.5585577E-05,   3.6455218E-05,   3.7264224E-05
     +,   3.8007784E-05,   3.8681595E-05,   3.9281775E-05
     +,   3.9805043E-05,   4.0248709E-05,   4.0610728E-05
     +,   4.0889750E-05,   4.1085190E-05,   4.1197211E-05
     +,   4.1226773E-05,   4.1175666E-05,   4.1046467E-05
     +,   4.0842591E-05,   4.0568266E-05,   4.0228475E-05
     +,   3.9829003E-05,   3.9376337E-05,   3.8877661E-05
     +,   3.8340801E-05,   3.7774120E-05,   3.7186564E-05
     +,   3.6587513E-05,   3.5986697E-05,   3.5394136E-05
     +,   3.4820143E-05,   3.4275086E-05,   3.3769476E-05
     +,   3.3313689E-05,   3.2918084E-05,   3.2592739E-05
     +,   3.2347500E-05,   3.2191794E-05,   3.2134627E-05
     +,   3.2184453E-05,   3.2349144E-05,   3.2635908E-05
     +,   3.3051190E-05,   3.3600714E-05,   3.4289395E-05
     +,   3.5121251E-05,   3.6099562E-05,   3.7226655E-05
     +,   3.8504186E-05,   3.9932886E-05,   4.1512976E-05
     +,   4.3243861E-05,   4.5124681E-05,   4.7153964E-05
     +,   4.9330236E-05,   5.1651990E-05,   5.4117732E-05
     +,   5.6726258E-05,   5.9477090E-05,   6.2370433E-05
     +,   6.5407017E-05,   6.8588903E-05,   7.1918679E-05
     +,   7.5400298E-05,   7.9038087E-05,   8.2837454E-05
     +,   8.6803688E-05,   9.0942689E-05,   9.5259638E-05
     +,   9.9759731E-05,   1.0444784E-04,   1.0932872E-04
     +,   1.1440834E-04,   1.1969647E-04,   1.2521021E-04
     +,   1.3097949E-04,   1.3705625E-04,   1.4352684E-04
     +,   1.5052827E-04,   1.5826752E-04,   1.6704688E-04
     +,   1.7728901E-04,   1.8956084E-04,   2.0459357E-04
     +,   2.2329175E-04,   2.4672278E-04,   2.7607873E-04
     +,   3.1260547E-04,   3.5749815E-04,   4.1175896E-04
     +,   4.7604315E-04,   5.5054831E-04,   6.3501461E-04
     +,   7.2890625E-04,   8.3182234E-04,   9.4413868E-04
     +,   1.0676752E-03,   1.2061779E-03,   1.3654458E-03
     +,   1.5530545E-03,   1.7776986E-03,   2.0480847E-03
     +,   2.3713878E-03,   2.7524827E-03,   3.1972195E-03
     +,   3.7222670E-03,   4.3644882E-03,   5.1695835E-03
     +,   6.1525400E-03,   7.2830878E-03,   8.5735470E-03
     +,   1.0165895E-02,   1.2139900E-02,   1.4243329E-02
     +,   1.6431710E-02,   1.9893602E-02,   2.5964998E-02
     +,   3.3847794E-02,   4.1179657E-02,   4.4802073E-02
     +,   4.5150097E-02,   4.6165660E-02,   4.5717109E-02
     +,   4.3510072E-02,   4.0591042E-02,   3.5385985E-02
     +,   2.8941257E-02,   2.2955043E-02,   1.7626505E-02
     +,   1.3330022E-02,   1.0468969E-02,   8.7040858E-03
     +,   7.4395700E-03,   6.3969372E-03,   5.5254241E-03
     +,   4.8102029E-03,   4.2230091E-03,   3.7333735E-03
     +,   3.3204448E-03,   2.9739316E-03,   2.6881490E-03
     +,   2.4552839E-03,   2.2624275E-03,   2.0936695E-03
     +,   1.9348743E-03,   1.7774969E-03,   1.6194789E-03
     +,   1.4635600E-03,   1.3145324E-03,   1.1768582E-03
     +,   1.0533112E-03,   9.4462128E-04,   8.4983831E-04
     +,   7.6700107E-04,   6.9380191E-04,   6.2805647E-04
     +,   5.6798407E-04,   5.1230285E-04,   4.6019698E-04
     +,   4.1122583E-04,   3.6522030E-04,   3.2218482E-04
     +,   2.8220858E-04,   2.4539867E-04,   2.1183827E-04
     +,   1.8156090E-04,   1.5453489E-04,   1.3066082E-04
     +,   1.0978062E-04,   9.1691640E-05,   7.6156706E-05
     +,   6.2921215E-05,   5.1726878E-05,   4.2321120E-05
     +,   3.4464709E-05,   2.7937738E-05,   2.2542687E-05
     +,   1.8104665E-05,   1.4470761E-05,   1.1509027E-05
     +,   9.1066686E-06,   7.1676718E-06,   5.6106269E-06
     +,   4.3669697E-06,   3.3792558E-06,   2.5993609E-06
     +,   1.9872659E-06,   1.5098750E-06,   1.1399321E-06
     +,   8.5511084E-07,   6.3727299E-07,   4.7179208E-07
     +,   3.4694472E-07,   2.5339995E-07,   1.8379720E-07
     +,   1.3237737E-07,   9.4664152E-08,   6.7204354E-08
     +,   4.7357684E-08,   3.3122316E-08,   2.2989427E-08
     +,   1.5832661E-08,   1.0818093E-08,   7.3328494E-09
     +,   4.9302304E-09,   3.2876253E-09,   2.1741096E-09
     +,   1.4257071E-09,   9.2701957E-10,   5.9760896E-10
     +,   3.8194295E-10,   2.4198807E-10,   1.5198263E-10
     +,   9.4615697E-11,   5.8384707E-11,   3.5708464E-11
     +,   2.1646143E-11,   1.3004735E-11,   7.7435202E-12
     +,   4.5694919E-12,   2.6723858E-12,   1.5488771E-12
     +,   8.8963098E-13,   5.0639413E-13,   2.8565044E-13
     +,   1.5968375E-13,   8.8460238E-14,   4.8563682E-14
     +,   2.6419979E-14,   1.4243882E-14,   7.6098931E-15
     +,   4.0290278E-15,   2.1138571E-15,   1.0990642E-15
     +,   5.6626958E-16,   2.8912996E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ttz95 = Yx/0.165232558139535
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0637362E-05,   4.1144362E-05
     +,   4.1624047E-05,   4.2076186E-05,   4.2500706E-05
     +,   4.2897715E-05,   4.3267501E-05,   4.3610522E-05
     +,   4.3927441E-05,   4.4219105E-05,   4.4486544E-05
     +,   4.4731012E-05,   4.4953933E-05,   4.5156936E-05
     +,   4.5341851E-05,   4.5510700E-05,   4.5665645E-05
     +,   4.5809105E-05,   4.5943620E-05,   4.6071898E-05
     +,   4.6196830E-05,   4.6321416E-05,   4.6448808E-05
     +,   4.6582260E-05,   4.6725141E-05,   4.6880883E-05
     +,   4.7053021E-05,   4.7245085E-05,   4.7460653E-05
     +,   4.7703314E-05,   4.7976620E-05,   4.8284099E-05
     +,   4.8629197E-05,   4.9015256E-05,   4.9445516E-05
     +,   4.9923077E-05,   5.0450861E-05,   5.1031591E-05
     +,   5.1667805E-05,   5.2361753E-05,   5.3115480E-05
     +,   5.3930697E-05,   5.4808854E-05,   5.5751058E-05
     +,   5.6758108E-05,   5.7830428E-05,   5.8968122E-05
     +,   6.0170947E-05,   6.1438222E-05,   6.2768988E-05
     +,   6.4161897E-05,   6.5615211E-05,   6.7126886E-05
     +,   6.8694622E-05,   7.0315582E-05,   7.1986855E-05
     +,   7.3705181E-05,   7.5467025E-05,   7.7268662E-05
     +,   7.9106154E-05,   8.0975449E-05,   8.2872371E-05
     +,   8.4792526E-05,   8.6731648E-05,   8.8685476E-05
     +,   9.0649548E-05,   9.2619819E-05,   9.4591982E-05
     +,   9.6562253E-05,   9.8526682E-05,   1.0048189E-04
     +,   1.0242451E-04,   1.0435172E-04,   1.0626081E-04
     +,   1.0814965E-04,   1.1001661E-04,   1.1186028E-04
     +,   1.1367987E-04,   1.1547522E-04,   1.1724675E-04
     +,   1.1899530E-04,   1.2072267E-04,   1.2243103E-04
     +,   1.2412353E-04,   1.2580388E-04,   1.2747674E-04
     +,   1.2914737E-04,   1.3082204E-04,   1.3250772E-04
     +,   1.3421221E-04,   1.3594440E-04,   1.3771369E-04
     +,   1.3953040E-04,   1.4140569E-04,   1.4335148E-04
     +,   1.4538017E-04,   1.4750504E-04,   1.4973950E-04
     +,   1.5209765E-04,   1.5459361E-04,   1.5724181E-04
     +,   1.6005622E-04,   1.6305094E-04,   1.6623919E-04
     +,   1.6963364E-04,   1.7324617E-04,   1.7708706E-04
     +,   1.8116528E-04,   1.8548808E-04,   1.9006111E-04
     +,   1.9488718E-04,   1.9996753E-04,   2.0530015E-04
     +,   2.1088109E-04,   2.1670322E-04,   2.2275702E-04
     +,   2.2903008E-04,   2.3550783E-04,   2.4217289E-04
     +,   2.4900620E-04,   2.5598725E-04,   2.6309374E-04
     +,   2.7030244E-04,   2.7759047E-04,   2.8493558E-04
     +,   2.9231570E-04,   2.9971133E-04,   3.0710470E-04
     +,   3.1448173E-04,   3.2183120E-04,   3.2914703E-04
     +,   3.3642654E-04,   3.4367296E-04,   3.5089345E-04
     +,   3.5810037E-04,   3.6531061E-04,   3.7254425E-04
     +,   3.7982446E-04,   3.8717638E-04,   3.9462614E-04
     +,   4.0219768E-04,   4.0991267E-04,   4.1778854E-04
     +,   4.2583622E-04,   4.3405729E-04,   4.4244417E-04
     +,   4.5097730E-04,   4.5962405E-04,   4.6833750E-04
     +,   4.7705724E-04,   4.8570873E-04,   4.9420353E-04
     +,   5.0244184E-04,   5.1031419E-04,   5.1770516E-04
     +,   5.2449491E-04,   5.3056562E-04,   5.3580507E-04
     +,   5.4011226E-04,   5.4340326E-04,   5.4561743E-04
     +,   5.4672366E-04,   5.4672785E-04,   5.4568017E-04
     +,   5.4368330E-04,   5.4090074E-04,   5.3756591E-04
     +,   5.3399202E-04,   5.3058082E-04,   5.2783295E-04
     +,   5.2635616E-04,   5.2687345E-04,   5.3022592E-04
     +,   5.3737272E-04,   5.4938131E-04,   5.6740950E-04
     +,   5.9267244E-04,   6.2639534E-04,   6.6975434E-04
     +,   7.2381773E-04,   7.8949449E-04,   8.6750888E-04
     +,   9.5843268E-04,   1.0628026E-03,   1.1813117E-03
     +,   1.3150977E-03,   1.4661455E-03,   1.6377770E-03
     +,   1.8351462E-03,   2.0656218E-03,   2.3388828E-03
     +,   2.6663423E-03,   3.0597122E-03,   3.5287817E-03
     +,   4.0787766E-03,   4.7078412E-03,   5.4053995E-03
     +,   6.1524520E-03,   6.9249342E-03,   7.7008358E-03
     +,   8.4694354E-03,   9.2370668E-03,   1.0022324E-02
     +,   1.0841189E-02,   1.1696381E-02,   1.2591420E-02
     +,   1.3569354E-02,   1.4737296E-02,   1.6221687E-02
     +,   1.8052515E-02,   2.0065423E-02,   2.1931451E-02
     +,   2.3313152E-02,   2.4015313E-02,   2.4013851E-02
     +,   2.3395298E-02,   2.2317374E-02,   2.1011338E-02
     +,   1.9741694E-02,   1.8688746E-02,   1.7851442E-02
     +,   1.7078346E-02,   1.6201532E-02,   1.5151616E-02
     +,   1.3974069E-02,   1.2769674E-02,   1.1628466E-02
     +,   1.0598826E-02,   9.6906545E-03,   8.8932095E-03
     +,   8.1911916E-03,   7.5719813E-03,   7.0242644E-03
     +,   6.5339487E-03,   6.0829897E-03,   5.6527453E-03
     +,   5.2293595E-03,   4.8070862E-03,   4.3881708E-03
     +,   3.9800219E-03,   3.5917754E-03,   3.2315850E-03
     +,   2.9051290E-03,   2.6152192E-03,   2.3620825E-03
     +,   2.1438866E-03,   1.9572971E-03,   1.7980551E-03
     +,   1.6615452E-03,   1.5432823E-03,   1.4392223E-03
     +,   1.3459938E-03,   1.2609608E-03,   1.1821778E-03
     +,   1.1082853E-03,   1.0383882E-03,   9.7193610E-04
     +,   9.0860575E-04,   8.4820908E-04,   7.9063140E-04
     +,   7.3578878E-04,   6.8359985E-04,   6.3396996E-04
     +,   5.8679731E-04,   5.4198131E-04,   4.9942144E-04
     +,   4.5903036E-04,   4.2073976E-04,   3.8450072E-04
     +,   3.5027921E-04,   3.1805618E-04,   2.8782341E-04
     +,   2.5957607E-04,   2.3330504E-04,   2.0899397E-04
     +,   1.8661782E-04,   1.6613475E-04,   1.4749079E-04
     +,   1.3061475E-04,   1.1542410E-04,   1.0182246E-04
     +,   8.9706482E-05,   7.8964644E-05,   6.9483503E-05
     +,   6.1147613E-05,   5.3844302E-05,   4.7463829E-05
     +,   4.1901982E-05,   3.7061709E-05,   3.2852779E-05
     +,   2.9193512E-05,   2.6009820E-05,   2.3236158E-05
     +,   2.0814319E-05,   1.8693770E-05,   1.6830483E-05
     +,   1.5186867E-05,   1.3730671E-05,   1.2434764E-05
     +,   1.1276159E-05,   1.0235760E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz100 = Yx/0.158720930232558
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8490539E-06,   4.0001623E-06
     +,   4.1553135E-06,   4.3145506E-06,   4.4779181E-06
     +,   4.6454666E-06,   4.8172496E-06,   4.9933301E-06
     +,   5.1737798E-06,   5.3586818E-06,   5.5481328E-06
     +,   5.7422467E-06,   5.9411541E-06,   6.1450096E-06
     +,   6.3539969E-06,   6.5683271E-06,   6.7882497E-06
     +,   7.0140545E-06,   7.2460716E-06,   7.4846944E-06
     +,   7.7303612E-06,   7.9835845E-06,   8.2449433E-06
     +,   8.5151105E-06,   8.7948165E-06,   9.0849180E-06
     +,   9.3863591E-06,   9.7001957E-06,   1.0027613E-05
     +,   1.0369909E-05,   1.0728533E-05,   1.1105068E-05
     +,   1.1501242E-05,   1.1918946E-05,   1.2360226E-05
     +,   1.2827285E-05,   1.3322493E-05,   1.3848373E-05
     +,   1.4407635E-05,   1.5003086E-05,   1.5637735E-05
     +,   1.6314691E-05,   1.7037184E-05,   1.7808548E-05
     +,   1.8632185E-05,   1.9511559E-05,   2.0450148E-05
     +,   2.1451418E-05,   2.2518772E-05,   2.3655541E-05
     +,   2.4864894E-05,   2.6149835E-05,   2.7513082E-05
     +,   2.8957174E-05,   3.0484121E-05,   3.2095712E-05
     +,   3.3793152E-05,   3.5577174E-05,   3.7447920E-05
     +,   3.9404909E-05,   4.1446994E-05,   4.3572316E-05
     +,   4.5778161E-05,   4.8061131E-05,   5.0417089E-05
     +,   5.2840802E-05,   5.5326513E-05,   5.7867324E-05
     +,   6.0455859E-05,   6.3083622E-05,   6.5741689E-05
     +,   6.8420122E-05,   7.1108763E-05,   7.3796422E-05
     +,   7.6471872E-05,   7.9123420E-05,   8.1738981E-05
     +,   8.4306368E-05,   8.6813561E-05,   8.9248613E-05
     +,   9.1599628E-05,   9.3855386E-05,   9.6004973E-05
     +,   9.8038348E-05,   9.9946054E-05,   1.0171971E-04
     +,   1.0335185E-04,   1.0483625E-04,   1.0616778E-04
     +,   1.0734280E-04,   1.0835896E-04,   1.0921531E-04
     +,   1.0991243E-04,   1.1045248E-04,   1.1083903E-04
     +,   1.1107726E-04,   1.1117382E-04,   1.1113690E-04
     +,   1.1097619E-04,   1.1070266E-04,   1.1032890E-04
     +,   1.0986867E-04,   1.0933711E-04,   1.0875065E-04
     +,   1.0812681E-04,   1.0748427E-04,   1.0684293E-04
     +,   1.0622368E-04,   1.0564843E-04,   1.0513992E-04
     +,   1.0472204E-04,   1.0441929E-04,   1.0425703E-04
     +,   1.0426118E-04,   1.0445823E-04,   1.0487498E-04
     +,   1.0553832E-04,   1.0647519E-04,   1.0771200E-04
     +,   1.0927446E-04,   1.1118729E-04,   1.1347351E-04
     +,   1.1615393E-04,   1.1924704E-04,   1.2276812E-04
     +,   1.2672835E-04,   1.3113495E-04,   1.3598958E-04
     +,   1.4128897E-04,   1.4702289E-04,   1.5317534E-04
     +,   1.5972242E-04,   1.6663386E-04,   1.7387106E-04
     +,   1.8138879E-04,   1.8913468E-04,   1.9704908E-04
     +,   2.0506626E-04,   2.1311555E-04,   2.2112210E-04
     +,   2.2900735E-04,   2.3669092E-04,   2.4409281E-04
     +,   2.5113430E-04,   2.5773907E-04,   2.6383641E-04
     +,   2.6936206E-04,   2.7425992E-04,   2.7848396E-04
     +,   2.8200002E-04,   2.8478698E-04,   2.8683781E-04
     +,   2.8816087E-04,   2.8878116E-04,   2.8874038E-04
     +,   2.8809792E-04,   2.8693117E-04,   2.8533550E-04
     +,   2.8342436E-04,   2.8132985E-04,   2.7920163E-04
     +,   2.7720720E-04,   2.7553146E-04,   2.7437595E-04
     +,   2.7395794E-04,   2.7450899E-04,   2.7627384E-04
     +,   2.7950667E-04,   2.8446910E-04,   2.9142553E-04
     +,   3.0063748E-04,   3.1235706E-04,   3.2682100E-04
     +,   3.4424118E-04,   3.6479451E-04,   3.8861667E-04
     +,   4.1579205E-04,   4.4634528E-04,   4.8023622E-04
     +,   5.1736133E-04,   5.5755331E-04,   6.0058589E-04
     +,   6.4618699E-04,   6.9406029E-04,   7.4390444E-04
     +,   7.9543341E-04,   8.4840733E-04,   9.0266141E-04
     +,   9.5812336E-04,   1.0148217E-03,   1.0729039E-03
     +,   1.1326213E-03,   1.1943091E-03,   1.2583567E-03
     +,   1.3251750E-03,   1.3951476E-03,   1.4685922E-03
     +,   1.5457469E-03,   1.6267961E-03,   1.7119267E-03
     +,   1.8014454E-03,   1.8959362E-03,   1.9964678E-03
     +,   2.1047816E-03,   2.2234907E-03,   2.3563271E-03
     +,   2.5083818E-03,   2.6862950E-03,   2.8982419E-03
     +,   3.1534196E-03,   3.4608182E-03,   3.8274403E-03
     +,   4.2569065E-03,   4.7497898E-03,   5.3067831E-03
     +,   5.9346529E-03,   6.6523273E-03,   7.4915010E-03
     +,   8.4849149E-03,   9.6398890E-03,   1.0907832E-02
     +,   1.2176080E-02,   1.3311422E-02,   1.4249092E-02
     +,   1.5057704E-02,   1.5893767E-02,   1.6858272E-02
     +,   1.7896101E-02,   1.8854385E-02,   1.9627115E-02
     +,   2.0214580E-02,   2.0658130E-02,   2.0970441E-02
     +,   2.1134749E-02,   2.1113586E-02,   2.0829238E-02
     +,   2.0184534E-02,   1.9148517E-02,   1.7807905E-02
     +,   1.6325839E-02,   1.4874065E-02,   1.3596982E-02
     +,   1.2581924E-02,   1.1821465E-02,   1.1209982E-02
     +,   1.0599869E-02,   9.8787658E-03,   9.0134395E-03
     +,   8.0438936E-03,   7.0485612E-03,   6.1071878E-03
     +,   5.2767140E-03,   4.5826859E-03,   4.0227138E-03
     +,   3.5766622E-03,   3.2178676E-03,   2.9213030E-03
     +,   2.6674259E-03,   2.4426912E-03,   2.2384161E-03
     +,   2.0493141E-03,   1.8723063E-03,   1.7057288E-03
     +,   1.5488263E-03,   1.4013810E-03,   1.2633873E-03
     +,   1.1348535E-03,   1.0156995E-03,   9.0571627E-04
     +,   8.0458092E-04,   7.1191479E-04,   6.2732806E-04
     +,   5.5043772E-04,   4.8086804E-04,   4.1825185E-04
     +,   3.6222412E-04,   3.1239924E-04,   2.6838004E-04
     +,   2.2974519E-04,   1.9606478E-04,   1.6689660E-04
     +,   1.4180258E-04,   1.2034904E-04,   1.0211998E-04
     +,   8.6717257E-05,   7.3769959E-05,   6.2934043E-05
     +,   5.3896314E-05,   4.6376208E-05,   4.0124054E-05
     +,   3.4922483E-05,   3.0583498E-05,   2.6947962E-05
     +,   2.3882119E-05,   2.1275973E-05,   1.9039660E-05
     +,   1.7101347E-05,   1.5403875E-05,   1.3902735E-05
     +,   1.2563276E-05,   1.1359046E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz104 = Yx/0.150418604651163
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7108224E-06,   4.8477064E-06
     +,   4.9881037E-06,   5.1322886E-06,   5.2805667E-06
     +,   5.4332786E-06,   5.5908040E-06,   5.7535599E-06
     +,   5.9220006E-06,   6.0966308E-06,   6.2779968E-06
     +,   6.4666865E-06,   6.6633379E-06,   6.8686400E-06
     +,   7.0833294E-06,   7.3081901E-06,   7.5440598E-06
     +,   7.7918239E-06,   8.0524160E-06,   8.3268214E-06
     +,   8.6160671E-06,   8.9212253E-06,   9.2434084E-06
     +,   9.5837840E-06,   9.9435138E-06,   1.0323835E-05
     +,   1.0725979E-05,   1.1151209E-05,   1.1600789E-05
     +,   1.2075995E-05,   1.2578100E-05,   1.3108360E-05
     +,   1.3668016E-05,   1.4258268E-05,   1.4880287E-05
     +,   1.5535185E-05,   1.6224007E-05,   1.6947724E-05
     +,   1.7707258E-05,   1.8503353E-05,   1.9336730E-05
     +,   2.0207939E-05,   2.1117408E-05,   2.2065426E-05
     +,   2.3052127E-05,   2.4077473E-05,   2.5141271E-05
     +,   2.6243119E-05,   2.7382459E-05,   2.8558499E-05
     +,   2.9770275E-05,   3.1016611E-05,   3.2296102E-05
     +,   3.3607201E-05,   3.4948029E-05,   3.6316633E-05
     +,   3.7710790E-05,   3.9128070E-05,   4.0565883E-05
     +,   4.2021456E-05,   4.3491800E-05,   4.4973855E-05
     +,   4.6464280E-05,   4.7959726E-05,   4.9456743E-05
     +,   5.0951636E-05,   5.2440821E-05,   5.3920474E-05
     +,   5.5386914E-05,   5.6836270E-05,   5.8264846E-05
     +,   5.9668830E-05,   6.1044615E-05,   6.2388492E-05
     +,   6.3696985E-05,   6.4966771E-05,   6.6194545E-05
     +,   6.7377201E-05,   6.8511872E-05,   6.9595946E-05
     +,   7.0626862E-05,   7.1602466E-05,   7.2520772E-05
     +,   7.3380157E-05,   7.4179166E-05,   7.4916759E-05
     +,   7.5592121E-05,   7.6204866E-05,   7.6754783E-05
     +,   7.7242141E-05,   7.7667479E-05,   7.8031648E-05
     +,   7.8335899E-05,   7.8581790E-05,   7.8771249E-05
     +,   7.8906451E-05,   7.8990015E-05,   7.9024830E-05
     +,   7.9014055E-05,   7.8961195E-05,   7.8870020E-05
     +,   7.8744641E-05,   7.8589321E-05,   7.8408681E-05
     +,   7.8207486E-05,   7.7990750E-05,   7.7763718E-05
     +,   7.7531753E-05,   7.7300392E-05,   7.7075303E-05
     +,   7.6862292E-05,   7.6667238E-05,   7.6496079E-05
     +,   7.6354809E-05,   7.6249489E-05,   7.6186101E-05
     +,   7.6170691E-05,   7.6209210E-05,   7.6307588E-05
     +,   7.6471631E-05,   7.6707103E-05,   7.7019591E-05
     +,   7.7414545E-05,   7.7897283E-05,   7.8472956E-05
     +,   7.9146484E-05,   7.9922596E-05,   8.0805752E-05
     +,   8.1800215E-05,   8.2909901E-05,   8.4138584E-05
     +,   8.5489497E-05,   8.6965774E-05,   8.8570036E-05
     +,   9.0304609E-05,   9.2171453E-05,   9.4172035E-05
     +,   9.6307347E-05,   9.8578021E-05,   1.0098428E-04
     +,   1.0352570E-04,   1.0620127E-04,   1.0900967E-04
     +,   1.1194917E-04,   1.1501706E-04,   1.1821056E-04
     +,   1.2152641E-04,   1.2496064E-04,   1.2850895E-04
     +,   1.3216696E-04,   1.3592996E-04,   1.3979310E-04
     +,   1.4375137E-04,   1.4780030E-04,   1.5193575E-04
     +,   1.5615397E-04,   1.6045220E-04,   1.6482899E-04
     +,   1.6928464E-04,   1.7382097E-04,   1.7844253E-04
     +,   1.8315695E-04,   1.8797493E-04,   1.9291100E-04
     +,   1.9798463E-04,   2.0322036E-04,   2.0864770E-04
     +,   2.1430214E-04,   2.2022564E-04,   2.2646648E-04
     +,   2.3307881E-04,   2.4012261E-04,   2.4766379E-04
     +,   2.5577302E-04,   2.6452384E-04,   2.7399280E-04
     +,   2.8425793E-04,   2.9539617E-04,   3.0748302E-04
     +,   3.2059199E-04,   3.3479402E-04,   3.5015633E-04
     +,   3.6674435E-04,   3.8462476E-04,   4.0386803E-04
     +,   4.2455035E-04,   4.4675980E-04,   4.7060178E-04
     +,   4.9620296E-04,   5.2371132E-04,   5.5330177E-04
     +,   5.8517157E-04,   6.1953347E-04,   6.5660483E-04
     +,   6.9659646E-04,   7.3968811E-04,   7.8600273E-04
     +,   8.3557912E-04,   8.8834972E-04,   9.4411767E-04
     +,   1.0025414E-03,   1.0631556E-03,   1.1254238E-03
     +,   1.1888408E-03,   1.2530908E-03,   1.3183067E-03
     +,   1.3853892E-03,   1.4563660E-03,   1.5347467E-03
     +,   1.6257027E-03,   1.7359017E-03,   1.8727964E-03
     +,   2.0433161E-03,   2.2521853E-03,   2.5004006E-03
     +,   2.7847537E-03,   3.0991761E-03,   3.4380483E-03
     +,   3.8002594E-03,   4.1917837E-03,   4.6242573E-03
     +,   5.1080575E-03,   5.6425277E-03,   6.2100585E-03
     +,   6.7822817E-03,   7.3413188E-03,   7.9070162E-03
     +,   8.5499231E-03,   9.3703074E-03,   1.0442805E-02
     +,   1.1753350E-02,   1.3169827E-02,   1.4476914E-02
     +,   1.5474131E-02,   1.6094701E-02,   1.6466081E-02
     +,   1.6847126E-02,   1.7470328E-02,   1.8398035E-02
     +,   1.9468702E-02,   2.0337297E-02,   2.0616679E-02
     +,   2.0100767E-02,   1.8922916E-02,   1.7484527E-02
     +,   1.6191551E-02,   1.5217637E-02,   1.4467574E-02
     +,   1.3723662E-02,   1.2824368E-02,   1.1743460E-02
     +,   1.0555826E-02,   9.3633905E-03,   8.2477368E-03
     +,   7.2601819E-03,   6.4272718E-03,   5.7540843E-03
     +,   5.2250335E-03,   4.8082131E-03,   4.4645653E-03
     +,   4.1579562E-03,   3.8620124E-03,   3.5624639E-03
     +,   3.2558709E-03,   2.9462853E-03,   2.6413756E-03
     +,   2.3492402E-03,   2.0763779E-03,   1.8267834E-03
     +,   1.6019562E-03,   1.4014586E-03,   1.2236589E-03
     +,   1.0664031E-03,   9.2752016E-04,   8.0511521E-04
     +,   6.9765409E-04,   6.0386822E-04,   5.2264903E-04
     +,   4.5290016E-04,   3.9347840E-04,   3.4315893E-04
     +,   3.0068128E-04,   2.6479605E-04,   2.3433866E-04
     +,   2.0827116E-04,   1.8572030E-04,   1.6597938E-04
     +,   1.4850189E-04,   1.3288128E-04,   1.1882070E-04
     +,   1.0611000E-04,   9.4597446E-05,   8.4173356E-05
     +,   7.4751631E-05,   6.6261891E-05,   5.8639915E-05
     +,   5.1825558E-05,   4.5758734E-05,   4.0380284E-05
     +,   3.5630561E-05,   3.1451324E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz106 = Yx/0.135666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8821534E-05,   1.9532974E-05
     +,   2.0266232E-05,   2.1021182E-05,   2.1797652E-05
     +,   2.2595379E-05,   2.3414008E-05,   2.4253119E-05
     +,   2.5112176E-05,   2.5990605E-05,   2.6887705E-05
     +,   2.7802676E-05,   2.8734641E-05,   2.9682638E-05
     +,   3.0645577E-05,   3.1622316E-05,   3.2611588E-05
     +,   3.3612047E-05,   3.4622266E-05,   3.5640714E-05
     +,   3.6665810E-05,   3.7695863E-05,   3.8729104E-05
     +,   3.9763774E-05,   4.0797917E-05,   4.1829659E-05
     +,   4.2856995E-05,   4.3877921E-05,   4.4890381E-05
     +,   4.5892317E-05,   4.6881636E-05,   4.7856283E-05
     +,   4.8814170E-05,   4.9753278E-05,   5.0671573E-05
     +,   5.1567113E-05,   5.2437972E-05,   5.3282300E-05
     +,   5.4098400E-05,   5.4884542E-05,   5.5639204E-05
     +,   5.6360946E-05,   5.7048470E-05,   5.7700578E-05
     +,   5.8316295E-05,   5.8894755E-05,   5.9435300E-05
     +,   5.9937425E-05,   6.0400838E-05,   6.0825467E-05
     +,   6.1211416E-05,   6.1559032E-05,   6.1868857E-05
     +,   6.2141698E-05,   6.2378575E-05,   6.2580737E-05
     +,   6.2749670E-05,   6.2887113E-05,   6.2995037E-05
     +,   6.3075640E-05,   6.3131331E-05,   6.3164814E-05
     +,   6.3178937E-05,   6.3176798E-05,   6.3161686E-05
     +,   6.3137086E-05,   6.3106665E-05,   6.3074258E-05
     +,   6.3043830E-05,   6.3019514E-05,   6.3005515E-05
     +,   6.3006162E-05,   6.3025851E-05,   6.3069019E-05
     +,   6.3140134E-05,   6.3243657E-05,   6.3384025E-05
     +,   6.3565596E-05,   6.3792708E-05,   6.4069507E-05
     +,   6.4400054E-05,   6.4788212E-05,   6.5237611E-05
     +,   6.5751752E-05,   6.6333741E-05,   6.6986482E-05
     +,   6.7712514E-05,   6.8514113E-05,   6.9393078E-05
     +,   7.0350921E-05,   7.1388749E-05,   7.2507173E-05
     +,   7.3706404E-05,   7.4986274E-05,   7.6346194E-05
     +,   7.7784978E-05,   7.9301244E-05,   8.0892947E-05
     +,   8.2557897E-05,   8.4293228E-05,   8.6096050E-05
     +,   8.7962828E-05,   8.9890040E-05,   9.1873626E-05
     +,   9.3909563E-05,   9.5993586E-05,   9.8121323E-05
     +,   1.0028828E-04,   1.0249009E-04,   1.0472247E-04
     +,   1.0698110E-04,   1.0926199E-04,   1.1156120E-04
     +,   1.1387536E-04,   1.1620105E-04,   1.1853550E-04
     +,   1.2087608E-04,   1.2322090E-04,   1.2556807E-04
     +,   1.2791647E-04,   1.3026535E-04,   1.3261422E-04
     +,   1.3496302E-04,   1.3731209E-04,   1.3966221E-04
     +,   1.4201399E-04,   1.4436868E-04,   1.4672728E-04
     +,   1.4909099E-04,   1.5146080E-04,   1.5383771E-04
     +,   1.5622228E-04,   1.5861489E-04,   1.6101518E-04
     +,   1.6342261E-04,   1.6583581E-04,   1.6825294E-04
     +,   1.7067094E-04,   1.7308656E-04,   1.7549556E-04
     +,   1.7789273E-04,   1.8027223E-04,   1.8262744E-04
     +,   1.8495132E-04,   1.8723588E-04,   1.8947283E-04
     +,   1.9165379E-04,   1.9376997E-04,   1.9581252E-04
     +,   1.9777325E-04,   1.9964411E-04,   2.0141779E-04
     +,   2.0308806E-04,   2.0464968E-04,   2.0609924E-04
     +,   2.0743468E-04,   2.0865594E-04,   2.0976541E-04
     +,   2.1076771E-04,   2.1166996E-04,   2.1248234E-04
     +,   2.1321776E-04,   2.1389208E-04,   2.1452441E-04
     +,   2.1513684E-04,   2.1575458E-04,   2.1640572E-04
     +,   2.1712120E-04,   2.1793460E-04,   2.1888182E-04
     +,   2.2000061E-04,   2.2133054E-04,   2.2291187E-04
     +,   2.2478589E-04,   2.2699317E-04,   2.2957384E-04
     +,   2.3256658E-04,   2.3600717E-04,   2.3992837E-04
     +,   2.4435896E-04,   2.4932288E-04,   2.5483806E-04
     +,   2.6091610E-04,   2.6756193E-04,   2.7477369E-04
     +,   2.8254176E-04,   2.9085006E-04,   2.9967690E-04
     +,   3.0899656E-04,   3.1878028E-04,   3.2900085E-04
     +,   3.3963507E-04,   3.5066807E-04,   3.6209857E-04
     +,   3.7394639E-04,   3.8625795E-04,   3.9911282E-04
     +,   4.1263242E-04,   4.2698841E-04,   4.4241015E-04
     +,   4.5918988E-04,   4.7768990E-04,   4.9834914E-04
     +,   5.2168494E-04,   5.4829125E-04,   5.7884253E-04
     +,   6.1408675E-04,   6.5483525E-04,   7.0195133E-04
     +,   7.5633259E-04,   8.1887818E-04,   8.9043699E-04
     +,   9.7174436E-04,   1.0633398E-03,   1.1654566E-03
     +,   1.2779047E-03,   1.3999864E-03,   1.5304803E-03
     +,   1.6677144E-03,   1.8097663E-03,   1.9548540E-03
     +,   2.1018065E-03,   2.2505915E-03,   2.4028525E-03
     +,   2.5624223E-03,   2.7357324E-03,   2.9320742E-03
     +,   3.1634443E-03,   3.4435471E-03,   3.7855613E-03
     +,   4.1990099E-03,   4.6871849E-03,   5.2473107E-03
     +,   5.8748857E-03,   6.5705432E-03,   7.3443027E-03
     +,   8.2103405E-03,   9.1719879E-03,   1.0207132E-02
     +,   1.1268634E-02,   1.2303870E-02,   1.3277894E-02
     +,   1.4179043E-02,   1.5003545E-02,   1.5738811E-02
     +,   1.6362878E-02,   1.6854150E-02,   1.7197851E-02
     +,   1.7389074E-02,   1.7439533E-02,   1.7378774E-02
     +,   1.7235352E-02,   1.7010503E-02,   1.6675241E-02
     +,   1.6200876E-02,   1.5592958E-02,   1.4893340E-02
     +,   1.4147153E-02,   1.3367215E-02,   1.2527918E-02
     +,   1.1591436E-02,   1.0542572E-02,   9.4068013E-03
     +,   8.2433568E-03,   7.1217748E-03,   6.0970229E-03
     +,   5.1960689E-03,   4.4192784E-03,   3.7514698E-03
     +,   3.1742537E-03,   2.6735545E-03,   2.2410250E-03
     +,   1.8716996E-03,   1.5610432E-03,   1.3032504E-03
     +,   1.0910752E-03,   9.1658568E-04,   7.7225140E-04
     +,   6.5166067E-04,   5.4986344E-04,   4.6326136E-04
     +,   3.8933926E-04,   3.2629477E-04,   2.7275988E-04
     +,   2.2757947E-04,   1.8971085E-04,   1.5816766E-04
     +,   1.3202074E-04,   1.1041343E-04,   9.2572613E-05
     +,   7.7826116E-05,   6.5601293E-05,   5.5425324E-05
     +,   4.6912643E-05,   3.9755680E-05,   3.3709475E-05
     +,   2.8581220E-05,   2.4217612E-05,   2.0497026E-05
     +,   1.7320961E-05,   1.4609345E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz108 = Yx/0.126333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0822961E-05,   3.1936601E-05
     +,   3.3057513E-05,   3.4183620E-05,   3.5312736E-05
     +,   3.6442623E-05,   3.7570957E-05,   3.8695347E-05
     +,   3.9813342E-05,   4.0922514E-05,   4.2020336E-05
     +,   4.3104279E-05,   4.4171822E-05,   4.5220422E-05
     +,   4.6247591E-05,   4.7250858E-05,   4.8227776E-05
     +,   4.9175986E-05,   5.0093182E-05,   5.0977145E-05
     +,   5.1825766E-05,   5.2637031E-05,   5.3409050E-05
     +,   5.4140095E-05,   5.4828524E-05,   5.5472919E-05
     +,   5.6072004E-05,   5.6624653E-05,   5.7129961E-05
     +,   5.7587189E-05,   5.7995807E-05,   5.8355494E-05
     +,   5.8666130E-05,   5.8927795E-05,   5.9140795E-05
     +,   5.9305643E-05,   5.9423073E-05,   5.9494025E-05
     +,   5.9519636E-05,   5.9501243E-05,   5.9440412E-05
     +,   5.9338865E-05,   5.9198526E-05,   5.9021495E-05
     +,   5.8810019E-05,   5.8566537E-05,   5.8293597E-05
     +,   5.7993890E-05,   5.7670251E-05,   5.7325589E-05
     +,   5.6962926E-05,   5.6585373E-05,   5.6196095E-05
     +,   5.5798300E-05,   5.5395300E-05,   5.4990353E-05
     +,   5.4586781E-05,   5.4187916E-05,   5.3797070E-05
     +,   5.3417531E-05,   5.3052579E-05,   5.2705440E-05
     +,   5.2379313E-05,   5.2077354E-05,   5.1802625E-05
     +,   5.1558192E-05,   5.1347008E-05,   5.1172014E-05
     +,   5.1036073E-05,   5.0941988E-05,   5.0892537E-05
     +,   5.0890438E-05,   5.0938383E-05,   5.1039049E-05
     +,   5.1195082E-05,   5.1409166E-05,   5.1683975E-05
     +,   5.2022187E-05,   5.2426578E-05,   5.2899974E-05
     +,   5.3445219E-05,   5.4065327E-05,   5.4763346E-05
     +,   5.5542489E-05,   5.6406010E-05,   5.7357422E-05
     +,   5.8400190E-05,   5.9538092E-05,   6.0774863E-05
     +,   6.2114435E-05,   6.3560874E-05,   6.5118205E-05
     +,   6.6790468E-05,   6.8581860E-05,   7.0496433E-05
     +,   7.2538111E-05,   7.4710755E-05,   7.7017794E-05
     +,   7.9462669E-05,   8.2048085E-05,   8.4776642E-05
     +,   8.7650013E-05,   9.0669579E-05,   9.3835588E-05
     +,   9.7147778E-05,   1.0060491E-04,   1.0420450E-04
     +,   1.0794299E-04,   1.1181580E-04,   1.1581713E-04
     +,   1.1993946E-04,   1.2417445E-04,   1.2851182E-04
     +,   1.3294040E-04,   1.3744710E-04,   1.4201812E-04
     +,   1.4663757E-04,   1.5128912E-04,   1.5595456E-04
     +,   1.6061516E-04,   1.6525137E-04,   1.6984253E-04
     +,   1.7436751E-04,   1.7880516E-04,   1.8313421E-04
     +,   1.8733305E-04,   1.9138113E-04,   1.9525773E-04
     +,   1.9894372E-04,   2.0242068E-04,   2.0567173E-04
     +,   2.0868148E-04,   2.1143658E-04,   2.1392546E-04
     +,   2.1613896E-04,   2.1807045E-04,   2.1971572E-04
     +,   2.2107322E-04,   2.2214439E-04,   2.2293342E-04
     +,   2.2344725E-04,   2.2369596E-04,   2.2369252E-04
     +,   2.2345246E-04,   2.2299441E-04,   2.2233931E-04
     +,   2.2151088E-04,   2.2053513E-04,   2.1944036E-04
     +,   2.1825686E-04,   2.1701667E-04,   2.1575380E-04
     +,   2.1450344E-04,   2.1330218E-04,   2.1218757E-04
     +,   2.1119801E-04,   2.1037248E-04,   2.0975040E-04
     +,   2.0937114E-04,   2.0927416E-04,   2.0949823E-04
     +,   2.1008179E-04,   2.1106204E-04,   2.1247500E-04
     +,   2.1435482E-04,   2.1673401E-04,   2.1964226E-04
     +,   2.2310615E-04,   2.2714947E-04,   2.3179170E-04
     +,   2.3704776E-04,   2.4292743E-04,   2.4943511E-04
     +,   2.5656930E-04,   2.6432087E-04,   2.7267414E-04
     +,   2.8160590E-04,   2.9108426E-04,   3.0106885E-04
     +,   3.1151134E-04,   3.2235510E-04,   3.3353444E-04
     +,   3.4497544E-04,   3.5659762E-04,   3.6831383E-04
     +,   3.8003060E-04,   3.9164981E-04,   4.0307123E-04
     +,   4.1419384E-04,   4.2491572E-04,   4.3513940E-04
     +,   4.4477251E-04,   4.5372994E-04,   4.6193725E-04
     +,   4.6933390E-04,   4.7587560E-04,   4.8153722E-04
     +,   4.8631598E-04,   4.9023534E-04,   4.9334735E-04
     +,   4.9573596E-04,   4.9752020E-04,   4.9885741E-04
     +,   4.9994490E-04,   5.0102232E-04,   5.0237187E-04
     +,   5.0431705E-04,   5.0722057E-04,   5.1147683E-04
     +,   5.1750458E-04,   5.2573328E-04,   5.3658878E-04
     +,   5.5047416E-04,   5.6775514E-04,   5.8874476E-04
     +,   6.1369321E-04,   6.4279552E-04,   6.7621149E-04
     +,   7.1411015E-04,   7.5673120E-04,   8.0448878E-04
     +,   8.5808604E-04,   9.1864757E-04,   9.8785851E-04
     +,   1.0680859E-03,   1.1624356E-03,   1.2747088E-03
     +,   1.4092035E-03,   1.5703365E-03,   1.7620119E-03
     +,   1.9867802E-03,   2.2449451E-03,   2.5338237E-03
     +,   2.8474363E-03,   3.1769695E-03,   3.5123252E-03
     +,   3.8445194E-03,   4.1686394E-03,   4.4867657E-03
     +,   4.8100417E-03,   5.1591150E-03,   5.5623283E-03
     +,   6.0511795E-03,   6.6531482E-03,   7.3827915E-03
     +,   8.2335286E-03,   9.1734631E-03,   1.0148749E-02
     +,   1.1096712E-02,   1.1968161E-02,   1.2752188E-02
     +,   1.3488974E-02,   1.4256184E-02,   1.5127491E-02
     +,   1.6122766E-02,   1.7180454E-02,   1.8170392E-02
     +,   1.8937990E-02,   1.9355401E-02,   1.9358048E-02
     +,   1.8957339E-02,   1.8227696E-02,   1.7273540E-02
     +,   1.6191505E-02,   1.5043529E-02,   1.3851115E-02
     +,   1.2610276E-02,   1.1317943E-02,   9.9939778E-03
     +,   8.6853523E-03,   7.4504111E-03,   6.3354489E-03
     +,   5.3598043E-03,   4.5171129E-03,   3.7877271E-03
     +,   3.1517847E-03,   2.5958994E-03,   2.1134794E-03
     +,   1.7011713E-03,   1.3555593E-03,   1.0712771E-03
     +,   8.4106985E-04,   6.5665977E-04,   5.0991884E-04
     +,   3.9359459E-04,   3.0167520E-04,   2.2933270E-04
     +,   1.7273413E-04,   1.2880978E-04,   9.5049792E-05
     +,   6.9385729E-05,   5.0100043E-05,   3.5780242E-05
     +,   2.5273868E-05,   1.7657629E-05,   1.2201297E-05
     +,   8.3382320E-06,   5.6346189E-06,   3.7642947E-06
     +,   2.4852040E-06,   1.6206814E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz110 = Yx/0.120878048780488
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.0493506E-06,   7.3481310E-06
     +,   7.6583192E-06,   7.9804286E-06,   8.3150098E-06
     +,   8.6626578E-06,   9.0240128E-06,   9.3997551E-06
     +,   9.7906131E-06,   1.0197390E-05,   1.0620922E-05
     +,   1.1062113E-05,   1.1521932E-05,   1.2001413E-05
     +,   1.2501652E-05,   1.3023830E-05,   1.3569189E-05
     +,   1.4139052E-05,   1.4734819E-05,   1.5357968E-05
     +,   1.6010055E-05,   1.6692713E-05,   1.7407645E-05
     +,   1.8156674E-05,   1.8941613E-05,   1.9764422E-05
     +,   2.0627085E-05,   2.1531661E-05,   2.2480244E-05
     +,   2.3474982E-05,   2.4518053E-05,   2.5611649E-05
     +,   2.6757985E-05,   2.7959259E-05,   2.9217646E-05
     +,   3.0535284E-05,   3.1914264E-05,   3.3356540E-05
     +,   3.4864104E-05,   3.6438629E-05,   3.8081816E-05
     +,   3.9795104E-05,   4.1579759E-05,   4.3436787E-05
     +,   4.5367007E-05,   4.7370915E-05,   4.9448714E-05
     +,   5.1600276E-05,   5.3825137E-05,   5.6122430E-05
     +,   5.8490896E-05,   6.0928865E-05,   6.3434192E-05
     +,   6.6004424E-05,   6.8636371E-05,   7.1326671E-05
     +,   7.4071249E-05,   7.6865726E-05,   7.9705147E-05
     +,   8.2584098E-05,   8.5496773E-05,   8.8436973E-05
     +,   9.1397858E-05,   9.4372437E-05,   9.7353492E-05
     +,   1.0033311E-04,   1.0330354E-04,   1.0625642E-04
     +,   1.0918365E-04,   1.1207664E-04,   1.1492713E-04
     +,   1.1772651E-04,   1.2046663E-04,   1.2313921E-04
     +,   1.2573635E-04,   1.2825051E-04,   1.3067431E-04
     +,   1.3300082E-04,   1.3522379E-04,   1.3733745E-04
     +,   1.3933644E-04,   1.4121628E-04,   1.4297309E-04
     +,   1.4460373E-04,   1.4610578E-04,   1.4747780E-04
     +,   1.4871884E-04,   1.4982901E-04,   1.5080906E-04
     +,   1.5166073E-04,   1.5238633E-04,   1.5298903E-04
     +,   1.5347265E-04,   1.5384173E-04,   1.5410142E-04
     +,   1.5425742E-04,   1.5431586E-04,   1.5428336E-04
     +,   1.5416696E-04,   1.5397379E-04,   1.5371136E-04
     +,   1.5338710E-04,   1.5300866E-04,   1.5258350E-04
     +,   1.5211904E-04,   1.5162249E-04,   1.5110071E-04
     +,   1.5056031E-04,   1.5000747E-04,   1.4944785E-04
     +,   1.4888668E-04,   1.4832853E-04,   1.4777758E-04
     +,   1.4723730E-04,   1.4671042E-04,   1.4619915E-04
     +,   1.4570513E-04,   1.4522923E-04,   1.4477182E-04
     +,   1.4433265E-04,   1.4391085E-04,   1.4350501E-04
     +,   1.4311343E-04,   1.4273381E-04,   1.4236345E-04
     +,   1.4199938E-04,   1.4163840E-04,   1.4127695E-04
     +,   1.4091151E-04,   1.4053828E-04,   1.4015358E-04
     +,   1.3975368E-04,   1.3933497E-04,   1.3889397E-04
     +,   1.3842744E-04,   1.3793232E-04,   1.3740596E-04
     +,   1.3684598E-04,   1.3625043E-04,   1.3561771E-04
     +,   1.3494673E-04,   1.3423698E-04,   1.3348834E-04
     +,   1.3270116E-04,   1.3187650E-04,   1.3101584E-04
     +,   1.3012125E-04,   1.2919537E-04,   1.2824142E-04
     +,   1.2726306E-04,   1.2626452E-04,   1.2525058E-04
     +,   1.2422653E-04,   1.2319797E-04,   1.2217107E-04
     +,   1.2115233E-04,   1.2014870E-04,   1.1916732E-04
     +,   1.1821565E-04,   1.1730142E-04,   1.1643246E-04
     +,   1.1561673E-04,   1.1486227E-04,   1.1417713E-04
     +,   1.1356924E-04,   1.1304636E-04,   1.1261614E-04
     +,   1.1228592E-04,   1.1206267E-04,   1.1195299E-04
     +,   1.1196306E-04,   1.1209847E-04,   1.1236439E-04
     +,   1.1276528E-04,   1.1330511E-04,   1.1398729E-04
     +,   1.1481463E-04,   1.1578950E-04,   1.1691388E-04
     +,   1.1818950E-04,   1.1961810E-04,   1.2120148E-04
     +,   1.2294186E-04,   1.2484232E-04,   1.2690715E-04
     +,   1.2914221E-04,   1.3155545E-04,   1.3415782E-04
     +,   1.3696373E-04,   1.3999164E-04,   1.4326541E-04
     +,   1.4681497E-04,   1.5067720E-04,   1.5489709E-04
     +,   1.5952937E-04,   1.6463957E-04,   1.7030456E-04
     +,   1.7661489E-04,   1.8367558E-04,   1.9160748E-04
     +,   2.0054744E-04,   2.1064904E-04,   2.2208343E-04
     +,   2.3503797E-04,   2.4971340E-04,   2.6632324E-04
     +,   2.8508928E-04,   3.0623470E-04,   3.2997836E-04
     +,   3.5652882E-04,   3.8607311E-04,   4.1876611E-04
     +,   4.5472095E-04,   4.9400079E-04,   5.3660839E-04
     +,   5.8247440E-04,   6.3145446E-04,   6.8332971E-04
     +,   7.3780614E-04,   7.9451513E-04,   8.5303694E-04
     +,   9.1291353E-04,   9.7367202E-04,   1.0348605E-03
     +,   1.0960960E-03,   1.1571129E-03,   1.2178208E-03
     +,   1.2783832E-03,   1.3392993E-03,   1.4014754E-03
     +,   1.4662870E-03,   1.5356146E-03,   1.6118340E-03
     +,   1.6977586E-03,   1.7965303E-03,   1.9115127E-03
     +,   2.0461606E-03,   2.2038524E-03,   2.3876727E-03
     +,   2.6000980E-03,   2.8425588E-03,   3.1150961E-03
     +,   3.4163990E-03,   3.7445263E-03,   4.0982510E-03
     +,   4.4786735E-03,   4.8904130E-03,   5.3416751E-03
     +,   5.8426778E-03,   6.4024241E-03,   7.0244237E-03
     +,   7.7018533E-03,   8.4142117E-03,   9.1290660E-03
     +,   9.8128961E-03,   1.0451796E-02,   1.1074340E-02
     +,   1.1760727E-02,   1.2624303E-02,   1.3767496E-02
     +,   1.5231336E-02,   1.6960787E-02,   1.8798877E-02
     +,   2.0515323E-02,   2.1866625E-02,   2.2666197E-02
     +,   2.2825867E-02,   2.2349600E-02,   2.1299852E-02
     +,   1.9773673E-02,   1.7899388E-02,   1.5834449E-02
     +,   1.3743776E-02,   1.1764937E-02,   9.9813510E-03
     +,   8.4178131E-03,   7.0567043E-03,   5.8640358E-03
     +,   4.8101079E-03,   3.8792198E-03,   3.0677731E-03
     +,   2.3775140E-03,   1.8084953E-03,   1.3553881E-03
     +,   1.0067436E-03,   7.4672047E-04,   5.5755791E-04
     +,   4.2209792E-04,   3.2553734E-04,   2.5619974E-04
     +,   2.0554187E-04,   1.6762453E-04,   1.3845491E-04
     +,   1.1537190E-04,   9.6604330E-05,   8.0968428E-05
     +,   6.7683955E-05,   5.6245837E-05,   4.6338206E-05
     +,   3.7763333E-05,   3.0392410E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz112 = Yx/0.121390243902439
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5351283E-07,   3.8342171E-07
     +,   4.1560384E-07,   4.5021204E-07,   4.8740753E-07
     +,   5.2736101E-07,   5.7025261E-07,   6.1627276E-07
     +,   6.6562171E-07,   7.1851258E-07,   7.7516870E-07
     +,   8.3582461E-07,   9.0072922E-07,   9.7014265E-07
     +,   1.0443397E-06,   1.1236092E-06,   1.2082539E-06
     +,   1.2985922E-06,   1.3949588E-06,   1.4977028E-06
     +,   1.6071940E-06,   1.7238167E-06,   1.8479724E-06
     +,   1.9800912E-06,   2.1206070E-06,   2.2699903E-06
     +,   2.4287233E-06,   2.5973168E-06,   2.7763003E-06
     +,   2.9662303E-06,   3.1676905E-06,   3.3812898E-06
     +,   3.6076656E-06,   3.8474882E-06,   4.1014550E-06
     +,   4.3703017E-06,   4.6547943E-06,   4.9557375E-06
     +,   5.2739870E-06,   5.6104086E-06,   5.9659519E-06
     +,   6.3415832E-06,   6.7383276E-06,   7.1572599E-06
     +,   7.5995090E-06,   8.0662539E-06,   8.5587390E-06
     +,   9.0782605E-06,   9.6261829E-06,   1.0203928E-05
     +,   1.0812983E-05,   1.1454905E-05,   1.2131292E-05
     +,   1.2843861E-05,   1.3594319E-05,   1.4384494E-05
     +,   1.5216242E-05,   1.6091482E-05,   1.7012177E-05
     +,   1.7980343E-05,   1.8998013E-05,   2.0067286E-05
     +,   2.1190202E-05,   2.2368882E-05,   2.3605468E-05
     +,   2.4901952E-05,   2.6260459E-05,   2.7682912E-05
     +,   2.9171335E-05,   3.0727497E-05,   3.2353259E-05
     +,   3.4050187E-05,   3.5819929E-05,   3.7663754E-05
     +,   3.9582992E-05,   4.1578776E-05,   4.3651966E-05
     +,   4.5803197E-05,   4.8033075E-05,   5.0342012E-05
     +,   5.2729978E-05,   5.5197052E-05,   5.7742855E-05
     +,   6.0367023E-05,   6.3068786E-05,   6.5847475E-05
     +,   6.8701913E-05,   7.1631141E-05,   7.4633681E-05
     +,   7.7708202E-05,   8.0853315E-05,   8.4067258E-05
     +,   8.7348213E-05,   9.0694492E-05,   9.4104340E-05
     +,   9.7575561E-05,   1.0110637E-04,   1.0469442E-04
     +,   1.0833776E-04,   1.1203382E-04,   1.1578043E-04
     +,   1.1957466E-04,   1.2341398E-04,   1.2729505E-04
     +,   1.3121469E-04,   1.3516935E-04,   1.3915483E-04
     +,   1.4316653E-04,   1.4719971E-04,   1.5124904E-04
     +,   1.5530825E-04,   1.5937108E-04,   1.6343003E-04
     +,   1.6747770E-04,   1.7150544E-04,   1.7550442E-04
     +,   1.7946497E-04,   1.8337721E-04,   1.8723037E-04
     +,   1.9101361E-04,   1.9471576E-04,   1.9832533E-04
     +,   2.0183061E-04,   2.0522012E-04,   2.0848271E-04
     +,   2.1160697E-04,   2.1458257E-04,   2.1739924E-04
     +,   2.2004786E-04,   2.2251990E-04,   2.2480788E-04
     +,   2.2690550E-04,   2.2880769E-04,   2.3051049E-04
     +,   2.3201146E-04,   2.3330950E-04,   2.3440490E-04
     +,   2.3529935E-04,   2.3599599E-04,   2.3649924E-04
     +,   2.3681471E-04,   2.3694920E-04,   2.3691078E-04
     +,   2.3670818E-04,   2.3635100E-04,   2.3584957E-04
     +,   2.3521457E-04,   2.3445720E-04,   2.3358877E-04
     +,   2.3262048E-04,   2.3156367E-04,   2.3042932E-04
     +,   2.2922820E-04,   2.2797026E-04,   2.2666530E-04
     +,   2.2532229E-04,   2.2394968E-04,   2.2255507E-04
     +,   2.2114531E-04,   2.1972675E-04,   2.1830476E-04
     +,   2.1688425E-04,   2.1546929E-04,   2.1406377E-04
     +,   2.1267065E-04,   2.1129254E-04,   2.0993191E-04
     +,   2.0859086E-04,   2.0727134E-04,   2.0597507E-04
     +,   2.0470399E-04,   2.0346018E-04,   2.0224582E-04
     +,   2.0106336E-04,   1.9991590E-04,   1.9880683E-04
     +,   1.9774016E-04,   1.9672075E-04,   1.9575417E-04
     +,   1.9484677E-04,   1.9400600E-04,   1.9324021E-04
     +,   1.9255900E-04,   1.9197303E-04,   1.9149407E-04
     +,   1.9113520E-04,   1.9091064E-04,   1.9083596E-04
     +,   1.9092766E-04,   1.9120361E-04,   1.9168256E-04
     +,   1.9238431E-04,   1.9332966E-04,   1.9454009E-04
     +,   1.9603819E-04,   1.9784774E-04,   1.9999332E-04
     +,   2.0250125E-04,   2.0540008E-04,   2.0872128E-04
     +,   2.1250006E-04,   2.1677672E-04,   2.2159885E-04
     +,   2.2702315E-04,   2.3311678E-04,   2.3996166E-04
     +,   2.4765669E-04,   2.5631976E-04,   2.6609207E-04
     +,   2.7714137E-04,   2.8966396E-04,   3.0388660E-04
     +,   3.2006760E-04,   3.3849865E-04,   3.5950216E-04
     +,   3.8342594E-04,   4.1063773E-04,   4.4151864E-04
     +,   4.7644932E-04,   5.1579217E-04,   5.5988203E-04
     +,   6.0900918E-04,   6.6340371E-04,   7.2323176E-04
     +,   7.8860117E-04,   8.5957057E-04,   9.3616755E-04
     +,   1.0184244E-03,   1.1064281E-03,   1.2003687E-03
     +,   1.3005936E-03,   1.4076774E-03,   1.5224923E-03
     +,   1.6462432E-03,   1.7804403E-03,   1.9268218E-03
     +,   2.0871093E-03,   2.2626179E-03,   2.4537926E-03
     +,   2.6597476E-03,   2.8779765E-03,   3.1044034E-03
     +,   3.3339525E-03,   3.5615233E-03,   3.7831229E-03
     +,   3.9968737E-03,   4.2036967E-03,   4.4076652E-03
     +,   4.6161497E-03,   4.8397942E-03,   5.0920420E-03
     +,   5.3874515E-03,   5.7387743E-03,   6.1536366E-03
     +,   6.6326321E-03,   7.1702013E-03,   7.7582183E-03
     +,   8.3906846E-03,   9.0686614E-03,   9.8064356E-03
     +,   1.0638238E-02,   1.1618755E-02,   1.2808311E-02
     +,   1.4241610E-02,   1.5892135E-02,   1.7649358E-02
     +,   1.9322176E-02,   2.0677995E-02,   2.1509118E-02
     +,   2.1693306E-02,   2.1214610E-02,   2.0144876E-02
     +,   1.8612148E-02,   1.6772527E-02,   1.4784013E-02
     +,   1.2781311E-02,   1.0860959E-02,   9.0842238E-03
     +,   7.4875923E-03,   6.0910191E-03,   4.8993118E-03
     +,   3.9033033E-03,   3.0835613E-03,   2.4167090E-03
     +,   1.8798615E-03,   1.4525752E-03,   1.1165410E-03
     +,   8.5516030E-04,   6.5349584E-04,   4.9849978E-04
     +,   3.7935286E-04,   2.8748371E-04,   2.1641332E-04
     +,   1.6136689E-04,   1.1886298E-04,   8.6301159E-05
     +,   6.1667000E-05,   4.3324610E-05,   2.9914365E-05
     +,   2.0296944E-05,   1.3533830E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz113 = Yx/0.11490243902439
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4860689E-05,   1.5236682E-05
     +,   1.5621048E-05,   1.6013959E-05,   1.6415588E-05
     +,   1.6826118E-05,   1.7245726E-05,   1.7674591E-05
     +,   1.8112883E-05,   1.8560791E-05,   1.9018489E-05
     +,   1.9486157E-05,   1.9963963E-05,   2.0452084E-05
     +,   2.0950694E-05,   2.1459959E-05,   2.1980044E-05
     +,   2.2511116E-05,   2.3053341E-05,   2.3606864E-05
     +,   2.4171846E-05,   2.4748431E-05,   2.5336762E-05
     +,   2.5937008E-05,   2.6549260E-05,   2.7173684E-05
     +,   2.7810393E-05,   2.8459513E-05,   2.9121153E-05
     +,   2.9795436E-05,   3.0482455E-05,   3.1182313E-05
     +,   3.1895117E-05,   3.2620941E-05,   3.3359876E-05
     +,   3.4111999E-05,   3.4877386E-05,   3.5656081E-05
     +,   3.6448208E-05,   3.7253754E-05,   3.8072805E-05
     +,   3.8905415E-05,   3.9751609E-05,   4.0611420E-05
     +,   4.1484876E-05,   4.2372005E-05,   4.3272834E-05
     +,   4.4187349E-05,   4.5115572E-05,   4.6057477E-05
     +,   4.7013073E-05,   4.7982325E-05,   4.8965183E-05
     +,   4.9961665E-05,   5.0971652E-05,   5.1995121E-05
     +,   5.3031996E-05,   5.4082175E-05,   5.5145560E-05
     +,   5.6222034E-05,   5.7311474E-05,   5.8413720E-05
     +,   5.9528582E-05,   6.0655890E-05,   6.1795465E-05
     +,   6.2947038E-05,   6.4110391E-05,   6.5285189E-05
     +,   6.6471228E-05,   6.7668072E-05,   6.8875488E-05
     +,   7.0093025E-05,   7.1320326E-05,   7.2556890E-05
     +,   7.3802330E-05,   7.5056196E-05,   7.6317927E-05
     +,   7.7586978E-05,   7.8862802E-05,   8.0144884E-05
     +,   8.1432525E-05,   8.2725179E-05,   8.4022096E-05
     +,   8.5322732E-05,   8.6626256E-05,   8.7932094E-05
     +,   8.9239402E-05,   9.0547510E-05,   9.1855618E-05
     +,   9.3162991E-05,   9.4468887E-05,   9.5772477E-05
     +,   9.7072945E-05,   9.8369499E-05,   9.9661382E-05
     +,   1.0094771E-04,   1.0222775E-04,   1.0350061E-04
     +,   1.0476553E-04,   1.0602161E-04,   1.0726808E-04
     +,   1.0850405E-04,   1.0972871E-04,   1.1094118E-04
     +,   1.1214065E-04,   1.1332624E-04,   1.1449707E-04
     +,   1.1565214E-04,   1.1679070E-04,   1.1791172E-04
     +,   1.1901424E-04,   1.2009734E-04,   1.2116000E-04
     +,   1.2220119E-04,   1.2321983E-04,   1.2421490E-04
     +,   1.2518519E-04,   1.2612964E-04,   1.2704701E-04
     +,   1.2793610E-04,   1.2879574E-04,   1.2962460E-04
     +,   1.3042144E-04,   1.3118490E-04,   1.3191377E-04
     +,   1.3260660E-04,   1.3326218E-04,   1.3387916E-04
     +,   1.3445625E-04,   1.3499222E-04,   1.3548584E-04
     +,   1.3593589E-04,   1.3634138E-04,   1.3670120E-04
     +,   1.3701447E-04,   1.3728044E-04,   1.3749840E-04
     +,   1.3766780E-04,   1.3778835E-04,   1.3785984E-04
     +,   1.3788232E-04,   1.3785608E-04,   1.3778161E-04
     +,   1.3765971E-04,   1.3749143E-04,   1.3727813E-04
     +,   1.3702152E-04,   1.3672367E-04,   1.3638697E-04
     +,   1.3601418E-04,   1.3560860E-04,   1.3517374E-04
     +,   1.3471374E-04,   1.3423309E-04,   1.3373679E-04
     +,   1.3323026E-04,   1.3271948E-04,   1.3221095E-04
     +,   1.3171154E-04,   1.3122876E-04,   1.3077052E-04
     +,   1.3034532E-04,   1.2996201E-04,   1.2963005E-04
     +,   1.2935918E-04,   1.2915955E-04,   1.2904181E-04
     +,   1.2901677E-04,   1.2909570E-04,   1.2928984E-04
     +,   1.2961090E-04,   1.3007049E-04,   1.3068049E-04
     +,   1.3145288E-04,   1.3239952E-04,   1.3353261E-04
     +,   1.3486434E-04,   1.3640709E-04,   1.3817349E-04
     +,   1.4017679E-04,   1.4243084E-04,   1.4495025E-04
     +,   1.4775060E-04,   1.5084929E-04,   1.5426538E-04
     +,   1.5801981E-04,   1.6213609E-04,   1.6664070E-04
     +,   1.7156333E-04,   1.7693658E-04,   1.8279703E-04
     +,   1.8918510E-04,   1.9614435E-04,   2.0372178E-04
     +,   2.1196812E-04,   2.2093698E-04,   2.3068390E-04
     +,   2.4126579E-04,   2.5274151E-04,   2.6517024E-04
     +,   2.7861004E-04,   2.9311798E-04,   3.0875040E-04
     +,   3.2556197E-04,   3.4360320E-04,   3.6292407E-04
     +,   3.8357236E-04,   4.0559209E-04,   4.2902460E-04
     +,   4.5391056E-04,   4.8028684E-04,   5.0818507E-04
     +,   5.3762947E-04,   5.6863710E-04,   6.0121209E-04
     +,   6.3533790E-04,   6.7097513E-04,   7.0805848E-04
     +,   7.4649067E-04,   7.8613957E-04,   8.2684652E-04
     +,   8.6843531E-04,   9.1072288E-04,   9.5354812E-04
     +,   9.9680654E-04,   1.0404813E-03,   1.0846826E-03
     +,   1.1296826E-03,   1.1759431E-03,   1.2241222E-03
     +,   1.2750550E-03,   1.3297122E-03,   1.3891367E-03
     +,   1.4543504E-03,   1.5262503E-03,   1.6055278E-03
     +,   1.6926031E-03,   1.7875921E-03,   1.8903458E-03
     +,   2.0005703E-03,   2.1180073E-03,   2.2427065E-03
     +,   2.3753850E-03,   2.5177801E-03,   2.6728555E-03
     +,   2.8446601E-03,   3.0376781E-03,   3.2555782E-03
     +,   3.4996171E-03,   3.7672818E-03,   4.0522111E-03
     +,   4.3460154E-03,   4.6422007E-03,   4.9411911E-03
     +,   5.2543716E-03,   5.6048403E-03,   6.0237017E-03
     +,   6.5425667E-03,   7.1846806E-03,   7.9578301E-03
     +,   8.8517796E-03,   9.8424926E-03,   1.0902575E-02
     +,   1.2013583E-02,   1.3172374E-02,   1.4385290E-02
     +,   1.5651623E-02,   1.6947394E-02,   1.8218638E-02
     +,   1.9381605E-02,   2.0323822E-02,   2.0911640E-02
     +,   2.1017043E-02,   2.0561257E-02,   1.9548384E-02
     +,   1.8062694E-02,   1.6232856E-02,   1.4193484E-02
     +,   1.2066161E-02,   9.9609923E-03,   7.9788854E-03
     +,   6.2059602E-03,   4.7007436E-03,   3.4861895E-03
     +,   2.5506336E-03,   1.8578457E-03,   1.3596141E-03
     +,   1.0069204E-03,   7.5707305E-04,   5.7683385E-04
     +,   4.4275299E-04,   3.3964289E-04,   2.5840345E-04
     +,   1.9378887E-04,   1.4267545E-04,   1.0289043E-04
     +,   7.2618313E-05,   5.0162718E-05,   3.3933480E-05
     +,   2.2494414E-05,   1.4621014E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz114 = Yx/0.11319512195122
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz1148(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1662587E-06,   9.4091129E-06
     +,   9.6661497E-06,   9.9387344E-06,   1.0228334E-05
     +,   1.0536529E-05,   1.0865007E-05,   1.1215579E-05
     +,   1.1590155E-05,   1.1990794E-05,   1.2419644E-05
     +,   1.2878985E-05,   1.3371210E-05,   1.3898832E-05
     +,   1.4464455E-05,   1.5070807E-05,   1.5720700E-05
     +,   1.6417047E-05,   1.7162822E-05,   1.7961082E-05
     +,   1.8814919E-05,   1.9727473E-05,   2.0701887E-05
     +,   2.1741362E-05,   2.2848963E-05,   2.4027828E-05
     +,   2.5280962E-05,   2.6611277E-05,   2.8021568E-05
     +,   2.9514476E-05,   3.1092459E-05,   3.2757747E-05
     +,   3.4512326E-05,   3.6357898E-05,   3.8295857E-05
     +,   4.0327239E-05,   4.2452688E-05,   4.4672437E-05
     +,   4.6986377E-05,   4.9393711E-05,   5.1893381E-05
     +,   5.4483688E-05,   5.7162411E-05,   5.9926788E-05
     +,   6.2773492E-05,   6.5698659E-05,   6.8697809E-05
     +,   7.1765906E-05,   7.4897376E-05,   7.8086116E-05
     +,   8.1325466E-05,   8.4608320E-05,   8.7927030E-05
     +,   9.1273781E-05,   9.4640003E-05,   9.8017190E-05
     +,   1.0139641E-04,   1.0476857E-04,   1.0812450E-04
     +,   1.1145498E-04,   1.1475087E-04,   1.1800323E-04
     +,   1.2120307E-04,   1.2434216E-04,   1.2741250E-04
     +,   1.3040645E-04,   1.3331728E-04,   1.3613865E-04
     +,   1.3886539E-04,   1.4149286E-04,   1.4401766E-04
     +,   1.4643723E-04,   1.4875039E-04,   1.5095687E-04
     +,   1.5305776E-04,   1.5505558E-04,   1.5695390E-04
     +,   1.5875763E-04,   1.6047322E-04,   1.6210828E-04
     +,   1.6367165E-04,   1.6517354E-04,   1.6662521E-04
     +,   1.6803907E-04,   1.6942843E-04,   1.7080753E-04
     +,   1.7219131E-04,   1.7359534E-04,   1.7503538E-04
     +,   1.7652762E-04,   1.7808820E-04,   1.7973298E-04
     +,   1.8147730E-04,   1.8333610E-04,   1.8532328E-04
     +,   1.8745146E-04,   1.8973208E-04,   1.9217483E-04
     +,   1.9478780E-04,   1.9757658E-04,   2.0054510E-04
     +,   2.0369433E-04,   2.0702317E-04,   2.1052745E-04
     +,   2.1420034E-04,   2.1803258E-04,   2.2201153E-04
     +,   2.2612185E-04,   2.3034579E-04,   2.3466283E-04
     +,   2.3904965E-04,   2.4348132E-04,   2.4793006E-04
     +,   2.5236697E-04,   2.5676124E-04,   2.6108135E-04
     +,   2.6529454E-04,   2.6936815E-04,   2.7326899E-04
     +,   2.7696477E-04,   2.8042402E-04,   2.8361627E-04
     +,   2.8651269E-04,   2.8908657E-04,   2.9131392E-04
     +,   2.9317269E-04,   2.9464447E-04,   2.9571398E-04
     +,   2.9636893E-04,   2.9660115E-04,   2.9640575E-04
     +,   2.9578179E-04,   2.9473187E-04,   2.9326236E-04
     +,   2.9138307E-04,   2.8910706E-04,   2.8645076E-04
     +,   2.8343350E-04,   2.8007705E-04,   2.7640539E-04
     +,   2.7244503E-04,   2.6822364E-04,   2.6377011E-04
     +,   2.5911440E-04,   2.5428718E-04,   2.4931898E-04
     +,   2.4424031E-04,   2.3908119E-04,   2.3387134E-04
     +,   2.2863888E-04,   2.2341065E-04,   2.1821266E-04
     +,   2.1306906E-04,   2.0800212E-04,   2.0303228E-04
     +,   1.9817862E-04,   1.9345811E-04,   1.8888577E-04
     +,   1.8447464E-04,   1.8023688E-04,   1.7618222E-04
     +,   1.7231907E-04,   1.6865481E-04,   1.6519557E-04
     +,   1.6194613E-04,   1.5891048E-04,   1.5609208E-04
     +,   1.5349382E-04,   1.5111803E-04,   1.4896698E-04
     +,   1.4704293E-04,   1.4534811E-04,   1.4388521E-04
     +,   1.4265710E-04,   1.4166748E-04,   1.4092066E-04
     +,   1.4042188E-04,   1.4017741E-04,   1.4019487E-04
     +,   1.4048321E-04,   1.4105314E-04,   1.4191707E-04
     +,   1.4308955E-04,   1.4458747E-04,   1.4643041E-04
     +,   1.4864058E-04,   1.5124310E-04,   1.5426663E-04
     +,   1.5774330E-04,   1.6170838E-04,   1.6620124E-04
     +,   1.7126474E-04,   1.7694524E-04,   1.8329201E-04
     +,   1.9035760E-04,   1.9819720E-04,   2.0686693E-04
     +,   2.1642330E-04,   2.2692308E-04,   2.3842130E-04
     +,   2.5096891E-04,   2.6461168E-04,   2.7938973E-04
     +,   2.9533450E-04,   3.1246585E-04,   3.3079373E-04
     +,   3.5031524E-04,   3.7101307E-04,   3.9285643E-04
     +,   4.1580331E-04,   4.3980186E-04,   4.6479053E-04
     +,   4.9070432E-04,   5.1748130E-04,   5.4506661E-04
     +,   5.7341816E-04,   6.0251518E-04,   6.3236745E-04
     +,   6.6301954E-04,   6.9455610E-04,   7.2711211E-04
     +,   7.6087564E-04,   7.9609116E-04,   8.3306385E-04
     +,   8.7216793E-04,   9.1384881E-04,   9.5862127E-04
     +,   1.0070786E-03,   1.0598904E-03,   1.1177972E-03
     +,   1.1815940E-03,   1.2521218E-03,   1.3302534E-03
     +,   1.4168740E-03,   1.5128697E-03,   1.6191321E-03
     +,   1.7365381E-03,   1.8659062E-03,   2.0079203E-03
     +,   2.1629978E-03,   2.3310955E-03,   2.5115067E-03
     +,   2.7027582E-03,   2.9026924E-03,   3.1087797E-03
     +,   3.3187009E-03,   3.5311230E-03,   3.7464374E-03
     +,   3.9671389E-03,   4.1976618E-03,   4.4436087E-03
     +,   4.7104689E-03,   5.0021796E-03,   5.3200661E-03
     +,   5.6623877E-03,   6.0245986E-03,   6.4001181E-03
     +,   6.7815753E-03,   7.1623977E-03,   7.5390153E-03
     +,   7.9138568E-03,   8.2987882E-03,   8.7176776E-03
     +,   9.2061777E-03,   9.8068072E-03,   1.0558842E-02
     +,   1.1484081E-02,   1.2572156E-02,   1.3770660E-02
     +,   1.4985067E-02,   1.6090656E-02,   1.6954731E-02
     +,   1.7462717E-02,   1.7539825E-02,   1.7161591E-02
     +,   1.6352294E-02,   1.5174348E-02,   1.3714567E-02
     +,   1.2071300E-02,   1.0344937E-02,   8.6299712E-03
     +,   7.0087737E-03,   5.5452576E-03,   4.2811609E-03
     +,   3.2343606E-03,   2.4014723E-03,   1.7626343E-03
     +,   1.2881036E-03,   9.4455294E-04,   6.9992623E-04
     +,   5.2665436E-04,   4.0293994E-04,   3.1280561E-04
     +,   2.4524331E-04,   1.9308292E-04,   1.5182553E-04
     +,   1.1870306E-04,   9.1969101E-05,   7.0451591E-05
     +,   5.3276202E-05,   3.9731338E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz1148 = Yx/0.10605
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4584339E-05,   1.5051504E-05
     +,   1.5535397E-05,   1.6036403E-05,   1.6554925E-05
     +,   1.7091328E-05,   1.7645962E-05,   1.8219162E-05
     +,   1.8811217E-05,   1.9422429E-05,   2.0053038E-05
     +,   2.0703255E-05,   2.1373275E-05,   2.2063241E-05
     +,   2.2773269E-05,   2.3503437E-05,   2.4253770E-05
     +,   2.5024272E-05,   2.5814885E-05,   2.6625517E-05
     +,   2.7456037E-05,   2.8306260E-05,   2.9175939E-05
     +,   3.0064853E-05,   3.0972635E-05,   3.1898970E-05
     +,   3.2843447E-05,   3.3805638E-05,   3.4785069E-05
     +,   3.5781253E-05,   3.6793645E-05,   3.7821701E-05
     +,   3.8864859E-05,   3.9922528E-05,   4.0994117E-05
     +,   4.2079060E-05,   4.3176737E-05,   4.4286593E-05
     +,   4.5408146E-05,   4.6540801E-05,   4.7684171E-05
     +,   4.8837832E-05,   5.0001428E-05,   5.1174735E-05
     +,   5.2357573E-05,   5.3549902E-05,   5.4751770E-05
     +,   5.5963392E-05,   5.7185098E-05,   5.8417383E-05
     +,   5.9660964E-05,   6.0916718E-05,   6.2185660E-05
     +,   6.3469219E-05,   6.4768770E-05,   6.6086199E-05
     +,   6.7423491E-05,   6.8782974E-05,   7.0167189E-05
     +,   7.1579001E-05,   7.3021554E-05,   7.4498290E-05
     +,   7.6012839E-05,   7.7569282E-05,   7.9171921E-05
     +,   8.0825223E-05,   8.2534076E-05,   8.4303458E-05
     +,   8.6138731E-05,   8.8045221E-05,   9.0028683E-05
     +,   9.2094728E-05,   9.4249328E-05,   9.6498217E-05
     +,   9.8847348E-05,   1.0130260E-04,   1.0386958E-04
     +,   1.0655369E-04,   1.0936030E-04,   1.1229444E-04
     +,   1.1536042E-04,   1.1856258E-04,   1.2190423E-04
     +,   1.2538850E-04,   1.2901740E-04,   1.3279261E-04
     +,   1.3671460E-04,   1.4078322E-04,   1.4499700E-04
     +,   1.4935376E-04,   1.5385033E-04,   1.5848200E-04
     +,   1.6324305E-04,   1.6812672E-04,   1.7312510E-04
     +,   1.7822871E-04,   1.8342743E-04,   1.8870927E-04
     +,   1.9406181E-04,   1.9947097E-04,   2.0492215E-04
     +,   2.1039919E-04,   2.1588588E-04,   2.2136432E-04
     +,   2.2681663E-04,   2.3222441E-04,   2.3756837E-04
     +,   2.4282913E-04,   2.4798739E-04,   2.5302390E-04
     +,   2.5791916E-04,   2.6265453E-04,   2.6721132E-04
     +,   2.7157206E-04,   2.7571945E-04,   2.7963766E-04
     +,   2.8331138E-04,   2.8672695E-04,   2.8987168E-04
     +,   2.9273462E-04,   2.9530580E-04,   2.9757753E-04
     +,   2.9954297E-04,   3.0119758E-04,   3.0253848E-04
     +,   3.0356445E-04,   3.0427607E-04,   3.0467584E-04
     +,   3.0476786E-04,   3.0455837E-04,   3.0405508E-04
     +,   3.0326738E-04,   3.0220655E-04,   3.0088547E-04
     +,   2.9931834E-04,   2.9752112E-04,   2.9551104E-04
     +,   2.9330669E-04,   2.9092800E-04,   2.8839594E-04
     +,   2.8573256E-04,   2.8296106E-04,   2.8010528E-04
     +,   2.7718997E-04,   2.7424042E-04,   2.7128265E-04
     +,   2.6834282E-04,   2.6544760E-04,   2.6262406E-04
     +,   2.5989857E-04,   2.5729800E-04,   2.5484868E-04
     +,   2.5257663E-04,   2.5050726E-04,   2.4866476E-04
     +,   2.4707304E-04,   2.4575446E-04,   2.4472998E-04
     +,   2.4401913E-04,   2.4363984E-04,   2.4360798E-04
     +,   2.4393742E-04,   2.4463987E-04,   2.4572451E-04
     +,   2.4719816E-04,   2.4906502E-04,   2.5132674E-04
     +,   2.5398200E-04,   2.5702699E-04,   2.6045548E-04
     +,   2.6425827E-04,   2.6842393E-04,   2.7293887E-04
     +,   2.7778739E-04,   2.8295178E-04,   2.8841326E-04
     +,   2.9415195E-04,   3.0014667E-04,   3.0637594E-04
     +,   3.1281856E-04,   3.1945357E-04,   3.2626078E-04
     +,   3.3321997E-04,   3.4031368E-04,   3.4752546E-04
     +,   3.5484022E-04,   3.6224452E-04,   3.6972723E-04
     +,   3.7727901E-04,   3.8489138E-04,   3.9255756E-04
     +,   4.0027240E-04,   4.0803006E-04,   4.1582552E-04
     +,   4.2365430E-04,   4.3151042E-04,   4.3938716E-04
     +,   4.4727640E-04,   4.5516872E-04,   4.6305364E-04
     +,   4.7091875E-04,   4.7875082E-04,   4.8653714E-04
     +,   4.9426546E-04,   5.0192571E-04,   5.0951249E-04
     +,   5.1702687E-04,   5.2447885E-04,   5.3189142E-04
     +,   5.3930440E-04,   5.4677954E-04,   5.5440463E-04
     +,   5.6230044E-04,   5.7062518E-04,   5.7958369E-04
     +,   5.8942975E-04,   6.0047227E-04,   6.1308115E-04
     +,   6.2768656E-04,   6.4477883E-04,   6.6490518E-04
     +,   6.8866072E-04,   7.1667437E-04,   7.4958929E-04
     +,   7.8803871E-04,   8.3261292E-04,   8.8381773E-04
     +,   9.4202964E-04,   1.0074581E-03,   1.0801030E-03
     +,   1.1597192E-03,   1.2458210E-03,   1.3377191E-03
     +,   1.4345896E-03,   1.5355897E-03,   1.6400382E-03
     +,   1.7475907E-03,   1.8583990E-03,   1.9732150E-03
     +,   2.0933917E-03,   2.2207019E-03,   2.3569972E-03
     +,   2.5037655E-03,   2.6616594E-03,   2.8301431E-03
     +,   3.0074005E-03,   3.1907056E-03,   3.3772241E-03
     +,   3.5651443E-03,   3.7548100E-03,   3.9495318E-03
     +,   4.1555129E-03,   4.3806271E-03,   4.6322704E-03
     +,   4.9146744E-03,   5.2267220E-03,   5.5611385E-03
     +,   5.9058354E-03,   6.2471083E-03,   6.5737637E-03
     +,   6.8806498E-03,   7.1704485E-03,   7.4531222E-03
     +,   7.7435700E-03,   8.0585685E-03,   8.4141400E-03
     +,   8.8233575E-03,   9.2941262E-03,   9.8259300E-03
     +,   1.0405854E-02,   1.1004621E-02,   1.1575283E-02
     +,   1.2056417E-02,   1.2380633E-02,   1.2486404E-02
     +,   1.2330313E-02,   1.1896065E-02,   1.1197691E-02
     +,   1.0276422E-02,   9.1931354E-03,   8.0180550E-03
     +,   6.8212138E-03,   5.6642340E-03,   4.5954366E-03
     +,   3.6471614E-03,   2.8360996E-03,   2.1650218E-03
     +,   1.6260238E-03,   1.2042588E-03,   8.8136946E-04
     +,   6.3851720E-04,   4.5830864E-04,   3.2594736E-04
     +,   2.2950032E-04,   1.5974768E-04,   1.0971704E-04
     +,   7.4205862E-05,   4.9326616E-05,   3.2172164E-05
     +,   2.0559393E-05,   1.2858657E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz116 = Yx/0.0913589743589744
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5746340E-05,   2.6824739E-05
     +,   2.7943241E-05,   2.9102954E-05,   3.0304995E-05
     +,   3.1550499E-05,   3.2840573E-05,   3.4176359E-05
     +,   3.5558929E-05,   3.6989459E-05,   3.8468988E-05
     +,   3.9998602E-05,   4.1579344E-05,   4.3212200E-05
     +,   4.4898148E-05,   4.6638084E-05,   4.8432874E-05
     +,   5.0283306E-05,   5.2190080E-05,   5.4153810E-05
     +,   5.6175038E-05,   5.8254172E-05,   6.0391507E-05
     +,   6.2587293E-05,   6.4841450E-05,   6.7153996E-05
     +,   6.9524591E-05,   7.1952854E-05,   7.4438220E-05
     +,   7.6979872E-05,   7.9576894E-05,   8.2228122E-05
     +,   8.4932261E-05,   8.7687789E-05,   9.0492991E-05
     +,   9.3345952E-05,   9.6244650E-05,   9.9186705E-05
     +,   1.0216988E-04,   1.0519139E-04,   1.0824858E-04
     +,   1.1133863E-04,   1.1445847E-04,   1.1760504E-04
     +,   1.2077521E-04,   1.2396574E-04,   1.2717341E-04
     +,   1.3039497E-04,   1.3362720E-04,   1.3686693E-04
     +,   1.4011108E-04,   1.4335672E-04,   1.4660097E-04
     +,   1.4984133E-04,   1.5307512E-04,   1.5630035E-04
     +,   1.5951489E-04,   1.6271713E-04,   1.6590570E-04
     +,   1.6907952E-04,   1.7223776E-04,   1.7538029E-04
     +,   1.7850667E-04,   1.8161755E-04,   1.8471373E-04
     +,   1.8779596E-04,   1.9086603E-04,   1.9392540E-04
     +,   1.9697654E-04,   2.0002152E-04,   2.0306341E-04
     +,   2.0610497E-04,   2.0914967E-04,   2.1220082E-04
     +,   2.1526212E-04,   2.1833740E-04,   2.2143053E-04
     +,   2.2454525E-04,   2.2768554E-04,   2.3085532E-04
     +,   2.3405832E-04,   2.3729820E-04,   2.4057821E-04
     +,   2.4390180E-04,   2.4727144E-04,   2.5068986E-04
     +,   2.5415901E-04,   2.5768069E-04,   2.6125569E-04
     +,   2.6488476E-04,   2.6856779E-04,   2.7230397E-04
     +,   2.7609177E-04,   2.7992885E-04,   2.8381270E-04
     +,   2.8773895E-04,   2.9170327E-04,   2.9569984E-04
     +,   2.9972260E-04,   3.0376363E-04,   3.0781535E-04
     +,   3.1186789E-04,   3.1591163E-04,   3.1993535E-04
     +,   3.2392726E-04,   3.2787496E-04,   3.3176472E-04
     +,   3.3558247E-04,   3.3931329E-04,   3.4294234E-04
     +,   3.4645328E-04,   3.4983020E-04,   3.5305644E-04
     +,   3.5611560E-04,   3.5899112E-04,   3.6166649E-04
     +,   3.6412533E-04,   3.6635221E-04,   3.6833147E-04
     +,   3.7004895E-04,   3.7149084E-04,   3.7264457E-04
     +,   3.7349857E-04,   3.7404252E-04,   3.7426766E-04
     +,   3.7416667E-04,   3.7373384E-04,   3.7296495E-04
     +,   3.7185775E-04,   3.7041199E-04,   3.6862862E-04
     +,   3.6651129E-04,   3.6406465E-04,   3.6129568E-04
     +,   3.5821318E-04,   3.5482718E-04,   3.5114994E-04
     +,   3.4719502E-04,   3.4297726E-04,   3.3851311E-04
     +,   3.3381995E-04,   3.2891659E-04,   3.2382246E-04
     +,   3.1855749E-04,   3.1314316E-04,   3.0760068E-04
     +,   3.0195160E-04,   2.9621832E-04,   2.9042320E-04
     +,   2.8458799E-04,   2.7873507E-04,   2.7288630E-04
     +,   2.6706388E-04,   2.6128904E-04,   2.5558294E-04
     +,   2.4996678E-04,   2.4446126E-04,   2.3908674E-04
     +,   2.3386307E-04,   2.2881039E-04,   2.2394831E-04
     +,   2.1929610E-04,   2.1487335E-04,   2.1069970E-04
     +,   2.0679427E-04,   2.0317626E-04,   1.9986546E-04
     +,   1.9688145E-04,   1.9424390E-04,   1.9197255E-04
     +,   1.9008755E-04,   1.8860905E-04,   1.8755738E-04
     +,   1.8695294E-04,   1.8681648E-04,   1.8716858E-04
     +,   1.8803043E-04,   1.8942347E-04,   1.9136936E-04
     +,   1.9389046E-04,   1.9701027E-04,   2.0075313E-04
     +,   2.0514462E-04,   2.1021265E-04,   2.1598769E-04
     +,   2.2250239E-04,   2.2979267E-04,   2.3789858E-04
     +,   2.4686457E-04,   2.5673825E-04,   2.6757256E-04
     +,   2.7942483E-04,   2.9235534E-04,   3.0642719E-04
     +,   3.2170617E-04,   3.3825869E-04,   3.5614811E-04
     +,   3.7543426E-04,   3.9617124E-04,   4.1840450E-04
     +,   4.4216544E-04,   4.6747015E-04,   4.9431861E-04
     +,   5.2268995E-04,   5.5253820E-04,   5.8379601E-04
     +,   6.1637280E-04,   6.5015128E-04,   6.8499468E-04
     +,   7.2075066E-04,   7.5725734E-04,   7.9434767E-04
     +,   8.3186332E-04,   8.6967007E-04,   9.0766832E-04
     +,   9.4580569E-04,   9.8409504E-04,   1.0226275E-03
     +,   1.0615772E-03,   1.1011993E-03,   1.1418292E-03
     +,   1.1838645E-03,   1.2277338E-03,   1.2738637E-03
     +,   1.3226419E-03,   1.3743700E-03,   1.4292229E-03
     +,   1.4872234E-03,   1.5482343E-03,   1.6119720E-03
     +,   1.6780407E-03,   1.7460012E-03,   1.8154763E-03
     +,   1.8862445E-03,   1.9583518E-03,   2.0322218E-03
     +,   2.1087169E-03,   2.1891424E-03,   2.2752003E-03
     +,   2.3688488E-03,   2.4720628E-03,   2.5865389E-03
     +,   2.7133385E-03,   2.8525919E-03,   3.0032611E-03
     +,   3.1630816E-03,   3.3287804E-03,   3.4965477E-03
     +,   3.6627646E-03,   3.8248228E-03,   3.9819842E-03
     +,   4.1359011E-03,   4.2907516E-03,   4.4528181E-03
     +,   4.6295645E-03,   4.8284088E-03,   5.0554471E-03
     +,   5.3145825E-03,   5.6071989E-03,   5.9324466E-03
     +,   6.2879492E-03,   6.6706487E-03,   7.0772669E-03
     +,   7.5040883E-03,   7.9459697E-03,   8.3949761E-03
     +,   8.8388864E-03,   9.2602950E-03,   9.6367877E-03
     +,   9.9424636E-03,   1.0150400E-02,   1.0236040E-02
     +,   1.0180519E-02,   9.9735279E-03,   9.6149389E-03
     +,   9.1153048E-03,   8.4946752E-03,   7.7805510E-03
     +,   7.0049157E-03,   6.2011783E-03,   5.4009929E-03
     +,   4.6320306E-03,   3.9160349E-03,   3.2681904E-03
     +,   2.6969167E-03,   2.2046990E-03,   1.7890807E-03
     +,   1.4441186E-03,   1.1617698E-03,   9.3305123E-04
     +,   7.4905984E-04,   6.0155877E-04,   4.8338715E-04
     +,   3.8854481E-04,   3.1219341E-04,   2.5049917E-04
     +,   2.0048622E-04,   1.5984669E-04,   1.2679926E-04
     +,   9.9949670E-05,   7.8199031E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz117 = Yx/0.0872307692307692
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.5790771E-06,   9.2514074E-06
     +,   9.9665713E-06,   1.0726350E-05,   1.1532513E-05
     +,   1.2386799E-05,   1.3290912E-05,   1.4246526E-05
     +,   1.5255216E-05,   1.6318550E-05,   1.7437960E-05
     +,   1.8614801E-05,   1.9850320E-05,   2.1145626E-05
     +,   2.2501708E-05,   2.3919387E-05,   2.5399322E-05
     +,   2.6941994E-05,   2.8547689E-05,   3.0216492E-05
     +,   3.1948242E-05,   3.3742566E-05,   3.5598816E-05
     +,   3.7516202E-05,   3.9493458E-05,   4.1529278E-05
     +,   4.3621942E-05,   4.5769477E-05,   4.7969639E-05
     +,   5.0219885E-05,   5.2517426E-05,   5.4859127E-05
     +,   5.7241650E-05,   5.9661375E-05,   6.2114414E-05
     +,   6.4596657E-05,   6.7103778E-05,   6.9631213E-05
     +,   7.2174349E-05,   7.4728167E-05,   7.7287863E-05
     +,   7.9848214E-05,   8.2404149E-05,   8.4950494E-05
     +,   8.7482054E-05,   8.9993729E-05,   9.2480484E-05
     +,   9.4937393E-05,   9.7359756E-05,   9.9743083E-05
     +,   1.0208305E-04,   1.0437573E-04,   1.0661746E-04
     +,   1.0880511E-04,   1.1093579E-04,   1.1300723E-04
     +,   1.1501754E-04,   1.1696547E-04,   1.1885039E-04
     +,   1.2067211E-04,   1.2243121E-04,   1.2412894E-04
     +,   1.2576712E-04,   1.2734836E-04,   1.2887608E-04
     +,   1.3035409E-04,   1.3178740E-04,   1.3318127E-04
     +,   1.3454197E-04,   1.3587638E-04,   1.3719210E-04
     +,   1.3849729E-04,   1.3980095E-04,   1.4111241E-04
     +,   1.4244177E-04,   1.4379967E-04,   1.4519705E-04
     +,   1.4664533E-04,   1.4815626E-04,   1.4974206E-04
     +,   1.5141490E-04,   1.5318728E-04,   1.5507158E-04
     +,   1.5708034E-04,   1.5922580E-04,   1.6152015E-04
     +,   1.6397490E-04,   1.6660155E-04,   1.6941082E-04
     +,   1.7241262E-04,   1.7561656E-04,   1.7903083E-04
     +,   1.8266252E-04,   1.8651807E-04,   1.9060234E-04
     +,   1.9491870E-04,   1.9946920E-04,   2.0425384E-04
     +,   2.0927156E-04,   2.1451867E-04,   2.1999022E-04
     +,   2.2567862E-04,   2.3157492E-04,   2.3766728E-04
     +,   2.4394240E-04,   2.5038476E-04,   2.5697637E-04
     +,   2.6369726E-04,   2.7052575E-04,   2.7743843E-04
     +,   2.8440944E-04,   2.9141214E-04,   2.9841781E-04
     +,   3.0539720E-04,   3.1231926E-04,   3.1915322E-04
     +,   3.2586680E-04,   3.3242867E-04,   3.3880651E-04
     +,   3.4496939E-04,   3.5088672E-04,   3.5652897E-04
     +,   3.6186792E-04,   3.6687698E-04,   3.7153211E-04
     +,   3.7581043E-04,   3.7969215E-04,   3.8316002E-04
     +,   3.8619948E-04,   3.8879859E-04,   3.9094893E-04
     +,   3.9264493E-04,   3.9388379E-04,   3.9466654E-04
     +,   3.9499634E-04,   3.9487984E-04,   3.9432649E-04
     +,   3.9334805E-04,   3.9195907E-04,   3.9017608E-04
     +,   3.8801797E-04,   3.8550526E-04,   3.8266007E-04
     +,   3.7950568E-04,   3.7606686E-04,   3.7236881E-04
     +,   3.6843726E-04,   3.6429879E-04,   3.5998019E-04
     +,   3.5550765E-04,   3.5090744E-04,   3.4620595E-04
     +,   3.4142873E-04,   3.3660093E-04,   3.3174697E-04
     +,   3.2689067E-04,   3.2205554E-04,   3.1726406E-04
     +,   3.1253780E-04,   3.0789821E-04,   3.0336584E-04
     +,   2.9896022E-04,   2.9470117E-04,   2.9060780E-04
     +,   2.8669852E-04,   2.8299168E-04,   2.7950550E-04
     +,   2.7625830E-04,   2.7326829E-04,   2.7055384E-04
     +,   2.6813411E-04,   2.6602874E-04,   2.6425818E-04
     +,   2.6284379E-04,   2.6180860E-04,   2.6117708E-04
     +,   2.6097556E-04,   2.6123255E-04,   2.6197921E-04
     +,   2.6324904E-04,   2.6507874E-04,   2.6750815E-04
     +,   2.7058012E-04,   2.7434068E-04,   2.7883914E-04
     +,   2.8412696E-04,   2.9025791E-04,   2.9728748E-04
     +,   3.0527162E-04,   3.1426479E-04,   3.2431990E-04
     +,   3.3548585E-04,   3.4780527E-04,   3.6131166E-04
     +,   3.7602964E-04,   3.9197062E-04,   4.0913004E-04
     +,   4.2748565E-04,   4.4699750E-04,   4.6760438E-04
     +,   4.8922288E-04,   5.1174656E-04,   5.3505035E-04
     +,   5.5898889E-04,   5.8339722E-04,   6.0809974E-04
     +,   6.3291105E-04,   6.5764046E-04,   6.8209984E-04
     +,   7.0611032E-04,   7.2950893E-04,   7.5215247E-04
     +,   7.7392481E-04,   7.9474517E-04,   8.1456767E-04
     +,   8.3338848E-04,   8.5124484E-04,   8.6822169E-04
     +,   8.8445080E-04,   9.0011256E-04,   9.1543887E-04
     +,   9.3071617E-04,   9.4628404E-04,   9.6253824E-04
     +,   9.7993074E-04,   9.9895918E-04,   1.0201610E-03
     +,   1.0440962E-03,   1.0713304E-03,   1.1024128E-03
     +,   1.1378557E-03,   1.1781218E-03,   1.2236255E-03
     +,   1.2747442E-03,   1.3318361E-03,   1.3952866E-03
     +,   1.4655343E-03,   1.5430877E-03,   1.6285162E-03
     +,   1.7224295E-03,   1.8253925E-03,   1.9378492E-03
     +,   2.0600546E-03,   2.1920616E-03,   2.3337605E-03
     +,   2.4849742E-03,   2.6456162E-03,   2.8158524E-03
     +,   2.9961688E-03,   3.1872957E-03,   3.3900586E-03
     +,   3.6050631E-03,   3.8323211E-03,   4.0709968E-03
     +,   4.3193200E-03,   4.5747403E-03,   4.8343246E-03
     +,   5.0954306E-03,   5.3564184E-03,   5.6172530E-03
     +,   5.8797882E-03,   6.1476650E-03,   6.4256880E-03
     +,   6.7186696E-03,   7.0298924E-03,   7.3594856E-03
     +,   7.7028144E-03,   8.0494005E-03,   8.3825151E-03
     +,   8.6799487E-03,   8.9157652E-03,   9.0631722E-03
     +,   9.0980446E-03,   9.0025775E-03,   8.7681096E-03
     +,   8.3968826E-03,   7.9019647E-03,   7.3057078E-03
     +,   6.6367085E-03,   5.9264507E-03,   5.2055977E-03
     +,   4.5013390E-03,   3.8352970E-03,   3.2228958E-03
     +,   2.6733007E-03,   2.1903822E-03,   1.7737095E-03
     +,   1.4198865E-03,   1.1237001E-03,   8.7896240E-04
     +,   6.7925168E-04,   5.1827519E-04,   3.9016819E-04
     +,   2.8956964E-04,   2.1169936E-04,   1.5233409E-04
     +,   1.0781219E-04,   7.4992800E-05,   5.1237552E-05
     +,   3.4365097E-05,   2.2615197E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz118 = Yx/0.0775384615384615
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1526641E-05,   2.2446857E-05
     +,   2.3403707E-05,   2.4398252E-05,   2.5431555E-05
     +,   2.6504740E-05,   2.7618957E-05,   2.8775381E-05
     +,   2.9975217E-05,   3.1219781E-05,   3.2510354E-05
     +,   3.3848319E-05,   3.5235076E-05,   3.6672089E-05
     +,   3.8160881E-05,   3.9703031E-05,   4.1300143E-05
     +,   4.2953903E-05,   4.4666027E-05,   4.6438305E-05
     +,   4.8272537E-05,   5.0170573E-05,   5.2134274E-05
     +,   5.4165648E-05,   5.6266435E-05,   5.8438687E-05
     +,   6.0684248E-05,   6.3005020E-05,   6.5402790E-05
     +,   6.7879373E-05,   7.0436407E-05,   7.3075491E-05
     +,   7.5798082E-05,   7.8605422E-05,   8.1498678E-05
     +,   8.4478750E-05,   8.7546308E-05,   9.0701687E-05
     +,   9.3945186E-05,   9.7276403E-05,   1.0069492E-04
     +,   1.0419975E-04,   1.0778957E-04,   1.1146260E-04
     +,   1.1521668E-04,   1.1904905E-04,   1.2295661E-04
     +,   1.2693561E-04,   1.3098189E-04,   1.3509077E-04
     +,   1.3925697E-04,   1.4347478E-04,   1.4773787E-04
     +,   1.5203975E-04,   1.5637292E-04,   1.6072996E-04
     +,   1.6510279E-04,   1.6948304E-04,   1.7386192E-04
     +,   1.7823056E-04,   1.8257990E-04,   1.8690045E-04
     +,   1.9118289E-04,   1.9541795E-04,   1.9959656E-04
     +,   2.0370935E-04,   2.0774767E-04,   2.1170299E-04
     +,   2.1556746E-04,   2.1933316E-04,   2.2299362E-04
     +,   2.2654225E-04,   2.2997375E-04,   2.3328330E-04
     +,   2.3646707E-04,   2.3952246E-04,   2.4244741E-04
     +,   2.4524107E-04,   2.4790360E-04,   2.5043651E-04
     +,   2.5284200E-04,   2.5512368E-04,   2.5728586E-04
     +,   2.5933422E-04,   2.6127527E-04,   2.6311650E-04
     +,   2.6486625E-04,   2.6653367E-04,   2.6812867E-04
     +,   2.6966180E-04,   2.7114412E-04,   2.7258715E-04
     +,   2.7400252E-04,   2.7540245E-04,   2.7679911E-04
     +,   2.7820459E-04,   2.7963106E-04,   2.8109024E-04
     +,   2.8259362E-04,   2.8415225E-04,   2.8577691E-04
     +,   2.8747739E-04,   2.8926306E-04,   2.9114247E-04
     +,   2.9312322E-04,   2.9521246E-04,   2.9741597E-04
     +,   2.9973875E-04,   3.0218469E-04,   3.0475683E-04
     +,   3.0745685E-04,   3.1028574E-04,   3.1324296E-04
     +,   3.1632712E-04,   3.1953555E-04,   3.2286430E-04
     +,   3.2630833E-04,   3.2986156E-04,   3.3351657E-04
     +,   3.3726441E-04,   3.4109550E-04,   3.4499864E-04
     +,   3.4896136E-04,   3.5297006E-04,   3.5701046E-04
     +,   3.6106608E-04,   3.6512074E-04,   3.6915581E-04
     +,   3.7315299E-04,   3.7709222E-04,   3.8095322E-04
     +,   3.8471515E-04,   3.8835674E-04,   3.9185616E-04
     +,   3.9519204E-04,   3.9834325E-04,   4.0128859E-04
     +,   4.0400765E-04,   4.0648147E-04,   4.0869150E-04
     +,   4.1062129E-04,   4.1225538E-04,   4.1358059E-04
     +,   4.1458599E-04,   4.1526262E-04,   4.1560395E-04
     +,   4.1560613E-04,   4.1526847E-04,   4.1459274E-04
     +,   4.1358356E-04,   4.1224851E-04,   4.1059812E-04
     +,   4.0864563E-04,   4.0640731E-04,   4.0390153E-04
     +,   4.0114930E-04,   3.9817422E-04,   3.9500161E-04
     +,   3.9165828E-04,   3.8817315E-04,   3.8457598E-04
     +,   3.8089757E-04,   3.7716981E-04,   3.7342453E-04
     +,   3.6969408E-04,   3.6601038E-04,   3.6240523E-04
     +,   3.5891004E-04,   3.5555509E-04,   3.5237012E-04
     +,   3.4938307E-04,   3.4662144E-04,   3.4411115E-04
     +,   3.4187650E-04,   3.3994045E-04,   3.3832458E-04
     +,   3.3704867E-04,   3.3613126E-04,   3.3558902E-04
     +,   3.3543768E-04,   3.3569068E-04,   3.3636027E-04
     +,   3.3745711E-04,   3.3899010E-04,   3.4096662E-04
     +,   3.4339176E-04,   3.4626893E-04,   3.4959952E-04
     +,   3.5338243E-04,   3.5761387E-04,   3.6228768E-04
     +,   3.6739474E-04,   3.7292275E-04,   3.7885609E-04
     +,   3.8517624E-04,   3.9186180E-04,   3.9888799E-04
     +,   4.0622716E-04,   4.1385027E-04,   4.2172687E-04
     +,   4.2982548E-04,   4.3811611E-04,   4.4657139E-04
     +,   4.5516819E-04,   4.6388939E-04,   4.7272773E-04
     +,   4.8168775E-04,   4.9078854E-04,   5.0006638E-04
     +,   5.0958002E-04,   5.1941170E-04,   5.2966981E-04
     +,   5.4049195E-04,   5.5204541E-04,   5.6452863E-04
     +,   5.7816837E-04,   5.9321680E-04,   6.0995016E-04
     +,   6.2866072E-04,   6.4964779E-04,   6.7321089E-04
     +,   6.9963804E-04,   7.2919374E-04,   7.6210516E-04
     +,   7.9855771E-04,   8.3867920E-04,   8.8253227E-04
     +,   9.3011226E-04,   9.8134775E-04,   1.0361064E-03
     +,   1.0941980E-03,   1.1553942E-03,   1.2194526E-03
     +,   1.2861360E-03,   1.3552386E-03,   1.4266196E-03
     +,   1.5002370E-03,   1.5761646E-03,   1.6546239E-03
     +,   1.7360064E-03,   1.8208721E-03,   1.9099395E-03
     +,   2.0040662E-03,   2.1042142E-03,   2.2113794E-03
     +,   2.3265288E-03,   2.4505204E-03,   2.5840646E-03
     +,   2.7276839E-03,   2.8816785E-03,   3.0462057E-03
     +,   3.2213395E-03,   3.4071649E-03,   3.6039064E-03
     +,   3.8120681E-03,   4.0324773E-03,   4.2663030E-03
     +,   4.5149615E-03,   4.7799251E-03,   5.0623268E-03
     +,   5.3624725E-03,   5.6792749E-03,   6.0096690E-03
     +,   6.3481685E-03,   6.6864979E-03,   7.0138103E-03
     +,   7.3169996E-03,   7.5816098E-03,   7.7928794E-03
     +,   7.9370663E-03,   8.0026826E-03,   7.9815406E-03
     +,   7.8695249E-03,   7.6669380E-03,   7.3784161E-03
     +,   7.0125172E-03,   6.5809647E-03,   6.0977819E-03
     +,   5.5782343E-03,   5.0379685E-03,   4.4920137E-03
     +,   3.9542075E-03,   3.4364816E-03,   2.9486634E-03
     +,   2.4981441E-03,   2.0899908E-03,   1.7269579E-03
     +,   1.4097599E-03,   1.1374105E-03,   9.0749079E-04
     +,   7.1659411E-04,   5.6061812E-04,   4.3514124E-04
     +,   3.3566263E-04,   2.5786014E-04,   1.9773125E-04
     +,   1.5172243E-04,   1.1676993E-04,   9.0324131E-05
     +,   7.0317510E-05,   5.5125871E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz119 = Yx/0.0727631578947368
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8602599E-05,   2.9261580E-05
     +,   2.9936185E-05,   3.0627365E-05,   3.1336116E-05
     +,   3.2063512E-05,   3.2810662E-05,   3.3578741E-05
     +,   3.4368946E-05,   3.5182580E-05,   3.6020949E-05
     +,   3.6885420E-05,   3.7777394E-05,   3.8698319E-05
     +,   3.9649676E-05,   4.0632949E-05,   4.1649684E-05
     +,   4.2701424E-05,   4.3789718E-05,   4.4916120E-05
     +,   4.6082194E-05,   4.7289475E-05,   4.8539463E-05
     +,   4.9833725E-05,   5.1173603E-05,   5.2560597E-05
     +,   5.3996013E-05,   5.5481123E-05,   5.7017140E-05
     +,   5.8605172E-05,   6.0246239E-05,   6.1941231E-05
     +,   6.3690939E-05,   6.5496039E-05,   6.7357047E-05
     +,   6.9274385E-05,   7.1248229E-05,   7.3278658E-05
     +,   7.5365730E-05,   7.7509023E-05,   7.9708268E-05
     +,   8.1962855E-05,   8.4272062E-05,   8.6635002E-05
     +,   8.9050598E-05,   9.1517672E-05,   9.4034884E-05
     +,   9.6600743E-05,   9.9213670E-05,   1.0187193E-04
     +,   1.0457374E-04,   1.0731720E-04,   1.1010031E-04
     +,   1.1292124E-04,   1.1577774E-04,   1.1866801E-04
     +,   1.2158992E-04,   1.2454149E-04,   1.2752082E-04
     +,   1.3052608E-04,   1.3355547E-04,   1.3660743E-04
     +,   1.3968020E-04,   1.4277261E-04,   1.4588342E-04
     +,   1.4901138E-04,   1.5215582E-04,   1.5531573E-04
     +,   1.5849082E-04,   1.6168045E-04,   1.6488465E-04
     +,   1.6810307E-04,   1.7133608E-04,   1.7458366E-04
     +,   1.7784626E-04,   1.8112455E-04,   1.8441890E-04
     +,   1.8772983E-04,   1.9105827E-04,   1.9440499E-04
     +,   1.9777054E-04,   2.0115581E-04,   2.0456144E-04
     +,   2.0798836E-04,   2.1143697E-04,   2.1490820E-04
     +,   2.1840242E-04,   2.2192027E-04,   2.2546215E-04
     +,   2.2902865E-04,   2.3262028E-04,   2.3623733E-04
     +,   2.3988022E-04,   2.4354945E-04,   2.4724592E-04
     +,   2.5096990E-04,   2.5472254E-04,   2.5850450E-04
     +,   2.6231719E-04,   2.6616166E-04,   2.7003998E-04
     +,   2.7395366E-04,   2.7790514E-04,   2.8189630E-04
     +,   2.8593003E-04,   2.9000934E-04,   2.9413722E-04
     +,   2.9831630E-04,   3.0255015E-04,   3.0684186E-04
     +,   3.1119445E-04,   3.1561064E-04,   3.2009243E-04
     +,   3.2464208E-04,   3.2926019E-04,   3.3394751E-04
     +,   3.3870267E-04,   3.4352398E-04,   3.4840772E-04
     +,   3.5334920E-04,   3.5834164E-04,   3.6337643E-04
     +,   3.6844300E-04,   3.7352901E-04,   3.7861965E-04
     +,   3.8369815E-04,   3.8874568E-04,   3.9374101E-04
     +,   3.9866142E-04,   4.0348191E-04,   4.0817625E-04
     +,   4.1271615E-04,   4.1707308E-04,   4.2121668E-04
     +,   4.2511700E-04,   4.2874343E-04,   4.3206586E-04
     +,   4.3505459E-04,   4.3768162E-04,   4.3992003E-04
     +,   4.4174521E-04,   4.4313431E-04,   4.4406817E-04
     +,   4.4453001E-04,   4.4450667E-04,   4.4398883E-04
     +,   4.4297089E-04,   4.4145106E-04,   4.3943236E-04
     +,   4.3692131E-04,   4.3392871E-04,   4.3046978E-04
     +,   4.2656370E-04,   4.2223305E-04,   4.1750385E-04
     +,   4.1240593E-04,   4.0697213E-04,   4.0123748E-04
     +,   3.9523945E-04,   3.8901772E-04,   3.8261371E-04
     +,   3.7606969E-04,   3.6942927E-04,   3.6273705E-04
     +,   3.5603749E-04,   3.4937492E-04,   3.4279446E-04
     +,   3.3634034E-04,   3.3005638E-04,   3.2398547E-04
     +,   3.1816994E-04,   3.1265136E-04,   3.0746972E-04
     +,   3.0266368E-04,   2.9827090E-04,   2.9432727E-04
     +,   2.9086653E-04,   2.8792085E-04,   2.8552031E-04
     +,   2.8369186E-04,   2.8246010E-04,   2.8184662E-04
     +,   2.8186932E-04,   2.8254261E-04,   2.8387690E-04
     +,   2.8587846E-04,   2.8854879E-04,   2.9188496E-04
     +,   2.9587984E-04,   3.0052083E-04,   3.0579147E-04
     +,   3.1167106E-04,   3.1813467E-04,   3.2515399E-04
     +,   3.3269834E-04,   3.4073531E-04,   3.4923057E-04
     +,   3.5814964E-04,   3.6745920E-04,   3.7712755E-04
     +,   3.8712571E-04,   3.9742829E-04,   4.0801588E-04
     +,   4.1887563E-04,   4.3000156E-04,   4.4139771E-04
     +,   4.5307982E-04,   4.6507496E-04,   4.7742613E-04
     +,   4.9019326E-04,   5.0345680E-04,   5.1731750E-04
     +,   5.3190067E-04,   5.4735749E-04,   5.6386687E-04
     +,   5.8163336E-04,   6.0088554E-04,   6.2187575E-04
     +,   6.4487028E-04,   6.7013799E-04,   6.9794373E-04
     +,   7.2852918E-04,   7.6209271E-04,   7.9877081E-04
     +,   8.3862088E-04,   8.8159979E-04,   9.2754693E-04
     +,   9.7617874E-04,   1.0270944E-03,   1.0797882E-03
     +,   1.1336735E-03,   1.1881312E-03,   1.2425673E-03
     +,   1.2964786E-03,   1.3495168E-03,   1.4015716E-03
     +,   1.4528275E-03,   1.5037979E-03,   1.5553512E-03
     +,   1.6087060E-03,   1.6653766E-03,   1.7271044E-03
     +,   1.7957544E-03,   1.8732050E-03,   1.9612124E-03
     +,   2.0612883E-03,   2.1745823E-03,   2.3018157E-03
     +,   2.4432263E-03,   2.5985786E-03,   2.7672579E-03
     +,   2.9484010E-03,   3.1410812E-03,   3.3445163E-03
     +,   3.5582697E-03,   3.7823317E-03,   4.0170546E-03
     +,   4.2629261E-03,   4.5201960E-03,   4.7883280E-03
     +,   5.0654262E-03,   5.3478084E-03,   5.6298142E-03
     +,   5.9038857E-03,   6.1610020E-03,   6.3914545E-03
     +,   6.5857312E-03,   6.7353719E-03,   6.8337158E-03
     +,   6.8763448E-03,   6.8611857E-03,   6.7883525E-03
     +,   6.6597941E-03,   6.4788600E-03,   6.2499037E-03
     +,   5.9780255E-03,   5.6688213E-03,   5.3283847E-03
     +,   4.9631796E-03,   4.5800707E-03,   4.1861096E-03
     +,   3.7884803E-03,   3.3941383E-03,   3.0096543E-03
     +,   2.6408571E-03,   2.2927050E-03,   1.9690664E-03
     +,   1.6726763E-03,   1.4051856E-03,   1.1671705E-03
     +,   9.5833000E-04,   7.7758473E-04,   6.2329700E-04
     +,   4.9338792E-04,   3.8552858E-04,   2.9723643E-04
     +,   2.2601376E-04,   1.6941318E-04,   1.2512659E-04
     +,   9.1021233E-05,   6.5186068E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz120 = Yx/0.0676052631578947
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2203609E-05,   1.2770683E-05
     +,   1.3368310E-05,   1.3998134E-05,   1.4661851E-05
     +,   1.5361189E-05,   1.6097903E-05,   1.6873766E-05
     +,   1.7690543E-05,   1.8550041E-05,   1.9454001E-05
     +,   2.0404157E-05,   2.1402184E-05,   2.2449700E-05
     +,   2.3548242E-05,   2.4699253E-05,   2.5904053E-05
     +,   2.7163827E-05,   2.8479610E-05,   2.9852263E-05
     +,   3.1282456E-05,   3.2770662E-05,   3.4317098E-05
     +,   3.5921857E-05,   3.7584621E-05,   3.9305003E-05
     +,   4.1082269E-05,   4.2915475E-05,   4.4803448E-05
     +,   4.6744837E-05,   4.8738086E-05,   5.0781524E-05
     +,   5.2873409E-05,   5.5011955E-05,   5.7195473E-05
     +,   5.9422393E-05,   6.1691440E-05,   6.4001746E-05
     +,   6.6353015E-05,   6.8745510E-05,   7.1180621E-05
     +,   7.3660645E-05,   7.6189259E-05,   7.8771693E-05
     +,   8.1414910E-05,   8.4127962E-05,   8.6922162E-05
     +,   8.9811481E-05,   9.2812639E-05,   9.5945725E-05
     +,   9.9234232E-05,   1.0270566E-04,   1.0639190E-04
     +,   1.1033018E-04,   1.1456301E-04,   1.1914023E-04
     +,   1.2411931E-04,   1.2956743E-04,   1.3556295E-04
     +,   1.4219763E-04,   1.4957871E-04,   1.5783145E-04
     +,   1.6710001E-04,   1.7755028E-04,   1.8936914E-04
     +,   2.0276218E-04,   2.1795300E-04,   2.3517497E-04
     +,   2.5466914E-04,   2.7667332E-04,   3.0142357E-04
     +,   3.2914997E-04,   3.6009285E-04,   3.9451820E-04
     +,   4.3276278E-04,   4.7528546E-04,   5.2273227E-04
     +,   5.7601853E-04,   6.3641259E-04,   7.0560898E-04
     +,   7.8577601E-04,   8.7960286E-04,   9.9026761E-04
     +,   1.1213988E-03,   1.2769258E-03,   1.4609244E-03
     +,   1.6773205E-03,   1.9296533E-03,   2.2207389E-03
     +,   2.5525137E-03,   2.9259003E-03,   3.3407044E-03
     +,   3.7955167E-03,   4.2874622E-03,   4.8117326E-03
     +,   5.3611896E-03,   5.9267511E-03,   6.4985314E-03
     +,   7.0679942E-03,   7.6296893E-03,   8.1816697E-03
     +,   8.7234089E-03,   9.2526823E-03,   9.7631812E-03
     +,   1.0245212E-02,   1.0688487E-02,   1.1084711E-02
     +,   1.1426576E-02,   1.1703570E-02,   1.1897981E-02
     +,   1.1986289E-02,   1.1947687E-02,   1.1776230E-02
     +,   1.1489850E-02,   1.1130419E-02,   1.0753314E-02
     +,   1.0411249E-02,   1.0138585E-02,   9.9427626E-03
     +,   9.8048206E-03,   9.6877282E-03,   9.5485803E-03
     +,   9.3501220E-03,   9.0688393E-03,   8.6983237E-03
     +,   8.2482146E-03,   7.7399993E-03,   7.2013219E-03
     +,   6.6601150E-03,   6.1401767E-03,   5.6585022E-03
     +,   5.2248929E-03,   4.8429198E-03,   4.5118816E-03
     +,   4.2285761E-03,   3.9886427E-03,   3.7873257E-03
     +,   3.6196683E-03,   3.4805378E-03,   3.3646678E-03
     +,   3.2667795E-03,   3.1817853E-03,   3.1050190E-03
     +,   3.0324252E-03,   2.9606975E-03,   2.8872695E-03
     +,   2.8103041E-03,   2.7286308E-03,   2.6416827E-03
     +,   2.5494287E-03,   2.4523283E-03,   2.3512852E-03
     +,   2.2475459E-03,   2.1425996E-03,   2.0380551E-03
     +,   1.9355074E-03,   1.8364151E-03,   1.7419808E-03
     +,   1.6530922E-03,   1.5702918E-03,   1.4937634E-03
     +,   1.4233767E-03,   1.3587490E-03,   1.2993109E-03
     +,   1.2443889E-03,   1.1932806E-03,   1.1453294E-03
     +,   1.0999637E-03,   1.0567337E-03,   1.0153258E-03
     +,   9.7556424E-04,   9.3739177E-04,   9.0084464E-04
     +,   8.6602604E-04,   8.3308184E-04,   8.0216525E-04
     +,   7.7342259E-04,   7.4697874E-04,   7.2292559E-04
     +,   7.0131820E-04,   6.8217760E-04,   6.6549488E-04
     +,   6.5123505E-04,   6.3934113E-04,   6.2974211E-04
     +,   6.2235486E-04,   6.1708788E-04,   6.1384006E-04
     +,   6.1250298E-04,   6.1295897E-04,   6.1507995E-04
     +,   6.1872642E-04,   6.2374526E-04,   6.2997045E-04
     +,   6.3722185E-04,   6.4530765E-04,   6.5402419E-04
     +,   6.6315889E-04,   6.7249540E-04,   6.8181544E-04
     +,   6.9090247E-04,   6.9954718E-04,   7.0755259E-04
     +,   7.1473623E-04,   7.2093430E-04,   7.2600640E-04
     +,   7.2983658E-04,   7.3233596E-04,   7.3344336E-04
     +,   7.3312572E-04,   7.3137745E-04,   7.2821975E-04
     +,   7.2369701E-04,   7.1787526E-04,   7.1083772E-04
     +,   7.0268300E-04,   6.9351977E-04,   6.8346364E-04
     +,   6.7263254E-04,   6.6114537E-04,   6.4911589E-04
     +,   6.3665141E-04,   6.2385178E-04,   6.1080651E-04
     +,   5.9759273E-04,   5.8427604E-04,   5.7091046E-04
     +,   5.5753964E-04,   5.4419489E-04,   5.3089892E-04
     +,   5.1766704E-04,   5.0450838E-04,   4.9142586E-04
     +,   4.7842017E-04,   4.6549118E-04,   4.5263662E-04
     +,   4.3985544E-04,   4.2714897E-04,   4.1452073E-04
     +,   4.0197597E-04,   3.8952334E-04,   3.7717450E-04
     +,   3.6494422E-04,   3.5284861E-04,   3.4090583E-04
     +,   3.2913583E-04,   3.1755969E-04,   3.0619744E-04
     +,   2.9506886E-04,   2.8419375E-04,   2.7358939E-04
     +,   2.6327089E-04,   2.5325228E-04,   2.4354443E-04
     +,   2.3415542E-04,   2.2509044E-04,   2.1635254E-04
     +,   2.0794223E-04,   1.9985695E-04,   1.9209173E-04
     +,   1.8464030E-04,   1.7749435E-04,   1.7064378E-04
     +,   1.6407718E-04,   1.5778281E-04,   1.5174766E-04
     +,   1.4595839E-04,   1.4040180E-04,   1.3506472E-04
     +,   1.2993391E-04,   1.2499640E-04,   1.2024020E-04
     +,   1.1565386E-04,   1.1122639E-04,   1.0694755E-04
     +,   1.0280831E-04,   9.8799930E-05,   9.4914962E-05
     +,   9.1146343E-05,   8.7488181E-05,   8.3934930E-05
     +,   8.0482154E-05,   7.7125638E-05,   7.3862182E-05
     +,   7.0688686E-05,   6.7602945E-05,   6.4602937E-05
     +,   6.1686929E-05,   5.8853802E-05,   5.6102395E-05
     +,   5.3432028E-05,   5.0841882E-05,   4.8331618E-05
     +,   4.5900619E-05,   4.3548665E-05,   4.1275223E-05
     +,   3.9080067E-05,   3.6962640E-05,   3.4922614E-05
     +,   3.2959331E-05,   3.1072286E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz75 = Yx/0.124
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3194450E-05,   2.4088218E-05
     +,   2.5016026E-05,   2.5978865E-05,   2.6977734E-05
     +,   2.8013676E-05,   2.9087785E-05,   3.0201203E-05
     +,   3.1355110E-05,   3.2550797E-05,   3.3789624E-05
     +,   3.5073004E-05,   3.6402475E-05,   3.7779686E-05
     +,   3.9206381E-05,   4.0684456E-05,   4.2215917E-05
     +,   4.3802920E-05,   4.5447763E-05,   4.7152895E-05
     +,   4.8920912E-05,   5.0754545E-05,   5.2656636E-05
     +,   5.4630305E-05,   5.6678531E-05,   5.8804620E-05
     +,   6.1011870E-05,   6.3303589E-05,   6.5683169E-05
     +,   6.8153902E-05,   7.0719077E-05,   7.3381845E-05
     +,   7.6145174E-05,   7.9011807E-05,   8.1984203E-05
     +,   8.5064501E-05,   8.8254346E-05,   9.1554946E-05
     +,   9.4967094E-05,   9.8490629E-05,   1.0212513E-04
     +,   1.0586921E-04,   1.0972080E-04,   1.1367707E-04
     +,   1.1773433E-04,   1.2188824E-04,   1.2613351E-04
     +,   1.3046429E-04,   1.3487396E-04,   1.3935537E-04
     +,   1.4390094E-04,   1.4850282E-04,   1.5315285E-04
     +,   1.5784349E-04,   1.6256684E-04,   1.6731632E-04
     +,   1.7208599E-04,   1.7687128E-04,   1.8166950E-04
     +,   1.8647988E-04,   1.9130457E-04,   1.9614873E-04
     +,   2.0102068E-04,   2.0593328E-04,   2.1090372E-04
     +,   2.1595355E-04,   2.2111020E-04,   2.2640551E-04
     +,   2.3187751E-04,   2.3756911E-04,   2.4352904E-04
     +,   2.4981034E-04,   2.5647177E-04,   2.6357578E-04
     +,   2.7119019E-04,   2.7938792E-04,   2.8824707E-04
     +,   2.9785364E-04,   3.0830418E-04,   3.1971012E-04
     +,   3.3220157E-04,   3.4593660E-04,   3.6110639E-04
     +,   3.7794796E-04,   3.9674822E-04,   4.1785609E-04
     +,   4.4168293E-04,   4.6870692E-04,   4.9946166E-04
     +,   5.3452677E-04,   5.7450164E-04,   6.1996945E-04
     +,   6.7145628E-04,   7.2938850E-04,   7.9404365E-04
     +,   8.6550362E-04,   9.4365358E-04,   1.0281733E-03
     +,   1.1186162E-03,   1.2144988E-03,   1.3154950E-03
     +,   1.4216288E-03,   1.5335482E-03,   1.6527312E-03
     +,   1.7816708E-03,   1.9239164E-03,   2.0839237E-03
     +,   2.2667279E-03,   2.4774179E-03,   2.7205355E-03
     +,   2.9995875E-03,   3.3171438E-03,   3.6755961E-03
     +,   4.0789433E-03,   4.5348820E-03,   5.0565843E-03
     +,   5.6624990E-03,   6.3738073E-03,   7.2091701E-03
     +,   8.1787268E-03,   9.2786830E-03,   1.0487777E-02
     +,   1.1766134E-02,   1.3056842E-02,   1.4292504E-02
     +,   1.5407847E-02,   1.6355753E-02,   1.7115574E-02
     +,   1.7688144E-02,   1.8082183E-02,   1.8310521E-02
     +,   1.8402271E-02,   1.8412733E-02,   1.8405750E-02
     +,   1.8413374E-02,   1.8409835E-02,   1.8326724E-02
     +,   1.8092604E-02,   1.7661901E-02,   1.7020995E-02
     +,   1.6185295E-02,   1.5197991E-02,   1.4125096E-02
     +,   1.3040762E-02,   1.2007807E-02,   1.1063450E-02
     +,   1.0215737E-02,   9.4489576E-03,   8.7346826E-03
     +,   8.0446154E-03,   7.3611098E-03,   6.6819354E-03
     +,   6.0185092E-03,   5.3898995E-03,   4.8159240E-03
     +,   4.3116775E-03,   3.8845425E-03,   3.5337310E-03
     +,   3.2517698E-03,   3.0269208E-03,   2.8457339E-03
     +,   2.6952282E-03,   2.5643811E-03,   2.4448121E-03
     +,   2.3308778E-03,   2.2193482E-03,   2.1088396E-03
     +,   1.9991989E-03,   1.8909435E-03,   1.7848723E-03
     +,   1.6818219E-03,   1.5825504E-03,   1.4877124E-03
     +,   1.3978900E-03,   1.3136290E-03,   1.2354302E-03
     +,   1.1637558E-03,   1.0989980E-03,   1.0414459E-03
     +,   9.9124515E-04,   9.4838609E-04,   9.1270026E-04
     +,   8.8386121E-04,   8.6141081E-04,   8.4478431E-04
     +,   8.3335047E-04,   8.2643796E-04,   8.2336995E-04
     +,   8.2348625E-04,   8.2616456E-04,   8.3083467E-04
     +,   8.3698321E-04,   8.4415887E-04,   8.5196871E-04
     +,   8.6007698E-04,   8.6819689E-04,   8.7608414E-04
     +,   8.8353071E-04,   8.9035684E-04,   8.9640560E-04
     +,   9.0153632E-04,   9.0562174E-04,   9.0854435E-04
     +,   9.1019453E-04,   9.1047015E-04,   9.0927631E-04
     +,   9.0652960E-04,   9.0215629E-04,   8.9609763E-04
     +,   8.8831311E-04,   8.7877974E-04,   8.6750073E-04
     +,   8.5450313E-04,   8.3983934E-04,   8.2358991E-04
     +,   8.0586213E-04,   7.8678917E-04,   7.6652679E-04
     +,   7.4524956E-04,   7.2315114E-04,   7.0043310E-04
     +,   6.7730458E-04,   6.5397669E-04,   6.3065748E-04
     +,   6.0754345E-04,   5.8481935E-04,   5.6265394E-04
     +,   5.4119615E-04,   5.2057131E-04,   5.0088129E-04
     +,   4.8220507E-04,   4.6459798E-04,   4.4809093E-04
     +,   4.3269349E-04,   4.1839716E-04,   4.0517515E-04
     +,   3.9298620E-04,   3.8177732E-04,   3.7148682E-04
     +,   3.6204528E-04,   3.5337920E-04,   3.4541317E-04
     +,   3.3807106E-04,   3.3127778E-04,   3.2496077E-04
     +,   3.1905097E-04,   3.1348341E-04,   3.0819760E-04
     +,   3.0313776E-04,   2.9825390E-04,   2.9350031E-04
     +,   2.8883657E-04,   2.8422693E-04,   2.7964058E-04
     +,   2.7505044E-04,   2.7043361E-04,   2.6577112E-04
     +,   2.6104753E-04,   2.5625044E-04,   2.5137010E-04
     +,   2.4640030E-04,   2.4133702E-04,   2.3617833E-04
     +,   2.3092444E-04,   2.2557803E-04,   2.2014308E-04
     +,   2.1462493E-04,   2.0903100E-04,   2.0336964E-04
     +,   1.9765008E-04,   1.9188227E-04,   1.8607742E-04
     +,   1.8024720E-04,   1.7440339E-04,   1.6855786E-04
     +,   1.6272321E-04,   1.5691134E-04,   1.5113459E-04
     +,   1.4540431E-04,   1.3973229E-04,   1.3412893E-04
     +,   1.2860495E-04,   1.2316959E-04,   1.1783220E-04
     +,   1.1260060E-04,   1.0748260E-04,   1.0248465E-04
     +,   9.7612443E-05,   9.2871349E-05,   8.8265318E-05
     +,   8.3798128E-05,   7.9472215E-05,   7.5289892E-05
     +,   7.1252231E-05,   6.7360197E-05,   6.3613690E-05
     +,   6.0012513E-05,   5.6555484E-05,   5.3241485E-05
     +,   5.0068516E-05,   4.7034635E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz80 = Yx/0.15806976744186
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.4352890E-06,   9.7035490E-06
     +,   9.9821691E-06,   1.0271833E-05,   1.0573276E-05
     +,   1.0887272E-05,   1.1214658E-05,   1.1556313E-05
     +,   1.1913166E-05,   1.2286224E-05,   1.2676533E-05
     +,   1.3085208E-05,   1.3513422E-05,   1.3962424E-05
     +,   1.4433521E-05,   1.4928097E-05,   1.5447606E-05
     +,   1.5993575E-05,   1.6567619E-05,   1.7171415E-05
     +,   1.7806737E-05,   1.8475434E-05,   1.9179432E-05
     +,   1.9920797E-05,   2.0701595E-05,   2.1524065E-05
     +,   2.2390508E-05,   2.3303310E-05,   2.4264973E-05
     +,   2.5278092E-05,   2.6345368E-05,   2.7469598E-05
     +,   2.8653694E-05,   2.9900668E-05,   3.1213647E-05
     +,   3.2595857E-05,   3.4050663E-05,   3.5581481E-05
     +,   3.7191974E-05,   3.8885722E-05,   4.0666600E-05
     +,   4.2538497E-05,   4.4505439E-05,   4.6571553E-05
     +,   4.8741058E-05,   5.1018269E-05,   5.3407603E-05
     +,   5.5913501E-05,   5.8540492E-05,   6.1293133E-05
     +,   6.4175976E-05,   6.7193556E-05,   7.0350296E-05
     +,   7.3650779E-05,   7.7099037E-05,   8.0699334E-05
     +,   8.4455452E-05,   8.8370958E-05,   9.2449111E-05
     +,   9.6692718E-05,   1.0110410E-04,   1.0568525E-04
     +,   1.1043711E-04,   1.1536050E-04,   1.2045555E-04
     +,   1.2572120E-04,   1.3115632E-04,   1.3675849E-04
     +,   1.4252528E-04,   1.4845295E-04,   1.5453805E-04
     +,   1.6077593E-04,   1.6716258E-04,   1.7369316E-04
     +,   1.8036370E-04,   1.8717060E-04,   1.9411078E-04
     +,   2.0118206E-04,   2.0838402E-04,   2.1571798E-04
     +,   2.2318636E-04,   2.3079461E-04,   2.3854924E-04
     +,   2.4646023E-04,   2.5453846E-04,   2.6279810E-04
     +,   2.7125390E-04,   2.7992277E-04,   2.8882147E-04
     +,   2.9796787E-04,   3.0737935E-04,   3.1707156E-04
     +,   3.2705851E-04,   3.3735271E-04,   3.4796470E-04
     +,   3.5890192E-04,   3.7017209E-04,   3.8178224E-04
     +,   3.9374395E-04,   4.0607472E-04,   4.1880656E-04
     +,   4.3199136E-04,   4.4571597E-04,   4.6011258E-04
     +,   4.7538165E-04,   4.9181329E-04,   5.0981354E-04
     +,   5.2993436E-04,   5.5290200E-04,   5.7963980E-04
     +,   6.1127538E-04,   6.4914225E-04,   6.9473946E-04
     +,   7.4968999E-04,   8.1565348E-04,   8.9425669E-04
     +,   9.8699587E-04,   1.0951946E-03,   1.2199368E-03
     +,   1.3620569E-03,   1.5220806E-03,   1.7001277E-03
     +,   1.8958100E-03,   2.1082233E-03,   2.3361484E-03
     +,   2.5787177E-03,   2.8366949E-03,   3.1140356E-03
     +,   3.4192631E-03,   3.7653674E-03,   4.1674576E-03
     +,   4.6375575E-03,   5.1781647E-03,   5.7772356E-03
     +,   6.4091356E-03,   7.0442311E-03,   7.6665492E-03
     +,   8.2928706E-03,   8.9808861E-03,   9.8147765E-03
     +,   1.0869254E-02,   1.2172086E-02,   1.3691733E-02
     +,   1.5355159E-02,   1.7070800E-02,   1.8735733E-02
     +,   2.0239890E-02,   2.1488439E-02,   2.2421360E-02
     +,   2.2996439E-02,   2.3169205E-02,   2.2934508E-02
     +,   2.2396682E-02,   2.1749055E-02,   2.1139121E-02
     +,   2.0557040E-02,   1.9876143E-02,   1.8995304E-02
     +,   1.7933030E-02,   1.6800875E-02,   1.5711978E-02
     +,   1.4716282E-02,   1.3796709E-02,   1.2900682E-02
     +,   1.1972175E-02,   1.0970977E-02,   9.8845009E-03
     +,   8.7347524E-03,   7.5753168E-03,   6.4755403E-03
     +,   5.4979869E-03,   4.6807779E-03,   4.0322226E-03
     +,   3.5369545E-03,   3.1670516E-03,   2.8921342E-03
     +,   2.6857941E-03,   2.5279811E-03,   2.4047755E-03
     +,   2.3069573E-03,   2.2283946E-03,   2.1647497E-03
     +,   2.1126536E-03,   2.0692644E-03,   2.0321261E-03
     +,   1.9991291E-03,   1.9685195E-03,   1.9389183E-03
     +,   1.9093305E-03,   1.8791413E-03,   1.8480911E-03
     +,   1.8162441E-03,   1.7839378E-03,   1.7517022E-03
     +,   1.7201646E-03,   1.6899547E-03,   1.6616166E-03
     +,   1.6355212E-03,   1.6118130E-03,   1.5903855E-03
     +,   1.5708866E-03,   1.5527487E-03,   1.5352439E-03
     +,   1.5175494E-03,   1.4988366E-03,   1.4783306E-03
     +,   1.4553859E-03,   1.4295343E-03,   1.4005190E-03
     +,   1.3683046E-03,   1.3330671E-03,   1.2951781E-03
     +,   1.2551617E-03,   1.2136493E-03,   1.1713293E-03
     +,   1.1289073E-03,   1.0870565E-03,   1.0463806E-03
     +,   1.0073916E-03,   9.7049511E-04,   9.3597895E-04
     +,   9.0401602E-04,   8.7467779E-04,   8.4794196E-04
     +,   8.2371285E-04,   8.0183824E-04,   7.8213081E-04
     +,   7.6438207E-04,   7.4837729E-04,   7.3390658E-04
     +,   7.2077516E-04,   7.0880691E-04,   6.9784519E-04
     +,   6.8775448E-04,   6.7841832E-04,   6.6973368E-04
     +,   6.6160766E-04,   6.5395370E-04,   6.4668694E-04
     +,   6.3971849E-04,   6.3295616E-04,   6.2630035E-04
     +,   6.1964482E-04,   6.1287638E-04,   6.0587749E-04
     +,   5.9852866E-04,   5.9071160E-04,   5.8231218E-04
     +,   5.7322497E-04,   5.6335737E-04,   5.5263157E-04
     +,   5.4098823E-04,   5.2838941E-04,   5.1481940E-04
     +,   5.0028507E-04,   4.8481533E-04,   4.6846291E-04
     +,   4.5130000E-04,   4.3341689E-04,   4.1491858E-04
     +,   3.9592409E-04,   3.7656105E-04,   3.5696186E-04
     +,   3.3726118E-04,   3.1759462E-04,   2.9809182E-04
     +,   2.7887599E-04,   2.6006316E-04,   2.4175839E-04
     +,   2.2405355E-04,   2.0702792E-04,   1.9074813E-04
     +,   1.7526733E-04,   1.6062423E-04,   1.4684450E-04
     +,   1.3394329E-04,   1.2192273E-04,   1.1077629E-04
     +,   1.0048727E-04,   9.1032409E-05,   8.2380946E-05
     +,   7.4497926E-05,   6.7343339E-05,   6.0875198E-05
     +,   5.5048578E-05,   4.9818478E-05,   4.5138942E-05
     +,   4.0964613E-05,   3.7251535E-05,   3.3956727E-05
     +,   3.1039606E-05,   2.8461300E-05,   2.6185695E-05
     +,   2.4178913E-05,   2.2409875E-05,   2.0849891E-05
     +,   1.9473036E-05,   1.8255689E-05,   1.7176793E-05
     +,   1.6217406E-05,   1.5360858E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz85 = Yx/0.172931818181818
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6141117E-05,   2.6855583E-05
     +,   2.7580076E-05,   2.8313982E-05,   2.9056690E-05
     +,   2.9807539E-05,   3.0565869E-05,   3.1330983E-05
     +,   3.2102173E-05,   3.2878765E-05,   3.3660064E-05
     +,   3.4445377E-05,   3.5234050E-05,   3.6025474E-05
     +,   3.6819059E-05,   3.7614263E-05,   3.8410653E-05
     +,   3.9207825E-05,   4.0005485E-05,   4.0803439E-05
     +,   4.1601605E-05,   4.2400025E-05,   4.3198888E-05
     +,   4.3998549E-05,   4.4799468E-05,   4.5602374E-05
     +,   4.6408117E-05,   4.7217771E-05,   4.8032638E-05
     +,   4.8854225E-05,   4.9684269E-05,   5.0524759E-05
     +,   5.1377931E-05,   5.2246283E-05,   5.3132557E-05
     +,   5.4039770E-05,   5.4971202E-05,   5.5930410E-05
     +,   5.6921243E-05,   5.7947727E-05,   5.9014303E-05
     +,   6.0125592E-05,   6.1286482E-05,   6.2502171E-05
     +,   6.3778127E-05,   6.5120061E-05,   6.6533990E-05
     +,   6.8026231E-05,   6.9603382E-05,   7.1272319E-05
     +,   7.3040275E-05,   7.4914824E-05,   7.6903860E-05
     +,   7.9015765E-05,   8.1259139E-05,   8.3643208E-05
     +,   8.6177512E-05,   8.8872162E-05,   9.1737675E-05
     +,   9.4785108E-05,   9.8026001E-05,   1.0147248E-04
     +,   1.0513680E-04,   1.0903198E-04,   1.1317137E-04
     +,   1.1756806E-04,   1.2223578E-04,   1.2718768E-04
     +,   1.3243710E-04,   1.3799609E-04,   1.4387666E-04
     +,   1.5008876E-04,   1.5664160E-04,   1.6354144E-04
     +,   1.7079285E-04,   1.7839737E-04,   1.8635285E-04
     +,   1.9465301E-04,   2.0328800E-04,   2.1224297E-04
     +,   2.2149719E-04,   2.3102558E-04,   2.4079610E-04
     +,   2.5077217E-04,   2.6090987E-04,   2.7116097E-04
     +,   2.8147039E-04,   2.9177923E-04,   3.0202285E-04
     +,   3.1213393E-04,   3.2204232E-04,   3.3167604E-04
     +,   3.4096238E-04,   3.4983052E-04,   3.5821280E-04
     +,   3.6604481E-04,   3.7326981E-04,   3.7983843E-04
     +,   3.8571173E-04,   3.9086261E-04,   3.9527818E-04
     +,   3.9896084E-04,   4.0193019E-04,   4.0422461E-04
     +,   4.0590236E-04,   4.0704265E-04,   4.0774589E-04
     +,   4.0813436E-04,   4.0835250E-04,   4.0856551E-04
     +,   4.0895911E-04,   4.0973825E-04,   4.1112522E-04
     +,   4.1335740E-04,   4.1668487E-04,   4.2136799E-04
     +,   4.2767398E-04,   4.3587410E-04,   4.4624141E-04
     +,   4.5904942E-04,   4.7457102E-04,   4.9307913E-04
     +,   5.1485072E-04,   5.4017449E-04,   5.6935911E-04
     +,   6.0274493E-04,   6.4072636E-04,   6.8376469E-04
     +,   7.3242537E-04,   7.8739738E-04,   8.4954064E-04
     +,   9.1990747E-04,   9.9979190E-04,   1.0907181E-03
     +,   1.1944398E-03,   1.3128537E-03,   1.4478390E-03
     +,   1.6010286E-03,   1.7735361E-03,   1.9656590E-03
     +,   2.1766999E-03,   2.4050712E-03,   2.6488164E-03
     +,   2.9065977E-03,   3.1790484E-03,   3.4702981E-03
     +,   3.7890384E-03,   4.1487371E-03,   4.5666466E-03
     +,   5.0616618E-03,   5.6511890E-03,   6.3477186E-03
     +,   7.1558463E-03,   8.0707362E-03,   9.0792123E-03
     +,   1.0164442E-02,   1.1313210E-02,   1.2519692E-02
     +,   1.3777695E-02,   1.5060621E-02,   1.6304573E-02
     +,   1.7417599E-02,   1.8321428E-02,   1.8997533E-02
     +,   1.9491475E-02,   1.9860687E-02,   2.0103529E-02
     +,   2.0130329E-02,   1.9804427E-02,   1.9024413E-02
     +,   1.7792895E-02,   1.6233120E-02,   1.4551015E-02
     +,   1.2966581E-02,   1.1646909E-02,   1.0670530E-02
     +,   1.0035222E-02,   9.6936822E-03,   9.5890472E-03
     +,   9.6712206E-03,   9.8947575E-03,   1.0211280E-02
     +,   1.0567873E-02,   1.0912743E-02,   1.1202298E-02
     +,   1.1403694E-02,   1.1492640E-02,   1.1450430E-02
     +,   1.1264745E-02,   1.0934581E-02,   1.0474978E-02
     +,   9.9166231E-03,   9.2992187E-03,   8.6612068E-03
     +,   8.0315182E-03,   7.4264882E-03,   6.8521430E-03
     +,   6.3089528E-03,   5.7963147E-03,   5.3152065E-03
     +,   4.8687714E-03,   4.4614095E-03,   4.0973532E-03
     +,   3.7793943E-03,   3.5080696E-03,   3.2813712E-03
     +,   3.0950524E-03,   2.9433232E-03,   2.8196054E-03
     +,   2.7172863E-03,   2.6303276E-03,   2.5536644E-03
     +,   2.4833777E-03,   2.4167311E-03,   2.3520426E-03
     +,   2.2885089E-03,   2.2259592E-03,   2.1646251E-03
     +,   2.1049301E-03,   2.0473266E-03,   1.9921570E-03
     +,   1.9395782E-03,   1.8895264E-03,   1.8417097E-03
     +,   1.7956397E-03,   1.7506819E-03,   1.7061330E-03
     +,   1.6612830E-03,   1.6154804E-03,   1.5681906E-03
     +,   1.5190352E-03,   1.4678063E-03,   1.4144673E-03
     +,   1.3591395E-03,   1.3020838E-03,   1.2436580E-03
     +,   1.1842900E-03,   1.1244502E-03,   1.0646200E-03
     +,   1.0052633E-03,   9.4681617E-04,   8.8967523E-04
     +,   8.3418947E-04,   7.8064960E-04,   7.2929455E-04
     +,   6.8031141E-04,   6.3383684E-04,   5.8995641E-04
     +,   5.4871110E-04,   5.1010592E-04,   4.7410658E-04
     +,   4.4064803E-04,   4.0964235E-04,   3.8098081E-04
     +,   3.5453789E-04,   3.3017789E-04,   3.0776116E-04
     +,   2.8714605E-04,   2.6819046E-04,   2.5075724E-04
     +,   2.3471611E-04,   2.1994433E-04,   2.0632647E-04
     +,   1.9375603E-04,   1.8213666E-04,   1.7137958E-04
     +,   1.6140423E-04,   1.5213863E-04,   1.4351800E-04
     +,   1.3548355E-04,   1.2798271E-04,   1.2096884E-04
     +,   1.1440011E-04,   1.0823884E-04,   1.0245116E-04
     +,   9.7007396E-05,   9.1880203E-05,   8.7045773E-05
     +,   8.2482024E-05,   7.8169709E-05,   7.4090953E-05
     +,   7.0230089E-05,   6.6572517E-05,   6.3105406E-05
     +,   5.9816721E-05,   5.6695913E-05,   5.3733023E-05
     +,   5.0918996E-05,   4.8245816E-05,   4.5705743E-05
     +,   4.3291970E-05,   4.0997944E-05,   3.8817871E-05
     +,   3.6746060E-05,   3.4777506E-05,   3.2907235E-05
     +,   3.1130839E-05,   2.9443912E-05,   2.7842510E-05
     +,   2.6322668E-05,   2.4880797E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz90 = Yx/0.181522727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0459100E-05,   2.1358817E-05
     +,   2.2284865E-05,   2.3236826E-05,   2.4214185E-05
     +,   2.5216323E-05,   2.6242509E-05,   2.7291930E-05
     +,   2.8363631E-05,   2.9456618E-05,   3.0569747E-05
     +,   3.1701784E-05,   3.2851422E-05,   3.4017248E-05
     +,   3.5197791E-05,   3.6391488E-05,   3.7596710E-05
     +,   3.8811791E-05,   4.0034985E-05,   4.1264528E-05
     +,   4.2498628E-05,   4.3735472E-05,   4.4973211E-05
     +,   4.6210094E-05,   4.7444235E-05,   4.8673941E-05
     +,   4.9897440E-05,   5.1113060E-05,   5.2319170E-05
     +,   5.3514235E-05,   5.4696797E-05,   5.5865461E-05
     +,   5.7018962E-05,   5.8156122E-05,   5.9275884E-05
     +,   6.0377315E-05,   6.1459599E-05,   6.2522005E-05
     +,   6.3564017E-05,   6.4585125E-05,   6.5585031E-05
     +,   6.6563516E-05,   6.7520486E-05,   6.8455927E-05
     +,   6.9369977E-05,   7.0262817E-05,   7.1134746E-05
     +,   7.1986113E-05,   7.2817333E-05,   7.3628871E-05
     +,   7.4421230E-05,   7.5194977E-05,   7.5950615E-05
     +,   7.6688753E-05,   7.7409866E-05,   7.8114550E-05
     +,   7.8803248E-05,   7.9476493E-05,   8.0134661E-05
     +,   8.0778147E-05,   8.1407292E-05,   8.2022372E-05
     +,   8.2623636E-05,   8.3211256E-05,   8.3785490E-05
     +,   8.4346400E-05,   8.4894207E-05,   8.5429048E-05
     +,   8.5951178E-05,   8.6460852E-05,   8.6958527E-05
     +,   8.7444692E-05,   8.7920183E-05,   8.8385874E-05
     +,   8.8843117E-05,   8.9293535E-05,   8.9739129E-05
     +,   9.0182439E-05,   9.0626556E-05,   9.1075148E-05
     +,   9.1532587E-05,   9.2004033E-05,   9.2495502E-05
     +,   9.3013841E-05,   9.3566967E-05,   9.4163755E-05
     +,   9.4814219E-05,   9.5529474E-05,   9.6321746E-05
     +,   9.7204473E-05,   9.8192315E-05,   9.9300945E-05
     +,   1.0054718E-04,   1.0194891E-04,   1.0352502E-04
     +,   1.0529513E-04,   1.0727964E-04,   1.0949952E-04
     +,   1.1197629E-04,   1.1473143E-04,   1.1778683E-04
     +,   1.2116393E-04,   1.2488422E-04,   1.2896834E-04
     +,   1.3343651E-04,   1.3830843E-04,   1.4360249E-04
     +,   1.4933638E-04,   1.5552719E-04,   1.6219165E-04
     +,   1.6934545E-04,   1.7700542E-04,   1.8518827E-04
     +,   1.9391325E-04,   2.0320149E-04,   2.1307921E-04
     +,   2.2357699E-04,   2.3473384E-04,   2.4659664E-04
     +,   2.5922377E-04,   2.7268642E-04,   2.8706828E-04
     +,   3.0246764E-04,   3.1899766E-04,   3.3678475E-04
     +,   3.5596392E-04,   3.7667839E-04,   3.9906963E-04
     +,   4.2327432E-04,   4.4940977E-04,   4.7757139E-04
     +,   5.0781417E-04,   5.4015045E-04,   5.7453668E-04
     +,   6.1087403E-04,   6.4900803E-04,   6.8873301E-04
     +,   7.2981033E-04,   7.7199592E-04,   8.1507076E-04
     +,   8.5887965E-04,   9.0338051E-04,   9.4869407E-04
     +,   9.9514518E-04,   1.0432863E-03,   1.0939201E-03
     +,   1.1480731E-03,   1.2069407E-03,   1.2717970E-03
     +,   1.3438697E-03,   1.4241836E-03,   1.5133856E-03
     +,   1.6115973E-03,   1.7183063E-03,   1.8323207E-03
     +,   1.9517980E-03,   2.0743969E-03,   2.1975064E-03
     +,   2.3185080E-03,   2.4350388E-03,   2.5452264E-03
     +,   2.6477850E-03,   2.7419981E-03,   2.8275880E-03
     +,   2.9045376E-03,   2.9729158E-03,   3.0328149E-03
     +,   3.0844486E-03,   3.1284338E-03,   3.1661440E-03
     +,   3.2000665E-03,   3.2340239E-03,   3.2731676E-03
     +,   3.3237909E-03,   3.3931667E-03,   3.4897320E-03
     +,   3.6239778E-03,   3.8100062E-03,   4.0673995E-03
     +,   4.4221617E-03,   4.9055056E-03,   5.5502383E-03
     +,   6.3865921E-03,   7.4405442E-03,   8.7343892E-03
     +,   1.0283750E-02,   1.2084124E-02,   1.4089760E-02
     +,   1.6201098E-02,   1.8274095E-02,   2.0148162E-02
     +,   2.1681057E-02,   2.2788798E-02,   2.3471808E-02
     +,   2.3790119E-02,   2.3793260E-02,   2.3484100E-02
     +,   2.2861006E-02,   2.1973331E-02,   2.0910831E-02
     +,   1.9751629E-02,   1.8539621E-02,   1.7302210E-02
     +,   1.6073955E-02,   1.4904929E-02,   1.3848049E-02
     +,   1.2927943E-02,   1.2116105E-02,   1.1341383E-02
     +,   1.0531894E-02,   9.6539045E-03,   8.7221991E-03
     +,   7.7842772E-03,   6.8957936E-03,   6.1006555E-03
     +,   5.4210159E-03,   4.8570796E-03,   4.3937974E-03
     +,   4.0098922E-03,   3.6849871E-03,   3.4030499E-03
     +,   3.1528971E-03,   2.9271501E-03,   2.7209888E-03
     +,   2.5312309E-03,   2.3558117E-03,   2.1933932E-03
     +,   2.0430514E-03,   1.9040176E-03,   1.7755538E-03
     +,   1.6569063E-03,   1.5473295E-03,   1.4461224E-03
     +,   1.3526756E-03,   1.2664858E-03,   1.1871217E-03
     +,   1.1142005E-03,   1.0473585E-03,   9.8622008E-04
     +,   9.3037507E-04,   8.7938458E-04,   8.3278562E-04
     +,   7.9010468E-04,   7.5086899E-04,   7.1462814E-04
     +,   6.8096811E-04,   6.4951798E-04,   6.1995588E-04
     +,   5.9200946E-04,   5.6545826E-04,   5.4012286E-04
     +,   5.1586225E-04,   4.9256929E-04,   4.7016286E-04
     +,   4.4858007E-04,   4.2777444E-04,   4.0771146E-04
     +,   3.8836544E-04,   3.6971457E-04,   3.5174115E-04
     +,   3.3443101E-04,   3.1777160E-04,   3.0174991E-04
     +,   2.8635361E-04,   2.7157192E-04,   2.5739265E-04
     +,   2.4380359E-04,   2.3079332E-04,   2.1835002E-04
     +,   2.0646078E-04,   1.9511252E-04,   1.8429237E-04
     +,   1.7398693E-04,   1.6418177E-04,   1.5486185E-04
     +,   1.4601253E-04,   1.3761759E-04,   1.2966128E-04
     +,   1.2212653E-04,   1.1499706E-04,   1.0825525E-04
     +,   1.0188447E-04,   9.5867166E-05,   9.0186892E-05
     +,   8.4826628E-05,   7.9770456E-05,   7.5002477E-05
     +,   7.0507303E-05,   6.6270630E-05,   6.2278166E-05
     +,   5.8516864E-05,   5.4973807E-05,   5.1637253E-05
     +,   4.8495571E-05,   4.5538232E-05,   4.2754858E-05
     +,   4.0135983E-05,   3.7672336E-05,   3.5355406E-05
     +,   3.3176861E-05,   3.1129050E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ttz95 = Yx/0.165232558139535
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8540576E-06,   7.3906385E-06
     +,   7.9561833E-06,   8.5509846E-06,   9.1752127E-06
     +,   9.8288965E-06,   1.0511920E-05,   1.1224011E-05
     +,   1.1964717E-05,   1.2733446E-05,   1.3529392E-05
     +,   1.4351568E-05,   1.5198802E-05,   1.6069713E-05
     +,   1.6962733E-05,   1.7876084E-05,   1.8807796E-05
     +,   1.9755698E-05,   2.0717427E-05,   2.1690435E-05
     +,   2.2671991E-05,   2.3659202E-05,   2.4649002E-05
     +,   2.5638237E-05,   2.6623524E-05,   2.7601474E-05
     +,   2.8568549E-05,   2.9521143E-05,   3.0455607E-05
     +,   3.1368265E-05,   3.2255441E-05,   3.3113462E-05
     +,   3.3938719E-05,   3.4727651E-05,   3.5476816E-05
     +,   3.6182875E-05,   3.6842641E-05,   3.7453083E-05
     +,   3.8011396E-05,   3.8514932E-05,   3.8961331E-05
     +,   3.9348462E-05,   3.9674451E-05,   3.9937731E-05
     +,   4.0137020E-05,   4.0271345E-05,   4.0340048E-05
     +,   4.0342795E-05,   4.0279567E-05,   4.0150684E-05
     +,   3.9956765E-05,   3.9698760E-05,   3.9377937E-05
     +,   3.8995822E-05,   3.8554281E-05,   3.8055405E-05
     +,   3.7501559E-05,   3.6895344E-05,   3.6239562E-05
     +,   3.5537236E-05,   3.4791530E-05,   3.4005760E-05
     +,   3.3183405E-05,   3.2327989E-05,   3.1443087E-05
     +,   3.0532421E-05,   2.9599612E-05,   2.8648403E-05
     +,   2.7682379E-05,   2.6705216E-05,   2.5720377E-05
     +,   2.4731373E-05,   2.3741466E-05,   2.2753935E-05
     +,   2.1771810E-05,   2.0797970E-05,   1.9835186E-05
     +,   1.8886059E-05,   1.7952931E-05,   1.7037959E-05
     +,   1.6143191E-05,   1.5270361E-05,   1.4421120E-05
     +,   1.3596797E-05,   1.2798642E-05,   1.2027603E-05
     +,   1.1284543E-05,   1.0570038E-05,   9.8845967E-06
     +,   9.2284745E-06,   8.6017862E-06,   8.0045311E-06
     +,   7.4365730E-06,   6.8976046E-06,   6.3872112E-06
     +,   5.9049166E-06,   5.4500906E-06,   5.0220751E-06
     +,   4.6200844E-06,   4.2433239E-06,   3.8908956E-06
     +,   3.5619066E-06,   3.2553867E-06,   2.9703804E-06
     +,   2.7058882E-06,   2.4609039E-06,   2.2344354E-06
     +,   2.0254931E-06,   1.8330844E-06,   1.6562361E-06
     +,   1.4940102E-06,   1.3454742E-06,   1.2097443E-06
     +,   1.0859511E-06,   9.7327870E-07,   8.7093554E-07
     +,   7.7818828E-07,   6.9433901E-07,   6.1875437E-07
     +,   5.5085320E-07,   4.9012300E-07,   4.3613542E-07
     +,   3.8855435E-07,   3.4715200E-07,   3.1183666E-07
     +,   2.8268417E-07,   2.5996715E-07,   2.4420714E-07
     +,   2.3622258E-07,   2.3719527E-07,   2.4874174E-07
     +,   2.7299427E-07,   3.1269437E-07,   3.7128098E-07
     +,   4.5299552E-07,   5.6297631E-07,   7.0733415E-07
     +,   8.9322060E-07,   1.1288863E-06,   1.4236798E-06
     +,   1.7879813E-06,   2.2331108E-06,   2.7711956E-06
     +,   3.4149132E-06,   4.1771000E-06,   5.0704889E-06
     +,   6.1072087E-06,   7.2982120E-06,   8.6527962E-06
     +,   1.0178222E-05,   1.1879210E-05,   1.3757505E-05
     +,   1.5811804E-05,   1.8037963E-05,   2.0429214E-05
     +,   2.2976581E-05,   2.5669859E-05,   2.8498869E-05
     +,   3.1454558E-05,   3.4529974E-05,   3.7722093E-05
     +,   4.1032563E-05,   4.4468336E-05,   4.8042439E-05
     +,   5.1774754E-05,   5.5692417E-05,   5.9830996E-05
     +,   6.4237356E-05,   6.8974899E-05,   7.4131123E-05
     +,   7.9828831E-05,   8.6242188E-05,   9.3616705E-05
     +,   1.0229172E-04,   1.1272310E-04,   1.2550647E-04
     +,   1.4139223E-04,   1.6128863E-04,   1.8625015E-04
     +,   2.1744655E-04,   2.5610480E-04,   3.0342274E-04
     +,   3.6046299E-04,   4.2803088E-04,   5.0653686E-04
     +,   5.9585524E-04,   6.9521187E-04,   8.0310804E-04
     +,   9.1728079E-04,   1.0347182E-03,   1.1517827E-03
     +,   1.2643703E-03,   1.3681398E-03,   1.4588131E-03
     +,   1.5324935E-03,   1.5859666E-03,   1.6169703E-03
     +,   1.6244011E-03,   1.6084096E-03,   1.5703875E-03
     +,   1.5128385E-03,   1.4391515E-03,   1.3532884E-03
     +,   1.2594494E-03,   1.1617452E-03,   1.0638874E-03
     +,   9.6897082E-04,   8.7934628E-04,   7.9656602E-04
     +,   7.2141498E-04,   6.5401895E-04,   5.9399015E-04
     +,   5.4058142E-04,   4.9284345E-04,   4.4976742E-04
     +,   4.1039858E-04,   3.7391167E-04,   3.3965369E-04
     +,   3.0716322E-04,   2.7616578E-04,   2.4654355E-04
     +,   2.1830417E-04,   1.9154370E-04,   1.6640598E-04
     +,   1.4304617E-04,   1.2160469E-04,   1.0218773E-04
     +,   8.4852516E-05,   6.9601003E-05,   5.6382214E-05
     +,   4.5098339E-05,   3.5612629E-05,   2.7759508E-05
     +,   2.1356678E-05,   1.6215834E-05,   1.2150505E-05
     +,   8.9839859E-06,   6.5546110E-06,   4.7186236E-06
     +,   3.3516226E-06,   2.3488096E-06,   1.6239998E-06
     +,   1.1078042E-06,   7.4552372E-07,   4.9495139E-07
     +,   3.2415898E-07,   2.0942973E-07,   1.3346940E-07
     +,   8.3900055E-08,   5.2020454E-08,   3.1811858E-08
     +,   1.9185697E-08,   1.1410956E-08,   6.6927761E-09
     +,   3.8707619E-09,   2.2072879E-09,   1.2410089E-09
     +,   6.8790196E-10,   3.7590606E-10,   2.0248767E-10
     +,   1.0751474E-10,   5.6269368E-11,   2.9025411E-11
     +,   1.4755534E-11,   7.3926481E-12,   3.6499180E-12
     +,   1.7757267E-12,   8.5127717E-13,   4.0212522E-13
     +,   1.8716377E-13,   8.5827755E-14,   3.8777189E-14
     +,   1.7261127E-14,   7.5697446E-15,   3.2703546E-15
     +,   1.3919470E-15,   5.8362264E-16,   2.4106923E-16
     +,   9.8089214E-17,   3.9317797E-17,   1.5524392E-17
     +,   6.0383614E-18,   2.3135220E-18,   8.7317372E-19
     +,   3.2461535E-19,   1.1887919E-19,   4.2883980E-20
     +,   1.5237660E-20,   5.3334009E-21,   1.8387645E-21
     +,   6.2446780E-22,   2.0889775E-22,   6.8839436E-23
     +,   2.2346640E-23,   7.1472581E-24,   2.2526982E-24
     +,   7.0013146E-25,   2.1483044E-25,   6.5271528E-26
     +,   1.9760619E-26,   6.0447014E-27
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz100 = Yx/0.00991666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3167761E-06,   1.4303881E-06
     +,   1.5518598E-06,   1.6815450E-06,   1.8197945E-06
     +,   1.9669562E-06,   2.1233736E-06,   2.2893810E-06
     +,   2.4653013E-06,   2.6514551E-06,   2.8481379E-06
     +,   3.0556330E-06,   3.2742057E-06,   3.5040964E-06
     +,   3.7455261E-06,   3.9986858E-06,   4.2637398E-06
     +,   4.5408210E-06,   4.8300276E-06,   5.1314223E-06
     +,   5.4450311E-06,   5.7708421E-06,   6.1087903E-06
     +,   6.4587953E-06,   6.8206905E-06,   7.1943032E-06
     +,   7.5793928E-06,   7.9756755E-06,   8.3828199E-06
     +,   8.8004490E-06,   9.2281334E-06,   9.6654021E-06
     +,   1.0111736E-05,   1.0566572E-05,   1.1029303E-05
     +,   1.1499280E-05,   1.1975820E-05,   1.2458189E-05
     +,   1.2945654E-05,   1.3437401E-05,   1.3932636E-05
     +,   1.4430519E-05,   1.4930194E-05,   1.5430789E-05
     +,   1.5931422E-05,   1.6431210E-05,   1.6929260E-05
     +,   1.7424689E-05,   1.7916615E-05,   1.8404169E-05
     +,   1.8886500E-05,   1.9362777E-05,   1.9832180E-05
     +,   2.0293954E-05,   2.0747315E-05,   2.1191579E-05
     +,   2.1626054E-05,   2.2050106E-05,   2.2463139E-05
     +,   2.2864602E-05,   2.3253991E-05,   2.3630852E-05
     +,   2.3994759E-05,   2.4345347E-05,   2.4682318E-05
     +,   2.5005376E-05,   2.5314312E-05,   2.5608919E-05
     +,   2.5889069E-05,   2.6154634E-05,   2.6405565E-05
     +,   2.6641801E-05,   2.6863350E-05,   2.7070206E-05
     +,   2.7262424E-05,   2.7440057E-05,   2.7603170E-05
     +,   2.7751845E-05,   2.7886173E-05,   2.8006250E-05
     +,   2.8112167E-05,   2.8204018E-05,   2.8281882E-05
     +,   2.8345841E-05,   2.8395965E-05,   2.8432301E-05
     +,   2.8454901E-05,   2.8463781E-05,   2.8458957E-05
     +,   2.8440421E-05,   2.8408153E-05,   2.8362112E-05
     +,   2.8302253E-05,   2.8228509E-05,   2.8140799E-05
     +,   2.8039052E-05,   2.7923166E-05,   2.7793061E-05
     +,   2.7648626E-05,   2.7489785E-05,   2.7316441E-05
     +,   2.7128533E-05,   2.6925985E-05,   2.6708773E-05
     +,   2.6476862E-05,   2.6230251E-05,   2.5968979E-05
     +,   2.5693111E-05,   2.5402744E-05,   2.5097996E-05
     +,   2.4779067E-05,   2.4446146E-05,   2.4099521E-05
     +,   2.3739471E-05,   2.3366372E-05,   2.2980601E-05
     +,   2.2582626E-05,   2.2172915E-05,   2.1752028E-05
     +,   2.1320540E-05,   2.0879059E-05,   2.0428261E-05
     +,   1.9968873E-05,   1.9501611E-05,   1.9027242E-05
     +,   1.8546585E-05,   1.8060447E-05,   1.7569701E-05
     +,   1.7075181E-05,   1.6577793E-05,   1.6078391E-05
     +,   1.5577898E-05,   1.5077170E-05,   1.4577121E-05
     +,   1.4078611E-05,   1.3582479E-05,   1.3089590E-05
     +,   1.2600776E-05,   1.2116818E-05,   1.1638460E-05
     +,   1.1166460E-05,   1.0701524E-05,   1.0244298E-05
     +,   9.7953871E-06,   9.3553954E-06,   8.9248415E-06
     +,   8.5041966E-06,   8.0939190E-06,   7.6944107E-06
     +,   7.3060037E-06,   6.9289872E-06,   6.5636264E-06
     +,   6.2101453E-06,   5.8687006E-06,   5.5394280E-06
     +,   5.2224723E-06,   4.9179966E-06,   4.6262162E-06
     +,   4.3475161E-06,   4.0826421E-06,   3.8329035E-06
     +,   3.6006368E-06,   3.3898923E-06,   3.2074304E-06
     +,   3.0642132E-06,   2.9775474E-06,   2.9740022E-06
     +,   3.0932138E-06,   3.3926974E-06,   3.9535921E-06
     +,   4.8870038E-06,   6.3405396E-06,   8.5043866E-06
     +,   1.1615647E-05,   1.5959316E-05,   2.1866092E-05
     +,   2.9704273E-05,   3.9865390E-05,   5.2745298E-05
     +,   6.8722467E-05,   8.8134278E-05,   1.1125539E-04
     +,   1.3828605E-04,   1.6935411E-04,   2.0452902E-04
     +,   2.4384863E-04,   2.8736153E-04,   3.3517380E-04
     +,   3.8748115E-04,   4.4457405E-04,   5.0682202E-04
     +,   5.7459739E-04,   6.4814993E-04,   7.2745036E-04
     +,   8.1201806E-04,   9.0074935E-04,   9.9179230E-04
     +,   1.0825163E-03,   1.1695945E-03,   1.2491914E-03
     +,   1.3172667E-03,   1.3699633E-03,   1.4040205E-03
     +,   1.4171400E-03,   1.4082673E-03,   1.3777314E-03
     +,   1.3272158E-03,   1.2595785E-03,   1.1785440E-03
     +,   1.0883030E-03,   9.9311117E-04,   8.9692889E-04
     +,   8.0312742E-04,   7.1430567E-04,   6.3223019E-04
     +,   5.5787514E-04,   4.9152423E-04,   4.3292102E-04
     +,   3.8144347E-04,   3.3626807E-04,   2.9649536E-04
     +,   2.6125825E-04,   2.2979136E-04,   2.0146422E-04
     +,   1.7579104E-04,   1.5242415E-04,   1.3113518E-04
     +,   1.1178568E-04,   9.4297080E-05,   7.8624398E-05
     +,   6.4733693E-05,   5.2582600E-05,   4.2107942E-05
     +,   3.3221186E-05,   2.5808762E-05,   1.9734200E-05
     +,   1.4845794E-05,   1.0984649E-05,   7.9920974E-06
     +,   5.7165134E-06,   4.0190080E-06,   2.7769554E-06
     +,   1.8855595E-06,   1.2580299E-06,   8.2468330E-07
     +,   5.3114610E-07,   3.3609666E-07,   2.0894100E-07
     +,   1.2760977E-07,   7.6571006E-08,   4.5141217E-08
     +,   2.6147568E-08,   1.4883120E-08,   8.3262641E-09
     +,   4.5795865E-09,   2.4776245E-09,   1.3196481E-09
     +,   6.9299672E-10,   3.5966924E-10,   1.8524221E-10
     +,   9.5318163E-11,   4.9527348E-11,   2.6393179E-11
     +,   1.4712244E-11,   8.7481741E-12,   5.6143046E-12
     +,   3.8816671E-12,   2.8521430E-12,   2.1872580E-12
     +,   1.7227439E-12,   1.3775872E-12,   1.1102946E-12
     +,   8.9812435E-13,   7.2742935E-13,   5.8918875E-13
     +,   4.7692221E-13,   3.8567606E-13,   3.1153910E-13
     +,   2.5134942E-13,   2.0253782E-13,   1.6299875E-13
     +,   1.3101309E-13,   1.0516928E-13,   8.4316560E-14
     +,   6.7511921E-14,   5.3988006E-14,   4.3118134E-14
     +,   3.4392624E-14,   2.7398107E-14,   2.1798090E-14
     +,   1.7320731E-14,   1.3745347E-14,   1.0894196E-14
     +,   8.6233748E-15,   6.8172384E-15,   5.3824874E-15
     +,   4.2443063E-15,   3.3425123E-15,   2.6289919E-15
     +,   2.0651290E-15,   1.6201496E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz104 = Yx/0.00827272727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3921820E-09,   2.8937639E-09
     +,   3.4936414E-09,   4.2096042E-09,   5.0623363E-09
     +,   6.0758683E-09,   7.2780142E-09,   8.7009280E-09
     +,   1.0381610E-08,   1.2362710E-08,   1.4693019E-08
     +,   1.7428389E-08,   2.0632537E-08,   2.4377970E-08
     +,   2.8746982E-08,   3.3832713E-08,   3.9740367E-08
     +,   4.6588433E-08,   5.4509865E-08,   6.3653744E-08
     +,   7.4186545E-08,   8.6293639E-08,   1.0018081E-07
     +,   1.1607692E-07,   1.3423308E-07,   1.5492765E-07
     +,   1.7846527E-07,   2.0517963E-07,   2.3543542E-07
     +,   2.6962900E-07,   3.0819106E-07,   3.5158649E-07
     +,   4.0031708E-07,   4.5492197E-07,   5.1597812E-07
     +,   5.8410171E-07,   6.5994715E-07,   7.4420745E-07
     +,   8.3761864E-07,   9.4094497E-07,   1.0549970E-06
     +,   1.1806146E-06,   1.3186695E-06,   1.4700653E-06
     +,   1.6357289E-06,   1.8166111E-06,   2.0136774E-06
     +,   2.2279080E-06,   2.4602873E-06,   2.7117992E-06
     +,   2.9834193E-06,   3.2761109E-06,   3.5908054E-06
     +,   3.9284241E-06,   4.2898118E-06,   4.6757987E-06
     +,   5.0871349E-06,   5.5245059E-06,   5.9885147E-06
     +,   6.4796832E-06,   6.9984258E-06,   7.5450625E-06
     +,   8.1197604E-06,   8.7226035E-06,   9.3535509E-06
     +,   1.0012353E-05,   1.0698707E-05,   1.1412065E-05
     +,   1.2151818E-05,   1.2917103E-05,   1.3706998E-05
     +,   1.4520318E-05,   1.5355829E-05,   1.6212020E-05
     +,   1.7087328E-05,   1.7980034E-05,   1.8888222E-05
     +,   1.9809841E-05,   2.0742782E-05,   2.1684817E-05
     +,   2.2633523E-05,   2.3586519E-05,   2.4541212E-05
     +,   2.5495074E-05,   2.6445403E-05,   2.7389582E-05
     +,   2.8324857E-05,   2.9248577E-05,   3.0157982E-05
     +,   3.1050426E-05,   3.1923297E-05,   3.2773958E-05
     +,   3.3599856E-05,   3.4398538E-05,   3.5167657E-05
     +,   3.5904861E-05,   3.6607998E-05,   3.7274953E-05
     +,   3.7903777E-05,   3.8492584E-05,   3.9039693E-05
     +,   3.9543465E-05,   4.0002473E-05,   4.0415369E-05
     +,   4.0780986E-05,   4.1098272E-05,   4.1366333E-05
     +,   4.1584397E-05,   4.1751846E-05,   4.1868225E-05
     +,   4.1933199E-05,   4.1946590E-05,   4.1908348E-05
     +,   4.1818588E-05,   4.1677566E-05,   4.1485673E-05
     +,   4.1243457E-05,   4.0951581E-05,   4.0610903E-05
     +,   4.0222378E-05,   3.9787108E-05,   3.9306346E-05
     +,   3.8781513E-05,   3.8214112E-05,   3.7605791E-05
     +,   3.6958365E-05,   3.6273705E-05,   3.5553883E-05
     +,   3.4801003E-05,   3.4017343E-05,   3.3205200E-05
     +,   3.2367050E-05,   3.1505348E-05,   3.0622712E-05
     +,   2.9721743E-05,   2.8805063E-05,   2.7875398E-05
     +,   2.6935488E-05,   2.5987998E-05,   2.5035592E-05
     +,   2.4080960E-05,   2.3126757E-05,   2.2175509E-05
     +,   2.1229675E-05,   2.0291727E-05,   1.9363948E-05
     +,   1.8448503E-05,   1.7547514E-05,   1.6662962E-05
     +,   1.5796641E-05,   1.4950197E-05,   1.4125183E-05
     +,   1.3323003E-05,   1.2544841E-05,   1.1791727E-05
     +,   1.1064587E-05,   1.0364178E-05,   9.6910571E-06
     +,   9.0456333E-06,   8.4282237E-06,   7.8389485E-06
     +,   7.2777875E-06,   6.7446299E-06,   6.2392455E-06
     +,   5.7612592E-06,   5.3102053E-06,   4.8855663E-06
     +,   4.4867747E-06,   4.1132198E-06,   3.7643554E-06
     +,   3.4398256E-06,   3.1396314E-06,   2.8644170E-06
     +,   2.6160003E-06,   2.3981554E-06,   2.2177317E-06
     +,   2.0863833E-06,   2.0229584E-06,   2.0567190E-06
     +,   2.2315933E-06,   2.6115595E-06,   3.2871756E-06
     +,   4.3833538E-06,   6.0684661E-06,   8.5646789E-06
     +,   1.2159380E-05,   1.7218223E-05,   2.4200070E-05
     +,   3.3672863E-05,   4.6328547E-05,   6.2999250E-05
     +,   8.4665466E-05,   1.1245082E-04,   1.4759858E-04
     +,   1.9142084E-04,   2.4520553E-04,   3.1007652E-04
     +,   3.8681764E-04,   4.7567088E-04,   5.7611888E-04
     +,   6.8668864E-04,   8.0483453E-04,   9.2693197E-04
     +,   1.0483883E-03,   1.1638966E-03,   1.2678549E-03
     +,   1.3548422E-03,   1.4201290E-03,   1.4601632E-03
     +,   1.4729288E-03,   1.4581319E-03,   1.4172008E-03
     +,   1.3530942E-03,   1.2699483E-03,   1.1726291E-03
     +,   1.0662696E-03,   9.5581973E-04,   8.4568292E-04
     +,   7.3947984E-04,   6.3993910E-04,   5.4886687E-04
     +,   4.6723607E-04,   3.9532606E-04,   3.3287751E-04
     +,   2.7925314E-04,   2.3359212E-04,   1.9493484E-04
     +,   1.6231280E-04,   1.3481241E-04,   1.1161733E-04
     +,   9.2028684E-05,   7.5465548E-05,   6.1456092E-05
     +,   4.9623355E-05,   3.9667120E-05,   3.1342497E-05
     +,   2.4444274E-05,   1.8793693E-05,   1.4228468E-05
     +,   1.0597314E-05,   7.7583763E-06,   5.5795217E-06
     +,   3.9395154E-06,   2.7296824E-06,   1.8554398E-06
     +,   1.2368921E-06,   8.0849736E-07,   5.1809445E-07
     +,   3.2543153E-07,   2.0035567E-07,   1.2089149E-07
     +,   7.1484436E-08,   4.1422620E-08,   2.3521791E-08
     +,   1.3088624E-08,   7.1366690E-09,   3.8131303E-09
     +,   1.9964821E-09,   1.0243468E-09,   5.1503141E-10
     +,   2.5378485E-10,   1.2257655E-10,   5.8042553E-11
     +,   2.6955140E-11,   1.2286302E-11,   5.5033504E-12
     +,   2.4280339E-12,   1.0596162E-12,   4.6089532E-13
     +,   2.0242229E-13,   9.1634999E-14,   4.3962694E-14
     +,   2.2980089E-14,   1.3270297E-14,   8.3957694E-15
     +,   5.6832501E-15,   4.0124345E-15,   2.8986287E-15
     +,   2.1173958E-15,   1.5538262E-15,   1.1416028E-15
     +,   8.3834403E-16,   6.1484555E-16,   4.5018531E-16
     +,   3.2901391E-16,   2.3999998E-16,   1.7472807E-16
     +,   1.2695741E-16,   9.2066790E-17,   6.6632674E-17
     +,   4.8130593E-17,   3.4697083E-17,   2.4964002E-17
     +,   1.7925575E-17,   1.2846400E-17,   9.1881560E-18
     +,   6.5587771E-18,   4.6725816E-18,   3.3223039E-18
     +,   2.3575473E-18,   1.6696609E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz106 = Yx/0.00733333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1823541E-06,   4.4273161E-06
     +,   4.6826458E-06,   4.9485247E-06,   5.2251230E-06
     +,   5.5125993E-06,   5.8111009E-06,   6.1207584E-06
     +,   6.4416845E-06,   6.7739943E-06,   7.1177724E-06
     +,   7.4730892E-06,   7.8400053E-06,   8.2185579E-06
     +,   8.6087739E-06,   9.0106550E-06,   9.4241941E-06
     +,   9.8493610E-06,   1.0286109E-05,   1.0734369E-05
     +,   1.1194062E-05,   1.1665079E-05,   1.2147291E-05
     +,   1.2640582E-05,   1.3144754E-05,   1.3659653E-05
     +,   1.4185070E-05,   1.4720780E-05,   1.5266542E-05
     +,   1.5822092E-05,   1.6387146E-05,   1.6961400E-05
     +,   1.7544526E-05,   1.8136172E-05,   1.8735966E-05
     +,   1.9343519E-05,   1.9958414E-05,   2.0580199E-05
     +,   2.1208443E-05,   2.1842616E-05,   2.2482240E-05
     +,   2.3126773E-05,   2.3775656E-05,   2.4428306E-05
     +,   2.5084119E-05,   2.5742462E-05,   2.6402684E-05
     +,   2.7064105E-05,   2.7726026E-05,   2.8387731E-05
     +,   2.9048468E-05,   2.9707475E-05,   3.0363954E-05
     +,   3.1017145E-05,   3.1666179E-05,   3.2310258E-05
     +,   3.2948516E-05,   3.3580101E-05,   3.4204139E-05
     +,   3.4819757E-05,   3.5426077E-05,   3.6022229E-05
     +,   3.6607304E-05,   3.7180434E-05,   3.7740792E-05
     +,   3.8287464E-05,   3.8819653E-05,   3.9336501E-05
     +,   3.9837232E-05,   4.0321047E-05,   4.0787218E-05
     +,   4.1234998E-05,   4.1663741E-05,   4.2072767E-05
     +,   4.2461506E-05,   4.2829401E-05,   4.3175944E-05
     +,   4.3500670E-05,   4.3803189E-05,   4.4083168E-05
     +,   4.4340304E-05,   4.4574390E-05,   4.4785254E-05
     +,   4.4972800E-05,   4.5136992E-05,   4.5277862E-05
     +,   4.5395485E-05,   4.5490040E-05,   4.5561734E-05
     +,   4.5610846E-05,   4.5637713E-05,   4.5642730E-05
     +,   4.5626341E-05,   4.5589062E-05,   4.5531437E-05
     +,   4.5454060E-05,   4.5357567E-05,   4.5242639E-05
     +,   4.5109984E-05,   4.4960336E-05,   4.4794459E-05
     +,   4.4613127E-05,   4.4417135E-05,   4.4207296E-05
     +,   4.3984397E-05,   4.3749245E-05,   4.3502645E-05
     +,   4.3245382E-05,   4.2978223E-05,   4.2701904E-05
     +,   4.2417163E-05,   4.2124673E-05,   4.1825111E-05
     +,   4.1519081E-05,   4.1207175E-05,   4.0889910E-05
     +,   4.0567793E-05,   4.0241244E-05,   3.9910683E-05
     +,   3.9576422E-05,   3.9238748E-05,   3.8897891E-05
     +,   3.8554062E-05,   3.8207367E-05,   3.7857870E-05
     +,   3.7505637E-05,   3.7150614E-05,   3.6792775E-05
     +,   3.6431982E-05,   3.6068122E-05,   3.5700996E-05
     +,   3.5330417E-05,   3.4956131E-05,   3.4577901E-05
     +,   3.4195451E-05,   3.3808486E-05,   3.3416720E-05
     +,   3.3019896E-05,   3.2617721E-05,   3.2209922E-05
     +,   3.1796291E-05,   3.1376658E-05,   3.0950872E-05
     +,   3.0518859E-05,   3.0080682E-05,   2.9636469E-05
     +,   2.9186509E-05,   2.8731285E-05,   2.8271532E-05
     +,   2.7808212E-05,   2.7342650E-05,   2.6876596E-05
     +,   2.6412301E-05,   2.5952584E-05,   2.5500933E-05
     +,   2.5061649E-05,   2.4639927E-05,   2.4241921E-05
     +,   2.3874862E-05,   2.3547171E-05,   2.3268401E-05
     +,   2.3049313E-05,   2.2901799E-05,   2.2838774E-05
     +,   2.2873965E-05,   2.3021701E-05,   2.3296514E-05
     +,   2.3712744E-05,   2.4284076E-05,   2.5023031E-05
     +,   2.5940373E-05,   2.7044645E-05,   2.8341861E-05
     +,   2.9835268E-05,   3.1525240E-05,   3.3409939E-05
     +,   3.5486111E-05,   3.7750364E-05,   4.0201317E-05
     +,   4.2842654E-05,   4.5686567E-05,   4.8757865E-05
     +,   5.2099142E-05,   5.5776611E-05,   5.9885682E-05
     +,   6.4556531E-05,   6.9959351E-05,   7.6308948E-05
     +,   8.3866980E-05,   9.2940885E-05,   1.0388245E-04
     +,   1.1708044E-04,   1.3294870E-04,   1.5191123E-04
     +,   1.7438404E-04,   2.0075106E-04,   2.3133520E-04
     +,   2.6637118E-04,   3.0597943E-04,   3.5013736E-04
     +,   3.9865274E-04,   4.5114860E-04,   5.0705689E-04
     +,   5.6561612E-04,   6.2587444E-04,   6.8672316E-04
     +,   7.4692204E-04,   8.0513750E-04,   8.5999508E-04
     +,   9.1013667E-04,   9.5427386E-04,   9.9123898E-04
     +,   1.0200409E-03,   1.0399098E-03,   1.0503253E-03
     +,   1.0510411E-03,   1.0420922E-03,   1.0237903E-03
     +,   9.9670375E-04,   9.6163194E-04,   9.1956090E-04
     +,   8.7161857E-04,   8.1902859E-04,   7.6305697E-04
     +,   7.0495787E-04,   6.4593233E-04,   5.8709347E-04
     +,   5.2943215E-04,   4.7379138E-04,   4.2085748E-04
     +,   3.7115967E-04,   3.2506991E-04,   2.8281010E-04
     +,   2.4447165E-04,   2.1003684E-04,   1.7939221E-04
     +,   1.5235366E-04,   1.2868752E-04,   1.0812691E-04
     +,   9.0386100E-05,   7.5175463E-05,   6.2212363E-05
     +,   5.1227114E-05,   4.1967509E-05,   3.4202822E-05
     +,   2.7725340E-05,   2.2349655E-05,   1.7911692E-05
     +,   1.4267735E-05,   1.1293013E-05,   8.8791357E-06
     +,   6.9327712E-06,   5.3739859E-06,   4.1345093E-06
     +,   3.1562633E-06,   2.3902148E-06,   1.7952601E-06
     +,   1.3371184E-06,   9.8740588E-07,   7.2285854E-07
     +,   5.2458830E-07,   3.7739099E-07,   2.6914708E-07
     +,   1.9031179E-07,   1.3345330E-07,   9.2839279E-08
     +,   6.4105571E-08,   4.3969060E-08,   2.9987028E-08
     +,   2.0363125E-08,   1.3793033E-08,   9.3411190E-09
     +,   6.3435524E-09,   4.3348169E-09,   2.9924261E-09
     +,   2.0955302E-09,   1.4943271E-09,   1.0884325E-09
     +,   8.1111740E-10,   6.1848493E-10,   4.8182025E-10
     +,   3.8248135E-10,   3.0837538E-10,   2.5167118E-10
     +,   2.0726103E-10,   1.7178735E-10,   1.4299903E-10
     +,   1.1935439E-10,   9.9767729E-11,   8.3446694E-11
     +,   6.9796988E-11,   5.8355716E-11,   4.8756239E-11
     +,   4.0699416E-11,   3.3939608E-11,   2.8271295E-11
     +,   2.3522595E-11,   1.9548141E-11,   1.6225642E-11
     +,   1.3451271E-11,   1.1137596E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz108 = Yx/0.00795454545454546
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3397335E-08,   1.6077554E-08
     +,   1.9254800E-08,   2.3013142E-08,   2.7449351E-08
     +,   3.2674457E-08,   3.8815639E-08,   4.6017988E-08
     +,   5.4446659E-08,   6.4289701E-08,   7.5759573E-08
     +,   8.9096645E-08,   1.0457149E-07,   1.2248840E-07
     +,   1.4318833E-07,   1.6705204E-07,   1.9450420E-07
     +,   2.2601640E-07,   2.6211129E-07,   3.0336659E-07
     +,   3.5041796E-07,   4.0396441E-07,   4.6476947E-07
     +,   5.3367131E-07,   6.1157345E-07,   6.9946481E-07
     +,   7.9840862E-07,   9.0955251E-07,   1.0341274E-06
     +,   1.1734506E-06,   1.3289258E-06,   1.5020433E-06
     +,   1.6943794E-06,   1.9075933E-06,   2.1434253E-06
     +,   2.4036935E-06,   2.6902840E-06,   3.0051449E-06
     +,   3.3502970E-06,   3.7277732E-06,   4.1396761E-06
     +,   4.5881043E-06,   5.0751710E-06,   5.6029758E-06
     +,   6.1735877E-06,   6.7890260E-06,   7.4512359E-06
     +,   8.1620701E-06,   8.9232608E-06,   9.7363918E-06
     +,   1.0602876E-05,   1.1523930E-05,   1.2500520E-05
     +,   1.3533430E-05,   1.4623039E-05,   1.5769538E-05
     +,   1.6972708E-05,   1.8231995E-05,   1.9546449E-05
     +,   2.0914729E-05,   2.2335060E-05,   2.3805254E-05
     +,   2.5322581E-05,   2.6883974E-05,   2.8485902E-05
     +,   3.0124216E-05,   3.1794541E-05,   3.3491811E-05
     +,   3.5210775E-05,   3.6945541E-05,   3.8690061E-05
     +,   4.0437710E-05,   4.2181768E-05,   4.3915024E-05
     +,   4.5630215E-05,   4.7319871E-05,   4.8976322E-05
     +,   5.0591803E-05,   5.2158670E-05,   5.3669319E-05
     +,   5.5116117E-05,   5.6491794E-05,   5.7789151E-05
     +,   5.9001475E-05,   6.0122238E-05,   6.1145503E-05
     +,   6.2065657E-05,   6.2877763E-05,   6.3577339E-05
     +,   6.4160602E-05,   6.4624408E-05,   6.4966262E-05
     +,   6.5184380E-05,   6.5277731E-05,   6.5245986E-05
     +,   6.5089545E-05,   6.4809545E-05,   6.4407825E-05
     +,   6.3886902E-05,   6.3250016E-05,   6.2500934E-05
     +,   6.1644147E-05,   6.0684575E-05,   5.9627764E-05
     +,   5.8479625E-05,   5.7246463E-05,   5.5934997E-05
     +,   5.4552260E-05,   5.3105417E-05,   5.1601808E-05
     +,   5.0049039E-05,   4.8454567E-05,   4.6826073E-05
     +,   4.5170989E-05,   4.3496886E-05,   4.1810963E-05
     +,   4.0120496E-05,   3.8432307E-05,   3.6753238E-05
     +,   3.5089692E-05,   3.3447799E-05,   3.1833508E-05
     +,   3.0252455E-05,   2.8709868E-05,   2.7210664E-05
     +,   2.5759600E-05,   2.4360932E-05,   2.3018800E-05
     +,   2.1736871E-05,   2.0518710E-05,   1.9367444E-05
     +,   1.8286097E-05,   1.7277292E-05,   1.6343552E-05
     +,   1.5487061E-05,   1.4709783E-05,   1.4013507E-05
     +,   1.3399775E-05,   1.2869840E-05,   1.2424730E-05
     +,   1.2065224E-05,   1.1791814E-05,   1.1604661E-05
     +,   1.1503605E-05,   1.1488135E-05,   1.1557335E-05
     +,   1.1709878E-05,   1.1943974E-05,   1.2257338E-05
     +,   1.2647190E-05,   1.3110227E-05,   1.3642561E-05
     +,   1.4239731E-05,   1.4896752E-05,   1.5608093E-05
     +,   1.6367652E-05,   1.7168839E-05,   1.8004695E-05
     +,   1.8867946E-05,   1.9751022E-05,   2.0646379E-05
     +,   2.1546621E-05,   2.2444674E-05,   2.3334129E-05
     +,   2.4209634E-05,   2.5067251E-05,   2.5904803E-05
     +,   2.6722442E-05,   2.7523141E-05,   2.8313165E-05
     +,   2.9102390E-05,   2.9904715E-05,   3.0738232E-05
     +,   3.1625139E-05,   3.2591299E-05,   3.3665783E-05
     +,   3.4879758E-05,   3.6265221E-05,   3.7853402E-05
     +,   3.9673407E-05,   4.1750700E-05,   4.4105829E-05
     +,   4.6754380E-05,   4.9707938E-05,   5.2976222E-05
     +,   5.6570843E-05,   6.0511135E-05,   6.4831787E-05
     +,   6.9591319E-05,   7.4881158E-05,   8.0835824E-05
     +,   8.7641711E-05,   9.5544041E-05,   1.0485288E-04
     +,   1.1594832E-04,   1.2928317E-04,   1.4538465E-04
     +,   1.6485759E-04,   1.8838838E-04,   2.1674599E-04
     +,   2.5077583E-04,   2.9138825E-04,   3.3953154E-04
     +,   3.9613820E-04,   4.6203705E-04,   5.3785142E-04
     +,   6.2385673E-04,   7.1981840E-04,   8.2484371E-04
     +,   9.3726523E-04,   1.0545641E-03,   1.1733710E-03
     +,   1.2895782E-03,   1.3985551E-03,   1.4954385E-03
     +,   1.5754884E-03,   1.6344860E-03,   1.6691078E-03
     +,   1.6772164E-03,   1.6580638E-03,   1.6123556E-03
     +,   1.5421839E-03,   1.4508356E-03,   1.3425044E-03
     +,   1.2219319E-03,   1.0940469E-03,   9.6363167E-04
     +,   8.3502644E-04,   7.1190367E-04,   5.9714873E-04
     +,   4.9281726E-04,   4.0014874E-04,   3.1963881E-04
     +,   2.5116280E-04,   1.9411575E-04,   1.4753827E-04
     +,   1.1025644E-04,   8.0997968E-05,   5.8482234E-05
     +,   4.1490523E-05,   2.8916140E-05,   1.9792447E-05
     +,   1.3302394E-05,   8.7766330E-06,   5.6832246E-06
     +,   3.6111967E-06,   2.2512763E-06,   1.3767644E-06
     +,   8.2583074E-07,   4.8586492E-07,   2.8037252E-07
     +,   1.5870773E-07,   8.8152596E-08,   4.8071030E-08
     +,   2.5758700E-08,   1.3582744E-08,   7.0650219E-09
     +,   3.6386092E-09,   1.8661042E-09,   9.6108732E-10
     +,   5.0282589E-10,   2.7098801E-10,   1.5253102E-10
     +,   9.0531672E-11,   5.6760371E-11,   3.7350987E-11
     +,   2.5507251E-11,   1.7862097E-11,   1.2699159E-11
     +,   9.1004929E-12,   6.5426844E-12,   4.7054379E-12
     +,   3.3796067E-12,   2.4217757E-12,   1.7304829E-12
     +,   1.2326897E-12,   8.7522177E-13,   6.1934984E-13
     +,   4.3679874E-13,   3.0701234E-13,   2.1505246E-13
     +,   1.5012634E-13,   1.0444338E-13,   7.2414663E-14
     +,   5.0036029E-14,   3.4455728E-14,   2.3645892E-14
     +,   1.6171885E-14,   1.1022694E-14,   7.4873045E-15
     +,   5.0685609E-15,   3.4194358E-15,   2.2990397E-15
     +,   1.5404552E-15,   1.0286630E-15,   6.8455408E-16
     +,   4.5400918E-16,   3.0007601E-16,   1.9766101E-16
     +,   1.2975369E-16,   8.4887048E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz110 = Yx/0.00933333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.0131142E-07,   7.7929366E-07
     +,   8.6479304E-07,   9.5839539E-07,   1.0607166E-06
     +,   1.1724015E-06,   1.2941256E-06,   1.4265923E-06
     +,   1.5705310E-06,   1.7267051E-06,   1.8958966E-06
     +,   2.0789125E-06,   2.2765828E-06,   2.4897552E-06
     +,   2.7192934E-06,   2.9660764E-06,   3.2309906E-06
     +,   3.5149280E-06,   3.8187823E-06,   4.1434446E-06
     +,   4.4897943E-06,   4.8586994E-06,   5.2510009E-06
     +,   5.6675394E-06,   6.1090736E-06,   6.5763752E-06
     +,   7.0701381E-06,   7.5910079E-06,   8.1395738E-06
     +,   8.7163517E-06,   9.3217823E-06,   9.9562212E-06
     +,   1.0619930E-05,   1.1313077E-05,   1.2035715E-05
     +,   1.2787795E-05,   1.3569133E-05,   1.4379418E-05
     +,   1.5218246E-05,   1.6084992E-05,   1.6978982E-05
     +,   1.7899336E-05,   1.8845036E-05,   1.9814926E-05
     +,   2.0807682E-05,   2.1821837E-05,   2.2855762E-05
     +,   2.3907689E-05,   2.4975694E-05,   2.6057707E-05
     +,   2.7151533E-05,   2.8254832E-05,   2.9365134E-05
     +,   3.0479916E-05,   3.1596432E-05,   3.2711956E-05
     +,   3.3823624E-05,   3.4928515E-05,   3.6023648E-05
     +,   3.7106005E-05,   3.8172551E-05,   3.9220246E-05
     +,   4.0245999E-05,   4.1246829E-05,   4.2219788E-05
     +,   4.3161883E-05,   4.4070352E-05,   4.4942361E-05
     +,   4.5775330E-05,   4.6566682E-05,   4.7314086E-05
     +,   4.8015245E-05,   4.8668149E-05,   4.9270860E-05
     +,   4.9821698E-05,   5.0319162E-05,   5.0761941E-05
     +,   5.1148923E-05,   5.1479255E-05,   5.1752289E-05
     +,   5.1967574E-05,   5.2124913E-05,   5.2224321E-05
     +,   5.2266016E-05,   5.2250449E-05,   5.2178275E-05
     +,   5.2050349E-05,   5.1867708E-05,   5.1631599E-05
     +,   5.1343417E-05,   5.1004707E-05,   5.0617196E-05
     +,   5.0182742E-05,   4.9703289E-05,   4.9180901E-05
     +,   4.8617771E-05,   4.8016100E-05,   4.7378231E-05
     +,   4.6706464E-05,   4.6003235E-05,   4.5270899E-05
     +,   4.4511893E-05,   4.3728585E-05,   4.2923399E-05
     +,   4.2098658E-05,   4.1256633E-05,   4.0399613E-05
     +,   3.9529816E-05,   3.8649356E-05,   3.7760245E-05
     +,   3.6864520E-05,   3.5964007E-05,   3.5060566E-05
     +,   3.4155852E-05,   3.3251545E-05,   3.2349093E-05
     +,   3.1449996E-05,   3.0555522E-05,   2.9666971E-05
     +,   2.8785469E-05,   2.7912045E-05,   2.7047708E-05
     +,   2.6193375E-05,   2.5349833E-05,   2.4517800E-05
     +,   2.3697989E-05,   2.2890956E-05,   2.2097283E-05
     +,   2.1317404E-05,   2.0551786E-05,   1.9800753E-05
     +,   1.9064681E-05,   1.8343797E-05,   1.7638389E-05
     +,   1.6948637E-05,   1.6274689E-05,   1.5616699E-05
     +,   1.4974803E-05,   1.4349052E-05,   1.3739485E-05
     +,   1.3146156E-05,   1.2569091E-05,   1.2008263E-05
     +,   1.1463623E-05,   1.0935161E-05,   1.0422793E-05
     +,   9.9264189E-06,   9.4459620E-06,   8.9813193E-06
     +,   8.5323454E-06,   8.0988830E-06,   7.6807855E-06
     +,   7.2778962E-06,   6.8900149E-06,   6.5169302E-06
     +,   6.1584492E-06,   5.8143683E-06,   5.4844568E-06
     +,   5.1684888E-06,   4.8662791E-06,   4.5776319E-06
     +,   4.3023906E-06,   4.0404821E-06,   3.7919172E-06
     +,   3.5568289E-06,   3.3355409E-06,   3.1286586E-06
     +,   2.9371465E-06,   2.7624358E-06,   2.6065909E-06
     +,   2.4724970E-06,   2.3640596E-06,   2.2864367E-06
     +,   2.2463291E-06,   2.2522688E-06,   2.3149166E-06
     +,   2.4473732E-06,   2.6654614E-06,   2.9879700E-06
     +,   3.4368966E-06,   4.0376085E-06,   4.8189218E-06
     +,   5.8131945E-06,   7.0565443E-06,   8.5890479E-06
     +,   1.0455036E-05,   1.2703919E-05,   1.5391608E-05
     +,   1.8582346E-05,   2.2351112E-05,   2.6787879E-05
     +,   3.2002110E-05,   3.8127990E-05,   4.5330969E-05
     +,   5.3814965E-05,   6.3828636E-05,   7.5669814E-05
     +,   8.9689202E-05,   1.0629109E-04,   1.2592835E-04
     +,   1.4909016E-04,   1.7628548E-04,   2.0802020E-04
     +,   2.4476385E-04,   2.8690617E-04,   3.3472001E-04
     +,   3.8831137E-04,   4.4756883E-04,   5.1212369E-04
     +,   5.8132230E-04,   6.5420248E-04,   7.2948658E-04
     +,   8.0560398E-04,   8.8073761E-04,   9.5288223E-04
     +,   1.0199222E-03,   1.0797363E-03,   1.1303094E-03
     +,   1.1698389E-03,   1.1968358E-03,   1.2102224E-03
     +,   1.2093956E-03,   1.1942672E-03,   1.1652753E-03
     +,   1.1233583E-03,   1.0698999E-03,   1.0066539E-03
     +,   9.3564304E-04,   8.5904339E-04,   7.7907270E-04
     +,   6.9788919E-04,   6.1749120E-04,   5.3963350E-04
     +,   4.6577863E-04,   3.9707150E-04,   3.3431599E-04
     +,   2.7799406E-04,   2.2829702E-04,   1.8516080E-04
     +,   1.4831127E-04,   1.1731883E-04,   9.1649097E-05
     +,   7.0705850E-05,   5.3869342E-05,   4.0530242E-05
     +,   3.0113959E-05,   2.2095724E-05,   1.6010037E-05
     +,   1.1455433E-05,   8.0941491E-06,   5.6475842E-06
     +,   3.8911362E-06,   2.6473615E-06,   1.7785844E-06
     +,   1.1799148E-06,   7.7291384E-07,   4.9993957E-07
     +,   3.1931017E-07,   2.0137573E-07,   1.2539823E-07
     +,   7.7102882E-08,   4.6811596E-08,   2.8063207E-08
     +,   1.6612107E-08,   9.7106678E-09,   5.6057634E-09
     +,   3.1961473E-09,   1.8001994E-09,   1.0019983E-09
     +,   5.5142901E-10,   3.0029979E-10,   1.6206173E-10
     +,   8.6867090E-11,   4.6412360E-11,   2.4856544E-11
     +,   1.3456512E-11,   7.4498194E-12,   4.2787839E-12
     +,   2.5864770E-12,   1.6621486E-12,   1.1372566E-12
     +,   8.2244996E-13,   6.2083173E-13,   4.8279132E-13
     +,   3.8260768E-13,   3.0662080E-13,   2.4723366E-13
     +,   1.9994989E-13,   1.6190071E-13,   1.3110764E-13
     +,   1.0612220E-13,   8.5829252E-14,   6.9349793E-14
     +,   5.5974051E-14,   4.5127788E-14,   3.6341220E-14
     +,   2.9231703E-14,   2.3485405E-14,   1.8846751E-14
     +,   1.5106435E-14,   1.2094307E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz112 = Yx/0.00763636363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8324519E-05,   1.8799807E-05
     +,   1.9272722E-05,   1.9742487E-05,   2.0208317E-05
     +,   2.0669411E-05,   2.1124970E-05,   2.1574187E-05
     +,   2.2016238E-05,   2.2450331E-05,   2.2875647E-05
     +,   2.3291386E-05,   2.3696748E-05,   2.4090950E-05
     +,   2.4473215E-05,   2.4842786E-05,   2.5198919E-05
     +,   2.5540887E-05,   2.5867997E-05,   2.6179570E-05
     +,   2.6474958E-05,   2.6753536E-05,   2.7014717E-05
     +,   2.7257955E-05,   2.7482713E-05,   2.7688517E-05
     +,   2.7874921E-05,   2.8041517E-05,   2.8187944E-05
     +,   2.8313882E-05,   2.8419057E-05,   2.8503235E-05
     +,   2.8566235E-05,   2.8607914E-05,   2.8628185E-05
     +,   2.8627008E-05,   2.8604385E-05,   2.8560376E-05
     +,   2.8495071E-05,   2.8408633E-05,   2.8301245E-05
     +,   2.8173159E-05,   2.8024657E-05,   2.7856076E-05
     +,   2.7667797E-05,   2.7460230E-05,   2.7233846E-05
     +,   2.6989139E-05,   2.6726653E-05,   2.6446965E-05
     +,   2.6150681E-05,   2.5838450E-05,   2.5510946E-05
     +,   2.5168862E-05,   2.4812951E-05,   2.4443952E-05
     +,   2.4062650E-05,   2.3669847E-05,   2.3266361E-05
     +,   2.2853035E-05,   2.2430706E-05,   2.2000244E-05
     +,   2.1562535E-05,   2.1118456E-05,   2.0668873E-05
     +,   2.0214718E-05,   1.9756853E-05,   1.9296209E-05
     +,   1.8833656E-05,   1.8370120E-05,   1.7906459E-05
     +,   1.7443601E-05,   1.6982396E-05,   1.6523747E-05
     +,   1.6068512E-05,   1.5617530E-05,   1.5171667E-05
     +,   1.4731776E-05,   1.4298668E-05,   1.3873141E-05
     +,   1.3456024E-05,   1.3048078E-05,   1.2650099E-05
     +,   1.2262819E-05,   1.1887002E-05,   1.1523350E-05
     +,   1.1172595E-05,   1.0835401E-05,   1.0512462E-05
     +,   1.0204418E-05,   9.9118915E-06,   9.6355006E-06
     +,   9.3758417E-06,   9.1334678E-06,   8.9089081E-06
     +,   8.7026929E-06,   8.5152878E-06,   8.3471550E-06
     +,   8.1987091E-06,   8.0703403E-06,   7.9623924E-06
     +,   7.8751827E-06,   7.8089715E-06,   7.7639916E-06
     +,   7.7404156E-06,   7.7383756E-06,   7.7579462E-06
     +,   7.7991490E-06,   7.8619487E-06,   7.9462498E-06
     +,   8.0518876E-06,   8.1786447E-06,   8.3262175E-06
     +,   8.4942485E-06,   8.6822938E-06,   8.8898532E-06
     +,   9.1163256E-06,   9.3610615E-06,   9.6233043E-06
     +,   9.9022436E-06,   1.0196994E-05,   1.0506571E-05
     +,   1.0829915E-05,   1.1165916E-05,   1.1513393E-05
     +,   1.1871058E-05,   1.2237606E-05,   1.2611629E-05
     +,   1.2991712E-05,   1.3376332E-05,   1.3763991E-05
     +,   1.4153083E-05,   1.4542045E-05,   1.4929240E-05
     +,   1.5313066E-05,   1.5691927E-05,   1.6064219E-05
     +,   1.6428385E-05,   1.6782940E-05,   1.7126487E-05
     +,   1.7457704E-05,   1.7775403E-05,   1.8078585E-05
     +,   1.8366454E-05,   1.8638448E-05,   1.8894320E-05
     +,   1.9134204E-05,   1.9358638E-05,   1.9568675E-05
     +,   1.9765987E-05,   1.9952919E-05,   2.0132613E-05
     +,   2.0309102E-05,   2.0487476E-05,   2.0673931E-05
     +,   2.0875937E-05,   2.1102333E-05,   2.1363448E-05
     +,   2.1671209E-05,   2.2039141E-05,   2.2482536E-05
     +,   2.3018401E-05,   2.3665425E-05,   2.4443925E-05
     +,   2.5375781E-05,   2.6484247E-05,   2.7793647E-05
     +,   2.9329094E-05,   3.1116273E-05,   3.3180957E-05
     +,   3.5548383E-05,   3.8242815E-05,   4.1287160E-05
     +,   4.4702305E-05,   4.8506103E-05,   5.2713447E-05
     +,   5.7335448E-05,   6.2378662E-05,   6.7844841E-05
     +,   7.3731215E-05,   8.0030128E-05,   8.6728833E-05
     +,   9.3810413E-05,   1.0125522E-04,   1.0904197E-04
     +,   1.1714906E-04,   1.2555764E-04,   1.3425530E-04
     +,   1.4323927E-04,   1.5251986E-04,   1.6212685E-04
     +,   1.7211352E-04,   1.8256110E-04,   1.9358363E-04
     +,   2.0533268E-04,   2.1799885E-04,   2.3181192E-04
     +,   2.4703928E-04,   2.6398266E-04,   2.8296927E-04
     +,   3.0433899E-04,   3.2842997E-04,   3.5556170E-04
     +,   3.8601214E-04,   4.1999033E-04,   4.5761728E-04
     +,   4.9889839E-04,   5.4369727E-04,   5.9171853E-04
     +,   6.4249727E-04,   6.9538894E-04,   7.4956828E-04
     +,   8.0404349E-04,   8.5768173E-04,   9.0923888E-04
     +,   9.5739582E-04,   1.0008143E-03,   1.0381927E-03
     +,   1.0683218E-03,   1.0901392E-03,   1.1027887E-03
     +,   1.1056624E-03,   1.0984342E-03,   1.0810855E-03
     +,   1.0539065E-03,   1.0174882E-03,   9.7269844E-04
     +,   9.2064322E-04,   8.6261146E-04,   8.0001820E-04
     +,   7.3434669E-04,   6.6708145E-04,   5.9964386E-04
     +,   5.3334376E-04,   4.6934275E-04,   4.0861074E-04
     +,   3.5191275E-04,   2.9980644E-04,   2.5264168E-04
     +,   2.1057263E-04,   1.7358306E-04,   1.4151543E-04
     +,   1.1409748E-04,   9.0971313E-05,   7.1724957E-05
     +,   5.5919445E-05,   4.3109540E-05,   3.2861546E-05
     +,   2.4768149E-05,   1.8458268E-05,   1.3601022E-05
     +,   9.9089775E-06,   7.1378608E-06,   5.0839335E-06
     +,   3.5803898E-06,   2.4932897E-06,   1.7169610E-06
     +,   1.1693401E-06,   7.8771666E-07,   5.2496478E-07
     +,   3.4622084E-07,   2.2606066E-07,   1.4621635E-07
     +,   9.3761493E-08,   5.9681611E-08,   3.7771656E-08
     +,   2.3823608E-08,   1.5022927E-08,   9.5113544E-09
     +,   6.0781717E-09,   3.9450847E-09,   2.6180682E-09
     +,   1.7871611E-09,   1.2600849E-09,   9.1885122E-10
     +,   6.9171935E-10,   5.3531785E-10,   4.2356665E-10
     +,   3.4074599E-10,   2.7733671E-10,   2.2747489E-10
     +,   1.8747089E-10,   1.5491346E-10,   1.2816760E-10
     +,   1.0606584E-10,   8.7743056E-11,   7.2528768E-11
     +,   5.9889975E-11,   4.9394717E-11,   4.0685559E-11
     +,   3.3466768E-11,   2.7490260E-11,   2.2549297E-11
     +,   1.8469863E-11,   1.5106853E-11,   1.2338362E-11
     +,   1.0062754E-11,   8.1949768E-12,   6.6642867E-12
     +,   5.4116559E-12,   4.3881621E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz113 = Yx/0.00852173913043478
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1194414E-09,   1.3437290E-09
     +,   1.6102453E-09,   1.9263746E-09,   2.3006932E-09
     +,   2.7431271E-09,   3.2651450E-09,   3.8799661E-09
     +,   4.6027973E-09,   5.4511231E-09,   6.4449481E-09
     +,   7.6071567E-09,   8.9638457E-09,   1.0544739E-08
     +,   1.2383592E-08,   1.4518681E-08,   1.6993278E-08
     +,   1.9856220E-08,   2.3162510E-08,   2.6973936E-08
     +,   3.1359765E-08,   3.6397431E-08,   4.2173340E-08
     +,   4.8783949E-08,   5.6335725E-08,   6.4947415E-08
     +,   7.4749806E-08,   8.5887237E-08,   9.8518370E-08
     +,   1.1281755E-07,   1.2897522E-07,   1.4719971E-07
     +,   1.6771750E-07,   1.9077463E-07,   2.1663787E-07
     +,   2.4559475E-07,   2.7795562E-07,   3.1405281E-07
     +,   3.5424452E-07,   3.9890955E-07,   4.4845484E-07
     +,   5.0330988E-07,   5.6393020E-07,   6.3079506E-07
     +,   7.0440859E-07,   7.8529854E-07,   8.7401560E-07
     +,   9.7113184E-07,   1.0772389E-06,   1.1929475E-06
     +,   1.3188841E-06,   1.4556877E-06,   1.6040062E-06
     +,   1.7645050E-06,   1.9378342E-06,   2.1246615E-06
     +,   2.3256398E-06,   2.5414154E-06,   2.7726173E-06
     +,   3.0198569E-06,   3.2837179E-06,   3.5647577E-06
     +,   3.8634753E-06,   4.1803510E-06,   4.5158145E-06
     +,   4.8702045E-06,   5.2438463E-06,   5.6369418E-06
     +,   6.0496732E-06,   6.4820833E-06,   6.9341877E-06
     +,   7.4058503E-06,   7.8969015E-06,   8.4070080E-06
     +,   8.9357809E-06,   9.4827310E-06,   1.0047222E-05
     +,   1.0628515E-05,   1.1225798E-05,   1.1838155E-05
     +,   1.2464511E-05,   1.3103765E-05,   1.3754646E-05
     +,   1.4415870E-05,   1.5085993E-05,   1.5763579E-05
     +,   1.6447035E-05,   1.7134800E-05,   1.7825181E-05
     +,   1.8516512E-05,   1.9207109E-05,   1.9895222E-05
     +,   2.0579109E-05,   2.1257083E-05,   2.1927484E-05
     +,   2.2588622E-05,   2.3238947E-05,   2.3876886E-05
     +,   2.4501023E-05,   2.5109945E-05,   2.5702420E-05
     +,   2.6277236E-05,   2.6833355E-05,   2.7369810E-05
     +,   2.7885786E-05,   2.8380606E-05,   2.8853678E-05
     +,   2.9304540E-05,   2.9732899E-05,   3.0138566E-05
     +,   3.0521438E-05,   3.0881583E-05,   3.1219115E-05
     +,   3.1534295E-05,   3.1827432E-05,   3.2098938E-05
     +,   3.2349279E-05,   3.2578973E-05,   3.2788575E-05
     +,   3.2978671E-05,   3.3149863E-05,   3.3302742E-05
     +,   3.3437882E-05,   3.3555847E-05,   3.3657154E-05
     +,   3.3742272E-05,   3.3811612E-05,   3.3865512E-05
     +,   3.3904249E-05,   3.3928009E-05,   3.3936907E-05
     +,   3.3930959E-05,   3.3910099E-05,   3.3874185E-05
     +,   3.3822987E-05,   3.3756183E-05,   3.3673401E-05
     +,   3.3574193E-05,   3.3458062E-05,   3.3324453E-05
     +,   3.3172786E-05,   3.3002467E-05,   3.2812870E-05
     +,   3.2603388E-05,   3.2373428E-05,   3.2122429E-05
     +,   3.1849853E-05,   3.1555250E-05,   3.1238229E-05
     +,   3.0898467E-05,   3.0535728E-05,   3.0149893E-05
     +,   2.9740964E-05,   2.9309032E-05,   2.8854296E-05
     +,   2.8377126E-05,   2.7878012E-05,   2.7357539E-05
     +,   2.6816433E-05,   2.6255577E-05,   2.5675947E-05
     +,   2.5078614E-05,   2.4464814E-05,   2.3835879E-05
     +,   2.3193197E-05,   2.2538235E-05,   2.1872573E-05
     +,   2.1197868E-05,   2.0515761E-05,   1.9827945E-05
     +,   1.9136171E-05,   1.8442206E-05,   1.7747769E-05
     +,   1.7054557E-05,   1.6364325E-05,   1.5678699E-05
     +,   1.4999277E-05,   1.4327624E-05,   1.3665249E-05
     +,   1.3013532E-05,   1.2373781E-05,   1.1747255E-05
     +,   1.1135133E-05,   1.0538479E-05,   9.9583131E-06
     +,   9.3956951E-06,   8.8517627E-06,   8.3278528E-06
     +,   7.8257917E-06,   7.3483607E-06,   6.8998334E-06
     +,   6.4870574E-06,   6.1210058E-06,   5.8189621E-06
     +,   5.6076792E-06,   5.5278033E-06,   5.6397462E-06
     +,   6.0313082E-06,   6.8273262E-06,   8.2014358E-06
     +,   1.0389623E-05,   1.3705443E-05,   1.8556304E-05
     +,   2.5459074E-05,   3.5052173E-05,   4.8104794E-05
     +,   6.5515851E-05,   8.8298788E-05,   1.1755041E-04
     +,   1.5439930E-04,   1.9992547E-04,   2.5504921E-04
     +,   3.2039973E-04,   3.9616899E-04,   4.8195268E-04
     +,   5.7660131E-04,   6.7812001E-04,   7.8363623E-04
     +,   8.8944228E-04,   9.9113467E-04,   1.0838951E-03
     +,   1.1628291E-03,   1.2233766E-03,   1.2617486E-03
     +,   1.2753182E-03,   1.2629089E-03,   1.2249519E-03
     +,   1.1634747E-03,   1.0819139E-03,   9.8478433E-04
     +,   8.7726093E-04,   7.6470082E-04,   6.5218296E-04
     +,   5.4413662E-04,   4.4408572E-04,   3.5448989E-04
     +,   2.7674559E-04,   2.1128585E-04,   1.5774352E-04
     +,   1.1515912E-04,   8.2203034E-05,   5.7373301E-05
     +,   3.9152455E-05,   2.6123047E-05,   1.7041046E-05
     +,   1.0868929E-05,   6.7782212E-06,   4.1333715E-06
     +,   2.4648680E-06,   1.4377408E-06,   8.2053532E-07
     +,   4.5842671E-07,   2.5096026E-07,   1.3483162E-07
     +,   7.1283417E-08,   3.7254324E-08,   1.9395442E-08
     +,   1.0183860E-08,   5.4911520E-09,   3.1103344E-09
     +,   1.8908821E-09,   1.2471514E-09,   8.8762453E-10
     +,   6.7000483E-10,   5.2577886E-10,   4.2205975E-10
     +,   3.4284731E-10,   2.8003128E-10,   2.2917337E-10
     +,   1.8757165E-10,   1.5339408E-10,   1.2528266E-10
     +,   1.0217002E-10,   8.3187325E-11,   6.7619230E-11
     +,   5.4873148E-11,   4.4454398E-11,   3.5953431E-11
     +,   2.9028830E-11,   2.3398524E-11,   1.8828281E-11
     +,   1.5125229E-11,   1.2129878E-11,   9.7113689E-12
     +,   7.7618918E-12,   6.1933236E-12,   4.9334022E-12
     +,   3.9231283E-12,   3.1144939E-12,   2.4683437E-12
     +,   1.9529617E-12,   1.5425657E-12,   1.2163650E-12
     +,   9.5751792E-13,   7.5248770E-13,   5.9035686E-13
     +,   4.6238024E-13,   3.6153272E-13,   2.8220479E-13
     +,   2.1990995E-13,   1.7107824E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz114 = Yx/0.00595
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz1148(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9324891E-05,   1.9690749E-05
     +,   2.0053991E-05,   2.0414287E-05,   2.0771307E-05
     +,   2.1124726E-05,   2.1474232E-05,   2.1819513E-05
     +,   2.2160270E-05,   2.2496219E-05,   2.2827080E-05
     +,   2.3152592E-05,   2.3472505E-05,   2.3786577E-05
     +,   2.4094594E-05,   2.4396353E-05,   2.4691666E-05
     +,   2.4980369E-05,   2.5262314E-05,   2.5537374E-05
     +,   2.5805452E-05,   2.6066458E-05,   2.6320327E-05
     +,   2.6567037E-05,   2.6806560E-05,   2.7038914E-05
     +,   2.7264134E-05,   2.7482278E-05,   2.7693430E-05
     +,   2.7897697E-05,   2.8095206E-05,   2.8286124E-05
     +,   2.8470620E-05,   2.8648903E-05,   2.8821192E-05
     +,   2.8987737E-05,   2.9148798E-05,   2.9304665E-05
     +,   2.9455643E-05,   2.9602043E-05,   2.9744202E-05
     +,   2.9882476E-05,   3.0017218E-05,   3.0148800E-05
     +,   3.0277597E-05,   3.0403997E-05,   3.0528387E-05
     +,   3.0651157E-05,   3.0772691E-05,   3.0893381E-05
     +,   3.1013609E-05,   3.1133735E-05,   3.1254134E-05
     +,   3.1375155E-05,   3.1497118E-05,   3.1620359E-05
     +,   3.1745163E-05,   3.1871805E-05,   3.2000531E-05
     +,   3.2131567E-05,   3.2265103E-05,   3.2401309E-05
     +,   3.2540294E-05,   3.2682165E-05,   3.2826974E-05
     +,   3.2974742E-05,   3.3125438E-05,   3.3279011E-05
     +,   3.3435354E-05,   3.3594311E-05,   3.3755707E-05
     +,   3.3919299E-05,   3.4084824E-05,   3.4251949E-05
     +,   3.4420333E-05,   3.4589568E-05,   3.4759210E-05
     +,   3.4928773E-05,   3.5097750E-05,   3.5265581E-05
     +,   3.5431673E-05,   3.5595414E-05,   3.5756144E-05
     +,   3.5913195E-05,   3.6065856E-05,   3.6213412E-05
     +,   3.6355119E-05,   3.6490219E-05,   3.6617937E-05
     +,   3.6737514E-05,   3.6848167E-05,   3.6949106E-05
     +,   3.7039554E-05,   3.7118753E-05,   3.7185939E-05
     +,   3.7240367E-05,   3.7281308E-05,   3.7308066E-05
     +,   3.7319955E-05,   3.7316338E-05,   3.7296591E-05
     +,   3.7260143E-05,   3.7206446E-05,   3.7135007E-05
     +,   3.7045378E-05,   3.6937148E-05,   3.6809968E-05
     +,   3.6663529E-05,   3.6497589E-05,   3.6311954E-05
     +,   3.6106489E-05,   3.5881101E-05,   3.5635796E-05
     +,   3.5370584E-05,   3.5085592E-05,   3.4780940E-05
     +,   3.4456883E-05,   3.4113658E-05,   3.3751625E-05
     +,   3.3371158E-05,   3.2972679E-05,   3.2556687E-05
     +,   3.2123746E-05,   3.1674430E-05,   3.1209351E-05
     +,   3.0729228E-05,   3.0234743E-05,   2.9726678E-05
     +,   2.9205790E-05,   2.8672939E-05,   2.8128929E-05
     +,   2.7574670E-05,   2.7011014E-05,   2.6438907E-05
     +,   2.5859255E-05,   2.5272966E-05,   2.4680996E-05
     +,   2.4084307E-05,   2.3483819E-05,   2.2880451E-05
     +,   2.2275148E-05,   2.1668850E-05,   2.1062444E-05
     +,   2.0456804E-05,   1.9852841E-05,   1.9251394E-05
     +,   1.8653271E-05,   1.8059314E-05,   1.7470325E-05
     +,   1.6887063E-05,   1.6310260E-05,   1.5740681E-05
     +,   1.5179082E-05,   1.4626181E-05,   1.4082720E-05
     +,   1.3549504E-05,   1.3027407E-05,   1.2517345E-05
     +,   1.2020372E-05,   1.1537772E-05,   1.1071025E-05
     +,   1.0621934E-05,   1.0192759E-05,   9.7863003E-06
     +,   9.4060297E-06,   9.0562871E-06,   8.7425124E-06
     +,   8.4714748E-06,   8.2515235E-06,   8.0929685E-06
     +,   8.0084510E-06,   8.0133450E-06,   8.1262551E-06
     +,   8.3695304E-06,   8.7698172E-06,   9.3586950E-06
     +,   1.0173324E-05,   1.1257022E-05,   1.2659933E-05
     +,   1.4439757E-05,   1.6662310E-05,   1.9401856E-05
     +,   2.2741506E-05,   2.6773716E-05,   3.1600175E-05
     +,   3.7331105E-05,   4.4084845E-05,   5.1987347E-05
     +,   6.1170424E-05,   7.1768685E-05,   8.3918902E-05
     +,   9.7756056E-05,   1.1340869E-04,   1.3099513E-04
     +,   1.5062014E-04,   1.7236857E-04,   1.9629834E-04
     +,   2.2243554E-04,   2.5077077E-04,   2.8125191E-04
     +,   3.1377748E-04,   3.4819348E-04,   3.8429335E-04
     +,   4.2181375E-04,   4.6043092E-04,   4.9976946E-04
     +,   5.3940318E-04,   5.7885749E-04,   6.1762036E-04
     +,   6.5515464E-04,   6.9090730E-04,   7.2431949E-04
     +,   7.5484405E-04,   7.8196166E-04,   8.0519286E-04
     +,   8.2411093E-04,   8.3835697E-04,   8.4765168E-04
     +,   8.5180276E-04,   8.5071166E-04,   8.4437791E-04
     +,   8.3289813E-04,   8.1646541E-04,   7.9536380E-04
     +,   7.6995697E-04,   7.4067997E-04,   7.0802728E-04
     +,   6.7253836E-04,   6.3477934E-04,   5.9533038E-04
     +,   5.5477326E-04,   5.1367440E-04,   4.7256993E-04
     +,   4.3195664E-04,   3.9228724E-04,   3.5395514E-04
     +,   3.1729409E-04,   2.8257770E-04,   2.5001640E-04
     +,   2.1975717E-04,   1.9188905E-04,   1.6644932E-04
     +,   1.4342710E-04,   1.2276822E-04,   1.0438399E-04
     +,   8.8159155E-05,   7.3956951E-05,   6.1624924E-05
     +,   5.1001942E-05,   4.1924253E-05,   3.4227858E-05
     +,   2.7753456E-05,   2.2349632E-05,   1.7874469E-05
     +,   1.4196882E-05,   1.1197919E-05,   8.7712251E-06
     +,   6.8227068E-06,   5.2700502E-06,   4.0422456E-06
     +,   3.0787639E-06,   2.3284831E-06,   1.7486486E-06
     +,   1.3039313E-06,   9.6545841E-07,   7.0979235E-07
     +,   5.1813356E-07,   3.7555080E-07,   2.7028358E-07
     +,   1.9315030E-07,   1.3705679E-07,   9.6572826E-08
     +,   6.7574987E-08,   4.6959162E-08,   3.2411400E-08
     +,   2.2222412E-08,   1.5138237E-08,   1.0248944E-08
     +,   6.8984662E-09,   4.6187716E-09,   3.0781360E-09
     +,   2.0438584E-09,   1.3537634E-09,   8.9596042E-10
     +,   5.9375110E-10,   3.9507195E-10,   2.6480898E-10
     +,   1.7948718E-10,   1.2353502E-10,   8.6686124E-11
     +,   6.2229520E-11,   4.5799586E-11,   3.4576994E-11
     +,   2.6746504E-11,   2.1145235E-11,   1.7027746E-11
     +,   1.3916589E-11,   1.1503742E-11,   9.5891819E-12
     +,   8.0407139E-12,   6.7695276E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz1148 = Yx/0.00763636363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8798350E-09,   2.3008264E-09
     +,   2.8101721E-09,   3.4250551E-09,   4.1657175E-09
     +,   5.0559161E-09,   6.1235008E-09,   7.4010011E-09
     +,   8.9263006E-09,   1.0743539E-08,   1.2903816E-08
     +,   1.5466256E-08,   1.8499065E-08,   2.2080750E-08
     +,   2.6301388E-08,   3.1264111E-08,   3.7086689E-08
     +,   4.3903178E-08,   5.1865946E-08,   6.1147418E-08
     +,   7.1942587E-08,   8.4471040E-08,   9.8979314E-08
     +,   1.1574480E-07,   1.3507557E-07,   1.5731702E-07
     +,   1.8285193E-07,   2.1210491E-07,   2.4554524E-07
     +,   2.8369035E-07,   3.2710881E-07,   3.7642388E-07
     +,   4.3231657E-07,   4.9552898E-07,   5.6686736E-07
     +,   6.4720462E-07,   7.3748339E-07,   8.3871714E-07
     +,   9.5199897E-07,   1.0784864E-06,   1.2194257E-06
     +,   1.3761330E-06,   1.5500045E-06,   1.7425106E-06
     +,   1.9551974E-06,   2.1896849E-06,   2.4476583E-06
     +,   2.7308699E-06,   3.0411295E-06,   3.3802999E-06
     +,   3.7502846E-06,   4.1530261E-06,   4.5904817E-06
     +,   5.0646499E-06,   5.5774758E-06,   6.1309447E-06
     +,   6.7269762E-06,   7.3674523E-06,   8.0541831E-06
     +,   8.7888948E-06,   9.5732075E-06,   1.0408622E-05
     +,   1.1296430E-05,   1.2237821E-05,   1.3233787E-05
     +,   1.4285003E-05,   1.5392026E-05,   1.6555006E-05
     +,   1.7773942E-05,   1.9048362E-05,   2.0377622E-05
     +,   2.1760547E-05,   2.3195764E-05,   2.4681325E-05
     +,   2.6215012E-05,   2.7794207E-05,   2.9415765E-05
     +,   3.1076095E-05,   3.2771310E-05,   3.4497083E-05
     +,   3.6248519E-05,   3.8020535E-05,   3.9807441E-05
     +,   4.1603413E-05,   4.3402059E-05,   4.5196903E-05
     +,   4.6980993E-05,   4.8747344E-05,   5.0488572E-05
     +,   5.2197334E-05,   5.3866177E-05,   5.5487515E-05
     +,   5.7053774E-05,   5.8557580E-05,   5.9991686E-05
     +,   6.1348903E-05,   6.2622465E-05,   6.3805790E-05
     +,   6.4892782E-05,   6.5877655E-05,   6.6755230E-05
     +,   6.7520727E-05,   6.8170048E-05,   6.8699621E-05
     +,   6.9106580E-05,   6.9388690E-05,   6.9544425E-05
     +,   6.9572954E-05,   6.9474176E-05,   6.9248701E-05
     +,   6.8897847E-05,   6.8423629E-05,   6.7828776E-05
     +,   6.7116620E-05,   6.6291206E-05,   6.5357082E-05
     +,   6.4319451E-05,   6.3183928E-05,   6.1956744E-05
     +,   6.0644437E-05,   5.9253922E-05,   5.7792531E-05
     +,   5.6267905E-05,   5.4687815E-05,   5.3060223E-05
     +,   5.1393410E-05,   4.9695565E-05,   4.7975169E-05
     +,   4.6240541E-05,   4.4500244E-05,   4.2762626E-05
     +,   4.1036234E-05,   3.9329389E-05,   3.7650556E-05
     +,   3.6008019E-05,   3.4410012E-05,   3.2864798E-05
     +,   3.1380587E-05,   2.9965420E-05,   2.8627284E-05
     +,   2.7374186E-05,   2.6214046E-05,   2.5154601E-05
     +,   2.4203538E-05,   2.3368511E-05,   2.2656985E-05
     +,   2.2076330E-05,   2.1633850E-05,   2.1336718E-05
     +,   2.1191998E-05,   2.1206712E-05,   2.1387832E-05
     +,   2.1742326E-05,   2.2277223E-05,   2.2999679E-05
     +,   2.3916964E-05,   2.5036521E-05,   2.6366082E-05
     +,   2.7913633E-05,   2.9687184E-05,   3.1694985E-05
     +,   3.3945220E-05,   3.6445625E-05,   3.9203213E-05
     +,   4.2224056E-05,   4.5512606E-05,   4.9070826E-05
     +,   5.2897671E-05,   5.6988640E-05,   6.1334860E-05
     +,   6.5922119E-05,   7.0730632E-05,   7.5735108E-05
     +,   8.0904509E-05,   8.6201937E-05,   9.1586524E-05
     +,   9.7014294E-05,   1.0243974E-04,   1.0781852E-04
     +,   1.1311058E-04,   1.1828300E-04,   1.2331267E-04
     +,   1.2819006E-04,   1.3292200E-04,   1.3753359E-04
     +,   1.4206930E-04,   1.4659349E-04,   1.5118976E-04
     +,   1.5595881E-04,   1.6101505E-04,   1.6648424E-04
     +,   1.7249984E-04,   1.7920027E-04,   1.8672817E-04
     +,   1.9523261E-04,   2.0487281E-04,   2.1582465E-04
     +,   2.2829034E-04,   2.4250975E-04,   2.5876932E-04
     +,   2.7740651E-04,   2.9881016E-04,   3.2341096E-04
     +,   3.5165876E-04,   3.8398299E-04,   4.2075015E-04
     +,   4.6220270E-04,   5.0839223E-04,   5.5911858E-04
     +,   6.1388098E-04,   6.7183998E-04,   7.3180394E-04
     +,   7.9225062E-04,   8.5138698E-04,   9.0722617E-04
     +,   9.5769309E-04,   1.0007541E-03,   1.0345489E-03
     +,   1.0575100E-03,   1.0684674E-03,   1.0667284E-03
     +,   1.0521202E-03,   1.0249970E-03,   9.8621170E-04
     +,   9.3705242E-04,   8.7915652E-04,   8.1441295E-04
     +,   7.4484956E-04,   6.7251688E-04,   5.9939129E-04
     +,   5.2729179E-04,   4.5780704E-04,   3.9224196E-04
     +,   3.3159665E-04,   2.7656628E-04,   2.2754111E-04
     +,   1.8464102E-04,   1.4775590E-04,   1.1658728E-04
     +,   9.0694863E-05,   6.9546513E-05,   5.2562307E-05
     +,   3.9149658E-05,   2.8732878E-05,   2.0776521E-05
     +,   1.4800153E-05,   1.0385329E-05,   7.1777749E-06
     +,   4.8857519E-06,   3.2750784E-06,   2.1618393E-06
     +,   1.4050813E-06,   8.9915687E-07,   5.6651066E-07
     +,   3.5139166E-07,   2.1456493E-07,   1.2897300E-07
     +,   7.6313839E-08,   4.4447827E-08,   2.5481162E-08
     +,   1.4378235E-08,   7.9855971E-09,   4.3652273E-09
     +,   2.3484845E-09,   1.2435405E-09,   6.4805133E-10
     +,   3.3236969E-10,   1.6776562E-10,   8.3341896E-11
     +,   4.0746961E-11,   1.9606247E-11,   9.2850059E-12
     +,   4.3280275E-12,   1.9858223E-12,   8.9695769E-13
     +,   3.9892338E-13,   1.7474146E-13,   7.5424787E-14
     +,   3.2101979E-14,   1.3488602E-14,   5.6049822E-15
     +,   2.3099743E-15,   9.4830167E-16,   3.9040077E-16
     +,   1.6272190E-16,   6.9553753E-17,   3.0941379E-17
     +,   1.4520929E-17,   7.2469509E-18,   3.8434252E-18
     +,   2.1484767E-18,   1.2510029E-18,   7.5023100E-19
     +,   4.5929302E-19,   2.8532011E-19,   1.7916568E-19
     +,   1.1346668E-19,   7.2367725E-20,   4.6439810E-20
     +,   2.9962556E-20,   1.9424547E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz116 = Yx/0.00795454545454546
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8640914E-05,   2.8735754E-05
     +,   2.8809158E-05,   2.8860995E-05,   2.8891191E-05
     +,   2.8899720E-05,   2.8886614E-05,   2.8851953E-05
     +,   2.8795870E-05,   2.8718559E-05,   2.8620256E-05
     +,   2.8501254E-05,   2.8361897E-05,   2.8202578E-05
     +,   2.8023736E-05,   2.7825867E-05,   2.7609498E-05
     +,   2.7375212E-05,   2.7123631E-05,   2.6855412E-05
     +,   2.6571259E-05,   2.6271904E-05,   2.5958123E-05
     +,   2.5630696E-05,   2.5290479E-05,   2.4938310E-05
     +,   2.4575063E-05,   2.4201645E-05,   2.3818968E-05
     +,   2.3427960E-05,   2.3029570E-05,   2.2624745E-05
     +,   2.2214444E-05,   2.1799631E-05,   2.1381265E-05
     +,   2.0960315E-05,   2.0537727E-05,   2.0114459E-05
     +,   1.9691433E-05,   1.9269604E-05,   1.8849854E-05
     +,   1.8433093E-05,   1.8020191E-05,   1.7612007E-05
     +,   1.7209361E-05,   1.6813065E-05,   1.6423886E-05
     +,   1.6042579E-05,   1.5669855E-05,   1.5306399E-05
     +,   1.4952858E-05,   1.4609845E-05,   1.4277949E-05
     +,   1.3957685E-05,   1.3649580E-05,   1.3354083E-05
     +,   1.3071619E-05,   1.2802571E-05,   1.2547282E-05
     +,   1.2306048E-05,   1.2079132E-05,   1.1866744E-05
     +,   1.1669075E-05,   1.1486248E-05,   1.1318351E-05
     +,   1.1165448E-05,   1.1027540E-05,   1.0904606E-05
     +,   1.0796571E-05,   1.0703335E-05,   1.0624746E-05
     +,   1.0560629E-05,   1.0510760E-05,   1.0474887E-05
     +,   1.0452725E-05,   1.0443952E-05,   1.0448220E-05
     +,   1.0465148E-05,   1.0494328E-05,   1.0535329E-05
     +,   1.0587692E-05,   1.0650939E-05,   1.0724568E-05
     +,   1.0808071E-05,   1.0900912E-05,   1.1002561E-05
     +,   1.1112458E-05,   1.1230064E-05,   1.1354816E-05
     +,   1.1486170E-05,   1.1623591E-05,   1.1766546E-05
     +,   1.1914522E-05,   1.2067037E-05,   1.2223641E-05
     +,   1.2383899E-05,   1.2547445E-05,   1.2713937E-05
     +,   1.2883110E-05,   1.3054744E-05,   1.3228705E-05
     +,   1.3404920E-05,   1.3583421E-05,   1.3764313E-05
     +,   1.3947812E-05,   1.4134251E-05,   1.4324050E-05
     +,   1.4517756E-05,   1.4716045E-05,   1.4919722E-05
     +,   1.5129696E-05,   1.5347026E-05,   1.5572869E-05
     +,   1.5808533E-05,   1.6055406E-05,   1.6315020E-05
     +,   1.6588954E-05,   1.6878923E-05,   1.7186654E-05
     +,   1.7513963E-05,   1.7862687E-05,   1.8234665E-05
     +,   1.8631701E-05,   1.9055604E-05,   1.9508119E-05
     +,   1.9990870E-05,   2.0505442E-05,   2.1053236E-05
     +,   2.1635593E-05,   2.2253631E-05,   2.2908413E-05
     +,   2.3600758E-05,   2.4331450E-05,   2.5101037E-05
     +,   2.5910056E-05,   2.6758971E-05,   2.7648150E-05
     +,   2.8577972E-05,   2.9548941E-05,   3.0561681E-05
     +,   3.1616932E-05,   3.2715681E-05,   3.3859291E-05
     +,   3.5049539E-05,   3.6288522E-05,   3.7578997E-05
     +,   3.8924307E-05,   4.0328378E-05,   4.1795858E-05
     +,   4.3332264E-05,   4.4943965E-05,   4.6638139E-05
     +,   4.8422891E-05,   5.0307463E-05,   5.2302144E-05
     +,   5.4418280E-05,   5.6668330E-05,   5.9066191E-05
     +,   6.1627048E-05,   6.4367261E-05,   6.7304842E-05
     +,   7.0459362E-05,   7.3851734E-05,   7.7504461E-05
     +,   8.1441882E-05,   8.5690044E-05,   9.0276328E-05
     +,   9.5229661E-05,   1.0058082E-04,   1.0636201E-04
     +,   1.1260637E-04,   1.1934804E-04,   1.2662241E-04
     +,   1.3446550E-04,   1.4291276E-04,   1.5200017E-04
     +,   1.6176308E-04,   1.7223501E-04,   1.8344738E-04
     +,   1.9542986E-04,   2.0820854E-04,   2.2180456E-04
     +,   2.3623358E-04,   2.5150590E-04,   2.6762483E-04
     +,   2.8458430E-04,   3.0236901E-04,   3.2095509E-04
     +,   3.4030800E-04,   3.6038019E-04,   3.8111475E-04
     +,   4.0244311E-04,   4.2428408E-04,   4.4654513E-04
     +,   4.6912435E-04,   4.9190945E-04,   5.1477680E-04
     +,   5.3759338E-04,   5.6021905E-04,   5.8250461E-04
     +,   6.0429168E-04,   6.2541437E-04,   6.4570049E-04
     +,   6.6497119E-04,   6.8303983E-04,   6.9971755E-04
     +,   7.1481185E-04,   7.2812929E-04,   7.3947862E-04
     +,   7.4867567E-04,   7.5554632E-04,   7.5993064E-04
     +,   7.6168904E-04,   7.6070643E-04,   7.5689779E-04
     +,   7.5021159E-04,   7.4063428E-04,   7.2819280E-04
     +,   7.1295496E-04,   6.9503236E-04,   6.7457673E-04
     +,   6.5177766E-04,   6.2686153E-04,   6.0008495E-04
     +,   5.7172793E-04,   5.4208824E-04,   5.1147700E-04
     +,   4.8021052E-04,   4.4860071E-04,   4.1695093E-04
     +,   3.8555256E-04,   3.5467724E-04,   3.2457086E-04
     +,   2.9545237E-04,   2.6751368E-04,   2.4091281E-04
     +,   2.1577594E-04,   1.9219947E-04,   1.7024868E-04
     +,   1.4995836E-04,   1.3133642E-04,   1.1436757E-04
     +,   9.9014731E-05,   8.5221247E-05,   7.2915376E-05
     +,   6.2014005E-05,   5.2424879E-05,   4.4048913E-05
     +,   3.6783804E-05,   3.0526979E-05,   2.5176325E-05
     +,   2.0632799E-05,   1.6802131E-05,   1.3595489E-05
     +,   1.0930241E-05,   8.7307035E-06,   6.9285443E-06
     +,   5.4625857E-06,   4.2786146E-06,   3.3292258E-06
     +,   2.5734385E-06,   1.9761201E-06,   1.5074204E-06
     +,   1.1422809E-06,   8.5988364E-07,   6.4303998E-07
     +,   4.7772221E-07,   3.5259416E-07,   2.5856437E-07
     +,   1.8840359E-07,   1.3642166E-07,   9.8180507E-08
     +,   7.0244454E-08,   4.9976226E-08,   3.5370263E-08
     +,   2.4915119E-08,   1.7478859E-08,   1.2222819E-08
     +,   8.5292449E-09,   5.9478342E-09,   4.1522532E-09
     +,   2.9083700E-09,   2.0491828E-09,   1.4567112E-09
     +,   1.0480800E-09,   7.6560086E-10,   5.6933375E-10
     +,   4.3183832E-10,   3.3438266E-10,   2.6423266E-10
     +,   2.1278707E-10,   1.7424477E-10,   1.4470874E-10
     +,   1.2155396E-10,   1.0301159E-10,   8.7877927E-11
     +,   7.5328396E-11,   6.4786516E-11,   5.5843458E-11
     +,   4.8200149E-11,   4.1633620E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz117 = Yx/0.00882608695652174
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8977042E-06,   3.1830687E-06
     +,   3.4915890E-06,   3.8245962E-06,   4.1834373E-06
     +,   4.5694760E-06,   4.9840801E-06,   5.4286161E-06
     +,   5.9044351E-06,   6.4128922E-06,   6.9552912E-06
     +,   7.5329071E-06,   8.1469670E-06,   8.7986391E-06
     +,   9.4890211E-06,   1.0219125E-05,   1.0989870E-05
     +,   1.1802072E-05,   1.2656416E-05,   1.3553466E-05
     +,   1.4493634E-05,   1.5477175E-05,   1.6504157E-05
     +,   1.7574534E-05,   1.8687944E-05,   1.9843956E-05
     +,   2.1041833E-05,   2.2280654E-05,   2.3559260E-05
     +,   2.4876259E-05,   2.6230015E-05,   2.7618651E-05
     +,   2.9040042E-05,   3.0491818E-05,   3.1971369E-05
     +,   3.3475837E-05,   3.5002129E-05,   3.6546906E-05
     +,   3.8106711E-05,   3.9677703E-05,   4.1256018E-05
     +,   4.2837521E-05,   4.4417935E-05,   4.5992856E-05
     +,   4.7557754E-05,   4.9107995E-05,   5.0638879E-05
     +,   5.2145650E-05,   5.3623538E-05,   5.5067794E-05
     +,   5.6473677E-05,   5.7836529E-05,   5.9151756E-05
     +,   6.0414954E-05,   6.1621759E-05,   6.2768100E-05
     +,   6.3850028E-05,   6.4863882E-05,   6.5806213E-05
     +,   6.6673878E-05,   6.7464040E-05,   6.8174166E-05
     +,   6.8802045E-05,   6.9345886E-05,   6.9804228E-05
     +,   7.0175964E-05,   7.0460395E-05,   7.0657232E-05
     +,   7.0766546E-05,   7.0788810E-05,   7.0724891E-05
     +,   7.0576018E-05,   7.0343805E-05,   7.0030219E-05
     +,   6.9637572E-05,   6.9168484E-05,   6.8625879E-05
     +,   6.8013025E-05,   6.7333371E-05,   6.6590605E-05
     +,   6.5788699E-05,   6.4931672E-05,   6.4023850E-05
     +,   6.3069536E-05,   6.2073246E-05,   6.1039427E-05
     +,   5.9972703E-05,   5.8877533E-05,   5.7758523E-05
     +,   5.6620087E-05,   5.5466589E-05,   5.4302323E-05
     +,   5.3131473E-05,   5.1957988E-05,   5.0785660E-05
     +,   4.9618164E-05,   4.8458864E-05,   4.7311030E-05
     +,   4.6177545E-05,   4.5061210E-05,   4.3964421E-05
     +,   4.2889467E-05,   4.1838255E-05,   4.0812556E-05
     +,   3.9813796E-05,   3.8843151E-05,   3.7901620E-05
     +,   3.6989972E-05,   3.6108671E-05,   3.5257995E-05
     +,   3.4438101E-05,   3.3648848E-05,   3.2890035E-05
     +,   3.2161213E-05,   3.1461906E-05,   3.0791427E-05
     +,   3.0149087E-05,   2.9534041E-05,   2.8945489E-05
     +,   2.8382532E-05,   2.7844279E-05,   2.7329888E-05
     +,   2.6838559E-05,   2.6369511E-05,   2.5922061E-05
     +,   2.5495661E-05,   2.5089834E-05,   2.4704290E-05
     +,   2.4338848E-05,   2.3993547E-05,   2.3668554E-05
     +,   2.3364279E-05,   2.3081284E-05,   2.2820383E-05
     +,   2.2582562E-05,   2.2369015E-05,   2.2181153E-05
     +,   2.2020575E-05,   2.1889040E-05,   2.1788474E-05
     +,   2.1720965E-05,   2.1688702E-05,   2.1693968E-05
     +,   2.1739106E-05,   2.1826496E-05,   2.1958509E-05
     +,   2.2137479E-05,   2.2365664E-05,   2.2645203E-05
     +,   2.2978102E-05,   2.3366203E-05,   2.3811124E-05
     +,   2.4314262E-05,   2.4876788E-05,   2.5499658E-05
     +,   2.6183536E-05,   2.6928848E-05,   2.7735872E-05
     +,   2.8604703E-05,   2.9535238E-05,   3.0527397E-05
     +,   3.1581123E-05,   3.2696382E-05,   3.3873348E-05
     +,   3.5112607E-05,   3.6415193E-05,   3.7782658E-05
     +,   3.9217321E-05,   4.0722505E-05,   4.2302639E-05
     +,   4.3963340E-05,   4.5711695E-05,   4.7556547E-05
     +,   4.9508588E-05,   5.1580362E-05,   5.3786756E-05
     +,   5.6145018E-05,   5.8674690E-05,   6.1397819E-05
     +,   6.4339190E-05,   6.7526147E-05,   7.0988324E-05
     +,   7.4757620E-05,   7.8868194E-05,   8.3356048E-05
     +,   8.8258086E-05,   9.3611954E-05,   9.9455588E-05
     +,   1.0582621E-04,   1.1275876E-04,   1.2028600E-04
     +,   1.2843689E-04,   1.3723479E-04,   1.4669658E-04
     +,   1.5683204E-04,   1.6764202E-04,   1.7911640E-04
     +,   1.9123344E-04,   2.0395975E-04,   2.1724860E-04
     +,   2.3103840E-04,   2.4525315E-04,   2.5980329E-04
     +,   2.7458539E-04,   2.8948093E-04,   3.0436087E-04
     +,   3.1908526E-04,   3.3350408E-04,   3.4746097E-04
     +,   3.6079626E-04,   3.7334912E-04,   3.8495945E-04
     +,   3.9547234E-04,   4.0474182E-04,   4.1263318E-04
     +,   4.1902540E-04,   4.2381475E-04,   4.2691783E-04
     +,   4.2827238E-04,   4.2783952E-04,   4.2560470E-04
     +,   4.2157824E-04,   4.1579522E-04,   4.0831536E-04
     +,   3.9922050E-04,   3.8861370E-04,   3.7661762E-04
     +,   3.6337136E-04,   3.4902667E-04,   3.3374535E-04
     +,   3.1769727E-04,   3.0105584E-04,   2.8399381E-04
     +,   2.6668105E-04,   2.4928339E-04,   2.3195658E-04
     +,   2.1484564E-04,   1.9808412E-04,   1.8179149E-04
     +,   1.6607092E-04,   1.5100979E-04,   1.3668042E-04
     +,   1.2313912E-04,   1.1042572E-04,   9.8565470E-05
     +,   8.7570792E-05,   7.7441371E-05,   6.8165187E-05
     +,   5.9720642E-05,   5.2078733E-05,   4.5202985E-05
     +,   3.9051800E-05,   3.3580156E-05,   2.8740424E-05
     +,   2.4483239E-05,   2.0759006E-05,   1.7518913E-05
     +,   1.4715411E-05,   1.2302652E-05,   1.0237238E-05
     +,   8.4786379E-06,   6.9892553E-06,   5.7344746E-06
     +,   4.6828554E-06,   3.8061651E-06,   3.0790768E-06
     +,   2.4791689E-06,   1.9867664E-06,   1.5846945E-06
     +,   1.2580526E-06,   9.9403815E-07,   7.8173832E-07
     +,   6.1189542E-07,   4.7670216E-07,   3.6963056E-07
     +,   2.8526375E-07,   2.1911735E-07,   1.6751973E-07
     +,   1.2746990E-07,   9.6540766E-08,   7.2772693E-08
     +,   5.4599727E-08,   4.0772843E-08,   3.0305461E-08
     +,   2.2419965E-08,   1.6509196E-08,   1.2100249E-08
     +,   8.8275884E-09,   6.4104073E-09,   4.6336770E-09
     +,   3.3341370E-09,   2.3881621E-09,   1.7029211E-09
     +,   1.2088959E-09,   8.5444718E-10,   6.0132327E-10
     +,   4.2141718E-10,   2.9413255E-10,   2.0449353E-10
     +,   1.4164392E-10,   9.7772672E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz118 = Yx/0.0056
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5264566E-05,   3.5706467E-05
     +,   3.6158432E-05,   3.6620891E-05,   3.7094229E-05
     +,   3.7578804E-05,   3.8074919E-05,   3.8582850E-05
     +,   3.9102812E-05,   3.9634979E-05,   4.0179468E-05
     +,   4.0736326E-05,   4.1305568E-05,   4.1887120E-05
     +,   4.2480860E-05,   4.3086595E-05,   4.3704058E-05
     +,   4.4332934E-05,   4.4972807E-05,   4.5623201E-05
     +,   4.6283596E-05,   4.6953366E-05,   4.7631816E-05
     +,   4.8318234E-05,   4.9011745E-05,   4.9711503E-05
     +,   5.0416540E-05,   5.1125837E-05,   5.1838335E-05
     +,   5.2552885E-05,   5.3268315E-05,   5.3983382E-05
     +,   5.4696819E-05,   5.5407309E-05,   5.6113488E-05
     +,   5.6813988E-05,   5.7507386E-05,   5.8192243E-05
     +,   5.8867143E-05,   5.9530605E-05,   6.0181184E-05
     +,   6.0817441E-05,   6.1437917E-05,   6.2041181E-05
     +,   6.2625819E-05,   6.3190462E-05,   6.3733758E-05
     +,   6.4254382E-05,   6.4751075E-05,   6.5222615E-05
     +,   6.5667809E-05,   6.6085573E-05,   6.6474851E-05
     +,   6.6834669E-05,   6.7164074E-05,   6.7462272E-05
     +,   6.7728484E-05,   6.7961999E-05,   6.8162248E-05
     +,   6.8328678E-05,   6.8460875E-05,   6.8558475E-05
     +,   6.8621193E-05,   6.8648857E-05,   6.8641370E-05
     +,   6.8598711E-05,   6.8520938E-05,   6.8408226E-05
     +,   6.8260772E-05,   6.8078887E-05,   6.7862973E-05
     +,   6.7613444E-05,   6.7330853E-05,   6.7015761E-05
     +,   6.6668821E-05,   6.6290733E-05,   6.5882246E-05
     +,   6.5444205E-05,   6.4977445E-05,   6.4482818E-05
     +,   6.3961321E-05,   6.3413878E-05,   6.2841515E-05
     +,   6.2245213E-05,   6.1626066E-05,   6.0985090E-05
     +,   6.0323393E-05,   5.9642032E-05,   5.8942132E-05
     +,   5.8224763E-05,   5.7491019E-05,   5.6742021E-05
     +,   5.5978879E-05,   5.5202669E-05,   5.4414457E-05
     +,   5.3615368E-05,   5.2806430E-05,   5.1988758E-05
     +,   5.1163373E-05,   5.0331379E-05,   4.9493770E-05
     +,   4.8651651E-05,   4.7806006E-05,   4.6957957E-05
     +,   4.6108515E-05,   4.5258705E-05,   4.4409633E-05
     +,   4.3562402E-05,   4.2718082E-05,   4.1877774E-05
     +,   4.1042662E-05,   4.0213879E-05,   3.9392682E-05
     +,   3.8580256E-05,   3.7777954E-05,   3.6987032E-05
     +,   3.6208912E-05,   3.5444984E-05,   3.4696750E-05
     +,   3.3965698E-05,   3.3253378E-05,   3.2561416E-05
     +,   3.1891479E-05,   3.1245239E-05,   3.0624375E-05
     +,   3.0030673E-05,   2.9465837E-05,   2.8931632E-05
     +,   2.8429777E-05,   2.7961989E-05,   2.7529899E-05
     +,   2.7135118E-05,   2.6779138E-05,   2.6463391E-05
     +,   2.6189149E-05,   2.5957548E-05,   2.5769594E-05
     +,   2.5626108E-05,   2.5527688E-05,   2.5474754E-05
     +,   2.5467525E-05,   2.5505968E-05,   2.5589847E-05
     +,   2.5718726E-05,   2.5891955E-05,   2.6108708E-05
     +,   2.6368049E-05,   2.6668895E-05,   2.7010134E-05
     +,   2.7390672E-05,   2.7809530E-05,   2.8265897E-05
     +,   2.8759221E-05,   2.9289411E-05,   2.9856925E-05
     +,   3.0462885E-05,   3.1109226E-05,   3.1798983E-05
     +,   3.2536387E-05,   3.3326996E-05,   3.4178047E-05
     +,   3.5098590E-05,   3.6099624E-05,   3.7194368E-05
     +,   3.8398506E-05,   3.9730348E-05,   4.1210897E-05
     +,   4.2864049E-05,   4.4716842E-05,   4.6799443E-05
     +,   4.9145059E-05,   5.1790004E-05,   5.4773784E-05
     +,   5.8138914E-05,   6.1930237E-05,   6.6195331E-05
     +,   7.0983842E-05,   7.6346623E-05,   8.2335420E-05
     +,   8.9002591E-05,   9.6399926E-05,   1.0457748E-04
     +,   1.1358267E-04,   1.2345996E-04,   1.3424932E-04
     +,   1.4598419E-04,   1.5869070E-04,   1.7238746E-04
     +,   1.8708351E-04,   2.0277564E-04,   2.1944995E-04
     +,   2.3707961E-04,   2.5562270E-04,   2.7502252E-04
     +,   2.9520821E-04,   3.1609353E-04,   3.3757553E-04
     +,   3.5953560E-04,   3.8184205E-04,   4.0434970E-04
     +,   4.2689906E-04,   4.4931995E-04,   4.7143485E-04
     +,   4.9305917E-04,   5.1400205E-04,   5.3407304E-04
     +,   5.5308297E-04,   5.7084538E-04,   5.8718090E-04
     +,   6.0192181E-04,   6.1491283E-04,   6.2601356E-04
     +,   6.3510210E-04,   6.4207736E-04,   6.4686016E-04
     +,   6.4939458E-04,   6.4964959E-04,   6.4761960E-04
     +,   6.4332364E-04,   6.3680607E-04,   6.2813523E-04
     +,   6.1740098E-04,   6.0471572E-04,   5.9021055E-04
     +,   5.7403208E-04,   5.5634102E-04,   5.3730985E-04
     +,   5.1712024E-04,   4.9595727E-04,   4.7400850E-04
     +,   4.5146287E-04,   4.2850609E-04,   4.0531697E-04
     +,   3.8206694E-04,   3.5891958E-04,   3.3602526E-04
     +,   3.1352160E-04,   2.9153418E-04,   2.7017409E-04
     +,   2.4953621E-04,   2.2970079E-04,   2.1073435E-04
     +,   1.9268935E-04,   1.7560292E-04,   1.5949958E-04
     +,   1.4439279E-04,   1.3028475E-04,   1.1716679E-04
     +,   1.0502162E-04,   9.3825438E-05,   8.3546729E-05
     +,   7.4148782E-05,   6.5591223E-05,   5.7830352E-05
     +,   5.0819635E-05,   4.4511220E-05,   3.8856993E-05
     +,   3.3808832E-05,   2.9318870E-05,   2.5340492E-05
     +,   2.1828873E-05,   1.8741050E-05,   1.6035998E-05
     +,   1.3675080E-05,   1.1622365E-05,   9.8442270E-06
     +,   8.3096520E-06,   6.9902644E-06,   5.8601649E-06
     +,   4.8957809E-06,   4.0758705E-06,   3.3814276E-06
     +,   2.7954807E-06,   2.3029222E-06,   1.8904177E-06
     +,   1.5462867E-06,   1.2602674E-06,   1.0234670E-06
     +,   8.2815126E-07,   6.6768013E-07,   5.3633602E-07
     +,   4.2925313E-07,   3.4228233E-07,   2.7192490E-07
     +,   2.1522531E-07,   1.6971389E-07,   1.3332475E-07
     +,   1.0434303E-07,   8.1353470E-08,   6.3188075E-08
     +,   4.8892421E-08,   3.7686263E-08,   2.8937494E-08
     +,   2.2134138E-08,   1.6865171E-08,   1.2800683E-08
     +,   9.6781703E-09,   7.2888535E-09,   5.4680949E-09
     +,   4.0861381E-09,   3.0415528E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz119 = Yx/0.00882608695652174
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0530933E-05,   2.1068836E-05
     +,   2.1605198E-05,   2.2139315E-05,   2.2670516E-05
     +,   2.3198154E-05,   2.3721612E-05,   2.4240308E-05
     +,   2.4753695E-05,   2.5261324E-05,   2.5762760E-05
     +,   2.6257656E-05,   2.6745747E-05,   2.7226857E-05
     +,   2.7700895E-05,   2.8167880E-05,   2.8627945E-05
     +,   2.9081346E-05,   2.9528457E-05,   2.9969800E-05
     +,   3.0406038E-05,   3.0837979E-05,   3.1266583E-05
     +,   3.1693002E-05,   3.2118507E-05,   3.2544584E-05
     +,   3.2972857E-05,   3.3405140E-05,   3.3843415E-05
     +,   3.4289849E-05,   3.4746739E-05,   3.5216584E-05
     +,   3.5702018E-05,   3.6205827E-05,   3.6730940E-05
     +,   3.7280388E-05,   3.7857328E-05,   3.8464997E-05
     +,   3.9106752E-05,   3.9785908E-05,   4.0505907E-05
     +,   4.1270123E-05,   4.2081960E-05,   4.2944725E-05
     +,   4.3861659E-05,   4.4835910E-05,   4.5870434E-05
     +,   4.6968049E-05,   4.8131355E-05,   4.9362654E-05
     +,   5.0664024E-05,   5.2037194E-05,   5.3483487E-05
     +,   5.5003995E-05,   5.6599165E-05,   5.8269208E-05
     +,   6.0013725E-05,   6.1831881E-05,   6.3722277E-05
     +,   6.5683009E-05,   6.7711590E-05,   6.9805006E-05
     +,   7.1959570E-05,   7.4171126E-05,   7.6435048E-05
     +,   7.8745870E-05,   8.1097882E-05,   8.3484563E-05
     +,   8.5899243E-05,   8.8334426E-05,   9.0782516E-05
     +,   9.3235234E-05,   9.5684278E-05,   9.8120778E-05
     +,   1.0053580E-04,   1.0292032E-04,   1.0526498E-04
     +,   1.0756049E-04,   1.0979762E-04,   1.1196734E-04
     +,   1.1406052E-04,   1.1606858E-04,   1.1798295E-04
     +,   1.1979568E-04,   1.2149908E-04,   1.2308614E-04
     +,   1.2455021E-04,   1.2588546E-04,   1.2708653E-04
     +,   1.2814891E-04,   1.2906879E-04,   1.2984307E-04
     +,   1.3046949E-04,   1.3094663E-04,   1.3127383E-04
     +,   1.3145131E-04,   1.3147997E-04,   1.3136170E-04
     +,   1.3109898E-04,   1.3069516E-04,   1.3015419E-04
     +,   1.2948079E-04,   1.2868023E-04,   1.2775838E-04
     +,   1.2672158E-04,   1.2557661E-04,   1.2433072E-04
     +,   1.2299139E-04,   1.2156639E-04,   1.2006361E-04
     +,   1.1849112E-04,   1.1685698E-04,   1.1516932E-04
     +,   1.1343601E-04,   1.1166497E-04,   1.0986369E-04
     +,   1.0803962E-04,   1.0619968E-04,   1.0435064E-04
     +,   1.0249870E-04,   1.0064961E-04,   9.8808778E-05
     +,   9.6981137E-05,   9.5170966E-05,   9.3382012E-05
     +,   9.1617701E-05,   8.9880690E-05,   8.8173329E-05
     +,   8.6497232E-05,   8.4853767E-05,   8.3243569E-05
     +,   8.1667102E-05,   8.0124169E-05,   7.8614408E-05
     +,   7.7136967E-05,   7.5690754E-05,   7.4274496E-05
     +,   7.2886767E-05,   7.1525872E-05,   7.0190101E-05
     +,   6.8877795E-05,   6.7587389E-05,   6.6317312E-05
     +,   6.5066219E-05,   6.3833118E-05,   6.2617255E-05
     +,   6.1418235E-05,   6.0236238E-05,   5.9071946E-05
     +,   5.7926591E-05,   5.6802055E-05,   5.5701010E-05
     +,   5.4626915E-05,   5.3584019E-05,   5.2577434E-05
     +,   5.1613322E-05,   5.0698800E-05,   4.9841976E-05
     +,   4.9052029E-05,   4.8339327E-05,   4.7715326E-05
     +,   4.7192614E-05,   4.6785077E-05,   4.6507783E-05
     +,   4.6377045E-05,   4.6410478E-05,   4.6626999E-05
     +,   4.7046877E-05,   4.7691716E-05,   4.8584589E-05
     +,   4.9749906E-05,   5.1213483E-05,   5.3002666E-05
     +,   5.5146276E-05,   5.7674348E-05,   6.0618473E-05
     +,   6.4011634E-05,   6.7887733E-05,   7.2281662E-05
     +,   7.7229313E-05,   8.2767270E-05,   8.8931716E-05
     +,   9.5758514E-05,   1.0328308E-04,   1.1153935E-04
     +,   1.2055848E-04,   1.3036838E-04,   1.4099354E-04
     +,   1.5245346E-04,   1.6476031E-04,   1.7792010E-04
     +,   1.9193043E-04,   2.0677835E-04,   2.2243992E-04
     +,   2.3888050E-04,   2.5605276E-04,   2.7389449E-04
     +,   2.9232938E-04,   3.1126768E-04,   3.3060519E-04
     +,   3.5022205E-04,   3.6998442E-04,   3.8974703E-04
     +,   4.0935315E-04,   4.2863391E-04,   4.4741493E-04
     +,   4.6551603E-04,   4.8275289E-04,   4.9894169E-04
     +,   5.1390257E-04,   5.2746187E-04,   5.3945498E-04
     +,   5.4972962E-04,   5.5815076E-04,   5.6460127E-04
     +,   5.6898507E-04,   5.7122979E-04,   5.7128799E-04
     +,   5.6913885E-04,   5.6478824E-04,   5.5826938E-04
     +,   5.4964208E-04,   5.3899188E-04,   5.2642886E-04
     +,   5.1208475E-04,   4.9611030E-04,   4.7867413E-04
     +,   4.5995874E-04,   4.4015556E-04,   4.1946257E-04
     +,   3.9808266E-04,   3.7621823E-04,   3.5406701E-04
     +,   3.3181999E-04,   3.0966112E-04,   2.8776019E-04
     +,   2.6627333E-04,   2.4534247E-04,   2.2509271E-04
     +,   2.0563032E-04,   1.8704367E-04,   1.6940446E-04
     +,   1.5276673E-04,   1.3716654E-04,   1.2262419E-04
     +,   1.0914624E-04,   9.6725853E-05,   8.5343563E-05
     +,   7.4969743E-05,   6.5567227E-05,   5.7090780E-05
     +,   4.9489849E-05,   4.2710410E-05,   3.6695736E-05
     +,   3.1387328E-05,   2.6726497E-05,   2.2655597E-05
     +,   1.9118401E-05,   1.6060629E-05,   1.3430746E-05
     +,   1.1180501E-05,   9.2649552E-06,   7.6425449E-06
     +,   6.2753370E-06,   5.1290913E-06,   4.1729190E-06
     +,   3.3793042E-06,   2.7239530E-06,   2.1855208E-06
     +,   1.7453588E-06,   1.3873325E-06,   1.0975903E-06
     +,   8.6429520E-07,   6.7738824E-07,   5.2839454E-07
     +,   4.1022921E-07,   3.1697860E-07,   2.4376487E-07
     +,   1.8656829E-07,   1.4211285E-07,   1.0773216E-07
     +,   8.1278777E-08,   6.1026235E-08,   4.5600299E-08
     +,   3.3909213E-08,   2.5094099E-08,   1.8480815E-08
     +,   1.3544348E-08,   9.8784154E-09,   7.1696276E-09
     +,   5.1783555E-09,   3.7218597E-09,   2.6619960E-09
     +,   1.8946180E-09,   1.3418660E-09,   9.4570785E-10
     +,   6.6324246E-10,   4.6285256E-10,   3.2142228E-10
     +,   2.2210488E-10,   1.5272075E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz120 = Yx/0.00852173913043478
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7190671E-11,   2.5345172E-11
     +,   3.7183260E-11,   5.4281406E-11,   7.8851183E-11
     +,   1.1397793E-10,   1.6394153E-10,   2.3464736E-10
     +,   3.3419453E-10,   4.7363830E-10,   6.6796935E-10
     +,   9.3741148E-10,   1.3090891E-09,   1.8191763E-09
     +,   2.5156366E-09,   3.4617058E-09,   4.7402602E-09
     +,   6.4592989E-09,   8.7587173E-09,   1.1818670E-08
     +,   1.5869761E-08,   2.1205409E-08,   2.8196554E-08
     +,   3.7309988E-08,   4.9127706E-08,   6.4373431E-08
     +,   8.3938936E-08,   1.0891745E-07,   1.4064007E-07
     +,   1.8071661E-07,   2.3108112E-07,   2.9404129E-07
     +,   3.7233113E-07,   4.6916662E-07,   5.8830386E-07
     +,   7.3409512E-07,   9.1154618E-07,   1.1263630E-06
     +,   1.3850188E-06,   1.6947416E-06,   2.0636003E-06
     +,   2.5004574E-06,   3.0149802E-06,   3.6175888E-06
     +,   4.3193932E-06,   5.1320853E-06,   6.0678017E-06
     +,   7.1389431E-06,   8.3579580E-06,   9.7370812E-06
     +,   1.1288032E-05,   1.3021679E-05,   1.4947642E-05
     +,   1.7074046E-05,   1.9406756E-05,   2.1949430E-05
     +,   2.4702720E-05,   2.7664049E-05,   3.0827221E-05
     +,   3.4182103E-05,   3.7714406E-05,   4.1405550E-05
     +,   4.5232318E-05,   4.9167440E-05,   5.3179465E-05
     +,   5.7232635E-05,   6.1288229E-05,   6.5304041E-05
     +,   6.9236092E-05,   7.3038340E-05,   7.6664575E-05
     +,   8.0068341E-05,   8.3204875E-05,   8.6031207E-05
     +,   8.8507957E-05,   9.0599962E-05,   9.2277209E-05
     +,   9.3516021E-05,   9.4300129E-05,   9.4621697E-05
     +,   9.4482581E-05,   9.3895935E-05,   9.2888346E-05
     +,   9.1502399E-05,   8.9800451E-05,   8.7868997E-05
     +,   8.5824962E-05,   8.3822299E-05,   8.2060615E-05
     +,   8.0793121E-05,   8.0334707E-05,   8.1067577E-05
     +,   8.3442297E-05,   8.7972592E-05,   9.5220705E-05
     +,   1.0577005E-04,   1.2018806E-04,   1.3897190E-04
     +,   1.6249168E-04,   1.9092095E-04,   2.2418320E-04
     +,   2.6189946E-04,   3.0337679E-04,   3.4761344E-04
     +,   3.9336018E-04,   4.3920722E-04,   4.8370025E-04
     +,   5.2547822E-04,   5.6340598E-04,   5.9667957E-04
     +,   6.2489306E-04,   6.4806879E-04,   6.6662685E-04
     +,   6.8133138E-04,   6.9320388E-04,   7.0344284E-04
     +,   7.1335293E-04,   7.2430668E-04,   7.3772547E-04
     +,   7.5508200E-04,   7.7788456E-04,   8.0761022E-04
     +,   8.4556016E-04,   8.9262315E-04,   9.4897102E-04
     +,   1.0137466E-03,   1.0848738E-03,   1.1590454E-03
     +,   1.2320179E-03,   1.2991390E-03,   1.3560801E-03
     +,   1.3995322E-03,   1.4277336E-03,   1.4406232E-03
     +,   1.4396368E-03,   1.4271985E-03,   1.4061289E-03
     +,   1.3791502E-03,   1.3486325E-03,   1.3165793E-03
     +,   1.2847494E-03,   1.2547461E-03,   1.2279649E-03
     +,   1.2053919E-03,   1.1873140E-03,   1.1730816E-03
     +,   1.1610531E-03,   1.1487682E-03,   1.1333303E-03
     +,   1.1119026E-03,   1.0822046E-03,   1.0428947E-03
     +,   9.9375856E-04,   9.3568093E-04,   8.7043463E-04
     +,   8.0035342E-04,   7.2795863E-04,   6.5562234E-04
     +,   5.8533892E-04,   5.1861466E-04,   4.5644364E-04
     +,   3.9938214E-04,   3.4765413E-04,   3.0125168E-04
     +,   2.6001743E-04,   2.2370589E-04,   1.9201764E-04
     +,   1.6461236E-04,   1.4111659E-04,   1.2113423E-04
     +,   1.0425784E-04,   9.0079506E-05,   7.8203797E-05
     +,   6.8261448E-05,   5.9919814E-05,   5.2887430E-05
     +,   4.6917910E-05,   4.1809948E-05,   3.7403850E-05
     +,   3.3576638E-05,   3.0236568E-05,   2.7317021E-05
     +,   2.4770119E-05,   2.2560986E-05,   2.0663283E-05
     +,   1.9055584E-05,   1.7718483E-05,   1.6632805E-05
     +,   1.5778765E-05,   1.5135681E-05,   1.4681909E-05
     +,   1.4395338E-05,   1.4253882E-05,   1.4235957E-05
     +,   1.4320985E-05,   1.4489763E-05,   1.4724714E-05
     +,   1.5010034E-05,   1.5331760E-05,   1.5677715E-05
     +,   1.6037386E-05,   1.6401784E-05,   1.6763328E-05
     +,   1.7115632E-05,   1.7453309E-05,   1.7771885E-05
     +,   1.8067631E-05,   1.8337412E-05,   1.8578638E-05
     +,   1.8789178E-05,   1.8967294E-05,   1.9111571E-05
     +,   1.9220912E-05,   1.9294510E-05,   1.9331819E-05
     +,   1.9332532E-05,   1.9296594E-05,   1.9224170E-05
     +,   1.9115645E-05,   1.8971623E-05,   1.8792909E-05
     +,   1.8580491E-05,   1.8335553E-05,   1.8059458E-05
     +,   1.7753706E-05,   1.7419945E-05,   1.7059963E-05
     +,   1.6675669E-05,   1.6269047E-05,   1.5842152E-05
     +,   1.5397130E-05,   1.4936177E-05,   1.4461480E-05
     +,   1.3975234E-05,   1.3479679E-05,   1.2976981E-05
     +,   1.2469264E-05,   1.1958631E-05,   1.1447123E-05
     +,   1.0936665E-05,   1.0429088E-05,   9.9261615E-06
     +,   9.4295438E-06,   8.9407422E-06,   8.4611502E-06
     +,   7.9920601E-06,   7.5346388E-06,   7.0898941E-06
     +,   6.6587058E-06,   6.2418662E-06,   5.8399974E-06
     +,   5.4536017E-06,   5.0830904E-06,   4.7287544E-06
     +,   4.3907576E-06,   4.0691580E-06,   3.7639450E-06
     +,   3.4750146E-06,   3.2021653E-06,   2.9451210E-06
     +,   2.7035608E-06,   2.4771027E-06,   2.2652987E-06
     +,   2.0676605E-06,   1.8836834E-06,   1.7128142E-06
     +,   1.5544787E-06,   1.4080974E-06,   1.2730802E-06
     +,   1.1488216E-06,   1.0347167E-06,   9.3017314E-07
     +,   8.3460554E-07,   7.4743338E-07,   6.6809088E-07
     +,   5.9603786E-07,   5.3074297E-07,   4.7170425E-07
     +,   4.1843427E-07,   3.7047596E-07,   3.2738933E-07
     +,   2.8876497E-07,   2.5421221E-07,   2.2336937E-07
     +,   1.9589453E-07,   1.7147342E-07,   1.4981144E-07
     +,   1.3063652E-07,   1.1369978E-07,   9.8770336E-08
     +,   8.5638518E-08,   7.4111071E-08,   6.4013669E-08
     +,   5.5186604E-08,   4.7486566E-08,   4.0782979E-08
     +,   3.4959314E-08,   2.9910144E-08,   2.5541702E-08
     +,   2.1769701E-08,   1.8519577E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz75 = Yx/0.0147777777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2234096E-08,   1.5068457E-08
     +,   1.8506155E-08,   2.2662812E-08,   2.7673329E-08
     +,   3.3694548E-08,   4.0907988E-08,   4.9522985E-08
     +,   5.9779779E-08,   7.1953792E-08,   8.6358142E-08
     +,   1.0334831E-07,   1.2332566E-07,   1.4674191E-07
     +,   1.7410251E-07,   2.0597098E-07,   2.4297279E-07
     +,   2.8579802E-07,   3.3520578E-07,   3.9202513E-07
     +,   4.5715873E-07,   5.3158215E-07,   6.1634398E-07
     +,   7.1257125E-07,   8.2145203E-07,   9.4425189E-07
     +,   1.0822912E-06,   1.2369475E-06,   1.4096436E-06
     +,   1.6018381E-06,   1.8150110E-06,   2.0506502E-06
     +,   2.3102339E-06,   2.5952111E-06,   2.9069815E-06
     +,   3.2468729E-06,   3.6161184E-06,   4.0158207E-06
     +,   4.4469639E-06,   4.9103101E-06,   5.4064722E-06
     +,   5.9358103E-06,   6.4984392E-06,   7.0942083E-06
     +,   7.7226741E-06,   8.3830910E-06,   9.0743961E-06
     +,   9.7952043E-06,   1.0543817E-05,   1.1318209E-05
     +,   1.2116065E-05,   1.2934783E-05,   1.3771504E-05
     +,   1.4623202E-05,   1.5486594E-05,   1.6358370E-05
     +,   1.7235117E-05,   1.8113431E-05,   1.8989997E-05
     +,   1.9861638E-05,   2.0725416E-05,   2.1578695E-05
     +,   2.2419157E-05,   2.3244984E-05,   2.4054847E-05
     +,   2.4847870E-05,   2.5623858E-05,   2.6383083E-05
     +,   2.7126505E-05,   2.7855534E-05,   2.8572184E-05
     +,   2.9278819E-05,   2.9978230E-05,   3.0673371E-05
     +,   3.1367330E-05,   3.2063184E-05,   3.2763724E-05
     +,   3.3471370E-05,   3.4188033E-05,   3.4914905E-05
     +,   3.5652254E-05,   3.6399473E-05,   3.7154816E-05
     +,   3.7915590E-05,   3.8678048E-05,   3.9437757E-05
     +,   4.0189767E-05,   4.0929302E-05,   4.1652303E-05
     +,   4.2356627E-05,   4.3043263E-05,   4.3717995E-05
     +,   4.4393510E-05,   4.5091936E-05,   4.5847708E-05
     +,   4.6710833E-05,   4.7750698E-05,   4.9059767E-05
     +,   5.0757797E-05,   5.2995310E-05,   5.5957331E-05
     +,   5.9865077E-05,   6.4977408E-05,   7.1587907E-05
     +,   8.0020669E-05,   9.0620022E-05,   1.0373406E-04
     +,   1.1969247E-04,   1.3877875E-04,   1.6119401E-04
     +,   1.8701467E-04,   2.1615696E-04,   2.4833335E-04
     +,   2.8303303E-04,   3.1950287E-04,   3.5676762E-04
     +,   3.9365806E-04,   4.2888525E-04,   4.6112089E-04
     +,   4.8911286E-04,   5.1179668E-04,   5.2840257E-04
     +,   5.3854601E-04,   5.4228108E-04,   5.4011086E-04
     +,   5.3296419E-04,   5.2214880E-04,   5.0931622E-04
     +,   4.9645820E-04,   4.8596080E-04,   4.8068227E-04
     +,   4.8398884E-04,   4.9963745E-04,   5.3139892E-04
     +,   5.8240251E-04,   6.5430289E-04,   7.4650889E-04
     +,   8.5582037E-04,   9.7671326E-04,   1.1022879E-03
     +,   1.2256220E-03,   1.3410861E-03,   1.4451022E-03
     +,   1.5360501E-03,   1.6134081E-03,   1.6765437E-03
     +,   1.7236673E-03,   1.7514763E-03,   1.7557185E-03
     +,   1.7325094E-03,   1.6799452E-03,   1.5993896E-03
     +,   1.4958814E-03,   1.3774260E-03,   1.2533921E-03
     +,   1.1325463E-03,   1.0213598E-03,   9.2310406E-04
     +,   8.3792699E-04,   7.6369208E-04,   6.9716212E-04
     +,   6.3515315E-04,   5.7532452E-04,   5.1650865E-04
     +,   4.5864817E-04,   4.0249305E-04,   3.4920932E-04
     +,   3.0001329E-04,   2.5590486E-04,   2.1752543E-04
     +,   1.8511643E-04,   1.5854686E-04,   1.3738644E-04
     +,   1.2099959E-04,   1.0863664E-04,   9.9510042E-05
     +,   9.2859511E-05,   8.7997498E-05,   8.4336905E-05
     +,   8.1404010E-05,   7.8839104E-05,   7.6387521E-05
     +,   7.3884505E-05,   7.1237308E-05,   6.8407571E-05
     +,   6.5395216E-05,   6.2224855E-05,   5.8934755E-05
     +,   5.5569286E-05,   5.2173727E-05,   4.8790065E-05
     +,   4.5455268E-05,   4.2200427E-05,   3.9050326E-05
     +,   3.6023455E-05,   3.3132845E-05,   3.0386964E-05
     +,   2.7790371E-05,   2.5344354E-05,   2.3047913E-05
     +,   2.0898528E-05,   1.8892548E-05,   1.7025495E-05
     +,   1.5292511E-05,   1.3688707E-05,   1.2208950E-05
     +,   1.0848088E-05,   9.6010517E-06,   8.4627154E-06
     +,   7.4278159E-06,   6.4910155E-06,   5.6469335E-06
     +,   4.8900752E-06,   4.2147967E-06,   3.6153999E-06
     +,   3.0862011E-06,   2.6215296E-06,   2.2157551E-06
     +,   1.8633846E-06,   1.5591394E-06,   1.2979335E-06
     +,   1.0749562E-06,   8.8571261E-07,   7.2602882E-07
     +,   5.9205843E-07,   4.8030495E-07,   3.8762340E-07
     +,   3.1120260E-07,   2.4854867E-07,   1.9747381E-07
     +,   1.5607691E-07,   1.2271600E-07,   9.5982706E-08
     +,   7.4680898E-08,   5.7803980E-08,   4.4507555E-08
     +,   3.4090473E-08,   2.5975213E-08,   1.9688660E-08
     +,   1.4845675E-08,   1.1135405E-08,   8.3088088E-09
     +,   6.1673986E-09,   4.5539883E-09,   3.3450571E-09
     +,   2.4442284E-09,   1.7766864E-09,   1.2847137E-09
     +,   9.2410996E-10,   6.6125966E-10,   4.7070264E-10
     +,   3.3330574E-10,   2.3478222E-10,   1.6452033E-10
     +,   1.1468307E-10,   7.9524519E-11,   5.4856612E-11
     +,   3.7643368E-11,   2.5696511E-11,   1.7449407E-11
     +,   1.1787283E-11,   7.9209755E-12,   5.2950530E-12
     +,   3.5211356E-12,   2.3293045E-12,   1.5328430E-12
     +,   1.0034317E-12,   6.5343878E-13,   4.2330641E-13
     +,   2.7279155E-13,   1.7487487E-13,   1.1151908E-13
     +,   7.0746455E-14,   4.4646470E-14,   2.8027754E-14
     +,   1.7503429E-14,   1.0873683E-14,   6.7199287E-15
     +,   4.1311457E-15,   2.5264511E-15,   1.5369862E-15
     +,   9.3017071E-16,   5.5998418E-16,   3.3536734E-16
     +,   1.9979496E-16,   1.1840871E-16,   6.9808459E-17
     +,   4.0940315E-17,   2.3885193E-17,   1.3862000E-17
     +,   8.0030560E-18,   4.5962593E-18,   2.6259572E-18
     +,   1.4924147E-18,   8.4377174E-19,   4.7454695E-19
     +,   2.6550153E-19,   1.4776595E-19,   8.1811697E-20
     +,   4.5058334E-20,   2.4687012E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz80 = Yx/0.01232
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7630697E-07,   2.0552382E-07
     +,   2.3902868E-07,   2.7735484E-07,   3.2108645E-07
     +,   3.7086113E-07,   4.2737258E-07,   4.9137259E-07
     +,   5.6367213E-07,   6.4514722E-07,   7.3673351E-07
     +,   8.3943121E-07,   9.5430437E-07,   1.0824808E-06
     +,   1.2251504E-06,   1.3835636E-06,   1.5590306E-06
     +,   1.7529136E-06,   1.9666290E-06,   2.2016379E-06
     +,   2.4594435E-06,   2.7415813E-06,   3.0496092E-06
     +,   3.3851254E-06,   3.7496995E-06,   4.1449398E-06
     +,   4.5724219E-06,   5.0337057E-06,   5.5303167E-06
     +,   6.0637340E-06,   6.6353814E-06,   7.2466055E-06
     +,   7.8986732E-06,   8.5927486E-06,   9.3298859E-06
     +,   1.0111012E-05,   1.0936913E-05,   1.1808207E-05
     +,   1.2725412E-05,   1.3688754E-05,   1.4698381E-05
     +,   1.5754187E-05,   1.6855865E-05,   1.8002898E-05
     +,   1.9194546E-05,   2.0429843E-05,   2.1707598E-05
     +,   2.3026398E-05,   2.4384593E-05,   2.5780333E-05
     +,   2.7211549E-05,   2.8675968E-05,   3.0171124E-05
     +,   3.1694472E-05,   3.3243148E-05,   3.4814344E-05
     +,   3.6405047E-05,   3.8012207E-05,   3.9632727E-05
     +,   4.1263484E-05,   4.2901389E-05,   4.4543427E-05
     +,   4.6186527E-05,   4.7827863E-05,   4.9464736E-05
     +,   5.1094394E-05,   5.2714469E-05,   5.4322514E-05
     +,   5.5916458E-05,   5.7494155E-05,   5.9053767E-05
     +,   6.0593375E-05,   6.2111299E-05,   6.3605694E-05
     +,   6.5074819E-05,   6.6516848E-05,   6.7929730E-05
     +,   6.9311187E-05,   7.0658789E-05,   7.1969742E-05
     +,   7.3240779E-05,   7.4468320E-05,   7.5648168E-05
     +,   7.6775774E-05,   7.7845900E-05,   7.8852929E-05
     +,   7.9790610E-05,   8.0652302E-05,   8.1430910E-05
     +,   8.2119004E-05,   8.2708888E-05,   8.3192754E-05
     +,   8.3562751E-05,   8.3811246E-05,   8.3930878E-05
     +,   8.3914791E-05,   8.3756844E-05,   8.3451821E-05
     +,   8.2995561E-05,   8.2385319E-05,   8.1619823E-05
     +,   8.0699734E-05,   7.9627578E-05,   7.8408309E-05
     +,   7.7049248E-05,   7.5560383E-05,   7.3954689E-05
     +,   7.2248149E-05,   7.0459799E-05,   6.8611807E-05
     +,   6.6729626E-05,   6.4841399E-05,   6.2978135E-05
     +,   6.1172730E-05,   5.9459810E-05,   5.7874418E-05
     +,   5.6451401E-05,   5.5223798E-05,   5.4221895E-05
     +,   5.3471500E-05,   5.2992760E-05,   5.2798929E-05
     +,   5.2895477E-05,   5.3279695E-05,   5.3941170E-05
     +,   5.4863045E-05,   5.6024739E-05,   5.7405683E-05
     +,   5.8991238E-05,   6.0779465E-05,   6.2790161E-05
     +,   6.5074310E-05,   6.7725101E-05,   7.0887727E-05
     +,   7.4769210E-05,   7.9645288E-05,   8.5863387E-05
     +,   9.3841336E-05,   1.0406090E-04,   1.1705385E-04
     +,   1.3338050E-04,   1.5360303E-04,   1.7825383E-04
     +,   2.0779730E-04,   2.4258516E-04,   2.8282055E-04
     +,   3.2851531E-04,   3.7945170E-04,   4.3515785E-04
     +,   4.9489830E-04,   5.5767439E-04,   6.2224182E-04
     +,   6.8715785E-04,   7.5084751E-04,   8.1167638E-04
     +,   8.6803187E-04,   9.1841223E-04,   9.6150476E-04
     +,   9.9624076E-04,   1.0218293E-03,   1.0377815E-03
     +,   1.0438990E-03,   1.0402568E-03,   1.0271781E-03
     +,   1.0052011E-03,   9.7504945E-04,   9.3760743E-04
     +,   8.9388952E-04,   8.4500865E-04,   7.9214270E-04
     +,   7.3650148E-04,   6.7927927E-04,   6.2161050E-04
     +,   5.6453416E-04,   5.0896924E-04,   4.5568540E-04
     +,   4.0530058E-04,   3.5828835E-04,   3.1498526E-04
     +,   2.7560387E-04,   2.4025298E-04,   2.0895430E-04
     +,   1.8165165E-04,   1.5821855E-04,   1.3846792E-04
     +,   1.2215982E-04,   1.0900749E-04,   9.8686120E-05
     +,   9.0845460E-05,   8.5122832E-05,   8.1154583E-05
     +,   7.8589408E-05,   7.7098935E-05,   7.6385557E-05
     +,   7.6187862E-05,   7.6283381E-05,   7.6488694E-05
     +,   7.6657525E-05,   7.6677774E-05,   7.6467542E-05
     +,   7.5970951E-05,   7.5154116E-05,   7.4001175E-05
     +,   7.2511029E-05,   7.0694470E-05,   6.8571433E-05
     +,   6.6168970E-05,   6.3519597E-05,   6.0659582E-05
     +,   5.7627400E-05,   5.4462645E-05,   5.1205185E-05
     +,   4.7894075E-05,   4.4566463E-05,   4.1257153E-05
     +,   3.7998267E-05,   3.4818575E-05,   3.1742995E-05
     +,   2.8792636E-05,   2.5985009E-05,   2.3333478E-05
     +,   2.0847705E-05,   1.8534010E-05,   1.6395454E-05
     +,   1.4432035E-05,   1.2641204E-05,   1.1018356E-05
     +,   9.5570331E-06,   8.2492379E-06,   7.0859078E-06
     +,   6.0572852E-06,   5.1531397E-06,   4.3629757E-06
     +,   3.6763402E-06,   3.0830638E-06,   2.5732861E-06
     +,   2.1376482E-06,   1.7674034E-06,   1.4544381E-06
     +,   1.1912903E-06,   9.7119187E-07,   7.8806983E-07
     +,   6.3650867E-07,   5.1171025E-07,   4.0947219E-07
     +,   3.2614545E-07,   2.5857722E-07,   2.0406092E-07
     +,   1.6029439E-07,   1.2533525E-07,   9.7548778E-08
     +,   7.5571933E-08,   5.8276378E-08,   4.4732271E-08
     +,   3.4177575E-08,   2.5992493E-08,   1.9676268E-08
     +,   1.4826129E-08,   1.1119801E-08,   8.3012583E-09
     +,   6.1683534E-09,   4.5621977E-09,   3.3585486E-09
     +,   2.4608964E-09,   1.7947556E-09,   1.3028045E-09
     +,   9.4125285E-10,   6.7684292E-10,   4.8442322E-10
     +,   3.4507111E-10,   2.4464195E-10,   1.7262010E-10
     +,   1.2122531E-10,   8.4727877E-11,   5.8936259E-11
     +,   4.0800703E-11,   2.8110519E-11,   1.9274948E-11
     +,   1.3153052E-11,   8.9325439E-12,   6.0370732E-12
     +,   4.0605878E-12,   2.7179819E-12,   1.8105466E-12
     +,   1.2002246E-12,   7.9180190E-13,   5.1982957E-13
     +,   3.3961703E-13,   2.2080542E-13,   1.4285970E-13
     +,   9.1981212E-14,   5.8933584E-14,   3.7576150E-14
     +,   2.3841494E-14,   1.5053464E-14,   9.4581757E-15
     +,   5.9137045E-15,   3.6793947E-15,   2.2780833E-15
     +,   1.4035485E-15,   8.6051909E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz85 = Yx/0.00821739130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5646922E-06,   8.0834825E-06
     +,   8.6244791E-06,   9.1874590E-06,   9.7720776E-06
     +,   1.0377872E-05,   1.1004255E-05,   1.1650503E-05
     +,   1.2315760E-05,   1.2999052E-05,   1.3699248E-05
     +,   1.4415085E-05,   1.5145169E-05,   1.5887965E-05
     +,   1.6641810E-05,   1.7404916E-05,   1.8175366E-05
     +,   1.8951134E-05,   1.9730083E-05,   2.0509979E-05
     +,   2.1288486E-05,   2.2063210E-05,   2.2831657E-05
     +,   2.3591341E-05,   2.4339639E-05,   2.5073994E-05
     +,   2.5791793E-05,   2.6490419E-05,   2.7167298E-05
     +,   2.7819879E-05,   2.8445667E-05,   2.9042234E-05
     +,   2.9607238E-05,   3.0138441E-05,   3.0633717E-05
     +,   3.1091080E-05,   3.1508684E-05,   3.1884829E-05
     +,   3.2218039E-05,   3.2506952E-05,   3.2750460E-05
     +,   3.2947624E-05,   3.3097731E-05,   3.3200282E-05
     +,   3.3255015E-05,   3.3261869E-05,   3.3221029E-05
     +,   3.3132910E-05,   3.2998149E-05,   3.2817599E-05
     +,   3.2592347E-05,   3.2323682E-05,   3.2013111E-05
     +,   3.1662305E-05,   3.1273179E-05,   3.0847761E-05
     +,   3.0388272E-05,   2.9897077E-05,   2.9376673E-05
     +,   2.8829669E-05,   2.8258781E-05,   2.7666796E-05
     +,   2.7056612E-05,   2.6431120E-05,   2.5793252E-05
     +,   2.5146008E-05,   2.4492309E-05,   2.3835131E-05
     +,   2.3177348E-05,   2.2521855E-05,   2.1871390E-05
     +,   2.1228705E-05,   2.0596364E-05,   1.9976913E-05
     +,   1.9372706E-05,   1.8785977E-05,   1.8218838E-05
     +,   1.7673270E-05,   1.7151047E-05,   1.6653774E-05
     +,   1.6182948E-05,   1.5739812E-05,   1.5325495E-05
     +,   1.4940888E-05,   1.4586749E-05,   1.4263605E-05
     +,   1.3971850E-05,   1.3711643E-05,   1.3483014E-05
     +,   1.3285789E-05,   1.3119625E-05,   1.2984028E-05
     +,   1.2878345E-05,   1.2801758E-05,   1.2753311E-05
     +,   1.2731918E-05,   1.2736356E-05,   1.2765292E-05
     +,   1.2817278E-05,   1.2890765E-05,   1.2984126E-05
     +,   1.3095639E-05,   1.3223535E-05,   1.3365967E-05
     +,   1.3521053E-05,   1.3686887E-05,   1.3861518E-05
     +,   1.4042988E-05,   1.4229346E-05,   1.4418655E-05
     +,   1.4608971E-05,   1.4798416E-05,   1.4985118E-05
     +,   1.5167286E-05,   1.5343165E-05,   1.5511094E-05
     +,   1.5669475E-05,   1.5816835E-05,   1.5951795E-05
     +,   1.6073138E-05,   1.6179834E-05,   1.6271091E-05
     +,   1.6346463E-05,   1.6405975E-05,   1.6450325E-05
     +,   1.6481166E-05,   1.6501481E-05,   1.6516098E-05
     +,   1.6532360E-05,   1.6560900E-05,   1.6616601E-05
     +,   1.6719594E-05,   1.6896311E-05,   1.7180406E-05
     +,   1.7613535E-05,   1.8245759E-05,   1.9135587E-05
     +,   2.0349733E-05,   2.1962915E-05,   2.4057956E-05
     +,   2.6726737E-05,   3.0073252E-05,   3.4219436E-05
     +,   3.9313727E-05,   4.5542016E-05,   5.3142077E-05
     +,   6.2416271E-05,   7.3739873E-05,   8.7561704E-05
     +,   1.0439146E-04,   1.2476649E-04,   1.4919601E-04
     +,   1.7808811E-04,   2.1167115E-04,   2.4992789E-04
     +,   2.9258305E-04,   3.3919985E-04,   3.8943146E-04
     +,   4.4344849E-04,   5.0252106E-04,   5.6967948E-04
     +,   6.5022649E-04,   7.5185503E-04,   8.8409806E-04
     +,   1.0569276E-03,   1.2785028E-03,   1.5523942E-03
     +,   1.8749412E-03,   2.2335507E-03,   2.6065877E-03
     +,   2.9652708E-03,   3.2774347E-03,   3.5124032E-03
     +,   3.6458082E-03,   3.6634312E-03,   3.5632870E-03
     +,   3.3556097E-03,   3.0609742E-03,   2.7070066E-03
     +,   2.3242629E-03,   1.9421231E-03,   1.5853285E-03
     +,   1.2716260E-03,   1.0108652E-03,   8.0554088E-04
     +,   6.5233919E-04,   5.4417009E-04,   4.7220584E-04
     +,   4.2754743E-04,   4.0231043E-04,   3.9014299E-04
     +,   3.8631755E-04,   3.8753109E-04,   3.9157583E-04
     +,   3.9699432E-04,   4.0278534E-04,   4.0819569E-04
     +,   4.1260058E-04,   4.1545628E-04,   4.1630128E-04
     +,   4.1477825E-04,   4.1066116E-04,   4.0386914E-04
     +,   3.9446543E-04,   3.8264276E-04,   3.6869422E-04
     +,   3.5298133E-04,   3.3590230E-04,   3.1786141E-04
     +,   2.9924343E-04,   2.8039727E-04,   2.6162609E-04
     +,   2.4318084E-04,   2.2525847E-04,   2.0800601E-04
     +,   1.9152694E-04,   1.7588655E-04,   1.6111799E-04
     +,   1.4723021E-04,   1.3421566E-04,   1.2205276E-04
     +,   1.1071201E-04,   1.0015996E-04,   9.0360867E-05
     +,   8.1278027E-05,   7.2875584E-05,   6.5119668E-05
     +,   5.7978017E-05,   5.1419571E-05,   4.5414865E-05
     +,   3.9936112E-05,   3.4956360E-05,   3.0448948E-05
     +,   2.6387594E-05,   2.2746492E-05,   1.9499386E-05
     +,   1.6619902E-05,   1.4081757E-05,   1.1858562E-05
     +,   9.9238778E-06,   8.2515980E-06,   6.8162644E-06
     +,   5.5931623E-06,   4.5584970E-06,   3.6897356E-06
     +,   2.9658190E-06,   2.3672385E-06,   1.8761031E-06
     +,   1.4762574E-06,   1.1533075E-06,   8.9451117E-07
     +,   6.8875664E-07,   5.2647476E-07,   3.9949879E-07
     +,   3.0093190E-07,   2.2502236E-07,   1.6702732E-07
     +,   1.2307068E-07,   9.0016243E-08,   6.5355273E-08
     +,   4.7101889E-08,   3.3697635E-08,   2.3931003E-08
     +,   1.6870226E-08,   1.1805732E-08,   8.2011873E-09
     +,   5.6555352E-09,   3.8716581E-09,   2.6312563E-09
     +,   1.7753292E-09,   1.1892055E-09,   7.9090312E-10
     +,   5.2229160E-10,   3.4249667E-10,   2.2304628E-10
     +,   1.4427907E-10,   9.2715183E-11,   5.9205120E-11
     +,   3.7580095E-11,   2.3721887E-11,   1.4899481E-11
     +,   9.3189675E-12,   5.8097767E-12,   3.6151251E-12
     +,   2.2488999E-12,   1.4016014E-12,   8.7738833E-13
     +,   5.5331916E-13,   3.5273282E-13,   2.2808662E-13
     +,   1.5009074E-13,   1.0076490E-13,   6.9123160E-14
     +,   4.8457644E-14,   3.4677451E-14,   2.5277120E-14
     +,   1.8715320E-14,   1.4032636E-14,   1.0624427E-14
     +,   8.1017770E-15,   6.2093326E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz90 = Yx/0.01675
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0440573E-06,   4.4412909E-06
     +,   4.8697898E-06,   5.3311433E-06,   5.8269270E-06
     +,   6.3586931E-06,   6.9279545E-06,   7.5361681E-06
     +,   8.1847165E-06,   8.8749293E-06,   9.6080003E-06
     +,   1.0385023E-05,   1.1206949E-05,   1.2074574E-05
     +,   1.2988527E-05,   1.3949238E-05,   1.4956930E-05
     +,   1.6011600E-05,   1.7112990E-05,   1.8260585E-05
     +,   1.9453590E-05,   2.0690910E-05,   2.1971127E-05
     +,   2.3292587E-05,   2.4653162E-05,   2.6050539E-05
     +,   2.7481970E-05,   2.8944414E-05,   3.0434465E-05
     +,   3.1948395E-05,   3.3482163E-05,   3.5031397E-05
     +,   3.6591438E-05,   3.8157352E-05,   3.9723942E-05
     +,   4.1285792E-05,   4.2837273E-05,   4.4372580E-05
     +,   4.5885874E-05,   4.7371050E-05,   4.8822127E-05
     +,   5.0233008E-05,   5.1597686E-05,   5.2910214E-05
     +,   5.4164793E-05,   5.5355780E-05,   5.6477787E-05
     +,   5.7525693E-05,   5.8494672E-05,   5.9380265E-05
     +,   6.0178445E-05,   6.0885573E-05,   6.1498504E-05
     +,   6.2014595E-05,   6.2431711E-05,   6.2748280E-05
     +,   6.2963292E-05,   6.3076273E-05,   6.3087355E-05
     +,   6.2997249E-05,   6.2807194E-05,   6.2519022E-05
     +,   6.2135106E-05,   6.1658291E-05,   6.1091938E-05
     +,   6.0439892E-05,   5.9706352E-05,   5.8895985E-05
     +,   5.8013713E-05,   5.7064826E-05,   5.6054781E-05
     +,   5.4989345E-05,   5.3874297E-05,   5.2715666E-05
     +,   5.1519426E-05,   5.0291532E-05,   4.9037997E-05
     +,   4.7764734E-05,   4.6477449E-05,   4.5181660E-05
     +,   4.3882828E-05,   4.2585983E-05,   4.1296054E-05
     +,   4.0017523E-05,   3.8754701E-05,   3.7511400E-05
     +,   3.6291258E-05,   3.5097364E-05,   3.3932640E-05
     +,   3.2799486E-05,   3.1699965E-05,   3.0635842E-05
     +,   2.9608524E-05,   2.8619019E-05,   2.7668009E-05
     +,   2.6755957E-05,   2.5882911E-05,   2.5048768E-05
     +,   2.4253057E-05,   2.3495188E-05,   2.2774264E-05
     +,   2.2089302E-05,   2.1439057E-05,   2.0822246E-05
     +,   2.0237399E-05,   1.9682957E-05,   1.9157333E-05
     +,   1.8658875E-05,   1.8185870E-05,   1.7736593E-05
     +,   1.7309358E-05,   1.6902442E-05,   1.6514208E-05
     +,   1.6143003E-05,   1.5787276E-05,   1.5445490E-05
     +,   1.5116226E-05,   1.4798091E-05,   1.4489819E-05
     +,   1.4190192E-05,   1.3898086E-05,   1.3612479E-05
     +,   1.3332442E-05,   1.3057113E-05,   1.2785720E-05
     +,   1.2517607E-05,   1.2252158E-05,   1.1988882E-05
     +,   1.1727323E-05,   1.1467141E-05,   1.1208024E-05
     +,   1.0949767E-05,   1.0692185E-05,   1.0435191E-05
     +,   1.0178724E-05,   9.9227782E-06,   9.6674221E-06
     +,   9.4127918E-06,   9.1590891E-06,   8.9066571E-06
     +,   8.6560622E-06,   8.4082303E-06,   8.1646622E-06
     +,   7.9278598E-06,   7.7019531E-06,   7.4936352E-06
     +,   7.3135848E-06,   7.1785312E-06,   7.1140430E-06
     +,   7.1582940E-06,   7.3668994E-06,   7.8188168E-06
     +,   8.6232021E-06,   9.9271019E-06,   1.1923279E-05
     +,   1.4857313E-05,   1.9033383E-05,   2.4817946E-05
     +,   3.2639622E-05,   4.2984058E-05,   5.6387100E-05
     +,   7.3422503E-05,   9.4686671E-05,   1.2078557E-04
     +,   1.5232708E-04,   1.8991734E-04,   2.3416521E-04
     +,   2.8570124E-04,   3.4520708E-04,   4.1344008E-04
     +,   4.9124268E-04,   5.7952985E-04,   6.7923311E-04
     +,   7.9116609E-04,   9.1580977E-04,   1.0530663E-03
     +,   1.2019440E-03,   1.3602569E-03,   1.5244235E-03
     +,   1.6894222E-03,   1.8489320E-03,   1.9957034E-03
     +,   2.1221710E-03,   2.2211985E-03,   2.2868458E-03
     +,   2.3150544E-03,   2.3041465E-03,   2.2550223E-03
     +,   2.1710447E-03,   2.0576539E-03,   1.9217477E-03
     +,   1.7709673E-03,   1.6129916E-03,   1.4548993E-03
     +,   1.3026897E-03,   1.1610016E-03,   1.0330250E-03
     +,   9.2054310E-04,   8.2410220E-04,   7.4326602E-04
     +,   6.7688804E-04,   6.2336045E-04,   5.8082928E-04
     +,   5.4736354E-04,   5.2106922E-04,   5.0015119E-04
     +,   4.8295662E-04,   4.6799952E-04,   4.5397854E-04
     +,   4.3979840E-04,   4.2459241E-04,   4.0774394E-04
     +,   3.8889505E-04,   3.6794200E-04,   3.4501436E-04
     +,   3.2043937E-04,   2.9468964E-04,   2.6832419E-04
     +,   2.4193105E-04,   2.1607884E-04,   1.9126853E-04
     +,   1.6790810E-04,   1.4629839E-04,   1.2662834E-04
     +,   1.0898112E-04,   9.3350180E-05,   7.9658363E-05
     +,   6.7776389E-05,   5.7541274E-05,   4.8773949E-05
     +,   4.1293151E-05,   3.4924677E-05,   2.9507735E-05
     +,   2.4899291E-05,   2.0975751E-05,   1.7631726E-05
     +,   1.4779077E-05,   1.2344906E-05,   1.0268921E-05
     +,   8.5009997E-06,   6.9992670E-06,   5.7283687E-06
     +,   4.6579103E-06,   3.7613286E-06,   3.0152062E-06
     +,   2.3987525E-06,   1.8933803E-06,   1.4824481E-06
     +,   1.1511559E-06,   8.8644515E-07,   6.7684039E-07
     +,   5.1239226E-07,   3.8457870E-07,   2.8617319E-07
     +,   2.1112056E-07,   1.5441771E-07,   1.1198383E-07
     +,   8.0528054E-08,   5.7427766E-08,   4.0620886E-08
     +,   2.8506213E-08,   1.9853573E-08,   1.3728885E-08
     +,   9.4315666E-09,   6.4423928E-09,   4.3801656E-09
     +,   2.9684897E-09,   2.0091351E-09,   1.3613621E-09
     +,   9.2628438E-10,   6.3518374E-10,   4.4079437E-10
     +,   3.1090328E-10,   2.2376492E-10,   1.6483942E-10
     +,   1.2449014E-10,   9.6370849E-11,   7.6336798E-11
     +,   6.1689674E-11,   5.0681660E-11,   4.2178244E-11
     +,   3.5441972E-11,   2.9988220E-11,   2.5494747E-11
     +,   2.1741964E-11,   1.8576881E-11,   1.5888915E-11
     +,   1.3595453E-11,   1.1633042E-11,   9.9508995E-12
     +,   8.5078689E-12,   7.2695656E-12,   6.2071572E-12
     +,   5.2959629E-12,   4.5149557E-12,   3.8459561E-12
     +,   3.2733709E-12,   2.7836693E-12,   2.3652337E-12
     +,   2.0079756E-12,   1.7032355E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ttz95 = Yx/0.0142692307692308
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8886756E-05,   4.0529852E-05
     +,   4.2238411E-05,   4.4013821E-05,   4.5857265E-05
     +,   4.7769765E-05,   4.9752103E-05,   5.1804851E-05
     +,   5.3928237E-05,   5.6122364E-05,   5.8386860E-05
     +,   6.0721130E-05,   6.3124164E-05,   6.5594606E-05
     +,   6.8130736E-05,   7.0730406E-05,   7.3391093E-05
     +,   7.6109813E-05,   7.8883204E-05,   8.1707476E-05
     +,   8.4578402E-05,   8.7491324E-05,   9.0441201E-05
     +,   9.3422779E-05,   9.6429998E-05,   9.9456964E-05
     +,   1.0249713E-04,   1.0554377E-04,   1.0858986E-04
     +,   1.1162824E-04,   1.1465148E-04,   1.1765209E-04
     +,   1.2062246E-04,   1.2355496E-04,   1.2644194E-04
     +,   1.2927587E-04,   1.3204924E-04,   1.3475478E-04
     +,   1.3738548E-04,   1.3993442E-04,   1.4239516E-04
     +,   1.4476164E-04,   1.4702800E-04,   1.4918901E-04
     +,   1.5123989E-04,   1.5317631E-04,   1.5499452E-04
     +,   1.5669134E-04,   1.5826435E-04,   1.5971146E-04
     +,   1.6103136E-04,   1.6222344E-04,   1.6328755E-04
     +,   1.6422445E-04,   1.6503526E-04,   1.6572194E-04
     +,   1.6628702E-04,   1.6673365E-04,   1.6706552E-04
     +,   1.6728691E-04,   1.6740283E-04,   1.6741865E-04
     +,   1.6734037E-04,   1.6717432E-04,   1.6692758E-04
     +,   1.6660741E-04,   1.6622161E-04,   1.6577843E-04
     +,   1.6528649E-04,   1.6475465E-04,   1.6419218E-04
     +,   1.6360881E-04,   1.6301428E-04,   1.6241884E-04
     +,   1.6183293E-04,   1.6126718E-04,   1.6073242E-04
     +,   1.6023990E-04,   1.5980084E-04,   1.5942658E-04
     +,   1.5912889E-04,   1.5891936E-04,   1.5880990E-04
     +,   1.5881231E-04,   1.5893858E-04,   1.5920054E-04
     +,   1.5961012E-04,   1.6017903E-04,   1.6091893E-04
     +,   1.6184124E-04,   1.6295712E-04,   1.6427730E-04
     +,   1.6581218E-04,   1.6757147E-04,   1.6956448E-04
     +,   1.7179958E-04,   1.7428443E-04,   1.7702547E-04
     +,   1.8002839E-04,   1.8329736E-04,   1.8683537E-04
     +,   1.9064365E-04,   1.9472223E-04,   1.9906882E-04
     +,   2.0367968E-04,   2.0854903E-04,   2.1366887E-04
     +,   2.1902889E-04,   2.2461702E-04,   2.3041874E-04
     +,   2.3641708E-04,   2.4259347E-04,   2.4892637E-04
     +,   2.5539324E-04,   2.6196879E-04,   2.6862702E-04
     +,   2.7533952E-04,   2.8207793E-04,   2.8881215E-04
     +,   2.9551252E-04,   3.0214919E-04,   3.0869280E-04
     +,   3.1511474E-04,   3.2138851E-04,   3.2748986E-04
     +,   3.3339640E-04,   3.3908989E-04,   3.4455513E-04
     +,   3.4978177E-04,   3.5476373E-04,   3.5950085E-04
     +,   3.6399794E-04,   3.6826637E-04,   3.7232309E-04
     +,   3.7619181E-04,   3.7990272E-04,   3.8349142E-04
     +,   3.8700015E-04,   3.9047666E-04,   3.9397343E-04
     +,   3.9754735E-04,   4.0125818E-04,   4.0516839E-04
     +,   4.0934174E-04,   4.1384101E-04,   4.1872796E-04
     +,   4.2406132E-04,   4.2989483E-04,   4.3627660E-04
     +,   4.4324793E-04,   4.5084223E-04,   4.5908400E-04
     +,   4.6798875E-04,   4.7756470E-04,   4.8781303E-04
     +,   4.9873081E-04,   5.1031361E-04,   5.2256288E-04
     +,   5.3549203E-04,   5.4913381E-04,   5.6355546E-04
     +,   5.7886954E-04,   5.9525046E-04,   6.1295216E-04
     +,   6.3232676E-04,   6.5384078E-04,   6.7808764E-04
     +,   7.0579391E-04,   7.3781965E-04,   7.7513937E-04
     +,   8.1881025E-04,   8.6992583E-04,   9.2955917E-04
     +,   9.9869561E-04,   1.0781615E-03,   1.1685893E-03
     +,   1.2704018E-03,   1.3838301E-03,   1.5090024E-03
     +,   1.6460805E-03,   1.7954210E-03,   1.9577274E-03
     +,   2.1342097E-03,   2.3266750E-03,   2.5375071E-03
     +,   2.7695638E-03,   3.0260051E-03,   3.3100809E-03
     +,   3.6248919E-03,   3.9731539E-03,   4.3571559E-03
     +,   4.7787721E-03,   5.2397652E-03,   5.7425690E-03
     +,   6.2918430E-03,   6.8968036E-03,   7.5743124E-03
     +,   8.3518019E-03,   9.2680249E-03,   1.0369388E-02
     +,   1.1701645E-02,   1.3299841E-02,   1.5178875E-02
     +,   1.7324597E-02,   1.9687941E-02,   2.2197364E-02
     +,   2.4794485E-02,   2.7447646E-02,   3.0071324E-02
     +,   3.2411259E-02,   3.4127105E-02,   3.5144012E-02
     +,   3.5887737E-02,   3.7002284E-02,   3.8791578E-02
     +,   4.0981892E-02,   4.2930931E-02,   4.3982208E-02
     +,   4.3773778E-02,   4.2407587E-02,   4.0349983E-02
     +,   3.8127929E-02,   3.6085218E-02,   3.4325942E-02
     +,   3.2755420E-02,   3.1145010E-02,   2.9264085E-02
     +,   2.7055463E-02,   2.4687774E-02,   2.2413468E-02
     +,   2.0392068E-02,   1.8639762E-02,   1.7086316E-02
     +,   1.5646566E-02,   1.4265871E-02,   1.2936521E-02
     +,   1.1686311E-02,   1.0551005E-02,   9.5513221E-03
     +,   8.6868405E-03,   7.9423981E-03,   7.2973403E-03
     +,   6.7317029E-03,   6.2290845E-03,   5.7772901E-03
     +,   5.3677633E-03,   4.9945354E-03,   4.6532224E-03
     +,   4.3403972E-03,   4.0532639E-03,   3.7894431E-03
     +,   3.5468237E-03,   3.3234549E-03,   3.1174016E-03
     +,   2.9267203E-03,   2.7495394E-03,   2.5841708E-03
     +,   2.4291619E-03,   2.2833170E-03,   2.1456799E-03
     +,   2.0154819E-03,   1.8920697E-03,   1.7748658E-03
     +,   1.6633492E-03,   1.5570720E-03,   1.4556475E-03
     +,   1.3587730E-03,   1.2662362E-03,   1.1779023E-03
     +,   1.0936895E-03,   1.0135570E-03,   9.3748601E-04
     +,   8.6545578E-04,   7.9742825E-04,   7.3334557E-04
     +,   6.7313458E-04,   6.1669556E-04,   5.6392152E-04
     +,   5.1468861E-04,   4.6887322E-04,   4.2634245E-04
     +,   3.8696782E-04,   3.5061411E-04,   3.1714971E-04
     +,   2.8643647E-04,   2.5833756E-04,   2.3271027E-04
     +,   2.0940923E-04,   1.8828901E-04,   1.6919977E-04
     +,   1.5199407E-04,   1.3652339E-04,   1.2264407E-04
     +,   1.1021466E-04,   9.9101017E-05,   8.9174166E-05
     +,   8.0314021E-05,   7.2407609E-05,   6.5351684E-05
     +,   5.9050850E-05,   5.3419481E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz100 = Yx/0.30975
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4344819E-05,   4.5981367E-05
     +,   4.7671776E-05,   4.9416372E-05,   5.1215222E-05
     +,   5.3068277E-05,   5.4975182E-05,   5.6935402E-05
     +,   5.8948142E-05,   6.1012433E-05,   6.3126965E-05
     +,   6.5290216E-05,   6.7500368E-05,   6.9755377E-05
     +,   7.2052928E-05,   7.4390475E-05,   7.6765187E-05
     +,   7.9174053E-05,   8.1613798E-05,   8.4081003E-05
     +,   8.6572014E-05,   8.9083107E-05,   9.1610338E-05
     +,   9.4149815E-05,   9.6697382E-05,   9.9249140E-05
     +,   1.0180102E-04,   1.0434907E-04,   1.0688954E-04
     +,   1.0941882E-04,   1.1193346E-04,   1.1443035E-04
     +,   1.1690676E-04,   1.1936037E-04,   1.2178919E-04
     +,   1.2419188E-04,   1.2656768E-04,   1.2891633E-04
     +,   1.3123848E-04,   1.3353524E-04,   1.3580876E-04
     +,   1.3806186E-04,   1.4029838E-04,   1.4252293E-04
     +,   1.4474108E-04,   1.4695936E-04,   1.4918543E-04
     +,   1.5142752E-04,   1.5369515E-04,   1.5599857E-04
     +,   1.5834901E-04,   1.6075844E-04,   1.6323953E-04
     +,   1.6580583E-04,   1.6847115E-04,   1.7125002E-04
     +,   1.7415704E-04,   1.7720708E-04,   1.8041494E-04
     +,   1.8379516E-04,   1.8736192E-04,   1.9112868E-04
     +,   1.9510803E-04,   1.9931144E-04,   2.0374916E-04
     +,   2.0842934E-04,   2.1335893E-04,   2.1854170E-04
     +,   2.2398029E-04,   2.2967342E-04,   2.3561806E-04
     +,   2.4180711E-04,   2.4823096E-04,   2.5487601E-04
     +,   2.6172557E-04,   2.6875956E-04,   2.7595353E-04
     +,   2.8327978E-04,   2.9070754E-04,   2.9820250E-04
     +,   3.0572651E-04,   3.1323949E-04,   3.2069802E-04
     +,   3.2805683E-04,   3.3526862E-04,   3.4228485E-04
     +,   3.4905571E-04,   3.5553187E-04,   3.6166323E-04
     +,   3.6740149E-04,   3.7269929E-04,   3.7751134E-04
     +,   3.8179458E-04,   3.8551036E-04,   3.8862266E-04
     +,   3.9110001E-04,   3.9291615E-04,   3.9404910E-04
     +,   3.9448330E-04,   3.9420807E-04,   3.9321915E-04
     +,   3.9151806E-04,   3.8911228E-04,   3.8601563E-04
     +,   3.8224750E-04,   3.7783239E-04,   3.7280098E-04
     +,   3.6718824E-04,   3.6103383E-04,   3.5438128E-04
     +,   3.4727779E-04,   3.3977299E-04,   3.3191970E-04
     +,   3.2377138E-04,   3.1538369E-04,   3.0681168E-04
     +,   2.9811152E-04,   2.8933768E-04,   2.8054445E-04
     +,   2.7178388E-04,   2.6310582E-04,   2.5455846E-04
     +,   2.4618694E-04,   2.3803320E-04,   2.3013567E-04
     +,   2.2253026E-04,   2.1524816E-04,   2.0831829E-04
     +,   2.0176481E-04,   1.9560913E-04,   1.8986852E-04
     +,   1.8455739E-04,   1.7968629E-04,   1.7526314E-04
     +,   1.7129253E-04,   1.6777620E-04,   1.6471371E-04
     +,   1.6210187E-04,   1.5993520E-04,   1.5820650E-04
     +,   1.5690667E-04,   1.5602495E-04,   1.5554937E-04
     +,   1.5546659E-04,   1.5576252E-04,   1.5642229E-04
     +,   1.5743056E-04,   1.5877167E-04,   1.6042980E-04
     +,   1.6238974E-04,   1.6463659E-04,   1.6715618E-04
     +,   1.6993556E-04,   1.7296361E-04,   1.7623087E-04
     +,   1.7973046E-04,   1.8345832E-04,   1.8741420E-04
     +,   1.9160213E-04,   1.9603095E-04,   2.0071582E-04
     +,   2.0567898E-04,   2.1095017E-04,   2.1656882E-04
     +,   2.2258487E-04,   2.2906023E-04,   2.3606955E-04
     +,   2.4370152E-04,   2.5206027E-04,   2.6126593E-04
     +,   2.7145384E-04,   2.8277439E-04,   2.9539343E-04
     +,   3.0948911E-04,   3.2524852E-04,   3.4286722E-04
     +,   3.6254415E-04,   3.8447717E-04,   4.0886097E-04
     +,   4.3588656E-04,   4.6573931E-04,   4.9860054E-04
     +,   5.3465349E-04,   5.7409826E-04,   6.1716308E-04
     +,   6.6412409E-04,   7.1533362E-04,   7.7125750E-04
     +,   8.3251297E-04,   8.9990697E-04,   9.7450864E-04
     +,   1.0576970E-03,   1.1512223E-03,   1.2572635E-03
     +,   1.3784608E-03,   1.5178984E-03,   1.6789855E-03
     +,   1.8652702E-03,   2.0801453E-03,   2.3264289E-03
     +,   2.6059260E-03,   2.9190551E-03,   3.2646353E-03
     +,   3.6398587E-03,   4.0405211E-03,   4.4616372E-03
     +,   4.8982850E-03,   5.3467355E-03,   5.8059464E-03
     +,   6.2793097E-03,   6.7764348E-03,   7.3147085E-03
     +,   7.9199849E-03,   8.6249337E-03,   9.4633857E-03
     +,   1.0460200E-02,   1.1619348E-02,   1.2916372E-02
     +,   1.4302432E-02,   1.5724996E-02,   1.7164592E-02
     +,   1.8672198E-02,   2.0371953E-02,   2.2394262E-02
     +,   2.4759855E-02,   2.7317740E-02,   2.9826004E-02
     +,   3.2119051E-02,   3.4198839E-02,   3.6187973E-02
     +,   3.8221955E-02,   4.0336791E-02,   4.2359546E-02
     +,   4.3909818E-02,   4.4615600E-02,   4.4366516E-02
     +,   4.3309785E-02,   4.1665148E-02,   3.9670710E-02
     +,   3.7631191E-02,   3.5804193E-02,   3.4182034E-02
     +,   3.2484252E-02,   3.0418521E-02,   2.7933773E-02
     +,   2.5234979E-02,   2.2615205E-02,   2.0297857E-02
     +,   1.8378852E-02,   1.6831657E-02,   1.5537382E-02
     +,   1.4341137E-02,   1.3122838E-02,   1.1844329E-02
     +,   1.0545816E-02,   9.3037067E-03,   8.1841070E-03
     +,   7.2178901E-03,   6.4007980E-03,   5.7079652E-03
     +,   5.1097320E-03,   4.5817774E-03,   4.1085472E-03
     +,   3.6820313E-03,   3.2985995E-03,   2.9559811E-03
     +,   2.6515049E-03,   2.3815990E-03,   2.1420508E-03
     +,   1.9285835E-03,   1.7373705E-03,   1.5652941E-03
     +,   1.4099316E-03,   1.2694102E-03,   1.1422266E-03
     +,   1.0271037E-03,   9.2286553E-04,   8.2842796E-04
     +,   7.4277376E-04,   6.6499453E-04,   5.9428537E-04
     +,   5.2997080E-04,   4.7147908E-04,   4.1834370E-04
     +,   3.7016356E-04,   3.2659608E-04,   2.8732530E-04
     +,   2.5205369E-04,   2.2049509E-04,   1.9236382E-04
     +,   1.6738175E-04,   1.4527283E-04,   1.2577247E-04
     +,   1.0862448E-04,   9.3589173E-05,   8.0440557E-05
     +,   6.8971611E-05,   5.8991209E-05,   5.0327133E-05
     +,   4.2822805E-05,   3.6338672E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz104 = Yx/0.304354166666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.3080777E-05,   5.4526339E-05
     +,   5.5990116E-05,   5.7471338E-05,   5.8969272E-05
     +,   6.0482991E-05,   6.2011663E-05,   6.3554333E-05
     +,   6.5110027E-05,   6.6677807E-05,   6.8256624E-05
     +,   6.9845410E-05,   7.1443123E-05,   7.3048701E-05
     +,   7.4661060E-05,   7.6279168E-05,   7.7902019E-05
     +,   7.9528589E-05,   8.1157930E-05,   8.2789178E-05
     +,   8.4421496E-05,   8.6054199E-05,   8.7686669E-05
     +,   8.9318455E-05,   9.0949165E-05,   9.2578659E-05
     +,   9.4207018E-05,   9.5834446E-05,   9.7461409E-05
     +,   9.9088647E-05,   1.0071713E-04,   1.0234825E-04
     +,   1.0398353E-04,   1.0562500E-04,   1.0727498E-04
     +,   1.0893615E-04,   1.1061157E-04,   1.1230478E-04
     +,   1.1401966E-04,   1.1576050E-04,   1.1753198E-04
     +,   1.1933919E-04,   1.2118759E-04,   1.2308297E-04
     +,   1.2503144E-04,   1.2703937E-04,   1.2911340E-04
     +,   1.3126027E-04,   1.3348681E-04,   1.3579990E-04
     +,   1.3820645E-04,   1.4071290E-04,   1.4332567E-04
     +,   1.4605082E-04,   1.4889358E-04,   1.5185891E-04
     +,   1.5495082E-04,   1.5817245E-04,   1.6152595E-04
     +,   1.6501233E-04,   1.6863133E-04,   1.7238133E-04
     +,   1.7625911E-04,   1.8026012E-04,   1.8437812E-04
     +,   1.8860502E-04,   1.9293127E-04,   1.9734538E-04
     +,   2.0183450E-04,   2.0638360E-04,   2.1097661E-04
     +,   2.1559560E-04,   2.2022174E-04,   2.2483440E-04
     +,   2.2941260E-04,   2.3393430E-04,   2.3837679E-04
     +,   2.4271711E-04,   2.4693235E-04,   2.5100017E-04
     +,   2.5489810E-04,   2.5860514E-04,   2.6210086E-04
     +,   2.6536683E-04,   2.6838575E-04,   2.7114261E-04
     +,   2.7362438E-04,   2.7582049E-04,   2.7772275E-04
     +,   2.7932596E-04,   2.8062725E-04,   2.8162691E-04
     +,   2.8232776E-04,   2.8273574E-04,   2.8285928E-04
     +,   2.8270957E-04,   2.8230032E-04,   2.8164728E-04
     +,   2.8076849E-04,   2.7968374E-04,   2.7841420E-04
     +,   2.7698261E-04,   2.7541220E-04,   2.7372723E-04
     +,   2.7195190E-04,   2.7011032E-04,   2.6822661E-04
     +,   2.6632374E-04,   2.6442404E-04,   2.6254819E-04
     +,   2.6071598E-04,   2.5894470E-04,   2.5725042E-04
     +,   2.5564671E-04,   2.5414524E-04,   2.5275510E-04
     +,   2.5148343E-04,   2.5033476E-04,   2.4931168E-04
     +,   2.4841420E-04,   2.4764019E-04,   2.4698590E-04
     +,   2.4644536E-04,   2.4601110E-04,   2.4567405E-04
     +,   2.4542410E-04,   2.4524977E-04,   2.4513906E-04
     +,   2.4507966E-04,   2.4505833E-04,   2.4506252E-04
     +,   2.4507957E-04,   2.4509744E-04,   2.4510507E-04
     +,   2.4509212E-04,   2.4504954E-04,   2.4497003E-04
     +,   2.4484785E-04,   2.4467890E-04,   2.4446132E-04
     +,   2.4419528E-04,   2.4388322E-04,   2.4352982E-04
     +,   2.4314204E-04,   2.4272941E-04,   2.4230345E-04
     +,   2.4187820E-04,   2.4146959E-04,   2.4109565E-04
     +,   2.4077632E-04,   2.4053318E-04,   2.4038884E-04
     +,   2.4036776E-04,   2.4049473E-04,   2.4079546E-04
     +,   2.4129602E-04,   2.4202236E-04,   2.4300082E-04
     +,   2.4425716E-04,   2.4581663E-04,   2.4770453E-04
     +,   2.4994535E-04,   2.5256374E-04,   2.5558390E-04
     +,   2.5903119E-04,   2.6293154E-04,   2.6731307E-04
     +,   2.7220658E-04,   2.7764656E-04,   2.8367381E-04
     +,   2.9033431E-04,   2.9768306E-04,   3.0578487E-04
     +,   3.1471637E-04,   3.2456632E-04,   3.3543882E-04
     +,   3.4745398E-04,   3.6074690E-04,   3.7546974E-04
     +,   3.9179160E-04,   4.0989669E-04,   4.2998223E-04
     +,   4.5225502E-04,   4.7693148E-04,   5.0423294E-04
     +,   5.3437776E-04,   5.6758150E-04,   6.0405280E-04
     +,   6.4399024E-04,   6.8757462E-04,   7.3497434E-04
     +,   7.8634027E-04,   8.4180263E-04,   9.0147078E-04
     +,   9.6543704E-04,   1.0337747E-03,   1.1065286E-03
     +,   1.1837225E-03,   1.2653621E-03,   1.3514364E-03
     +,   1.4419151E-03,   1.5367660E-03,   1.6359801E-03
     +,   1.7395843E-03,   1.8476570E-03,   1.9603812E-03
     +,   2.0780955E-03,   2.2013939E-03,   2.3313772E-03
     +,   2.4701010E-03,   2.6213070E-03,   2.7914182E-03
     +,   2.9906917E-03,   3.2340642E-03,   3.5410314E-03
     +,   3.9338712E-03,   4.4338554E-03,   5.0558737E-03
     +,   5.8027706E-03,   6.6616465E-03,   7.6047564E-03
     +,   8.5960571E-03,   9.6038328E-03,   1.0617469E-02
     +,   1.1663633E-02,   1.2812379E-02,   1.4161822E-02
     +,   1.5796922E-02,   1.7739201E-02,   1.9929724E-02
     +,   2.2280673E-02,   2.4759471E-02,   2.7396983E-02
     +,   3.0176023E-02,   3.2943103E-02,   3.5507452E-02
     +,   3.7803028E-02,   3.9848294E-02,   4.1579872E-02
     +,   4.2903669E-02,   4.3922193E-02,   4.4887122E-02
     +,   4.5797192E-02,   4.6151355E-02,   4.5239396E-02
     +,   4.2732220E-02,   3.9040886E-02,   3.5120796E-02
     +,   3.1849723E-02,   2.9487509E-02,   2.7670609E-02
     +,   2.5875254E-02,   2.3853946E-02,   2.1702556E-02
     +,   1.9653250E-02,   1.7878996E-02,   1.6440827E-02
     +,   1.5318764E-02,   1.4442463E-02,   1.3707463E-02
     +,   1.2998658E-02,   1.2223921E-02,   1.1338882E-02
     +,   1.0348671E-02,   9.2911972E-03,   8.2153473E-03
     +,   7.1655731E-03,   6.1752088E-03,   5.2660741E-03
     +,   4.4505959E-03,   3.7341504E-03,   3.1165101E-03
     +,   2.5928400E-03,   2.1547196E-03,   1.7915730E-03
     +,   1.4921206E-03,   1.2455075E-03,   1.0421559E-03
     +,   8.7400997E-04,   7.3456462E-04,   6.1861612E-04
     +,   5.2203453E-04,   4.4148797E-04,   3.7427412E-04
     +,   3.1815478E-04,   2.7127360E-04,   2.3207211E-04
     +,   1.9924533E-04,   1.7170604E-04,   1.4854557E-04
     +,   1.2901418E-04,   1.1249048E-04,   9.8464712E-05
     +,   8.6515865E-05,   7.6298697E-05,   6.7527290E-05
     +,   5.9966384E-05,   5.3420317E-05,   4.7727819E-05
     +,   4.2754582E-05,   3.8390146E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz106 = Yx/0.300854166666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6620753E-05,   3.7405865E-05
     +,   3.8198883E-05,   3.9000304E-05,   3.9810722E-05
     +,   4.0630774E-05,   4.1461240E-05,   4.2302963E-05
     +,   4.3156873E-05,   4.4024055E-05,   4.4905624E-05
     +,   4.5802855E-05,   4.6717054E-05,   4.7649672E-05
     +,   4.8602269E-05,   4.9576440E-05,   5.0573897E-05
     +,   5.1596478E-05,   5.2646039E-05,   5.3724521E-05
     +,   5.4833938E-05,   5.5976336E-05,   5.7153833E-05
     +,   5.8368620E-05,   5.9622747E-05,   6.0918468E-05
     +,   6.2257917E-05,   6.3643245E-05,   6.5076551E-05
     +,   6.6559871E-05,   6.8095222E-05,   6.9684502E-05
     +,   7.1329472E-05,   7.3031850E-05,   7.4793170E-05
     +,   7.6614822E-05,   7.8498015E-05,   8.0443751E-05
     +,   8.2452927E-05,   8.4526080E-05,   8.6663589E-05
     +,   8.8865563E-05,   9.1131915E-05,   9.3462142E-05
     +,   9.5855576E-05,   9.8311175E-05,   1.0082767E-04
     +,   1.0340341E-04,   1.0603644E-04,   1.0872455E-04
     +,   1.1146515E-04,   1.1425540E-04,   1.1709196E-04
     +,   1.1997156E-04,   1.2289018E-04,   1.2584387E-04
     +,   1.2882822E-04,   1.3183858E-04,   1.3487009E-04
     +,   1.3791765E-04,   1.4097591E-04,   1.4403944E-04
     +,   1.4710239E-04,   1.5015909E-04,   1.5320361E-04
     +,   1.5622980E-04,   1.5923173E-04,   1.6220304E-04
     +,   1.6513781E-04,   1.6802970E-04,   1.7087285E-04
     +,   1.7366106E-04,   1.7638852E-04,   1.7904941E-04
     +,   1.8163811E-04,   1.8414934E-04,   1.8657776E-04
     +,   1.8891829E-04,   1.9116628E-04,   1.9331729E-04
     +,   1.9536717E-04,   1.9731202E-04,   1.9914840E-04
     +,   2.0087308E-04,   2.0248328E-04,   2.0397658E-04
     +,   2.0535091E-04,   2.0660473E-04,   2.0773665E-04
     +,   2.0874593E-04,   2.0963217E-04,   2.1039532E-04
     +,   2.1103577E-04,   2.1155445E-04,   2.1195269E-04
     +,   2.1223204E-04,   2.1239472E-04,   2.1244332E-04
     +,   2.1238076E-04,   2.1221048E-04,   2.1193631E-04
     +,   2.1156248E-04,   2.1109368E-04,   2.1053503E-04
     +,   2.0989189E-04,   2.0917026E-04,   2.0837630E-04
     +,   2.0751692E-04,   2.0659892E-04,   2.0562980E-04
     +,   2.0461735E-04,   2.0356968E-04,   2.0249530E-04
     +,   2.0140296E-04,   2.0030160E-04,   1.9920073E-04
     +,   1.9810985E-04,   1.9703880E-04,   1.9599764E-04
     +,   1.9499651E-04,   1.9404555E-04,   1.9315531E-04
     +,   1.9233624E-04,   1.9159877E-04,   1.9095313E-04
     +,   1.9040982E-04,   1.8997879E-04,   1.8967020E-04
     +,   1.8949360E-04,   1.8945846E-04,   1.8957374E-04
     +,   1.8984814E-04,   1.9028975E-04,   1.9090617E-04
     +,   1.9170436E-04,   1.9269083E-04,   1.9387128E-04
     +,   1.9525064E-04,   1.9683325E-04,   1.9862261E-04
     +,   2.0062130E-04,   2.0283120E-04,   2.0525329E-04
     +,   2.0788796E-04,   2.1073419E-04,   2.1379080E-04
     +,   2.1705552E-04,   2.2052530E-04,   2.2419634E-04
     +,   2.2806443E-04,   2.3212479E-04,   2.3637204E-04
     +,   2.4080042E-04,   2.4540420E-04,   2.5017792E-04
     +,   2.5511580E-04,   2.6021290E-04,   2.6546489E-04
     +,   2.7086947E-04,   2.7642463E-04,   2.8213160E-04
     +,   2.8799416E-04,   2.9401909E-04,   3.0021727E-04
     +,   3.0660487E-04,   3.1320346E-04,   3.2004158E-04
     +,   3.2715406E-04,   3.3458517E-04,   3.4238742E-04
     +,   3.5062296E-04,   3.5936313E-04,   3.6868971E-04
     +,   3.7869456E-04,   3.8947648E-04,   4.0114406E-04
     +,   4.1381182E-04,   4.2759837E-04,   4.4262406E-04
     +,   4.5901115E-04,   4.7687994E-04,   4.9634505E-04
     +,   5.1751657E-04,   5.4049975E-04,   5.6539447E-04
     +,   5.9229473E-04,   6.2129332E-04,   6.5248762E-04
     +,   6.8598246E-04,   7.2189345E-04,   7.6035591E-04
     +,   8.0152770E-04,   8.4558700E-04,   8.9273381E-04
     +,   9.4318599E-04,   9.9716545E-04,   1.0548788E-03
     +,   1.1164985E-03,   1.1821435E-03,   1.2518496E-03
     +,   1.3255444E-03,   1.4030292E-03,   1.4839828E-03
     +,   1.5679639E-03,   1.6544273E-03,   1.7427843E-03
     +,   1.8324673E-03,   1.9230144E-03,   2.0142021E-03
     +,   2.1061974E-03,   2.1997229E-03,   2.2962408E-03
     +,   2.3981133E-03,   2.5087392E-03,   2.6325658E-03
     +,   2.7749785E-03,   2.9420336E-03,   3.1400523E-03
     +,   3.3750432E-03,   3.6519743E-03,   3.9740293E-03
     +,   4.3417774E-03,   4.7524320E-03,   5.1995832E-03
     +,   5.6737270E-03,   6.1640674E-03,   6.6620070E-03
     +,   7.1662869E-03,   7.6886378E-03,   8.2575995E-03
     +,   8.9178942E-03,   9.7243460E-03,   1.0731227E-02
     +,   1.1979644E-02,   1.3485069E-02,   1.5231808E-02
     +,   1.7184040E-02,   1.9315982E-02,   2.1636503E-02
     +,   2.4166023E-02,   2.6862258E-02,   2.9561589E-02
     +,   3.2017045E-02,   3.4043491E-02,   3.5697922E-02
     +,   3.7351143E-02,   3.9468370E-02,   4.2143937E-02
     +,   4.4870555E-02,   4.6912838E-02,   4.7875267E-02
     +,   4.7831513E-02,   4.7073524E-02,   4.5870949E-02
     +,   4.4340435E-02,   4.2431891E-02,   4.0055804E-02
     +,   3.7196409E-02,   3.3908479E-02,   3.0324489E-02
     +,   2.6697595E-02,   2.3343647E-02,   2.0480683E-02
     +,   1.8132528E-02,   1.6182415E-02,   1.4489594E-02
     +,   1.2958489E-02,   1.1537762E-02,   1.0195243E-02
     +,   8.9073302E-03,   7.6651243E-03,   6.4800051E-03
     +,   5.3785015E-03,   4.3896846E-03,   3.5336935E-03
     +,   2.8165700E-03,   2.2313136E-03,   1.7627632E-03
     +,   1.3924324E-03,   1.1021545E-03,   8.7575457E-04
     +,   6.9966092E-04,   5.6274567E-04,   4.5608229E-04
     +,   3.7259280E-04,   3.0678613E-04,   2.5446588E-04
     +,   2.1248244E-04,   1.7849893E-04,   1.5077663E-04
     +,   1.2801838E-04,   1.0923613E-04,   9.3667171E-05
     +,   8.0707920E-05,   6.9876311E-05,   6.0780563E-05
     +,   5.3102689E-05,   4.6582107E-05,   4.1007246E-05
     +,   3.6205522E-05,   3.2038257E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz108 = Yx/0.302489361702128
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.2947201E-05,   9.7007578E-05
     +,   1.0112641E-04,   1.0529582E-04,   1.0950740E-04
     +,   1.1375269E-04,   1.1802264E-04,   1.2230822E-04
     +,   1.2660006E-04,   1.3088883E-04,   1.3516501E-04
     +,   1.3941921E-04,   1.4364198E-04,   1.4782413E-04
     +,   1.5195663E-04,   1.5603063E-04,   1.6003764E-04
     +,   1.6396957E-04,   1.6781864E-04,   1.7157757E-04
     +,   1.7523953E-04,   1.7879812E-04,   1.8224758E-04
     +,   1.8558285E-04,   1.8879895E-04,   1.9189197E-04
     +,   1.9485832E-04,   1.9769497E-04,   2.0039955E-04
     +,   2.0297008E-04,   2.0540516E-04,   2.0770388E-04
     +,   2.0986583E-04,   2.1189083E-04,   2.1377919E-04
     +,   2.1553187E-04,   2.1714959E-04,   2.1863369E-04
     +,   2.1998573E-04,   2.2120729E-04,   2.2230032E-04
     +,   2.2326688E-04,   2.2410901E-04,   2.2482884E-04
     +,   2.2542859E-04,   2.2591065E-04,   2.2627728E-04
     +,   2.2653071E-04,   2.2667342E-04,   2.2670753E-04
     +,   2.2663557E-04,   2.2645970E-04,   2.2618243E-04
     +,   2.2580607E-04,   2.2533305E-04,   2.2476596E-04
     +,   2.2410719E-04,   2.2335959E-04,   2.2252589E-04
     +,   2.2160896E-04,   2.2061179E-04,   2.1953763E-04
     +,   2.1839001E-04,   2.1717233E-04,   2.1588831E-04
     +,   2.1454210E-04,   2.1313762E-04,   2.1167946E-04
     +,   2.1017197E-04,   2.0862005E-04,   2.0702848E-04
     +,   2.0540250E-04,   2.0374711E-04,   2.0206782E-04
     +,   2.0037011E-04,   1.9865923E-04,   1.9694086E-04
     +,   1.9522065E-04,   1.9350396E-04,   1.9179629E-04
     +,   1.9010315E-04,   1.8842959E-04,   1.8678088E-04
     +,   1.8516171E-04,   1.8357691E-04,   1.8203074E-04
     +,   1.8052748E-04,   1.7907075E-04,   1.7766420E-04
     +,   1.7631092E-04,   1.7501351E-04,   1.7377448E-04
     +,   1.7259570E-04,   1.7147875E-04,   1.7042474E-04
     +,   1.6943441E-04,   1.6850801E-04,   1.6764562E-04
     +,   1.6684656E-04,   1.6611008E-04,   1.6543485E-04
     +,   1.6481940E-04,   1.6426173E-04,   1.6375970E-04
     +,   1.6331076E-04,   1.6291217E-04,   1.6256100E-04
     +,   1.6225400E-04,   1.6198792E-04,   1.6175916E-04
     +,   1.6156431E-04,   1.6139966E-04,   1.6126149E-04
     +,   1.6114619E-04,   1.6104996E-04,   1.6096926E-04
     +,   1.6090061E-04,   1.6084046E-04,   1.6078561E-04
     +,   1.6073295E-04,   1.6067947E-04,   1.6062253E-04
     +,   1.6055965E-04,   1.6048861E-04,   1.6040757E-04
     +,   1.6031481E-04,   1.6020919E-04,   1.6008974E-04
     +,   1.5995580E-04,   1.5980730E-04,   1.5964448E-04
     +,   1.5946793E-04,   1.5927885E-04,   1.5907869E-04
     +,   1.5886957E-04,   1.5865393E-04,   1.5843491E-04
     +,   1.5821599E-04,   1.5800138E-04,   1.5779574E-04
     +,   1.5760433E-04,   1.5743310E-04,   1.5728861E-04
     +,   1.5717797E-04,   1.5710907E-04,   1.5709049E-04
     +,   1.5713139E-04,   1.5724180E-04,   1.5743241E-04
     +,   1.5771460E-04,   1.5810058E-04,   1.5860306E-04
     +,   1.5923571E-04,   1.6001264E-04,   1.6094888E-04
     +,   1.6205963E-04,   1.6336089E-04,   1.6486888E-04
     +,   1.6660038E-04,   1.6857209E-04,   1.7080108E-04
     +,   1.7330419E-04,   1.7609810E-04,   1.7919904E-04
     +,   1.8262306E-04,   1.8638565E-04,   1.9050117E-04
     +,   1.9498351E-04,   1.9984602E-04,   2.0510145E-04
     +,   2.1076157E-04,   2.1683822E-04,   2.2334351E-04
     +,   2.3029029E-04,   2.3769223E-04,   2.4556578E-04
     +,   2.5393069E-04,   2.6281059E-04,   2.7223438E-04
     +,   2.8223914E-04,   2.9287022E-04,   3.0418223E-04
     +,   3.1624144E-04,   3.2912780E-04,   3.4293512E-04
     +,   3.5777074E-04,   3.7375736E-04,   3.9103389E-04
     +,   4.0975268E-04,   4.3007830E-04,   4.5218668E-04
     +,   4.7626279E-04,   5.0249352E-04,   5.3106627E-04
     +,   5.6216348E-04,   5.9595768E-04,   6.3260167E-04
     +,   6.7222229E-04,   7.1491743E-04,   7.6074462E-04
     +,   8.0971210E-04,   8.6177525E-04,   9.1683399E-04
     +,   9.7473204E-04,   1.0352526E-03,   1.0981422E-03
     +,   1.1631236E-03,   1.2299189E-03,   1.2982942E-03
     +,   1.3681048E-03,   1.4393479E-03,   1.5122055E-03
     +,   1.5870893E-03,   1.6646797E-03,   1.7459269E-03
     +,   1.8320266E-03,   1.9243929E-03,   2.0246105E-03
     +,   2.1343827E-03,   2.2554805E-03,   2.3897593E-03
     +,   2.5391688E-03,   2.7057680E-03,   2.8917519E-03
     +,   3.0994269E-03,   3.3310628E-03,   3.5886094E-03
     +,   3.8733007E-03,   4.1851723E-03,   4.5226491E-03
     +,   4.8824758E-03,   5.2605248E-03,   5.6538638E-03
     +,   6.0638553E-03,   6.4997766E-03,   6.9813663E-03
     +,   7.5384891E-03,   8.2070176E-03,   9.0215420E-03
     +,   1.0006711E-02,   1.1169983E-02,   1.2499501E-02
     +,   1.3971707E-02,   1.5570007E-02,   1.7308185E-02
     +,   1.9244585E-02,   2.1477966E-02,   2.4129439E-02
     +,   2.7314031E-02,   3.1075792E-02,   3.5274245E-02
     +,   3.9521091E-02,   4.3326702E-02,   4.6394221E-02
     +,   4.8741654E-02,   5.0506283E-02,   5.1706683E-02
     +,   5.2237030E-02,   5.2012581E-02,   5.1037461E-02
     +,   4.9371522E-02,   4.7118045E-02,   4.4438772E-02
     +,   4.1495483E-02,   3.8354851E-02,   3.5003655E-02
     +,   3.1458776E-02,   2.7827224E-02,   2.4272431E-02
     +,   2.0946365E-02,   1.7939007E-02,   1.5268127E-02
     +,   1.2908433E-02,   1.0830476E-02,   9.0172794E-03
     +,   7.4565150E-03,   6.1282301E-03,   5.0031296E-03
     +,   4.0488662E-03,   3.2381355E-03,   2.5520846E-03
     +,   1.9791410E-03,   1.5107916E-03,   1.1379472E-03
     +,   8.4906240E-04,   6.3058443E-04,   4.6837071E-04
     +,   3.4929681E-04,   2.6227572E-04,   1.9857851E-04
     +,   1.5170436E-04,   1.1696127E-04,   9.1027519E-05
     +,   7.1548835E-05,   5.6845798E-05,   4.5698489E-05
     +,   3.7209986E-05,   3.0710755E-05,   2.5699326E-05
     +,   2.1798076E-05,   1.8724117E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz110 = Yx/0.304127659574468
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5713601E-05,   4.6680845E-05
     +,   4.7661197E-05,   4.8656235E-05,   4.9667749E-05
     +,   5.0697665E-05,   5.1748106E-05,   5.2821364E-05
     +,   5.3919881E-05,   5.5046352E-05,   5.6203560E-05
     +,   5.7394482E-05,   5.8622245E-05,   5.9890135E-05
     +,   6.1201543E-05,   6.2560037E-05,   6.3969215E-05
     +,   6.5432854E-05,   6.6954679E-05,   6.8538626E-05
     +,   7.0188500E-05,   7.1908216E-05,   7.3701580E-05
     +,   7.5572447E-05,   7.7524470E-05,   7.9561258E-05
     +,   8.1686281E-05,   8.3902763E-05,   8.6213797E-05
     +,   8.8622139E-05,   9.1130307E-05,   9.3740498E-05
     +,   9.6454569E-05,   9.9273959E-05,   1.0219967E-04
     +,   1.0523240E-04,   1.0837216E-04,   1.1161859E-04
     +,   1.1497088E-04,   1.1842737E-04,   1.2198638E-04
     +,   1.2564508E-04,   1.2940051E-04,   1.3324882E-04
     +,   1.3718581E-04,   1.4120659E-04,   1.4530572E-04
     +,   1.4947735E-04,   1.5371481E-04,   1.5801124E-04
     +,   1.6235920E-04,   1.6675070E-04,   1.7117750E-04
     +,   1.7563117E-04,   1.8010243E-04,   1.8458239E-04
     +,   1.8906145E-04,   1.9353017E-04,   1.9797881E-04
     +,   2.0239773E-04,   2.0677710E-04,   2.1110740E-04
     +,   2.1537903E-04,   2.1958252E-04,   2.2370912E-04
     +,   2.2774949E-04,   2.3169539E-04,   2.3553823E-04
     +,   2.3927043E-04,   2.4288436E-04,   2.4637312E-04
     +,   2.4972993E-04,   2.5294902E-04,   2.5602439E-04
     +,   2.5895113E-04,   2.6172464E-04,   2.6434069E-04
     +,   2.6679557E-04,   2.6908610E-04,   2.7120978E-04
     +,   2.7316401E-04,   2.7494715E-04,   2.7655772E-04
     +,   2.7799487E-04,   2.7925774E-04,   2.8034628E-04
     +,   2.8126035E-04,   2.8200058E-04,   2.8256763E-04
     +,   2.8296257E-04,   2.8318670E-04,   2.8324168E-04
     +,   2.8312954E-04,   2.8285233E-04,   2.8241269E-04
     +,   2.8181321E-04,   2.8105709E-04,   2.8014765E-04
     +,   2.7908859E-04,   2.7788361E-04,   2.7653726E-04
     +,   2.7505396E-04,   2.7343864E-04,   2.7169651E-04
     +,   2.6983311E-04,   2.6785425E-04,   2.6576617E-04
     +,   2.6357549E-04,   2.6128895E-04,   2.5891353E-04
     +,   2.5645690E-04,   2.5392650E-04,   2.5133041E-04
     +,   2.4867652E-04,   2.4597338E-04,   2.4322922E-04
     +,   2.4045281E-04,   2.3765248E-04,   2.3483712E-04
     +,   2.3201524E-04,   2.2919524E-04,   2.2638583E-04
     +,   2.2359526E-04,   2.2083153E-04,   2.1810246E-04
     +,   2.1541592E-04,   2.1277882E-04,   2.1019843E-04
     +,   2.0768105E-04,   2.0523301E-04,   2.0286000E-04
     +,   2.0056743E-04,   1.9835995E-04,   1.9624234E-04
     +,   1.9421849E-04,   1.9229179E-04,   1.9046578E-04
     +,   1.8874323E-04,   1.8712657E-04,   1.8561797E-04
     +,   1.8421952E-04,   1.8293288E-04,   1.8175975E-04
     +,   1.8070157E-04,   1.7975981E-04,   1.7893610E-04
     +,   1.7823205E-04,   1.7764953E-04,   1.7719080E-04
     +,   1.7685826E-04,   1.7665484E-04,   1.7658398E-04
     +,   1.7664972E-04,   1.7685673E-04,   1.7721037E-04
     +,   1.7771678E-04,   1.7838291E-04,   1.7921673E-04
     +,   1.8022694E-04,   1.8142341E-04,   1.8281674E-04
     +,   1.8441887E-04,   1.8624257E-04,   1.8830155E-04
     +,   1.9061081E-04,   1.9318645E-04,   1.9604553E-04
     +,   1.9920597E-04,   2.0268728E-04,   2.0651000E-04
     +,   2.1069577E-04,   2.1526741E-04,   2.2024951E-04
     +,   2.2566834E-04,   2.3155106E-04,   2.3792747E-04
     +,   2.4482940E-04,   2.5229077E-04,   2.6034756E-04
     +,   2.6903921E-04,   2.7840835E-04,   2.8849975E-04
     +,   2.9936139E-04,   3.1104515E-04,   3.2360578E-04
     +,   3.3710033E-04,   3.5158781E-04,   3.6712966E-04
     +,   3.8378913E-04,   4.0162727E-04,   4.2070664E-04
     +,   4.4108741E-04,   4.6282640E-04,   4.8597567E-04
     +,   5.1058439E-04,   5.3669664E-04,   5.6434842E-04
     +,   5.9357018E-04,   6.2438776E-04,   6.5682101E-04
     +,   6.9088215E-04,   7.2657800E-04,   7.6391303E-04
     +,   8.0288650E-04,   8.4348995E-04,   8.8571548E-04
     +,   9.2955289E-04,   9.7498600E-04,   1.0220024E-03
     +,   1.0705976E-03,   1.1207806E-03,   1.1725808E-03
     +,   1.2260611E-03,   1.2813382E-03,   1.3386001E-03
     +,   1.3981194E-03,   1.4602805E-03,   1.5256045E-03
     +,   1.5947700E-03,   1.6686256E-03,   1.7482274E-03
     +,   1.8348505E-03,   1.9300096E-03,   2.0354756E-03
     +,   2.1532800E-03,   2.2857003E-03,   2.4351878E-03
     +,   2.6042676E-03,   2.7953903E-03,   3.0107249E-03
     +,   3.2519025E-03,   3.5198173E-03,   3.8145115E-03
     +,   4.1351654E-03,   4.4802823E-03,   4.8482274E-03
     +,   5.2379216E-03,   5.6496328E-03,   6.0854922E-03
     +,   6.5493453E-03,   7.0454977E-03,   7.5768679E-03
     +,   8.1437826E-03,   8.7447492E-03,   9.3794670E-03
     +,   1.0052029E-02,   1.0771927E-02,   1.1552427E-02
     +,   1.2410713E-02,   1.3373781E-02,   1.4488749E-02
     +,   1.5826439E-02,   1.7471125E-02,   1.9496517E-02
     +,   2.1933906E-02,   2.4739832E-02,   2.7786210E-02
     +,   3.0907152E-02,   3.3988785E-02,   3.7018307E-02
     +,   4.0022019E-02,   4.2953528E-02,   4.5658752E-02
     +,   4.7966346E-02,   4.9812373E-02,   5.1246248E-02
     +,   5.2251954E-02,   5.2552015E-02,   5.1667091E-02
     +,   4.9256910E-02,   4.5427337E-02,   4.0693745E-02
     +,   3.5656955E-02,   3.0732982E-02,   2.6118824E-02
     +,   2.1884056E-02,   1.8048419E-02,   1.4624643E-02
     +,   1.1633634E-02,   9.0952432E-03,   7.0057590E-03
     +,   5.3301272E-03,   4.0121097E-03,   2.9911448E-03
     +,   2.2118196E-03,   1.6261014E-03,   1.1921875E-03
     +,   8.7413104E-04,   6.4225827E-04,   4.7337101E-04
     +,   3.5029638E-04,   2.6068112E-04,   1.9569701E-04
     +,   1.4890207E-04,   1.1548999E-04,   9.1810325E-05
     +,   7.5100390E-05,   6.3296262E-05,   5.4894968E-05
     +,   4.8827194E-05,   4.4351269E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz112 = Yx/0.290574468085106
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.2530150E-05,   9.5406816E-05
     +,   9.8325174E-05,   1.0128279E-04,   1.0427694E-04
     +,   1.0730493E-04,   1.1036364E-04,   1.1344994E-04
     +,   1.1656046E-04,   1.1969171E-04,   1.2284005E-04
     +,   1.2600170E-04,   1.2917272E-04,   1.3234922E-04
     +,   1.3552712E-04,   1.3870223E-04,   1.4187048E-04
     +,   1.4502754E-04,   1.4816948E-04,   1.5129203E-04
     +,   1.5439119E-04,   1.5746296E-04,   1.6050346E-04
     +,   1.6350913E-04,   1.6647625E-04,   1.6940171E-04
     +,   1.7228225E-04,   1.7511508E-04,   1.7789766E-04
     +,   1.8062770E-04,   1.8330333E-04,   1.8592308E-04
     +,   1.8848569E-04,   1.9099053E-04,   1.9343711E-04
     +,   1.9582569E-04,   1.9815681E-04,   2.0043143E-04
     +,   2.0265135E-04,   2.0481825E-04,   2.0693481E-04
     +,   2.0900402E-04,   2.1102936E-04,   2.1301476E-04
     +,   2.1496466E-04,   2.1688396E-04,   2.1877787E-04
     +,   2.2065228E-04,   2.2251313E-04,   2.2436690E-04
     +,   2.2622042E-04,   2.2808049E-04,   2.2995452E-04
     +,   2.3184986E-04,   2.3377393E-04,   2.3573423E-04
     +,   2.3773838E-04,   2.3979368E-04,   2.4190753E-04
     +,   2.4408683E-04,   2.4633828E-04,   2.4866840E-04
     +,   2.5108288E-04,   2.5358691E-04,   2.5618545E-04
     +,   2.5888238E-04,   2.6168086E-04,   2.6458321E-04
     +,   2.6759112E-04,   2.7070471E-04,   2.7392383E-04
     +,   2.7724661E-04,   2.8067036E-04,   2.8419128E-04
     +,   2.8780435E-04,   2.9150347E-04,   2.9528135E-04
     +,   2.9912937E-04,   3.0303805E-04,   3.0699695E-04
     +,   3.1099410E-04,   3.1501750E-04,   3.1905310E-04
     +,   3.2308718E-04,   3.2710450E-04,   3.3109015E-04
     +,   3.3502781E-04,   3.3890174E-04,   3.4269525E-04
     +,   3.4639245E-04,   3.4997682E-04,   3.5343258E-04
     +,   3.5674387E-04,   3.5989578E-04,   3.6287404E-04
     +,   3.6566495E-04,   3.6825603E-04,   3.7063548E-04
     +,   3.7279297E-04,   3.7471880E-04,   3.7640563E-04
     +,   3.7784633E-04,   3.7903583E-04,   3.7997038E-04
     +,   3.8064749E-04,   3.8106635E-04,   3.8122750E-04
     +,   3.8113268E-04,   3.8078547E-04,   3.8018989E-04
     +,   3.7935234E-04,   3.7827936E-04,   3.7697889E-04
     +,   3.7546022E-04,   3.7373291E-04,   3.7180746E-04
     +,   3.6969502E-04,   3.6740766E-04,   3.6495712E-04
     +,   3.6235599E-04,   3.5961697E-04,   3.5675269E-04
     +,   3.5377601E-04,   3.5069988E-04,   3.4753644E-04
     +,   3.4429814E-04,   3.4099747E-04,   3.3764591E-04
     +,   3.3425473E-04,   3.3083544E-04,   3.2739845E-04
     +,   3.2395410E-04,   3.2051213E-04,   3.1708233E-04
     +,   3.1367378E-04,   3.1029512E-04,   3.0695487E-04
     +,   3.0366163E-04,   3.0042307E-04,   2.9724711E-04
     +,   2.9414162E-04,   2.9111400E-04,   2.8817216E-04
     +,   2.8532348E-04,   2.8257567E-04,   2.7993665E-04
     +,   2.7741399E-04,   2.7501612E-04,   2.7275129E-04
     +,   2.7062796E-04,   2.6865475E-04,   2.6684091E-04
     +,   2.6519576E-04,   2.6372881E-04,   2.6244990E-04
     +,   2.6136928E-04,   2.6049733E-04,   2.5984470E-04
     +,   2.5942229E-04,   2.5924121E-04,   2.5931295E-04
     +,   2.5964866E-04,   2.6026045E-04,   2.6115967E-04
     +,   2.6235863E-04,   2.6386901E-04,   2.6570304E-04
     +,   2.6787273E-04,   2.7039036E-04,   2.7326812E-04
     +,   2.7651829E-04,   2.8015277E-04,   2.8418380E-04
     +,   2.8862379E-04,   2.9348434E-04,   2.9877757E-04
     +,   3.0451544E-04,   3.1070938E-04,   3.1737049E-04
     +,   3.2451007E-04,   3.3213949E-04,   3.4026880E-04
     +,   3.4890790E-04,   3.5806687E-04,   3.6775548E-04
     +,   3.7798280E-04,   3.8875765E-04,   4.0008983E-04
     +,   4.1198934E-04,   4.2446531E-04,   4.3753043E-04
     +,   4.5119741E-04,   4.6548180E-04,   4.8040113E-04
     +,   4.9597741E-04,   5.1223690E-04,   5.2921037E-04
     +,   5.4693280E-04,   5.6544709E-04,   5.8480271E-04
     +,   6.0505414E-04,   6.2626280E-04,   6.4849749E-04
     +,   6.7183503E-04,   6.9635629E-04,   7.2215032E-04
     +,   7.4931420E-04,   7.7795150E-04,   8.0817548E-04
     +,   8.4011408E-04,   8.7391335E-04,   9.0973824E-04
     +,   9.4778399E-04,   9.8828878E-04,   1.0315393E-03
     +,   1.0778820E-03,   1.1277372E-03,   1.1816146E-03
     +,   1.2401200E-03,   1.3039532E-03,   1.3739212E-03
     +,   1.4509148E-03,   1.5358875E-03,   1.6298168E-03
     +,   1.7336750E-03,   1.8483774E-03,   1.9747517E-03
     +,   2.1135316E-03,   2.2654296E-03,   2.4312215E-03
     +,   2.6118956E-03,   2.8088482E-03,   3.0240740E-03
     +,   3.2602579E-03,   3.5207183E-03,   3.8092255E-03
     +,   4.1295490E-03,   4.4847312E-03,   4.8762918E-03
     +,   5.3032762E-03,   5.7614394E-03,   6.2428764E-03
     +,   6.7368508E-03,   7.2322539E-03,   7.7219377E-03
     +,   8.2080737E-03,   8.7064942E-03,   9.2469044E-03
     +,   9.8669371E-03,   1.0601068E-02,   1.1469908E-02
     +,   1.2477196E-02,   1.3619297E-02,   1.4903922E-02
     +,   1.6365271E-02,   1.8060992E-02,   2.0047931E-02
     +,   2.2352131E-02,   2.4951240E-02,   2.7775533E-02
     +,   3.0721741E-02,   3.3684660E-02,   3.6608580E-02
     +,   3.9529700E-02,   4.2557783E-02,   4.5785446E-02
     +,   4.9178105E-02,   5.2502967E-02,   5.5333368E-02
     +,   5.7160303E-02,   5.7605553E-02,   5.6605648E-02
     +,   5.4362725E-02,   5.1083528E-02,   4.6814710E-02
     +,   4.1574631E-02,   3.5593923E-02,   2.9355962E-02
     +,   2.3398982E-02,   1.8105863E-02,   1.3642146E-02
     +,   1.0020181E-02,   7.1783778E-03,   5.0256508E-03
     +,   3.4548179E-03,   2.3504680E-03,   1.5985905E-03
     +,   1.0976385E-03,   7.6596666E-04,   5.4387754E-04
     +,   3.9139090E-04,   2.8350492E-04,   2.0526745E-04
     +,   1.4772976E-04,   1.0528542E-04,   7.4118630E-05
     +,   5.1444229E-05,   3.5139630E-05,   2.3574888E-05
     +,   1.5499811E-05,   9.9645604E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz113 = Yx/0.303382978723404
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0262684E-04,   1.0548066E-04
     +,   1.0831664E-04,   1.1112999E-04,   1.1391589E-04
     +,   1.1666969E-04,   1.1938690E-04,   1.2206317E-04
     +,   1.2469433E-04,   1.2727664E-04,   1.2980640E-04
     +,   1.3228031E-04,   1.3469531E-04,   1.3704869E-04
     +,   1.3933818E-04,   1.4156179E-04,   1.4371789E-04
     +,   1.4580532E-04,   1.4782329E-04,   1.4977138E-04
     +,   1.5164973E-04,   1.5345871E-04,   1.5519919E-04
     +,   1.5687253E-04,   1.5848030E-04,   1.6002462E-04
     +,   1.6150800E-04,   1.6293327E-04,   1.6430355E-04
     +,   1.6562240E-04,   1.6689362E-04,   1.6812125E-04
     +,   1.6930985E-04,   1.7046393E-04,   1.7158827E-04
     +,   1.7268801E-04,   1.7376826E-04,   1.7483428E-04
     +,   1.7589152E-04,   1.7694538E-04,   1.7800150E-04
     +,   1.7906529E-04,   1.8014222E-04,   1.8123773E-04
     +,   1.8235709E-04,   1.8350557E-04,   1.8468832E-04
     +,   1.8591012E-04,   1.8717570E-04,   1.8848952E-04
     +,   1.8985587E-04,   1.9127858E-04,   1.9276125E-04
     +,   1.9430733E-04,   1.9591964E-04,   1.9760091E-04
     +,   1.9935309E-04,   2.0117834E-04,   2.0307778E-04
     +,   2.0505236E-04,   2.0710274E-04,   2.0922897E-04
     +,   2.1143058E-04,   2.1370685E-04,   2.1605646E-04
     +,   2.1847770E-04,   2.2096850E-04,   2.2352600E-04
     +,   2.2614746E-04,   2.2882930E-04,   2.3156778E-04
     +,   2.3435858E-04,   2.3719740E-04,   2.4007905E-04
     +,   2.4299865E-04,   2.4595088E-04,   2.4892995E-04
     +,   2.5192989E-04,   2.5494499E-04,   2.5796922E-04
     +,   2.6099611E-04,   2.6401979E-04,   2.6703384E-04
     +,   2.7003209E-04,   2.7300854E-04,   2.7595714E-04
     +,   2.7887212E-04,   2.8174784E-04,   2.8457871E-04
     +,   2.8735958E-04,   2.9008556E-04,   2.9275191E-04
     +,   2.9535423E-04,   2.9788841E-04,   3.0035083E-04
     +,   3.0273787E-04,   3.0504665E-04,   3.0727423E-04
     +,   3.0941825E-04,   3.1147659E-04,   3.1344738E-04
     +,   3.1532906E-04,   3.1712046E-04,   3.1882062E-04
     +,   3.2042863E-04,   3.2194419E-04,   3.2336678E-04
     +,   3.2469630E-04,   3.2593284E-04,   3.2707647E-04
     +,   3.2812770E-04,   3.2908650E-04,   3.2995362E-04
     +,   3.3072953E-04,   3.3141498E-04,   3.3201036E-04
     +,   3.3251659E-04,   3.3293435E-04,   3.3326447E-04
     +,   3.3350795E-04,   3.3366543E-04,   3.3373811E-04
     +,   3.3372690E-04,   3.3363313E-04,   3.3345787E-04
     +,   3.3320262E-04,   3.3286886E-04,   3.3245835E-04
     +,   3.3197284E-04,   3.3141454E-04,   3.3078576E-04
     +,   3.3008904E-04,   3.2932736E-04,   3.2850384E-04
     +,   3.2762188E-04,   3.2668535E-04,   3.2569846E-04
     +,   3.2466592E-04,   3.2359231E-04,   3.2248328E-04
     +,   3.2134415E-04,   3.2018145E-04,   3.1900164E-04
     +,   3.1781127E-04,   3.1661781E-04,   3.1542886E-04
     +,   3.1425231E-04,   3.1309651E-04,   3.1197022E-04
     +,   3.1088199E-04,   3.0984101E-04,   3.0885695E-04
     +,   3.0793887E-04,   3.0709672E-04,   3.0634017E-04
     +,   3.0567916E-04,   3.0512354E-04,   3.0468346E-04
     +,   3.0436870E-04,   3.0418939E-04,   3.0415566E-04
     +,   3.0427711E-04,   3.0456416E-04,   3.0502645E-04
     +,   3.0567448E-04,   3.0651802E-04,   3.0756774E-04
     +,   3.0883416E-04,   3.1032861E-04,   3.1206239E-04
     +,   3.1404797E-04,   3.1629839E-04,   3.1882786E-04
     +,   3.2165227E-04,   3.2478839E-04,   3.2825550E-04
     +,   3.3207505E-04,   3.3627095E-04,   3.4087006E-04
     +,   3.4590263E-04,   3.5140288E-04,   3.5740907E-04
     +,   3.6396337E-04,   3.7111362E-04,   3.7891284E-04
     +,   3.8741864E-04,   3.9669458E-04,   4.0680970E-04
     +,   4.1783976E-04,   4.2986375E-04,   4.4296769E-04
     +,   4.5724178E-04,   4.7278008E-04,   4.8967975E-04
     +,   5.0804205E-04,   5.2796974E-04,   5.4956588E-04
     +,   5.7293294E-04,   5.9817394E-04,   6.2539038E-04
     +,   6.5468036E-04,   6.8613817E-04,   7.1985781E-04
     +,   7.5592985E-04,   7.9443859E-04,   8.3547045E-04
     +,   8.7910722E-04,   9.2542649E-04,   9.7449892E-04
     +,   1.0263915E-03,   1.0811614E-03,   1.1388462E-03
     +,   1.1994606E-03,   1.2629984E-03,   1.3294207E-03
     +,   1.3986527E-03,   1.4705879E-03,   1.5451018E-03
     +,   1.6220652E-03,   1.7013602E-03,   1.7829320E-03
     +,   1.8668207E-03,   1.9532072E-03,   2.0424679E-03
     +,   2.1352295E-03,   2.2324035E-03,   2.3352134E-03
     +,   2.4452007E-03,   2.5642128E-03,   2.6943483E-03
     +,   2.8378572E-03,   2.9970130E-03,   3.1739559E-03
     +,   3.3704820E-03,   3.5877835E-03,   3.8262601E-03
     +,   4.0852716E-03,   4.3630172E-03,   4.6565575E-03
     +,   4.9621314E-03,   5.2758208E-03,   5.5946419E-03
     +,   5.9181112E-03,   6.2499503E-03,   6.5994747E-03
     +,   6.9819838E-03,   7.4176658E-03,   7.9286955E-03
     +,   8.5349279E-03,   9.2491675E-03,   1.0074118E-02
     +,   1.1003172E-02,   1.2026889E-02,   1.3144663E-02
     +,   1.4375625E-02,   1.5757237E-02,   1.7323611E-02
     +,   1.9068394E-02,   2.0918628E-02,   2.2748481E-02
     +,   2.4440255E-02,   2.5962416E-02,   2.7422136E-02
     +,   2.9064214E-02,   3.1206427E-02,   3.4110751E-02
     +,   3.7827134E-02,   4.2109720E-02,   4.6477783E-02
     +,   5.0373461E-02,   5.3295866E-02,   5.4864738E-02
     +,   5.4849382E-02,   5.3188875E-02,   4.9994808E-02
     +,   4.5529637E-02,   4.0160064E-02,   3.4299668E-02
     +,   2.8353166E-02,   2.2679241E-02,   1.7563317E-02
     +,   1.3196991E-02,   9.6624289E-03,   6.9377949E-03
     +,   4.9226419E-03,   3.4779818E-03,   2.4622476E-03
     +,   1.7542862E-03,   1.2610736E-03,   9.1554789E-04
     +,   6.7120121E-04,   4.9641321E-04,   3.7003926E-04
     +,   2.7794548E-04,   2.1055448E-04,   1.6114015E-04
     +,   1.2482662E-04,   9.8003926E-05,   7.8014607E-05
     +,   6.2933024E-05,   5.1399897E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz114 = Yx/0.283872340425532
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz1148(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1588034E-05,   6.3140411E-05
     +,   6.4720683E-05,   6.6329201E-05,   6.7966321E-05
     +,   6.9632413E-05,   7.1327828E-05,   7.3052943E-05
     +,   7.4808071E-05,   7.6593686E-05,   7.8410114E-05
     +,   8.0257829E-05,   8.2137267E-05,   8.4048894E-05
     +,   8.5993292E-05,   8.7971050E-05,   8.9982866E-05
     +,   9.2029462E-05,   9.4111747E-05,   9.6230702E-05
     +,   9.8387434E-05,   1.0058330E-04,   1.0281969E-04
     +,   1.0509837E-04,   1.0742110E-04,   1.0979015E-04
     +,   1.1220792E-04,   1.1467709E-04,   1.1720066E-04
     +,   1.1978205E-04,   1.2242491E-04,   1.2513335E-04
     +,   1.2791176E-04,   1.3076505E-04,   1.3369836E-04
     +,   1.3671737E-04,   1.3982794E-04,   1.4303642E-04
     +,   1.4634953E-04,   1.4977404E-04,   1.5331726E-04
     +,   1.5698638E-04,   1.6078894E-04,   1.6473240E-04
     +,   1.6882420E-04,   1.7307160E-04,   1.7748147E-04
     +,   1.8206061E-04,   1.8681485E-04,   1.9174979E-04
     +,   1.9686997E-04,   2.0217894E-04,   2.0767914E-04
     +,   2.1337219E-04,   2.1925745E-04,   2.2533348E-04
     +,   2.3159670E-04,   2.3804202E-04,   2.4466199E-04
     +,   2.5144755E-04,   2.5838733E-04,   2.6546774E-04
     +,   2.7267289E-04,   2.7998511E-04,   2.8738464E-04
     +,   2.9484869E-04,   3.0235379E-04,   3.0987355E-04
     +,   3.1738056E-04,   3.2484534E-04,   3.3223798E-04
     +,   3.3952660E-04,   3.4667959E-04,   3.5366378E-04
     +,   3.6044692E-04,   3.6699700E-04,   3.7328195E-04
     +,   3.7927090E-04,   3.8493480E-04,   3.9024599E-04
     +,   3.9517874E-04,   3.9970988E-04,   4.0381862E-04
     +,   4.0748753E-04,   4.1070208E-04,   4.1345140E-04
     +,   4.1572770E-04,   4.1752728E-04,   4.1885010E-04
     +,   4.1969950E-04,   4.2008370E-04,   4.2001280E-04
     +,   4.1950229E-04,   4.1856981E-04,   4.1723691E-04
     +,   4.1552761E-04,   4.1346904E-04,   4.1109050E-04
     +,   4.0842307E-04,   4.0550029E-04,   4.0235621E-04
     +,   3.9902609E-04,   3.9554591E-04,   3.9195217E-04
     +,   3.8828026E-04,   3.8456547E-04,   3.8084245E-04
     +,   3.7714443E-04,   3.7350284E-04,   3.6994737E-04
     +,   3.6650596E-04,   3.6320381E-04,   3.6006398E-04
     +,   3.5710627E-04,   3.5434845E-04,   3.5180498E-04
     +,   3.4948732E-04,   3.4740410E-04,   3.4556090E-04
     +,   3.4396048E-04,   3.4260267E-04,   3.4148450E-04
     +,   3.4060021E-04,   3.3994182E-04,   3.3949883E-04
     +,   3.3925852E-04,   3.3920596E-04,   3.3932531E-04
     +,   3.3959813E-04,   3.4000547E-04,   3.4052684E-04
     +,   3.4114113E-04,   3.4182690E-04,   3.4256207E-04
     +,   3.4332465E-04,   3.4409313E-04,   3.4484605E-04
     +,   3.4556325E-04,   3.4622473E-04,   3.4681259E-04
     +,   3.4730972E-04,   3.4770073E-04,   3.4797218E-04
     +,   3.4811240E-04,   3.4811164E-04,   3.4796307E-04
     +,   3.4766085E-04,   3.4720279E-04,   3.4658826E-04
     +,   3.4581951E-04,   3.4490071E-04,   3.4383888E-04
     +,   3.4264300E-04,   3.4132448E-04,   3.3989645E-04
     +,   3.3837470E-04,   3.3677625E-04,   3.3512028E-04
     +,   3.3342693E-04,   3.3171827E-04,   3.3001724E-04
     +,   3.2834787E-04,   3.2673500E-04,   3.2520411E-04
     +,   3.2378131E-04,   3.2249329E-04,   3.2136680E-04
     +,   3.2042890E-04,   3.1970724E-04,   3.1922932E-04
     +,   3.1902327E-04,   3.1911756E-04,   3.1954155E-04
     +,   3.2032479E-04,   3.2149840E-04,   3.2309443E-04
     +,   3.2514686E-04,   3.2769126E-04,   3.3076564E-04
     +,   3.3441070E-04,   3.3867036E-04,   3.4359167E-04
     +,   3.4922545E-04,   3.5562736E-04,   3.6285730E-04
     +,   3.7098056E-04,   3.8006701E-04,   3.9019337E-04
     +,   4.0144229E-04,   4.1390222E-04,   4.2767037E-04
     +,   4.4285131E-04,   4.5955781E-04,   4.7791083E-04
     +,   4.9804442E-04,   5.2010379E-04,   5.4424698E-04
     +,   5.7064532E-04,   5.9948955E-04,   6.3098938E-04
     +,   6.6537200E-04,   7.0288492E-04,   7.4379850E-04
     +,   7.8840478E-04,   8.3701004E-04,   8.8993728E-04
     +,   9.4752293E-04,   1.0101058E-03,   1.0780233E-03
     +,   1.1516131E-03,   1.2312058E-03,   1.3171191E-03
     +,   1.4096634E-03,   1.5091498E-03,   1.6158945E-03
     +,   1.7302148E-03,   1.8524382E-03,   1.9829047E-03
     +,   2.1219503E-03,   2.2698604E-03,   2.4268515E-03
     +,   2.5929995E-03,   2.7681524E-03,   2.9518600E-03
     +,   3.1433420E-03,   3.3414478E-03,   3.5446868E-03
     +,   3.7513881E-03,   3.9599398E-03,   4.1691051E-03
     +,   4.3783751E-03,   4.5883274E-03,   4.8008594E-03
     +,   5.0191684E-03,   5.2473913E-03,   5.4900497E-03
     +,   5.7511297E-03,   6.0332050E-03,   6.3367719E-03
     +,   6.6601913E-03,   7.0003592E-03,   7.3540569E-03
     +,   7.7198795E-03,   8.0999574E-03,   8.5007660E-03
     +,   8.9324843E-03,   9.4071077E-03,   9.9359779E-03
     +,   1.0528092E-02,   1.1189812E-02,   1.1925663E-02
     +,   1.2738485E-02,   1.3627270E-02,   1.4583901E-02
     +,   1.5591654E-02,   1.6628496E-02,   1.7676516E-02
     +,   1.8734360E-02,   1.9827543E-02,   2.1011194E-02
     +,   2.2360314E-02,   2.3945067E-02,   2.5799626E-02
     +,   2.7904678E-02,   3.0200697E-02,   3.2618076E-02
     +,   3.5092447E-02,   3.7559539E-02,   3.9951958E-02
     +,   4.2200793E-02,   4.4211257E-02,   4.5816276E-02
     +,   4.6763994E-02,   4.6777193E-02,   4.5650352E-02
     +,   4.3321725E-02,   3.9893426E-02,   3.5609487E-02
     +,   3.0805899E-02,   2.5848212E-02,   2.1067282E-02
     +,   1.6713314E-02,   1.2934973E-02,   9.7870305E-03
     +,   7.2527262E-03,   5.2722823E-03,   3.7655022E-03
     +,   2.6477652E-03,   1.8388195E-03,   1.2668913E-03
     +,   8.7088469E-04,   6.0105551E-04,   4.1897557E-04
     +,   2.9639335E-04,   2.1351138E-04,   1.5691570E-04
     +,   1.1772459E-04,   9.0102243E-05,   7.0231115E-05
     +,   5.5613706E-05,   4.4623859E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz1148 = Yx/0.287744680851064
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3713086E-04,   1.4001153E-04
     +,   1.4285975E-04,   1.4567406E-04,   1.4845301E-04
     +,   1.5119572E-04,   1.5390161E-04,   1.5657024E-04
     +,   1.5920175E-04,   1.6179663E-04,   1.6435568E-04
     +,   1.6688000E-04,   1.6937120E-04,   1.7183130E-04
     +,   1.7426234E-04,   1.7666721E-04,   1.7904879E-04
     +,   1.8141053E-04,   1.8375613E-04,   1.8608954E-04
     +,   1.8841522E-04,   1.9073776E-04,   1.9306196E-04
     +,   1.9539311E-04,   1.9773643E-04,   2.0009754E-04
     +,   2.0248232E-04,   2.0489642E-04,   2.0734601E-04
     +,   2.0983687E-04,   2.1237538E-04,   2.1496757E-04
     +,   2.1761937E-04,   2.2033688E-04,   2.2312591E-04
     +,   2.2599219E-04,   2.2894106E-04,   2.3197786E-04
     +,   2.3510758E-04,   2.3833457E-04,   2.4166303E-04
     +,   2.4509680E-04,   2.4863900E-04,   2.5229205E-04
     +,   2.5605821E-04,   2.5993868E-04,   2.6393414E-04
     +,   2.6804442E-04,   2.7226840E-04,   2.7660458E-04
     +,   2.8104996E-04,   2.8560110E-04,   2.9025335E-04
     +,   2.9500114E-04,   2.9983785E-04,   3.0475619E-04
     +,   3.0974729E-04,   3.1480161E-04,   3.1990875E-04
     +,   3.2505716E-04,   3.3023453E-04,   3.3542776E-04
     +,   3.4062230E-04,   3.4580391E-04,   3.5095756E-04
     +,   3.5606700E-04,   3.6111652E-04,   3.6608905E-04
     +,   3.7096915E-04,   3.7573947E-04,   3.8038453E-04
     +,   3.8488809E-04,   3.8923521E-04,   3.9341158E-04
     +,   3.9740349E-04,   4.0119904E-04,   4.0478722E-04
     +,   4.0815835E-04,   4.1130520E-04,   4.1422187E-04
     +,   4.1690437E-04,   4.1935183E-04,   4.2156485E-04
     +,   4.2354694E-04,   4.2530405E-04,   4.2684449E-04
     +,   4.2818024E-04,   4.2932498E-04,   4.3029559E-04
     +,   4.3111143E-04,   4.3179476E-04,   4.3237026E-04
     +,   4.3286479E-04,   4.3330761E-04,   4.3373008E-04
     +,   4.3416503E-04,   4.3464726E-04,   4.3521202E-04
     +,   4.3589575E-04,   4.3673592E-04,   4.3776882E-04
     +,   4.3903160E-04,   4.4055970E-04,   4.4238786E-04
     +,   4.4454844E-04,   4.4707244E-04,   4.4998722E-04
     +,   4.5331698E-04,   4.5708264E-04,   4.6130145E-04
     +,   4.6598475E-04,   4.7113985E-04,   4.7676833E-04
     +,   4.8286663E-04,   4.8942410E-04,   4.9642631E-04
     +,   5.0385029E-04,   5.1166856E-04,   5.1984657E-04
     +,   5.2834407E-04,   5.3711579E-04,   5.4610998E-04
     +,   5.5527012E-04,   5.6453579E-04,   5.7384273E-04
     +,   5.8312243E-04,   5.9230556E-04,   6.0131861E-04
     +,   6.1009027E-04,   6.1854627E-04,   6.2661641E-04
     +,   6.3422974E-04,   6.4131955E-04,   6.4782152E-04
     +,   6.5367867E-04,   6.5883604E-04,   6.6324731E-04
     +,   6.6687167E-04,   6.6967646E-04,   6.7163579E-04
     +,   6.7273353E-04,   6.7296164E-04,   6.7232072E-04
     +,   6.7081919E-04,   6.6847581E-04,   6.6531630E-04
     +,   6.6137535E-04,   6.5669563E-04,   6.5132644E-04
     +,   6.4532395E-04,   6.3874951E-04,   6.3167122E-04
     +,   6.2416145E-04,   6.1629491E-04,   6.0815027E-04
     +,   5.9980789E-04,   5.9134990E-04,   5.8285764E-04
     +,   5.7441305E-04,   5.6609698E-04,   5.5798772E-04
     +,   5.5016187E-04,   5.4269243E-04,   5.3564983E-04
     +,   5.2909943E-04,   5.2310259E-04,   5.1771640E-04
     +,   5.1299308E-04,   5.0897920E-04,   5.0571706E-04
     +,   5.0324324E-04,   5.0158973E-04,   5.0078332E-04
     +,   5.0084572E-04,   5.0179492E-04,   5.0364342E-04
     +,   5.0640013E-04,   5.1007024E-04,   5.1465526E-04
     +,   5.2015402E-04,   5.2656175E-04,   5.3387170E-04
     +,   5.4207572E-04,   5.5116398E-04,   5.6112645E-04
     +,   5.7195325E-04,   5.8363593E-04,   5.9616979E-04
     +,   6.0955470E-04,   6.2379515E-04,   6.3890911E-04
     +,   6.5492466E-04,   6.7188492E-04,   6.8985409E-04
     +,   7.0891954E-04,   7.2919694E-04,   7.5083156E-04
     +,   7.7400147E-04,   7.9892331E-04,   8.2584855E-04
     +,   8.5506431E-04,   8.8688685E-04,   9.2166284E-04
     +,   9.5975923E-04,   1.0015494E-03,   1.0474158E-03
     +,   1.0977315E-03,   1.1528539E-03,   1.2131149E-03
     +,   1.2788266E-03,   1.3502724E-03,   1.4277041E-03
     +,   1.5113478E-03,   1.6014148E-03,   1.6980967E-03
     +,   1.8015620E-03,   1.9119516E-03,   2.0293873E-03
     +,   2.1539554E-03,   2.2856854E-03,   2.4245898E-03
     +,   2.5706561E-03,   2.7238920E-03,   2.8843922E-03
     +,   3.0524279E-03,   3.2285247E-03,   3.4135401E-03
     +,   3.6087134E-03,   3.8156537E-03,   4.0362631E-03
     +,   4.2725350E-03,   4.5263814E-03,   4.7994154E-03
     +,   5.0927633E-03,   5.4068891E-03,   5.7416004E-03
     +,   6.0959449E-03,   6.4681415E-03,   6.8554021E-03
     +,   7.2538396E-03,   7.6584257E-03,   8.0633415E-03
     +,   8.4629236E-03,   8.8532837E-03,   9.2342263E-03
     +,   9.6108820E-03,   9.9945050E-03,   1.0401385E-02
     +,   1.0850134E-02,   1.1357708E-02,   1.1935760E-02
     +,   1.2588436E-02,   1.3312510E-02,   1.4100703E-02
     +,   1.4946838E-02,   1.5851464E-02,   1.6824288E-02
     +,   1.7880457E-02,   1.9029584E-02,   2.0262793E-02
     +,   2.1548590E-02,   2.2845922E-02,   2.4132719E-02
     +,   2.5430605E-02,   2.6804473E-02,   2.8327283E-02
     +,   3.0025449E-02,   3.1840779E-02,   3.3636786E-02
     +,   3.5247054E-02,   3.6532812E-02,   3.7412293E-02
     +,   3.7847076E-02,   3.7802935E-02,   3.7219040E-02
     +,   3.6011048E-02,   3.4107704E-02,   3.1500194E-02
     +,   2.8276790E-02,   2.4623133E-02,   2.0787226E-02
     +,   1.7027032E-02,   1.3558965E-02,   1.0528008E-02
     +,   7.9994723E-03,   5.9714732E-03,   4.3957797E-03
     +,   3.2007920E-03,   2.3099640E-03,   1.6533282E-03
     +,   1.1731457E-03,   8.2451181E-04,   5.7368848E-04
     +,   3.9542693E-04,   2.7069653E-04,   1.8493844E-04
     +,   1.2700426E-04,   8.8432062E-05,   6.2961451E-05
     +,   4.6102821E-05,   3.4761695E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz116 = Yx/0.273148936170213
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2180686E-04,   1.2590073E-04
     +,   1.3006937E-04,   1.3431016E-04,   1.3862041E-04
     +,   1.4299683E-04,   1.4743606E-04,   1.5193460E-04
     +,   1.5648849E-04,   1.6109359E-04,   1.6574570E-04
     +,   1.7044017E-04,   1.7517200E-04,   1.7993651E-04
     +,   1.8472828E-04,   1.8954210E-04,   1.9437227E-04
     +,   1.9921323E-04,   2.0405914E-04,   2.0890415E-04
     +,   2.1374218E-04,   2.1856734E-04,   2.2337334E-04
     +,   2.2815441E-04,   2.3290410E-04,   2.3761662E-04
     +,   2.4228584E-04,   2.4690593E-04,   2.5147101E-04
     +,   2.5597546E-04,   2.6041389E-04,   2.6478092E-04
     +,   2.6907129E-04,   2.7328019E-04,   2.7740307E-04
     +,   2.8143567E-04,   2.8537397E-04,   2.8921402E-04
     +,   2.9295275E-04,   2.9658733E-04,   3.0011492E-04
     +,   3.0353363E-04,   3.0684183E-04,   3.1003819E-04
     +,   3.1312215E-04,   3.1609356E-04,   3.1895269E-04
     +,   3.2170050E-04,   3.2433870E-04,   3.2686931E-04
     +,   3.2929514E-04,   3.3161970E-04,   3.3384678E-04
     +,   3.3598169E-04,   3.3802958E-04,   3.3999688E-04
     +,   3.4189064E-04,   3.4371862E-04,   3.4548918E-04
     +,   3.4721196E-04,   3.4889710E-04,   3.5055535E-04
     +,   3.5219852E-04,   3.5383942E-04,   3.5549089E-04
     +,   3.5716724E-04,   3.5888309E-04,   3.6065374E-04
     +,   3.6249516E-04,   3.6442355E-04,   3.6645625E-04
     +,   3.6860982E-04,   3.7090192E-04,   3.7334967E-04
     +,   3.7597047E-04,   3.7878149E-04,   3.8179947E-04
     +,   3.8503978E-04,   3.8851774E-04,   3.9224778E-04
     +,   3.9624207E-04,   4.0051225E-04,   4.0506746E-04
     +,   4.0991564E-04,   4.1506157E-04,   4.2050870E-04
     +,   4.2625674E-04,   4.3230344E-04,   4.3864295E-04
     +,   4.4526631E-04,   4.5216229E-04,   4.5931540E-04
     +,   4.6670632E-04,   4.7431383E-04,   4.8211243E-04
     +,   4.9007352E-04,   4.9816596E-04,   5.0635496E-04
     +,   5.1460386E-04,   5.2287278E-04,   5.3112156E-04
     +,   5.3930603E-04,   5.4738298E-04,   5.5530661E-04
     +,   5.6303182E-04,   5.7051389E-04,   5.7770807E-04
     +,   5.8457017E-04,   5.9105892E-04,   5.9713435E-04
     +,   6.0275826E-04,   6.0789665E-04,   6.1251794E-04
     +,   6.1659433E-04,   6.2010158E-04,   6.2302017E-04
     +,   6.2533392E-04,   6.2703242E-04,   6.2810775E-04
     +,   6.2855845E-04,   6.2838627E-04,   6.2759762E-04
     +,   6.2620267E-04,   6.2421686E-04,   6.2165764E-04
     +,   6.1854662E-04,   6.1490916E-04,   6.1077264E-04
     +,   6.0616754E-04,   6.0112617E-04,   5.9568271E-04
     +,   5.8987277E-04,   5.8373320E-04,   5.7730213E-04
     +,   5.7061767E-04,   5.6371820E-04,   5.5664266E-04
     +,   5.4943020E-04,   5.4211874E-04,   5.3474569E-04
     +,   5.2734942E-04,   5.1996636E-04,   5.1263289E-04
     +,   5.0538429E-04,   4.9825571E-04,   4.9128156E-04
     +,   4.8449522E-04,   4.7793068E-04,   4.7162038E-04
     +,   4.6559752E-04,   4.5989393E-04,   4.5454246E-04
     +,   4.4957528E-04,   4.4502495E-04,   4.4092370E-04
     +,   4.3730409E-04,   4.3419914E-04,   4.3164115E-04
     +,   4.2966352E-04,   4.2829913E-04,   4.2757994E-04
     +,   4.2753934E-04,   4.2820774E-04,   4.2961672E-04
     +,   4.3179549E-04,   4.3477162E-04,   4.3857083E-04
     +,   4.4321592E-04,   4.4872635E-04,   4.5511869E-04
     +,   4.6240402E-04,   4.7058819E-04,   4.7967295E-04
     +,   4.8965280E-04,   5.0051569E-04,   5.1224302E-04
     +,   5.2480988E-04,   5.3818343E-04,   5.5232371E-04
     +,   5.6718563E-04,   5.8271992E-04,   5.9887097E-04
     +,   6.1558251E-04,   6.3279847E-04,   6.5046508E-04
     +,   6.6853256E-04,   6.8696047E-04,   7.0572126E-04
     +,   7.2480226E-04,   7.4420974E-04,   7.6397340E-04
     +,   7.8414968E-04,   8.0482406E-04,   8.2611054E-04
     +,   8.4816047E-04,   8.7115233E-04,   8.9529721E-04
     +,   9.2082989E-04,   9.4800844E-04,   9.7710418E-04
     +,   1.0083895E-03,   1.0421304E-03,   1.0785756E-03
     +,   1.1179431E-03,   1.1604049E-03,   1.2060858E-03
     +,   1.2550568E-03,   1.3073321E-03,   1.3628834E-03
     +,   1.4216579E-03,   1.4836113E-03,   1.5487314E-03
     +,   1.6171010E-03,   1.6889448E-03,   1.7646876E-03
     +,   1.8449875E-03,   1.9307799E-03,   2.0232857E-03
     +,   2.1239882E-03,   2.2345551E-03,   2.3567642E-03
     +,   2.4923456E-03,   2.6428236E-03,   2.8093420E-03
     +,   2.9925450E-03,   3.1924688E-03,   3.4085196E-03
     +,   3.6395856E-03,   3.8842754E-03,   4.1412180E-03
     +,   4.4095013E-03,   4.6891146E-03,   4.9814358E-03
     +,   5.2895430E-03,   5.6182933E-03,   5.9742131E-03
     +,   6.3648303E-03,   6.7976164E-03,   7.2785234E-03
     +,   7.8102774E-03,   8.3905580E-03,   9.0105031E-03
     +,   9.6539874E-03,   1.0298156E-02,   1.0915587E-02
     +,   1.1478510E-02,   1.1964823E-02,   1.2365150E-02
     +,   1.2688823E-02,   1.2966976E-02,   1.3250711E-02
     +,   1.3603440E-02,   1.4088669E-02,   1.4755314E-02
     +,   1.5625333E-02,   1.6688010E-02,   1.7903984E-02
     +,   1.9218924E-02,   2.0582477E-02,   2.1962922E-02
     +,   2.3349857E-02,   2.4742138E-02,   2.6126593E-02
     +,   2.7462924E-02,   2.8686909E-02,   2.9735629E-02
     +,   3.0578192E-02,   3.1232396E-02,   3.1753581E-02
     +,   3.2199107E-02,   3.2585528E-02,   3.2860711E-02
     +,   3.2905120E-02,   3.2564674E-02,   3.1702287E-02
     +,   3.0245725E-02,   2.8211370E-02,   2.5697015E-02
     +,   2.2851240E-02,   1.9838650E-02,   1.6812904E-02
     +,   1.3904773E-02,   1.1217549E-02,   8.8266954E-03
     +,   6.7778276E-03,   5.0866301E-03,   3.7404764E-03
     +,   2.7047819E-03,   1.9317715E-03,   1.3693024E-03
     +,   9.6820795E-04,   6.8638992E-04,   4.9042655E-04
     +,   3.5508262E-04,   2.6200232E-04,   1.9809161E-04
     +,   1.5414068E-04,   1.2371203E-04,   1.0235469E-04
     +,   8.7023676E-05,   7.5674856E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz117 = Yx/0.266595744680851
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.7808454E-05,   7.0207643E-05
     +,   7.2706745E-05,   7.5309712E-05,   7.8020516E-05
     +,   8.0843216E-05,   8.3781830E-05,   8.6840344E-05
     +,   9.0022797E-05,   9.3333219E-05,   9.6775490E-05
     +,   1.0035355E-04,   1.0407114E-04,   1.0793206E-04
     +,   1.1193982E-04,   1.1609806E-04,   1.2041003E-04
     +,   1.2487892E-04,   1.2950780E-04,   1.3429955E-04
     +,   1.3925676E-04,   1.4438191E-04,   1.4967695E-04
     +,   1.5514425E-04,   1.6078501E-04,   1.6660090E-04
     +,   1.7259293E-04,   1.7876182E-04,   1.8510803E-04
     +,   1.9163163E-04,   1.9833221E-04,   2.0520932E-04
     +,   2.1226179E-04,   2.1948824E-04,   2.2688667E-04
     +,   2.3445504E-04,   2.4219057E-04,   2.5008991E-04
     +,   2.5815002E-04,   2.6636623E-04,   2.7473446E-04
     +,   2.8324980E-04,   2.9190682E-04,   3.0069961E-04
     +,   3.0962197E-04,   3.1866727E-04,   3.2782814E-04
     +,   3.3709707E-04,   3.4646597E-04,   3.5592643E-04
     +,   3.6546958E-04,   3.7508603E-04,   3.8476603E-04
     +,   3.9449977E-04,   4.0427616E-04,   4.1408479E-04
     +,   4.2391423E-04,   4.3375263E-04,   4.4358807E-04
     +,   4.5340793E-04,   4.6319931E-04,   4.7294915E-04
     +,   4.8264305E-04,   4.9226749E-04,   5.0180784E-04
     +,   5.1124860E-04,   5.2057521E-04,   5.2977051E-04
     +,   5.3881935E-04,   5.4770435E-04,   5.5640860E-04
     +,   5.6491437E-04,   5.7320390E-04,   5.8125926E-04
     +,   5.8906164E-04,   5.9659331E-04,   6.0383487E-04
     +,   6.1076839E-04,   6.1737472E-04,   6.2363717E-04
     +,   6.2953669E-04,   6.3505716E-04,   6.4018235E-04
     +,   6.4489688E-04,   6.4918655E-04,   6.5303873E-04
     +,   6.5644219E-04,   6.5938837E-04,   6.6186866E-04
     +,   6.6387781E-04,   6.6541345E-04,   6.6647428E-04
     +,   6.6706201E-04,   6.6718151E-04,   6.6683977E-04
     +,   6.6604652E-04,   6.6481443E-04,   6.6315918E-04
     +,   6.6109805E-04,   6.5865193E-04,   6.5584399E-04
     +,   6.5269897E-04,   6.4924365E-04,   6.4550753E-04
     +,   6.4152101E-04,   6.3731574E-04,   6.3292391E-04
     +,   6.2837842E-04,   6.2371383E-04,   6.1896245E-04
     +,   6.1415776E-04,   6.0933188E-04,   6.0451619E-04
     +,   5.9974071E-04,   5.9503340E-04,   5.9042074E-04
     +,   5.8592774E-04,   5.8157602E-04,   5.7738554E-04
     +,   5.7337357E-04,   5.6955474E-04,   5.6594110E-04
     +,   5.6254247E-04,   5.5936532E-04,   5.5641436E-04
     +,   5.5369141E-04,   5.5119605E-04,   5.4892665E-04
     +,   5.4687861E-04,   5.4504618E-04,   5.4342288E-04
     +,   5.4199982E-04,   5.4076826E-04,   5.3971924E-04
     +,   5.3884229E-04,   5.3812802E-04,   5.3756713E-04
     +,   5.3715060E-04,   5.3687114E-04,   5.3672167E-04
     +,   5.3669768E-04,   5.3679460E-04,   5.3701125E-04
     +,   5.3734763E-04,   5.3780543E-04,   5.3838966E-04
     +,   5.3910597E-04,   5.3996348E-04,   5.4097321E-04
     +,   5.4214767E-04,   5.4350193E-04,   5.4505270E-04
     +,   5.4681790E-04,   5.4881832E-04,   5.5107393E-04
     +,   5.5360701E-04,   5.5644003E-04,   5.5959518E-04
     +,   5.6309596E-04,   5.6696427E-04,   5.7122210E-04
     +,   5.7589106E-04,   5.8099005E-04,   5.8653776E-04
     +,   5.9255143E-04,   5.9904653E-04,   6.0603692E-04
     +,   6.1353378E-04,   6.2154763E-04,   6.3008728E-04
     +,   6.3915888E-04,   6.4876786E-04,   6.5891870E-04
     +,   6.6961435E-04,   6.8085623E-04,   6.9264579E-04
     +,   7.0498459E-04,   7.1787252E-04,   7.3130999E-04
     +,   7.4529776E-04,   7.5983704E-04,   7.7492947E-04
     +,   7.9057622E-04,   8.0678152E-04,   8.2354969E-04
     +,   8.4088620E-04,   8.5879839E-04,   8.7729684E-04
     +,   8.9639472E-04,   9.1610779E-04,   9.3645899E-04
     +,   9.5747714E-04,   9.7919744E-04,   1.0016666E-03
     +,   1.0249458E-03,   1.0491103E-03,   1.0742560E-03
     +,   1.1005012E-03,   1.1279917E-03,   1.1569065E-03
     +,   1.1874571E-03,   1.2198910E-03,   1.2544977E-03
     +,   1.2916090E-03,   1.3315888E-03,   1.3748375E-03
     +,   1.4217857E-03,   1.4728758E-03,   1.5285544E-03
     +,   1.5892545E-03,   1.6553822E-03,   1.7272820E-03
     +,   1.8052204E-03,   1.8893717E-03,   1.9797969E-03
     +,   2.0764242E-03,   2.1790629E-03,   2.2874209E-03
     +,   2.4011380E-03,   2.5198283E-03,   2.6431778E-03
     +,   2.7710027E-03,   2.9033362E-03,   3.0404797E-03
     +,   3.1830543E-03,   3.3319907E-03,   3.4884657E-03
     +,   3.6538749E-03,   3.8297607E-03,   4.0178113E-03
     +,   4.2198333E-03,   4.4378736E-03,   4.6742782E-03
     +,   4.9317651E-03,   5.2133156E-03,   5.5219578E-03
     +,   5.8603226E-03,   6.2299841E-03,   6.6308421E-03
     +,   7.0607560E-03,   7.5155152E-03,   7.9896757E-03
     +,   8.4781405E-03,   8.9783799E-03,   9.4926376E-03
     +,   1.0029383E-02,   1.0603569E-02,   1.1235300E-02
     +,   1.1946914E-02,   1.2758989E-02,   1.3685281E-02
     +,   1.4726882E-02,   1.5866246E-02,   1.7064014E-02
     +,   1.8261364E-02,   1.9389978E-02,   2.0388909E-02
     +,   2.1223061E-02,   2.1896366E-02,   2.2452543E-02
     +,   2.2962324E-02,   2.3501107E-02,   2.4124816E-02
     +,   2.4854975E-02,   2.5679013E-02,   2.6563896E-02
     +,   2.7473900E-02,   2.8381007E-02,   2.9261278E-02
     +,   3.0080756E-02,   3.0778620E-02,   3.1258255E-02
     +,   3.1393845E-02,   3.1053128E-02,   3.0131349E-02
     +,   2.8584944E-02,   2.6450848E-02,   2.3844115E-02
     +,   2.0934219E-02,   1.7911702E-02,   1.4954539E-02
     +,   1.2205116E-02,   9.7583290E-03,   7.6619522E-03
     +,   5.9232158E-03,   4.5202300E-03,   3.4131627E-03
     +,   2.5547007E-03,   1.8976480E-03,   1.3994671E-03
     +,   1.0245069E-03,   7.4410881E-04,   5.3588120E-04
     +,   3.8244884E-04,   2.7039653E-04,   1.8933140E-04
     +,   1.3125488E-04,   9.0045716E-05,   6.1087660E-05
     +,   4.0938063E-05,   2.7067110E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz118 = Yx/0.259913043478261
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2406849E-04,   1.2857845E-04
     +,   1.3321827E-04,   1.3799040E-04,   1.4289710E-04
     +,   1.4794072E-04,   1.5312344E-04,   1.5844723E-04
     +,   1.6391423E-04,   1.6952648E-04,   1.7528556E-04
     +,   1.8119327E-04,   1.8725111E-04,   1.9346029E-04
     +,   1.9982217E-04,   2.0633765E-04,   2.1300766E-04
     +,   2.1983251E-04,   2.2681282E-04,   2.3394842E-04
     +,   2.4123922E-04,   2.4868455E-04,   2.5628338E-04
     +,   2.6403493E-04,   2.7193697E-04,   2.7998773E-04
     +,   2.8818427E-04,   2.9652362E-04,   3.0500197E-04
     +,   3.1361473E-04,   3.2235691E-04,   3.3122284E-04
     +,   3.4020570E-04,   3.4929827E-04,   3.5849176E-04
     +,   3.6777745E-04,   3.7714464E-04,   3.8658211E-04
     +,   3.9607767E-04,   4.0561747E-04,   4.1518724E-04
     +,   4.2477113E-04,   4.3435238E-04,   4.4391275E-04
     +,   4.5343325E-04,   4.6289386E-04,   4.7227312E-04
     +,   4.8154918E-04,   4.9069867E-04,   4.9969845E-04
     +,   5.0852355E-04,   5.1714946E-04,   5.2555115E-04
     +,   5.3370319E-04,   5.4158043E-04,   5.4915814E-04
     +,   5.5641122E-04,   5.6331669E-04,   5.6985102E-04
     +,   5.7599292E-04,   5.8172247E-04,   5.8702129E-04
     +,   5.9187243E-04,   5.9626199E-04,   6.0017803E-04
     +,   6.0361112E-04,   6.0655549E-04,   6.0900708E-04
     +,   6.1096612E-04,   6.1243557E-04,   6.1342202E-04
     +,   6.1393494E-04,   6.1398820E-04,   6.1359804E-04
     +,   6.1278447E-04,   6.1157125E-04,   6.0998485E-04
     +,   6.0805480E-04,   6.0581247E-04,   6.0329301E-04
     +,   6.0053280E-04,   5.9757067E-04,   5.9444649E-04
     +,   5.9120113E-04,   5.8787613E-04,   5.8451400E-04
     +,   5.8115600E-04,   5.7784328E-04,   5.7461654E-04
     +,   5.7151366E-04,   5.6857133E-04,   5.6582468E-04
     +,   5.6330505E-04,   5.6104147E-04,   5.5905903E-04
     +,   5.5738026E-04,   5.5602385E-04,   5.5500388E-04
     +,   5.5433105E-04,   5.5401208E-04,   5.5404974E-04
     +,   5.5444281E-04,   5.5518659E-04,   5.5627199E-04
     +,   5.5768841E-04,   5.5942056E-04,   5.6145055E-04
     +,   5.6375971E-04,   5.6632515E-04,   5.6912442E-04
     +,   5.7213259E-04,   5.7532528E-04,   5.7867623E-04
     +,   5.8216089E-04,   5.8575411E-04,   5.8943202E-04
     +,   5.9317186E-04,   5.9695222E-04,   6.0075335E-04
     +,   6.0455763E-04,   6.0834864E-04,   6.1211310E-04
     +,   6.1583857E-04,   6.1951502E-04,   6.2313461E-04
     +,   6.2669115E-04,   6.3017919E-04,   6.3359615E-04
     +,   6.3693908E-04,   6.4020697E-04,   6.4339821E-04
     +,   6.4651301E-04,   6.4955064E-04,   6.5251015E-04
     +,   6.5539067E-04,   6.5819127E-04,   6.6090911E-04
     +,   6.6354213E-04,   6.6608674E-04,   6.6853891E-04
     +,   6.7089399E-04,   6.7314756E-04,   6.7529496E-04
     +,   6.7733118E-04,   6.7925151E-04,   6.8105431E-04
     +,   6.8273681E-04,   6.8429980E-04,   6.8574573E-04
     +,   6.8707980E-04,   6.8831060E-04,   6.8945112E-04
     +,   6.9051707E-04,   6.9153059E-04,   6.9251779E-04
     +,   6.9350994E-04,   6.9454359E-04,   6.9566187E-04
     +,   6.9691287E-04,   6.9834944E-04,   7.0003135E-04
     +,   7.0202298E-04,   7.0439238E-04,   7.0721359E-04
     +,   7.1056309E-04,   7.1452098E-04,   7.1916892E-04
     +,   7.2458968E-04,   7.3086633E-04,   7.3808199E-04
     +,   7.4631628E-04,   7.5564592E-04,   7.6614332E-04
     +,   7.7787571E-04,   7.9090195E-04,   8.0527464E-04
     +,   8.2103634E-04,   8.3822035E-04,   8.5684884E-04
     +,   8.7693526E-04,   8.9848245E-04,   9.2148129E-04
     +,   9.4591477E-04,   9.7175880E-04,   9.9898281E-04
     +,   1.0275494E-03,   1.0574197E-03,   1.0885547E-03
     +,   1.1209187E-03,   1.1544755E-03,   1.1891973E-03
     +,   1.2250653E-03,   1.2620664E-03,   1.3001950E-03
     +,   1.3394614E-03,   1.3798847E-03,   1.4214921E-03
     +,   1.4643257E-03,   1.5084399E-03,   1.5539058E-03
     +,   1.6008094E-03,   1.6492549E-03,   1.6993737E-03
     +,   1.7513194E-03,   1.8052687E-03,   1.8614298E-03
     +,   1.9200332E-03,   1.9813182E-03,   2.0455311E-03
     +,   2.1129032E-03,   2.1836343E-03,   2.2578540E-03
     +,   2.3356143E-03,   2.4168598E-03,   2.5014235E-03
     +,   2.5889955E-03,   2.6791592E-03,   2.7714139E-03
     +,   2.8652188E-03,   2.9600419E-03,   3.0554456E-03
     +,   3.1511625E-03,   3.2471512E-03,   3.3436737E-03
     +,   3.4413326E-03,   3.5411036E-03,   3.6443206E-03
     +,   3.7526619E-03,   3.8681326E-03,   3.9930441E-03
     +,   4.1300063E-03,   4.2819716E-03,   4.4523189E-03
     +,   4.6449881E-03,   4.8645404E-03,   5.1162154E-03
     +,   5.4057338E-03,   5.7388102E-03,   6.1203879E-03
     +,   6.5537044E-03,   7.0393751E-03,   7.5748060E-03
     +,   8.1545329E-03,   8.7714167E-03,   9.4184009E-03
     +,   1.0090319E-02,   1.0785067E-02,   1.1503287E-02
     +,   1.2246627E-02,   1.3015377E-02,   1.3806342E-02
     +,   1.4612202E-02,   1.5422016E-02,   1.6222984E-02
     +,   1.7002454E-02,   1.7749440E-02,   1.8456759E-02
     +,   1.9123102E-02,   1.9755198E-02,   2.0367710E-02
     +,   2.0980455E-02,   2.1612257E-02,   2.2274368E-02
     +,   2.2965536E-02,   2.3671573E-02,   2.4368195E-02
     +,   2.5026111E-02,   2.5614712E-02,   2.6103703E-02
     +,   2.6461704E-02,   2.6653500E-02,   2.6638156E-02
     +,   2.6370063E-02,   2.5804255E-02,   2.4905212E-02
     +,   2.3657283E-02,   2.2073083E-02,   2.0197485E-02
     +,   1.8104529E-02,   1.5888812E-02,   1.3652281E-02
     +,   1.1491251E-02,   9.4846841E-03,   7.6878783E-03
     +,   6.1302478E-03,   4.8181182E-03,   3.7396702E-03
     +,   2.8714330E-03,   2.1843042E-03,   1.6480411E-03
     +,   1.2344625E-03,   9.1884198E-04,   6.8043015E-04
     +,   5.0215644E-04,   3.7020005E-04,   2.7344047E-04
     +,   2.0304756E-04,   1.5209496E-04,   1.1527399E-04
     +,   8.8601089E-05,   6.9168185E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz119 = Yx/0.24804347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5877496E-04,   1.6337686E-04
     +,   1.6802709E-04,   1.7272696E-04,   1.7747813E-04
     +,   1.8228311E-04,   1.8714482E-04,   1.9206709E-04
     +,   1.9705424E-04,   2.0211174E-04,   2.0724552E-04
     +,   2.1246244E-04,   2.1777011E-04,   2.2317706E-04
     +,   2.2869244E-04,   2.3432657E-04,   2.4009020E-04
     +,   2.4599503E-04,   2.5205340E-04,   2.5827825E-04
     +,   2.6468304E-04,   2.7128163E-04,   2.7808832E-04
     +,   2.8511792E-04,   2.9238427E-04,   2.9990220E-04
     +,   3.0768558E-04,   3.1574783E-04,   3.2410186E-04
     +,   3.3275923E-04,   3.4173043E-04,   3.5102447E-04
     +,   3.6064893E-04,   3.7060847E-04,   3.8090607E-04
     +,   3.9154233E-04,   4.0251430E-04,   4.1381631E-04
     +,   4.2543991E-04,   4.3737199E-04,   4.4959679E-04
     +,   4.6209415E-04,   4.7484037E-04,   4.8780785E-04
     +,   5.0096447E-04,   5.1427458E-04,   5.2769936E-04
     +,   5.4119562E-04,   5.5471738E-04,   5.6821533E-04
     +,   5.8163819E-04,   5.9493200E-04,   6.0804008E-04
     +,   6.2090717E-04,   6.3347508E-04,   6.4568722E-04
     +,   6.5748725E-04,   6.6881935E-04,   6.7963166E-04
     +,   6.8987359E-04,   6.9949840E-04,   7.0846389E-04
     +,   7.1673212E-04,   7.2427082E-04,   7.3105295E-04
     +,   7.3705852E-04,   7.4227294E-04,   7.4668980E-04
     +,   7.5030903E-04,   7.5313722E-04,   7.5518893E-04
     +,   7.5648486E-04,   7.5705332E-04,   7.5692858E-04
     +,   7.5615005E-04,   7.5476413E-04,   7.5282127E-04
     +,   7.5037620E-04,   7.4748707E-04,   7.4421515E-04
     +,   7.4062357E-04,   7.3677656E-04,   7.3273818E-04
     +,   7.2857272E-04,   7.2434323E-04,   7.2010927E-04
     +,   7.1592955E-04,   7.1185722E-04,   7.0794334E-04
     +,   7.0423260E-04,   7.0076471E-04,   6.9757510E-04
     +,   6.9469179E-04,   6.9213758E-04,   6.8992830E-04
     +,   6.8807410E-04,   6.8657869E-04,   6.8544003E-04
     +,   6.8464916E-04,   6.8419299E-04,   6.8405183E-04
     +,   6.8420201E-04,   6.8461546E-04,   6.8525999E-04
     +,   6.8610057E-04,   6.8709900E-04,   6.8821496E-04
     +,   6.8940723E-04,   6.9063361E-04,   6.9185096E-04
     +,   6.9301692E-04,   6.9409021E-04,   6.9503044E-04
     +,   6.9579988E-04,   6.9636211E-04,   6.9668388E-04
     +,   6.9673575E-04,   6.9649029E-04,   6.9592387E-04
     +,   6.9501810E-04,   6.9375697E-04,   6.9212890E-04
     +,   6.9012656E-04,   6.8774691E-04,   6.8498886E-04
     +,   6.8185839E-04,   6.7836203E-04,   6.7451166E-04
     +,   6.7032082E-04,   6.6580781E-04,   6.6099194E-04
     +,   6.5589696E-04,   6.5054576E-04,   6.4496649E-04
     +,   6.3918601E-04,   6.3323427E-04,   6.2714121E-04
     +,   6.2093796E-04,   6.1465625E-04,   6.0832733E-04
     +,   6.0198316E-04,   5.9565541E-04,   5.8937538E-04
     +,   5.8317295E-04,   5.7707867E-04,   5.7112123E-04
     +,   5.6532887E-04,   5.5972877E-04,   5.5434712E-04
     +,   5.4920791E-04,   5.4433593E-04,   5.3975271E-04
     +,   5.3548027E-04,   5.3153746E-04,   5.2794366E-04
     +,   5.2471663E-04,   5.2187237E-04,   5.1942677E-04
     +,   5.1739346E-04,   5.1578652E-04,   5.1461876E-04
     +,   5.1390281E-04,   5.1364943E-04,   5.1387097E-04
     +,   5.1457842E-04,   5.1578286E-04,   5.1749666E-04
     +,   5.1973131E-04,   5.2249955E-04,   5.2581477E-04
     +,   5.2969059E-04,   5.3414283E-04,   5.3918653E-04
     +,   5.4484064E-04,   5.5112212E-04,   5.5805111E-04
     +,   5.6564843E-04,   5.7393516E-04,   5.8293395E-04
     +,   5.9266825E-04,   6.0316233E-04,   6.1444059E-04
     +,   6.2652823E-04,   6.3945068E-04,   6.5323553E-04
     +,   6.6791050E-04,   6.8350323E-04,   7.0004642E-04
     +,   7.1757362E-04,   7.3612126E-04,   7.5573247E-04
     +,   7.7645626E-04,   7.9834706E-04,   8.2146871E-04
     +,   8.4589660E-04,   8.7171613E-04,   8.9902343E-04
     +,   9.2792779E-04,   9.5855113E-04,   9.9102897E-04
     +,   1.0255039E-03,   1.0621316E-03,   1.1010766E-03
     +,   1.1425156E-03,   1.1866302E-03,   1.2336170E-03
     +,   1.2836875E-03,   1.3370720E-03,   1.3940218E-03
     +,   1.4548285E-03,   1.5198165E-03,   1.5893480E-03
     +,   1.6638258E-03,   1.7436870E-03,   1.8293951E-03
     +,   1.9214080E-03,   2.0201674E-03,   2.1260765E-03
     +,   2.2394801E-03,   2.3606352E-03,   2.4897414E-03
     +,   2.6269362E-03,   2.7723231E-03,   2.9259999E-03
     +,   3.0881146E-03,   3.2588602E-03,   3.4384567E-03
     +,   3.6271184E-03,   3.8250065E-03,   4.0321345E-03
     +,   4.2483099E-03,   4.4731591E-03,   4.7061956E-03
     +,   4.9470272E-03,   5.1955539E-03,   5.4523237E-03
     +,   5.7187304E-03,   5.9971237E-03,   6.2907534E-03
     +,   6.6034123E-03,   6.9389646E-03,   7.3006912E-03
     +,   7.6908534E-03,   8.1107058E-03,   8.5608186E-03
     +,   9.0420321E-03,   9.5565449E-03,   1.0108580E-02
     +,   1.0704084E-02,   1.1348754E-02,   1.2045260E-02
     +,   1.2789843E-02,   1.3570325E-02,   1.4366613E-02
     +,   1.5154470E-02,   1.5911318E-02,   1.6622772E-02
     +,   1.7287031E-02,   1.7916037E-02,   1.8532325E-02
     +,   1.9163204E-02,   1.9833311E-02,   2.0557957E-02
     +,   2.1337567E-02,   2.2154896E-02,   2.2975016E-02
     +,   2.3748683E-02,   2.4418393E-02,   2.4926290E-02
     +,   2.5221562E-02,   2.5265558E-02,   2.5034292E-02
     +,   2.4518138E-02,   2.3720633E-02,   2.2657070E-02
     +,   2.1353409E-02,   1.9844960E-02,   1.8175256E-02
     +,   1.6393617E-02,   1.4553218E-02,   1.2708025E-02
     +,   1.0910701E-02,   9.2089660E-03,   7.6431530E-03
     +,   6.2428052E-03,   5.0252904E-03,   3.9949762E-03
     +,   3.1447145E-03,   2.4585261E-03,   1.9148245E-03
     +,   1.4899869E-03,   1.1609715E-03,   9.0728299E-04
     +,   7.1176578E-04,   5.6080101E-04,   4.4389002E-04
     +,   3.5311747E-04,   2.8251432E-04,   2.2756372E-04
     +,   1.8478507E-04,   1.5147039E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz120 = Yx/0.230239130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8530008E-05,   4.0135990E-05
     +,   4.1799591E-05,   4.3522326E-05,   4.5305802E-05
     +,   4.7151625E-05,   4.9061535E-05,   5.1037274E-05
     +,   5.3080643E-05,   5.5193617E-05,   5.7378184E-05
     +,   5.9636484E-05,   6.1970699E-05,   6.4383225E-05
     +,   6.6876608E-05,   6.9453534E-05,   7.2116920E-05
     +,   7.4869982E-05,   7.7716133E-05,   8.0659236E-05
     +,   8.3703453E-05,   8.6853477E-05,   9.0114489E-05
     +,   9.3492425E-05,   9.6993710E-05,   1.0062587E-04
     +,   1.0439716E-04,   1.0831706E-04,   1.1239618E-04
     +,   1.1664647E-04,   1.2108152E-04,   1.2571641E-04
     +,   1.3056812E-04,   1.3565557E-04,   1.4099982E-04
     +,   1.4662401E-04,   1.5255372E-04,   1.5881677E-04
     +,   1.6544390E-04,   1.7246767E-04,   1.7992400E-04
     +,   1.8785089E-04,   1.9628965E-04,   2.0528404E-04
     +,   2.1488173E-04,   2.2513370E-04,   2.3609580E-04
     +,   2.4782959E-04,   2.6040370E-04,   2.7389618E-04
     +,   2.8839658E-04,   3.0400915E-04,   3.2085646E-04
     +,   3.3908346E-04,   3.5885905E-04,   3.8038249E-04
     +,   4.0388230E-04,   4.2961779E-04,   4.5787625E-04
     +,   4.8896659E-04,   5.2321068E-04,   5.6093035E-04
     +,   6.0242898E-04,   6.4798183E-04,   6.9781963E-04
     +,   7.5211882E-04,   8.1102061E-04,   8.7464706E-04
     +,   9.4316795E-04,   1.0168697E-03,   1.0962846E-03
     +,   1.1823035E-03,   1.2763417E-03,   1.3804353E-03
     +,   1.4973520E-03,   1.6305976E-03,   1.7843362E-03
     +,   1.9632461E-03,   2.1722901E-03,   2.4164431E-03
     +,   2.7003798E-03,   3.0283292E-03,   3.4039549E-03
     +,   3.8306508E-03,   4.3120319E-03,   4.8529496E-03
     +,   5.4603610E-03,   6.1440887E-03,   6.9164662E-03
     +,   7.7913515E-03,   8.7822853E-03,   9.9003874E-03
     +,   1.1151799E-02,   1.2534438E-02,   1.4034786E-02
     +,   1.5628882E-02,   1.7292801E-02,   1.9018847E-02
     +,   2.0825058E-02,   2.2738557E-02,   2.4755754E-02
     +,   2.6809392E-02,   2.8779600E-02,   3.0543538E-02
     +,   3.2018308E-02,   3.3161368E-02,   3.3953976E-02
     +,   3.4409080E-02,   3.4591392E-02,   3.4593310E-02
     +,   3.4461446E-02,   3.4146588E-02,   3.3544529E-02
     +,   3.2586649E-02,   3.1283718E-02,   2.9687881E-02
     +,   2.7838202E-02,   2.5761152E-02,   2.3517674E-02
     +,   2.1230735E-02,   1.9055754E-02,   1.7118212E-02
     +,   1.5469966E-02,   1.4089980E-02,   1.2917445E-02
     +,   1.1888314E-02,   1.0957050E-02,   1.0101630E-02
     +,   9.3174716E-03,   8.6084632E-03,   7.9787346E-03
     +,   7.4279141E-03,   6.9491370E-03,   6.5302835E-03
     +,   6.1566732E-03,   5.8144131E-03,   5.4929033E-03
     +,   5.1859468E-03,   4.8914179E-03,   4.6100500E-03
     +,   4.3438654E-03,   4.0947706E-03,   3.8636997E-03
     +,   3.6502881E-03,   3.4530957E-03,   3.2699856E-03
     +,   3.0986511E-03,   2.9370533E-03,   2.7836650E-03
     +,   2.6375393E-03,   2.4982635E-03,   2.3658087E-03
     +,   2.2403579E-03,   2.1221258E-03,   2.0112572E-03
     +,   1.9077653E-03,   1.8115045E-03,   1.7221817E-03
     +,   1.6393929E-03,   1.5626791E-03,   1.4915479E-03
     +,   1.4255118E-03,   1.3641125E-03,   1.3069282E-03
     +,   1.2535731E-03,   1.2036953E-03,   1.1569858E-03
     +,   1.1131587E-03,   1.0719600E-03,   1.0331611E-03
     +,   9.9657115E-04,   9.6203014E-04,   9.2941482E-04
     +,   8.9863932E-04,   8.6966011E-04,   8.4246777E-04
     +,   8.1708573E-04,   7.9356652E-04,   7.7198312E-04
     +,   7.5241976E-04,   7.3496485E-04,   7.1970496E-04
     +,   7.0671499E-04,   6.9605117E-04,   6.8774715E-04
     +,   6.8181130E-04,   6.7822327E-04,   6.7693065E-04
     +,   6.7785196E-04,   6.8087719E-04,   6.8586948E-04
     +,   6.9266633E-04,   7.0108485E-04,   7.1092491E-04
     +,   7.2197372E-04,   7.3400675E-04,   7.4679544E-04
     +,   7.6010759E-04,   7.7371451E-04,   7.8739133E-04
     +,   8.0092368E-04,   8.1410602E-04,   8.2674832E-04
     +,   8.3867786E-04,   8.4973889E-04,   8.5979601E-04
     +,   8.6873671E-04,   8.7646919E-04,   8.8292419E-04
     +,   8.8805624E-04,   8.9184218E-04,   8.9428091E-04
     +,   8.9539232E-04,   8.9521444E-04,   8.9380622E-04
     +,   8.9123956E-04,   8.8760414E-04,   8.8299945E-04
     +,   8.7753474E-04,   8.7132741E-04,   8.6450035E-04
     +,   8.5717678E-04,   8.4948330E-04,   8.4154343E-04
     +,   8.3347649E-04,   8.2539645E-04,   8.1741001E-04
     +,   8.0961693E-04,   8.0210465E-04,   7.9495134E-04
     +,   7.8822376E-04,   7.8197615E-04,   7.7625090E-04
     +,   7.7107863E-04,   7.6647662E-04,   7.6245214E-04
     +,   7.5899897E-04,   7.5610162E-04,   7.5373385E-04
     +,   7.5185898E-04,   7.5043261E-04,   7.4940157E-04
     +,   7.4870640E-04,   7.4828032E-04,   7.4805110E-04
     +,   7.4794289E-04,   7.4787531E-04,   7.4776588E-04
     +,   7.4752921E-04,   7.4708101E-04,   7.4633531E-04
     +,   7.4520748E-04,   7.4361684E-04,   7.4148318E-04
     +,   7.3873263E-04,   7.3529436E-04,   7.3110574E-04
     +,   7.2610856E-04,   7.2025479E-04,   7.1350310E-04
     +,   7.0582167E-04,   6.9718919E-04,   6.8759313E-04
     +,   6.7703152E-04,   6.6551322E-04,   6.5305684E-04
     +,   6.3969061E-04,   6.2545360E-04,   6.1039376E-04
     +,   5.9456652E-04,   5.7803461E-04,   5.6086859E-04
     +,   5.4314418E-04,   5.2494108E-04,   5.0634175E-04
     +,   4.8743226E-04,   4.6829818E-04,   4.4902650E-04
     +,   4.2970054E-04,   4.1040394E-04,   3.9121494E-04
     +,   3.7220988E-04,   3.5345776E-04,   3.3502514E-04
     +,   3.1697017E-04,   2.9934756E-04,   2.8220355E-04
     +,   2.6557824E-04,   2.4950696E-04,   2.3401678E-04
     +,   2.1913057E-04,   2.0486329E-04,   1.9122678E-04
     +,   1.7822548E-04,   1.6586130E-04,   1.5412975E-04
     +,   1.4302465E-04,   1.3253471E-04,   1.2264712E-04
     +,   1.1334542E-04,   1.0461232E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz75 = Yx/0.277170212765957
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.2826555E-05,   8.5139451E-05
     +,   8.7425717E-05,   8.9680107E-05,   9.1897324E-05
     +,   9.4072224E-05,   9.6199663E-05,   9.8274664E-05
     +,   1.0029239E-04,   1.0224824E-04,   1.0413770E-04
     +,   1.0595658E-04,   1.0770090E-04,   1.0936694E-04
     +,   1.1095138E-04,   1.1245113E-04,   1.1386348E-04
     +,   1.1518617E-04,   1.1641718E-04,   1.1755509E-04
     +,   1.1859871E-04,   1.1954738E-04,   1.2040101E-04
     +,   1.2115985E-04,   1.2182463E-04,   1.2239673E-04
     +,   1.2287787E-04,   1.2327047E-04,   1.2357738E-04
     +,   1.2380211E-04,   1.2394869E-04,   1.2402180E-04
     +,   1.2402669E-04,   1.2396937E-04,   1.2385641E-04
     +,   1.2369515E-04,   1.2349361E-04,   1.2326060E-04
     +,   1.2300571E-04,   1.2273928E-04,   1.2247259E-04
     +,   1.2221774E-04,   1.2198769E-04,   1.2179639E-04
     +,   1.2165868E-04,   1.2159037E-04,   1.2160825E-04
     +,   1.2173016E-04,   1.2197486E-04,   1.2236228E-04
     +,   1.2291332E-04,   1.2365007E-04,   1.2459574E-04
     +,   1.2577498E-04,   1.2721363E-04,   1.2893933E-04
     +,   1.3098147E-04,   1.3337164E-04,   1.3614388E-04
     +,   1.3933536E-04,   1.4298687E-04,   1.4714358E-04
     +,   1.5185551E-04,   1.5717903E-04,   1.6317787E-04
     +,   1.6992314E-04,   1.7749636E-04,   1.8598884E-04
     +,   1.9550489E-04,   2.0616132E-04,   2.1809139E-04
     +,   2.3144380E-04,   2.4638823E-04,   2.6311449E-04
     +,   2.8183870E-04,   3.0280720E-04,   3.2630004E-04
     +,   3.5263874E-04,   3.8219575E-04,   4.1540287E-04
     +,   4.5275677E-04,   4.9483479E-04,   5.4229388E-04
     +,   5.9588411E-04,   6.5643684E-04,   7.2487263E-04
     +,   8.0217503E-04,   8.8939222E-04,   9.8760379E-04
     +,   1.0979262E-03,   1.2214992E-03,   1.3594831E-03
     +,   1.5130717E-03,   1.6835107E-03,   1.8720805E-03
     +,   2.0800231E-03,   2.3084607E-03,   2.5581459E-03
     +,   2.8292388E-03,   3.1209285E-03,   3.4312587E-03
     +,   3.7570270E-03,   4.0943362E-03,   4.4396925E-03
     +,   4.7921254E-03,   5.1559685E-03,   5.5435984E-03
     +,   5.9769410E-03,   6.4860638E-03,   7.1034450E-03
     +,   7.8543061E-03,   8.7457141E-03,   9.7591430E-03
     +,   1.0853465E-02,   1.1981371E-02,   1.3116554E-02
     +,   1.4277011E-02,   1.5527112E-02,   1.6948439E-02
     +,   1.8597024E-02,   2.0478116E-02,   2.2558082E-02
     +,   2.4789743E-02,   2.7107142E-02,   2.9383343E-02
     +,   3.1410225E-02,   3.2962471E-02,   3.3920012E-02
     +,   3.4340091E-02,   3.4396458E-02,   3.4231465E-02
     +,   3.3852540E-02,   3.3153836E-02,   3.2021780E-02
     +,   3.0430114E-02,   2.8471639E-02,   2.6329368E-02
     +,   2.4207825E-02,   2.2259500E-02,   2.0544915E-02
     +,   1.9045450E-02,   1.7708115E-02,   1.6486637E-02
     +,   1.5357225E-02,   1.4312445E-02,   1.3347749E-02
     +,   1.2453315E-02,   1.1613926E-02,   1.0814073E-02
     +,   1.0043017E-02,   9.2973933E-03,   8.5804192E-03
     +,   7.8988858E-03,   7.2597759E-03,   6.6678016E-03
     +,   6.1244303E-03,   5.6282319E-03,   5.1760436E-03
     +,   4.7642607E-03,   4.3897606E-03,   4.0501184E-03
     +,   3.7434604E-03,   3.4680814E-03,   3.2220744E-03
     +,   3.0031139E-03,   2.8085064E-03,   2.6354031E-03
     +,   2.4810613E-03,   2.3430595E-03,   2.2194842E-03
     +,   2.1089651E-03,   2.0106081E-03,   1.9238751E-03
     +,   1.8484398E-03,   1.7840548E-03,   1.7304366E-03
     +,   1.6871907E-03,   1.6537827E-03,   1.6295159E-03
     +,   1.6135441E-03,   1.6048964E-03,   1.6025051E-03
     +,   1.6052405E-03,   1.6119509E-03,   1.6214952E-03
     +,   1.6327797E-03,   1.6447899E-03,   1.6566206E-03
     +,   1.6675038E-03,   1.6768125E-03,   1.6840870E-03
     +,   1.6890256E-03,   1.6914831E-03,   1.6914593E-03
     +,   1.6890798E-03,   1.6845720E-03,   1.6782380E-03
     +,   1.6704280E-03,   1.6615082E-03,   1.6518350E-03
     +,   1.6417303E-03,   1.6314602E-03,   1.6212170E-03
     +,   1.6111105E-03,   1.6011645E-03,   1.5913155E-03
     +,   1.5814218E-03,   1.5712726E-03,   1.5606075E-03
     +,   1.5491331E-03,   1.5365405E-03,   1.5225313E-03
     +,   1.5068363E-03,   1.4892307E-03,   1.4695484E-03
     +,   1.4476996E-03,   1.4236708E-03,   1.3975283E-03
     +,   1.3694150E-03,   1.3395478E-03,   1.3082034E-03
     +,   1.2757014E-03,   1.2423972E-03,   1.2086624E-03
     +,   1.1748637E-03,   1.1413511E-03,   1.1084478E-03
     +,   1.0764340E-03,   1.0455383E-03,   1.0159352E-03
     +,   9.8774058E-04,   9.6101582E-04,   9.3576551E-04
     +,   9.1194687E-04,   8.8947627E-04,   8.6823839E-04
     +,   8.4809185E-04,   8.2888355E-04,   8.1045390E-04
     +,   7.9264439E-04,   7.7530491E-04,   7.5830193E-04
     +,   7.4151932E-04,   7.2486256E-04,   7.0825906E-04
     +,   6.9166068E-04,   6.7504199E-04,   6.5839605E-04
     +,   6.4173480E-04,   6.2508637E-04,   6.0848886E-04
     +,   5.9198885E-04,   5.7563902E-04,   5.5949303E-04
     +,   5.4360350E-04,   5.2801863E-04,   5.1278184E-04
     +,   4.9792923E-04,   4.8348733E-04,   4.6947369E-04
     +,   4.5589695E-04,   4.4275649E-04,   4.3004207E-04
     +,   4.1773589E-04,   4.0581386E-04,   3.9424552E-04
     +,   3.8299631E-04,   3.7202926E-04,   3.6130598E-04
     +,   3.5078765E-04,   3.4043632E-04,   3.3021695E-04
     +,   3.2009839E-04,   3.1005230E-04,   3.0005534E-04
     +,   2.9009013E-04,   2.8014337E-04,   2.7020852E-04
     +,   2.6028304E-04,   2.5037056E-04,   2.4047805E-04
     +,   2.3061819E-04,   2.2080557E-04,   2.1105938E-04
     +,   2.0139967E-04,   1.9184947E-04,   1.8243174E-04
     +,   1.7317008E-04,   1.6408865E-04,   1.5520975E-04
     +,   1.4655557E-04,   1.3814568E-04,   1.2999872E-04
     +,   1.2213014E-04,   1.1455403E-04,   1.0728104E-04
     +,   1.0032018E-04,   9.3677030E-05,   8.7355555E-05
     +,   8.1356477E-05,   7.5679141E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz80 = Yx/0.270468085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.3459913E-05,   6.5096763E-05
     +,   6.6721273E-05,   6.8330468E-05,   6.9921334E-05
     +,   7.1490897E-05,   7.3036157E-05,   7.4554213E-05
     +,   7.6042095E-05,   7.7497025E-05,   7.8916215E-05
     +,   8.0297046E-05,   8.1636892E-05,   8.2933344E-05
     +,   8.4184088E-05,   8.5387008E-05,   8.6540102E-05
     +,   8.7641558E-05,   8.8689849E-05,   8.9683519E-05
     +,   9.0621448E-05,   9.1502683E-05,   9.2326576E-05
     +,   9.3092742E-05,   9.3800976E-05,   9.4451410E-05
     +,   9.5044488E-05,   9.5580886E-05,   9.6061623E-05
     +,   9.6487951E-05,   9.6861513E-05,   9.7184122E-05
     +,   9.7457989E-05,   9.7685654E-05,   9.7869794E-05
     +,   9.8013552E-05,   9.8120239E-05,   9.8193494E-05
     +,   9.8237149E-05,   9.8255390E-05,   9.8252647E-05
     +,   9.8233526E-05,   9.8202843E-05,   9.8165794E-05
     +,   9.8127603E-05,   9.8093857E-05,   9.8070224E-05
     +,   9.8062606E-05,   9.8077100E-05,   9.8120057E-05
     +,   9.8197939E-05,   9.8317461E-05,   9.8485543E-05
     +,   9.8709337E-05,   9.8996228E-05,   9.9353965E-05
     +,   9.9790559E-05,   1.0031441E-04,   1.0093430E-04
     +,   1.0165962E-04,   1.0250017E-04,   1.0346654E-04
     +,   1.0456995E-04,   1.0582254E-04,   1.0723759E-04
     +,   1.0882919E-04,   1.1061305E-04,   1.1260602E-04
     +,   1.1482677E-04,   1.1729560E-04,   1.2003499E-04
     +,   1.2306927E-04,   1.2642544E-04,   1.3013261E-04
     +,   1.3422291E-04,   1.3873135E-04,   1.4369581E-04
     +,   1.4915728E-04,   1.5516058E-04,   1.6175430E-04
     +,   1.6899053E-04,   1.7692654E-04,   1.8562352E-04
     +,   1.9514920E-04,   2.0557616E-04,   2.1698499E-04
     +,   2.2946244E-04,   2.4310505E-04,   2.5801655E-04
     +,   2.7431105E-04,   2.9211247E-04,   3.1155220E-04
     +,   3.3276915E-04,   3.5590949E-04,   3.8112237E-04
     +,   4.0855395E-04,   4.3834886E-04,   4.7063804E-04
     +,   5.0554285E-04,   5.4316275E-04,   5.8358227E-04
     +,   6.2686397E-04,   6.7306485E-04,   7.2223973E-04
     +,   7.7446847E-04,   8.2988437E-04,   8.8870677E-04
     +,   9.5129159E-04,   1.0181871E-03,   1.0901865E-03
     +,   1.1683650E-03,   1.2541296E-03,   1.3492003E-03
     +,   1.4555876E-03,   1.5754761E-03,   1.7111097E-03
     +,   1.8645742E-03,   2.0376618E-03,   2.2317073E-03
     +,   2.4476142E-03,   2.6859760E-03,   2.9473258E-03
     +,   3.2325080E-03,   3.5430461E-03,   3.8814426E-03
     +,   4.2514508E-03,   4.6585258E-03,   5.1101707E-03
     +,   5.6161517E-03,   6.1875894E-03,   6.8345824E-03
     +,   7.5622853E-03,   8.3680749E-03,   9.2430711E-03
     +,   1.0181786E-02,   1.1196871E-02,   1.2329956E-02
     +,   1.3645772E-02,   1.5205095E-02,   1.7028751E-02
     +,   1.9074593E-02,   2.1241777E-02,   2.3396164E-02
     +,   2.5400031E-02,   2.7136652E-02,   2.8531792E-02
     +,   2.9569751E-02,   3.0291665E-02,   3.0765379E-02
     +,   3.1041270E-02,   3.1133249E-02,   3.1038975E-02
     +,   3.0759662E-02,   3.0282697E-02,   2.9560596E-02
     +,   2.8545622E-02,   2.7263179E-02,   2.5830457E-02
     +,   2.4380350E-02,   2.2965407E-02,   2.1539243E-02
     +,   2.0026430E-02,   1.8404117E-02,   1.6726092E-02
     +,   1.5088574E-02,   1.3581936E-02,   1.2263319E-02
     +,   1.1152986E-02,   1.0241278E-02,   9.4965417E-03
     +,   8.8737076E-03,   8.3247665E-03,   7.8098816E-03
     +,   7.3048589E-03,   6.8026446E-03,   6.3094473E-03
     +,   5.8385534E-03,   5.4044621E-03,   5.0188750E-03
     +,   4.6887929E-03,   4.4162851E-03,   4.1991519E-03
     +,   4.0320340E-03,   3.9076172E-03,   3.8177602E-03
     +,   3.7544449E-03,   3.7103477E-03,   3.6791919E-03
     +,   3.6558118E-03,   3.6360661E-03,   3.6166406E-03
     +,   3.5948430E-03,   3.5684288E-03,   3.5354639E-03
     +,   3.4942757E-03,   3.4434651E-03,   3.3819759E-03
     +,   3.3091863E-03,   3.2250118E-03,   3.1299866E-03
     +,   3.0252959E-03,   2.9127551E-03,   2.7947028E-03
     +,   2.6738672E-03,   2.5531945E-03,   2.4356251E-03
     +,   2.3239129E-03,   2.2204779E-03,   2.1272560E-03
     +,   2.0456384E-03,   1.9764320E-03,   1.9198850E-03
     +,   1.8757273E-03,   1.8432377E-03,   1.8213303E-03
     +,   1.8086497E-03,   1.8036474E-03,   1.8046659E-03
     +,   1.8100076E-03,   1.8179974E-03,   1.8270353E-03
     +,   1.8356370E-03,   1.8424805E-03,   1.8464267E-03
     +,   1.8465498E-03,   1.8421622E-03,   1.8328079E-03
     +,   1.8182806E-03,   1.7986066E-03,   1.7740304E-03
     +,   1.7449862E-03,   1.7120652E-03,   1.6759711E-03
     +,   1.6374772E-03,   1.5973849E-03,   1.5564685E-03
     +,   1.5154430E-03,   1.4749342E-03,   1.4354490E-03
     +,   1.3973593E-03,   1.3608991E-03,   1.3261731E-03
     +,   1.2931610E-03,   1.2617382E-03,   1.2316983E-03
     +,   1.2027810E-03,   1.1746943E-03,   1.1471367E-03
     +,   1.1198219E-03,   1.0924975E-03,   1.0649536E-03
     +,   1.0370333E-03,   1.0086390E-03,   9.7973086E-04
     +,   9.5031952E-04,   9.2046260E-04,   8.9025777E-04
     +,   8.5983123E-04,   8.2932622E-04,   7.9889357E-04
     +,   7.6868746E-04,   7.3885213E-04,   7.0951862E-04
     +,   6.8079785E-04,   6.5278326E-04,   6.2554277E-04
     +,   5.9912255E-04,   5.7354994E-04,   5.4883328E-04
     +,   5.2496331E-04,   5.0191925E-04,   4.7967196E-04
     +,   4.5818632E-04,   4.3742350E-04,   4.1734401E-04
     +,   3.9791211E-04,   3.7909352E-04,   3.6086049E-04
     +,   3.4318925E-04,   3.2606319E-04,   3.0946912E-04
     +,   2.9340124E-04,   2.7785593E-04,   2.6283518E-04
     +,   2.4834162E-04,   2.3438137E-04,   2.2096008E-04
     +,   2.0808322E-04,   1.9575676E-04,   1.8398336E-04
     +,   1.7276545E-04,   1.6210148E-04,   1.5198879E-04
     +,   1.4242067E-04,   1.3338894E-04,   1.2488157E-04
     +,   1.1688522E-04,   1.0938344E-04,   1.0235875E-04
     +,   9.5791089E-05,   8.9660069E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz85 = Yx/0.267340425531915
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.5180534E-05,   9.8482233E-05
     +,   1.0179001E-04,   1.0509623E-04,   1.0839308E-04
     +,   1.1167271E-04,   1.1492726E-04,   1.1814886E-04
     +,   1.2132981E-04,   1.2446263E-04,   1.2754004E-04
     +,   1.3055505E-04,   1.3350102E-04,   1.3637183E-04
     +,   1.3916180E-04,   1.4186592E-04,   1.4447961E-04
     +,   1.4699911E-04,   1.4942122E-04,   1.5174370E-04
     +,   1.5396487E-04,   1.5608387E-04,   1.5810071E-04
     +,   1.6001635E-04,   1.6183220E-04,   1.6355078E-04
     +,   1.6517531E-04,   1.6670969E-04,   1.6815864E-04
     +,   1.6952743E-04,   1.7082196E-04,   1.7204881E-04
     +,   1.7321494E-04,   1.7432771E-04,   1.7539485E-04
     +,   1.7642425E-04,   1.7742410E-04,   1.7840257E-04
     +,   1.7936774E-04,   1.8032773E-04,   1.8129035E-04
     +,   1.8226304E-04,   1.8325304E-04,   1.8426697E-04
     +,   1.8531102E-04,   1.8639061E-04,   1.8751068E-04
     +,   1.8867526E-04,   1.8988767E-04,   1.9115042E-04
     +,   1.9246519E-04,   1.9383270E-04,   1.9525285E-04
     +,   1.9672488E-04,   1.9824682E-04,   1.9981613E-04
     +,   2.0142949E-04,   2.0308272E-04,   2.0477122E-04
     +,   2.0648970E-04,   2.0823230E-04,   2.0999313E-04
     +,   2.1176564E-04,   2.1354354E-04,   2.1532046E-04
     +,   2.1709007E-04,   2.1884672E-04,   2.2058503E-04
     +,   2.2230060E-04,   2.2398964E-04,   2.2564999E-04
     +,   2.2728027E-04,   2.2888118E-04,   2.3045474E-04
     +,   2.3200548E-04,   2.3353966E-04,   2.3506615E-04
     +,   2.3659634E-04,   2.3814445E-04,   2.3972736E-04
     +,   2.4136493E-04,   2.4308030E-04,   2.4489913E-04
     +,   2.4685051E-04,   2.4896613E-04,   2.5128049E-04
     +,   2.5383043E-04,   2.5665545E-04,   2.5979622E-04
     +,   2.6329549E-04,   2.6719685E-04,   2.7154424E-04
     +,   2.7638147E-04,   2.8175215E-04,   2.8769861E-04
     +,   2.9426109E-04,   3.0147785E-04,   3.0938387E-04
     +,   3.1801171E-04,   3.2738867E-04,   3.3753944E-04
     +,   3.4848260E-04,   3.6023397E-04,   3.7280261E-04
     +,   3.8619406E-04,   4.0040945E-04,   4.1544443E-04
     +,   4.3129115E-04,   4.4793924E-04,   4.6537656E-04
     +,   4.8358840E-04,   5.0256395E-04,   5.2229228E-04
     +,   5.4277224E-04,   5.6400802E-04,   5.8602041E-04
     +,   6.0884457E-04,   6.3254085E-04,   6.5719336E-04
     +,   6.8292092E-04,   7.0987904E-04,   7.3826301E-04
     +,   7.6831010E-04,   8.0030633E-04,   8.3457900E-04
     +,   8.7149383E-04,   9.1145659E-04,   9.5489383E-04
     +,   1.0022584E-03,   1.0540115E-03,   1.1106302E-03
     +,   1.1725993E-03,   1.2404394E-03,   1.3147121E-03
     +,   1.3960742E-03,   1.4853198E-03,   1.5834402E-03
     +,   1.6917204E-03,   1.8118711E-03,   1.9462211E-03
     +,   2.0979850E-03,   2.2716571E-03,   2.4735085E-03
     +,   2.7120190E-03,   2.9981011E-03,   3.3448597E-03
     +,   3.7664773E-03,   4.2760568E-03,   4.8826081E-03
     +,   5.5879508E-03,   6.3846842E-03,   7.2569079E-03
     +,   8.1849396E-03,   9.1531342E-03,   1.0158149E-02
     +,   1.1213865E-02,   1.2350343E-02,   1.3606039E-02
     +,   1.5014757E-02,   1.6590307E-02,   1.8314477E-02
     +,   2.0135736E-02,   2.1984020E-02,   2.3793882E-02
     +,   2.5513375E-02,   2.7080750E-02,   2.8387437E-02
     +,   2.9274656E-02,   2.9590059E-02,   2.9270774E-02
     +,   2.8388865E-02,   2.7130866E-02,   2.5732631E-02
     +,   2.4405705E-02,   2.3285026E-02,   2.2415707E-02
     +,   2.1781994E-02,   2.1348760E-02,   2.1081544E-02
     +,   2.0937914E-02,   2.0852288E-02,   2.0741593E-02
     +,   2.0535603E-02,   2.0208461E-02,   1.9783245E-02
     +,   1.9304372E-02,   1.8799169E-02,   1.8256528E-02
     +,   1.7635386E-02,   1.6891927E-02,   1.6006645E-02
     +,   1.4997225E-02,   1.3915110E-02,   1.2830446E-02
     +,   1.1811853E-02,   1.0908019E-02,   1.0136534E-02
     +,   9.4842082E-03,   8.9177871E-03,   8.3998889E-03
     +,   7.9024220E-03,   7.4129929E-03,   6.9336253E-03
     +,   6.4750169E-03,   6.0499315E-03,   5.6683710E-03
     +,   5.3355265E-03,   5.0518573E-03,   4.8141829E-03
     +,   4.6170005E-03,   4.4536567E-03,   4.3171220E-03
     +,   4.2005354E-03,   4.0975744E-03,   4.0027658E-03
     +,   3.9116954E-03,   3.8211267E-03,   3.7290265E-03
     +,   3.6344875E-03,   3.5375434E-03,   3.4389251E-03
     +,   3.3397647E-03,   3.2413297E-03,   3.1447818E-03
     +,   3.0509958E-03,   2.9604950E-03,   2.8734212E-03
     +,   2.7895975E-03,   2.7086074E-03,   2.6299160E-03
     +,   2.5529852E-03,   2.4773630E-03,   2.4027382E-03
     +,   2.3289809E-03,   2.2561355E-03,   2.1843843E-03
     +,   2.1139935E-03,   2.0452663E-03,   1.9784761E-03
     +,   1.9138214E-03,   1.8513894E-03,   1.7911509E-03
     +,   1.7329630E-03,   1.6765762E-03,   1.6216718E-03
     +,   1.5678952E-03,   1.5148888E-03,   1.4623187E-03
     +,   1.4099041E-03,   1.3574384E-03,   1.3047908E-03
     +,   1.2519123E-03,   1.1988343E-03,   1.1456606E-03
     +,   1.0925462E-03,   1.0396895E-03,   9.8732044E-04
     +,   9.3568309E-04,   8.8501791E-04,   8.3555549E-04
     +,   7.8750873E-04,   7.4106356E-04,   6.9637055E-04
     +,   6.5354508E-04,   6.1267219E-04,   5.7379686E-04
     +,   5.3693249E-04,   5.0206616E-04,   4.6915913E-04
     +,   4.3815159E-04,   4.0896749E-04,   3.8152258E-04
     +,   3.5572585E-04,   3.3148209E-04,   3.0869636E-04
     +,   2.8727937E-04,   2.6714386E-04,   2.4821114E-04
     +,   2.3040702E-04,   2.1366635E-04,   1.9792834E-04
     +,   1.8314066E-04,   1.6925416E-04,   1.5622623E-04
     +,   1.4401613E-04,   1.3258774E-04,   1.2190574E-04
     +,   1.1193650E-04,   1.0264837E-04,   9.4008974E-05
     +,   8.5987667E-05,   7.8552817E-05,   7.1674025E-05
     +,   6.5320295E-05,   5.9461679E-05,   5.4068012E-05
     +,   4.9110367E-05,   4.4559918E-05,   4.0389354E-05
     +,   3.6571779E-05,   3.3081971E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz90 = Yx/0.277617021276596
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3328503E-05,   2.4532794E-05
     +,   2.5802799E-05,   2.7141132E-05,   2.8550392E-05
     +,   3.0033096E-05,   3.1591699E-05,   3.3228520E-05
     +,   3.4945740E-05,   3.6745427E-05,   3.8629398E-05
     +,   4.0599258E-05,   4.2656357E-05,   4.4801745E-05
     +,   4.7036170E-05,   4.9359980E-05,   5.1773201E-05
     +,   5.4275351E-05,   5.6865567E-05,   5.9542464E-05
     +,   6.2304171E-05,   6.5148248E-05,   6.8071684E-05
     +,   7.1071103E-05,   7.4142183E-05,   7.7280325E-05
     +,   8.0480211E-05,   8.3735962E-05,   8.7041102E-05
     +,   9.0388639E-05,   9.3770999E-05,   9.7180156E-05
     +,   1.0060755E-04,   1.0404435E-04,   1.0748122E-04
     +,   1.1090862E-04,   1.1431664E-04,   1.1769538E-04
     +,   1.2103489E-04,   1.2432493E-04,   1.2755566E-04
     +,   1.3071732E-04,   1.3380044E-04,   1.3679585E-04
     +,   1.3969498E-04,   1.4248968E-04,   1.4517261E-04
     +,   1.4773708E-04,   1.5017723E-04,   1.5248818E-04
     +,   1.5466599E-04,   1.5670777E-04,   1.5861164E-04
     +,   1.6037711E-04,   1.6200458E-04,   1.6349583E-04
     +,   1.6485382E-04,   1.6608270E-04,   1.6718765E-04
     +,   1.6817538E-04,   1.6905341E-04,   1.6983032E-04
     +,   1.7051591E-04,   1.7112069E-04,   1.7165614E-04
     +,   1.7213427E-04,   1.7256792E-04,   1.7297029E-04
     +,   1.7335505E-04,   1.7373599E-04,   1.7412708E-04
     +,   1.7454241E-04,   1.7499563E-04,   1.7550023E-04
     +,   1.7606933E-04,   1.7671539E-04,   1.7745017E-04
     +,   1.7828472E-04,   1.7922903E-04,   1.8029213E-04
     +,   1.8148185E-04,   1.8280507E-04,   1.8426696E-04
     +,   1.8587169E-04,   1.8762189E-04,   1.8951896E-04
     +,   1.9156258E-04,   1.9375150E-04,   1.9608256E-04
     +,   1.9855170E-04,   2.0115351E-04,   2.0388140E-04
     +,   2.0672771E-04,   2.0968421E-04,   2.1274186E-04
     +,   2.1589098E-04,   2.1912223E-04,   2.2242578E-04
     +,   2.2579270E-04,   2.2921458E-04,   2.3268427E-04
     +,   2.3619617E-04,   2.3974699E-04,   2.4333558E-04
     +,   2.4696405E-04,   2.5063811E-04,   2.5436733E-04
     +,   2.5816564E-04,   2.6205249E-04,   2.6605240E-04
     +,   2.7019577E-04,   2.7451932E-04,   2.7906572E-04
     +,   2.8388487E-04,   2.8903235E-04,   2.9457119E-04
     +,   3.0056966E-04,   3.0710283E-04,   3.1425059E-04
     +,   3.2209832E-04,   3.3073546E-04,   3.4025501E-04
     +,   3.5075203E-04,   3.6232432E-04,   3.7507049E-04
     +,   3.8908739E-04,   4.0447206E-04,   4.2131689E-04
     +,   4.3971240E-04,   4.5973939E-04,   4.8147424E-04
     +,   5.0497905E-04,   5.3030637E-04,   5.5748894E-04
     +,   5.8654259E-04,   6.1746099E-04,   6.5021060E-04
     +,   6.8472931E-04,   7.2093034E-04,   7.5869873E-04
     +,   7.9789630E-04,   8.3836907E-04,   8.7996450E-04
     +,   9.2254614E-04,   9.6601521E-04,   1.0103444E-03
     +,   1.0556091E-03,   1.1020186E-03,   1.1499499E-03
     +,   1.1999838E-03,   1.2529170E-03,   1.3097620E-03
     +,   1.3717380E-03,   1.4402393E-03,   1.5167771E-03
     +,   1.6029084E-03,   1.7001670E-03,   1.8100078E-03
     +,   1.9337563E-03,   2.0725774E-03,   2.2274940E-03
     +,   2.3993743E-03,   2.5888849E-03,   2.7964059E-03
     +,   3.0218812E-03,   3.2646088E-03,   3.5230084E-03
     +,   3.7945365E-03,   4.0757107E-03,   4.3623191E-03
     +,   4.6498054E-03,   4.9340255E-03,   5.2127149E-03
     +,   5.4880022E-03,   5.7702321E-03,   6.0823159E-03
     +,   6.4621996E-03,   6.9603031E-03,   7.6302784E-03
     +,   8.5154017E-03,   9.6383505E-03,   1.1004382E-02
     +,   1.2620781E-02,   1.4518068E-02,   1.6745035E-02
     +,   1.9321376E-02,   2.2170115E-02,   2.5087411E-02
     +,   2.7805906E-02,   3.0148102E-02,   3.2159902E-02
     +,   3.4074735E-02,   3.6098916E-02,   3.8193826E-02
     +,   4.0036052E-02,   4.1184995E-02,   4.1344985E-02
     +,   4.0548675E-02,   3.9136991E-02,   3.7515037E-02
     +,   3.5862628E-02,   3.4101397E-02,   3.2139536E-02
     +,   3.0045457E-02,   2.7956458E-02,   2.5922421E-02
     +,   2.3906853E-02,   2.1899872E-02,   1.9967984E-02
     +,   1.8194351E-02,   1.6611781E-02,   1.5204416E-02
     +,   1.3950544E-02,   1.2848128E-02,   1.1908688E-02
     +,   1.1137345E-02,   1.0517923E-02,   1.0011803E-02
     +,   9.5694149E-03,   9.1465591E-03,   8.7162126E-03
     +,   8.2710944E-03,   7.8179808E-03,   7.3688622E-03
     +,   6.9336854E-03,   6.5169651E-03,   6.1181947E-03
     +,   5.7341438E-03,   5.3616287E-03,   4.9993857E-03
     +,   4.6486687E-03,   4.3127276E-03,   3.9957007E-03
     +,   3.7015707E-03,   3.4333337E-03,   3.1925710E-03
     +,   2.9794071E-03,   2.7927414E-03,   2.6305658E-03
     +,   2.4903284E-03,   2.3692779E-03,   2.2647372E-03
     +,   2.1742610E-03,   2.0957300E-03,   2.0273505E-03
     +,   1.9676269E-03,   1.9152807E-03,   1.8691627E-03
     +,   1.8281993E-03,   1.7913480E-03,   1.7575684E-03
     +,   1.7258341E-03,   1.6951463E-03,   1.6645603E-03
     +,   1.6332130E-03,   1.6003497E-03,   1.5653494E-03
     +,   1.5277365E-03,   1.4871873E-03,   1.4435326E-03
     +,   1.3967541E-03,   1.3469711E-03,   1.2944210E-03
     +,   1.2394427E-03,   1.1824612E-03,   1.1239508E-03
     +,   1.0644216E-03,   1.0043989E-03,   9.4440219E-04
     +,   8.8492240E-04,   8.2641380E-04,   7.6928578E-04
     +,   7.1389414E-04,   6.6053116E-04,   6.0943037E-04
     +,   5.6077098E-04,   5.1467121E-04,   4.7120484E-04
     +,   4.3039481E-04,   3.9223224E-04,   3.5667064E-04
     +,   3.2364324E-04,   2.9305986E-04,   2.6482015E-04
     +,   2.3881061E-04,   2.1491596E-04,   1.9301564E-04
     +,   1.7298938E-04,   1.5472030E-04,   1.3809193E-04
     +,   1.2299338E-04,   1.0931590E-04,   9.6956675E-05
     +,   8.5815707E-05,   7.5798773E-05,   6.6814784E-05
     +,   5.8778223E-05,   5.1606912E-05,   4.5224206E-05
     +,   3.9556930E-05,   3.4537305E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ttz95 = Yx/0.295936170212766
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5751012E-07,   8.2881098E-07
     +,   9.0545973E-07,   9.8771511E-07,   1.0758350E-06
     +,   1.1700741E-06,   1.2706846E-06,   1.3779116E-06
     +,   1.4919933E-06,   1.6131640E-06,   1.7416434E-06
     +,   1.8776403E-06,   2.0213522E-06,   2.1729609E-06
     +,   2.3326329E-06,   2.5005177E-06,   2.6767455E-06
     +,   2.8614290E-06,   3.0546594E-06,   3.2565074E-06
     +,   3.4670204E-06,   3.6862277E-06,   3.9141291E-06
     +,   4.1507192E-06,   4.3959435E-06,   4.6497553E-06
     +,   4.9120713E-06,   5.1827924E-06,   5.4618017E-06
     +,   5.7489679E-06,   6.0441444E-06,   6.3471730E-06
     +,   6.6578846E-06,   6.9761045E-06,   7.3016513E-06
     +,   7.6343449E-06,   7.9740003E-06,   8.3204413E-06
     +,   8.6735099E-06,   9.0330304E-06,   9.3988692E-06
     +,   9.7708980E-06,   1.0149007E-05,   1.0533114E-05
     +,   1.0923161E-05,   1.1319127E-05,   1.1721017E-05
     +,   1.2128879E-05,   1.2542800E-05,   1.2962908E-05
     +,   1.3389391E-05,   1.3822480E-05,   1.4262465E-05
     +,   1.4709723E-05,   1.5164659E-05,   1.5627806E-05
     +,   1.6099753E-05,   1.6581205E-05,   1.7072978E-05
     +,   1.7576012E-05,   1.8091414E-05,   1.8620443E-05
     +,   1.9164547E-05,   1.9725427E-05,   2.0305057E-05
     +,   2.0905654E-05,   2.1529861E-05,   2.2180617E-05
     +,   2.2861419E-05,   2.3576169E-05,   2.4329429E-05
     +,   2.5126305E-05,   2.5972693E-05,   2.6875159E-05
     +,   2.7841170E-05,   2.8879072E-05,   2.9998080E-05
     +,   3.1208361E-05,   3.2521089E-05,   3.3948465E-05
     +,   3.5503424E-05,   3.7199959E-05,   3.9052600E-05
     +,   4.1076706E-05,   4.3287775E-05,   4.5701767E-05
     +,   4.8334194E-05,   5.1200466E-05,   5.4314856E-05
     +,   5.7690610E-05,   6.1339408E-05,   6.5270571E-05
     +,   6.9490787E-05,   7.4003990E-05,   7.8810757E-05
     +,   8.3907238E-05,   8.9286208E-05,   9.4935196E-05
     +,   1.0083809E-04,   1.0697336E-04,   1.1331576E-04
     +,   1.1983511E-04,   1.2649821E-04,   1.3326776E-04
     +,   1.4010449E-04,   1.4696745E-04,   1.5381450E-04
     +,   1.6060403E-04,   1.6729617E-04,   1.7385428E-04
     +,   1.8024506E-04,   1.8644184E-04,   1.9242412E-04
     +,   1.9818021E-04,   2.0370740E-04,   2.0901398E-04
     +,   2.1411885E-04,   2.1905366E-04,   2.2386140E-04
     +,   2.2859768E-04,   2.3332973E-04,   2.3813527E-04
     +,   2.4310131E-04,   2.4832293E-04,   2.5390121E-04
     +,   2.5993984E-04,   2.6654406E-04,   2.7381658E-04
     +,   2.8185660E-04,   2.9075565E-04,   3.0059688E-04
     +,   3.1145193E-04,   3.2338084E-04,   3.3642762E-04
     +,   3.5062266E-04,   3.6597921E-04,   3.8249060E-04
     +,   4.0013005E-04,   4.1884877E-04,   4.3857266E-04
     +,   4.5919925E-04,   4.8059496E-04,   5.0259742E-04
     +,   5.2501354E-04,   5.4761965E-04,   5.7017180E-04
     +,   5.9240987E-04,   6.1406795E-04,   6.3488737E-04
     +,   6.5463246E-04,   6.7310262E-04,   6.9014437E-04
     +,   7.0566527E-04,   7.1964192E-04,   7.3212478E-04
     +,   7.4323901E-04,   7.5318880E-04,   7.6225604E-04
     +,   7.7080459E-04,   7.7928370E-04,   7.8824378E-04
     +,   7.9834805E-04,   8.1039208E-04,   8.2531531E-04
     +,   8.4420113E-04,   8.6825405E-04,   8.9873723E-04
     +,   9.3687419E-04,   9.8371145E-04,   1.0399490E-03
     +,   1.1057616E-03,   1.1806620E-03,   1.2634336E-03
     +,   1.3521616E-03,   1.4443800E-03,   1.5373606E-03
     +,   1.6284555E-03,   1.7154660E-03,   1.7969878E-03
     +,   1.8726643E-03,   1.9433341E-03,   2.0110977E-03
     +,   2.0793404E-03,   2.1527077E-03,   2.2369637E-03
     +,   2.3386201E-03,   2.4641885E-03,   2.6191231E-03
     +,   2.8066232E-03,   3.0268675E-03,   3.2772326E-03
     +,   3.5536091E-03,   3.8526116E-03,   4.1747484E-03
     +,   4.5296750E-03,   4.9452712E-03,   5.4786550E-03
     +,   6.2218620E-03,   7.3074764E-03,   8.9649875E-03
     +,   1.1655736E-02,   1.6097739E-02,   2.3192005E-02
     +,   3.4310531E-02,   5.0091632E-02,   6.9941141E-02
     +,   9.8596275E-02,   0.1401373    ,   0.1966477    
     +,   0.2409667    ,   0.2461307    ,   0.2161725    
     +,   0.1713090    ,   0.1301923    ,   9.3306623E-02
     +,   6.3941859E-02,   4.5599367E-02,   3.3110898E-02
     +,   2.3232911E-02,   1.5903350E-02,   1.1066180E-02
     +,   7.9313051E-03,   5.7711368E-03,   4.2322632E-03
     +,   3.1454908E-03,   2.3841541E-03,   1.8413573E-03
     +,   1.4406469E-03,   1.1354382E-03,   8.9894515E-04
     +,   7.1475992E-04,   5.7138258E-04,   4.5979369E-04
     +,   3.7261267E-04,   3.0388092E-04,   2.4897323E-04
     +,   2.0448070E-04,   1.6799613E-04,   1.3785310E-04
     +,   1.1288445E-04,   9.2235823E-05,   7.5238953E-05
     +,   6.1335239E-05,   5.0037939E-05,   4.0918087E-05
     +,   3.3599546E-05,   2.7756136E-05,   2.3109225E-05
     +,   1.9424870E-05,   1.6509417E-05,   1.4203682E-05
     +,   1.2378240E-05,   1.0928689E-05,   9.7712355E-06
     +,   8.8390125E-06,   8.0791406E-06,   7.4501868E-06
     +,   6.9199486E-06,   6.4636629E-06,   6.0625580E-06
     +,   5.7026314E-06,   5.3735871E-06,   5.0679837E-06
     +,   4.7805602E-06,   4.5077195E-06,   4.2470388E-06
     +,   3.9969495E-06,   3.7565108E-06,   3.5251853E-06
     +,   3.3026877E-06,   3.0888978E-06,   2.8838015E-06
     +,   2.6874254E-06,   2.4997928E-06,   2.3209129E-06
     +,   2.1507901E-06,   1.9893710E-06,   1.8365903E-06
     +,   1.6923246E-06,   1.5564368E-06,   1.4287383E-06
     +,   1.3090298E-06,   1.1970690E-06,   1.0926075E-06
     +,   9.9536373E-07,   9.0505426E-07,   8.2137456E-07
     +,   7.4401294E-07,   6.7265881E-07,   6.0699017E-07
     +,   5.4669334E-07,   4.9144870E-07,   4.4094855E-07
     +,   3.9488438E-07,   3.5296156E-07,   3.1488884E-07
     +,   2.8038991E-07,   2.4919518E-07,   2.2105102E-07
     +,   1.9571200E-07,   1.7294896E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_hatt100 = Yx/0.487392156862745
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_hatt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3499331E-06,   4.5054239E-06
     +,   4.6684809E-06,   4.8396405E-06,   5.0194772E-06
     +,   5.2085929E-06,   5.4076254E-06,   5.6172471E-06
     +,   5.8381556E-06,   6.0710977E-06,   6.3168400E-06
     +,   6.5761838E-06,   6.8499630E-06,   7.1390446E-06
     +,   7.4443201E-06,   7.7667146E-06,   8.1071748E-06
     +,   8.4666754E-06,   8.8462157E-06,   9.2468135E-06
     +,   9.6695067E-06,   1.0115355E-05,   1.0585413E-05
     +,   1.1080799E-05,   1.1602569E-05,   1.2151854E-05
     +,   1.2729759E-05,   1.3337399E-05,   1.3975897E-05
     +,   1.4646371E-05,   1.5349957E-05,   1.6087779E-05
     +,   1.6860968E-05,   1.7670653E-05,   1.8517976E-05
     +,   1.9404073E-05,   2.0330102E-05,   2.1297203E-05
     +,   2.2306600E-05,   2.3359427E-05,   2.4456947E-05
     +,   2.5600406E-05,   2.6791065E-05,   2.8030270E-05
     +,   2.9319399E-05,   3.0659881E-05,   3.2053209E-05
     +,   3.3500961E-05,   3.5004774E-05,   3.6566395E-05
     +,   3.8187613E-05,   3.9870363E-05,   4.1616600E-05
     +,   4.3428528E-05,   4.5308207E-05,   4.7258014E-05
     +,   4.9280279E-05,   5.1377425E-05,   5.3551936E-05
     +,   5.5806348E-05,   5.8143196E-05,   6.0565017E-05
     +,   6.3074192E-05,   6.5673215E-05,   6.8364432E-05
     +,   7.1149829E-05,   7.4031486E-05,   7.7010904E-05
     +,   8.0089616E-05,   8.3268489E-05,   8.6548287E-05
     +,   8.9929010E-05,   9.3410490E-05,   9.6991665E-05
     +,   1.0067119E-04,   1.0444716E-04,   1.0831685E-04
     +,   1.1227685E-04,   1.1632351E-04,   1.2045257E-04
     +,   1.2465892E-04,   1.2893757E-04,   1.3328265E-04
     +,   1.3768871E-04,   1.4214969E-04,   1.4666028E-04
     +,   1.5121495E-04,   1.5580947E-04,   1.6043991E-04
     +,   1.6510386E-04,   1.6980070E-04,   1.7453125E-04
     +,   1.7929864E-04,   1.8410900E-04,   1.8897135E-04
     +,   1.9389790E-04,   1.9890498E-04,   2.0401266E-04
     +,   2.0924586E-04,   2.1463376E-04,   2.2021084E-04
     +,   2.2601608E-04,   2.3209411E-04,   2.3849378E-04
     +,   2.4526945E-04,   2.5248024E-04,   2.6018909E-04
     +,   2.6846273E-04,   2.7737208E-04,   2.8699107E-04
     +,   2.9739528E-04,   3.0866341E-04,   3.2087395E-04
     +,   3.3410790E-04,   3.4844456E-04,   3.6396435E-04
     +,   3.8074396E-04,   3.9886034E-04,   4.1838377E-04
     +,   4.3938076E-04,   4.6191114E-04,   4.8602244E-04
     +,   5.1174953E-04,   5.3911202E-04,   5.6810933E-04
     +,   5.9871346E-04,   6.3087122E-04,   6.6449307E-04
     +,   6.9945806E-04,   7.3560310E-04,   7.7273120E-04
     +,   8.1060553E-04,   8.4896083E-04,   8.8750303E-04
     +,   9.2592364E-04,   9.6391188E-04,   1.0011623E-03
     +,   1.0373957E-03,   1.0723735E-03,   1.1059127E-03
     +,   1.1378956E-03,   1.1682835E-03,   1.1971249E-03
     +,   1.2245538E-03,   1.2507897E-03,   1.2761316E-03
     +,   1.3009484E-03,   1.3256662E-03,   1.3507560E-03
     +,   1.3767254E-03,   1.4041052E-03,   1.4334514E-03
     +,   1.4653374E-03,   1.5003651E-03,   1.5391657E-03
     +,   1.5824034E-03,   1.6307738E-03,   1.6849857E-03
     +,   1.7457331E-03,   1.8136299E-03,   1.8891441E-03
     +,   1.9724977E-03,   2.0635575E-03,   2.1617485E-03
     +,   2.2659975E-03,   2.3747210E-03,   2.4858906E-03
     +,   2.5971846E-03,   2.7062264E-03,   2.8108596E-03
     +,   2.9094154E-03,   3.0009779E-03,   3.0855222E-03
     +,   3.1639379E-03,   3.2378880E-03,   3.3096124E-03
     +,   3.3816041E-03,   3.4563143E-03,   3.5359019E-03
     +,   3.6220746E-03,   3.7159855E-03,   3.8181790E-03
     +,   3.9285440E-03,   4.0462734E-03,   4.1698311E-03
     +,   4.2969873E-03,   4.4250991E-03,   4.5516216E-03
     +,   4.6748738E-03,   4.7949636E-03,   4.9145948E-03
     +,   5.0394479E-03,   5.1778886E-03,   5.3397608E-03
     +,   5.5344389E-03,   5.7683056E-03,   6.0421983E-03
     +,   6.3495245E-03,   6.6756569E-03,   6.9989543E-03
     +,   7.2935061E-03,   7.5333440E-03,   7.6973899E-03
     +,   7.7741439E-03,   7.7656177E-03,   7.6897065E-03
     +,   7.5809769E-03,   7.4898559E-03,   7.4803238E-03
     +,   7.6259021E-03,   8.0031529E-03,   8.6808307E-03
     +,   9.7026564E-03,   1.1066169E-02,   1.2716671E-02
     +,   1.4604392E-02,   1.6853726E-02,   1.9994374E-02
     +,   2.4967507E-02,   3.2470904E-02,   4.2603437E-02
     +,   5.8024924E-02,   8.6624131E-02,   0.1366018    
     +,   0.2071517    ,   0.2668203    ,   0.2610175    
     +,   0.1886663    ,   0.1070584    ,   5.1224824E-02
     +,   2.1362955E-02,   7.8313667E-03,   2.6486528E-03
     +,   1.0001749E-03,   5.0235522E-04,   2.9844721E-04
     +,   1.8761653E-04,   1.3037943E-04,   1.0416484E-04
     +,   9.1124472E-05,   8.1626044E-05,   7.2237213E-05
     +,   6.2428189E-05,   5.2606749E-05,   4.3322354E-05
     +,   3.5010540E-05,   2.7929545E-05,   2.2165852E-05
     +,   1.7669068E-05,   1.4297025E-05,   1.1859279E-05
     +,   1.0154281E-05,   8.9948599E-06,   8.2223405E-06
     +,   7.7116574E-06,   7.3701913E-06,   7.1330155E-06
     +,   6.9568159E-06,   6.8140207E-06,   6.6878715E-06
     +,   6.5686518E-06,   6.4510032E-06,   6.3321436E-06
     +,   6.2107606E-06,   6.0863563E-06,   5.9588456E-06
     +,   5.8283549E-06,   5.6951285E-06,   5.5594555E-06
     +,   5.4216403E-06,   5.2819964E-06,   5.1408438E-06
     +,   4.9985047E-06,   4.8552856E-06,   4.7114868E-06
     +,   4.5674146E-06,   4.4233507E-06,   4.2795855E-06
     +,   4.1363801E-06,   3.9940051E-06,   3.8526996E-06
     +,   3.7127106E-06,   3.5742542E-06,   3.4375512E-06
     +,   3.3027929E-06,   3.1701727E-06,   3.0398587E-06
     +,   2.9120058E-06,   2.7867659E-06,   2.6642631E-06
     +,   2.5446222E-06,   2.4279382E-06,   2.3143102E-06
     +,   2.2038080E-06,   2.0965028E-06,   1.9924412E-06
     +,   1.8916687E-06,   1.7942079E-06,   1.7000831E-06
     +,   1.6092951E-06,   1.5218467E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_hatt104 = Yx/0.44058
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.2795739E-06,   6.3014986E-06
     +,   6.3303673E-06,   6.3675061E-06,   6.4143596E-06
     +,   6.4724918E-06,   6.5435834E-06,   6.6294419E-06
     +,   6.7319952E-06,   6.8532981E-06,   6.9955240E-06
     +,   7.1609616E-06,   7.3520141E-06,   7.5711846E-06
     +,   7.8210696E-06,   8.1043518E-06,   8.4237718E-06
     +,   8.7821300E-06,   9.1822485E-06,   9.6269705E-06
     +,   1.0119116E-05,   1.0661482E-05,   1.1256783E-05
     +,   1.1907706E-05,   1.2616751E-05,   1.3386369E-05
     +,   1.4218838E-05,   1.5116297E-05,   1.6080738E-05
     +,   1.7114024E-05,   1.8217916E-05,   1.9394132E-05
     +,   2.0644406E-05,   2.1970611E-05,   2.3374911E-05
     +,   2.4859932E-05,   2.6429036E-05,   2.8086604E-05
     +,   2.9838588E-05,   3.1692645E-05,   3.3659180E-05
     +,   3.5751666E-05,   3.7987676E-05,   4.0389736E-05
     +,   4.2986394E-05,   4.5813416E-05,   4.8915063E-05
     +,   5.2345349E-05,   5.6169516E-05,   6.0465274E-05
     +,   6.5323948E-05,   7.0851609E-05,   7.7169447E-05
     +,   8.4414678E-05,   9.2738817E-05,   1.0230813E-04
     +,   1.1330050E-04,   1.2590278E-04,   1.4030660E-04
     +,   1.5670290E-04,   1.7527520E-04,   1.9619224E-04
     +,   2.1959718E-04,   2.4560149E-04,   2.7427517E-04
     +,   3.0563632E-04,   3.3965593E-04,   3.7625528E-04
     +,   4.1533299E-04,   4.5679123E-04,   5.0060748E-04
     +,   5.4691220E-04,   5.9611886E-04,   6.4905442E-04
     +,   7.0711592E-04,   7.7238842E-04,   8.4769860E-04
     +,   9.3658554E-04,   1.0431889E-03,   1.1721152E-03
     +,   1.3284417E-03,   1.5180950E-03,   1.7486019E-03
     +,   2.0302462E-03,   2.3770353E-03,   2.8073597E-03
     +,   3.3440981E-03,   4.0154154E-03,   4.8568374E-03
     +,   5.9149112E-03,   7.2481581E-03,   8.9208148E-03
     +,   1.0996210E-02,   1.3553426E-02,   1.6720489E-02
     +,   2.0645494E-02,   2.5395220E-02,   3.0992793E-02
     +,   3.7657402E-02,   4.5630597E-02,   5.4483864E-02
     +,   6.3566640E-02,   7.2965793E-02,   8.1589505E-02
     +,   8.7353118E-02,   9.1095828E-02,   9.3975224E-02
     +,   9.5570721E-02,   9.4413206E-02,   8.9502811E-02
     +,   8.1868470E-02,   7.3488697E-02,   6.6189259E-02
     +,   5.9749737E-02,   5.3407084E-02,   4.7019649E-02
     +,   4.1190773E-02,   3.6595829E-02,   3.3111021E-02
     +,   3.0139359E-02,   2.7329817E-02,   2.4667174E-02
     +,   2.2207005E-02,   1.9962253E-02,   1.7925167E-02
     +,   1.6083270E-02,   1.4417712E-02,   1.2912254E-02
     +,   1.1566287E-02,   1.0393330E-02,   9.4024017E-03
     +,   8.5820723E-03,   7.8994986E-03,   7.3126368E-03
     +,   6.7846454E-03,   6.2926840E-03,   5.8285645E-03
     +,   5.3937929E-03,   4.9934974E-03,   4.6322620E-03
     +,   4.3124696E-03,   4.0341322E-03,   3.7951947E-03
     +,   3.5917875E-03,   3.4184901E-03,   3.2686859E-03
     +,   3.1352267E-03,   3.0112618E-03,   2.8909673E-03
     +,   2.7701468E-03,   2.6464949E-03,   2.5195626E-03
     +,   2.3904599E-03,   2.2613676E-03,   2.1350309E-03
     +,   2.0142812E-03,   1.9016346E-03,   1.7990419E-03
     +,   1.7077602E-03,   1.6283588E-03,   1.5607642E-03
     +,   1.5043868E-03,   1.4582559E-03,   1.4211504E-03
     +,   1.3917059E-03,   1.3685195E-03,   1.3502187E-03
     +,   1.3355121E-03,   1.3232169E-03,   1.3122814E-03
     +,   1.3017913E-03,   1.2909689E-03,   1.2791663E-03
     +,   1.2658600E-03,   1.2506437E-03,   1.2332149E-03
     +,   1.2133705E-03,   1.1910006E-03,   1.1660770E-03
     +,   1.1386512E-03,   1.1088421E-03,   1.0768354E-03
     +,   1.0428719E-03,   1.0072376E-03,   9.7025256E-04
     +,   9.3226432E-04,   8.9363521E-04,   8.5472577E-04
     +,   8.1588671E-04,   7.7745342E-04,   7.3972775E-04
     +,   7.0297509E-04,   6.6742260E-04,   6.3325150E-04
     +,   6.0059532E-04,   5.6954368E-04,   5.4014660E-04
     +,   5.1241688E-04,   4.8633385E-04,   4.6185107E-04
     +,   4.3890395E-04,   4.1741456E-04,   3.9729438E-04
     +,   3.7845140E-04,   3.6079509E-04,   3.4423580E-04
     +,   3.2868853E-04,   3.1407471E-04,   3.0032190E-04
     +,   2.8736278E-04,   2.7513588E-04,   2.6358565E-04
     +,   2.5266092E-04,   2.4231322E-04,   2.3249787E-04
     +,   2.2317297E-04,   2.1429926E-04,   2.0583851E-04
     +,   1.9775477E-04,   1.9001467E-04,   1.8258611E-04
     +,   1.7543897E-04,   1.6854600E-04,   1.6188216E-04
     +,   1.5542463E-04,   1.4915285E-04,   1.4304965E-04
     +,   1.3710021E-04,   1.3129199E-04,   1.2561490E-04
     +,   1.2006154E-04,   1.1462680E-04,   1.0930697E-04
     +,   1.0410036E-04,   9.9007149E-05,   9.4028408E-05
     +,   8.9166271E-05,   8.4423940E-05,   7.9805308E-05
     +,   7.5314281E-05,   7.0954986E-05,   6.6731831E-05
     +,   6.2649058E-05,   5.8710313E-05,   5.4918874E-05
     +,   5.1277741E-05,   4.7789272E-05,   4.4454991E-05
     +,   4.1275685E-05,   3.8251823E-05,   3.5382796E-05
     +,   3.2667333E-05,   3.0103680E-05,   2.7689415E-05
     +,   2.5421365E-05,   2.3295837E-05,   2.1308802E-05
     +,   1.9455774E-05,   1.7731798E-05,   1.6131633E-05
     +,   1.4649902E-05,   1.3281057E-05,   1.2019324E-05
     +,   1.0858893E-05,   9.7940465E-06,   8.8189990E-06
     +,   7.9280426E-06,   7.1156542E-06,   6.3764473E-06
     +,   5.7051516E-06,   5.0967092E-06,   4.5463130E-06
     +,   4.0493755E-06,   3.6015163E-06,   3.1986008E-06
     +,   2.8367792E-06,   2.5123961E-06,   2.2220840E-06
     +,   1.9626734E-06,   1.7312612E-06,   1.5251343E-06
     +,   1.3418233E-06,   1.1790356E-06,   1.0346945E-06
     +,   9.0688576E-07,   7.9388184E-07,   6.9410305E-07
     +,   6.0611831E-07,   5.2864306E-07,   4.6050707E-07
     +,   4.0066709E-07,   3.4817734E-07,   3.0219695E-07
     +,   2.6196713E-07,   2.2681576E-07,   1.9613829E-07
     +,   1.6940085E-07,   1.4612509E-07,   1.2588985E-07
     +,   1.0831889E-07,   9.3081844E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_hatt75 = Yx/0.4571
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8656776E-05,   1.9045057E-05
     +,   1.9440446E-05,   1.9843470E-05,   2.0254716E-05
     +,   2.0674806E-05,   2.1104401E-05,   2.1544216E-05
     +,   2.1994989E-05,   2.2457540E-05,   2.2932692E-05
     +,   2.3421337E-05,   2.3924395E-05,   2.4442841E-05
     +,   2.4977679E-05,   2.5529960E-05,   2.6100774E-05
     +,   2.6691239E-05,   2.7302527E-05,   2.7935832E-05
     +,   2.8592380E-05,   2.9273446E-05,   2.9980311E-05
     +,   3.0714342E-05,   3.1476855E-05,   3.2269276E-05
     +,   3.3093031E-05,   3.3949593E-05,   3.4840476E-05
     +,   3.5767232E-05,   3.6731497E-05,   3.7734946E-05
     +,   3.8779333E-05,   3.9866525E-05,   4.0998490E-05
     +,   4.2177333E-05,   4.3405329E-05,   4.4684926E-05
     +,   4.6018897E-05,   4.7410147E-05,   4.8862054E-05
     +,   5.0378319E-05,   5.1963099E-05,   5.3621090E-05
     +,   5.5357581E-05,   5.7178531E-05,   5.9090675E-05
     +,   6.1101571E-05,   6.3219697E-05,   6.5454544E-05
     +,   6.7816625E-05,   7.0317583E-05,   7.2970164E-05
     +,   7.5788383E-05,   7.8787125E-05,   8.1982624E-05
     +,   8.5391985E-05,   8.9033107E-05,   9.2924689E-05
     +,   9.7085933E-05,   1.0153624E-04,   1.0629510E-04
     +,   1.1138156E-04,   1.1681442E-04,   1.2261183E-04
     +,   1.2879056E-04,   1.3536720E-04,   1.4235661E-04
     +,   1.4977422E-04,   1.5763455E-04,   1.6595422E-04
     +,   1.7475120E-04,   1.8404881E-04,   1.9387581E-04
     +,   2.0427113E-04,   2.1528667E-04,   2.2698985E-04
     +,   2.3946891E-04,   2.5283734E-04,   2.6723772E-04
     +,   2.8284421E-04,   2.9986887E-04,   3.1856151E-04
     +,   3.3921615E-04,   3.6217028E-04,   3.8781454E-04
     +,   4.1659598E-04,   4.4903762E-04,   4.8575268E-04
     +,   5.2748102E-04,   5.7512405E-04,   6.2978046E-04
     +,   6.9278065E-04,   7.6570170E-04,   8.5033989E-04
     +,   9.4863115E-04,   1.0625643E-03,   1.1940427E-03
     +,   1.3448494E-03,   1.5166813E-03,   1.7114764E-03
     +,   1.9319572E-03,   2.1826567E-03,   2.4712617E-03
     +,   2.8104428E-03,   3.2196520E-03,   3.7261632E-03
     +,   4.3641552E-03,   5.1711681E-03,   6.1837197E-03
     +,   7.4367407E-03,   8.9685814E-03,   1.0818739E-02
     +,   1.3003947E-02,   1.5500852E-02,   1.8341167E-02
     +,   2.1851826E-02,   2.6748635E-02,   3.3681285E-02
     +,   4.2510048E-02,   5.2281782E-02,   6.2389255E-02
     +,   7.3372684E-02,   8.5795522E-02,   9.7843491E-02
     +,   0.1074893    ,   0.1179286    ,   0.1262965    
     +,   0.1260818    ,   0.1180390    ,   0.1072703    
     +,   9.8541453E-02,   8.7428756E-02,   7.4562423E-02
     +,   6.3822113E-02,   5.4979894E-02,   4.7287799E-02
     +,   4.0832546E-02,   3.5797518E-02,   3.2022115E-02
     +,   2.9095730E-02,   2.6637407E-02,   2.4391472E-02
     +,   2.2185994E-02,   1.9909019E-02,   1.7544080E-02
     +,   1.5205591E-02,   1.3085802E-02,   1.1342557E-02
     +,   1.0031987E-02,   9.1182841E-03,   8.5151671E-03
     +,   8.1208926E-03,   7.8418702E-03,   7.6076807E-03
     +,   7.3759733E-03,   7.1277199E-03,   6.8576103E-03
     +,   6.5655918E-03,   6.2525938E-03,   5.9198020E-03
     +,   5.5697905E-03,   5.2075819E-03,   4.8407619E-03
     +,   4.4786166E-03,   4.1308161E-03,   3.8060076E-03
     +,   3.5107420E-03,   3.2488883E-03,   3.0216596E-03
     +,   2.8280555E-03,   2.6654871E-03,   2.5304595E-03
     +,   2.4191453E-03,   2.3277602E-03,   2.2527343E-03
     +,   2.1908018E-03,   2.1389972E-03,   2.0946530E-03
     +,   2.0553910E-03,   2.0191357E-03,   1.9841213E-03
     +,   1.9488896E-03,   1.9122781E-03,   1.8733991E-03
     +,   1.8316077E-03,   1.7864696E-03,   1.7377279E-03
     +,   1.6852843E-03,   1.6291888E-03,   1.5696234E-03
     +,   1.5069027E-03,   1.4414754E-03,   1.3739112E-03
     +,   1.3048860E-03,   1.2351578E-03,   1.1655480E-03
     +,   1.0968940E-03,   1.0300046E-03,   9.6562196E-04
     +,   9.0438983E-04,   8.4681646E-04,   7.9325202E-04
     +,   7.4388122E-04,   6.9873588E-04,   6.5769354E-04
     +,   6.2050991E-04,   5.8684498E-04,   5.5629387E-04
     +,   5.2841398E-04,   5.0275697E-04,   4.7889407E-04
     +,   4.5643336E-04,   4.3503224E-04,   4.1440627E-04
     +,   3.9433467E-04,   3.7465693E-04,   3.5526796E-04
     +,   3.3611187E-04,   3.1717742E-04,   2.9848437E-04
     +,   2.8007739E-04,   2.6201946E-04,   2.4438321E-04
     +,   2.2724333E-04,   2.1067288E-04,   1.9474038E-04
     +,   1.7950548E-04,   1.6501607E-04,   1.5130846E-04
     +,   1.3840757E-04,   1.2632627E-04,   1.1506525E-04
     +,   1.0461513E-04,   9.4958596E-05,   8.6069551E-05
     +,   7.7916069E-05,   7.0461851E-05,   6.3667270E-05
     +,   5.7490091E-05,   5.1887135E-05,   4.6815483E-05
     +,   4.2232870E-05,   3.8098009E-05,   3.4371496E-05
     +,   3.1016283E-05,   2.7997643E-05,   2.5283105E-05
     +,   2.2842783E-05,   2.0649481E-05,   1.8678194E-05
     +,   1.6906233E-05,   1.5313191E-05,   1.3880649E-05
     +,   1.2591925E-05,   1.1432059E-05,   1.0387690E-05
     +,   9.4468396E-06,   8.5987067E-06,   7.8336288E-06
     +,   7.1430027E-06,   6.5191148E-06,   5.9550257E-06
     +,   5.4445245E-06,   4.9821024E-06,   4.5627812E-06
     +,   4.1821149E-06,   3.8361504E-06,   3.5213550E-06
     +,   3.2345504E-06,   2.9729053E-06,   2.7339099E-06
     +,   2.5153224E-06,   2.3151349E-06,   2.1315577E-06
     +,   1.9630145E-06,   1.8080808E-06,   1.6655080E-06
     +,   1.5341645E-06,   1.4130597E-06,   1.3012931E-06
     +,   1.1980752E-06,   1.1026868E-06,   1.0144947E-06
     +,   9.3291999E-07,   8.5745069E-07,   7.8761775E-07
     +,   7.2299611E-07,   6.6320683E-07,   6.0789563E-07
     +,   5.5674622E-07,   5.0946153E-07,   4.6577452E-07
     +,   4.2543263E-07,   3.8820724E-07,   3.5388089E-07
     +,   3.2225617E-07,   2.9314398E-07,   2.6637190E-07
     +,   2.4177481E-07,   2.1920117E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_hatt80 = Yx/0.522803921568627
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6957377E-06,   2.9617167E-06
     +,   3.2488856E-06,   3.5583448E-06,   3.8911894E-06
     +,   4.2484967E-06,   4.6313189E-06,   5.0406684E-06
     +,   5.4775078E-06,   5.9427603E-06,   6.4372612E-06
     +,   6.9617668E-06,   7.5169387E-06,   8.1033359E-06
     +,   8.7213966E-06,   9.3714234E-06,   1.0053579E-05
     +,   1.0767873E-05,   1.1514150E-05,   1.2292078E-05
     +,   1.3101146E-05,   1.3940654E-05,   1.4809696E-05
     +,   1.5707234E-05,   1.6631937E-05,   1.7582384E-05
     +,   1.8556913E-05,   1.9553720E-05,   2.0570827E-05
     +,   2.1606125E-05,   2.2657387E-05,   2.3722310E-05
     +,   2.4798510E-05,   2.5883593E-05,   2.6975187E-05
     +,   2.8070957E-05,   2.9168699E-05,   3.0266339E-05
     +,   3.1362077E-05,   3.2454289E-05,   3.3541768E-05
     +,   3.4623637E-05,   3.5699511E-05,   3.6769503E-05
     +,   3.7834277E-05,   3.8895163E-05,   3.9954175E-05
     +,   4.1014053E-05,   4.2078329E-05,   4.3151369E-05
     +,   4.4238390E-05,   4.5345489E-05,   4.6479650E-05
     +,   4.7648839E-05,   4.8861770E-05,   5.0128168E-05
     +,   5.1458534E-05,   5.2864165E-05,   5.4357053E-05
     +,   5.5949902E-05,   5.7655838E-05,   5.9488550E-05
     +,   6.1461804E-05,   6.3589687E-05,   6.5886183E-05
     +,   6.8364832E-05,   7.1038987E-05,   7.3921074E-05
     +,   7.7022858E-05,   8.0354672E-05,   8.3925945E-05
     +,   8.7744156E-05,   9.1815637E-05,   9.6144613E-05
     +,   1.0073404E-04,   1.0558550E-04,   1.1069908E-04
     +,   1.1607411E-04,   1.2171028E-04,   1.2760809E-04
     +,   1.3376922E-04,   1.4019929E-04,   1.4690738E-04
     +,   1.5390929E-04,   1.6122726E-04,   1.6889312E-04
     +,   1.7694748E-04,   1.8544249E-04,   1.9444001E-04
     +,   2.0401312E-04,   2.1424386E-04,   2.2522082E-04
     +,   2.3703634E-04,   2.4978374E-04,   2.6355212E-04
     +,   2.7842016E-04,   2.9445460E-04,   3.1170179E-04
     +,   3.3018910E-04,   3.4991829E-04,   3.7087096E-04
     +,   3.9300643E-04,   4.1627284E-04,   4.4061153E-04
     +,   4.6597372E-04,   4.9233623E-04,   5.1972119E-04
     +,   5.4822367E-04,   5.7805009E-04,   6.0955778E-04
     +,   6.4330618E-04,   6.8012701E-04,   7.2118209E-04
     +,   7.6804316E-04,   8.2272914E-04,   8.8773965E-04
     +,   9.6600363E-04,   1.0607963E-03,   1.1755426E-03
     +,   1.3136237E-03,   1.4781400E-03,   1.6717297E-03
     +,   1.8964974E-03,   2.1541214E-03,   2.4462228E-03
     +,   2.7753550E-03,   3.1471916E-03,   3.5737106E-03
     +,   4.0764776E-03,   4.6872152E-03,   5.4457071E-03
     +,   6.4007724E-03,   7.6273051E-03,   9.2626112E-03
     +,   1.1527878E-02,   1.4646097E-02,   1.8629557E-02
     +,   2.3229530E-02,   2.8513910E-02,   3.5539337E-02
     +,   4.5415383E-02,   5.7201374E-02,   6.9915585E-02
     +,   8.6086199E-02,   0.1047405    ,   0.1224337    
     +,   0.1359071    ,   0.1427673    ,   0.1447514    
     +,   0.1347687    ,   0.1273666    ,   0.1225199    
     +,   0.1133637    ,   0.1046382    ,   9.0795465E-02
     +,   7.4513458E-02,   6.0856275E-02,   4.9098585E-02
     +,   3.9701838E-02,   3.2734241E-02,   2.7577257E-02
     +,   2.3909409E-02,   2.1362828E-02,   1.9346610E-02
     +,   1.7410096E-02,   1.5478505E-02,   1.3724682E-02
     +,   1.2322037E-02,   1.1305587E-02,   1.0578847E-02
     +,   9.9924672E-03,   9.4173076E-03,   8.7802354E-03
     +,   8.0662817E-03,   7.3026204E-03,   6.5371171E-03
     +,   5.8196904E-03,   5.1899101E-03,   4.6715070E-03
     +,   4.2724088E-03,   3.9877011E-03,   3.8031070E-03
     +,   3.6979399E-03,   3.6476271E-03,   3.6261615E-03
     +,   3.6086494E-03,   3.5738612E-03,   3.5063836E-03
     +,   3.3978994E-03,   3.2474082E-03,   3.0602887E-03
     +,   2.8465155E-03,   2.6184367E-03,   2.3885334E-03
     +,   2.1675876E-03,   1.9635451E-03,   1.7811117E-03
     +,   1.6219369E-03,   1.4852330E-03,   1.3686051E-03
     +,   1.2688541E-03,   1.1826135E-03,   1.1067877E-03
     +,   1.0387981E-03,   9.7666122E-04,   9.1894442E-04
     +,   8.6468284E-04,   8.1327063E-04,   7.6435122E-04
     +,   7.1772520E-04,   6.7328382E-04,   6.3096191E-04
     +,   5.9070246E-04,   5.5243599E-04,   5.1607739E-04
     +,   4.8152774E-04,   4.4867897E-04,   4.1741919E-04
     +,   3.8764524E-04,   3.5927180E-04,   3.3223120E-04
     +,   3.0647838E-04,   2.8199205E-04,   2.5876911E-04
     +,   2.3681868E-04,   2.1615745E-04,   1.9680470E-04
     +,   1.7877544E-04,   1.6207428E-04,   1.4669372E-04
     +,   1.3261316E-04,   1.1979713E-04,   1.0819532E-04
     +,   9.7745367E-05,   8.8375928E-05,   8.0007296E-05
     +,   7.2555478E-05,   6.5935092E-05,   6.0061226E-05
     +,   5.4851189E-05,   5.0226583E-05,   4.6114688E-05
     +,   4.2448926E-05,   3.9169070E-05,   3.6221641E-05
     +,   3.3559940E-05,   3.1143496E-05,   2.8937498E-05
     +,   2.6912485E-05,   2.5043904E-05,   2.3311182E-05
     +,   2.1697384E-05,   2.0188752E-05,   1.8774117E-05
     +,   1.7444379E-05,   1.6192213E-05,   1.5011802E-05
     +,   1.3898460E-05,   1.2848302E-05,   1.1858134E-05
     +,   1.0925326E-05,   1.0047604E-05,   9.2228829E-06
     +,   8.4492449E-06,   7.7249433E-06,   7.0482010E-06
     +,   6.4172505E-06,   5.8303604E-06,   5.2857654E-06
     +,   4.7816288E-06,   4.3160899E-06,   3.8872918E-06
     +,   3.4933541E-06,   3.1323589E-06,   2.8023937E-06
     +,   2.5015913E-06,   2.2280651E-06,   1.9800029E-06
     +,   1.7555990E-06,   1.5531357E-06,   1.3709250E-06
     +,   1.2073730E-06,   1.0609346E-06,   9.3016223E-07
     +,   8.1366943E-07,   7.1016626E-07,   6.1843360E-07
     +,   5.3733481E-07,   4.6582187E-07,   4.0291539E-07
     +,   3.4772111E-07,   2.9941069E-07,   2.5723310E-07
     +,   2.2049855E-07,   1.8858546E-07,   1.6092741E-07
     +,   1.3701738E-07,   1.1639668E-07,   9.8657402E-08
     +,   8.3433044E-08,   7.0399707E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_hatt85 = Yx/0.557392156862745
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9931618E-05,   2.0813544E-05
     +,   2.1710888E-05,   2.2622682E-05,   2.3547951E-05
     +,   2.4485691E-05,   2.5434871E-05,   2.6394462E-05
     +,   2.7363401E-05,   2.8340692E-05,   2.9325291E-05
     +,   3.0316180E-05,   3.1312382E-05,   3.2312932E-05
     +,   3.3316908E-05,   3.4323428E-05,   3.5331650E-05
     +,   3.6340785E-05,   3.7350121E-05,   3.8358965E-05
     +,   3.9366718E-05,   4.0372826E-05,   4.1376796E-05
     +,   4.2378280E-05,   4.3376862E-05,   4.4372333E-05
     +,   4.5364479E-05,   4.6353183E-05,   4.7338392E-05
     +,   4.8320122E-05,   4.9298473E-05,   5.0273607E-05
     +,   5.1245745E-05,   5.2215164E-05,   5.3182255E-05
     +,   5.4147400E-05,   5.5111090E-05,   5.6073823E-05
     +,   5.7036239E-05,   5.7998895E-05,   5.8962516E-05
     +,   5.9927785E-05,   6.0895451E-05,   6.1866289E-05
     +,   6.2841114E-05,   6.3820713E-05,   6.4805929E-05
     +,   6.5797569E-05,   6.6796463E-05,   6.7803398E-05
     +,   6.8819165E-05,   6.9844478E-05,   7.0879993E-05
     +,   7.1926450E-05,   7.2984258E-05,   7.4053998E-05
     +,   7.5136035E-05,   7.6230674E-05,   7.7338147E-05
     +,   7.8458484E-05,   7.9591766E-05,   8.0737940E-05
     +,   8.1896818E-05,   8.3068262E-05,   8.4252140E-05
     +,   8.5448279E-05,   8.6656757E-05,   8.7877663E-05
     +,   8.9111556E-05,   9.0359237E-05,   9.1622322E-05
     +,   9.2902868E-05,   9.4204152E-05,   9.5530457E-05
     +,   9.6887554E-05,   9.8283163E-05,   9.9726924E-05
     +,   1.0123091E-04,   1.0281024E-04,   1.0448316E-04
     +,   1.0627138E-04,   1.0820085E-04,   1.1030136E-04
     +,   1.1260741E-04,   1.1515756E-04,   1.1799509E-04
     +,   1.2116674E-04,   1.2472323E-04,   1.2871719E-04
     +,   1.3320311E-04,   1.3823541E-04,   1.4386645E-04
     +,   1.5014468E-04,   1.5711277E-04,   1.6480520E-04
     +,   1.7324476E-04,   1.8244215E-04,   1.9239179E-04
     +,   2.0307257E-04,   2.1444383E-04,   2.2644854E-04
     +,   2.3900994E-04,   2.5203658E-04,   2.6542149E-04
     +,   2.7904849E-04,   2.9279545E-04,   3.0653834E-04
     +,   3.2015837E-04,   3.3354937E-04,   3.4662307E-04
     +,   3.5931499E-04,   3.7159293E-04,   3.8345944E-04
     +,   3.9495941E-04,   4.0618042E-04,   4.1725679E-04
     +,   4.2836665E-04,   4.3973309E-04,   4.5161630E-04
     +,   4.6430939E-04,   4.7812803E-04,   4.9339817E-04
     +,   5.1044271E-04,   5.2956783E-04,   5.5104709E-04
     +,   5.7510415E-04,   6.0190784E-04,   6.3156342E-04
     +,   6.6412450E-04,   6.9960911E-04,   7.3804770E-04
     +,   7.7953521E-04,   8.2432129E-04,   8.7289518E-04
     +,   9.2608784E-04,   9.8514417E-04,   1.0517389E-03
     +,   1.1279284E-03,   1.2160059E-03,   1.3182501E-03
     +,   1.4366172E-03,   1.5724568E-03,   1.7263761E-03
     +,   1.8983599E-03,   2.0883291E-03,   2.2974531E-03
     +,   2.5305105E-03,   2.7999685E-03,   3.1322923E-03
     +,   3.5756258E-03,   4.2042416E-03,   5.1102592E-03
     +,   6.3760625E-03,   8.0434559E-03,   1.0124131E-02
     +,   1.2668755E-02,   1.5810285E-02,   1.9704547E-02
     +,   2.4517428E-02,   3.0619416E-02,   3.8594984E-02
     +,   4.8235483E-02,   5.8615670E-02,   7.1261302E-02
     +,   8.7944649E-02,   0.1101593    ,   0.1348411    
     +,   0.1540285    ,   0.1648083    ,   0.1635884    
     +,   0.1561266    ,   0.1476725    ,   0.1301026    
     +,   0.1107453    ,   9.1426969E-02,   7.7841796E-02
     +,   6.7661896E-02,   5.4583408E-02,   4.1777283E-02
     +,   3.2569163E-02,   2.7092665E-02,   2.3904337E-02
     +,   2.1805003E-02,   2.0021284E-02,   1.8154688E-02
     +,   1.6182635E-02,   1.4247608E-02,   1.2467598E-02
     +,   1.0899258E-02,   9.5565924E-03,   8.4221866E-03
     +,   7.4583571E-03,   6.6238111E-03,   5.8875498E-03
     +,   5.2329516E-03,   4.6537719E-03,   4.1478835E-03
     +,   3.7128627E-03,   3.3444203E-03,   3.0364557E-03
     +,   2.7815842E-03,   2.5715595E-03,   2.3976546E-03
     +,   2.2510148E-03,   2.1230346E-03,   2.0057515E-03
     +,   1.8923095E-03,   1.7773937E-03,   1.6575496E-03
     +,   1.5313042E-03,   1.3990740E-03,   1.2628504E-03
     +,   1.1257137E-03,   9.9125830E-04,   8.6306385E-04
     +,   7.4424956E-04,   6.3715060E-04,   5.4316176E-04
     +,   4.6273740E-04,   3.9551183E-04,   3.4046892E-04
     +,   2.9617030E-04,   2.6096855E-04,   2.3318287E-04
     +,   2.1123247E-04,   1.9372374E-04,   1.7949258E-04
     +,   1.6760865E-04,   1.5735907E-04,   1.4821933E-04
     +,   1.3981909E-04,   1.3190757E-04,   1.2432264E-04
     +,   1.1696684E-04,   1.0978839E-04,   1.0276531E-04
     +,   9.5895462E-05,   8.9189576E-05,   8.2665530E-05
     +,   7.6344186E-05,   7.0247326E-05,   6.4396270E-05
     +,   5.8810267E-05,   5.3505239E-05,   4.8493715E-05
     +,   4.3784890E-05,   3.9384118E-05,   3.5292775E-05
     +,   3.1508793E-05,   2.8027225E-05,   2.4839926E-05
     +,   2.1936334E-05,   1.9304065E-05,   1.6929105E-05
     +,   1.4796108E-05,   1.2888963E-05,   1.1191270E-05
     +,   9.6864987E-06,   8.3581872E-06,   7.1903005E-06
     +,   6.1674864E-06,   5.2751170E-06,   4.4993599E-06
     +,   3.8273211E-06,   3.2471469E-06,   2.7478995E-06
     +,   2.3196314E-06,   1.9533820E-06,   1.6410957E-06
     +,   1.3755641E-06,   1.1503954E-06,   9.5996222E-07
     +,   7.9932079E-07,   6.6413833E-07,   5.5064868E-07
     +,   4.5559824E-07,   3.7616638E-07,   3.0993888E-07
     +,   2.5483752E-07,   2.0909513E-07,   1.7120071E-07
     +,   1.3987683E-07,   1.1403753E-07,   9.2769447E-08
     +,   7.5300363E-08,   6.0983794E-08,   4.9276153E-08
     +,   3.9723144E-08,   3.1946406E-08,   2.5629886E-08
     +,   2.0511838E-08,   1.6374553E-08,   1.3038518E-08
     +,   1.0355100E-08,   8.2023108E-09,   6.4795880E-09
     +,   5.1047833E-09,   4.0105195E-09,   3.1420075E-09
     +,   2.4545637E-09,   1.9120225E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_hatt90 = Yx/0.558490196078431
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1544980E-06,   9.6507219E-06
     +,   1.0164906E-05,   1.0697477E-05,   1.1248905E-05
     +,   1.1819682E-05,   1.2410339E-05,   1.3021430E-05
     +,   1.3653524E-05,   1.4307236E-05,   1.4983159E-05
     +,   1.5681886E-05,   1.6403998E-05,   1.7150040E-05
     +,   1.7920504E-05,   1.8715820E-05,   1.9536310E-05
     +,   2.0382195E-05,   2.1253541E-05,   2.2150271E-05
     +,   2.3072096E-05,   2.4018527E-05,   2.4988813E-05
     +,   2.5982015E-05,   2.6996791E-05,   2.8031631E-05
     +,   2.9084636E-05,   3.0153615E-05,   3.1236053E-05
     +,   3.2329121E-05,   3.3429664E-05,   3.4534252E-05
     +,   3.5639161E-05,   3.6740432E-05,   3.7833899E-05
     +,   3.8915216E-05,   3.9979914E-05,   4.1023428E-05
     +,   4.2041269E-05,   4.3028867E-05,   4.3981883E-05
     +,   4.4896104E-05,   4.5767538E-05,   4.6592562E-05
     +,   4.7367881E-05,   4.8090678E-05,   4.8758589E-05
     +,   4.9369810E-05,   4.9923161E-05,   5.0418013E-05
     +,   5.0854433E-05,   5.1233117E-05,   5.1555464E-05
     +,   5.1823528E-05,   5.2039988E-05,   5.2208205E-05
     +,   5.2332070E-05,   5.2416075E-05,   5.2465213E-05
     +,   5.2484898E-05,   5.2480977E-05,   5.2459585E-05
     +,   5.2427160E-05,   5.2390329E-05,   5.2355830E-05
     +,   5.2330524E-05,   5.2321273E-05,   5.2334941E-05
     +,   5.2378335E-05,   5.2458185E-05,   5.2581108E-05
     +,   5.2753647E-05,   5.2982232E-05,   5.3273205E-05
     +,   5.3632866E-05,   5.4067485E-05,   5.4583343E-05
     +,   5.5186734E-05,   5.5884117E-05,   5.6682060E-05
     +,   5.7587233E-05,   5.8606583E-05,   5.9747101E-05
     +,   6.1016101E-05,   6.2420797E-05,   6.3968626E-05
     +,   6.5666776E-05,   6.7522386E-05,   6.9541951E-05
     +,   7.1731534E-05,   7.4096359E-05,   7.6640346E-05
     +,   7.9365986E-05,   8.2274164E-05,   8.5363812E-05
     +,   8.8631175E-05,   9.2070404E-05,   9.5672374E-05
     +,   9.9425488E-05,   1.0331469E-04,   1.0732237E-04
     +,   1.1142763E-04,   1.1560735E-04,   1.1983576E-04
     +,   1.2408553E-04,   1.2832839E-04,   1.3253516E-04
     +,   1.3667712E-04,   1.4072702E-04,   1.4465986E-04
     +,   1.4845330E-04,   1.5208976E-04,   1.5555597E-04
     +,   1.5884501E-04,   1.6195585E-04,   1.6489494E-04
     +,   1.6767549E-04,   1.7031874E-04,   1.7285295E-04
     +,   1.7531408E-04,   1.7774517E-04,   1.8019593E-04
     +,   1.8272262E-04,   1.8538807E-04,   1.8826142E-04
     +,   1.9141794E-04,   1.9494037E-04,   1.9891812E-04
     +,   2.0344970E-04,   2.0864190E-04,   2.1461175E-04
     +,   2.2148552E-04,   2.2939935E-04,   2.3849701E-04
     +,   2.4892821E-04,   2.6084515E-04,   2.7439650E-04
     +,   2.8972374E-04,   3.0695717E-04,   3.2621200E-04
     +,   3.4758737E-04,   3.7117128E-04,   3.9705384E-04
     +,   4.2534294E-04,   4.5618636E-04,   4.8980699E-04
     +,   5.2652793E-04,   5.6679221E-04,   6.1116955E-04
     +,   6.6033477E-04,   7.1500515E-04,   7.7583623E-04
     +,   8.4328436E-04,   9.1745274E-04,   9.9793565E-04
     +,   1.0837123E-03,   1.1731375E-03,   1.2640805E-03
     +,   1.3542160E-03,   1.4414837E-03,   1.5247181E-03
     +,   1.6043034E-03,   1.6827534E-03,   1.7650344E-03
     +,   1.8584152E-03,   1.9717326E-03,   2.1142007E-03
     +,   2.2943404E-03,   2.5201209E-03,   2.8014937E-03
     +,   3.1557702E-03,   3.6146920E-03,   4.2316951E-03
     +,   5.0896960E-03,   6.3084499E-03,   8.0369152E-03
     +,   1.0398728E-02,   1.3380968E-02,   1.6767753E-02
     +,   2.0365693E-02,   2.4716439E-02,   3.1764589E-02
     +,   4.3413531E-02,   5.8880147E-02,   7.5996965E-02
     +,   9.5469952E-02,   0.1277685    ,   0.1630765    
     +,   0.1813899    ,   0.1845077    ,   0.1852633    
     +,   0.1788587    ,   0.1483442    ,   0.1190837    
     +,   9.5133841E-02,   7.2808720E-02,   5.5749997E-02
     +,   4.5241646E-02,   3.7561551E-02,   3.0714383E-02
     +,   2.4776302E-02,   2.0281117E-02,   1.7332952E-02
     +,   1.5343025E-02,   1.3628931E-02,   1.1904450E-02
     +,   1.0208212E-02,   8.6632306E-03,   7.3416634E-03
     +,   6.2483507E-03,   5.3511821E-03,   4.6079578E-03
     +,   3.9802254E-03,   3.4389624E-03,   2.9652566E-03
     +,   2.5481184E-03,   2.1814790E-03,   1.8617446E-03
     +,   1.5861293E-03,   1.3515992E-03,   1.1543308E-03
     +,   9.8976400E-04,   8.5296656E-04,   7.3908037E-04
     +,   6.4368872E-04,   5.6303898E-04,   4.9410725E-04
     +,   4.3454094E-04,   3.8255434E-04,   3.3681438E-04
     +,   2.9633194E-04,   2.6036589E-04,   2.2834938E-04
     +,   1.9983937E-04,   1.7448100E-04,   1.5197479E-04
     +,   1.3206128E-04,   1.1450984E-04,   9.9108751E-05
     +,   8.5659027E-05,   7.3973075E-05,   6.3873500E-05
     +,   5.5191729E-05,   4.7767619E-05,   4.1450759E-05
     +,   3.6101374E-05,   3.1590378E-05,   2.7799639E-05
     +,   2.4622645E-05,   2.1964721E-05,   1.9742138E-05
     +,   1.7882045E-05,   1.6321816E-05,   1.5008102E-05
     +,   1.3895837E-05,   1.2947427E-05,   1.2131827E-05
     +,   1.1423545E-05,   1.0801774E-05,   1.0249670E-05
     +,   9.7537104E-06,   9.3030530E-06,   8.8890147E-06
     +,   8.5046868E-06,   8.1446178E-06,   7.8044650E-06
     +,   7.4807940E-06,   7.1709273E-06,   6.8727682E-06
     +,   6.5846702E-06,   6.3053631E-06,   6.0339034E-06
     +,   5.7695916E-06,   5.5119071E-06,   5.2604928E-06
     +,   5.0151439E-06,   4.7757262E-06,   4.5422148E-06
     +,   4.3146151E-06,   4.0930099E-06,   3.8774797E-06
     +,   3.6681545E-06,   3.4651459E-06,   3.2685925E-06
     +,   3.0786007E-06,   2.8952895E-06,   2.7187450E-06
     +,   2.5490317E-06,   2.3862112E-06,   2.2302977E-06
     +,   2.0813034E-06,   1.9391932E-06,   1.8039294E-06
     +,   1.6754308E-06,   1.5536106E-06,   1.4383444E-06
     +,   1.3295042E-06,   1.2269289E-06,   1.1304553E-06
     +,   1.0398934E-06,   9.5505266E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_hatt95 = Yx/0.529529411764706
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.6379580E-05,   5.7931054E-05
     +,   5.9489917E-05,   6.1054729E-05,   6.2624022E-05
     +,   6.4196305E-05,   6.5770058E-05,   6.7343746E-05
     +,   6.8915797E-05,   7.0484704E-05,   7.2048919E-05
     +,   7.3606876E-05,   7.5157084E-05,   7.6698001E-05
     +,   7.8228208E-05,   7.9746336E-05,   8.1250975E-05
     +,   8.2740895E-05,   8.4214938E-05,   8.5672043E-05
     +,   8.7111293E-05,   8.8531888E-05,   8.9933223E-05
     +,   9.1314920E-05,   9.2676732E-05,   9.4018673E-05
     +,   9.5341107E-05,   9.6644573E-05,   9.7929995E-05
     +,   9.9198631E-05,   1.0045207E-04,   1.0169232E-04
     +,   1.0292180E-04,   1.0414339E-04,   1.0536040E-04
     +,   1.0657661E-04,   1.0779636E-04,   1.0902437E-04
     +,   1.1026603E-04,   1.1152704E-04,   1.1281379E-04
     +,   1.1413309E-04,   1.1549207E-04,   1.1689855E-04
     +,   1.1836061E-04,   1.1988669E-04,   1.2148554E-04
     +,   1.2316623E-04,   1.2493778E-04,   1.2680958E-04
     +,   1.2879082E-04,   1.3089064E-04,   1.3311788E-04
     +,   1.3548133E-04,   1.3798903E-04,   1.4064860E-04
     +,   1.4346701E-04,   1.4645039E-04,   1.4960389E-04
     +,   1.5293183E-04,   1.5643706E-04,   1.6012153E-04
     +,   1.6398556E-04,   1.6802823E-04,   1.7224735E-04
     +,   1.7663870E-04,   1.8119694E-04,   1.8591499E-04
     +,   1.9078447E-04,   1.9579504E-04,   2.0093568E-04
     +,   2.0619317E-04,   2.1155382E-04,   2.1700225E-04
     +,   2.2252233E-04,   2.2809750E-04,   2.3370994E-04
     +,   2.3934161E-04,   2.4497454E-04,   2.5059062E-04
     +,   2.5617168E-04,   2.6170025E-04,   2.6715928E-04
     +,   2.7253290E-04,   2.7780537E-04,   2.8296333E-04
     +,   2.8799337E-04,   2.9288465E-04,   2.9762706E-04
     +,   3.0221260E-04,   3.0663461E-04,   3.1088790E-04
     +,   3.1496896E-04,   3.1887594E-04,   3.2260839E-04
     +,   3.2616712E-04,   3.2955420E-04,   3.3277244E-04
     +,   3.3582590E-04,   3.3871914E-04,   3.4145714E-04
     +,   3.4404479E-04,   3.4648788E-04,   3.4879104E-04
     +,   3.5095989E-04,   3.5299835E-04,   3.5491039E-04
     +,   3.5669914E-04,   3.5836722E-04,   3.5991630E-04
     +,   3.6134696E-04,   3.6265975E-04,   3.6385437E-04
     +,   3.6492993E-04,   3.6588515E-04,   3.6671918E-04
     +,   3.6743065E-04,   3.6801927E-04,   3.6848499E-04
     +,   3.6882909E-04,   3.6905377E-04,   3.6916355E-04
     +,   3.6916402E-04,   3.6906326E-04,   3.6887146E-04
     +,   3.6860188E-04,   3.6826934E-04,   3.6789209E-04
     +,   3.6749037E-04,   3.6708711E-04,   3.6670710E-04
     +,   3.6637724E-04,   3.6612552E-04,   3.6598128E-04
     +,   3.6597380E-04,   3.6613236E-04,   3.6648533E-04
     +,   3.6705896E-04,   3.6787768E-04,   3.6896206E-04
     +,   3.7032933E-04,   3.7199169E-04,   3.7395611E-04
     +,   3.7622431E-04,   3.7879153E-04,   3.8164703E-04
     +,   3.8477397E-04,   3.8814879E-04,   3.9174297E-04
     +,   3.9552277E-04,   3.9945048E-04,   4.0348512E-04
     +,   4.0758462E-04,   4.1170666E-04,   4.1581134E-04
     +,   4.1986204E-04,   4.2382866E-04,   4.2768949E-04
     +,   4.3143381E-04,   4.3506356E-04,   4.3859662E-04
     +,   4.4206815E-04,   4.4553250E-04,   4.4906518E-04
     +,   4.5276404E-04,   4.5674926E-04,   4.6116335E-04
     +,   4.6617011E-04,   4.7195388E-04,   4.7871511E-04
     +,   4.8666762E-04,   4.9603271E-04,   5.0703494E-04
     +,   5.1989366E-04,   5.3481606E-04,   5.5199099E-04
     +,   5.7158095E-04,   5.9371447E-04,   6.1848178E-04
     +,   6.4593542E-04,   6.7608908E-04,   7.0892362E-04
     +,   7.4439723E-04,   7.8246935E-04,   8.2312082E-04
     +,   8.6638698E-04,   9.1240095E-04,   9.6144376E-04
     +,   1.0139955E-03,   1.0707865E-03,   1.1328559E-03
     +,   1.2015883E-03,   1.2787250E-03,   1.3663521E-03
     +,   1.4668431E-03,   1.5827391E-03,   1.7165587E-03
     +,   1.8705693E-03,   2.0465234E-03,   2.2453759E-03
     +,   2.4670188E-03,   2.7101447E-03,   2.9722538E-03
     +,   3.2498222E-03,   3.5386481E-03,   3.8345235E-03
     +,   4.1340599E-03,   4.4357451E-03,   4.7413334E-03
     +,   5.0573223E-03,   5.3962804E-03,   5.7776435E-03
     +,   6.2275589E-03,   6.7775720E-03,   7.4617486E-03
     +,   8.3121313E-03,   9.3529243E-03,   1.0596485E-02
     +,   1.2047289E-02,   1.3720002E-02,   1.5665554E-02
     +,   1.7977852E-02,   2.0749804E-02,   2.3994720E-02
     +,   2.7636137E-02,   3.1667713E-02,   3.6367368E-02
     +,   4.2180885E-02,   4.9087480E-02,   5.6099087E-02
     +,   6.1982479E-02,   6.6715598E-02,   7.1242116E-02
     +,   7.5603716E-02,   7.8904882E-02,   8.0793411E-02
     +,   8.1237450E-02,   7.9951160E-02,   7.7236712E-02
     +,   7.4402057E-02,   7.2554119E-02,   7.0999175E-02
     +,   6.7946702E-02,   6.2976591E-02,   5.7405218E-02
     +,   5.2418612E-02,   4.8221916E-02,   4.4650257E-02
     +,   4.1501272E-02,   3.8473688E-02,   3.5276804E-02
     +,   3.1767853E-02,   2.8000142E-02,   2.4214098E-02
     +,   2.0714898E-02,   1.7701125E-02,   1.5199868E-02
     +,   1.3125748E-02,   1.1366810E-02,   9.8329969E-03
     +,   8.4677152E-03,   7.2425068E-03,   6.1470862E-03
     +,   5.1798220E-03,   4.3403427E-03,   3.6249703E-03
     +,   3.0253981E-03,   2.5294677E-03,   2.1229340E-03
     +,   1.7913053E-03,   1.5212168E-03,   1.3010963E-03
     +,   1.1212672E-03,   9.7377336E-04,   8.5212628E-04
     +,   7.5105840E-04,   6.6628488E-04,   5.9437798E-04
     +,   5.3261424E-04,   4.7888589E-04,   4.3158198E-04
     +,   3.8950366E-04,   3.5176243E-04,   3.1771066E-04
     +,   2.8686636E-04,   2.5886940E-04,   2.3343538E-04
     +,   2.1033180E-04,   1.8936183E-04,   1.7034711E-04
     +,   1.5312689E-04,   1.3754914E-04,   1.2347355E-04
     +,   1.1076681E-04,   9.9306315E-05,   8.8976914E-05
     +,   7.9674013E-05,   7.1300790E-05,   6.3770240E-05
     +,   5.7002577E-05,   5.0926632E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_hatt100 = Yx/0.487392156862745
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.8475314E-05,   8.1325990E-05
     +,   8.4261374E-05,   8.7281900E-05,   9.0387832E-05
     +,   9.3579190E-05,   9.6855903E-05,   1.0021772E-04
     +,   1.0366410E-04,   1.0719460E-04,   1.1080838E-04
     +,   1.1450459E-04,   1.1828214E-04,   1.2213987E-04
     +,   1.2607657E-04,   1.3009080E-04,   1.3418116E-04
     +,   1.3834603E-04,   1.4258396E-04,   1.4689328E-04
     +,   1.5127241E-04,   1.5571981E-04,   1.6023382E-04
     +,   1.6481319E-04,   1.6945635E-04,   1.7416207E-04
     +,   1.7892921E-04,   1.8375681E-04,   1.8864388E-04
     +,   1.9358985E-04,   1.9859413E-04,   2.0365654E-04
     +,   2.0877694E-04,   2.1395550E-04,   2.1919246E-04
     +,   2.2448844E-04,   2.2984414E-04,   2.3526060E-04
     +,   2.4073895E-04,   2.4628031E-04,   2.5188643E-04
     +,   2.5755871E-04,   2.6329892E-04,   2.6910895E-04
     +,   2.7499054E-04,   2.8094577E-04,   2.8697660E-04
     +,   2.9308480E-04,   2.9927253E-04,   3.0554156E-04
     +,   3.1189376E-04,   3.1833121E-04,   3.2485512E-04
     +,   3.3146777E-04,   3.3817024E-04,   3.4496465E-04
     +,   3.5185198E-04,   3.5883422E-04,   3.6591265E-04
     +,   3.7308893E-04,   3.8036495E-04,   3.8774248E-04
     +,   3.9522318E-04,   4.0280962E-04,   4.1050455E-04
     +,   4.1831052E-04,   4.2623130E-04,   4.3426963E-04
     +,   4.4243078E-04,   4.5071857E-04,   4.5913868E-04
     +,   4.6769605E-04,   4.7639705E-04,   4.8524822E-04
     +,   4.9425574E-04,   5.0342781E-04,   5.1277096E-04
     +,   5.2229187E-04,   5.3199881E-04,   5.4189854E-04
     +,   5.5199733E-04,   5.6230155E-04,   5.7281548E-04
     +,   5.8354443E-04,   5.9449120E-04,   6.0565746E-04
     +,   6.1704358E-04,   6.2864920E-04,   6.4047065E-04
     +,   6.5250485E-04,   6.6474569E-04,   6.7718624E-04
     +,   6.8981759E-04,   7.0263166E-04,   7.1561831E-04
     +,   7.2876608E-04,   7.4206694E-04,   7.5550936E-04
     +,   7.6908577E-04,   7.8278867E-04,   7.9661357E-04
     +,   8.1055710E-04,   8.2462013E-04,   8.3880452E-04
     +,   8.5311674E-04,   8.6756714E-04,   8.8216667E-04
     +,   8.9693029E-04,   9.1187429E-04,   9.2701748E-04
     +,   9.4237644E-04,   9.5796929E-04,   9.7380893E-04
     +,   9.8990730E-04,   1.0062677E-03,   1.0228896E-03
     +,   1.0397593E-03,   1.0568560E-03,   1.0741445E-03
     +,   1.0915778E-03,   1.1090941E-03,   1.1266143E-03
     +,   1.1440472E-03,   1.1612829E-03,   1.1782006E-03
     +,   1.1946610E-03,   1.2105184E-03,   1.2256126E-03
     +,   1.2397780E-03,   1.2528453E-03,   1.2646419E-03
     +,   1.2749982E-03,   1.2837518E-03,   1.2907487E-03
     +,   1.2958486E-03,   1.2989274E-03,   1.2998799E-03
     +,   1.2986258E-03,   1.2951088E-03,   1.2892976E-03
     +,   1.2811919E-03,   1.2708185E-03,   1.2582330E-03
     +,   1.2435181E-03,   1.2267862E-03,   1.2081712E-03
     +,   1.1878338E-03,   1.1659518E-03,   1.1427237E-03
     +,   1.1183596E-03,   1.0930810E-03,   1.0671195E-03
     +,   1.0407079E-03,   1.0140828E-03,   9.8747539E-04
     +,   9.6111646E-04,   9.3522656E-04,   9.1001636E-04
     +,   8.8568445E-04,   8.6241972E-04,   8.4039394E-04
     +,   8.1976189E-04,   8.0066605E-04,   7.8323111E-04
     +,   7.6756492E-04,   7.5375906E-04,   7.4189127E-04
     +,   7.3202432E-04,   7.2420581E-04,   7.1847223E-04
     +,   7.1484869E-04,   7.1335078E-04,   7.1398681E-04
     +,   7.1675848E-04,   7.2166469E-04,   7.2870404E-04
     +,   7.3787622E-04,   7.4918458E-04,   7.6264114E-04
     +,   7.7826728E-04,   7.9609983E-04,   8.1618945E-04
     +,   8.3860895E-04,   8.6345209E-04,   8.9083833E-04
     +,   9.2091667E-04,   9.5385942E-04,   9.8987145E-04
     +,   1.0291910E-03,   1.0720752E-03,   1.1188125E-03
     +,   1.1697144E-03,   1.2251035E-03,   1.2853097E-03
     +,   1.3506658E-03,   1.4214920E-03,   1.4980738E-03
     +,   1.5806576E-03,   1.6694306E-03,   1.7645031E-03
     +,   1.8658793E-03,   1.9734481E-03,   2.0869700E-03
     +,   2.2060678E-03,   2.3302017E-03,   2.4587039E-03
     +,   2.5907815E-03,   2.7255455E-03,   2.8620465E-03
     +,   2.9993553E-03,   3.1366074E-03,   3.2730696E-03
     +,   3.4082148E-03,   3.5417769E-03,   3.6737844E-03
     +,   3.8045472E-03,   3.9346381E-03,   4.0648323E-03
     +,   4.1959970E-03,   4.3289787E-03,   4.4644633E-03
     +,   4.6028825E-03,   4.7443318E-03,   4.8885471E-03
     +,   5.0349534E-03,   5.1827771E-03,   5.3311414E-03
     +,   5.4792669E-03,   5.6266221E-03,   5.7729566E-03
     +,   5.9183287E-03,   6.0629938E-03,   6.2072831E-03
     +,   6.3514160E-03,   6.4954096E-03,   6.6391849E-03
     +,   6.7829513E-03,   6.9278334E-03,   7.0768576E-03
     +,   7.2360327E-03,   7.4153314E-03,   7.6292362E-03
     +,   7.8966366E-03,   8.2399361E-03,   8.6832410E-03
     +,   9.2498381E-03,   9.9591333E-03,   1.0822982E-02
     +,   1.1841557E-02,   1.2999107E-02,   1.4262040E-02
     +,   1.5582453E-02,   1.6912201E-02,   1.8230556E-02
     +,   1.9580154E-02,   2.1094317E-02,   2.2991901E-02
     +,   2.5524739E-02,   2.8894391E-02,   3.3183124E-02
     +,   3.8337979E-02,   4.4198357E-02,   5.0514676E-02
     +,   5.6920197E-02,   6.2897876E-02,   6.7851305E-02
     +,   7.1325265E-02,   7.3256470E-02,   7.4004710E-02
     +,   7.4060865E-02,   7.3642604E-02,   7.2517529E-02
     +,   7.0184663E-02,   6.6237643E-02,   6.0628172E-02
     +,   5.3712834E-02,   4.6137348E-02,   3.8647257E-02
     +,   3.1869628E-02,   2.6143568E-02,   2.1479877E-02
     +,   1.7675217E-02,   1.4482002E-02,   1.1728616E-02
     +,   9.3413861E-03,   7.3065148E-03,   5.6219646E-03
     +,   4.2712535E-03,   3.2191463E-03,   2.4183493E-03
     +,   1.8187118E-03,   1.3736476E-03,   1.0438816E-03
     +,   7.9842692E-04,   6.1417435E-04,   4.7448583E-04
     +,   3.6767268E-04,   2.8551329E-04,   2.2214947E-04
     +,   1.7326848E-04,   1.3560841E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_hatt102 = Yx/0.44058
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_hatt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.8475314E-05,   8.1325990E-05
     +,   8.4261374E-05,   8.7281900E-05,   9.0387832E-05
     +,   9.3579190E-05,   9.6855903E-05,   1.0021772E-04
     +,   1.0366410E-04,   1.0719460E-04,   1.1080838E-04
     +,   1.1450459E-04,   1.1828214E-04,   1.2213987E-04
     +,   1.2607657E-04,   1.3009080E-04,   1.3418116E-04
     +,   1.3834603E-04,   1.4258396E-04,   1.4689328E-04
     +,   1.5127241E-04,   1.5571981E-04,   1.6023382E-04
     +,   1.6481319E-04,   1.6945635E-04,   1.7416207E-04
     +,   1.7892921E-04,   1.8375681E-04,   1.8864388E-04
     +,   1.9358985E-04,   1.9859413E-04,   2.0365654E-04
     +,   2.0877694E-04,   2.1395550E-04,   2.1919246E-04
     +,   2.2448844E-04,   2.2984414E-04,   2.3526060E-04
     +,   2.4073895E-04,   2.4628031E-04,   2.5188643E-04
     +,   2.5755871E-04,   2.6329892E-04,   2.6910895E-04
     +,   2.7499054E-04,   2.8094577E-04,   2.8697660E-04
     +,   2.9308480E-04,   2.9927253E-04,   3.0554156E-04
     +,   3.1189376E-04,   3.1833121E-04,   3.2485512E-04
     +,   3.3146777E-04,   3.3817024E-04,   3.4496465E-04
     +,   3.5185198E-04,   3.5883422E-04,   3.6591265E-04
     +,   3.7308893E-04,   3.8036495E-04,   3.8774248E-04
     +,   3.9522318E-04,   4.0280962E-04,   4.1050455E-04
     +,   4.1831052E-04,   4.2623130E-04,   4.3426963E-04
     +,   4.4243078E-04,   4.5071857E-04,   4.5913868E-04
     +,   4.6769605E-04,   4.7639705E-04,   4.8524822E-04
     +,   4.9425574E-04,   5.0342781E-04,   5.1277096E-04
     +,   5.2229187E-04,   5.3199881E-04,   5.4189854E-04
     +,   5.5199733E-04,   5.6230155E-04,   5.7281548E-04
     +,   5.8354443E-04,   5.9449120E-04,   6.0565746E-04
     +,   6.1704358E-04,   6.2864920E-04,   6.4047065E-04
     +,   6.5250485E-04,   6.6474569E-04,   6.7718624E-04
     +,   6.8981759E-04,   7.0263166E-04,   7.1561831E-04
     +,   7.2876608E-04,   7.4206694E-04,   7.5550936E-04
     +,   7.6908577E-04,   7.8278867E-04,   7.9661357E-04
     +,   8.1055710E-04,   8.2462013E-04,   8.3880452E-04
     +,   8.5311674E-04,   8.6756714E-04,   8.8216667E-04
     +,   8.9693029E-04,   9.1187429E-04,   9.2701748E-04
     +,   9.4237644E-04,   9.5796929E-04,   9.7380893E-04
     +,   9.8990730E-04,   1.0062677E-03,   1.0228896E-03
     +,   1.0397593E-03,   1.0568560E-03,   1.0741445E-03
     +,   1.0915778E-03,   1.1090941E-03,   1.1266143E-03
     +,   1.1440472E-03,   1.1612829E-03,   1.1782006E-03
     +,   1.1946610E-03,   1.2105184E-03,   1.2256126E-03
     +,   1.2397780E-03,   1.2528453E-03,   1.2646419E-03
     +,   1.2749982E-03,   1.2837518E-03,   1.2907487E-03
     +,   1.2958486E-03,   1.2989274E-03,   1.2998799E-03
     +,   1.2986258E-03,   1.2951088E-03,   1.2892976E-03
     +,   1.2811919E-03,   1.2708185E-03,   1.2582330E-03
     +,   1.2435181E-03,   1.2267862E-03,   1.2081712E-03
     +,   1.1878338E-03,   1.1659518E-03,   1.1427237E-03
     +,   1.1183596E-03,   1.0930810E-03,   1.0671195E-03
     +,   1.0407079E-03,   1.0140828E-03,   9.8747539E-04
     +,   9.6111646E-04,   9.3522656E-04,   9.1001636E-04
     +,   8.8568445E-04,   8.6241972E-04,   8.4039394E-04
     +,   8.1976189E-04,   8.0066605E-04,   7.8323111E-04
     +,   7.6756492E-04,   7.5375906E-04,   7.4189127E-04
     +,   7.3202432E-04,   7.2420581E-04,   7.1847223E-04
     +,   7.1484869E-04,   7.1335078E-04,   7.1398681E-04
     +,   7.1675848E-04,   7.2166469E-04,   7.2870404E-04
     +,   7.3787622E-04,   7.4918458E-04,   7.6264114E-04
     +,   7.7826728E-04,   7.9609983E-04,   8.1618945E-04
     +,   8.3860895E-04,   8.6345209E-04,   8.9083833E-04
     +,   9.2091667E-04,   9.5385942E-04,   9.8987145E-04
     +,   1.0291910E-03,   1.0720752E-03,   1.1188125E-03
     +,   1.1697144E-03,   1.2251035E-03,   1.2853097E-03
     +,   1.3506658E-03,   1.4214920E-03,   1.4980738E-03
     +,   1.5806576E-03,   1.6694306E-03,   1.7645031E-03
     +,   1.8658793E-03,   1.9734481E-03,   2.0869700E-03
     +,   2.2060678E-03,   2.3302017E-03,   2.4587039E-03
     +,   2.5907815E-03,   2.7255455E-03,   2.8620465E-03
     +,   2.9993553E-03,   3.1366074E-03,   3.2730696E-03
     +,   3.4082148E-03,   3.5417769E-03,   3.6737844E-03
     +,   3.8045472E-03,   3.9346381E-03,   4.0648323E-03
     +,   4.1959970E-03,   4.3289787E-03,   4.4644633E-03
     +,   4.6028825E-03,   4.7443318E-03,   4.8885471E-03
     +,   5.0349534E-03,   5.1827771E-03,   5.3311414E-03
     +,   5.4792669E-03,   5.6266221E-03,   5.7729566E-03
     +,   5.9183287E-03,   6.0629938E-03,   6.2072831E-03
     +,   6.3514160E-03,   6.4954096E-03,   6.6391849E-03
     +,   6.7829513E-03,   6.9278334E-03,   7.0768576E-03
     +,   7.2360327E-03,   7.4153314E-03,   7.6292362E-03
     +,   7.8966366E-03,   8.2399361E-03,   8.6832410E-03
     +,   9.2498381E-03,   9.9591333E-03,   1.0822982E-02
     +,   1.1841557E-02,   1.2999107E-02,   1.4262040E-02
     +,   1.5582453E-02,   1.6912201E-02,   1.8230556E-02
     +,   1.9580154E-02,   2.1094317E-02,   2.2991901E-02
     +,   2.5524739E-02,   2.8894391E-02,   3.3183124E-02
     +,   3.8337979E-02,   4.4198357E-02,   5.0514676E-02
     +,   5.6920197E-02,   6.2897876E-02,   6.7851305E-02
     +,   7.1325265E-02,   7.3256470E-02,   7.4004710E-02
     +,   7.4060865E-02,   7.3642604E-02,   7.2517529E-02
     +,   7.0184663E-02,   6.6237643E-02,   6.0628172E-02
     +,   5.3712834E-02,   4.6137348E-02,   3.8647257E-02
     +,   3.1869628E-02,   2.6143568E-02,   2.1479877E-02
     +,   1.7675217E-02,   1.4482002E-02,   1.1728616E-02
     +,   9.3413861E-03,   7.3065148E-03,   5.6219646E-03
     +,   4.2712535E-03,   3.2191463E-03,   2.4183493E-03
     +,   1.8187118E-03,   1.3736476E-03,   1.0438816E-03
     +,   7.9842692E-04,   6.1417435E-04,   4.7448583E-04
     +,   3.6767268E-04,   2.8551329E-04,   2.2214947E-04
     +,   1.7326848E-04,   1.3560841E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_hatt104 = Yx/0.44058
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8720411E-04,   3.0597314E-04
     +,   3.2548327E-04,   3.4572254E-04,   3.6668233E-04
     +,   3.8835951E-04,   4.1076055E-04,   4.3390470E-04
     +,   4.5782820E-04,   4.8259005E-04,   5.0827512E-04
     +,   5.3499907E-04,   5.6291377E-04,   5.9221091E-04
     +,   6.2312547E-04,   6.5593736E-04,   6.9097418E-04
     +,   7.2860887E-04,   7.6925877E-04,   8.1338076E-04
     +,   8.6146547E-04,   9.1402733E-04,   9.7159151E-04
     +,   1.0346884E-03,   1.1038242E-03,   1.1794802E-03
     +,   1.2620834E-03,   1.3519956E-03,   1.4494968E-03
     +,   1.5547726E-03,   1.6679139E-03,   1.7889102E-03
     +,   1.9176609E-03,   2.0539921E-03,   2.1976845E-03
     +,   2.3484931E-03,   2.5062005E-03,   2.6706380E-03
     +,   2.8417341E-03,   3.0195178E-03,   3.2041632E-03
     +,   3.3959616E-03,   3.5953149E-03,   3.8027077E-03
     +,   4.0186616E-03,   4.2436728E-03,   4.4781757E-03
     +,   4.7224606E-03,   4.9765985E-03,   5.2403831E-03
     +,   5.5132732E-03,   5.7943938E-03,   6.0826461E-03
     +,   6.3770353E-03,   6.6770967E-03,   6.9836685E-03
     +,   7.2996714E-03,   7.6310132E-03,   7.9871295E-03
     +,   8.3810557E-03,   8.8285329E-03,   9.3461918E-03
     +,   9.9486839E-03,   1.0646027E-02,   1.1441734E-02
     +,   1.2333200E-02,   1.3314432E-02,   1.4378892E-02
     +,   1.5520604E-02,   1.6730145E-02,   1.7987594E-02
     +,   1.9255534E-02,   2.0480212E-02,   2.1605903E-02
     +,   2.2603948E-02,   2.3506433E-02,   2.4425337E-02
     +,   2.5535282E-02,   2.7010437E-02,   2.8937271E-02
     +,   3.1256989E-02,   3.3788517E-02,   3.6329728E-02
     +,   3.8763806E-02,   4.1080233E-02,   4.3297190E-02
     +,   4.5362622E-02,   4.7134738E-02,   4.8468176E-02
     +,   4.9336165E-02,   4.9877413E-02,   5.0290726E-02
     +,   5.0643098E-02,   5.0792255E-02,   5.0537109E-02
     +,   4.9826622E-02,   4.8755329E-02,   4.7363702E-02
     +,   4.5540620E-02,   4.3177076E-02,   4.0358189E-02
     +,   3.7342537E-02,   3.4371678E-02,   3.1537328E-02
     +,   2.8811073E-02,   2.6150212E-02,   2.3562500E-02
     +,   2.1099806E-02,   1.8820571E-02,   1.6763460E-02
     +,   1.4942129E-02,   1.3351127E-02,   1.1973383E-02
     +,   1.0784310E-02,   9.7548235E-03,   8.8539459E-03
     +,   8.0525009E-03,   7.3265494E-03,   6.6599860E-03
     +,   6.0449201E-03,   5.4800157E-03,   4.9676457E-03
     +,   4.5108055E-03,   4.1108397E-03,   3.7663952E-03
     +,   3.4734251E-03,   3.2257722E-03,   3.0162025E-03
     +,   2.8372479E-03,   2.6819785E-03,   2.5444094E-03
     +,   2.4197535E-03,   2.3044175E-03,   2.1959529E-03
     +,   2.0928620E-03,   1.9944152E-03,   1.9004535E-03
     +,   1.8111841E-03,   1.7269948E-03,   1.6483320E-03
     +,   1.5755913E-03,   1.5090408E-03,   1.4487864E-03
     +,   1.3947624E-03,   1.3467439E-03,   1.3043677E-03
     +,   1.2671592E-03,   1.2345727E-03,   1.2060171E-03
     +,   1.1808889E-03,   1.1585909E-03,   1.1385588E-03
     +,   1.1202703E-03,   1.1032555E-03,   1.0871029E-03
     +,   1.0714652E-03,   1.0560567E-03,   1.0406526E-03
     +,   1.0250857E-03,   1.0092452E-03,   9.9306880E-04
     +,   9.7653852E-04,   9.5967861E-04,   9.4254728E-04
     +,   9.2523149E-04,   9.0784190E-04,   8.9050992E-04
     +,   8.7338203E-04,   8.5661217E-04,   8.4036245E-04
     +,   8.2479528E-04,   8.1007276E-04,   7.9635059E-04
     +,   7.8377652E-04,   7.7248859E-04,   7.6261145E-04
     +,   7.5425365E-04,   7.4750878E-04,   7.4245129E-04
     +,   7.3913526E-04,   7.3759467E-04,   7.3784258E-04
     +,   7.3986879E-04,   7.4364123E-04,   7.4910483E-04
     +,   7.5618213E-04,   7.6477195E-04,   7.7475404E-04
     +,   7.8598683E-04,   7.9830829E-04,   8.1154075E-04
     +,   8.2549010E-04,   8.3995145E-04,   8.5470703E-04
     +,   8.6953526E-04,   8.8421052E-04,   8.9850632E-04
     +,   9.1220177E-04,   9.2508324E-04,   9.3694986E-04
     +,   9.4761397E-04,   9.5690659E-04,   9.6468203E-04
     +,   9.7081694E-04,   9.7521418E-04,   9.7780337E-04
     +,   9.7854482E-04,   9.7742258E-04,   9.7445259E-04
     +,   9.6967549E-04,   9.6315832E-04,   9.5498795E-04
     +,   9.4527577E-04,   9.3414634E-04,   9.2173973E-04
     +,   9.0820587E-04,   8.9370285E-04,   8.7838975E-04
     +,   8.6242682E-04,   8.4597181E-04,   8.2917511E-04
     +,   8.1217830E-04,   7.9511415E-04,   7.7810296E-04
     +,   7.6125003E-04,   7.4464665E-04,   7.2837109E-04
     +,   7.1248721E-04,   6.9704314E-04,   6.8207324E-04
     +,   6.6760118E-04,   6.5363920E-04,   6.4018805E-04
     +,   6.2724022E-04,   6.1478151E-04,   6.0279114E-04
     +,   5.9124309E-04,   5.8010913E-04,   5.6935818E-04
     +,   5.5895769E-04,   5.4887409E-04,   5.3907512E-04
     +,   5.2952935E-04,   5.2020600E-04,   5.1107560E-04
     +,   5.0211180E-04,   4.9328950E-04,   4.8458562E-04
     +,   4.7597889E-04,   4.6745088E-04,   4.5898405E-04
     +,   4.5056286E-04,   4.4217380E-04,   4.3380479E-04
     +,   4.2544474E-04,   4.1708362E-04,   4.0871333E-04
     +,   4.0032700E-04,   3.9191809E-04,   3.8348083E-04
     +,   3.7501156E-04,   3.6650753E-04,   3.5796608E-04
     +,   3.4938625E-04,   3.4076846E-04,   3.3211370E-04
     +,   3.2342406E-04,   3.1470330E-04,   3.0595608E-04
     +,   2.9718791E-04,   2.8840528E-04,   2.7961636E-04
     +,   2.7083023E-04,   2.6205636E-04,   2.5330504E-04
     +,   2.4458804E-04,   2.3591692E-04,   2.2730452E-04
     +,   2.1876306E-04,   2.1030635E-04,   2.0194692E-04
     +,   1.9369852E-04,   1.8557356E-04,   1.7758532E-04
     +,   1.6974554E-04,   1.6206650E-04,   1.5455911E-04
     +,   1.4723346E-04,   1.4009967E-04,   1.3316583E-04
     +,   1.2644019E-04,   1.1992899E-04,   1.1363827E-04
     +,   1.0757222E-04,   1.0173478E-04,   9.6128017E-05
     +,   9.0753645E-05,   8.5611733E-05,   8.0701939E-05
     +,   7.6022407E-05,   7.1571012E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_hatt75 = Yx/0.4571
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0992165E-04,   2.2130202E-04
     +,   2.3301999E-04,   2.4505786E-04,   2.5739596E-04
     +,   2.7001352E-04,   2.8288856E-04,   2.9599888E-04
     +,   3.0932244E-04,   3.2283948E-04,   3.3653152E-04
     +,   3.5038410E-04,   3.6438764E-04,   3.7853865E-04
     +,   3.9284100E-04,   4.0730869E-04,   4.2196576E-04
     +,   4.3685012E-04,   4.5201284E-04,   4.6752175E-04
     +,   4.8346087E-04,   4.9993355E-04,   5.1706017E-04
     +,   5.3498283E-04,   5.5385905E-04,   5.7386555E-04
     +,   5.9519260E-04,   6.1804289E-04,   6.4262724E-04
     +,   6.6915737E-04,   6.9784385E-04,   7.2888500E-04
     +,   7.6246232E-04,   7.9873175E-04,   8.3781639E-04
     +,   8.7979878E-04,   9.2471484E-04,   9.7254873E-04
     +,   1.0232345E-03,   1.0766472E-03,   1.1326178E-03
     +,   1.1909337E-03,   1.2513493E-03,   1.3136042E-03
     +,   1.3774451E-03,   1.4426468E-03,   1.5090399E-03
     +,   1.5765467E-03,   1.6452130E-03,   1.7152469E-03
     +,   1.7870539E-03,   1.8612754E-03,   1.9388167E-03
     +,   2.0208783E-03,   2.1089537E-03,   2.2048419E-03
     +,   2.3105990E-03,   2.4284904E-03,   2.5609063E-03
     +,   2.7102379E-03,   2.8787486E-03,   3.0684264E-03
     +,   3.2808029E-03,   3.5168712E-03,   3.7769398E-03
     +,   4.0605646E-03,   4.3666111E-03,   4.6932600E-03
     +,   5.0383266E-03,   5.3994390E-03,   5.7745636E-03
     +,   6.1622579E-03,   6.5620071E-03,   6.9741495E-03
     +,   7.3995749E-03,   7.8392159E-03,   8.2934862E-03
     +,   8.7623214E-03,   9.2457449E-03,   9.7450381E-03
     +,   1.0263967E-02,   1.0809794E-02,   1.1392888E-02
     +,   1.2025465E-02,   1.2718472E-02,   1.3477787E-02
     +,   1.4299214E-02,   1.5165546E-02,   1.6048694E-02
     +,   1.6922019E-02,   1.7782209E-02,   1.8672086E-02
     +,   1.9686602E-02,   2.0946382E-02,   2.2540446E-02
     +,   2.4472388E-02,   2.6660031E-02,   2.9009854E-02
     +,   3.1519402E-02,   3.4303918E-02,   3.7496358E-02
     +,   4.1091952E-02,   4.4880547E-02,   4.8517913E-02
     +,   5.1681265E-02,   5.4233842E-02,   5.6275588E-02
     +,   5.7993218E-02,   5.9481677E-02,   6.0784094E-02
     +,   6.1991885E-02,   6.3125037E-02,   6.3999891E-02
     +,   6.4418696E-02,   6.4377643E-02,   6.3824594E-02
     +,   6.2357754E-02,   5.9529211E-02,   5.5431195E-02
     +,   5.0773874E-02,   4.6366878E-02,   4.2546436E-02
     +,   3.9080348E-02,   3.5570625E-02,   3.1864777E-02
     +,   2.8102590E-02,   2.4515741E-02,   2.1271950E-02
     +,   1.8448165E-02,   1.6062751E-02,   1.4096613E-02
     +,   1.2502484E-02,   1.1215320E-02,   1.0168375E-02
     +,   9.3052965E-03,   8.5841743E-03,   7.9748975E-03
     +,   7.4545341E-03,   7.0038992E-03,   6.6062626E-03
     +,   6.2473165E-03,   5.9156301E-03,   5.6028771E-03
     +,   5.3037512E-03,   5.0154412E-03,   4.7367588E-03
     +,   4.4673919E-03,   4.2072823E-03,   3.9562145E-03
     +,   3.7137293E-03,   3.4792074E-03,   3.2520802E-03
     +,   3.0319735E-03,   2.8188452E-03,   2.6130294E-03
     +,   2.4152221E-03,   2.2263620E-03,   2.0474999E-03
     +,   1.8796782E-03,   1.7238384E-03,   1.5806824E-03
     +,   1.4506433E-03,   1.3338603E-03,   1.2301820E-03
     +,   1.1391704E-03,   1.0601701E-03,   9.9235447E-04
     +,   9.3478349E-04,   8.8645093E-04,   8.4634247E-04
     +,   8.1347319E-04,   7.8691758E-04,   7.6582830E-04
     +,   7.4945064E-04,   7.3712651E-04,   7.2829251E-04
     +,   7.2247523E-04,   7.1928330E-04,   7.1839849E-04
     +,   7.1956619E-04,   7.2258385E-04,   7.2729553E-04
     +,   7.3357928E-04,   7.4134261E-04,   7.5051584E-04
     +,   7.6104206E-04,   7.7287521E-04,   7.8597374E-04
     +,   8.0029591E-04,   8.1579346E-04,   8.3241134E-04
     +,   8.5008185E-04,   8.6871948E-04,   8.8822196E-04
     +,   9.0846536E-04,   9.2930649E-04,   9.5057534E-04
     +,   9.7207940E-04,   9.9360687E-04,   1.0149243E-03
     +,   1.0357798E-03,   1.0559071E-03,   1.0750339E-03
     +,   1.0928824E-03,   1.1091743E-03,   1.1236423E-03
     +,   1.1360334E-03,   1.1461141E-03,   1.1536796E-03
     +,   1.1585570E-03,   1.1606133E-03,   1.1597559E-03
     +,   1.1559385E-03,   1.1491583E-03,   1.1394655E-03
     +,   1.1269499E-03,   1.1117506E-03,   1.0940429E-03
     +,   1.0740383E-03,   1.0519809E-03,   1.0281355E-03
     +,   1.0027840E-03,   9.7621942E-04,   9.4873854E-04
     +,   9.2063181E-04,   8.9217932E-04,   8.6364808E-04
     +,   8.3528436E-04,   8.0730801E-04,   7.7991182E-04
     +,   7.5326156E-04,   7.2749204E-04,   7.0270704E-04
     +,   6.7898032E-04,   6.5636093E-04,   6.3486875E-04
     +,   6.1450159E-04,   5.9523730E-04,   5.7703623E-04
     +,   5.5984425E-04,   5.4359523E-04,   5.2821677E-04
     +,   5.1363005E-04,   4.9975322E-04,   4.8650370E-04
     +,   4.7380122E-04,   4.6156862E-04,   4.4973198E-04
     +,   4.3822295E-04,   4.2698026E-04,   4.1594883E-04
     +,   4.0507983E-04,   3.9433231E-04,   3.8367268E-04
     +,   3.7307292E-04,   3.6251178E-04,   3.5197448E-04
     +,   3.4145216E-04,   3.3094009E-04,   3.2043864E-04
     +,   3.0995248E-04,   2.9948985E-04,   2.8906151E-04
     +,   2.7868059E-04,   2.6836325E-04,   2.5812618E-04
     +,   2.4798702E-04,   2.3796498E-04,   2.2807930E-04
     +,   2.1834871E-04,   2.0879127E-04,   1.9942534E-04
     +,   1.9026805E-04,   1.8133491E-04,   1.7264015E-04
     +,   1.6419750E-04,   1.5601779E-04,   1.4811134E-04
     +,   1.4048595E-04,   1.3314851E-04,   1.2610322E-04
     +,   1.1935370E-04,   1.1290085E-04,   1.0674492E-04
     +,   1.0088395E-04,   9.5315190E-05,   9.0034104E-05
     +,   8.5035070E-05,   8.0311765E-05,   7.5856420E-05
     +,   7.1660914E-05,   6.7715977E-05,   6.4012238E-05
     +,   6.0539427E-05,   5.7287332E-05,   5.4245102E-05
     +,   5.1402167E-05,   4.8747526E-05,   4.6270594E-05
     +,   4.3960539E-05,   4.1807059E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_hatt80 = Yx/0.522803921568627
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.9695135E-05,   1.0289523E-04
     +,   1.0615568E-04,   1.0947896E-04,   1.1286809E-04
     +,   1.1632656E-04,   1.1985840E-04,   1.2346817E-04
     +,   1.2716115E-04,   1.3094327E-04,   1.3482095E-04
     +,   1.3880138E-04,   1.4289244E-04,   1.4710256E-04
     +,   1.5144091E-04,   1.5591727E-04,   1.6054188E-04
     +,   1.6532550E-04,   1.7027937E-04,   1.7541499E-04
     +,   1.8074404E-04,   1.8627834E-04,   1.9202950E-04
     +,   1.9800931E-04,   2.0422842E-04,   2.1069770E-04
     +,   2.1742695E-04,   2.2442511E-04,   2.3170008E-04
     +,   2.3925854E-04,   2.4710596E-04,   2.5524668E-04
     +,   2.6368318E-04,   2.7241686E-04,   2.8144807E-04
     +,   2.9077570E-04,   3.0039778E-04,   3.1031162E-04
     +,   3.2051513E-04,   3.3100497E-04,   3.4177984E-04
     +,   3.5283907E-04,   3.6418380E-04,   3.7581805E-04
     +,   3.8774838E-04,   3.9998512E-04,   4.1254330E-04
     +,   4.2544142E-04,   4.3870360E-04,   4.5235804E-04
     +,   4.6643824E-04,   4.8098131E-04,   4.9602863E-04
     +,   5.1162508E-04,   5.2781601E-04,   5.4464937E-04
     +,   5.6217244E-04,   5.8043242E-04,   5.9947331E-04
     +,   6.1933853E-04,   6.4007111E-04,   6.6171197E-04
     +,   6.8430364E-04,   7.0789678E-04,   7.3255139E-04
     +,   7.5834268E-04,   7.8537379E-04,   8.1377884E-04
     +,   8.4374170E-04,   8.7549991E-04,   9.0936618E-04
     +,   9.4573147E-04,   9.8508678E-04,   1.0280209E-03
     +,   1.0752324E-03,   1.1275250E-03,   1.1857905E-03
     +,   1.2509887E-03,   1.3241161E-03,   1.4061544E-03
     +,   1.4980036E-03,   1.6004338E-03,   1.7139991E-03
     +,   1.8390100E-03,   1.9754823E-03,   2.1231680E-03
     +,   2.2815890E-03,   2.4501826E-03,   2.6284242E-03
     +,   2.8160803E-03,   3.0134192E-03,   3.2214590E-03
     +,   3.4422320E-03,   3.6790741E-03,   3.9369087E-03
     +,   4.2224578E-03,   4.5444416E-03,   4.9133128E-03
     +,   5.3405524E-03,   5.8370982E-03,   6.4114165E-03
     +,   7.0672827E-03,   7.8026224E-03,   8.6094877E-03
     +,   9.4759846E-03,   1.0389336E-02,   1.1339976E-02
     +,   1.2326336E-02,   1.3359022E-02,   1.4461681E-02
     +,   1.5665466E-02,   1.6996171E-02,   1.8456610E-02
     +,   2.0013316E-02,   2.1600293E-02,   2.3156310E-02
     +,   2.4689257E-02,   2.6322547E-02,   2.8256550E-02
     +,   3.0650308E-02,   3.3531588E-02,   3.6829080E-02
     +,   4.0457193E-02,   4.4326883E-02,   4.8295420E-02
     +,   5.2156862E-02,   5.5751637E-02,   5.9213661E-02
     +,   6.3119389E-02,   6.8100698E-02,   7.3940784E-02
     +,   7.9091236E-02,   8.1864499E-02,   8.2418524E-02
     +,   8.2477145E-02,   8.2872577E-02,   8.2765304E-02
     +,   8.1218176E-02,   7.8064591E-02,   7.3385142E-02
     +,   6.7320921E-02,   6.0361110E-02,   5.3252794E-02
     +,   4.6689741E-02,   4.1081704E-02,   3.6414266E-02
     +,   3.2392044E-02,   2.8746419E-02,   2.5367465E-02
     +,   2.2247853E-02,   1.9406306E-02,   1.6853057E-02
     +,   1.4580240E-02,   1.2567320E-02,   1.0795145E-02
     +,   9.2545403E-03,   7.9422528E-03,   6.8503856E-03
     +,   5.9594195E-03,   5.2389312E-03,   4.6535828E-03
     +,   4.1700760E-03,   3.7614729E-03,   3.4082474E-03
     +,   3.0973481E-03,   2.8205232E-03,   2.5727341E-03
     +,   2.3509189E-03,   2.1531596E-03,   1.9781708E-03
     +,   1.8249806E-03,   1.6927074E-03,   1.5804396E-03
     +,   1.4871921E-03,   1.4118827E-03,   1.3533152E-03
     +,   1.3102035E-03,   1.2811825E-03,   1.2648283E-03
     +,   1.2596803E-03,   1.2642575E-03,   1.2770798E-03
     +,   1.2966801E-03,   1.3216214E-03,   1.3505088E-03
     +,   1.3820058E-03,   1.4148449E-03,   1.4478483E-03
     +,   1.4799404E-03,   1.5101589E-03,   1.5376729E-03
     +,   1.5617862E-03,   1.5819442E-03,   1.5977408E-03
     +,   1.6089191E-03,   1.6153633E-03,   1.6170975E-03
     +,   1.6142695E-03,   1.6071500E-03,   1.5961045E-03
     +,   1.5815885E-03,   1.5641244E-03,   1.5442802E-03
     +,   1.5226536E-03,   1.4998503E-03,   1.4764555E-03
     +,   1.4530247E-03,   1.4300592E-03,   1.4079891E-03
     +,   1.3871582E-03,   1.3678157E-03,   1.3501077E-03
     +,   1.3340749E-03,   1.3196543E-03,   1.3066817E-03
     +,   1.2949110E-03,   1.2840192E-03,   1.2736274E-03
     +,   1.2633222E-03,   1.2526710E-03,   1.2412476E-03
     +,   1.2286475E-03,   1.2145104E-03,   1.1985318E-03
     +,   1.1804736E-03,   1.1601745E-03,   1.1375528E-03
     +,   1.1126080E-03,   1.0854136E-03,   1.0561106E-03
     +,   1.0249040E-03,   9.9204644E-04,   9.5782510E-04
     +,   9.2255144E-04,   8.8655093E-04,   8.5014635E-04
     +,   8.1364962E-04,   7.7735557E-04,   7.4153394E-04
     +,   7.0642121E-04,   6.7221985E-04,   6.3909852E-04
     +,   6.0719252E-04,   5.7659892E-04,   5.4738432E-04
     +,   5.1958830E-04,   4.9322587E-04,   4.6828753E-04
     +,   4.4474736E-04,   4.2256704E-04,   4.0169447E-04
     +,   3.8207046E-04,   3.6363114E-04,   3.4630997E-04
     +,   3.3003712E-04,   3.1474343E-04,   3.0036218E-04
     +,   2.8682829E-04,   2.7407895E-04,   2.6205456E-04
     +,   2.5069984E-04,   2.3996309E-04,   2.2979596E-04
     +,   2.2015348E-04,   2.1099564E-04,   2.0228479E-04
     +,   1.9398687E-04,   1.8607135E-04,   1.7851091E-04
     +,   1.7128015E-04,   1.6435646E-04,   1.5771991E-04
     +,   1.5135258E-04,   1.4523798E-04,   1.3936126E-04
     +,   1.3370966E-04,   1.2827088E-04,   1.2303442E-04
     +,   1.1799008E-04,   1.1312901E-04,   1.0844258E-04
     +,   1.0392345E-04,   9.9563978E-05,   9.5357776E-05
     +,   9.1298207E-05,   8.7379689E-05,   8.3596453E-05
     +,   7.9943173E-05,   7.6415199E-05,   7.3007657E-05
     +,   6.9716465E-05,   6.6537359E-05,   6.3466810E-05
     +,   6.0501108E-05,   5.7637204E-05,   5.4871925E-05
     +,   5.2202649E-05,   4.9626640E-05,   4.7141704E-05
     +,   4.4745459E-05,   4.2436041E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_hatt85 = Yx/0.557392156862745
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0123915E-04,   1.0457498E-04
     +,   1.0793005E-04,   1.1129956E-04,   1.1467848E-04
     +,   1.1806183E-04,   1.2144452E-04,   1.2482137E-04
     +,   1.2818724E-04,   1.3153709E-04,   1.3486593E-04
     +,   1.3816881E-04,   1.4144107E-04,   1.4467820E-04
     +,   1.4787595E-04,   1.5103052E-04,   1.5413828E-04
     +,   1.5719638E-04,   1.6020219E-04,   1.6315370E-04
     +,   1.6604972E-04,   1.6888960E-04,   1.7167351E-04
     +,   1.7440255E-04,   1.7707855E-04,   1.7970434E-04
     +,   1.8228379E-04,   1.8482174E-04,   1.8732400E-04
     +,   1.8979755E-04,   1.9225026E-04,   1.9469121E-04
     +,   1.9713023E-04,   1.9957824E-04,   2.0204687E-04
     +,   2.0454852E-04,   2.0709611E-04,   2.0970304E-04
     +,   2.1238318E-04,   2.1514996E-04,   2.1801716E-04
     +,   2.2099799E-04,   2.2410500E-04,   2.2735000E-04
     +,   2.3074355E-04,   2.3429502E-04,   2.3801201E-04
     +,   2.4190050E-04,   2.4596439E-04,   2.5020560E-04
     +,   2.5462348E-04,   2.5921545E-04,   2.6397649E-04
     +,   2.6889949E-04,   2.7397470E-04,   2.7919118E-04
     +,   2.8453572E-04,   2.8999441E-04,   2.9555190E-04
     +,   3.0119275E-04,   3.0690158E-04,   3.1266367E-04
     +,   3.1846526E-04,   3.2429537E-04,   3.3014506E-04
     +,   3.3600847E-04,   3.4188409E-04,   3.4777424E-04
     +,   3.5368657E-04,   3.5963376E-04,   3.6563404E-04
     +,   3.7171185E-04,   3.7789706E-04,   3.8422560E-04
     +,   3.9073930E-04,   3.9748583E-04,   4.0451752E-04
     +,   4.1189254E-04,   4.1967357E-04,   4.2792855E-04
     +,   4.3672961E-04,   4.4615503E-04,   4.5628852E-04
     +,   4.6722163E-04,   4.7905356E-04,   4.9189647E-04
     +,   5.0587411E-04,   5.2112946E-04,   5.3782470E-04
     +,   5.5614690E-04,   5.7631196E-04,   5.9856538E-04
     +,   6.2318466E-04,   6.5048080E-04,   6.8079511E-04
     +,   7.1448996E-04,   7.5194391E-04,   7.9353078E-04
     +,   8.3961000E-04,   8.9048914E-04,   9.4641012E-04
     +,   1.0075056E-03,   1.0737790E-03,   1.1450592E-03
     +,   1.2209952E-03,   1.3010327E-03,   1.3844115E-03
     +,   1.4701954E-03,   1.5573248E-03,   1.6446863E-03
     +,   1.7312146E-03,   1.8160419E-03,   1.8986327E-03
     +,   1.9789694E-03,   2.0576930E-03,   2.1362507E-03
     +,   2.2169724E-03,   2.3031118E-03,   2.3987913E-03
     +,   2.5088866E-03,   2.6388448E-03,   2.7944611E-03
     +,   2.9816120E-03,   3.2060435E-03,   3.4731298E-03
     +,   3.7876302E-03,   4.1535576E-03,   4.5739645E-03
     +,   5.0510718E-03,   5.5863913E-03,   6.1815078E-03
     +,   6.8387622E-03,   7.5620194E-03,   8.3561894E-03
     +,   9.2263091E-03,   1.0177865E-02,   1.1223354E-02
     +,   1.2399126E-02,   1.3787315E-02,   1.5523577E-02
     +,   1.7764056E-02,   2.0605149E-02,   2.3996981E-02
     +,   2.7725697E-02,   3.1507399E-02,   3.5134356E-02
     +,   3.8549565E-02,   4.1820016E-02,   4.5118336E-02
     +,   4.8773024E-02,   5.3219400E-02,   5.8570664E-02
     +,   6.4227246E-02,   6.9773115E-02,   7.5970061E-02
     +,   8.2845859E-02,   8.8002726E-02,   8.9701720E-02
     +,   8.9455150E-02,   8.9144088E-02,   8.8281244E-02
     +,   8.5598134E-02,   8.0929264E-02,   7.4903123E-02
     +,   6.8288274E-02,   6.1599456E-02,   5.4758538E-02
     +,   4.7427252E-02,   3.9716315E-02,   3.2300178E-02
     +,   2.5906017E-02,   2.0857273E-02,   1.7053129E-02
     +,   1.4217140E-02,   1.2107139E-02,   1.0573182E-02
     +,   9.5253130E-03,   8.8892290E-03,   8.5849725E-03
     +,   8.5277762E-03,   8.6378213E-03,   8.8486057E-03
     +,   9.1105709E-03,   9.3902862E-03,   9.6665556E-03
     +,   9.9252230E-03,   1.0154217E-02,   1.0340089E-02
     +,   1.0466936E-02,   1.0517649E-02,   1.0476797E-02
     +,   1.0334009E-02,   1.0086841E-02,   9.7421417E-03
     +,   9.3155233E-03,   8.8293171E-03,   8.3092740E-03
     +,   7.7809980E-03,   7.2667105E-03,   6.7831604E-03
     +,   6.3408520E-03,   5.9443316E-03,   5.5934424E-03
     +,   5.2849022E-03,   5.0138608E-03,   4.7750012E-03
     +,   4.5632822E-03,   4.3742619E-03,   4.2041182E-03
     +,   4.0495368E-03,   3.9075990E-03,   3.7757033E-03
     +,   3.6515067E-03,   3.5329266E-03,   3.4181864E-03
     +,   3.3058417E-03,   3.1947982E-03,   3.0843022E-03
     +,   2.9739337E-03,   2.8635708E-03,   2.7533241E-03
     +,   2.6434835E-03,   2.5344791E-03,   2.4268138E-03
     +,   2.3210072E-03,   2.2175696E-03,   2.1169703E-03
     +,   2.0196077E-03,   1.9257895E-03,   1.8357293E-03
     +,   1.7495498E-03,   1.6672766E-03,   1.5888491E-03
     +,   1.5141271E-03,   1.4429222E-03,   1.3749952E-03
     +,   1.3100855E-03,   1.2479245E-03,   1.1882526E-03
     +,   1.1308250E-03,   1.0754251E-03,   1.0218759E-03
     +,   9.7003870E-04,   9.1980945E-04,   8.7112177E-04
     +,   8.2394428E-04,   7.7827304E-04,   7.3412264E-04
     +,   6.9152284E-04,   6.5051700E-04,   6.1114639E-04
     +,   5.7345303E-04,   5.3747400E-04,   5.0323899E-04
     +,   4.7076409E-04,   4.4005326E-04,   4.1110002E-04
     +,   3.8388479E-04,   3.5837403E-04,   3.3452309E-04
     +,   3.1227907E-04,   2.9158004E-04,   2.7235606E-04
     +,   2.5453165E-04,   2.3802942E-04,   2.2276766E-04
     +,   2.0866403E-04,   1.9563732E-04,   1.8360716E-04
     +,   1.7249494E-04,   1.6222488E-04,   1.5272541E-04
     +,   1.4392909E-04,   1.3577192E-04,   1.2819470E-04
     +,   1.2114346E-04,   1.1456791E-04,   1.0842318E-04
     +,   1.0266792E-04,   9.7265736E-05,   9.2183567E-05
     +,   8.7392618E-05,   8.2866864E-05,   7.8584024E-05
     +,   7.4524047E-05,   7.0669943E-05,   6.7006535E-05
     +,   6.3520631E-05,   6.0201080E-05,   5.7037749E-05
     +,   5.4022159E-05,   5.1146471E-05,   4.8404134E-05
     +,   4.5788896E-05,   4.3295466E-05,   4.0918691E-05
     +,   3.8654100E-05,   3.6497233E-05,   3.4444114E-05
     +,   3.2490727E-05,   3.0633419E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_hatt90 = Yx/0.558490196078431
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.9463382E-05,   6.0728624E-05
     +,   6.1984159E-05,   6.3228174E-05,   6.4458851E-05
     +,   6.5674314E-05,   6.6872635E-05,   6.8051915E-05
     +,   6.9210153E-05,   7.0345399E-05,   7.1455623E-05
     +,   7.2538802E-05,   7.3592979E-05,   7.4616146E-05
     +,   7.5606302E-05,   7.6561511E-05,   7.7479897E-05
     +,   7.8359619E-05,   7.9198900E-05,   7.9996040E-05
     +,   8.0749473E-05,   8.1457685E-05,   8.2119317E-05
     +,   8.2733168E-05,   8.3298139E-05,   8.3813335E-05
     +,   8.4278021E-05,   8.4691696E-05,   8.5053980E-05
     +,   8.5364794E-05,   8.5624262E-05,   8.5832740E-05
     +,   8.5990847E-05,   8.6099455E-05,   8.6159736E-05
     +,   8.6173059E-05,   8.6141175E-05,   8.6066066E-05
     +,   8.5949992E-05,   8.5795538E-05,   8.5605592E-05
     +,   8.5383261E-05,   8.5132007E-05,   8.4855557E-05
     +,   8.4557927E-05,   8.4243373E-05,   8.3916471E-05
     +,   8.3582017E-05,   8.3245046E-05,   8.2910869E-05
     +,   8.2585015E-05,   8.2273196E-05,   8.1981321E-05
     +,   8.1715531E-05,   8.1482111E-05,   8.1287508E-05
     +,   8.1138263E-05,   8.1041071E-05,   8.1002727E-05
     +,   8.1030121E-05,   8.1130158E-05,   8.1309823E-05
     +,   8.1576080E-05,   8.1935941E-05,   8.2396349E-05
     +,   8.2964194E-05,   8.3646337E-05,   8.4449493E-05
     +,   8.5380307E-05,   8.6445165E-05,   8.7650515E-05
     +,   8.9002278E-05,   9.0506503E-05,   9.2168731E-05
     +,   9.3994429E-05,   9.5988784E-05,   9.8156554E-05
     +,   1.0050224E-04,   1.0303011E-04,   1.0574420E-04
     +,   1.0864792E-04,   1.1174475E-04,   1.1503748E-04
     +,   1.1852904E-04,   1.2222168E-04,   1.2611777E-04
     +,   1.3021912E-04,   1.3452792E-04,   1.3904562E-04
     +,   1.4377413E-04,   1.4871542E-04,   1.5387133E-04
     +,   1.5924389E-04,   1.6483574E-04,   1.7065024E-04
     +,   1.7669058E-04,   1.8296175E-04,   1.8946876E-04
     +,   1.9621851E-04,   2.0321870E-04,   2.1047922E-04
     +,   2.1801102E-04,   2.2582784E-04,   2.3394474E-04
     +,   2.4238003E-04,   2.5115436E-04,   2.6029098E-04
     +,   2.6981541E-04,   2.7975725E-04,   2.9014776E-04
     +,   3.0102121E-04,   3.1241466E-04,   3.2436592E-04
     +,   3.3691636E-04,   3.5010593E-04,   3.6397777E-04
     +,   3.7857189E-04,   3.9392992E-04,   4.1008997E-04
     +,   4.2708885E-04,   4.4496063E-04,   4.6373578E-04
     +,   4.8343957E-04,   5.0409621E-04,   5.2572542E-04
     +,   5.4834178E-04,   5.7196029E-04,   5.9658958E-04
     +,   6.2224135E-04,   6.4892211E-04,   6.7664287E-04
     +,   7.0541253E-04,   7.3524483E-04,   7.6615234E-04
     +,   7.9815555E-04,   8.3127897E-04,   8.6555071E-04
     +,   9.0100820E-04,   9.3770289E-04,   9.7570405E-04
     +,   1.0151017E-03,   1.0560208E-03,   1.0986368E-03
     +,   1.1431844E-03,   1.1899770E-03,   1.2394277E-03
     +,   1.2920628E-03,   1.3485284E-03,   1.4095979E-03
     +,   1.4761619E-03,   1.5491985E-03,   1.6297229E-03
     +,   1.7187208E-03,   1.8170670E-03,   1.9254200E-03
     +,   2.0441029E-03,   2.1730047E-03,   2.3114989E-03
     +,   2.4583894E-03,   2.6118769E-03,   2.7696523E-03
     +,   2.9290000E-03,   3.0869914E-03,   3.2407544E-03
     +,   3.3878039E-03,   3.5263859E-03,   3.6558125E-03
     +,   3.7767957E-03,   3.8917442E-03,   4.0049315E-03
     +,   4.1226535E-03,   4.2532408E-03,   4.4069267E-03
     +,   4.5954417E-03,   4.8311208E-03,   5.1256088E-03
     +,   5.4883342E-03,   5.9257858E-03,   6.4431429E-03
     +,   7.0493487E-03,   7.7644642E-03,   8.6242585E-03
     +,   9.6764592E-03,   1.0969884E-02,   1.2554541E-02
     +,   1.4520704E-02,   1.7064791E-02,   2.0476719E-02
     +,   2.4941659E-02,   3.0317137E-02,   3.6250576E-02
     +,   4.2564228E-02,   4.9306665E-02,   5.6375880E-02
     +,   6.3492186E-02,   7.0451260E-02,   7.6704308E-02
     +,   8.1848413E-02,   8.6862668E-02,   9.1629051E-02
     +,   9.3450181E-02,   9.1201946E-02,   8.6229242E-02
     +,   7.9694815E-02,   7.3343821E-02,   6.9294535E-02
     +,   6.6999048E-02,   6.3837044E-02,   5.8538258E-02
     +,   5.2422326E-02,   4.7531094E-02,   4.4218879E-02
     +,   4.1381449E-02,   3.8318109E-02,   3.5222635E-02
     +,   3.2399416E-02,   2.9819559E-02,   2.7287893E-02
     +,   2.4692744E-02,   2.2075130E-02,   1.9568330E-02
     +,   1.7317459E-02,   1.5422258E-02,   1.3904199E-02
     +,   1.2705130E-02,   1.1718624E-02,   1.0835867E-02
     +,   9.9815903E-03,   9.1271913E-03,   8.2831532E-03
     +,   7.4812463E-03,   6.7561790E-03,   6.1326521E-03
     +,   5.6193923E-03,   5.2091815E-03,   4.8827971E-03
     +,   4.6149832E-03,   4.3801917E-03,   4.1569211E-03
     +,   3.9301077E-03,   3.6917233E-03,   3.4399780E-03
     +,   3.1777564E-03,   2.9107702E-03,   2.6458837E-03
     +,   2.3898091E-03,   2.1481975E-03,   1.9251589E-03
     +,   1.7231765E-03,   1.5432545E-03,   1.3851566E-03
     +,   1.2477549E-03,   1.1293545E-03,   1.0279542E-03
     +,   9.4144815E-04,   8.6778251E-04,   8.0504845E-04
     +,   7.5152400E-04,   7.0568937E-04,   6.6622783E-04
     +,   6.3201372E-04,   6.0208858E-04,   5.7563768E-04
     +,   5.5197271E-04,   5.3051446E-04,   5.1077234E-04
     +,   4.9233413E-04,   4.7485615E-04,   4.5805366E-04
     +,   4.4169227E-04,   4.2558400E-04,   4.0958391E-04
     +,   3.9358423E-04,   3.7751073E-04,   3.6131934E-04
     +,   3.4499561E-04,   3.2854662E-04,   3.1200252E-04
     +,   2.9540856E-04,   2.7882546E-04,   2.6232234E-04
     +,   2.4597687E-04,   2.2986814E-04,   2.1407746E-04
     +,   1.9868188E-04,   1.8375604E-04,   1.6936607E-04
     +,   1.5557006E-04,   1.4241844E-04,   1.2994964E-04
     +,   1.1819383E-04,   1.0716922E-04,   9.6885844E-05
     +,   8.7342924E-05,   7.8532699E-05,   7.0438567E-05
     +,   6.3038606E-05,   5.6304398E-05,   5.0204118E-05
     +,   4.4701854E-05,   3.9760045E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_hatt95 = Yx/0.529529411764706
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4284752E-05,   1.4588004E-05
     +,   1.4892571E-05,   1.5198607E-05,   1.5506314E-05
     +,   1.5815942E-05,   1.6127808E-05,   1.6442269E-05
     +,   1.6759757E-05,   1.7080778E-05,   1.7405890E-05
     +,   1.7735740E-05,   1.8071039E-05,   1.8412582E-05
     +,   1.8761248E-05,   1.9117992E-05,   1.9483856E-05
     +,   1.9859972E-05,   2.0247549E-05,   2.0647884E-05
     +,   2.1062355E-05,   2.1492415E-05,   2.1939588E-05
     +,   2.2405502E-05,   2.2891791E-05,   2.3400204E-05
     +,   2.3932498E-05,   2.4490491E-05,   2.5076015E-05
     +,   2.5690921E-05,   2.6337062E-05,   2.7016265E-05
     +,   2.7730337E-05,   2.8481019E-05,   2.9269993E-05
     +,   3.0098839E-05,   3.0969029E-05,   3.1881864E-05
     +,   3.2838576E-05,   3.3840068E-05,   3.4887176E-05
     +,   3.5980403E-05,   3.7120040E-05,   3.8306072E-05
     +,   3.9538198E-05,   4.0815765E-05,   4.2137803E-05
     +,   4.3502951E-05,   4.4909484E-05,   4.6355264E-05
     +,   4.7837773E-05,   4.9354061E-05,   5.0900755E-05
     +,   5.2474163E-05,   5.4069998E-05,   5.5683773E-05
     +,   5.7310488E-05,   5.8944814E-05,   6.0581089E-05
     +,   6.2213301E-05,   6.3835185E-05,   6.5440247E-05
     +,   6.7021647E-05,   6.8572561E-05,   7.0085967E-05
     +,   7.1554714E-05,   7.2971772E-05,   7.4329982E-05
     +,   7.5622447E-05,   7.6842240E-05,   7.7982841E-05
     +,   7.9037811E-05,   8.0001169E-05,   8.0867183E-05
     +,   8.1630649E-05,   8.2286802E-05,   8.2831342E-05
     +,   8.3260558E-05,   8.3571336E-05,   8.3761151E-05
     +,   8.3828134E-05,   8.3771061E-05,   8.3589388E-05
     +,   8.3283230E-05,   8.2853374E-05,   8.2301274E-05
     +,   8.1629049E-05,   8.0839382E-05,   7.9935664E-05
     +,   7.8921803E-05,   7.7802149E-05,   7.6581709E-05
     +,   7.5265918E-05,   7.3860523E-05,   7.2371629E-05
     +,   7.0805785E-05,   6.9169611E-05,   6.7470100E-05
     +,   6.5714215E-05,   6.3909196E-05,   6.2062107E-05
     +,   6.0180239E-05,   5.8270583E-05,   5.6340283E-05
     +,   5.4396140E-05,   5.2444782E-05,   5.0492738E-05
     +,   4.8546306E-05,   4.6611371E-05,   4.4693541E-05
     +,   4.2798296E-05,   4.0930547E-05,   3.9095125E-05
     +,   3.7296271E-05,   3.5538153E-05,   3.3824352E-05
     +,   3.2158361E-05,   3.0543139E-05,   2.8981547E-05
     +,   2.7476004E-05,   2.6028656E-05,   2.4641497E-05
     +,   2.3316259E-05,   2.2054364E-05,   2.0857055E-05
     +,   1.9725483E-05,   1.8660479E-05,   1.7662864E-05
     +,   1.6733173E-05,   1.5871932E-05,   1.5079432E-05
     +,   1.4355942E-05,   1.3701519E-05,   1.3116201E-05
     +,   1.2599833E-05,   1.2152164E-05,   1.1772852E-05
     +,   1.1461422E-05,   1.1217263E-05,   1.1039648E-05
     +,   1.0927755E-05,   1.0880647E-05,   1.0897310E-05
     +,   1.0976689E-05,   1.1117711E-05,   1.1319363E-05
     +,   1.1580762E-05,   1.1901221E-05,   1.2280349E-05
     +,   1.2718213E-05,   1.3215422E-05,   1.3773241E-05
     +,   1.4393720E-05,   1.5079880E-05,   1.5835747E-05
     +,   1.6666436E-05,   1.7578177E-05,   1.8578447E-05
     +,   1.9675928E-05,   2.0880383E-05,   2.2202898E-05
     +,   2.3655874E-05,   2.5253161E-05,   2.7010496E-05
     +,   2.8946339E-05,   3.1082811E-05,   3.3447071E-05
     +,   3.6073499E-05,   3.9006576E-05,   4.2304127E-05
     +,   4.6040932E-05,   5.0313221E-05,   5.5243210E-05
     +,   6.0982806E-05,   6.7715628E-05,   7.5658798E-05
     +,   8.5060354E-05,   9.6192278E-05,   1.0933947E-04
     +,   1.2478327E-04,   1.4277600E-04,   1.6350650E-04
     +,   1.8705931E-04,   2.1336760E-04,   2.4216110E-04
     +,   2.7291750E-04,   3.0483821E-04,   3.3686284E-04
     +,   3.6774014E-04,   3.9617909E-04,   4.2110551E-04
     +,   4.4200543E-04,   4.5936104E-04,   4.7515667E-04
     +,   4.9343321E-04,   5.2086200E-04,   5.6729850E-04
     +,   6.4621901E-04,   7.7486259E-04,   9.7375701E-04
     +,   1.2652202E-03,   1.6704673E-03,   2.2051758E-03
     +,   2.8737290E-03,   3.6630980E-03,   4.5384080E-03
     +,   5.4419194E-03,   6.2974175E-03,   7.0205503E-03
     +,   7.5334026E-03,   7.7796346E-03,   7.7360119E-03
     +,   7.4167610E-03,   6.8692914E-03,   6.1628884E-03
     +,   5.3741378E-03,   4.5730164E-03,   3.8132088E-03
     +,   3.1282739E-03,   2.5330908E-03,   2.0285051E-03
     +,   1.6072739E-03,   1.2590931E-03,   9.7373920E-04
     +,   7.4236060E-04,   5.5750646E-04,   4.1260311E-04
     +,   3.0144554E-04,   2.1801569E-04,   1.5660517E-04
     +,   1.1206697E-04,   8.0037360E-05,   5.7045792E-05
     +,   4.0491985E-05,   2.8519435E-05,   1.9840465E-05
     +,   1.3569233E-05,   9.0843914E-06,   5.9323761E-06
     +,   3.7682735E-06,   2.3235575E-06,   1.3889473E-06
     +,   8.0432585E-07,   4.5116508E-07,   2.4527279E-07
     +,   1.2944298E-07,   6.6529040E-08,   3.3492100E-08
     +,   1.6679710E-08,   8.3520737E-09,   4.3047579E-09
     +,   2.3481699E-09,   1.3864747E-09,   8.9105373E-10
     +,   6.1500161E-10,   4.4572457E-10,   3.3228320E-10
     +,   2.5118058E-10,   1.9091356E-10,   1.4524869E-10
     +,   1.1037064E-10,   8.3678141E-11,   6.3267273E-11
     +,   4.7694099E-11,   3.5845989E-11,   2.6859064E-11
     +,   2.0063579E-11,   1.4941595E-11,   1.1093376E-11
     +,   8.2112303E-12,   6.0594268E-12,   4.4580351E-12
     +,   3.2700502E-12,   2.3914891E-12,   1.7437779E-12
     +,   1.2677746E-12,   9.1902213E-13,   6.6430748E-13
     +,   4.7882889E-13,   3.4418632E-13,   2.4673300E-13
     +,   1.7640987E-13,   1.2580972E-13,   8.9506866E-14
     +,   6.3533082E-14,   4.5001048E-14,   3.1812874E-14
     +,   2.2451056E-14,   1.5821591E-14,   1.1137203E-14
     +,   7.8340891E-15,   5.5090023E-15,   3.8749403E-15
     +,   2.7278131E-15,   1.9232124E-15,   1.3590149E-15
     +,   9.6333195E-16,   6.8558566E-16,   4.9033493E-16
     +,   3.5274695E-16,   2.5548658E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_hatt100 = Yx/0.02865625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.4324939E-06,   7.4850514E-06
     +,   7.5402750E-06,   7.5987627E-06,   7.6611814E-06
     +,   7.7282521E-06,   7.8007743E-06,   7.8796138E-06
     +,   7.9657093E-06,   8.0600894E-06,   8.1638645E-06
     +,   8.2782262E-06,   8.4044677E-06,   8.5439797E-06
     +,   8.6982518E-06,   8.8688821E-06,   9.0575841E-06
     +,   9.2661840E-06,   9.4966299E-06,   9.7509992E-06
     +,   1.0031497E-05,   1.0340466E-05,   1.0680385E-05
     +,   1.1053903E-05,   1.1463770E-05,   1.1912935E-05
     +,   1.2404486E-05,   1.2941670E-05,   1.3527900E-05
     +,   1.4166742E-05,   1.4861940E-05,   1.5617386E-05
     +,   1.6437134E-05,   1.7325387E-05,   1.8286482E-05
     +,   1.9324907E-05,   2.0445237E-05,   2.1652138E-05
     +,   2.2950429E-05,   2.4344818E-05,   2.5840181E-05
     +,   2.7441281E-05,   2.9152829E-05,   3.0979412E-05
     +,   3.2925440E-05,   3.4995090E-05,   3.7192236E-05
     +,   3.9520353E-05,   4.1982505E-05,   4.4581182E-05
     +,   4.7318277E-05,   5.0194965E-05,   5.3211588E-05
     +,   5.6367790E-05,   5.9661910E-05,   6.3091582E-05
     +,   6.6653127E-05,   7.0341703E-05,   7.4151183E-05
     +,   7.8074168E-05,   8.2101935E-05,   8.6224340E-05
     +,   9.0429741E-05,   9.4705349E-05,   9.9037119E-05
     +,   1.0340924E-04,   1.0780529E-04,   1.1220714E-04
     +,   1.1659625E-04,   1.2095261E-04,   1.2525611E-04
     +,   1.2948540E-04,   1.3361954E-04,   1.3763674E-04
     +,   1.4151580E-04,   1.4523571E-04,   1.4877583E-04
     +,   1.5211616E-04,   1.5523817E-04,   1.5812431E-04
     +,   1.6075830E-04,   1.6312576E-04,   1.6521403E-04
     +,   1.6701251E-04,   1.6851260E-04,   1.6970819E-04
     +,   1.7059522E-04,   1.7117236E-04,   1.7144039E-04
     +,   1.7140276E-04,   1.7106516E-04,   1.7043555E-04
     +,   1.6952425E-04,   1.6834348E-04,   1.6690743E-04
     +,   1.6523211E-04,   1.6333483E-04,   1.6123443E-04
     +,   1.5895066E-04,   1.5650416E-04,   1.5391604E-04
     +,   1.5120796E-04,   1.4840133E-04,   1.4551771E-04
     +,   1.4257804E-04,   1.3960255E-04,   1.3661091E-04
     +,   1.3362177E-04,   1.3065241E-04,   1.2771877E-04
     +,   1.2483571E-04,   1.2201617E-04,   1.1927189E-04
     +,   1.1661263E-04,   1.1404684E-04,   1.1158104E-04
     +,   1.0922047E-04,   1.0696850E-04,   1.0482732E-04
     +,   1.0279754E-04,   1.0087842E-04,   9.9068209E-05
     +,   9.7364114E-05,   9.5762247E-05,   9.4257935E-05
     +,   9.2846072E-05,   9.1520764E-05,   9.0276008E-05
     +,   8.9105335E-05,   8.8002351E-05,   8.6960630E-05
     +,   8.5973959E-05,   8.5036321E-05,   8.4142230E-05
     +,   8.3286584E-05,   8.2464896E-05,   8.1673388E-05
     +,   8.0909063E-05,   8.0169702E-05,   7.9453923E-05
     +,   7.8761361E-05,   7.8092598E-05,   7.7449215E-05
     +,   7.6833800E-05,   7.6250013E-05,   7.5702614E-05
     +,   7.5197342E-05,   7.4741074E-05,   7.4341719E-05
     +,   7.4008152E-05,   7.3750285E-05,   7.3578914E-05
     +,   7.3505733E-05,   7.3543146E-05,   7.3704163E-05
     +,   7.4002295E-05,   7.4451251E-05,   7.5064840E-05
     +,   7.5856617E-05,   7.6839417E-05,   7.8025230E-05
     +,   7.9424703E-05,   8.1046441E-05,   8.2896731E-05
     +,   8.4979030E-05,   8.7293418E-05,   8.9835827E-05
     +,   9.2597693E-05,   9.5565701E-05,   9.8721262E-05
     +,   1.0204002E-04,   1.0549191E-04,   1.0904152E-04
     +,   1.1264814E-04,   1.1626599E-04,   1.1984582E-04
     +,   1.2333592E-04,   1.2668363E-04,   1.2983804E-04
     +,   1.3275351E-04,   1.3539309E-04,   1.3773373E-04
     +,   1.3977253E-04,   1.4153363E-04,   1.4307631E-04
     +,   1.4450290E-04,   1.4596702E-04,   1.4767954E-04
     +,   1.4991207E-04,   1.5299449E-04,   1.5730748E-04
     +,   1.6326547E-04,   1.7129131E-04,   1.8178269E-04
     +,   1.9507350E-04,   2.1139266E-04,   2.3082469E-04
     +,   2.5328313E-04,   2.7850084E-04,   3.0603941E-04
     +,   3.3532197E-04,   3.6569501E-04,   3.9651606E-04
     +,   4.2726347E-04,   4.5767310E-04,   4.8792252E-04
     +,   5.1885413E-04,   5.5226445E-04,   5.9125730E-04
     +,   6.4064376E-04,   7.0732413E-04,   8.0053846E-04
     +,   9.3183649E-04,   1.1145803E-03,   1.3627807E-03
     +,   1.6891491E-03,   2.1024775E-03,   2.6046240E-03
     +,   3.1875549E-03,   3.8311374E-03,   4.5027016E-03
     +,   5.1585883E-03,   5.7480861E-03,   6.2195002E-03
     +,   6.5273317E-03,   6.6391281E-03,   6.5407744E-03
     +,   6.2389602E-03,   5.7601682E-03,   5.1465048E-03
     +,   4.4493107E-03,   3.7218113E-03,   3.0122583E-03
     +,   2.3589542E-03,   1.7876334E-03,   1.3110441E-03
     +,   9.3067624E-04,   6.3960213E-04,   4.2565182E-04
     +,   2.7437144E-04,   1.7134901E-04,   1.0371133E-04
     +,   6.0859948E-05,   3.4638182E-05,   1.9128049E-05
     +,   1.0254023E-05,   5.3393755E-06,   2.7026583E-06
     +,   1.3313504E-06,   6.3949778E-07,   3.0051035E-07
     +,   1.3897375E-07,   6.3933243E-08,   2.9802344E-08
     +,   1.4479850E-08,   7.5908391E-09,   4.4115374E-09
     +,   2.8508154E-09,   2.0049917E-09,   1.4897026E-09
     +,   1.1414074E-09,   8.8840163E-10,   6.9683798E-10
     +,   5.4871740E-10,   4.3307036E-10,   3.4237793E-10
     +,   2.7111099E-10,   2.1504948E-10,   1.7091392E-10
     +,   1.3613609E-10,   1.0870310E-10,   8.7038071E-11
     +,   6.9903833E-11,   5.6329223E-11,   4.5553374E-11
     +,   3.6980884E-11,   3.0143915E-11,   2.4676546E-11
     +,   2.0291045E-11,   1.6762135E-11,   1.3912388E-11
     +,   1.1602621E-11,   9.7229941E-12,   8.1870899E-12
     +,   6.9265019E-12,   5.8872495E-12,   5.0264567E-12
     +,   4.3100454E-12,   3.7109764E-12,   3.2075642E-12
     +,   2.7825305E-12,   2.4219411E-12,   2.1146323E-12
     +,   1.8515348E-12,   1.6253341E-12,   1.4300523E-12
     +,   1.2608219E-12,   1.1136344E-12,   9.8519858E-13
     +,   8.7277950E-13,   7.7411558E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_hatt102 = Yx/0.028
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_hatt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.4324939E-06,   7.4850514E-06
     +,   7.5402750E-06,   7.5987627E-06,   7.6611814E-06
     +,   7.7282521E-06,   7.8007743E-06,   7.8796138E-06
     +,   7.9657093E-06,   8.0600894E-06,   8.1638645E-06
     +,   8.2782262E-06,   8.4044677E-06,   8.5439797E-06
     +,   8.6982518E-06,   8.8688821E-06,   9.0575841E-06
     +,   9.2661840E-06,   9.4966299E-06,   9.7509992E-06
     +,   1.0031497E-05,   1.0340466E-05,   1.0680385E-05
     +,   1.1053903E-05,   1.1463770E-05,   1.1912935E-05
     +,   1.2404486E-05,   1.2941670E-05,   1.3527900E-05
     +,   1.4166742E-05,   1.4861940E-05,   1.5617386E-05
     +,   1.6437134E-05,   1.7325387E-05,   1.8286482E-05
     +,   1.9324907E-05,   2.0445237E-05,   2.1652138E-05
     +,   2.2950429E-05,   2.4344818E-05,   2.5840181E-05
     +,   2.7441281E-05,   2.9152829E-05,   3.0979412E-05
     +,   3.2925440E-05,   3.4995090E-05,   3.7192236E-05
     +,   3.9520353E-05,   4.1982505E-05,   4.4581182E-05
     +,   4.7318277E-05,   5.0194965E-05,   5.3211588E-05
     +,   5.6367790E-05,   5.9661910E-05,   6.3091582E-05
     +,   6.6653127E-05,   7.0341703E-05,   7.4151183E-05
     +,   7.8074168E-05,   8.2101935E-05,   8.6224340E-05
     +,   9.0429741E-05,   9.4705349E-05,   9.9037119E-05
     +,   1.0340924E-04,   1.0780529E-04,   1.1220714E-04
     +,   1.1659625E-04,   1.2095261E-04,   1.2525611E-04
     +,   1.2948540E-04,   1.3361954E-04,   1.3763674E-04
     +,   1.4151580E-04,   1.4523571E-04,   1.4877583E-04
     +,   1.5211616E-04,   1.5523817E-04,   1.5812431E-04
     +,   1.6075830E-04,   1.6312576E-04,   1.6521403E-04
     +,   1.6701251E-04,   1.6851260E-04,   1.6970819E-04
     +,   1.7059522E-04,   1.7117236E-04,   1.7144039E-04
     +,   1.7140276E-04,   1.7106516E-04,   1.7043555E-04
     +,   1.6952425E-04,   1.6834348E-04,   1.6690743E-04
     +,   1.6523211E-04,   1.6333483E-04,   1.6123443E-04
     +,   1.5895066E-04,   1.5650416E-04,   1.5391604E-04
     +,   1.5120796E-04,   1.4840133E-04,   1.4551771E-04
     +,   1.4257804E-04,   1.3960255E-04,   1.3661091E-04
     +,   1.3362177E-04,   1.3065241E-04,   1.2771877E-04
     +,   1.2483571E-04,   1.2201617E-04,   1.1927189E-04
     +,   1.1661263E-04,   1.1404684E-04,   1.1158104E-04
     +,   1.0922047E-04,   1.0696850E-04,   1.0482732E-04
     +,   1.0279754E-04,   1.0087842E-04,   9.9068209E-05
     +,   9.7364114E-05,   9.5762247E-05,   9.4257935E-05
     +,   9.2846072E-05,   9.1520764E-05,   9.0276008E-05
     +,   8.9105335E-05,   8.8002351E-05,   8.6960630E-05
     +,   8.5973959E-05,   8.5036321E-05,   8.4142230E-05
     +,   8.3286584E-05,   8.2464896E-05,   8.1673388E-05
     +,   8.0909063E-05,   8.0169702E-05,   7.9453923E-05
     +,   7.8761361E-05,   7.8092598E-05,   7.7449215E-05
     +,   7.6833800E-05,   7.6250013E-05,   7.5702614E-05
     +,   7.5197342E-05,   7.4741074E-05,   7.4341719E-05
     +,   7.4008152E-05,   7.3750285E-05,   7.3578914E-05
     +,   7.3505733E-05,   7.3543146E-05,   7.3704163E-05
     +,   7.4002295E-05,   7.4451251E-05,   7.5064840E-05
     +,   7.5856617E-05,   7.6839417E-05,   7.8025230E-05
     +,   7.9424703E-05,   8.1046441E-05,   8.2896731E-05
     +,   8.4979030E-05,   8.7293418E-05,   8.9835827E-05
     +,   9.2597693E-05,   9.5565701E-05,   9.8721262E-05
     +,   1.0204002E-04,   1.0549191E-04,   1.0904152E-04
     +,   1.1264814E-04,   1.1626599E-04,   1.1984582E-04
     +,   1.2333592E-04,   1.2668363E-04,   1.2983804E-04
     +,   1.3275351E-04,   1.3539309E-04,   1.3773373E-04
     +,   1.3977253E-04,   1.4153363E-04,   1.4307631E-04
     +,   1.4450290E-04,   1.4596702E-04,   1.4767954E-04
     +,   1.4991207E-04,   1.5299449E-04,   1.5730748E-04
     +,   1.6326547E-04,   1.7129131E-04,   1.8178269E-04
     +,   1.9507350E-04,   2.1139266E-04,   2.3082469E-04
     +,   2.5328313E-04,   2.7850084E-04,   3.0603941E-04
     +,   3.3532197E-04,   3.6569501E-04,   3.9651606E-04
     +,   4.2726347E-04,   4.5767310E-04,   4.8792252E-04
     +,   5.1885413E-04,   5.5226445E-04,   5.9125730E-04
     +,   6.4064376E-04,   7.0732413E-04,   8.0053846E-04
     +,   9.3183649E-04,   1.1145803E-03,   1.3627807E-03
     +,   1.6891491E-03,   2.1024775E-03,   2.6046240E-03
     +,   3.1875549E-03,   3.8311374E-03,   4.5027016E-03
     +,   5.1585883E-03,   5.7480861E-03,   6.2195002E-03
     +,   6.5273317E-03,   6.6391281E-03,   6.5407744E-03
     +,   6.2389602E-03,   5.7601682E-03,   5.1465048E-03
     +,   4.4493107E-03,   3.7218113E-03,   3.0122583E-03
     +,   2.3589542E-03,   1.7876334E-03,   1.3110441E-03
     +,   9.3067624E-04,   6.3960213E-04,   4.2565182E-04
     +,   2.7437144E-04,   1.7134901E-04,   1.0371133E-04
     +,   6.0859948E-05,   3.4638182E-05,   1.9128049E-05
     +,   1.0254023E-05,   5.3393755E-06,   2.7026583E-06
     +,   1.3313504E-06,   6.3949778E-07,   3.0051035E-07
     +,   1.3897375E-07,   6.3933243E-08,   2.9802344E-08
     +,   1.4479850E-08,   7.5908391E-09,   4.4115374E-09
     +,   2.8508154E-09,   2.0049917E-09,   1.4897026E-09
     +,   1.1414074E-09,   8.8840163E-10,   6.9683798E-10
     +,   5.4871740E-10,   4.3307036E-10,   3.4237793E-10
     +,   2.7111099E-10,   2.1504948E-10,   1.7091392E-10
     +,   1.3613609E-10,   1.0870310E-10,   8.7038071E-11
     +,   6.9903833E-11,   5.6329223E-11,   4.5553374E-11
     +,   3.6980884E-11,   3.0143915E-11,   2.4676546E-11
     +,   2.0291045E-11,   1.6762135E-11,   1.3912388E-11
     +,   1.1602621E-11,   9.7229941E-12,   8.1870899E-12
     +,   6.9265019E-12,   5.8872495E-12,   5.0264567E-12
     +,   4.3100454E-12,   3.7109764E-12,   3.2075642E-12
     +,   2.7825305E-12,   2.4219411E-12,   2.1146323E-12
     +,   1.8515348E-12,   1.6253341E-12,   1.4300523E-12
     +,   1.2608219E-12,   1.1136344E-12,   9.8519858E-13
     +,   8.7277950E-13,   7.7411558E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_hatt104 = Yx/0.028
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2685728E-05,   2.2578130E-05
     +,   2.2500204E-05,   2.2455855E-05,   2.2449194E-05
     +,   2.2484530E-05,   2.2566348E-05,   2.2699323E-05
     +,   2.2888247E-05,   2.3138053E-05,   2.3453751E-05
     +,   2.3840419E-05,   2.4303165E-05,   2.4847110E-05
     +,   2.5477349E-05,   2.6198959E-05,   2.7016958E-05
     +,   2.7936330E-05,   2.8962006E-05,   3.0098925E-05
     +,   3.1352021E-05,   3.2726333E-05,   3.4226992E-05
     +,   3.5859455E-05,   3.7629299E-05,   3.9542709E-05
     +,   4.1606261E-05,   4.3827178E-05,   4.6213394E-05
     +,   4.8773651E-05,   5.1517538E-05,   5.4455548E-05
     +,   5.7599031E-05,   6.0960232E-05,   6.4552107E-05
     +,   6.8388144E-05,   7.2482333E-05,   7.6848584E-05
     +,   8.1500948E-05,   8.6452405E-05,   9.1715578E-05
     +,   9.7301519E-05,   1.0321979E-04,   1.0947818E-04
     +,   1.1608264E-04,   1.2303742E-04,   1.3034554E-04
     +,   1.3800948E-04,   1.4603251E-04,   1.5442038E-04
     +,   1.6318358E-04,   1.7234022E-04,   1.8191912E-04
     +,   1.9196402E-04,   2.0253527E-04,   2.1371487E-04
     +,   2.2560639E-04,   2.3833547E-04,   2.5204648E-04
     +,   2.6689644E-04,   2.8304444E-04,   3.0063762E-04
     +,   3.1979239E-04,   3.4057689E-04,   3.6299069E-04
     +,   3.8694590E-04,   4.1226405E-04,   4.3867232E-04
     +,   4.6582986E-04,   4.9336115E-04,   5.2092894E-04
     +,   5.4832269E-04,   5.7559519E-04,   6.0322037E-04
     +,   6.3229556E-04,   6.6475658E-04,   7.0358184E-04
     +,   7.5294729E-04,   8.1826583E-04,   9.0603105E-04
     +,   1.0233596E-03,   1.1771985E-03,   1.3731503E-03
     +,   1.6145051E-03,   1.9024160E-03,   2.2389134E-03
     +,   2.6328606E-03,   3.1062113E-03,   3.6934079E-03
     +,   4.4277669E-03,   5.3153103E-03,   6.3081160E-03
     +,   7.2994502E-03,   8.1699546E-03,   8.8969795E-03
     +,   9.6518910E-03,   1.0715811E-02,   1.2209071E-02
     +,   1.4030464E-02,   1.6231196E-02,   1.9121304E-02
     +,   2.2553613E-02,   2.5647888E-02,   2.7911047E-02
     +,   2.9616162E-02,   3.0396881E-02,   2.9354345E-02
     +,   2.6926987E-02,   2.4363533E-02,   2.1880023E-02
     +,   1.9259961E-02,   1.6838612E-02,   1.4810643E-02
     +,   1.2854696E-02,   1.0729623E-02,   8.5792439E-03
     +,   6.6825971E-03,   5.2006468E-03,   4.1466854E-03
     +,   3.4522302E-03,   3.0199133E-03,   2.7529718E-03
     +,   2.5723155E-03,   2.4231581E-03,   2.2737095E-03
     +,   2.1102950E-03,   1.9315616E-03,   1.7430827E-03
     +,   1.5529649E-03,   1.3690010E-03,   1.1971132E-03
     +,   1.0409375E-03,   9.0198236E-04,   7.8019430E-04
     +,   6.7452289E-04,   5.8344443E-04,   5.0531432E-04
     +,   4.3855247E-04,   3.8171737E-04,   3.3352192E-04
     +,   2.9281777E-04,   2.5856946E-04,   2.2983809E-04
     +,   2.0577764E-04,   1.8563312E-04,   1.6873560E-04
     +,   1.5450231E-04,   1.4243273E-04,   1.3210220E-04
     +,   1.2315434E-04,   1.1529485E-04,   1.0828537E-04
     +,   1.0193607E-04,   9.6099153E-05,   9.0663365E-05
     +,   8.5548425E-05,   8.0699276E-05,   7.6080352E-05
     +,   7.1671304E-05,   6.7463261E-05,   6.3454187E-05
     +,   5.9646558E-05,   5.6045126E-05,   5.2654919E-05
     +,   4.9479775E-05,   4.6521825E-05,   4.3781147E-05
     +,   4.1255433E-05,   3.8939834E-05,   3.6827380E-05
     +,   3.4909350E-05,   3.3175485E-05,   3.1614207E-05
     +,   3.0213163E-05,   2.8959628E-05,   2.7840559E-05
     +,   2.6843005E-05,   2.5954376E-05,   2.5162532E-05
     +,   2.4455880E-05,   2.3823522E-05,   2.3255381E-05
     +,   2.2742148E-05,   2.2275297E-05,   2.1847098E-05
     +,   2.1450622E-05,   2.1079701E-05,   2.0728827E-05
     +,   2.0393170E-05,   2.0068548E-05,   1.9751307E-05
     +,   1.9438323E-05,   1.9126965E-05,   1.8815035E-05
     +,   1.8500710E-05,   1.8182516E-05,   1.7859316E-05
     +,   1.7530267E-05,   1.7194745E-05,   1.6852360E-05
     +,   1.6502940E-05,   1.6146483E-05,   1.5783135E-05
     +,   1.5413156E-05,   1.5036967E-05,   1.4655045E-05
     +,   1.4267951E-05,   1.3876343E-05,   1.3480925E-05
     +,   1.3082424E-05,   1.2681597E-05,   1.2279246E-05
     +,   1.1876189E-05,   1.1473217E-05,   1.1071123E-05
     +,   1.0670712E-05,   1.0272770E-05,   9.8780411E-06
     +,   9.4872394E-06,   9.1010897E-06,   8.7202416E-06
     +,   8.3453069E-06,   7.9768861E-06,   7.6155393E-06
     +,   7.2617522E-06,   6.9159728E-06,   6.5786280E-06
     +,   6.2500931E-06,   5.9306817E-06,   5.6206591E-06
     +,   5.3202716E-06,   5.0297167E-06,   4.7491308E-06
     +,   4.4786125E-06,   4.2182442E-06,   3.9680476E-06
     +,   3.7280049E-06,   3.4980833E-06,   3.2782157E-06
     +,   3.0682907E-06,   2.8681691E-06,   2.6777000E-06
     +,   2.4967082E-06,   2.3249859E-06,   2.1623061E-06
     +,   2.0084367E-06,   1.8631301E-06,   1.7261168E-06
     +,   1.5971170E-06,   1.4758566E-06,   1.3620411E-06
     +,   1.2553725E-06,   1.1555574E-06,   1.0622991E-06
     +,   9.7529698E-07,   8.9425026E-07,   8.1886753E-07
     +,   7.4886105E-07,   6.8394201E-07,   6.2382946E-07
     +,   5.6825235E-07,   5.1694673E-07,   4.6965334E-07
     +,   4.2612214E-07,   3.8611577E-07,   3.4940214E-07
     +,   3.1575928E-07,   2.8497689E-07,   2.5685443E-07
     +,   2.3119910E-07,   2.0782831E-07,   1.8657076E-07
     +,   1.6726432E-07,   1.4975524E-07,   1.3389896E-07
     +,   1.1956165E-07,   1.0661586E-07,   9.4944504E-08
     +,   8.4436863E-08,   7.4991348E-08,   6.6512506E-08
     +,   5.8913034E-08,   5.2111226E-08,   4.6032682E-08
     +,   4.0608025E-08,   3.5774331E-08,   3.1473331E-08
     +,   2.7651801E-08,   2.4261462E-08,   2.1257827E-08
     +,   1.8600836E-08,   1.6253756E-08,   1.4183595E-08
     +,   1.2360191E-08,   1.0756597E-08,   9.3482484E-09
     +,   8.1132567E-09,   7.0317880E-09,   6.0861862E-09
     +,   5.2605258E-09,   4.5406838E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_hatt75 = Yx/0.124333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4742709E-05,   3.5839945E-05
     +,   3.6944315E-05,   3.8054688E-05,   3.9170478E-05
     +,   4.0291783E-05,   4.1419637E-05,   4.2556112E-05
     +,   4.3704615E-05,   4.4870168E-05,   4.6059558E-05
     +,   4.7281694E-05,   4.8547787E-05,   4.9871633E-05
     +,   5.1269806E-05,   5.2761854E-05,   5.4370346E-05
     +,   5.6120974E-05,   5.8042468E-05,   6.0166396E-05
     +,   6.2526909E-05,   6.5160209E-05,   6.8104055E-05
     +,   7.1397000E-05,   7.5077114E-05,   7.9181511E-05
     +,   8.3744562E-05,   8.8796747E-05,   9.4363313E-05
     +,   1.0046262E-04,   1.0710485E-04,   1.1429053E-04
     +,   1.2200930E-04,   1.3023900E-04,   1.3894487E-04
     +,   1.4807908E-04,   1.5758080E-04,   1.6737655E-04
     +,   1.7738172E-04,   1.8750028E-04,   1.9762891E-04
     +,   2.0765721E-04,   2.1747143E-04,   2.2695659E-04
     +,   2.3600023E-04,   2.4449444E-04,   2.5233993E-04
     +,   2.5944790E-04,   2.6574288E-04,   2.7116464E-04
     +,   2.7566976E-04,   2.7923231E-04,   2.8184438E-04
     +,   2.8351578E-04,   2.8427265E-04,   2.8415644E-04
     +,   2.8322192E-04,   2.8153436E-04,   2.7916758E-04
     +,   2.7620091E-04,   2.7271663E-04,   2.6879742E-04
     +,   2.6452460E-04,   2.5997558E-04,   2.5522304E-04
     +,   2.5033447E-04,   2.4537113E-04,   2.4038965E-04
     +,   2.3544190E-04,   2.3057757E-04,   2.2584549E-04
     +,   2.2129719E-04,   2.1698864E-04,   2.1298493E-04
     +,   2.0936267E-04,   2.0621435E-04,   2.0365231E-04
     +,   2.0181258E-04,   2.0085869E-04,   2.0098574E-04
     +,   2.0242354E-04,   2.0543915E-04,   2.1033717E-04
     +,   2.1745922E-04,   2.2717823E-04,   2.3989128E-04
     +,   2.5600364E-04,   2.7591307E-04,   2.9998028E-04
     +,   3.2850227E-04,   3.6167426E-04,   3.9954504E-04
     +,   4.4197284E-04,   4.8858038E-04,   5.3870794E-04
     +,   5.9137511E-04,   6.4528099E-04,   6.9882226E-04
     +,   7.5019570E-04,   7.9754263E-04,   8.3918945E-04
     +,   8.7392697E-04,   9.0136909E-04,   9.2237373E-04
     +,   9.3963352E-04,   9.5849799E-04,   9.8804676E-04
     +,   1.0421528E-03,   1.1398921E-03,   1.3043591E-03
     +,   1.5590400E-03,   1.9219773E-03,   2.3992653E-03
     +,   2.9816539E-03,   3.6478282E-03,   4.3762005E-03
     +,   5.1597208E-03,   6.0125380E-03,   6.9555803E-03
     +,   7.9815928E-03,   9.0192296E-03,   9.9281427E-03
     +,   1.0542797E-02,   1.0745617E-02,   1.0522030E-02
     +,   9.9595441E-03,   9.1943517E-03,   8.3469581E-03
     +,   7.4870046E-03,   6.6385153E-03,   5.8065010E-03
     +,   5.0010742E-03,   4.2450139E-03,   3.5669408E-03
     +,   2.9888819E-03,   2.5182839E-03,   2.1481272E-03
     +,   1.8627485E-03,   1.6444791E-03,   1.4776492E-03
     +,   1.3495712E-03,   1.2499779E-03,   1.1703945E-03
     +,   1.1039308E-03,   1.0453177E-03,   9.9089381E-04
     +,   9.3844009E-04,   8.8687619E-04,   8.3590683E-04
     +,   7.8569679E-04,   7.3662476E-04,   6.8911142E-04
     +,   6.4351177E-04,   6.0006324E-04,   5.5887579E-04
     +,   5.1994924E-04,   4.8319687E-04,   4.4847629E-04
     +,   4.1562552E-04,   3.8449230E-04,   3.5494947E-04
     +,   3.2690880E-04,   3.0032633E-04,   2.7519616E-04
     +,   2.5153963E-04,   2.2939508E-04,   2.0880678E-04
     +,   1.8981098E-04,   1.7242608E-04,   1.5664795E-04
     +,   1.4244780E-04,   1.2977107E-04,   1.1853929E-04
     +,   1.0865544E-04,   1.0000971E-04,   9.2483380E-05
     +,   8.5955005E-05,   8.0305443E-05,   7.5420925E-05
     +,   7.1195762E-05,   6.7534391E-05,   6.4352425E-05
     +,   6.1576589E-05,   5.9144011E-05,   5.7001715E-05
     +,   5.5105589E-05,   5.3418968E-05,   5.1911324E-05
     +,   5.0557312E-05,   4.9335744E-05,   4.8228470E-05
     +,   4.7219775E-05,   4.6295849E-05,   4.5444263E-05
     +,   4.4653603E-05,   4.3913296E-05,   4.3213564E-05
     +,   4.2545249E-05,   4.1899788E-05,   4.1269257E-05
     +,   4.0646413E-05,   4.0024683E-05,   3.9398183E-05
     +,   3.8761766E-05,   3.8111059E-05,   3.7442420E-05
     +,   3.6752939E-05,   3.6040445E-05,   3.5303510E-05
     +,   3.4541285E-05,   3.3753524E-05,   3.2940614E-05
     +,   3.2103457E-05,   3.1243322E-05,   3.0361876E-05
     +,   2.9461193E-05,   2.8543604E-05,   2.7611610E-05
     +,   2.6667880E-05,   2.5715290E-05,   2.4756704E-05
     +,   2.3795017E-05,   2.2833181E-05,   2.1874104E-05
     +,   2.0920568E-05,   1.9975258E-05,   1.9040795E-05
     +,   1.8119670E-05,   1.7214152E-05,   1.6326347E-05
     +,   1.5458241E-05,   1.4611635E-05,   1.3788072E-05
     +,   1.2988922E-05,   1.2215429E-05,   1.1468573E-05
     +,   1.0749148E-05,   1.0057811E-05,   9.3950403E-06
     +,   8.7611079E-06,   8.1561211E-06,   7.5800795E-06
     +,   7.0328419E-06,   6.5140994E-06,   6.0234279E-06
     +,   5.5603282E-06,   5.1242041E-06,   4.7143440E-06
     +,   4.3299656E-06,   3.9702622E-06,   3.6343376E-06
     +,   3.3212566E-06,   3.0300705E-06,   2.7598064E-06
     +,   2.5094587E-06,   2.2780168E-06,   2.0644850E-06
     +,   1.8678733E-06,   1.6871893E-06,   1.5214623E-06
     +,   1.3697529E-06,   1.2311488E-06,   1.1047549E-06
     +,   9.8971225E-07,   8.8520630E-07,   7.9044759E-07
     +,   7.0468508E-07,   6.2721159E-07,   5.5735785E-07
     +,   4.9448823E-07,   4.3800617E-07,   3.8735669E-07
     +,   3.4202108E-07,   3.0151347E-07,   2.6538325E-07
     +,   2.3321671E-07,   2.0462784E-07,   1.7926500E-07
     +,   1.5680189E-07,   1.3694284E-07,   1.1941513E-07
     +,   1.0397250E-07,   9.0389271E-08,   7.8462477E-08
     +,   6.8007033E-08,   5.8857342E-08,   5.0863267E-08
     +,   4.3890136E-08,   3.7817895E-08,   3.2538345E-08
     +,   2.7955712E-08,   2.3984068E-08,   2.0547633E-08
     +,   1.7578738E-08,   1.5017934E-08,   1.2812378E-08
     +,   1.0915825E-08,   9.2873380E-09,   7.8912130E-09
     +,   6.6959998E-09,   5.6743574E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_hatt80 = Yx/0.0513333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0114045E-06,   9.4248971E-06
     +,   9.8480878E-06,   1.0280639E-05,   1.0722169E-05
     +,   1.1172259E-05,   1.1630446E-05,   1.2096230E-05
     +,   1.2569054E-05,   1.3048344E-05,   1.3533468E-05
     +,   1.4023746E-05,   1.4518469E-05,   1.5016877E-05
     +,   1.5518181E-05,   1.6021544E-05,   1.6526097E-05
     +,   1.7030941E-05,   1.7535145E-05,   1.8037750E-05
     +,   1.8537783E-05,   1.9034262E-05,   1.9526178E-05
     +,   2.0012585E-05,   2.0492480E-05,   2.0964968E-05
     +,   2.1429163E-05,   2.1884278E-05,   2.2329617E-05
     +,   2.2764618E-05,   2.3188895E-05,   2.3602277E-05
     +,   2.4004841E-05,   2.4396988E-05,   2.4779503E-05
     +,   2.5153598E-05,   2.5521045E-05,   2.5884196E-05
     +,   2.6246151E-05,   2.6610769E-05,   2.6982880E-05
     +,   2.7368284E-05,   2.7773956E-05,   2.8208073E-05
     +,   2.8680199E-05,   2.9201308E-05,   2.9783900E-05
     +,   3.0442037E-05,   3.1191386E-05,   3.2049225E-05
     +,   3.3034368E-05,   3.4167144E-05,   3.5469180E-05
     +,   3.6963407E-05,   3.8673526E-05,   4.0624131E-05
     +,   4.2840089E-05,   4.5346347E-05,   4.8167567E-05
     +,   5.1327719E-05,   5.4849759E-05,   5.8755330E-05
     +,   6.3064108E-05,   6.7794186E-05,   7.2961528E-05
     +,   7.8579244E-05,   8.4658728E-05,   9.1208065E-05
     +,   9.8233540E-05,   1.0573778E-04,   1.1372146E-04
     +,   1.2218102E-04,   1.3111031E-04,   1.4049778E-04
     +,   1.5032779E-04,   1.6057871E-04,   1.7122117E-04
     +,   1.8221748E-04,   1.9352134E-04,   2.0507567E-04
     +,   2.1681126E-04,   2.2864867E-04,   2.4049549E-04
     +,   2.5225029E-04,   2.6380134E-04,   2.7503195E-04
     +,   2.8582101E-04,   2.9604963E-04,   3.0560285E-04
     +,   3.1437661E-04,   3.2228106E-04,   3.2924398E-04
     +,   3.3521478E-04,   3.4016621E-04,   3.4409444E-04
     +,   3.4701772E-04,   3.4897434E-04,   3.5001725E-04
     +,   3.5020942E-04,   3.4961742E-04,   3.4830504E-04
     +,   3.4632749E-04,   3.4372672E-04,   3.4052832E-04
     +,   3.3674095E-04,   3.3235806E-04,   3.2736262E-04
     +,   3.2173449E-04,   3.1545974E-04,   3.0854208E-04
     +,   3.0101684E-04,   2.9296227E-04,   2.8451448E-04
     +,   2.7587730E-04,   2.6733542E-04,   2.5926036E-04
     +,   2.5211889E-04,   2.4647251E-04,   2.4297468E-04
     +,   2.4235484E-04,   2.4539151E-04,   2.5286630E-04
     +,   2.6550074E-04,   2.8388033E-04,   3.0837479E-04
     +,   3.3906777E-04,   3.7573202E-04,   4.1785458E-04
     +,   4.6476643E-04,   5.1587127E-04,   5.7102874E-04
     +,   6.3104136E-04,   6.9824635E-04,   7.7701971E-04
     +,   8.7403122E-04,   9.9792134E-04,   1.1581654E-03
     +,   1.3630897E-03,   1.6172966E-03,   1.9190882E-03
     +,   2.2587078E-03,   2.6182106E-03,   2.9732694E-03
     +,   3.2966030E-03,   3.5622262E-03,   3.7495347E-03
     +,   3.8460186E-03,   3.8482295E-03,   3.7610664E-03
     +,   3.5958725E-03,   3.3681013E-03,   3.0951868E-03
     +,   2.7948027E-03,   2.4835134E-03,   2.1757677E-03
     +,   1.8831677E-03,   1.6140199E-03,   1.3733164E-03
     +,   1.1631513E-03,   9.8337734E-04,   8.3225273E-04
     +,   7.0703990E-04,   6.0443807E-04,   5.2088313E-04
     +,   4.5281296E-04,   3.9692014E-04,   3.5035925E-04
     +,   3.1087123E-04,   2.7680883E-04,   2.4707228E-04
     +,   2.2098079E-04,   1.9812107E-04,   1.7821655E-04
     +,   1.6103617E-04,   1.4634518E-04,   1.3388498E-04
     +,   1.2337982E-04,   1.1455159E-04,   1.0713417E-04
     +,   1.0088496E-04,   9.5592055E-05,   9.1076341E-05
     +,   8.7189212E-05,   8.3809013E-05,   8.0836573E-05
     +,   7.8191049E-05,   7.5805598E-05,   7.3624047E-05
     +,   7.1598661E-05,   6.9688605E-05,   6.7858513E-05
     +,   6.6078093E-05,   6.4321946E-05,   6.2569387E-05
     +,   6.0804112E-05,   5.9014365E-05,   5.7192756E-05
     +,   5.5335848E-05,   5.3443637E-05,   5.1519128E-05
     +,   4.9567941E-05,   4.7597594E-05,   4.5616791E-05
     +,   4.3635046E-05,   4.1662384E-05,   3.9708535E-05
     +,   3.7782811E-05,   3.5893965E-05,   3.4049852E-05
     +,   3.2257183E-05,   3.0521609E-05,   2.8847751E-05
     +,   2.7239146E-05,   2.5698160E-05,   2.4226176E-05
     +,   2.2823788E-05,   2.1490781E-05,   2.0226156E-05
     +,   1.9028344E-05,   1.7895414E-05,   1.6824950E-05
     +,   1.5814257E-05,   1.4860534E-05,   1.3960854E-05
     +,   1.3112192E-05,   1.2311558E-05,   1.1556073E-05
     +,   1.0842965E-05,   1.0169553E-05,   9.5333107E-06
     +,   8.9319301E-06,   8.3632758E-06,   7.8253452E-06
     +,   7.3163196E-06,   6.8345898E-06,   6.3786533E-06
     +,   5.9471513E-06,   5.5388819E-06,   5.1527527E-06
     +,   4.7877470E-06,   4.4429316E-06,   4.1174690E-06
     +,   3.8105809E-06,   3.5215126E-06,   3.2495518E-06
     +,   2.9940334E-06,   2.7543140E-06,   2.5297506E-06
     +,   2.3197144E-06,   2.1236083E-06,   1.9408201E-06
     +,   1.7707454E-06,   1.6127966E-06,   1.4663902E-06
     +,   1.3309384E-06,   1.2058623E-06,   1.0905986E-06
     +,   9.8459293E-07,   8.8729439E-07,   7.9816579E-07
     +,   7.1669007E-07,   6.4236491E-07,   5.7469907E-07
     +,   5.1322058E-07,   4.5748240E-07,   4.0705035E-07
     +,   3.6151209E-07,   3.2047851E-07,   2.8358119E-07
     +,   2.5047032E-07,   2.2081693E-07,   1.9431546E-07
     +,   1.7068021E-07,   1.4964326E-07,   1.3095647E-07
     +,   1.1439223E-07,   9.9738237E-08,   8.6801315E-08
     +,   7.5402525E-08,   6.5379986E-08,   5.6584661E-08
     +,   4.8882303E-08,   4.2150177E-08,   3.6278234E-08
     +,   3.1166472E-08,   2.6725640E-08,   2.2875215E-08
     +,   1.9543268E-08,   1.6665862E-08,   1.4185773E-08
     +,   1.2052506E-08,   1.0221054E-08,   8.6519396E-09
     +,   7.3101369E-09,   6.1650485E-09,   5.1896940E-09
     +,   4.3606017E-09,   3.6571697E-09,   3.0615601E-09
     +,   2.5582023E-09,   2.1336637E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_hatt85 = Yx/0.0217
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2968775E-05,   1.3203762E-05
     +,   1.3445330E-05,   1.3694294E-05,   1.3951526E-05
     +,   1.4217947E-05,   1.4494524E-05,   1.4782280E-05
     +,   1.5082272E-05,   1.5395615E-05,   1.5723457E-05
     +,   1.6066973E-05,   1.6427381E-05,   1.6805920E-05
     +,   1.7203849E-05,   1.7622448E-05,   1.8063000E-05
     +,   1.8526778E-05,   1.9015059E-05,   1.9529098E-05
     +,   2.0070114E-05,   2.0639294E-05,   2.1237754E-05
     +,   2.1866606E-05,   2.2526796E-05,   2.3219265E-05
     +,   2.3944802E-05,   2.4704110E-05,   2.5497740E-05
     +,   2.6326132E-05,   2.7189546E-05,   2.8088101E-05
     +,   2.9021721E-05,   2.9990162E-05,   3.0992975E-05
     +,   3.2029511E-05,   3.3098913E-05,   3.4200115E-05
     +,   3.5331876E-05,   3.6492642E-05,   3.7680780E-05
     +,   3.8894374E-05,   4.0131323E-05,   4.1389369E-05
     +,   4.2666077E-05,   4.3958855E-05,   4.5264995E-05
     +,   4.6581688E-05,   4.7906033E-05,   4.9235081E-05
     +,   5.0565865E-05,   5.1895422E-05,   5.3220832E-05
     +,   5.4539316E-05,   5.5848071E-05,   5.7144560E-05
     +,   5.8426365E-05,   5.9691294E-05,   6.0937378E-05
     +,   6.2162908E-05,   6.3366460E-05,   6.4546948E-05
     +,   6.5703462E-05,   6.6835564E-05,   6.7943110E-05
     +,   6.9026151E-05,   7.0085182E-05,   7.1120849E-05
     +,   7.2134186E-05,   7.3126299E-05,   7.4098629E-05
     +,   7.5052616E-05,   7.5989905E-05,   7.6912074E-05
     +,   7.7820710E-05,   7.8717378E-05,   7.9603342E-05
     +,   8.0479746E-05,   8.1347396E-05,   8.2206840E-05
     +,   8.3058061E-05,   8.3900719E-05,   8.4733860E-05
     +,   8.5556043E-05,   8.6365166E-05,   8.7158602E-05
     +,   8.7933011E-05,   8.8684508E-05,   8.9408524E-05
     +,   9.0099944E-05,   9.0753136E-05,   9.1361864E-05
     +,   9.1919566E-05,   9.2419228E-05,   9.2853654E-05
     +,   9.3215393E-05,   9.3496979E-05,   9.3690956E-05
     +,   9.3790091E-05,   9.3787392E-05,   9.3676332E-05
     +,   9.3451003E-05,   9.3106166E-05,   9.2637543E-05
     +,   9.2041824E-05,   9.1316928E-05,   9.0462170E-05
     +,   8.9478461E-05,   8.8368361E-05,   8.7136308E-05
     +,   8.5788997E-05,   8.4335203E-05,   8.2786319E-05
     +,   8.1156119E-05,   7.9461344E-05,   7.7721270E-05
     +,   7.5958262E-05,   7.4197378E-05,   7.2466668E-05
     +,   7.0796799E-05,   6.9221103E-05,   6.7775552E-05
     +,   6.6498498E-05,   6.5430635E-05,   6.4614978E-05
     +,   6.4097141E-05,   6.3925261E-05,   6.4150459E-05
     +,   6.4827262E-05,   6.6013978E-05,   6.7773639E-05
     +,   7.0174458E-05,   7.3291580E-05,   7.7208169E-05
     +,   8.2018756E-05,   8.7832974E-05,   9.4780655E-05
     +,   1.0301938E-04,   1.1274410E-04,   1.2419662E-04
     +,   1.3767420E-04,   1.5353605E-04,   1.7220552E-04
     +,   1.9416150E-04,   2.1991708E-04,   2.4999416E-04
     +,   2.8488375E-04,   3.2500210E-04,   3.7065931E-04
     +,   4.2204923E-04,   4.7926707E-04,   5.4236758E-04
     +,   6.1147305E-04,   6.8691617E-04,   7.6937972E-04
     +,   8.5999264E-04,   9.6034526E-04,   1.0723575E-03
     +,   1.1979545E-03,   1.3385473E-03,   1.4944278E-03
     +,   1.6641107E-03,   1.8438061E-03,   2.0272171E-03
     +,   2.2057826E-03,   2.3693636E-03,   2.5073795E-03
     +,   2.6102043E-03,   2.6705547E-03,   2.6845732E-03
     +,   2.6523948E-03,   2.5780827E-03,   2.4689180E-03
     +,   2.3342452E-03,   2.1841354E-03,   2.0280750E-03
     +,   1.8740171E-03,   1.7278504E-03,   1.5932953E-03
     +,   1.4721509E-03,   1.3647547E-03,   1.2704828E-03
     +,   1.1881535E-03,   1.1163165E-03,   1.0534109E-03
     +,   9.9783938E-04,   9.4799238E-04,   9.0227980E-04
     +,   8.5919409E-04,   8.1739045E-04,   7.7576208E-04
     +,   7.3350972E-04,   6.9017371E-04,   6.4562692E-04
     +,   6.0002820E-04,   5.5376207E-04,   5.0736679E-04
     +,   4.6145834E-04,   4.1666435E-04,   3.7357744E-04
     +,   3.3272267E-04,   2.9453140E-04,   2.5932601E-04
     +,   2.2731864E-04,   1.9861608E-04,   1.7322066E-04
     +,   1.5104584E-04,   1.3193210E-04,   1.1566203E-04
     +,   1.0197696E-04,   9.0595538E-05,   8.1229089E-05
     +,   7.3593255E-05,   6.7417306E-05,   6.2451596E-05
     +,   5.8471698E-05,   5.5279867E-05,   5.2704938E-05
     +,   5.0601710E-05,   4.8849139E-05,   4.7347745E-05
     +,   4.6017441E-05,   4.4795106E-05,   4.3632186E-05
     +,   4.2492400E-05,   4.1349780E-05,   4.0186918E-05
     +,   3.8993239E-05,   3.7763548E-05,   3.6496789E-05
     +,   3.5195138E-05,   3.3863016E-05,   3.2506301E-05
     +,   3.1131814E-05,   2.9746998E-05,   2.8359285E-05
     +,   2.6975980E-05,   2.5604120E-05,   2.4250254E-05
     +,   2.2920267E-05,   2.1619382E-05,   2.0352250E-05
     +,   1.9122826E-05,   1.7934310E-05,   1.6789265E-05
     +,   1.5689715E-05,   1.4637116E-05,   1.3632333E-05
     +,   1.2675767E-05,   1.1767495E-05,   1.0907140E-05
     +,   1.0094013E-05,   9.3272220E-06,   8.6056425E-06
     +,   7.9279280E-06,   7.2925968E-06,   6.6981042E-06
     +,   6.1428236E-06,   5.6250433E-06,   5.1430252E-06
     +,   4.6950586E-06,   4.2794331E-06,   3.8944290E-06
     +,   3.5383625E-06,   3.2096191E-06,   2.9065950E-06
     +,   2.6277376E-06,   2.3715643E-06,   2.1366452E-06
     +,   1.9215890E-06,   1.7250642E-06,   1.5458085E-06
     +,   1.3826162E-06,   1.2343255E-06,   1.0998344E-06
     +,   9.7810744E-07,   8.6814862E-07,   7.6903041E-07
     +,   6.7986355E-07,   5.9982449E-07,   5.2812743E-07
     +,   4.6404654E-07,   4.0689440E-07,   3.5603853E-07
     +,   3.1088291E-07,   2.7088205E-07,   2.3552650E-07
     +,   2.0434743E-07,   1.7691636E-07,   1.5283699E-07
     +,   1.3175016E-07,   1.1332578E-07,   9.7266479E-08
     +,   8.3300350E-08,   7.1184026E-08,   6.0696514E-08
     +,   5.1640775E-08,   4.3839311E-08,   3.7134708E-08
     +,   3.1385976E-08,   2.6468779E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_hatt90 = Yx/0.0193103448275862
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3936909E-05,   2.4579896E-05
     +,   2.5222431E-05,   2.5863799E-05,   2.6503272E-05
     +,   2.7140108E-05,   2.7773591E-05,   2.8402987E-05
     +,   2.9027566E-05,   2.9646628E-05,   3.0259434E-05
     +,   3.0865296E-05,   3.1463496E-05,   3.2053329E-05
     +,   3.2634118E-05,   3.3205171E-05,   3.3765817E-05
     +,   3.4315384E-05,   3.4853219E-05,   3.5378671E-05
     +,   3.5891109E-05,   3.6389902E-05,   3.6874426E-05
     +,   3.7344103E-05,   3.7798316E-05,   3.8236525E-05
     +,   3.8658152E-05,   3.9062674E-05,   3.9449573E-05
     +,   3.9818355E-05,   4.0168572E-05,   4.0499777E-05
     +,   4.0811577E-05,   4.1103613E-05,   4.1375559E-05
     +,   4.1627158E-05,   4.1858184E-05,   4.2068474E-05
     +,   4.2257936E-05,   4.2426549E-05,   4.2574356E-05
     +,   4.2701497E-05,   4.2808188E-05,   4.2894750E-05
     +,   4.2961605E-05,   4.3009288E-05,   4.3038443E-05
     +,   4.3049844E-05,   4.3044387E-05,   4.3023087E-05
     +,   4.2987129E-05,   4.2937798E-05,   4.2876556E-05
     +,   4.2804972E-05,   4.2724783E-05,   4.2637857E-05
     +,   4.2546188E-05,   4.2451913E-05,   4.2357286E-05
     +,   4.2264677E-05,   4.2176558E-05,   4.2095497E-05
     +,   4.2024123E-05,   4.1965126E-05,   4.1921234E-05
     +,   4.1895197E-05,   4.1889736E-05,   4.1907555E-05
     +,   4.1951298E-05,   4.2023490E-05,   4.2126576E-05
     +,   4.2262811E-05,   4.2434283E-05,   4.2642860E-05
     +,   4.2890166E-05,   4.3177548E-05,   4.3506032E-05
     +,   4.3876305E-05,   4.4288696E-05,   4.4743156E-05
     +,   4.5239183E-05,   4.5775898E-05,   4.6351906E-05
     +,   4.6965441E-05,   4.7614179E-05,   4.8295427E-05
     +,   4.9005939E-05,   4.9742110E-05,   5.0499788E-05
     +,   5.1274495E-05,   5.2061372E-05,   5.2855103E-05
     +,   5.3650096E-05,   5.4440497E-05,   5.5220240E-05
     +,   5.5982964E-05,   5.6722311E-05,   5.7431727E-05
     +,   5.8104753E-05,   5.8734873E-05,   5.9315807E-05
     +,   5.9841313E-05,   6.0305523E-05,   6.0702772E-05
     +,   6.1027837E-05,   6.1275903E-05,   6.1442624E-05
     +,   6.1524232E-05,   6.1517538E-05,   6.1419996E-05
     +,   6.1229781E-05,   6.0945786E-05,   6.0567672E-05
     +,   6.0095917E-05,   5.9531863E-05,   5.8877678E-05
     +,   5.8136487E-05,   5.7312271E-05,   5.6410045E-05
     +,   5.5435714E-05,   5.4396180E-05,   5.3299438E-05
     +,   5.2154541E-05,   5.0971557E-05,   4.9761675E-05
     +,   4.8537389E-05,   4.7312285E-05,   4.6101417E-05
     +,   4.4921118E-05,   4.3789372E-05,   4.2725693E-05
     +,   4.1751515E-05,   4.0890132E-05,   4.0167059E-05
     +,   3.9610044E-05,   3.9249262E-05,   3.9117480E-05
     +,   3.9249982E-05,   3.9684495E-05,   4.0460989E-05
     +,   4.1621137E-05,   4.3207532E-05,   4.5262812E-05
     +,   4.7828151E-05,   5.0941122E-05,   5.4633947E-05
     +,   5.8930655E-05,   6.3843756E-05,   6.9371163E-05
     +,   7.5493372E-05,   8.2170103E-05,   8.9337162E-05
     +,   9.6905009E-05,   1.0475898E-04,   1.1276012E-04
     +,   1.2074850E-04,   1.2855048E-04,   1.3599001E-04
     +,   1.4290292E-04,   1.4915632E-04,   1.5467496E-04
     +,   1.5946983E-04,   1.6367051E-04,   1.6755794E-04
     +,   1.7159287E-04,   1.7643409E-04,   1.8294044E-04
     +,   1.9215287E-04,   2.0525367E-04,   2.2350805E-04
     +,   2.4820119E-04,   2.8060295E-04,   3.2200260E-04
     +,   3.7385704E-04,   4.3809149E-04,   5.1757356E-04
     +,   6.1666715E-04,   7.4170611E-04,   9.0115092E-04
     +,   1.1051293E-03,   1.3641139E-03,   1.6866972E-03
     +,   2.0767762E-03,   2.5307245E-03,   3.0352753E-03
     +,   3.5669154E-03,   4.0933923E-03,   4.5772847E-03
     +,   4.9810261E-03,   5.2724057E-03,   5.4295096E-03
     +,   5.4436903E-03,   5.3201946E-03,   5.0763739E-03
     +,   4.7380305E-03,   4.3349881E-03,   3.8969226E-03
     +,   3.4501369E-03,   3.0155911E-03,   2.6082413E-03
     +,   2.2372426E-03,   1.9066734E-03,   1.6165733E-03
     +,   1.3641746E-03,   1.1451645E-03,   9.5475197E-04
     +,   7.8858330E-04,   6.4327189E-04,   5.1651930E-04
     +,   4.0692484E-04,   3.1362404E-04,   2.3588842E-04
     +,   1.7280281E-04,   1.2310481E-04,   8.5188265E-05
     +,   5.7215617E-05,   3.7276837E-05,   2.3549568E-05
     +,   1.4422304E-05,   8.5614402E-06,   4.9258465E-06
     +,   2.7467295E-06,   1.4844269E-06,   7.7754362E-07
     +,   3.9474213E-07,   1.9423388E-07,   9.2636654E-08
     +,   4.2827736E-08,   1.9195559E-08,   8.3432203E-09
     +,   3.5191774E-09,   1.4428211E-09,   5.7692218E-10
     +,   2.2663942E-10,   8.8834558E-11,   3.5794884E-11
     +,   1.5567582E-11,   7.7219099E-12,   4.4778586E-12
     +,   2.9565840E-12,   2.1142357E-12,   1.5726933E-12
     +,   1.1895332E-12,   9.0510130E-13,   6.8963471E-13
     +,   5.2523318E-13,   3.9957293E-13,   3.0355373E-13
     +,   2.3026695E-13,   1.7441559E-13,   1.3191584E-13
     +,   9.9626301E-14,   7.5133747E-14,   5.6584647E-14
     +,   4.2557947E-14,   3.1966661E-14,   2.3981424E-14
     +,   1.7969745E-14,   1.3449890E-14,   1.0056117E-14
     +,   7.5111739E-15,   5.6051376E-15,   4.1791996E-15
     +,   3.1135523E-15,   2.3180228E-15,   1.7246787E-15
     +,   1.2825043E-15,   9.5325554E-16,   7.0827148E-16
     +,   5.2609312E-16,   3.9068667E-16,   2.9009354E-16
     +,   2.1539124E-16,   1.5992923E-16,   1.1875820E-16
     +,   8.8201058E-17,   6.5520387E-17,   4.8685882E-17
     +,   3.6188222E-17,   2.6908738E-17,   2.0016528E-17
     +,   1.4896074E-17,   1.1090232E-17,   8.2604895E-18
     +,   6.1554505E-18,   4.5888564E-18,   3.4223870E-18
     +,   2.5533903E-18,   1.9057383E-18,   1.4227905E-18
     +,   1.0625250E-18,   7.9364847E-19,   5.9291417E-19
     +,   4.4299296E-19,   3.3099862E-19,   2.4731090E-19
     +,   1.8476944E-19,   1.3802249E-19,   1.0308183E-19
     +,   7.6965369E-20,   5.7447209E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_hatt95 = Yx/0.0245
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.2636488E-05,   9.5515708E-05
     +,   9.8423530E-05,   1.0135653E-04,   1.0431118E-04
     +,   1.0728362E-04,   1.1026996E-04,   1.1326592E-04
     +,   1.1626714E-04,   1.1926911E-04,   1.2226711E-04
     +,   1.2525634E-04,   1.2823171E-04,   1.3118828E-04
     +,   1.3412084E-04,   1.3702417E-04,   1.3989305E-04
     +,   1.4272223E-04,   1.4550654E-04,   1.4824075E-04
     +,   1.5091986E-04,   1.5353893E-04,   1.5609310E-04
     +,   1.5857791E-04,   1.6098884E-04,   1.6332182E-04
     +,   1.6557299E-04,   1.6773879E-04,   1.6981599E-04
     +,   1.7180189E-04,   1.7369387E-04,   1.7549001E-04
     +,   1.7718867E-04,   1.7878870E-04,   1.8028941E-04
     +,   1.8169062E-04,   1.8299250E-04,   1.8419580E-04
     +,   1.8530182E-04,   1.8631211E-04,   1.8722897E-04
     +,   1.8805485E-04,   1.8879290E-04,   1.8944641E-04
     +,   1.9001926E-04,   1.9051565E-04,   1.9093997E-04
     +,   1.9129706E-04,   1.9159196E-04,   1.9182987E-04
     +,   1.9201616E-04,   1.9215635E-04,   1.9225609E-04
     +,   1.9232096E-04,   1.9235666E-04,   1.9236872E-04
     +,   1.9236264E-04,   1.9234374E-04,   1.9231721E-04
     +,   1.9228796E-04,   1.9226075E-04,   1.9223998E-04
     +,   1.9222981E-04,   1.9223394E-04,   1.9225590E-04
     +,   1.9229873E-04,   1.9236504E-04,   1.9245721E-04
     +,   1.9257719E-04,   1.9272653E-04,   1.9290626E-04
     +,   1.9311732E-04,   1.9336010E-04,   1.9363474E-04
     +,   1.9394109E-04,   1.9427862E-04,   1.9464674E-04
     +,   1.9504456E-04,   1.9547089E-04,   1.9592453E-04
     +,   1.9640419E-04,   1.9690856E-04,   1.9743614E-04
     +,   1.9798557E-04,   1.9855554E-04,   1.9914487E-04
     +,   1.9975234E-04,   2.0037717E-04,   2.0101845E-04
     +,   2.0167575E-04,   2.0234891E-04,   2.0303784E-04
     +,   2.0374285E-04,   2.0446461E-04,   2.0520398E-04
     +,   2.0596238E-04,   2.0674134E-04,   2.0754291E-04
     +,   2.0836931E-04,   2.0922320E-04,   2.1010773E-04
     +,   2.1102601E-04,   2.1198197E-04,   2.1297928E-04
     +,   2.1402231E-04,   2.1511575E-04,   2.1626423E-04
     +,   2.1747274E-04,   2.1874676E-04,   2.2009164E-04
     +,   2.2151301E-04,   2.2301673E-04,   2.2460878E-04
     +,   2.2629510E-04,   2.2808183E-04,   2.2997538E-04
     +,   2.3198155E-04,   2.3410673E-04,   2.3635672E-04
     +,   2.3873766E-04,   2.4125515E-04,   2.4391476E-04
     +,   2.4672144E-04,   2.4968022E-04,   2.5279549E-04
     +,   2.5607087E-04,   2.5950980E-04,   2.6311458E-04
     +,   2.6688722E-04,   2.7082817E-04,   2.7493783E-04
     +,   2.7921458E-04,   2.8365621E-04,   2.8825889E-04
     +,   2.9301760E-04,   2.9792640E-04,   3.0297675E-04
     +,   3.0815916E-04,   3.1346260E-04,   3.1887458E-04
     +,   3.2438044E-04,   3.2996436E-04,   3.3560907E-04
     +,   3.4129593E-04,   3.4700517E-04,   3.5271607E-04
     +,   3.5840797E-04,   3.6405917E-04,   3.6964897E-04
     +,   3.7515778E-04,   3.8056742E-04,   3.8586205E-04
     +,   3.9102943E-04,   3.9606166E-04,   4.0095614E-04
     +,   4.0571691E-04,   4.1035493E-04,   4.1489096E-04
     +,   4.1935558E-04,   4.2378932E-04,   4.2824572E-04
     +,   4.3279043E-04,   4.3750272E-04,   4.4247406E-04
     +,   4.4781095E-04,   4.5363102E-04,   4.6006456E-04
     +,   4.6725094E-04,   4.7533915E-04,   4.8448378E-04
     +,   4.9484143E-04,   5.0656917E-04,   5.1981973E-04
     +,   5.3473987E-04,   5.5146130E-04,   5.7010265E-04
     +,   5.9076323E-04,   6.1351643E-04,   6.3841033E-04
     +,   6.6546374E-04,   6.9466332E-04,   7.2596193E-04
     +,   7.5927691E-04,   7.9449330E-04,   8.3146518E-04
     +,   8.7001425E-04,   9.0993725E-04,   9.5101626E-04
     +,   9.9302200E-04,   1.0357244E-03,   1.0789088E-03
     +,   1.1223907E-03,   1.1660322E-03,   1.2097592E-03
     +,   1.2536008E-03,   1.2977065E-03,   1.3423868E-03
     +,   1.3881514E-03,   1.4357629E-03,   1.4862852E-03
     +,   1.5411313E-03,   1.6021129E-03,   1.6714834E-03
     +,   1.7519341E-03,   1.8465302E-03,   1.9585947E-03
     +,   2.0914383E-03,   2.2479515E-03,   2.4300932E-03
     +,   2.6383300E-03,   2.8711618E-03,   3.1249591E-03
     +,   3.3943295E-03,   3.6732012E-03,   3.9564786E-03
     +,   4.2420560E-03,   4.5326888E-03,   4.8370156E-03
     +,   5.1690894E-03,   5.5462066E-03,   5.9852959E-03
     +,   6.4986222E-03,   7.0901359E-03,   7.7540781E-03
     +,   8.4766522E-03,   9.2404485E-03,   1.0029769E-02
     +,   1.0834427E-02,   1.1649434E-02,   1.2470485E-02
     +,   1.3287742E-02,   1.4081962E-02,   1.4825292E-02
     +,   1.5485356E-02,   1.6030619E-02,   1.6434308E-02
     +,   1.6677216E-02,   1.6751930E-02,   1.6667919E-02
     +,   1.6453845E-02,   1.6152123E-02,   1.5804637E-02
     +,   1.5435333E-02,   1.5039053E-02,   1.4584401E-02
     +,   1.4029432E-02,   1.3343321E-02,   1.2522546E-02
     +,   1.1595229E-02,   1.0612884E-02,   9.6349213E-03
     +,   8.7134810E-03,   7.8836093E-03,   7.1601230E-03
     +,   6.5403255E-03,   6.0096220E-03,   5.5477540E-03
     +,   5.1340470E-03,   4.7510206E-03,   4.3863156E-03
     +,   4.0330961E-03,   3.6892991E-03,   3.3562069E-03
     +,   3.0369386E-03,   2.7350872E-03,   2.4537027E-03
     +,   2.1948114E-03,   1.9592855E-03,   1.7469573E-03
     +,   1.5568415E-03,   1.3874333E-03,   1.2369573E-03
     +,   1.1035396E-03,   9.8532380E-04,   8.8056509E-04
     +,   7.8767689E-04,   7.0523034E-04,   6.3198048E-04
     +,   5.6683924E-04,   5.0888298E-04,   4.5731699E-04
     +,   4.1147351E-04,   3.7077648E-04,   3.3473445E-04
     +,   3.0291089E-04,   2.7491793E-04,   2.5039614E-04
     +,   2.2900937E-04,   2.1044038E-04,   1.9438323E-04
     +,   1.8054838E-04,   1.6865863E-04,   1.5845489E-04
     +,   1.4969498E-04,   1.4215804E-04,   1.3564348E-04
     +,   1.2997372E-04,   1.2499238E-04,   1.2056534E-04
     +,   1.1657803E-04,   1.1293535E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_hatt100 = Yx/0.145697674418605
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_hatt102(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3237578E-04,   2.4213908E-04
     +,   2.5216985E-04,   2.6246556E-04,   2.7302263E-04
     +,   2.8383642E-04,   2.9490105E-04,   3.0620949E-04
     +,   3.1775332E-04,   3.2952338E-04,   3.4150848E-04
     +,   3.5369687E-04,   3.6607488E-04,   3.7862832E-04
     +,   3.9134108E-04,   4.0419638E-04,   4.1717591E-04
     +,   4.3026113E-04,   4.4343204E-04,   4.5666768E-04
     +,   4.6994697E-04,   4.8324824E-04,   4.9654883E-04
     +,   5.0982705E-04,   5.2305963E-04,   5.3622475E-04
     +,   5.4930022E-04,   5.6226429E-04,   5.7509542E-04
     +,   5.8777351E-04,   6.0027820E-04,   6.1259122E-04
     +,   6.2469381E-04,   6.3656934E-04,   6.4820156E-04
     +,   6.5957598E-04,   6.7067874E-04,   6.8149652E-04
     +,   6.9201807E-04,   7.0223171E-04,   7.1212836E-04
     +,   7.2169770E-04,   7.3093141E-04,   7.3982158E-04
     +,   7.4836041E-04,   7.5654022E-04,   7.6435402E-04
     +,   7.7179435E-04,   7.7885465E-04,   7.8552711E-04
     +,   7.9180545E-04,   7.9768122E-04,   8.0314837E-04
     +,   8.0819882E-04,   8.1282400E-04,   8.1701850E-04
     +,   8.2077389E-04,   8.2408328E-04,   8.2694093E-04
     +,   8.2934013E-04,   8.3127728E-04,   8.3274790E-04
     +,   8.3374948E-04,   8.3428045E-04,   8.3434203E-04
     +,   8.3393673E-04,   8.3306833E-04,   8.3174382E-04
     +,   8.2997157E-04,   8.2776311E-04,   8.2513172E-04
     +,   8.2209351E-04,   8.1866630E-04,   8.1487064E-04
     +,   8.1072934E-04,   8.0626627E-04,   8.0150797E-04
     +,   7.9648272E-04,   7.9121860E-04,   7.8574603E-04
     +,   7.8009587E-04,   7.7429804E-04,   7.6838472E-04
     +,   7.6238473E-04,   7.5632852E-04,   7.5024465E-04
     +,   7.4415968E-04,   7.3809997E-04,   7.3208875E-04
     +,   7.2614750E-04,   7.2029501E-04,   7.1454793E-04
     +,   7.0892111E-04,   7.0342503E-04,   6.9806841E-04
     +,   6.9285760E-04,   6.8779651E-04,   6.8288512E-04
     +,   6.7812292E-04,   6.7350612E-04,   6.6902873E-04
     +,   6.6468434E-04,   6.6046329E-04,   6.5635593E-04
     +,   6.5235043E-04,   6.4843486E-04,   6.4459676E-04
     +,   6.4082263E-04,   6.3710014E-04,   6.3341542E-04
     +,   6.2975625E-04,   6.2611006E-04,   6.2246568E-04
     +,   6.1881205E-04,   6.1513903E-04,   6.1143795E-04
     +,   6.0770137E-04,   6.0392224E-04,   6.0009537E-04
     +,   5.9621700E-04,   5.9228396E-04,   5.8829499E-04
     +,   5.8424997E-04,   5.8015023E-04,   5.7599845E-04
     +,   5.7179882E-04,   5.6755624E-04,   5.6327792E-04
     +,   5.5897166E-04,   5.5464759E-04,   5.5031577E-04
     +,   5.4598955E-04,   5.4168177E-04,   5.3740887E-04
     +,   5.3318718E-04,   5.2903465E-04,   5.2497134E-04
     +,   5.2101881E-04,   5.1719969E-04,   5.1353819E-04
     +,   5.1006046E-04,   5.0679361E-04,   5.0376588E-04
     +,   5.0100748E-04,   4.9854955E-04,   4.9642363E-04
     +,   4.9466308E-04,   4.9330166E-04,   4.9237319E-04
     +,   4.9191288E-04,   4.9195543E-04,   4.9253553E-04
     +,   4.9368804E-04,   4.9544696E-04,   4.9784628E-04
     +,   5.0091854E-04,   5.0469546E-04,   5.0920807E-04
     +,   5.1448669E-04,   5.2055944E-04,   5.2745390E-04
     +,   5.3519721E-04,   5.4381520E-04,   5.5333256E-04
     +,   5.6377373E-04,   5.7516393E-04,   5.8752735E-04
     +,   6.0088787E-04,   6.1527098E-04,   6.3070230E-04
     +,   6.4720801E-04,   6.6481397E-04,   6.8354711E-04
     +,   7.0343481E-04,   7.2450121E-04,   7.4677047E-04
     +,   7.7026593E-04,   7.9500355E-04,   8.2099502E-04
     +,   8.4824942E-04,   8.7676529E-04,   9.0653286E-04
     +,   9.3753217E-04,   9.6973439E-04,   1.0031010E-03
     +,   1.0375808E-03,   1.0731115E-03,   1.1096250E-03
     +,   1.1470462E-03,   1.1852921E-03,   1.2242786E-03
     +,   1.2639234E-03,   1.3041435E-03,   1.3448602E-03
     +,   1.3860037E-03,   1.4275163E-03,   1.4693375E-03
     +,   1.5114184E-03,   1.5537145E-03,   1.5961836E-03
     +,   1.6387735E-03,   1.6814227E-03,   1.7240602E-03
     +,   1.7665912E-03,   1.8088921E-03,   1.8508170E-03
     +,   1.8921935E-03,   1.9328208E-03,   1.9724839E-03
     +,   2.0109601E-03,   2.0480317E-03,   2.0835022E-03
     +,   2.1172117E-03,   2.1490562E-03,   2.1790054E-03
     +,   2.2071095E-03,   2.2335055E-03,   2.2584302E-03
     +,   2.2822071E-03,   2.3052380E-03,   2.3279928E-03
     +,   2.3509851E-03,   2.3747575E-03,   2.3998655E-03
     +,   2.4268641E-03,   2.4563023E-03,   2.4887230E-03
     +,   2.5246665E-03,   2.5646973E-03,   2.6094057E-03
     +,   2.6594335E-03,   2.7154791E-03,   2.7783180E-03
     +,   2.8487998E-03,   2.9278419E-03,   3.0164181E-03
     +,   3.1155501E-03,   3.2262830E-03,   3.3496644E-03
     +,   3.4867476E-03,   3.6385718E-03,   3.8061524E-03
     +,   3.9904770E-03,   4.1925418E-03,   4.4133347E-03
     +,   4.6538687E-03,   4.9151536E-03,   5.1982165E-03
     +,   5.5040540E-03,   5.8334875E-03,   6.1870776E-03
     +,   6.5649766E-03,   6.9666957E-03,   7.3910654E-03
     +,   7.8362469E-03,   8.2997680E-03,   8.7788133E-03
     +,   9.2704110E-03,   9.7717829E-03,   1.0280338E-02
     +,   1.0793347E-02,   1.1307551E-02,   1.1818380E-02
     +,   1.2319087E-02,   1.2800017E-02,   1.3248451E-02
     +,   1.3648820E-02,   1.3983702E-02,   1.4235234E-02
     +,   1.4386989E-02,   1.4425729E-02,   1.4342739E-02
     +,   1.4134898E-02,   1.3804698E-02,   1.3359925E-02
     +,   1.2812627E-02,   1.2177911E-02,   1.1472744E-02
     +,   1.0714649E-02,   9.9210162E-03,   9.1082603E-03
     +,   8.2916431E-03,   7.4848244E-03,   6.6999597E-03
     +,   5.9474097E-03,   5.2358448E-03,   4.5720302E-03
     +,   3.9608614E-03,   3.4054122E-03,   2.9068957E-03
     +,   2.4649242E-03,   2.0776156E-03,   1.7419569E-03
     +,   1.4540150E-03,   1.2093055E-03,   1.0030268E-03
     +,   8.3035970E-04,   6.8662444E-04,   5.6747987E-04
     +,   4.6898000E-04,   3.8766582E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_hatt102 = Yx/0.161325581395349
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_hatt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3237578E-04,   2.4213908E-04
     +,   2.5216985E-04,   2.6246556E-04,   2.7302263E-04
     +,   2.8383642E-04,   2.9490105E-04,   3.0620949E-04
     +,   3.1775332E-04,   3.2952338E-04,   3.4150848E-04
     +,   3.5369687E-04,   3.6607488E-04,   3.7862832E-04
     +,   3.9134108E-04,   4.0419638E-04,   4.1717591E-04
     +,   4.3026113E-04,   4.4343204E-04,   4.5666768E-04
     +,   4.6994697E-04,   4.8324824E-04,   4.9654883E-04
     +,   5.0982705E-04,   5.2305963E-04,   5.3622475E-04
     +,   5.4930022E-04,   5.6226429E-04,   5.7509542E-04
     +,   5.8777351E-04,   6.0027820E-04,   6.1259122E-04
     +,   6.2469381E-04,   6.3656934E-04,   6.4820156E-04
     +,   6.5957598E-04,   6.7067874E-04,   6.8149652E-04
     +,   6.9201807E-04,   7.0223171E-04,   7.1212836E-04
     +,   7.2169770E-04,   7.3093141E-04,   7.3982158E-04
     +,   7.4836041E-04,   7.5654022E-04,   7.6435402E-04
     +,   7.7179435E-04,   7.7885465E-04,   7.8552711E-04
     +,   7.9180545E-04,   7.9768122E-04,   8.0314837E-04
     +,   8.0819882E-04,   8.1282400E-04,   8.1701850E-04
     +,   8.2077389E-04,   8.2408328E-04,   8.2694093E-04
     +,   8.2934013E-04,   8.3127728E-04,   8.3274790E-04
     +,   8.3374948E-04,   8.3428045E-04,   8.3434203E-04
     +,   8.3393673E-04,   8.3306833E-04,   8.3174382E-04
     +,   8.2997157E-04,   8.2776311E-04,   8.2513172E-04
     +,   8.2209351E-04,   8.1866630E-04,   8.1487064E-04
     +,   8.1072934E-04,   8.0626627E-04,   8.0150797E-04
     +,   7.9648272E-04,   7.9121860E-04,   7.8574603E-04
     +,   7.8009587E-04,   7.7429804E-04,   7.6838472E-04
     +,   7.6238473E-04,   7.5632852E-04,   7.5024465E-04
     +,   7.4415968E-04,   7.3809997E-04,   7.3208875E-04
     +,   7.2614750E-04,   7.2029501E-04,   7.1454793E-04
     +,   7.0892111E-04,   7.0342503E-04,   6.9806841E-04
     +,   6.9285760E-04,   6.8779651E-04,   6.8288512E-04
     +,   6.7812292E-04,   6.7350612E-04,   6.6902873E-04
     +,   6.6468434E-04,   6.6046329E-04,   6.5635593E-04
     +,   6.5235043E-04,   6.4843486E-04,   6.4459676E-04
     +,   6.4082263E-04,   6.3710014E-04,   6.3341542E-04
     +,   6.2975625E-04,   6.2611006E-04,   6.2246568E-04
     +,   6.1881205E-04,   6.1513903E-04,   6.1143795E-04
     +,   6.0770137E-04,   6.0392224E-04,   6.0009537E-04
     +,   5.9621700E-04,   5.9228396E-04,   5.8829499E-04
     +,   5.8424997E-04,   5.8015023E-04,   5.7599845E-04
     +,   5.7179882E-04,   5.6755624E-04,   5.6327792E-04
     +,   5.5897166E-04,   5.5464759E-04,   5.5031577E-04
     +,   5.4598955E-04,   5.4168177E-04,   5.3740887E-04
     +,   5.3318718E-04,   5.2903465E-04,   5.2497134E-04
     +,   5.2101881E-04,   5.1719969E-04,   5.1353819E-04
     +,   5.1006046E-04,   5.0679361E-04,   5.0376588E-04
     +,   5.0100748E-04,   4.9854955E-04,   4.9642363E-04
     +,   4.9466308E-04,   4.9330166E-04,   4.9237319E-04
     +,   4.9191288E-04,   4.9195543E-04,   4.9253553E-04
     +,   4.9368804E-04,   4.9544696E-04,   4.9784628E-04
     +,   5.0091854E-04,   5.0469546E-04,   5.0920807E-04
     +,   5.1448669E-04,   5.2055944E-04,   5.2745390E-04
     +,   5.3519721E-04,   5.4381520E-04,   5.5333256E-04
     +,   5.6377373E-04,   5.7516393E-04,   5.8752735E-04
     +,   6.0088787E-04,   6.1527098E-04,   6.3070230E-04
     +,   6.4720801E-04,   6.6481397E-04,   6.8354711E-04
     +,   7.0343481E-04,   7.2450121E-04,   7.4677047E-04
     +,   7.7026593E-04,   7.9500355E-04,   8.2099502E-04
     +,   8.4824942E-04,   8.7676529E-04,   9.0653286E-04
     +,   9.3753217E-04,   9.6973439E-04,   1.0031010E-03
     +,   1.0375808E-03,   1.0731115E-03,   1.1096250E-03
     +,   1.1470462E-03,   1.1852921E-03,   1.2242786E-03
     +,   1.2639234E-03,   1.3041435E-03,   1.3448602E-03
     +,   1.3860037E-03,   1.4275163E-03,   1.4693375E-03
     +,   1.5114184E-03,   1.5537145E-03,   1.5961836E-03
     +,   1.6387735E-03,   1.6814227E-03,   1.7240602E-03
     +,   1.7665912E-03,   1.8088921E-03,   1.8508170E-03
     +,   1.8921935E-03,   1.9328208E-03,   1.9724839E-03
     +,   2.0109601E-03,   2.0480317E-03,   2.0835022E-03
     +,   2.1172117E-03,   2.1490562E-03,   2.1790054E-03
     +,   2.2071095E-03,   2.2335055E-03,   2.2584302E-03
     +,   2.2822071E-03,   2.3052380E-03,   2.3279928E-03
     +,   2.3509851E-03,   2.3747575E-03,   2.3998655E-03
     +,   2.4268641E-03,   2.4563023E-03,   2.4887230E-03
     +,   2.5246665E-03,   2.5646973E-03,   2.6094057E-03
     +,   2.6594335E-03,   2.7154791E-03,   2.7783180E-03
     +,   2.8487998E-03,   2.9278419E-03,   3.0164181E-03
     +,   3.1155501E-03,   3.2262830E-03,   3.3496644E-03
     +,   3.4867476E-03,   3.6385718E-03,   3.8061524E-03
     +,   3.9904770E-03,   4.1925418E-03,   4.4133347E-03
     +,   4.6538687E-03,   4.9151536E-03,   5.1982165E-03
     +,   5.5040540E-03,   5.8334875E-03,   6.1870776E-03
     +,   6.5649766E-03,   6.9666957E-03,   7.3910654E-03
     +,   7.8362469E-03,   8.2997680E-03,   8.7788133E-03
     +,   9.2704110E-03,   9.7717829E-03,   1.0280338E-02
     +,   1.0793347E-02,   1.1307551E-02,   1.1818380E-02
     +,   1.2319087E-02,   1.2800017E-02,   1.3248451E-02
     +,   1.3648820E-02,   1.3983702E-02,   1.4235234E-02
     +,   1.4386989E-02,   1.4425729E-02,   1.4342739E-02
     +,   1.4134898E-02,   1.3804698E-02,   1.3359925E-02
     +,   1.2812627E-02,   1.2177911E-02,   1.1472744E-02
     +,   1.0714649E-02,   9.9210162E-03,   9.1082603E-03
     +,   8.2916431E-03,   7.4848244E-03,   6.6999597E-03
     +,   5.9474097E-03,   5.2358448E-03,   4.5720302E-03
     +,   3.9608614E-03,   3.4054122E-03,   2.9068957E-03
     +,   2.4649242E-03,   2.0776156E-03,   1.7419569E-03
     +,   1.4540150E-03,   1.2093055E-03,   1.0030268E-03
     +,   8.3035970E-04,   6.8662444E-04,   5.6747987E-04
     +,   4.6898000E-04,   3.8766582E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_hatt104 = Yx/0.161325581395349
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5544918E-04,   1.6443114E-04
     +,   1.7379728E-04,   1.8355981E-04,   1.9373088E-04
     +,   2.0432303E-04,   2.1534842E-04,   2.2681885E-04
     +,   2.3874534E-04,   2.5113829E-04,   2.6400635E-04
     +,   2.7735645E-04,   2.9119360E-04,   3.0551999E-04
     +,   3.2033509E-04,   3.3563504E-04,   3.5141196E-04
     +,   3.6765420E-04,   3.8434571E-04,   4.0146566E-04
     +,   4.1898849E-04,   4.3688359E-04,   4.5511438E-04
     +,   4.7364103E-04,   4.9241586E-04,   5.1138870E-04
     +,   5.3050293E-04,   5.4969807E-04,   5.6891044E-04
     +,   5.8807258E-04,   6.0711592E-04,   6.2597188E-04
     +,   6.4457383E-04,   6.6285877E-04,   6.8077265E-04
     +,   6.9827156E-04,   7.1532797E-04,   7.3193462E-04
     +,   7.4811163E-04,   7.6390977E-04,   7.7942014E-04
     +,   7.9477805E-04,   8.1017037E-04,   8.2583871E-04
     +,   8.4208749E-04,   8.5928116E-04,   8.7784807E-04
     +,   8.9827483E-04,   9.2110201E-04,   9.4691309E-04
     +,   9.7632041E-04,   1.0099487E-03,   1.0484128E-03
     +,   1.0922969E-03,   1.1421214E-03,   1.1983259E-03
     +,   1.2612343E-03,   1.3310354E-03,   1.4077586E-03
     +,   1.4912599E-03,   1.5812123E-03,   1.6771031E-03
     +,   1.7782329E-03,   1.8837458E-03,   1.9926447E-03
     +,   2.1038055E-03,   2.2160530E-03,   2.3281605E-03
     +,   2.4389436E-03,   2.5472690E-03,   2.6521422E-03
     +,   2.7527260E-03,   2.8484042E-03,   2.9387935E-03
     +,   3.0237720E-03,   3.1034844E-03,   3.1783003E-03
     +,   3.2487845E-03,   3.3156460E-03,   3.3796318E-03
     +,   3.4414437E-03,   3.5016602E-03,   3.5606213E-03
     +,   3.6183770E-03,   3.6746331E-03,   3.7287641E-03
     +,   3.7797999E-03,   3.8265323E-03,   3.8675657E-03
     +,   3.9014644E-03,   3.9268332E-03,   3.9424482E-03
     +,   3.9473395E-03,   3.9408458E-03,   3.9226599E-03
     +,   3.8928168E-03,   3.8516684E-03,   3.7998287E-03
     +,   3.7381130E-03,   3.6674859E-03,   3.5889726E-03
     +,   3.5036467E-03,   3.4125671E-03,   3.3167861E-03
     +,   3.2173148E-03,   3.1151455E-03,   3.0112369E-03
     +,   2.9065383E-03,   2.8019510E-03,   2.6983172E-03
     +,   2.5964275E-03,   2.4969487E-03,   2.4004395E-03
     +,   2.3072858E-03,   2.2177338E-03,   2.1318404E-03
     +,   2.0495348E-03,   1.9706085E-03,   1.8947723E-03
     +,   1.8216899E-03,   1.7510225E-03,   1.6824730E-03
     +,   1.6158145E-03,   1.5509032E-03,   1.4876940E-03
     +,   1.4262396E-03,   1.3666622E-03,   1.3091498E-03
     +,   1.2539141E-03,   1.2011760E-03,   1.1511340E-03
     +,   1.1039507E-03,   1.0597293E-03,   1.0185186E-03
     +,   9.8029955E-04,   9.4499550E-04,   9.1248291E-04
     +,   8.8259706E-04,   8.5514580E-04,   8.2992302E-04
     +,   8.0672163E-04,   7.8534178E-04,   7.6559663E-04
     +,   7.4731890E-04,   7.3036726E-04,   7.1462098E-04
     +,   6.9998309E-04,   6.8637700E-04,   6.7374494E-04
     +,   6.6204066E-04,   6.5122976E-04,   6.4128469E-04
     +,   6.3218171E-04,   6.2389800E-04,   6.1641005E-04
     +,   6.0969288E-04,   6.0371758E-04,   5.9845299E-04
     +,   5.9386378E-04,   5.8991188E-04,   5.8655720E-04
     +,   5.8375800E-04,   5.8147148E-04,   5.7965505E-04
     +,   5.7826727E-04,   5.7726703E-04,   5.7661528E-04
     +,   5.7627622E-04,   5.7621504E-04,   5.7640090E-04
     +,   5.7680486E-04,   5.7740120E-04,   5.7816628E-04
     +,   5.7907979E-04,   5.8012252E-04,   5.8127881E-04
     +,   5.8253377E-04,   5.8387429E-04,   5.8528950E-04
     +,   5.8676867E-04,   5.8830273E-04,   5.8988348E-04
     +,   5.9150293E-04,   5.9315405E-04,   5.9483020E-04
     +,   5.9652497E-04,   5.9823249E-04,   5.9994718E-04
     +,   6.0166360E-04,   6.0337735E-04,   6.0508359E-04
     +,   6.0677866E-04,   6.0845976E-04,   6.1012403E-04
     +,   6.1176973E-04,   6.1339611E-04,   6.1500323E-04
     +,   6.1659183E-04,   6.1816361E-04,   6.1972125E-04
     +,   6.2126806E-04,   6.2280765E-04,   6.2434375E-04
     +,   6.2588108E-04,   6.2742323E-04,   6.2897365E-04
     +,   6.3053565E-04,   6.3211046E-04,   6.3369813E-04
     +,   6.3529774E-04,   6.3690537E-04,   6.3851528E-04
     +,   6.4011925E-04,   6.4170622E-04,   6.4326252E-04
     +,   6.4477162E-04,   6.4621447E-04,   6.4756884E-04
     +,   6.4881070E-04,   6.4991310E-04,   6.5084780E-04
     +,   6.5158436E-04,   6.5209181E-04,   6.5233908E-04
     +,   6.5229367E-04,   6.5192452E-04,   6.5120118E-04
     +,   6.5009500E-04,   6.4857939E-04,   6.4662943E-04
     +,   6.4422505E-04,   6.4134796E-04,   6.3798425E-04
     +,   6.3412427E-04,   6.2976242E-04,   6.2489801E-04
     +,   6.1953341E-04,   6.1367755E-04,   6.0734240E-04
     +,   6.0054398E-04,   5.9330283E-04,   5.8564282E-04
     +,   5.7759171E-04,   5.6917942E-04,   5.6043826E-04
     +,   5.5140234E-04,   5.4210878E-04,   5.3259352E-04
     +,   5.2289409E-04,   5.1304762E-04,   5.0309108E-04
     +,   4.9305963E-04,   4.8298822E-04,   4.7290945E-04
     +,   4.6285405E-04,   4.5285001E-04,   4.4292322E-04
     +,   4.3309742E-04,   4.2339266E-04,   4.1382632E-04
     +,   4.0441324E-04,   3.9516599E-04,   3.8609336E-04
     +,   3.7720197E-04,   3.6849652E-04,   3.5997893E-04
     +,   3.5164887E-04,   3.4350465E-04,   3.3554339E-04
     +,   3.2775977E-04,   3.2014778E-04,   3.1270081E-04
     +,   3.0541138E-04,   2.9827148E-04,   2.9127233E-04
     +,   2.8440618E-04,   2.7766408E-04,   2.7103833E-04
     +,   2.6452067E-04,   2.5810406E-04,   2.5178125E-04
     +,   2.4554619E-04,   2.3939287E-04,   2.3331662E-04
     +,   2.2731257E-04,   2.2137757E-04,   2.1550841E-04
     +,   2.0970240E-04,   2.0395839E-04,   1.9827469E-04
     +,   1.9265120E-04,   1.8708750E-04,   1.8158443E-04
     +,   1.7614241E-04,   1.7076304E-04,   1.6544751E-04
     +,   1.6019802E-04,   1.5501620E-04,   1.4990465E-04
     +,   1.4486548E-04,   1.3990141E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_hatt75 = Yx/0.0771842105263158
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2902818E-05,   5.5038054E-05
     +,   5.7295521E-05,   5.9681232E-05,   6.2201347E-05
     +,   6.4862208E-05,   6.7670480E-05,   7.0633047E-05
     +,   7.3757219E-05,   7.7050914E-05,   8.0522470E-05
     +,   8.4181018E-05,   8.8036541E-05,   9.2100010E-05
     +,   9.6383534E-05,   1.0090064E-04,   1.0566629E-04
     +,   1.1069722E-04,   1.1601199E-04,   1.2163129E-04
     +,   1.2757805E-04,   1.3387753E-04,   1.4055733E-04
     +,   1.4764813E-04,   1.5518222E-04,   1.6319528E-04
     +,   1.7172481E-04,   1.8081028E-04,   1.9049320E-04
     +,   2.0081601E-04,   2.1182183E-04,   2.2355380E-04
     +,   2.3605383E-04,   2.4936226E-04,   2.6351618E-04
     +,   2.7854886E-04,   2.9448810E-04,   3.1135543E-04
     +,   3.2916616E-04,   3.4792579E-04,   3.6763324E-04
     +,   3.8827720E-04,   4.0983892E-04,   4.3229177E-04
     +,   4.5560295E-04,   4.7973628E-04,   5.0465367E-04
     +,   5.3032039E-04,   5.5670779E-04,   5.8379921E-04
     +,   6.1159418E-04,   6.4011500E-04,   6.6941115E-04
     +,   6.9956703E-04,   7.3070283E-04,   7.6298387E-04
     +,   7.9662027E-04,   8.3187164E-04,   8.6904800E-04
     +,   9.0850884E-04,   9.5066353E-04,   9.9596777E-04
     +,   1.0449128E-03,   1.0980286E-03,   1.1558658E-03
     +,   1.2189774E-03,   1.2879134E-03,   1.3631795E-03
     +,   1.4452288E-03,   1.5344092E-03,   1.6309463E-03
     +,   1.7348848E-03,   1.8460782E-03,   1.9641351E-03
     +,   2.0884224E-03,   2.2180579E-03,   2.3519159E-03
     +,   2.4886688E-03,   2.6268559E-03,   2.7649484E-03
     +,   2.9014153E-03,   3.0348466E-03,   3.1640010E-03
     +,   3.2879114E-03,   3.4059044E-03,   3.5176782E-03
     +,   3.6232690E-03,   3.7231033E-03,   3.8179178E-03
     +,   3.9087669E-03,   3.9969287E-03,   4.0838448E-03
     +,   4.1709910E-03,   4.2597973E-03,   4.3514851E-03
     +,   4.4469358E-03,   4.5466293E-03,   4.6505318E-03
     +,   4.7581214E-03,   4.8684501E-03,   4.9803001E-03
     +,   5.0923731E-03,   5.2035293E-03,   5.3129517E-03
     +,   5.4202750E-03,   5.5254968E-03,   5.6287511E-03
     +,   5.7298993E-03,   5.8280514E-03,   5.9211152E-03
     +,   6.0054963E-03,   6.0761510E-03,   6.1269538E-03
     +,   6.1514964E-03,   6.1440216E-03,   6.1004702E-03
     +,   6.0192682E-03,   5.9017604E-03,   5.7521956E-03
     +,   5.5771489E-03,   5.3846193E-03,   5.1829540E-03
     +,   4.9797767E-03,   4.7811219E-03,   4.5909532E-03
     +,   4.4110888E-03,   4.2413948E-03,   4.0803445E-03
     +,   3.9255978E-03,   3.7746830E-03,   3.6254697E-03
     +,   3.4765638E-03,   3.3274184E-03,   3.1783413E-03
     +,   3.0302948E-03,   2.8846520E-03,   2.7429366E-03
     +,   2.6065516E-03,   2.4765965E-03,   2.3537609E-03
     +,   2.2383125E-03,   2.1301284E-03,   2.0287801E-03
     +,   1.9336499E-03,   1.8440590E-03,   1.7593367E-03
     +,   1.6789020E-03,   1.6023102E-03,   1.5292485E-03
     +,   1.4595328E-03,   1.3930802E-03,   1.3298835E-03
     +,   1.2699767E-03,   1.2134027E-03,   1.1601987E-03
     +,   1.1103872E-03,   1.0639636E-03,   1.0208930E-03
     +,   9.8111585E-04,   9.4455405E-04,   9.1110694E-04
     +,   8.8066165E-04,   8.5309398E-04,   8.2827179E-04
     +,   8.0605270E-04,   7.8628800E-04,   7.6882535E-04
     +,   7.5350754E-04,   7.4017345E-04,   7.2865922E-04
     +,   7.1880227E-04,   7.1044150E-04,   7.0341647E-04
     +,   6.9757324E-04,   6.9276150E-04,   6.8883813E-04
     +,   6.8566645E-04,   6.8311836E-04,   6.8107335E-04
     +,   6.7941903E-04,   6.7805202E-04,   6.7687832E-04
     +,   6.7581213E-04,   6.7477737E-04,   6.7370664E-04
     +,   6.7254278E-04,   6.7123713E-04,   6.6975056E-04
     +,   6.6805340E-04,   6.6612492E-04,   6.6395197E-04
     +,   6.6153082E-04,   6.5886462E-04,   6.5596326E-04
     +,   6.5284286E-04,   6.4952450E-04,   6.4603414E-04
     +,   6.4240076E-04,   6.3865550E-04,   6.3483143E-04
     +,   6.3096173E-04,   6.2708079E-04,   6.2321994E-04
     +,   6.1941030E-04,   6.1568030E-04,   6.1205553E-04
     +,   6.0855894E-04,   6.0520956E-04,   6.0202373E-04
     +,   5.9901294E-04,   5.9618650E-04,   5.9354887E-04
     +,   5.9110211E-04,   5.8884505E-04,   5.8677280E-04
     +,   5.8487890E-04,   5.8315392E-04,   5.8158650E-04
     +,   5.8016385E-04,   5.7887175E-04,   5.7769410E-04
     +,   5.7661504E-04,   5.7561736E-04,   5.7468354E-04
     +,   5.7379587E-04,   5.7293632E-04,   5.7208730E-04
     +,   5.7123060E-04,   5.7034905E-04,   5.6942430E-04
     +,   5.6843919E-04,   5.6737667E-04,   5.6621968E-04
     +,   5.6495128E-04,   5.6355423E-04,   5.6201220E-04
     +,   5.6030875E-04,   5.5842724E-04,   5.5635133E-04
     +,   5.5406563E-04,   5.5155403E-04,   5.4880133E-04
     +,   5.4579292E-04,   5.4251472E-04,   5.3895300E-04
     +,   5.3509581E-04,   5.3093128E-04,   5.2644947E-04
     +,   5.2164181E-04,   5.1650073E-04,   5.1102118E-04
     +,   5.0519872E-04,   4.9903261E-04,   4.9252296E-04
     +,   4.8567238E-04,   4.7848557E-04,   4.7096971E-04
     +,   4.6313458E-04,   4.5499127E-04,   4.4655360E-04
     +,   4.3783727E-04,   4.2886095E-04,   4.1964371E-04
     +,   4.1020682E-04,   4.0057374E-04,   3.9076828E-04
     +,   3.8081553E-04,   3.7074205E-04,   3.6057460E-04
     +,   3.5034030E-04,   3.4006604E-04,   3.2977940E-04
     +,   3.1950741E-04,   3.0927610E-04,   2.9911098E-04
     +,   2.8903686E-04,   2.7907675E-04,   2.6925327E-04
     +,   2.5958655E-04,   2.5009600E-04,   2.4079869E-04
     +,   2.3171061E-04,   2.2284494E-04,   2.1421413E-04
     +,   2.0582772E-04,   1.9769429E-04,   1.8982001E-04
     +,   1.8220922E-04,   1.7486527E-04,   1.6778881E-04
     +,   1.6098011E-04,   1.5443700E-04,   1.4815688E-04
     +,   1.4213519E-04,   1.3636707E-04,   1.3084586E-04
     +,   1.2556507E-04,   1.2051679E-04,   1.1569313E-04
     +,   1.1108522E-04,   1.0668447E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_hatt80 = Yx/0.0994
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.9885787E-05,   1.0449033E-04
     +,   1.0917507E-04,   1.1393138E-04,   1.1874994E-04
     +,   1.2362108E-04,   1.2853449E-04,   1.3347961E-04
     +,   1.3844541E-04,   1.4342078E-04,   1.4839439E-04
     +,   1.5335488E-04,   1.5829080E-04,   1.6319103E-04
     +,   1.6804467E-04,   1.7284125E-04,   1.7757074E-04
     +,   1.8222383E-04,   1.8679195E-04,   1.9126752E-04
     +,   1.9564386E-04,   1.9991562E-04,   2.0407853E-04
     +,   2.0813014E-04,   2.1206895E-04,   2.1589552E-04
     +,   2.1961203E-04,   2.2322245E-04,   2.2673247E-04
     +,   2.3014992E-04,   2.3348434E-04,   2.3674741E-04
     +,   2.3995258E-04,   2.4311534E-04,   2.4625292E-04
     +,   2.4938447E-04,   2.5253071E-04,   2.5571420E-04
     +,   2.5895881E-04,   2.6228986E-04,   2.6573424E-04
     +,   2.6931980E-04,   2.7307586E-04,   2.7703281E-04
     +,   2.8122243E-04,   2.8567750E-04,   2.9043254E-04
     +,   2.9552373E-04,   3.0098885E-04,   3.0686852E-04
     +,   3.1320544E-04,   3.2004577E-04,   3.2743887E-04
     +,   3.3543858E-04,   3.4410221E-04,   3.5349227E-04
     +,   3.6367535E-04,   3.7472241E-04,   3.8670795E-04
     +,   3.9970895E-04,   4.1380373E-04,   4.2906974E-04
     +,   4.4558014E-04,   4.6340321E-04,   4.8259762E-04
     +,   5.0320686E-04,   5.2525988E-04,   5.4876291E-04
     +,   5.7370163E-04,   6.0003344E-04,   6.2769285E-04
     +,   6.5658562E-04,   6.8659836E-04,   7.1759627E-04
     +,   7.4943696E-04,   7.8197644E-04,   8.1507873E-04
     +,   8.4863033E-04,   8.8255474E-04,   9.1682392E-04
     +,   9.5146487E-04,   9.8657480E-04,   1.0223184E-03
     +,   1.0589322E-03,   1.0967115E-03,   1.1360111E-03
     +,   1.1772186E-03,   1.2207503E-03,   1.2670277E-03
     +,   1.3164714E-03,   1.3694924E-03,   1.4264823E-03
     +,   1.4878155E-03,   1.5538536E-03,   1.6249393E-03
     +,   1.7013783E-03,   1.7834402E-03,   1.8713062E-03
     +,   1.9650480E-03,   2.0645643E-03,   2.1695492E-03
     +,   2.2794320E-03,   2.3933756E-03,   2.5102752E-03
     +,   2.6288398E-03,   2.7477301E-03,   2.8657636E-03
     +,   2.9822495E-03,   3.0973852E-03,   3.2126554E-03
     +,   3.3311888E-03,   3.4579849E-03,   3.5997871E-03
     +,   3.7646873E-03,   3.9612572E-03,   4.1974415E-03
     +,   4.4792276E-03,   4.8094802E-03,   5.1869792E-03
     +,   5.6061693E-03,   6.0574478E-03,   6.5281540E-03
     +,   7.0040300E-03,   7.4709831E-03,   7.9165380E-03
     +,   8.3308192E-03,   8.7067941E-03,   9.0394979E-03
     +,   9.3247741E-03,   9.5576439E-03,   9.7314063E-03
     +,   9.8375315E-03,   9.8672993E-03,   9.8142875E-03
     +,   9.6773580E-03,   9.4627999E-03,   9.1847479E-03
     +,   8.8633718E-03,   8.5213128E-03,   8.1792893E-03
     +,   7.8521762E-03,   7.5466516E-03,   7.2609494E-03
     +,   6.9867028E-03,   6.7122141E-03,   6.4259619E-03
     +,   6.1197374E-03,   5.7904664E-03,   5.4405434E-03
     +,   5.0768452E-03,   4.7089439E-03,   4.3470850E-03
     +,   4.0003955E-03,   3.6757288E-03,   3.3772097E-03
     +,   3.1064332E-03,   2.8629818E-03,   2.6451063E-03
     +,   2.4504021E-03,   2.2763226E-03,   2.1204432E-03
     +,   1.9806044E-03,   1.8549386E-03,   1.7418141E-03
     +,   1.6397615E-03,   1.5474439E-03,   1.4636329E-03
     +,   1.3872045E-03,   1.3171455E-03,   1.2525741E-03
     +,   1.1927612E-03,   1.1371227E-03,   1.0852159E-03
     +,   1.0367283E-03,   9.9145761E-04,   9.4927574E-04
     +,   9.1010774E-04,   8.7390648E-04,   8.4063015E-04
     +,   8.1021938E-04,   7.8259007E-04,   7.5762958E-04
     +,   7.3519076E-04,   7.1509526E-04,   6.9713732E-04
     +,   6.8109692E-04,   6.6674000E-04,   6.5383152E-04
     +,   6.4214092E-04,   6.3145137E-04,   6.2156358E-04
     +,   6.1230117E-04,   6.0351513E-04,   5.9508614E-04
     +,   5.8692362E-04,   5.7896908E-04,   5.7119294E-04
     +,   5.6359457E-04,   5.5619847E-04,   5.4905209E-04
     +,   5.4222270E-04,   5.3579337E-04,   5.2985828E-04
     +,   5.2451895E-04,   5.1988097E-04,   5.1604799E-04
     +,   5.1311916E-04,   5.1118521E-04,   5.1032461E-04
     +,   5.1060092E-04,   5.1205978E-04,   5.1472767E-04
     +,   5.1860930E-04,   5.2368751E-04,   5.2992284E-04
     +,   5.3725264E-04,   5.4559298E-04,   5.5483886E-04
     +,   5.6486705E-04,   5.7553663E-04,   5.8669318E-04
     +,   5.9817045E-04,   6.0979411E-04,   6.2138302E-04
     +,   6.3275703E-04,   6.4373593E-04,   6.5414514E-04
     +,   6.6381774E-04,   6.7259849E-04,   6.8034610E-04
     +,   6.8693556E-04,   6.9225993E-04,   6.9623161E-04
     +,   6.9878466E-04,   6.9987361E-04,   6.9947448E-04
     +,   6.9758407E-04,   6.9421926E-04,   6.8941584E-04
     +,   6.8322569E-04,   6.7571626E-04,   6.6696777E-04
     +,   6.5707130E-04,   6.4612523E-04,   6.3423417E-04
     +,   6.2150584E-04,   6.0804962E-04,   5.9397356E-04
     +,   5.7938183E-04,   5.6437711E-04,   5.4905395E-04
     +,   5.3350098E-04,   5.1780010E-04,   5.0202582E-04
     +,   4.8624378E-04,   4.7051135E-04,   4.5487937E-04
     +,   4.3939191E-04,   4.2408481E-04,   4.0898810E-04
     +,   3.9412719E-04,   3.7952288E-04,   3.6519085E-04
     +,   3.5114383E-04,   3.3739238E-04,   3.2394426E-04
     +,   3.1080504E-04,   2.9798021E-04,   2.8547394E-04
     +,   2.7328925E-04,   2.6142824E-04,   2.4989381E-04
     +,   2.3868817E-04,   2.2781287E-04,   2.1726907E-04
     +,   2.0705866E-04,   1.9718199E-04,   1.8764006E-04
     +,   1.7843254E-04,   1.6955945E-04,   1.6101926E-04
     +,   1.5281099E-04,   1.4493187E-04,   1.3737949E-04
     +,   1.3014981E-04,   1.2323904E-04,   1.1664207E-04
     +,   1.1035306E-04,   1.0436622E-04,   9.8674413E-05
     +,   9.3270697E-05,   8.8146902E-05,   8.3295090E-05
     +,   7.8706398E-05,   7.4372074E-05,   7.0282658E-05
     +,   6.6429035E-05,   6.2801337E-05,   5.9390124E-05
     +,   5.6185476E-05,   5.3177926E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_hatt85 = Yx/0.112
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0415783E-05,   5.2791576E-05
     +,   5.5243032E-05,   5.7767342E-05,   6.0361199E-05
     +,   6.3020765E-05,   6.5741617E-05,   6.8518879E-05
     +,   7.1347022E-05,   7.4220166E-05,   7.7131830E-05
     +,   8.0075064E-05,   8.3042483E-05,   8.6026310E-05
     +,   8.9018416E-05,   9.2010305E-05,   9.4993244E-05
     +,   9.7958306E-05,   1.0089639E-04,   1.0379829E-04
     +,   1.0665488E-04,   1.0945697E-04,   1.1219551E-04
     +,   1.1486190E-04,   1.1744741E-04,   1.1994402E-04
     +,   1.2234405E-04,   1.2464024E-04,   1.2682608E-04
     +,   1.2889557E-04,   1.3084355E-04,   1.3266561E-04
     +,   1.3435824E-04,   1.3591877E-04,   1.3734555E-04
     +,   1.3863794E-04,   1.3979631E-04,   1.4082214E-04
     +,   1.4171809E-04,   1.4248773E-04,   1.4313601E-04
     +,   1.4366893E-04,   1.4409368E-04,   1.4441858E-04
     +,   1.4465315E-04,   1.4480800E-04,   1.4489498E-04
     +,   1.4492695E-04,   1.4491794E-04,   1.4488307E-04
     +,   1.4483854E-04,   1.4480150E-04,   1.4479014E-04
     +,   1.4482370E-04,   1.4492222E-04,   1.4510677E-04
     +,   1.4539919E-04,   1.4582209E-04,   1.4639883E-04
     +,   1.4715343E-04,   1.4811047E-04,   1.4929508E-04
     +,   1.5073264E-04,   1.5244896E-04,   1.5446988E-04
     +,   1.5682120E-04,   1.5952883E-04,   1.6261803E-04
     +,   1.6611398E-04,   1.7004092E-04,   1.7442273E-04
     +,   1.7928187E-04,   1.8464042E-04,   1.9051862E-04
     +,   1.9693591E-04,   2.0391066E-04,   2.1145931E-04
     +,   2.1959680E-04,   2.2833739E-04,   2.3769404E-04
     +,   2.4767761E-04,   2.5829885E-04,   2.6956620E-04
     +,   2.8148835E-04,   2.9407145E-04,   3.0732187E-04
     +,   3.2124328E-04,   3.3583926E-04,   3.5110960E-04
     +,   3.6705303E-04,   3.8366509E-04,   4.0093614E-04
     +,   4.1885182E-04,   4.3739224E-04,   4.5653107E-04
     +,   4.7623168E-04,   4.9645099E-04,   5.1713357E-04
     +,   5.3821638E-04,   5.5962353E-04,   5.8127218E-04
     +,   6.0306827E-04,   6.2491291E-04,   6.4669957E-04
     +,   6.6832243E-04,   6.8967603E-04,   7.1065815E-04
     +,   7.3117594E-04,   7.5115071E-04,   7.7052275E-04
     +,   7.8925421E-04,   8.0734154E-04,   8.2481897E-04
     +,   8.4177445E-04,   8.5835648E-04,   8.7479647E-04
     +,   8.9141756E-04,   9.0865517E-04,   9.2706608E-04
     +,   9.4733236E-04,   9.7025878E-04,   9.9674717E-04
     +,   1.0277655E-03,   1.0643038E-03,   1.1073223E-03
     +,   1.1576987E-03,   1.2162117E-03,   1.2835313E-03
     +,   1.3602760E-03,   1.4470747E-03,   1.5446970E-03
     +,   1.6541504E-03,   1.7768076E-03,   1.9144336E-03
     +,   2.0692188E-03,   2.2437063E-03,   2.4406889E-03
     +,   2.6630682E-03,   2.9137200E-03,   3.1952898E-03
     +,   3.5100165E-03,   3.8596035E-03,   4.2452412E-03
     +,   4.6676965E-03,   5.1273508E-03,   5.6240433E-03
     +,   6.1562886E-03,   6.7199459E-03,   7.3069786E-03
     +,   7.9052141E-03,   8.4997192E-03,   9.0757543E-03
     +,   9.6219471E-03,   1.0131540E-02,   1.0600314E-02
     +,   1.1021925E-02,   1.1383677E-02,   1.1665776E-02
     +,   1.1845466E-02,   1.1904383E-02,   1.1834862E-02
     +,   1.1641613E-02,   1.1338394E-02,   1.0942209E-02
     +,   1.0468994E-02,   9.9332016E-03,   9.3505709E-03
     +,   8.7412810E-03,   8.1308000E-03,   7.5473455E-03
     +,   7.0171384E-03,   6.5592155E-03,   6.1824387E-03
     +,   5.8854148E-03,   5.6590121E-03,   5.4900469E-03
     +,   5.3647882E-03,   5.2710245E-03,   5.1986077E-03
     +,   5.1388033E-03,   5.0833593E-03,   5.0240601E-03
     +,   4.9529406E-03,   4.8631034E-03,   4.7497791E-03
     +,   4.6110949E-03,   4.4482895E-03,   4.2652884E-03
     +,   4.0678387E-03,   3.8624343E-03,   3.6552274E-03
     +,   3.4512577E-03,   3.2540569E-03,   3.0656080E-03
     +,   2.8866231E-03,   2.7169955E-03,   2.5563142E-03
     +,   2.4042265E-03,   2.2606803E-03,   2.1259780E-03
     +,   2.0007021E-03,   1.8855194E-03,   1.7809789E-03
     +,   1.6873539E-03,   1.6045512E-03,   1.5320696E-03
     +,   1.4690555E-03,   1.4144009E-03,   1.3668498E-03
     +,   1.3251164E-03,   1.2879774E-03,   1.2543522E-03
     +,   1.2233397E-03,   1.1942259E-03,   1.1664866E-03
     +,   1.1397608E-03,   1.1138215E-03,   1.0885422E-03
     +,   1.0638649E-03,   1.0397776E-03,   1.0162861E-03
     +,   9.9340407E-04,   9.7114308E-04,   9.4950560E-04
     +,   9.2848536E-04,   9.0806599E-04,   8.8822818E-04
     +,   8.6894864E-04,   8.5020385E-04,   8.3197019E-04
     +,   8.1422896E-04,   7.9696398E-04,   7.8015967E-04
     +,   7.6380232E-04,   7.4788032E-04,   7.3237886E-04
     +,   7.1728195E-04,   7.0257130E-04,   6.8822550E-04
     +,   6.7421893E-04,   6.6052290E-04,   6.4710807E-04
     +,   6.3394161E-04,   6.2099105E-04,   6.0822250E-04
     +,   5.9560477E-04,   5.8310840E-04,   5.7070557E-04
     +,   5.5837206E-04,   5.4608815E-04,   5.3383748E-04
     +,   5.2160816E-04,   5.0939241E-04,   4.9718790E-04
     +,   4.8499447E-04,   4.7281667E-04,   4.6066268E-04
     +,   4.4854375E-04,   4.3647338E-04,   4.2446668E-04
     +,   4.1254179E-04,   4.0071760E-04,   3.8901318E-04
     +,   3.7744810E-04,   3.6604301E-04,   3.5481699E-04
     +,   3.4378847E-04,   3.3297541E-04,   3.2239495E-04
     +,   3.1206181E-04,   3.0198909E-04,   2.9218887E-04
     +,   2.8267142E-04,   2.7344428E-04,   2.6451328E-04
     +,   2.5588291E-04,   2.4755485E-04,   2.3952979E-04
     +,   2.3180556E-04,   2.2437933E-04,   2.1724554E-04
     +,   2.1039824E-04,   2.0382898E-04,   1.9752911E-04
     +,   1.9148814E-04,   1.8569537E-04,   1.8013873E-04
     +,   1.7480573E-04,   1.6968399E-04,   1.6476016E-04
     +,   1.6002150E-04,   1.5545466E-04,   1.5104729E-04
     +,   1.4678652E-04,   1.4266063E-04,   1.3865791E-04
     +,   1.3476772E-04,   1.3097965E-04,   1.2728457E-04
     +,   1.2367360E-04,   1.2013914E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_hatt90 = Yx/0.1235
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5878370E-04,   1.6419697E-04
     +,   1.6952108E-04,   1.7473446E-04,   1.7981519E-04
     +,   1.8474176E-04,   1.8949280E-04,   1.9404762E-04
     +,   1.9838595E-04,   2.0248884E-04,   2.0633794E-04
     +,   2.0991641E-04,   2.1320865E-04,   2.1620060E-04
     +,   2.1888006E-04,   2.2123638E-04,   2.2326103E-04
     +,   2.2494729E-04,   2.2629075E-04,   2.2728890E-04
     +,   2.2794164E-04,   2.2825069E-04,   2.2822028E-04
     +,   2.2785651E-04,   2.2716774E-04,   2.2616418E-04
     +,   2.2485811E-04,   2.2326341E-04,   2.2139587E-04
     +,   2.1927276E-04,   2.1691259E-04,   2.1433526E-04
     +,   2.1156187E-04,   2.0861415E-04,   2.0551485E-04
     +,   2.0228699E-04,   1.9895419E-04,   1.9554025E-04
     +,   1.9206878E-04,   1.8856380E-04,   1.8504838E-04
     +,   1.8154571E-04,   1.7807816E-04,   1.7466741E-04
     +,   1.7133448E-04,   1.6809942E-04,   1.6498122E-04
     +,   1.6199792E-04,   1.5916620E-04,   1.5650205E-04
     +,   1.5401964E-04,   1.5173219E-04,   1.4965165E-04
     +,   1.4778847E-04,   1.4615200E-04,   1.4475016E-04
     +,   1.4358963E-04,   1.4267582E-04,   1.4201288E-04
     +,   1.4160367E-04,   1.4144997E-04,   1.4155223E-04
     +,   1.4190981E-04,   1.4252106E-04,   1.4338319E-04
     +,   1.4449228E-04,   1.4584365E-04,   1.4743139E-04
     +,   1.4924900E-04,   1.5128884E-04,   1.5354260E-04
     +,   1.5600106E-04,   1.5865466E-04,   1.6149257E-04
     +,   1.6450389E-04,   1.6767709E-04,   1.7100001E-04
     +,   1.7446009E-04,   1.7804457E-04,   1.8174076E-04
     +,   1.8553526E-04,   1.8941522E-04,   1.9336751E-04
     +,   1.9737949E-04,   2.0143866E-04,   2.0553333E-04
     +,   2.0965197E-04,   2.1378430E-04,   2.1792061E-04
     +,   2.2205242E-04,   2.2617269E-04,   2.3027528E-04
     +,   2.3435561E-04,   2.3841106E-04,   2.4244060E-04
     +,   2.4644469E-04,   2.5042635E-04,   2.5438980E-04
     +,   2.5834190E-04,   2.6229100E-04,   2.6624789E-04
     +,   2.7022505E-04,   2.7423661E-04,   2.7829880E-04
     +,   2.8242910E-04,   2.8664683E-04,   2.9097212E-04
     +,   2.9542594E-04,   3.0003054E-04,   3.0480855E-04
     +,   3.0978225E-04,   3.1497492E-04,   3.2040855E-04
     +,   3.2610571E-04,   3.3208707E-04,   3.3837362E-04
     +,   3.4498435E-04,   3.5193763E-04,   3.5925012E-04
     +,   3.6693754E-04,   3.7501418E-04,   3.8349224E-04
     +,   3.9238256E-04,   4.0169500E-04,   4.1143780E-04
     +,   4.2161680E-04,   4.3223726E-04,   4.4330143E-04
     +,   4.5481164E-04,   4.6676610E-04,   4.7916305E-04
     +,   4.9199676E-04,   5.0526176E-04,   5.1894819E-04
     +,   5.3304597E-04,   5.4754328E-04,   5.6242722E-04
     +,   5.7768286E-04,   5.9329852E-04,   6.0926354E-04
     +,   6.2556920E-04,   6.4221112E-04,   6.5919186E-04
     +,   6.7652162E-04,   6.9421664E-04,   7.1230414E-04
     +,   7.3082111E-04,   7.4981182E-04,   7.6932850E-04
     +,   7.8943156E-04,   8.1018440E-04,   8.3165197E-04
     +,   8.5389736E-04,   8.7698392E-04,   9.0097322E-04
     +,   9.2592422E-04,   9.5189968E-04,   9.7897253E-04
     +,   1.0072332E-03,   1.0367911E-03,   1.0677902E-03
     +,   1.1004067E-03,   1.1348487E-03,   1.1713506E-03
     +,   1.2101718E-03,   1.2515859E-03,   1.2958869E-03
     +,   1.3434072E-03,   1.3945724E-03,   1.4499758E-03
     +,   1.5104729E-03,   1.5773077E-03,   1.6522207E-03
     +,   1.7375137E-03,   1.8360164E-03,   1.9509949E-03
     +,   2.0859132E-03,   2.2441011E-03,   2.4284190E-03
     +,   2.6409707E-03,   2.8829745E-03,   3.1548718E-03
     +,   3.4567809E-03,   3.7892191E-03,   4.1539241E-03
     +,   4.5546177E-03,   4.9975878E-03,   5.4919375E-03
     +,   6.0494579E-03,   6.6837668E-03,   7.4086459E-03
     +,   8.2345065E-03,   9.1632092E-03,   1.0182224E-02
     +,   1.1260414E-02,   1.2348070E-02,   1.3382643E-02
     +,   1.4299630E-02,   1.5044569E-02,   1.5581964E-02
     +,   1.5898595E-02,   1.6001824E-02,   1.5914600E-02
     +,   1.5669964E-02,   1.5305975E-02,   1.4860435E-02
     +,   1.4365680E-02,   1.3843518E-02,   1.3302618E-02
     +,   1.2739893E-02,   1.2145784E-02,   1.1511654E-02
     +,   1.0836037E-02,   1.0127398E-02,   9.4029326E-03
     +,   8.6847292E-03,   7.9951473E-03,   7.3532932E-03
     +,   6.7730984E-03,   6.2626633E-03,   5.8240388E-03
     +,   5.4536336E-03,   5.1429789E-03,   4.8800055E-03
     +,   4.6508661E-03,   4.4419742E-03,   4.2417841E-03
     +,   4.0418953E-03,   3.8374378E-03,   3.6267976E-03
     +,   3.4109079E-03,   3.1923482E-03,   2.9744967E-03
     +,   2.7608795E-03,   2.5547408E-03,   2.3587253E-03
     +,   2.1747921E-03,   2.0041987E-03,   1.8475516E-03
     +,   1.7048814E-03,   1.5757785E-03,   1.4595115E-03
     +,   1.3551346E-03,   1.2615821E-03,   1.1777580E-03
     +,   1.1026050E-03,   1.0351370E-03,   9.7445992E-04
     +,   9.1978413E-04,   8.7042421E-04,   8.2577753E-04
     +,   7.8531064E-04,   7.4854761E-04,   7.1505271E-04
     +,   6.8441947E-04,   6.5626681E-04,   6.3024194E-04
     +,   6.0601690E-04,   5.8329239E-04,   5.6180137E-04
     +,   5.4131413E-04,   5.2163703E-04,   5.0261180E-04
     +,   4.8411428E-04,   4.6605361E-04,   4.4836427E-04
     +,   4.3100378E-04,   4.1394916E-04,   3.9719159E-04
     +,   3.8073186E-04,   3.6457760E-04,   3.4874291E-04
     +,   3.3324343E-04,   3.1809637E-04,   3.0331829E-04
     +,   2.8892703E-04,   2.7493748E-04,   2.6136488E-04
     +,   2.4822113E-04,   2.3551831E-04,   2.2326465E-04
     +,   2.1146817E-04,   2.0013341E-04,   1.8926403E-04
     +,   1.7886044E-04,   1.6892212E-04,   1.5944567E-04
     +,   1.5042565E-04,   1.4185553E-04,   1.3372619E-04
     +,   1.2602775E-04,   1.1874806E-04,   1.1187465E-04
     +,   1.0539308E-04,   9.9289035E-05,   9.3546711E-05
     +,   8.8150540E-05,   8.3084051E-05,   7.8331221E-05
     +,   7.3875512E-05,   6.9701033E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_hatt95 = Yx/0.1375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8319701E-05,   2.8964601E-05
     +,   2.9600709E-05,   3.0226958E-05,   3.0842315E-05
     +,   3.1445765E-05,   3.2036321E-05,   3.2613018E-05
     +,   3.3174947E-05,   3.3721226E-05,   3.4251025E-05
     +,   3.4763565E-05,   3.5258094E-05,   3.5733960E-05
     +,   3.6190533E-05,   3.6627269E-05,   3.7043683E-05
     +,   3.7439357E-05,   3.7813956E-05,   3.8167218E-05
     +,   3.8498954E-05,   3.8809056E-05,   3.9097496E-05
     +,   3.9364360E-05,   3.9609778E-05,   3.9833998E-05
     +,   4.0037336E-05,   4.0220220E-05,   4.0383158E-05
     +,   4.0526746E-05,   4.0651692E-05,   4.0758798E-05
     +,   4.0848936E-05,   4.0923118E-05,   4.0982417E-05
     +,   4.1028019E-05,   4.1061219E-05,   4.1083422E-05
     +,   4.1096126E-05,   4.1100935E-05,   4.1099593E-05
     +,   4.1093888E-05,   4.1085816E-05,   4.1077419E-05
     +,   4.1070933E-05,   4.1068655E-05,   4.1073079E-05
     +,   4.1086802E-05,   4.1112613E-05,   4.1153438E-05
     +,   4.1212377E-05,   4.1292740E-05,   4.1398001E-05
     +,   4.1531872E-05,   4.1698295E-05,   4.1901472E-05
     +,   4.2145839E-05,   4.2436186E-05,   4.2777592E-05
     +,   4.3175514E-05,   4.3635744E-05,   4.4164564E-05
     +,   4.4768643E-05,   4.5455188E-05,   4.6231959E-05
     +,   4.7107209E-05,   4.8089889E-05,   4.9189559E-05
     +,   5.0416533E-05,   5.1781699E-05,   5.3296968E-05
     +,   5.4974698E-05,   5.6828372E-05,   5.8871985E-05
     +,   6.1120452E-05,   6.3589541E-05,   6.6295499E-05
     +,   6.9255235E-05,   7.2486255E-05,   7.6006661E-05
     +,   7.9834368E-05,   8.3987848E-05,   8.8484994E-05
     +,   9.3343770E-05,   9.8580997E-05,   1.0421318E-04
     +,   1.1025478E-04,   1.1671962E-04,   1.2361853E-04
     +,   1.3096082E-04,   1.3875325E-04,   1.4699905E-04
     +,   1.5569810E-04,   1.6484744E-04,   1.7444023E-04
     +,   1.8446498E-04,   1.9490738E-04,   2.0574793E-04
     +,   2.1696459E-04,   2.2853026E-04,   2.4041646E-04
     +,   2.5258996E-04,   2.6501715E-04,   2.7766169E-04
     +,   2.9048760E-04,   3.0345962E-04,   3.1654321E-04
     +,   3.2970670E-04,   3.4292345E-04,   3.5617212E-04
     +,   3.6943718E-04,   3.8271284E-04,   3.9600139E-04
     +,   4.0931735E-04,   4.2268599E-04,   4.3614651E-04
     +,   4.4975095E-04,   4.6356604E-04,   4.7767261E-04
     +,   4.9216510E-04,   5.0715223E-04,   5.2275328E-04
     +,   5.3909689E-04,   5.5632106E-04,   5.7456730E-04
     +,   5.9397530E-04,   6.1468268E-04,   6.3681428E-04
     +,   6.6048250E-04,   6.8577327E-04,   7.1274780E-04
     +,   7.4142904E-04,   7.7180186E-04,   8.0380059E-04
     +,   8.3731173E-04,   8.7216863E-04,   9.0814638E-04
     +,   9.4496668E-04,   9.8230282E-04,   1.0197822E-03
     +,   1.0569943E-03,   1.0935004E-03,   1.1288504E-03
     +,   1.1625942E-03,   1.1942929E-03,   1.2235409E-03
     +,   1.2499763E-03,   1.2732947E-03,   1.2932640E-03
     +,   1.3097302E-03,   1.3226271E-03,   1.3319760E-03
     +,   1.3378874E-03,   1.3405527E-03,   1.3402438E-03
     +,   1.3372959E-03,   1.3320983E-03,   1.3250806E-03
     +,   1.3167005E-03,   1.3074318E-03,   1.2977519E-03
     +,   1.2881362E-03,   1.2790558E-03,   1.2709725E-03
     +,   1.2643485E-03,   1.2596500E-03,   1.2573585E-03
     +,   1.2579904E-03,   1.2621066E-03,   1.2703392E-03
     +,   1.2834109E-03,   1.3021580E-03,   1.3275637E-03
     +,   1.3607939E-03,   1.4032432E-03,   1.4566039E-03
     +,   1.5229555E-03,   1.6048726E-03,   1.7055552E-03
     +,   1.8289490E-03,   1.9798095E-03,   2.1636386E-03
     +,   2.3865239E-03,   2.6549015E-03,   2.9753798E-03
     +,   3.3548102E-03,   3.8008883E-03,   4.3230457E-03
     +,   4.9330001E-03,   5.6437501E-03,   6.4665051E-03
     +,   7.4059032E-03,   8.4571280E-03,   9.6100215E-03
     +,   1.0862561E-02,   1.2237729E-02,   1.3789693E-02
     +,   1.5585004E-02,   1.7660724E-02,   1.9988932E-02
     +,   2.2488061E-02,   2.5091914E-02,   2.7824186E-02
     +,   3.0793674E-02,   3.4092940E-02,   3.7687514E-02
     +,   4.1364379E-02,   4.4754371E-02,   4.7519777E-02
     +,   4.9659099E-02,   5.1534243E-02,   5.3475641E-02
     +,   5.5368491E-02,   5.6734253E-02,   5.7266060E-02
     +,   5.7044223E-02,   5.6171719E-02,   5.4561734E-02
     +,   5.2228373E-02,   4.9575139E-02,   4.7131896E-02
     +,   4.5017723E-02,   4.2917725E-02,   4.0566746E-02
     +,   3.8021509E-02,   3.5499521E-02,   3.3138465E-02
     +,   3.0930236E-02,   2.8804796E-02,   2.6710734E-02
     +,   2.4619874E-02,   2.2528455E-02,   2.0494580E-02
     +,   1.8643575E-02,   1.7101353E-02,   1.5912279E-02
     +,   1.5014173E-02,   1.4278924E-02,   1.3578506E-02
     +,   1.2834053E-02,   1.2030320E-02,   1.1200866E-02
     +,   1.0399736E-02,   9.6746320E-03,   9.0509793E-03
     +,   8.5289013E-03,   8.0896718E-03,   7.7060750E-03
     +,   7.3516057E-03,   7.0060878E-03,   6.6573261E-03
     +,   6.3002585E-03,   5.9349551E-03,   5.5644801E-03
     +,   5.1932815E-03,   4.8261858E-03,   4.4678706E-03
     +,   4.1225841E-03,   3.7939234E-03,   3.4848053E-03
     +,   3.1974267E-03,   2.9332312E-03,   2.6929262E-03
     +,   2.4765346E-03,   2.2834893E-03,   2.1126501E-03
     +,   1.9624052E-03,   1.8307683E-03,   1.7154678E-03
     +,   1.6140632E-03,   1.5240757E-03,   1.4431141E-03
     +,   1.3689732E-03,   1.2997172E-03,   1.2337348E-03
     +,   1.1697720E-03,   1.1069163E-03,   1.0445910E-03
     +,   9.8249572E-04,   9.2058058E-04,   8.5897493E-04
     +,   7.9795258E-04,   7.3786767E-04,   6.7912944E-04
     +,   6.2214816E-04,   5.6732242E-04,   5.1500375E-04
     +,   4.6548693E-04,   4.1900415E-04,   3.7571052E-04
     +,   3.3569569E-04,   2.9897675E-04,   2.6551521E-04
     +,   2.3521493E-04,   2.0794175E-04,   1.8352397E-04
     +,   1.6176996E-04,   1.4247031E-04,   1.2541145E-04
     +,   1.1037762E-04,   9.7160664E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt100 = Yx/0.4368
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5962607E-06,   7.7118366E-06
     +,   7.8293033E-06,   7.9488709E-06,   8.0707750E-06
     +,   8.1952639E-06,   8.3225978E-06,   8.4530629E-06
     +,   8.5869560E-06,   8.7245962E-06,   8.8663210E-06
     +,   9.0124804E-06,   9.1634447E-06,   9.3196077E-06
     +,   9.4813768E-06,   9.6491749E-06,   9.8234486E-06
     +,   1.0004659E-05,   1.0193287E-05,   1.0389830E-05
     +,   1.0594799E-05,   1.0808727E-05,   1.1032152E-05
     +,   1.1265648E-05,   1.1509772E-05,   1.1765123E-05
     +,   1.2032297E-05,   1.2311902E-05,   1.2604557E-05
     +,   1.2910890E-05,   1.3231535E-05,   1.3567132E-05
     +,   1.3918320E-05,   1.4285744E-05,   1.4670049E-05
     +,   1.5071871E-05,   1.5491847E-05,   1.5930600E-05
     +,   1.6388762E-05,   1.6866921E-05,   1.7365694E-05
     +,   1.7885628E-05,   1.8427292E-05,   1.8991213E-05
     +,   1.9577898E-05,   2.0187823E-05,   2.0821426E-05
     +,   2.1479127E-05,   2.2161290E-05,   2.2868249E-05
     +,   2.3600292E-05,   2.4357661E-05,   2.5140540E-05
     +,   2.5949104E-05,   2.6783411E-05,   2.7643513E-05
     +,   2.8529403E-05,   2.9440998E-05,   3.0378158E-05
     +,   3.1340722E-05,   3.2328437E-05,   3.3341021E-05
     +,   3.4378118E-05,   3.5439356E-05,   3.6524350E-05
     +,   3.7632577E-05,   3.8763661E-05,   3.9917020E-05
     +,   4.1092258E-05,   4.2288844E-05,   4.3506436E-05
     +,   4.4744578E-05,   4.6003075E-05,   4.7281694E-05
     +,   4.8580419E-05,   4.9899467E-05,   5.1239200E-05
     +,   5.2600179E-05,   5.3983411E-05,   5.5390316E-05
     +,   5.6822493E-05,   5.8282360E-05,   5.9772556E-05
     +,   6.1296632E-05,   6.2858628E-05,   6.4463493E-05
     +,   6.6116867E-05,   6.7825466E-05,   6.9596761E-05
     +,   7.1439405E-05,   7.3363110E-05,   7.5378528E-05
     +,   7.7497447E-05,   7.9732868E-05,   8.2098770E-05
     +,   8.4610037E-05,   8.7282642E-05,   9.0133035E-05
     +,   9.3178598E-05,   9.6436706E-05,   9.9925288E-05
     +,   1.0366173E-04,   1.0766325E-04,   1.1194582E-04
     +,   1.1652448E-04,   1.2141257E-04,   1.2662100E-04
     +,   1.3215801E-04,   1.3802909E-04,   1.4423617E-04
     +,   1.5077654E-04,   1.5764413E-04,   1.6482701E-04
     +,   1.7230940E-04,   1.8006912E-04,   1.8807992E-04
     +,   1.9630908E-04,   2.0471981E-04,   2.1326938E-04
     +,   2.2191113E-04,   2.3059464E-04,   2.3926522E-04
     +,   2.4786565E-04,   2.5633728E-04,   2.6462044E-04
     +,   2.7265475E-04,   2.8038214E-04,   2.8774518E-04
     +,   2.9469086E-04,   3.0116949E-04,   3.0713700E-04
     +,   3.1255514E-04,   3.1739258E-04,   3.2162506E-04
     +,   3.2523679E-04,   3.2822005E-04,   3.3057533E-04
     +,   3.3231158E-04,   3.3344643E-04,   3.3400478E-04
     +,   3.3401928E-04,   3.3352908E-04,   3.3257954E-04
     +,   3.3122039E-04,   3.2950606E-04,   3.2749356E-04
     +,   3.2524191E-04,   3.2281101E-04,   3.2026073E-04
     +,   3.1764983E-04,   3.1503499E-04,   3.1247054E-04
     +,   3.1000757E-04,   3.0769370E-04,   3.0557282E-04
     +,   3.0368514E-04,   3.0206781E-04,   3.0075491E-04
     +,   2.9977862E-04,   2.9917029E-04,   2.9896165E-04
     +,   2.9918636E-04,   2.9988217E-04,   3.0109251E-04
     +,   3.0286962E-04,   3.0527660E-04,   3.0839076E-04
     +,   3.1230616E-04,   3.1713807E-04,   3.2302583E-04
     +,   3.3013642E-04,   3.3866864E-04,   3.4885752E-04
     +,   3.6097757E-04,   3.7534631E-04,   3.9232802E-04
     +,   4.1233690E-04,   4.3583702E-04,   4.6334372E-04
     +,   4.9542618E-04,   5.3270528E-04,   5.7585211E-04
     +,   6.2559079E-04,   6.8270846E-04,   7.4806547E-04
     +,   8.2260958E-04,   9.0740394E-04,   1.0036604E-03
     +,   1.1127513E-03,   1.2361947E-03,   1.3756178E-03
     +,   1.5326404E-03,   1.7086667E-03,   1.9046527E-03
     +,   2.1208676E-03,   2.3567332E-03,   2.6108949E-03
     +,   2.8817842E-03,   3.1687382E-03,   3.4737480E-03
     +,   3.8036020E-03,   4.1719940E-03,   4.6007647E-03
     +,   5.1194113E-03,   5.7625473E-03,   6.5659205E-03
     +,   7.5614229E-03,   8.7707154E-03,   1.0195710E-02
     +,   1.1806567E-02,   1.3538373E-02,   1.5317519E-02
     +,   1.7120188E-02,   1.9010216E-02,   2.1080989E-02
     +,   2.3318749E-02,   2.5545159E-02,   2.7555482E-02
     +,   2.9334839E-02,   3.1122154E-02,   3.3251781E-02
     +,   3.5891309E-02,   3.8859643E-02,   4.1712672E-02
     +,   4.4085808E-02,   4.5987546E-02,   4.7746751E-02
     +,   4.9560543E-02,   5.1100437E-02,   5.1899068E-02
     +,   5.2089691E-02,   5.2128848E-02,   5.1993940E-02
     +,   5.1509980E-02,   5.0839473E-02,   5.0021671E-02
     +,   4.8846412E-02,   4.7107115E-02,   4.4514686E-02
     +,   4.0976133E-02,   3.7161611E-02,   3.4133043E-02
     +,   3.2188766E-02,   3.0570304E-02,   2.8450228E-02
     +,   2.5778890E-02,   2.3078497E-02,   2.0802259E-02
     +,   1.9049110E-02,   1.7672069E-02,   1.6477434E-02
     +,   1.5345408E-02,   1.4247261E-02,   1.3197029E-02
     +,   1.2197777E-02,   1.1226806E-02,   1.0256964E-02
     +,   9.2826672E-03,   8.3267996E-03,   7.4281087E-03
     +,   6.6231289E-03,   5.9344317E-03,   5.3683575E-03
     +,   4.9184482E-03,   4.5700837E-03,   4.3040109E-03
     +,   4.0988964E-03,   3.9333748E-03,   3.7878733E-03
     +,   3.6461947E-03,   3.4965149E-03,   3.3316955E-03
     +,   3.1488675E-03,   2.9486069E-03,   2.7339263E-03
     +,   2.5093330E-03,   2.2799491E-03,   2.0509525E-03
     +,   1.8270869E-03,   1.6124556E-03,   1.4103286E-03
     +,   1.2231511E-03,   1.0525092E-03,   8.9924101E-04
     +,   7.6348142E-04,   6.4481329E-04,   5.4235233E-04
     +,   4.5488603E-04,   3.8099536E-04,   3.1914198E-04
     +,   2.6777652E-04,   2.2539248E-04,   1.9059122E-04
     +,   1.6210282E-04,   1.3881216E-04,   1.1975536E-04
     +,   1.0412081E-04,   9.1232709E-05,   8.0540187E-05
     +,   7.1597540E-05,   6.4050546E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt104 = Yx/0.408
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.6569656E-06,   1.0050280E-05
     +,   1.0456480E-05,   1.0875784E-05,   1.1308430E-05
     +,   1.1754639E-05,   1.2214648E-05,   1.2688683E-05
     +,   1.3176972E-05,   1.3679778E-05,   1.4197329E-05
     +,   1.4729884E-05,   1.5277712E-05,   1.5841080E-05
     +,   1.6420287E-05,   1.7015633E-05,   1.7627444E-05
     +,   1.8256073E-05,   1.8901881E-05,   1.9565266E-05
     +,   2.0246654E-05,   2.0946494E-05,   2.1665268E-05
     +,   2.2403530E-05,   2.3161789E-05,   2.3940682E-05
     +,   2.4740837E-05,   2.5562933E-05,   2.6407690E-05
     +,   2.7275884E-05,   2.8168311E-05,   2.9085830E-05
     +,   3.0029336E-05,   3.0999759E-05,   3.1998079E-05
     +,   3.3025302E-05,   3.4082448E-05,   3.5170586E-05
     +,   3.6290850E-05,   3.7444268E-05,   3.8632017E-05
     +,   3.9855193E-05,   4.1114890E-05,   4.2412226E-05
     +,   4.3748256E-05,   4.5124048E-05,   4.6540568E-05
     +,   4.7998779E-05,   4.9499551E-05,   5.1043688E-05
     +,   5.2631913E-05,   5.4264849E-05,   5.5942975E-05
     +,   5.7666814E-05,   5.9436476E-05,   6.1252198E-05
     +,   6.3114021E-05,   6.5021755E-05,   6.6975153E-05
     +,   6.8973764E-05,   7.1017050E-05,   7.3104311E-05
     +,   7.5234588E-05,   7.7406978E-05,   7.9620462E-05
     +,   8.1873673E-05,   8.4165484E-05,   8.6494380E-05
     +,   8.8859073E-05,   9.1257964E-05,   9.3689734E-05
     +,   9.6152857E-05,   9.8646029E-05,   1.0116787E-04
     +,   1.0371715E-04,   1.0629300E-04,   1.0889440E-04
     +,   1.1152058E-04,   1.1417115E-04,   1.1684597E-04
     +,   1.1954492E-04,   1.2226852E-04,   1.2501716E-04
     +,   1.2779199E-04,   1.3059404E-04,   1.3342506E-04
     +,   1.3628669E-04,   1.3918118E-04,   1.4211070E-04
     +,   1.4507800E-04,   1.4808580E-04,   1.5113696E-04
     +,   1.5423431E-04,   1.5738090E-04,   1.6057970E-04
     +,   1.6383329E-04,   1.6714455E-04,   1.7051544E-04
     +,   1.7394811E-04,   1.7744381E-04,   1.8100376E-04
     +,   1.8462799E-04,   1.8831632E-04,   1.9206748E-04
     +,   1.9587961E-04,   1.9974991E-04,   2.0367462E-04
     +,   2.0764882E-04,   2.1166689E-04,   2.1572235E-04
     +,   2.1980719E-04,   2.2391294E-04,   2.2802988E-04
     +,   2.3214772E-04,   2.3625493E-04,   2.4033972E-04
     +,   2.4438917E-04,   2.4839022E-04,   2.5232919E-04
     +,   2.5619206E-04,   2.5996499E-04,   2.6363379E-04
     +,   2.6718422E-04,   2.7060279E-04,   2.7387636E-04
     +,   2.7699198E-04,   2.7993790E-04,   2.8270282E-04
     +,   2.8527688E-04,   2.8765065E-04,   2.8981650E-04
     +,   2.9176779E-04,   2.9349944E-04,   2.9500737E-04
     +,   2.9628942E-04,   2.9734484E-04,   2.9817407E-04
     +,   2.9877937E-04,   2.9916430E-04,   2.9933391E-04
     +,   2.9929442E-04,   2.9905364E-04,   2.9862046E-04
     +,   2.9800486E-04,   2.9721810E-04,   2.9627225E-04
     +,   2.9518036E-04,   2.9395608E-04,   2.9261419E-04
     +,   2.9117006E-04,   2.8963946E-04,   2.8803918E-04
     +,   2.8638670E-04,   2.8470010E-04,   2.8299840E-04
     +,   2.8130191E-04,   2.7963181E-04,   2.7801152E-04
     +,   2.7646555E-04,   2.7502145E-04,   2.7370942E-04
     +,   2.7256293E-04,   2.7161962E-04,   2.7092214E-04
     +,   2.7051839E-04,   2.7046271E-04,   2.7081693E-04
     +,   2.7165111E-04,   2.7304442E-04,   2.7508626E-04
     +,   2.7787726E-04,   2.8153037E-04,   2.8617229E-04
     +,   2.9194422E-04,   2.9900283E-04,   3.0752190E-04
     +,   3.1769366E-04,   3.2972835E-04,   3.4385553E-04
     +,   3.6032457E-04,   3.7940417E-04,   4.0137803E-04
     +,   4.2654440E-04,   4.5521179E-04,   4.8769353E-04
     +,   5.2429782E-04,   5.6532078E-04,   6.1104051E-04
     +,   6.6170731E-04,   7.1752997E-04,   7.7868358E-04
     +,   8.4530376E-04,   9.1749162E-04,   9.9533726E-04
     +,   1.0789533E-03,   1.1685180E-03,   1.2643336E-03
     +,   1.3669082E-03,   1.4770614E-03,   1.5960297E-03
     +,   1.7255662E-03,   1.8680351E-03,   2.0264699E-03
     +,   2.2045220E-03,   2.4063364E-03,   2.6364368E-03
     +,   2.8996884E-03,   3.2015801E-03,   3.5489802E-03
     +,   3.9513046E-03,   4.4214637E-03,   4.9757850E-03
     +,   5.6320135E-03,   6.4054267E-03,   7.3041185E-03
     +,   8.3260825E-03,   9.4604129E-03,   1.0692397E-02
     +,   1.2009840E-02,   1.3409318E-02,   1.4904814E-02
     +,   1.6534436E-02,   1.8349357E-02,   2.0376807E-02
     +,   2.2592174E-02,   2.4957737E-02,   2.7512375E-02
     +,   3.0370299E-02,   3.3528563E-02,   3.6706325E-02
     +,   3.9595507E-02,   4.2304065E-02,   4.5260627E-02
     +,   4.8723768E-02,   5.2651782E-02,   5.6549419E-02
     +,   5.9130684E-02,   5.9115615E-02,   5.6796610E-02
     +,   5.3961422E-02,   5.2032534E-02,   5.1033150E-02
     +,   5.0513752E-02,   5.0340313E-02,   5.0124016E-02
     +,   4.9030010E-02,   4.6579532E-02,   4.3132070E-02
     +,   3.9502691E-02,   3.6221415E-02,   3.3206228E-02
     +,   3.0163685E-02,   2.7132563E-02,   2.4481535E-02
     +,   2.2489544E-02,   2.1077417E-02,   1.9898873E-02
     +,   1.8605743E-02,   1.7053183E-02,   1.5329718E-02
     +,   1.3641675E-02,   1.2168148E-02,   1.0983256E-02
     +,   1.0061209E-02,   9.3239630E-03,   8.6889518E-03
     +,   8.0967266E-03,   7.5174677E-03,   6.9443835E-03
     +,   6.3826833E-03,   5.8403225E-03,   5.3228354E-03
     +,   4.8320778E-03,   4.3673925E-03,   3.9274120E-03
     +,   3.5113189E-03,   3.1191891E-03,   2.7519464E-03
     +,   2.4108824E-03,   2.0973287E-03,   1.8122330E-03
     +,   1.5559952E-03,   1.3282771E-03,   1.1280542E-03
     +,   9.5365260E-04,   8.0297369E-04,   6.7364721E-04
     +,   5.6324067E-04,   4.6941199E-04,   3.8998178E-04
     +,   3.2300327E-04,   2.6675127E-04,   2.1972485E-04
     +,   1.8060760E-04,   1.4825336E-04,   1.2165156E-04
     +,   9.9917132E-05,   8.2269173E-05,   6.8026588E-05
     +,   5.6595367E-05,   4.7465499E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt106 = Yx/0.40978
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2064784E-05,   1.2506185E-05
     +,   1.2952026E-05,   1.3401740E-05,   1.3854754E-05
     +,   1.4310484E-05,   1.4768337E-05,   1.5227708E-05
     +,   1.5687992E-05,   1.6148619E-05,   1.6608979E-05
     +,   1.7068496E-05,   1.7526605E-05,   1.7982749E-05
     +,   1.8436413E-05,   1.8887076E-05,   1.9334268E-05
     +,   1.9777543E-05,   2.0216485E-05,   2.0650728E-05
     +,   2.1079934E-05,   2.1503811E-05,   2.1922109E-05
     +,   2.2334649E-05,   2.2741264E-05,   2.3141869E-05
     +,   2.3536413E-05,   2.3924911E-05,   2.4307416E-05
     +,   2.4684057E-05,   2.5054993E-05,   2.5420464E-05
     +,   2.5780730E-05,   2.6136120E-05,   2.6487021E-05
     +,   2.6833848E-05,   2.7177071E-05,   2.7517204E-05
     +,   2.7854809E-05,   2.8190450E-05,   2.8524775E-05
     +,   2.8858442E-05,   2.9192110E-05,   2.9526496E-05
     +,   2.9862344E-05,   3.0200394E-05,   3.0541400E-05
     +,   3.0886160E-05,   3.1235450E-05,   3.1590094E-05
     +,   3.1950880E-05,   3.2318661E-05,   3.2694261E-05
     +,   3.3078544E-05,   3.3472381E-05,   3.3876655E-05
     +,   3.4292301E-05,   3.4720284E-05,   3.5161600E-05
     +,   3.5617315E-05,   3.6088542E-05,   3.6576501E-05
     +,   3.7082475E-05,   3.7607893E-05,   3.8154292E-05
     +,   3.8723352E-05,   3.9316961E-05,   3.9937131E-05
     +,   4.0586165E-05,   4.1266518E-05,   4.1980969E-05
     +,   4.2732518E-05,   4.3524527E-05,   4.4360579E-05
     +,   4.5244673E-05,   4.6181140E-05,   4.7174592E-05
     +,   4.8229991E-05,   4.9352715E-05,   5.0548475E-05
     +,   5.1823150E-05,   5.3183117E-05,   5.4634816E-05
     +,   5.6185032E-05,   5.7840527E-05,   5.9608381E-05
     +,   6.1495397E-05,   6.3508553E-05,   6.5654378E-05
     +,   6.7939305E-05,   7.0369366E-05,   7.2949879E-05
     +,   7.5685493E-05,   7.8580204E-05,   8.1637118E-05
     +,   8.4857900E-05,   8.8243425E-05,   9.1792826E-05
     +,   9.5504140E-05,   9.9373392E-05,   1.0339545E-04
     +,   1.0756288E-04,   1.1186692E-04,   1.1629654E-04
     +,   1.2083920E-04,   1.2548048E-04,   1.3020393E-04
     +,   1.3499150E-04,   1.3982358E-04,   1.4467942E-04
     +,   1.4953621E-04,   1.5437091E-04,   1.5915882E-04
     +,   1.6387535E-04,   1.6849484E-04,   1.7299222E-04
     +,   1.7734202E-04,   1.8151986E-04,   1.8550162E-04
     +,   1.8926471E-04,   1.9278795E-04,   1.9605145E-04
     +,   1.9903755E-04,   2.0173071E-04,   2.0411787E-04
     +,   2.0618828E-04,   2.0793422E-04,   2.0935039E-04
     +,   2.1043485E-04,   2.1118806E-04,   2.1161376E-04
     +,   2.1171862E-04,   2.1151180E-04,   2.1100554E-04
     +,   2.1021451E-04,   2.0915567E-04,   2.0784853E-04
     +,   2.0631445E-04,   2.0457685E-04,   2.0266055E-04
     +,   2.0059189E-04,   1.9839873E-04,   1.9610934E-04
     +,   1.9375316E-04,   1.9136009E-04,   1.8896033E-04
     +,   1.8658407E-04,   1.8426184E-04,   1.8202377E-04
     +,   1.7989936E-04,   1.7791780E-04,   1.7610760E-04
     +,   1.7449635E-04,   1.7311053E-04,   1.7197554E-04
     +,   1.7111553E-04,   1.7055323E-04,   1.7030991E-04
     +,   1.7040504E-04,   1.7085645E-04,   1.7168022E-04
     +,   1.7289056E-04,   1.7449990E-04,   1.7651857E-04
     +,   1.7895558E-04,   1.8181819E-04,   1.8511232E-04
     +,   1.8884265E-04,   1.9301362E-04,   1.9762946E-04
     +,   2.0269457E-04,   2.0821471E-04,   2.1419764E-04
     +,   2.2065431E-04,   2.2759882E-04,   2.3505109E-04
     +,   2.4303696E-04,   2.5158955E-04,   2.6075024E-04
     +,   2.7057121E-04,   2.8111567E-04,   2.9245854E-04
     +,   3.0468820E-04,   3.1790757E-04,   3.3223460E-04
     +,   3.4780143E-04,   3.6475432E-04,   3.8325458E-04
     +,   4.0347513E-04,   4.2559835E-04,   4.4981521E-04
     +,   4.7632187E-04,   5.0531508E-04,   5.3699146E-04
     +,   5.7154882E-04,   6.0918828E-04,   6.5011601E-04
     +,   6.9455802E-04,   7.4277958E-04,   7.9510617E-04
     +,   8.5194944E-04,   9.1384433E-04,   9.8149304E-04
     +,   1.0558020E-03,   1.1379239E-03,   1.2293269E-03
     +,   1.3318646E-03,   1.4478618E-03,   1.5802337E-03
     +,   1.7326068E-03,   1.9093772E-03,   2.1156308E-03
     +,   2.3568817E-03,   2.6385710E-03,   2.9653225E-03
     +,   3.3401339E-03,   3.7638745E-03,   4.2354777E-03
     +,   4.7530918E-03,   5.3162170E-03,   5.9283446E-03
     +,   6.5985252E-03,   7.3409365E-03,   8.1730215E-03
     +,   9.1146855E-03,   1.0190771E-02,   1.1434278E-02
     +,   1.2883424E-02,   1.4569452E-02,   1.6503561E-02
     +,   1.8669982E-02,   2.1023693E-02,   2.3505621E-02
     +,   2.6095036E-02,   2.8832231E-02,   3.1689260E-02
     +,   3.4404222E-02,   3.6670942E-02,   3.8663872E-02
     +,   4.1027617E-02,   4.3876350E-02,   4.6259508E-02
     +,   4.7495149E-02,   4.8397239E-02,   5.0084166E-02
     +,   5.2588683E-02,   5.5336874E-02,   5.7761367E-02
     +,   5.9277661E-02,   5.9418045E-02,   5.8034435E-02
     +,   5.5305373E-02,   5.1806126E-02,   4.8425965E-02
     +,   4.5762323E-02,   4.3723039E-02,   4.1715667E-02
     +,   3.9129697E-02,   3.5838153E-02,   3.2227762E-02
     +,   2.8750326E-02,   2.5561508E-02,   2.2576122E-02
     +,   1.9734871E-02,   1.7129051E-02,   1.4908396E-02
     +,   1.3139604E-02,   1.1762884E-02,   1.0650520E-02
     +,   9.6838251E-03,   8.7886183E-03,   7.9315864E-03
     +,   7.1051866E-03,   6.3158143E-03,   5.5756373E-03
     +,   4.8960173E-03,   4.2830450E-03,   3.7368084E-03
     +,   3.2528348E-03,   2.8246101E-03,   2.4453322E-03
     +,   2.1090345E-03,   1.8108421E-03,   1.5469783E-03
     +,   1.3144193E-03,   1.1106537E-03,   9.3337015E-04
     +,   7.8032527E-04,   6.4928911E-04,   5.3801015E-04
     +,   4.4428228E-04,   3.6595756E-04,   3.0101225E-04
     +,   2.4755680E-04,   2.0387364E-04,   1.6841455E-04
     +,   1.3981404E-04,   1.1687593E-04,   9.8571290E-05
     +,   8.4020154E-05,   7.2481875E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt108 = Yx/0.395428571428571
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4915669E-05,   1.5305390E-05
     +,   1.5702799E-05,   1.6108268E-05,   1.6522205E-05
     +,   1.6945047E-05,   1.7377273E-05,   1.7819395E-05
     +,   1.8271952E-05,   1.8735544E-05,   1.9210776E-05
     +,   1.9698289E-05,   2.0198766E-05,   2.0712896E-05
     +,   2.1241398E-05,   2.1785017E-05,   2.2344499E-05
     +,   2.2920602E-05,   2.3514094E-05,   2.4125729E-05
     +,   2.4756260E-05,   2.5406420E-05,   2.6076901E-05
     +,   2.6768415E-05,   2.7481563E-05,   2.8216955E-05
     +,   2.8975126E-05,   2.9756531E-05,   3.0561576E-05
     +,   3.1390569E-05,   3.2243741E-05,   3.3121207E-05
     +,   3.4023000E-05,   3.4949026E-05,   3.5899073E-05
     +,   3.6872822E-05,   3.7869788E-05,   3.8889375E-05
     +,   3.9930906E-05,   4.0993433E-05,   4.2076001E-05
     +,   4.3177453E-05,   4.4296488E-05,   4.5431705E-05
     +,   4.6581532E-05,   4.7744314E-05,   4.8918235E-05
     +,   5.0101389E-05,   5.1291772E-05,   5.2487278E-05
     +,   5.3685726E-05,   5.4884855E-05,   5.6082346E-05
     +,   5.7275898E-05,   5.8463065E-05,   5.9641516E-05
     +,   6.0808845E-05,   6.1962695E-05,   6.3100735E-05
     +,   6.4220680E-05,   6.5320346E-05,   6.6397595E-05
     +,   6.7450390E-05,   6.8476824E-05,   6.9475143E-05
     +,   7.0443653E-05,   7.1380906E-05,   7.2285497E-05
     +,   7.3156312E-05,   7.3992305E-05,   7.4792682E-05
     +,   7.5556789E-05,   7.6284225E-05,   7.6974662E-05
     +,   7.7628043E-05,   7.8244535E-05,   7.8824363E-05
     +,   7.9367994E-05,   7.9876103E-05,   8.0349455E-05
     +,   8.0788996E-05,   8.1195823E-05,   8.1571110E-05
     +,   8.1916223E-05,   8.2232582E-05,   8.2521714E-05
     +,   8.2785205E-05,   8.3024715E-05,   8.3241954E-05
     +,   8.3438645E-05,   8.3616578E-05,   8.3777471E-05
     +,   8.3923085E-05,   8.4055144E-05,   8.4175364E-05
     +,   8.4285377E-05,   8.4386738E-05,   8.4481006E-05
     +,   8.4569583E-05,   8.4653831E-05,   8.4735009E-05
     +,   8.4814274E-05,   8.4892687E-05,   8.4971158E-05
     +,   8.5050553E-05,   8.5131527E-05,   8.5214720E-05
     +,   8.5300591E-05,   8.5389504E-05,   8.5481668E-05
     +,   8.5577267E-05,   8.5676278E-05,   8.5778622E-05
     +,   8.5884138E-05,   8.5992491E-05,   8.6103362E-05
     +,   8.6216285E-05,   8.6330700E-05,   8.6446023E-05
     +,   8.6561617E-05,   8.6676780E-05,   8.6790737E-05
     +,   8.6902743E-05,   8.7012006E-05,   8.7117754E-05
     +,   8.7219189E-05,   8.7315530E-05,   8.7406064E-05
     +,   8.7490123E-05,   8.7567088E-05,   8.7636450E-05
     +,   8.7697765E-05,   8.7750726E-05,   8.7795190E-05
     +,   8.7831169E-05,   8.7858840E-05,   8.7878623E-05
     +,   8.7891203E-05,   8.7897475E-05,   8.7898676E-05
     +,   8.7896420E-05,   8.7892658E-05,   8.7889712E-05
     +,   8.7890425E-05,   8.7898115E-05,   8.7916596E-05
     +,   8.7950306E-05,   8.8004257E-05,   8.8084118E-05
     +,   8.8196335E-05,   8.8347973E-05,   8.8547029E-05
     +,   8.8802219E-05,   8.9123190E-05,   8.9520567E-05
     +,   9.0005851E-05,   9.0591617E-05,   9.1291535E-05
     +,   9.2120434E-05,   9.3094255E-05,   9.4230323E-05
     +,   9.5547359E-05,   9.7065451E-05,   9.8806129E-05
     +,   1.0079287E-04,   1.0305076E-04,   1.0560669E-04
     +,   1.0848937E-04,   1.1172974E-04,   1.1536089E-04
     +,   1.1941758E-04,   1.2393655E-04,   1.2895657E-04
     +,   1.3451795E-04,   1.4066166E-04,   1.4742991E-04
     +,   1.5486493E-04,   1.6300777E-04,   1.7189770E-04
     +,   1.8157183E-04,   1.9206345E-04,   2.0340034E-04
     +,   2.1560366E-04,   2.2868806E-04,   2.4266004E-04
     +,   2.5751622E-04,   2.7324466E-04,   2.8982549E-04
     +,   3.0723296E-04,   3.2543548E-04,   3.4440323E-04
     +,   3.6411354E-04,   3.8455561E-04,   4.0574235E-04
     +,   4.2772351E-04,   4.5059659E-04,   4.7451930E-04
     +,   4.9972645E-04,   5.2654202E-04,   5.5539160E-04
     +,   5.8680383E-04,   6.2141521E-04,   6.5996428E-04
     +,   7.0327462E-04,   7.5222808E-04,   8.0773921E-04
     +,   8.7071554E-04,   9.4200787E-04,   1.0223758E-03
     +,   1.1124511E-03,   1.2127120E-03,   1.3234616E-03
     +,   1.4448531E-03,   1.5769498E-03,   1.7198314E-03
     +,   1.8737748E-03,   2.0395434E-03,   2.2187738E-03
     +,   2.4144142E-03,   2.6311148E-03,   2.8755104E-03
     +,   3.1560611E-03,   3.4823066E-03,   3.8634536E-03
     +,   4.3064263E-03,   4.8139226E-03,   5.3834026E-03
     +,   6.0082944E-03,   6.6822469E-03,   7.4059921E-03
     +,   8.1945788E-03,   9.0799676E-03,   1.0102508E-02
     +,   1.1289055E-02,   1.2626889E-02,   1.4054127E-02
     +,   1.5484122E-02,   1.6861666E-02,   1.8229138E-02
     +,   1.9767210E-02,   2.1748967E-02,   2.4361921E-02
     +,   2.7526317E-02,   3.0975642E-02,   3.4543570E-02
     +,   3.8218629E-02,   4.1911412E-02,   4.5484114E-02
     +,   4.9050611E-02,   5.2585527E-02,   5.5263303E-02
     +,   5.6405425E-02,   5.6693885E-02,   5.7039898E-02
     +,   5.7274461E-02,   5.6833420E-02,   5.5580363E-02
     +,   5.3744953E-02,   5.1873665E-02,   5.0612677E-02
     +,   4.9716413E-02,   4.7951654E-02,   4.4654328E-02
     +,   4.0556841E-02,   3.6900867E-02,   3.4130536E-02
     +,   3.1676289E-02,   2.8975267E-02,   2.6158081E-02
     +,   2.3580296E-02,   2.1237494E-02,   1.8881246E-02
     +,   1.6400393E-02,   1.3919521E-02,   1.1645636E-02
     +,   9.7116325E-03,   8.1321467E-03,   6.8479544E-03
     +,   5.7872916E-03,   4.8997556E-03,   4.1571031E-03
     +,   3.5406312E-03,   3.0311346E-03,   2.6072350E-03
     +,   2.2482802E-03,   1.9378030E-03,   1.6647493E-03
     +,   1.4227846E-03,   1.2086291E-03,   1.0203707E-03
     +,   8.5644738E-04,   7.1510876E-04,   5.9437030E-04
     +,   4.9207517E-04,   4.0606028E-04,   3.3423450E-04
     +,   2.7465998E-04,   2.2555742E-04,   1.8532753E-04
     +,   1.5253610E-04,   1.2592087E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt110 = Yx/0.386857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1928131E-05,   1.2181922E-05
     +,   1.2434809E-05,   1.2686522E-05,   1.2936801E-05
     +,   1.3185376E-05,   1.3431978E-05,   1.3676336E-05
     +,   1.3918171E-05,   1.4157219E-05,   1.4393204E-05
     +,   1.4625855E-05,   1.4854898E-05,   1.5080067E-05
     +,   1.5301091E-05,   1.5517715E-05,   1.5729674E-05
     +,   1.5936717E-05,   1.6138596E-05,   1.6335065E-05
     +,   1.6525893E-05,   1.6710852E-05,   1.6889715E-05
     +,   1.7062284E-05,   1.7228351E-05,   1.7387727E-05
     +,   1.7540240E-05,   1.7685719E-05,   1.7824012E-05
     +,   1.7954984E-05,   1.8078506E-05,   1.8194472E-05
     +,   1.8302788E-05,   1.8403374E-05,   1.8496177E-05
     +,   1.8581148E-05,   1.8658271E-05,   1.8727540E-05
     +,   1.8788969E-05,   1.8842593E-05,   1.8888470E-05
     +,   1.8926678E-05,   1.8957318E-05,   1.8980509E-05
     +,   1.8996396E-05,   1.9005141E-05,   1.9006937E-05
     +,   1.9001998E-05,   1.8990555E-05,   1.8972865E-05
     +,   1.8949215E-05,   1.8919904E-05,   1.8885265E-05
     +,   1.8845647E-05,   1.8801424E-05,   1.8752997E-05
     +,   1.8700777E-05,   1.8645207E-05,   1.8586758E-05
     +,   1.8525905E-05,   1.8463152E-05,   1.8399025E-05
     +,   1.8334069E-05,   1.8268845E-05,   1.8203929E-05
     +,   1.8139930E-05,   1.8077446E-05,   1.8017123E-05
     +,   1.7959597E-05,   1.7905537E-05,   1.7855617E-05
     +,   1.7810527E-05,   1.7770973E-05,   1.7737682E-05
     +,   1.7711387E-05,   1.7692839E-05,   1.7682816E-05
     +,   1.7682105E-05,   1.7691518E-05,   1.7711891E-05
     +,   1.7744094E-05,   1.7789027E-05,   1.7847622E-05
     +,   1.7920864E-05,   1.8009780E-05,   1.8115465E-05
     +,   1.8239070E-05,   1.8381841E-05,   1.8545092E-05
     +,   1.8730258E-05,   1.8938883E-05,   1.9172634E-05
     +,   1.9433321E-05,   1.9722915E-05,   2.0043581E-05
     +,   2.0397634E-05,   2.0787638E-05,   2.1216332E-05
     +,   2.1686739E-05,   2.2202070E-05,   2.2765851E-05
     +,   2.3381795E-05,   2.4053952E-05,   2.4786556E-05
     +,   2.5584144E-05,   2.6451491E-05,   2.7393546E-05
     +,   2.8415423E-05,   2.9522456E-05,   3.0720072E-05
     +,   3.2013639E-05,   3.3408669E-05,   3.4910390E-05
     +,   3.6524045E-05,   3.8254413E-05,   4.0106097E-05
     +,   4.2083004E-05,   4.4188659E-05,   4.6425655E-05
     +,   4.8795893E-05,   5.1300365E-05,   5.3938820E-05
     +,   5.6709763E-05,   5.9610615E-05,   6.2637358E-05
     +,   6.5784239E-05,   6.9044319E-05,   7.2408657E-05
     +,   7.5867094E-05,   7.9407415E-05,   8.3016253E-05
     +,   8.6678228E-05,   9.0376947E-05,   9.4094190E-05
     +,   9.7810887E-05,   1.0150691E-04,   1.0516106E-04
     +,   1.0875146E-04,   1.1225614E-04,   1.1565297E-04
     +,   1.1891970E-04,   1.2203453E-04,   1.2497662E-04
     +,   1.2772606E-04,   1.3026394E-04,   1.3257310E-04
     +,   1.3463825E-04,   1.3644583E-04,   1.3798456E-04
     +,   1.3924559E-04,   1.4022259E-04,   1.4091167E-04
     +,   1.4131163E-04,   1.4142395E-04,   1.4125278E-04
     +,   1.4080475E-04,   1.4008912E-04,   1.3911737E-04
     +,   1.3790329E-04,   1.3646272E-04,   1.3481341E-04
     +,   1.3297459E-04,   1.3096715E-04,   1.2881331E-04
     +,   1.2653612E-04,   1.2415962E-04,   1.2170867E-04
     +,   1.1920884E-04,   1.1668601E-04,   1.1416661E-04
     +,   1.1167768E-04,   1.0924692E-04,   1.0690245E-04
     +,   1.0467339E-04,   1.0259008E-04,   1.0068434E-04
     +,   9.8989680E-05,   9.7542172E-05,   9.6380689E-05
     +,   9.5547439E-05,   9.5088704E-05,   9.5055359E-05
     +,   9.5503492E-05,   9.6494805E-05,   9.8097102E-05
     +,   1.0038438E-04,   1.0343682E-04,   1.0734066E-04
     +,   1.1218767E-04,   1.1807360E-04,   1.2509785E-04
     +,   1.3336164E-04,   1.4296523E-04,   1.5400689E-04
     +,   1.6658125E-04,   1.8077756E-04,   1.9667739E-04
     +,   2.1435524E-04,   2.3388118E-04,   2.5532243E-04
     +,   2.7874755E-04,   3.0423456E-04,   3.3188320E-04
     +,   3.6182819E-04,   3.9425259E-04,   4.2941395E-04
     +,   4.6766462E-04,   5.0947221E-04,   5.5544206E-04
     +,   6.0633302E-04,   6.6305487E-04,   7.2664116E-04
     +,   7.9820020E-04,   8.7883236E-04,   9.6950831E-04
     +,   1.0709154E-03,   1.1833076E-03,   1.3063898E-03
     +,   1.4392424E-03,   1.5803347E-03,   1.7276984E-03
     +,   1.8791883E-03,   2.0328437E-03,   2.1873200E-03
     +,   2.3423214E-03,   2.4989555E-03,   2.6600235E-03
     +,   2.8303282E-03,   3.0170723E-03,   3.2304069E-03
     +,   3.4840761E-03,   3.7956855E-03,   4.1858507E-03
     +,   4.6754656E-03,   5.2814251E-03,   6.0129520E-03
     +,   6.8709180E-03,   7.8508742E-03,   8.9469543E-03
     +,   1.0153135E-02,   1.1462573E-02,   1.2867372E-02
     +,   1.4350753E-02,   1.5861673E-02,   1.7300883E-02
     +,   1.8589849E-02,   1.9818870E-02,   2.1300171E-02
     +,   2.3352820E-02,   2.5971614E-02,   2.8787460E-02
     +,   3.1395871E-02,   3.3634711E-02,   3.5682339E-02
     +,   3.8091693E-02,   4.1473787E-02,   4.5972373E-02
     +,   5.0887741E-02,   5.4618921E-02,   5.6046508E-02
     +,   5.6713481E-02,   5.9022188E-02,   6.1798867E-02
     +,   6.2853746E-02,   6.3392490E-02,   6.3791767E-02
     +,   6.2237117E-02,   5.8791369E-02,   5.4410264E-02
     +,   4.8998438E-02,   4.2769402E-02,   3.7148986E-02
     +,   3.3258986E-02,   3.0672504E-02,   2.8231332E-02
     +,   2.5374988E-02,   2.2276606E-02,   1.9227017E-02
     +,   1.6327519E-02,   1.3581422E-02,   1.1021078E-02
     +,   8.7248003E-03,   6.7682159E-03,   5.1834066E-03
     +,   3.9511775E-03,   3.0190414E-03,   2.3231735E-03
     +,   1.8037573E-03,   1.4120048E-03,   1.1117798E-03
     +,   8.7836414E-04,   6.9548021E-04,   5.5221457E-04
     +,   4.4055399E-04,   3.5403951E-04,   2.8717562E-04
     +,   2.3533152E-04,   1.9473280E-04,   1.6245723E-04
     +,   1.3633842E-04,   1.1483917E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt112 = Yx/0.378285714285714
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1560025E-05,   1.1704583E-05
     +,   1.1842973E-05,   1.1974964E-05,   1.2100340E-05
     +,   1.2218905E-05,   1.2330473E-05,   1.2434879E-05
     +,   1.2531973E-05,   1.2621632E-05,   1.2703744E-05
     +,   1.2778226E-05,   1.2845009E-05,   1.2904055E-05
     +,   1.2955346E-05,   1.2998889E-05,   1.3034718E-05
     +,   1.3062894E-05,   1.3083504E-05,   1.3096663E-05
     +,   1.3102516E-05,   1.3101237E-05,   1.3093032E-05
     +,   1.3078135E-05,   1.3056811E-05,   1.3029359E-05
     +,   1.2996111E-05,   1.2957431E-05,   1.2913715E-05
     +,   1.2865396E-05,   1.2812933E-05,   1.2756830E-05
     +,   1.2697618E-05,   1.2635866E-05,   1.2572173E-05
     +,   1.2507173E-05,   1.2441539E-05,   1.2375973E-05
     +,   1.2311207E-05,   1.2248011E-05,   1.2187183E-05
     +,   1.2129552E-05,   1.2075977E-05,   1.2027343E-05
     +,   1.1984562E-05,   1.1948569E-05,   1.1920324E-05
     +,   1.1900805E-05,   1.1891005E-05,   1.1891935E-05
     +,   1.1904617E-05,   1.1930076E-05,   1.1969347E-05
     +,   1.2023462E-05,   1.2093446E-05,   1.2180323E-05
     +,   1.2285095E-05,   1.2408753E-05,   1.2552255E-05
     +,   1.2716536E-05,   1.2902494E-05,   1.3110989E-05
     +,   1.3342819E-05,   1.3598748E-05,   1.3879476E-05
     +,   1.4185620E-05,   1.4517758E-05,   1.4876348E-05
     +,   1.5261810E-05,   1.5674428E-05,   1.6114438E-05
     +,   1.6581927E-05,   1.7076933E-05,   1.7599325E-05
     +,   1.8148907E-05,   1.8725366E-05,   1.9328249E-05
     +,   1.9956962E-05,   2.0610847E-05,   2.1289119E-05
     +,   2.1990812E-05,   2.2714932E-05,   2.3460267E-05
     +,   2.4225606E-05,   2.5009515E-05,   2.5810565E-05
     +,   2.6627129E-05,   2.7457589E-05,   2.8300145E-05
     +,   2.9153000E-05,   3.0014286E-05,   3.0882034E-05
     +,   3.1754233E-05,   3.2628879E-05,   3.3503955E-05
     +,   3.4377350E-05,   3.5247056E-05,   3.6110978E-05
     +,   3.6967158E-05,   3.7813537E-05,   3.8648239E-05
     +,   3.9469334E-05,   4.0275056E-05,   4.1063620E-05
     +,   4.1833409E-05,   4.2582898E-05,   4.3310618E-05
     +,   4.4015200E-05,   4.4695462E-05,   4.5350334E-05
     +,   4.5978795E-05,   4.6580040E-05,   4.7153324E-05
     +,   4.7698104E-05,   4.8213878E-05,   4.8700364E-05
     +,   4.9157330E-05,   4.9584727E-05,   4.9982566E-05
     +,   5.0351005E-05,   5.0690298E-05,   5.1000818E-05
     +,   5.1282976E-05,   5.1537347E-05,   5.1764517E-05
     +,   5.1965151E-05,   5.2140029E-05,   5.2289943E-05
     +,   5.2415737E-05,   5.2518295E-05,   5.2598567E-05
     +,   5.2657517E-05,   5.2696159E-05,   5.2715492E-05
     +,   5.2716598E-05,   5.2700550E-05,   5.2668467E-05
     +,   5.2621526E-05,   5.2560885E-05,   5.2487805E-05
     +,   5.2403611E-05,   5.2309661E-05,   5.2207433E-05
     +,   5.2098498E-05,   5.1984567E-05,   5.1867482E-05
     +,   5.1749277E-05,   5.1632218E-05,   5.1518775E-05
     +,   5.1411720E-05,   5.1314142E-05,   5.1229526E-05
     +,   5.1161765E-05,   5.1115218E-05,   5.1094779E-05
     +,   5.1105984E-05,   5.1154992E-05,   5.1248735E-05
     +,   5.1394945E-05,   5.1602208E-05,   5.1880095E-05
     +,   5.2239258E-05,   5.2691357E-05,   5.3249194E-05
     +,   5.3926840E-05,   5.4739576E-05,   5.5703862E-05
     +,   5.6837329E-05,   5.8158919E-05,   5.9688646E-05
     +,   6.1447339E-05,   6.3456719E-05,   6.5739085E-05
     +,   6.8317153E-05,   7.1213486E-05,   7.4450385E-05
     +,   7.8049634E-05,   8.2031591E-05,   8.6415115E-05
     +,   9.1217422E-05,   9.6453623E-05,   1.0213628E-04
     +,   1.0827548E-04,   1.1487971E-04,   1.2195600E-04
     +,   1.2951042E-04,   1.3754983E-04,   1.4608426E-04
     +,   1.5512889E-04,   1.6470594E-04,   1.7484964E-04
     +,   1.8560902E-04,   1.9705042E-04,   2.0926169E-04
     +,   2.2235542E-04,   2.3646980E-04,   2.5176737E-04
     +,   2.6843403E-04,   2.8667500E-04,   3.0670722E-04
     +,   3.2874697E-04,   3.5299905E-04,   3.7964332E-04
     +,   4.0881871E-04,   4.4060510E-04,   4.7501671E-04
     +,   5.1199185E-04,   5.5138842E-04,   5.9299381E-04
     +,   6.3654175E-04,   6.8173697E-04,   7.2828680E-04
     +,   7.7594351E-04,   8.2455273E-04,   8.7409216E-04
     +,   9.2470628E-04,   9.7672921E-04,   1.0306970E-03
     +,   1.0873303E-03,   1.1474957E-03,   1.2121696E-03
     +,   1.2823853E-03,   1.3591775E-03,   1.4435616E-03
     +,   1.5365384E-03,   1.6391051E-03,   1.7522756E-03
     +,   1.8771050E-03,   2.0147047E-03,   2.1662714E-03
     +,   2.3332334E-03,   2.5176946E-03,   2.7232745E-03
     +,   2.9563194E-03,   3.2271869E-03,   3.5509637E-03
     +,   3.9466461E-03,   4.4340594E-03,   5.0287484E-03
     +,   5.7364698E-03,   6.5506273E-03,   7.4561490E-03
     +,   8.4402403E-03,   9.5039029E-03,   1.0664447E-02
     +,   1.1944938E-02,   1.3358547E-02,   1.4900642E-02
     +,   1.6555270E-02,   1.8313771E-02,   2.0186765E-02
     +,   2.2171004E-02,   2.4195332E-02,   2.6190897E-02
     +,   2.8260034E-02,   3.0541332E-02,   3.2836426E-02
     +,   3.4896106E-02,   3.7204996E-02,   4.0719017E-02
     +,   4.5317531E-02,   4.9283892E-02,   5.1597469E-02
     +,   5.3159270E-02,   5.5200875E-02,   5.8453031E-02
     +,   6.1498530E-02,   6.2129170E-02,   6.1466280E-02
     +,   6.1122362E-02,   5.9765454E-02,   5.5785086E-02
     +,   4.9999211E-02,   4.4298552E-02,   3.9498784E-02
     +,   3.5515632E-02,   3.1995963E-02,   2.8595636E-02
     +,   2.5162634E-02,   2.1681760E-02,   1.8197630E-02
     +,   1.4830091E-02,   1.1762576E-02,   9.1530290E-03
     +,   7.0536104E-03,   5.4159202E-03,   4.1474155E-03
     +,   3.1610085E-03,   2.3935004E-03,   1.8018847E-03
     +,   1.3539641E-03,   1.0216046E-03,   7.7890576E-04
     +,   6.0282275E-04,   4.7438740E-04,   3.7911048E-04
     +,   3.0665949E-04,   2.5001468E-04,   2.0458615E-04
     +,   1.6741932E-04,   1.3662118E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt113 = Yx/0.356285714285714
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1547721E-05,   1.1813190E-05
     +,   1.2073847E-05,   1.2329134E-05,   1.2578505E-05
     +,   1.2821415E-05,   1.3057338E-05,   1.3285759E-05
     +,   1.3506171E-05,   1.3718106E-05,   1.3921096E-05
     +,   1.4114699E-05,   1.4298506E-05,   1.4472126E-05
     +,   1.4635209E-05,   1.4787423E-05,   1.4928482E-05
     +,   1.5058115E-05,   1.5176110E-05,   1.5282278E-05
     +,   1.5376472E-05,   1.5458592E-05,   1.5528567E-05
     +,   1.5586385E-05,   1.5632053E-05,   1.5665642E-05
     +,   1.5687259E-05,   1.5697055E-05,   1.5695232E-05
     +,   1.5682032E-05,   1.5657728E-05,   1.5622660E-05
     +,   1.5577196E-05,   1.5521759E-05,   1.5456799E-05
     +,   1.5382826E-05,   1.5300378E-05,   1.5210047E-05
     +,   1.5112445E-05,   1.5008257E-05,   1.4898165E-05
     +,   1.4782926E-05,   1.4663316E-05,   1.4540155E-05
     +,   1.4414300E-05,   1.4286650E-05,   1.4158129E-05
     +,   1.4029706E-05,   1.3902398E-05,   1.3777242E-05
     +,   1.3655325E-05,   1.3537769E-05,   1.3425744E-05
     +,   1.3320452E-05,   1.3223147E-05,   1.3135127E-05
     +,   1.3057732E-05,   1.2992359E-05,   1.2940450E-05
     +,   1.2903501E-05,   1.2883068E-05,   1.2880754E-05
     +,   1.2898235E-05,   1.2937239E-05,   1.2999562E-05
     +,   1.3087060E-05,   1.3201667E-05,   1.3345361E-05
     +,   1.3520217E-05,   1.3728349E-05,   1.3971957E-05
     +,   1.4253293E-05,   1.4574685E-05,   1.4938493E-05
     +,   1.5347154E-05,   1.5803165E-05,   1.6309032E-05
     +,   1.6867292E-05,   1.7480532E-05,   1.8151366E-05
     +,   1.8882343E-05,   1.9676079E-05,   2.0535077E-05
     +,   2.1461892E-05,   2.2458908E-05,   2.3528550E-05
     +,   2.4673000E-05,   2.5894464E-05,   2.7194854E-05
     +,   2.8576022E-05,   3.0039637E-05,   3.1587060E-05
     +,   3.3219403E-05,   3.4937595E-05,   3.6742316E-05
     +,   3.8633716E-05,   4.0611882E-05,   4.2676256E-05
     +,   4.4826189E-05,   4.7060334E-05,   4.9377239E-05
     +,   5.1774718E-05,   5.4250439E-05,   5.6801302E-05
     +,   5.9424008E-05,   6.2114836E-05,   6.4869360E-05
     +,   6.7682791E-05,   7.0549999E-05,   7.3465504E-05
     +,   7.6423094E-05,   7.9416546E-05,   8.2438928E-05
     +,   8.5483312E-05,   8.8542110E-05,   9.1607879E-05
     +,   9.4672541E-05,   9.7728167E-05,   1.0076641E-04
     +,   1.0377902E-04,   1.0675778E-04,   1.0969415E-04
     +,   1.1257979E-04,   1.1540659E-04,   1.1816652E-04
     +,   1.2085158E-04,   1.2345426E-04,   1.2596705E-04
     +,   1.2838311E-04,   1.3069567E-04,   1.3289852E-04
     +,   1.3498581E-04,   1.3695224E-04,   1.3879288E-04
     +,   1.4050347E-04,   1.4208027E-04,   1.4351998E-04
     +,   1.4481992E-04,   1.4597799E-04,   1.4699272E-04
     +,   1.4786317E-04,   1.4858895E-04,   1.4917027E-04
     +,   1.4960792E-04,   1.4990325E-04,   1.5005807E-04
     +,   1.5007479E-04,   1.4995635E-04,   1.4970612E-04
     +,   1.4932796E-04,   1.4882631E-04,   1.4820586E-04
     +,   1.4747202E-04,   1.4663051E-04,   1.4568736E-04
     +,   1.4464934E-04,   1.4352344E-04,   1.4231735E-04
     +,   1.4103900E-04,   1.3969709E-04,   1.3830085E-04
     +,   1.3685993E-04,   1.3538497E-04,   1.3388734E-04
     +,   1.3237911E-04,   1.3087328E-04,   1.2938409E-04
     +,   1.2792695E-04,   1.2651841E-04,   1.2517642E-04
     +,   1.2392068E-04,   1.2277246E-04,   1.2175485E-04
     +,   1.2089281E-04,   1.2021346E-04,   1.1974590E-04
     +,   1.1952138E-04,   1.1957339E-04,   1.1993739E-04
     +,   1.2065103E-04,   1.2175374E-04,   1.2328669E-04
     +,   1.2529243E-04,   1.2781481E-04,   1.3089848E-04
     +,   1.3458860E-04,   1.3893042E-04,   1.4396936E-04
     +,   1.4975092E-04,   1.5631964E-04,   1.6372089E-04
     +,   1.7200063E-04,   1.8120572E-04,   1.9138567E-04
     +,   2.0259473E-04,   2.1489419E-04,   2.2835331E-04
     +,   2.4305331E-04,   2.5909170E-04,   2.7658438E-04
     +,   2.9566756E-04,   3.1650066E-04,   3.3926941E-04
     +,   3.6418324E-04,   3.9147132E-04,   4.2138150E-04
     +,   4.5417086E-04,   4.9009337E-04,   5.2938808E-04
     +,   5.7226903E-04,   6.1890815E-04,   6.6941831E-04
     +,   7.2384684E-04,   7.8217371E-04,   8.4430783E-04
     +,   9.1009540E-04,   9.7934110E-04,   1.0518428E-03
     +,   1.1274337E-03,   1.2060255E-03,   1.2876863E-03
     +,   1.3727047E-03,   1.4616458E-03,   1.5554052E-03
     +,   1.6552276E-03,   1.7626547E-03,   1.8794141E-03
     +,   2.0072353E-03,   2.1476126E-03,   2.3015384E-03
     +,   2.4692870E-03,   2.6503706E-03,   2.8437697E-03
     +,   3.0484952E-03,   3.2645243E-03,   3.4940832E-03
     +,   3.7429417E-03,   4.0213321E-03,   4.3440098E-03
     +,   4.7290260E-03,   5.1948573E-03,   5.7563432E-03
     +,   6.4202901E-03,   7.1819020E-03,   8.0229230E-03
     +,   8.9128856E-03,   9.8158764E-03,   1.0703621E-02
     +,   1.1569632E-02,   1.2433038E-02,   1.3328193E-02
     +,   1.4298433E-02,   1.5418090E-02,   1.6819380E-02
     +,   1.8654626E-02,   2.0980621E-02,   2.3685835E-02
     +,   2.6586302E-02,   2.9602593E-02,   3.2806534E-02
     +,   3.6306810E-02,   4.0071797E-02,   4.3820169E-02
     +,   4.7068458E-02,   4.9250633E-02,   5.0248194E-02
     +,   5.1068652E-02,   5.2979812E-02,   5.5693746E-02
     +,   5.7604764E-02,   5.8156345E-02,   5.8536340E-02
     +,   5.8959179E-02,   5.8007345E-02,   5.5512015E-02
     +,   5.2623056E-02,   4.9596947E-02,   4.5713753E-02
     +,   4.0749073E-02,   3.5277870E-02,   2.9845517E-02
     +,   2.4717228E-02,   2.0085435E-02,   1.6055491E-02
     +,   1.2622658E-02,   9.7669410E-03,   7.4713733E-03
     +,   5.6800540E-03,   4.3005538E-03,   3.2409516E-03
     +,   2.4317764E-03,   1.8229634E-03,   1.3740573E-03
     +,   1.0485975E-03,   8.1416662E-04,   6.4406788E-04
     +,   5.1826949E-04,   4.2280467E-04,   3.4844925E-04
     +,   2.8924670E-04,   2.4136169E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt114 = Yx/0.354857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9185223E-05,   2.0058231E-05
     +,   2.0948823E-05,   2.1855827E-05,   2.2777978E-05
     +,   2.3713903E-05,   2.4662140E-05,   2.5621131E-05
     +,   2.6589249E-05,   2.7564802E-05,   2.8546001E-05
     +,   2.9531006E-05,   3.0517931E-05,   3.1504835E-05
     +,   3.2489752E-05,   3.3470689E-05,   3.4445638E-05
     +,   3.5412591E-05,   3.6369551E-05,   3.7314541E-05
     +,   3.8245624E-05,   3.9160888E-05,   4.0058494E-05
     +,   4.0936695E-05,   4.1793763E-05,   4.2628119E-05
     +,   4.3438267E-05,   4.4222816E-05,   4.4980494E-05
     +,   4.5710174E-05,   4.6410842E-05,   4.7081638E-05
     +,   4.7721878E-05,   4.8330978E-05,   4.8908547E-05
     +,   4.9454335E-05,   4.9968265E-05,   5.0450373E-05
     +,   5.0900930E-05,   5.1320279E-05,   5.1708957E-05
     +,   5.2067619E-05,   5.2397063E-05,   5.2698182E-05
     +,   5.2972067E-05,   5.3219814E-05,   5.3442680E-05
     +,   5.3641961E-05,   5.3819065E-05,   5.3975440E-05
     +,   5.4112545E-05,   5.4231921E-05,   5.4335083E-05
     +,   5.4423559E-05,   5.4498909E-05,   5.4562573E-05
     +,   5.4616037E-05,   5.4660712E-05,   5.4697917E-05
     +,   5.4728949E-05,   5.4754990E-05,   5.4777123E-05
     +,   5.4796350E-05,   5.4813583E-05,   5.4829598E-05
     +,   5.4845041E-05,   5.4860488E-05,   5.4876367E-05
     +,   5.4893029E-05,   5.4910644E-05,   5.4929336E-05
     +,   5.4949094E-05,   5.4969802E-05,   5.4991247E-05
     +,   5.5013181E-05,   5.5035223E-05,   5.5056953E-05
     +,   5.5077886E-05,   5.5097506E-05,   5.5115270E-05
     +,   5.5130597E-05,   5.5142922E-05,   5.5151660E-05
     +,   5.5156288E-05,   5.5156281E-05,   5.5151144E-05
     +,   5.5140506E-05,   5.5124001E-05,   5.5101351E-05
     +,   5.5072367E-05,   5.5036984E-05,   5.4995202E-05
     +,   5.4947159E-05,   5.4893077E-05,   5.4833326E-05
     +,   5.4768374E-05,   5.4698823E-05,   5.4625409E-05
     +,   5.4548949E-05,   5.4470423E-05,   5.4390894E-05
     +,   5.4311553E-05,   5.4233693E-05,   5.4158696E-05
     +,   5.4088014E-05,   5.4023203E-05,   5.3965894E-05
     +,   5.3917738E-05,   5.3880460E-05,   5.3855809E-05
     +,   5.3845524E-05,   5.3851421E-05,   5.3875225E-05
     +,   5.3918713E-05,   5.3983571E-05,   5.4071494E-05
     +,   5.4184035E-05,   5.4322798E-05,   5.4489163E-05
     +,   5.4684522E-05,   5.4910121E-05,   5.5167086E-05
     +,   5.5456429E-05,   5.5779044E-05,   5.6135686E-05
     +,   5.6526940E-05,   5.6953304E-05,   5.7415094E-05
     +,   5.7912544E-05,   5.8445676E-05,   5.9014448E-05
     +,   5.9618662E-05,   6.0258066E-05,   6.0932241E-05
     +,   6.1640749E-05,   6.2383115E-05,   6.3158768E-05
     +,   6.3967149E-05,   6.4807733E-05,   6.5680106E-05
     +,   6.6583809E-05,   6.7518551E-05,   6.8484245E-05
     +,   6.9480986E-05,   7.0508999E-05,   7.1568909E-05
     +,   7.2661627E-05,   7.3788302E-05,   7.4950527E-05
     +,   7.6150354E-05,   7.7390221E-05,   7.8673009E-05
     +,   8.0002064E-05,   8.1381273E-05,   8.2814971E-05
     +,   8.4307969E-05,   8.5865438E-05,   8.7493077E-05
     +,   8.9197049E-05,   9.0983594E-05,   9.2859380E-05
     +,   9.4831332E-05,   9.6906333E-05,   9.9091252E-05
     +,   1.0139318E-04,   1.0381891E-04,   1.0637493E-04
     +,   1.0906748E-04,   1.1190250E-04,   1.1488568E-04
     +,   1.1802213E-04,   1.2131649E-04,   1.2477340E-04
     +,   1.2839735E-04,   1.3219249E-04,   1.3616338E-04
     +,   1.4031517E-04,   1.4465355E-04,   1.4918530E-04
     +,   1.5391894E-04,   1.5886514E-04,   1.6403632E-04
     +,   1.6944790E-04,   1.7511862E-04,   1.8107059E-04
     +,   1.8732900E-04,   1.9392259E-04,   2.0088375E-04
     +,   2.0824783E-04,   2.1605179E-04,   2.2433445E-04
     +,   2.3313508E-04,   2.4249109E-04,   2.5243667E-04
     +,   2.6300206E-04,   2.7421038E-04,   2.8607529E-04
     +,   2.9859922E-04,   3.1177254E-04,   3.2557099E-04
     +,   3.3995378E-04,   3.5486367E-04,   3.7022837E-04
     +,   3.8596080E-04,   4.0195990E-04,   4.1811774E-04
     +,   4.3432336E-04,   4.5046920E-04,   4.6646222E-04
     +,   4.8223673E-04,   4.9776927E-04,   5.1309500E-04
     +,   5.2833033E-04,   5.4369943E-04,   5.5956020E-04
     +,   5.7643431E-04,   5.9504021E-04,   6.1632926E-04
     +,   6.4151967E-04,   6.7212491E-04,   7.0998841E-04
     +,   7.5729837E-04,   8.1658585E-04,   8.9070114E-04
     +,   9.8276115E-04,   1.0960558E-03,   1.2339189E-03
     +,   1.3995951E-03,   1.5961328E-03,   1.8262810E-03
     +,   2.0924122E-03,   2.3964508E-03,   2.7397322E-03
     +,   3.1226221E-03,   3.5438007E-03,   3.9993166E-03
     +,   4.4813086E-03,   4.9767857E-03,   5.4671555E-03
     +,   5.9291022E-03,   6.3373861E-03,   6.6697290E-03
     +,   6.9130827E-03,   7.0694350E-03,   7.1589486E-03
     +,   7.2187111E-03,   7.2969887E-03,   7.4446360E-03
     +,   7.7068992E-03,   8.1188027E-03,   8.7057799E-03
     +,   9.4880983E-03,   1.0483464E-02,   1.1701495E-02
     +,   1.3128384E-02,   1.4712177E-02,   1.6371418E-02
     +,   1.8045688E-02,   1.9766839E-02,   2.1679780E-02
     +,   2.3964852E-02,   2.6726052E-02,   2.9919038E-02
     +,   3.3296399E-02,   3.6546249E-02,   3.9822768E-02
     +,   4.3791022E-02,   4.8605133E-02,   5.3507481E-02
     +,   5.7487976E-02,   5.9767660E-02,   6.0423255E-02
     +,   6.0155053E-02,   5.9390225E-02,   5.9025243E-02
     +,   6.0096227E-02,   6.1598010E-02,   6.1282791E-02
     +,   5.8256287E-02,   5.3173117E-02,   4.6898887E-02
     +,   3.9984457E-02,   3.2969527E-02,   2.6466941E-02
     +,   2.0860955E-02,   1.6193293E-02,   1.2361329E-02
     +,   9.2717642E-03,   6.8530049E-03,   5.0340677E-03
     +,   3.7260023E-03,   2.8158964E-03,   2.1853598E-03
     +,   1.7349520E-03,   1.3960882E-03,   1.1280024E-03
     +,   9.0875471E-04,   7.2683505E-04,   5.7588459E-04
     +,   4.5180524E-04,   3.5139851E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt115 = Yx/0.353
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4781776E-05,   1.5138899E-05
     +,   1.5497060E-05,   1.5856071E-05,   1.6215752E-05
     +,   1.6575934E-05,   1.6936458E-05,   1.7297169E-05
     +,   1.7657929E-05,   1.8018623E-05,   1.8379133E-05
     +,   1.8739365E-05,   1.9099234E-05,   1.9458674E-05
     +,   1.9817637E-05,   2.0176081E-05,   2.0533991E-05
     +,   2.0891363E-05,   2.1248205E-05,   2.1604556E-05
     +,   2.1960457E-05,   2.2315973E-05,   2.2671165E-05
     +,   2.3026150E-05,   2.3381013E-05,   2.3735891E-05
     +,   2.4090907E-05,   2.4446212E-05,   2.4801959E-05
     +,   2.5158321E-05,   2.5515474E-05,   2.5873596E-05
     +,   2.6232885E-05,   2.6593536E-05,   2.6955751E-05
     +,   2.7319737E-05,   2.7685695E-05,   2.8053826E-05
     +,   2.8424356E-05,   2.8797464E-05,   2.9173369E-05
     +,   2.9552259E-05,   2.9934319E-05,   3.0319739E-05
     +,   3.0708688E-05,   3.1101332E-05,   3.1497832E-05
     +,   3.1898326E-05,   3.2302967E-05,   3.2711858E-05
     +,   3.3125139E-05,   3.3542896E-05,   3.3965229E-05
     +,   3.4392240E-05,   3.4823970E-05,   3.5260535E-05
     +,   3.5701967E-05,   3.6148340E-05,   3.6599704E-05
     +,   3.7056121E-05,   3.7517639E-05,   3.7984330E-05
     +,   3.8456245E-05,   3.8933460E-05,   3.9416085E-05
     +,   3.9904186E-05,   4.0397910E-05,   4.0897376E-05
     +,   4.1402778E-05,   4.1914253E-05,   4.2432071E-05
     +,   4.2956453E-05,   4.3487704E-05,   4.4026125E-05
     +,   4.4572094E-05,   4.5126042E-05,   4.5688397E-05
     +,   4.6259647E-05,   4.6840341E-05,   4.7431091E-05
     +,   4.8032485E-05,   4.8645248E-05,   4.9270060E-05
     +,   4.9907710E-05,   5.0558974E-05,   5.1224710E-05
     +,   5.1905750E-05,   5.2602998E-05,   5.3317352E-05
     +,   5.4049691E-05,   5.4800999E-05,   5.5572142E-05
     +,   5.6363977E-05,   5.7177414E-05,   5.8013302E-05
     +,   5.8872371E-05,   5.9755414E-05,   6.0663020E-05
     +,   6.1595834E-05,   6.2554267E-05,   6.3538762E-05
     +,   6.4549531E-05,   6.5586755E-05,   6.6650347E-05
     +,   6.7740191E-05,   6.8856010E-05,   6.9997252E-05
     +,   7.1163209E-05,   7.2353076E-05,   7.3565825E-05
     +,   7.4800126E-05,   7.6054610E-05,   7.7327546E-05
     +,   7.8617151E-05,   7.9921287E-05,   8.1237791E-05
     +,   8.2564104E-05,   8.3897692E-05,   8.5235653E-05
     +,   8.6575041E-05,   8.7912755E-05,   8.9245499E-05
     +,   9.0569774E-05,   9.1882132E-05,   9.3179013E-05
     +,   9.4456605E-05,   9.5711257E-05,   9.6939155E-05
     +,   9.8136530E-05,   9.9299556E-05,   1.0042462E-04
     +,   1.0150786E-04,   1.0254580E-04,   1.0353491E-04
     +,   1.0447176E-04,   1.0535324E-04,   1.0617618E-04
     +,   1.0693775E-04,   1.0763525E-04,   1.0826632E-04
     +,   1.0882872E-04,   1.0932050E-04,   1.0974004E-04
     +,   1.1008595E-04,   1.1035714E-04,   1.1055288E-04
     +,   1.1067269E-04,   1.1071642E-04,   1.1068433E-04
     +,   1.1057689E-04,   1.1039501E-04,   1.1013988E-04
     +,   1.0981307E-04,   1.0941651E-04,   1.0895239E-04
     +,   1.0842342E-04,   1.0783268E-04,   1.0718355E-04
     +,   1.0647989E-04,   1.0572613E-04,   1.0492714E-04
     +,   1.0408834E-04,   1.0321593E-04,   1.0231695E-04
     +,   1.0139915E-04,   1.0047150E-04,   9.9544166E-05
     +,   9.8628836E-05,   9.7738783E-05,   9.6889300E-05
     +,   9.6097974E-05,   9.5385069E-05,   9.4773677E-05
     +,   9.4290284E-05,   9.3965049E-05,   9.3832292E-05
     +,   9.3930670E-05,   9.4303577E-05,   9.4999341E-05
     +,   9.6071490E-05,   9.7578726E-05,   9.9584970E-05
     +,   1.0215881E-04,   1.0537367E-04,   1.0930705E-04
     +,   1.1403958E-04,   1.1965417E-04,   1.2623549E-04
     +,   1.3386861E-04,   1.4263667E-04,   1.5262114E-04
     +,   1.6390007E-04,   1.7654581E-04,   1.9062465E-04
     +,   2.0619672E-04,   2.2331491E-04,   2.4202357E-04
     +,   2.6235922E-04,   2.8435298E-04,   3.0803046E-04
     +,   3.3341211E-04,   3.6051657E-04,   3.8936545E-04
     +,   4.1998623E-04,   4.5241322E-04,   4.8669870E-04
     +,   5.2291743E-04,   5.6117075E-04,   6.0159713E-04
     +,   6.4438285E-04,   6.8976713E-04,   7.3804398E-04
     +,   7.8956934E-04,   8.4475905E-04,   9.0407999E-04
     +,   9.6802658E-04,   1.0371008E-03,   1.1117810E-03
     +,   1.1924802E-03,   1.2794948E-03,   1.3729825E-03
     +,   1.4729331E-03,   1.5791624E-03,   1.6913563E-03
     +,   1.8091657E-03,   1.9323420E-03,   2.0609039E-03
     +,   2.1953506E-03,   2.3368148E-03,   2.4871258E-03
     +,   2.6486674E-03,   2.8240567E-03,   3.0156153E-03
     +,   3.2247484E-03,   3.4513485E-03,   3.6935816E-03
     +,   3.9479886E-03,   4.2100032E-03,   4.4747409E-03
     +,   4.7377739E-03,   4.9956897E-03,   5.2464860E-03
     +,   5.4901075E-03,   5.7293093E-03,   5.9708068E-03
     +,   6.2262639E-03,   6.5123960E-03,   6.8496950E-03
     +,   7.2598215E-03,   7.7621560E-03,   8.3705718E-03
     +,   9.0909703E-03,   9.9213338E-03,   1.0856663E-02
     +,   1.1897864E-02,   1.3057789E-02,   1.4352897E-02
     +,   1.5780535E-02,   1.7302420E-02,   1.8855654E-02
     +,   2.0378230E-02,   2.1835333E-02,   2.3287939E-02
     +,   2.4990730E-02,   2.7297683E-02,   3.0270219E-02
     +,   3.3533331E-02,   3.6897134E-02,   4.0736809E-02
     +,   4.4917125E-02,   4.8107903E-02,   4.9603429E-02
     +,   5.0649598E-02,   5.2579746E-02,   5.5273294E-02
     +,   5.8189396E-02,   6.1079562E-02,   6.3008882E-02
     +,   6.2468622E-02,   5.9194263E-02,   5.4323617E-02
     +,   4.8909567E-02,   4.3401796E-02,   3.7885442E-02
     +,   3.2302719E-02,   2.6755882E-02,   2.1579225E-02
     +,   1.7096624E-02,   1.3408735E-02,   1.0416149E-02
     +,   7.9768049E-03,   6.0045747E-03,   4.4604810E-03
     +,   3.3030051E-03,   2.4658029E-03,   1.8691004E-03
     +,   1.4407642E-03,   1.1270925E-03,   8.9239824E-04
     +,   7.1357610E-04,   5.7523948E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt116 = Yx/0.345333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt1168(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5395495E-05,   1.5940754E-05
     +,   1.6500708E-05,   1.7075621E-05,   1.7665727E-05
     +,   1.8271265E-05,   1.8892444E-05,   1.9529469E-05
     +,   2.0182508E-05,   2.0851745E-05,   2.1537297E-05
     +,   2.2239270E-05,   2.2957738E-05,   2.3692735E-05
     +,   2.4444262E-05,   2.5212279E-05,   2.5996691E-05
     +,   2.6797359E-05,   2.7614095E-05,   2.8446651E-05
     +,   2.9294730E-05,   3.0157949E-05,   3.1035885E-05
     +,   3.1928073E-05,   3.2833883E-05,   3.3752731E-05
     +,   3.4683890E-05,   3.5626581E-05,   3.6579957E-05
     +,   3.7543072E-05,   3.8514951E-05,   3.9494495E-05
     +,   4.0480580E-05,   4.1471980E-05,   4.2467418E-05
     +,   4.3465570E-05,   4.4465025E-05,   4.5464316E-05
     +,   4.6462006E-05,   4.7456477E-05,   4.8446211E-05
     +,   4.9429571E-05,   5.0404935E-05,   5.1370691E-05
     +,   5.2325162E-05,   5.3266718E-05,   5.4193726E-05
     +,   5.5104596E-05,   5.5997734E-05,   5.6871620E-05
     +,   5.7724763E-05,   5.8555775E-05,   5.9363250E-05
     +,   6.0145980E-05,   6.0902730E-05,   6.1632447E-05
     +,   6.2334148E-05,   6.3006977E-05,   6.3650172E-05
     +,   6.4263128E-05,   6.4845328E-05,   6.5396474E-05
     +,   6.5916312E-05,   6.6404806E-05,   6.6862056E-05
     +,   6.7288267E-05,   6.7683861E-05,   6.8049339E-05
     +,   6.8385401E-05,   6.8692883E-05,   6.8972746E-05
     +,   6.9226116E-05,   6.9454240E-05,   6.9658490E-05
     +,   6.9840375E-05,   7.0001530E-05,   7.0143658E-05
     +,   7.0268630E-05,   7.0378337E-05,   7.0474824E-05
     +,   7.0560156E-05,   7.0636503E-05,   7.0706075E-05
     +,   7.0771144E-05,   7.0834001E-05,   7.0896975E-05
     +,   7.0962407E-05,   7.1032664E-05,   7.1110102E-05
     +,   7.1197035E-05,   7.1295806E-05,   7.1408700E-05
     +,   7.1537943E-05,   7.1685732E-05,   7.1854185E-05
     +,   7.2045383E-05,   7.2261253E-05,   7.2503688E-05
     +,   7.2774463E-05,   7.3075193E-05,   7.3407435E-05
     +,   7.3772528E-05,   7.4171745E-05,   7.4606090E-05
     +,   7.5076481E-05,   7.5583615E-05,   7.6127988E-05
     +,   7.6709832E-05,   7.7329212E-05,   7.7985969E-05
     +,   7.8679615E-05,   7.9409503E-05,   8.0174592E-05
     +,   8.0973703E-05,   8.1805199E-05,   8.2667313E-05
     +,   8.3557832E-05,   8.4474392E-05,   8.5414140E-05
     +,   8.6374072E-05,   8.7350898E-05,   8.8340887E-05
     +,   8.9340123E-05,   9.0344474E-05,   9.1349495E-05
     +,   9.2350499E-05,   9.3342693E-05,   9.4321025E-05
     +,   9.5280368E-05,   9.6215437E-05,   9.7120981E-05
     +,   9.7991637E-05,   9.8822158E-05,   9.9607358E-05
     +,   1.0034219E-04,   1.0102184E-04,   1.0164172E-04
     +,   1.0219749E-04,   1.0268538E-04,   1.0310190E-04
     +,   1.0344416E-04,   1.0370969E-04,   1.0389687E-04
     +,   1.0400463E-04,   1.0403262E-04,   1.0398142E-04
     +,   1.0385230E-04,   1.0364763E-04,   1.0337062E-04
     +,   1.0302546E-04,   1.0261756E-04,   1.0215330E-04
     +,   1.0164026E-04,   1.0108725E-04,   1.0050431E-04
     +,   9.9902769E-05,   9.9295423E-05,   9.8696386E-05
     +,   9.8121251E-05,   9.7587297E-05,   9.7113239E-05
     +,   9.6719690E-05,   9.6428928E-05,   9.6265067E-05
     +,   9.6254298E-05,   9.6424585E-05,   9.6806143E-05
     +,   9.7431111E-05,   9.8333760E-05,   9.9550591E-05
     +,   1.0111995E-04,   1.0308209E-04,   1.0547920E-04
     +,   1.0835509E-04,   1.1175457E-04,   1.1572377E-04
     +,   1.2030954E-04,   1.2555862E-04,   1.3151734E-04
     +,   1.3823157E-04,   1.4574584E-04,   1.5410224E-04
     +,   1.6334010E-04,   1.7349613E-04,   1.8460340E-04
     +,   1.9668997E-04,   2.0977916E-04,   2.2388985E-04
     +,   2.3903608E-04,   2.5522491E-04,   2.7245929E-04
     +,   2.9073749E-04,   3.1005184E-04,   3.3039006E-04
     +,   3.5173752E-04,   3.7407698E-04,   3.9738778E-04
     +,   4.2164777E-04,   4.4683614E-04,   4.7293291E-04
     +,   4.9991783E-04,   5.2777247E-04,   5.5648229E-04
     +,   5.8603584E-04,   6.1642134E-04,   6.4763293E-04
     +,   6.7966868E-04,   7.1253069E-04,   7.4622873E-04
     +,   7.8079040E-04,   8.1626832E-04,   8.5275102E-04
     +,   8.9038431E-04,   9.2940038E-04,   9.7014109E-04
     +,   1.0130889E-03,   1.0588982E-03,   1.1084195E-03
     +,   1.1627043E-03,   1.2229807E-03,   1.2906210E-03
     +,   1.3670512E-03,   1.4536306E-03,   1.5515117E-03
     +,   1.6614965E-03,   1.7839042E-03,   1.9184900E-03
     +,   2.0644760E-03,   2.2206977E-03,   2.3858817E-03
     +,   2.5589976E-03,   2.7396891E-03,   2.9286281E-03
     +,   3.1276552E-03,   3.3395858E-03,   3.5676677E-03
     +,   3.8145981E-03,   4.0812809E-03,   4.3656910E-03
     +,   4.6622492E-03,   4.9622934E-03,   5.2561089E-03
     +,   5.5367905E-03,   5.8053238E-03,   6.0753520E-03
     +,   6.3751694E-03,   6.7442609E-03,   7.2231726E-03
     +,   7.8390390E-03,   8.5925236E-03,   9.4537511E-03
     +,   1.0370417E-02,   1.1285996E-02,   1.2161491E-02
     +,   1.2992866E-02,   1.3815726E-02,   1.4687910E-02
     +,   1.5649876E-02,   1.6686875E-02,   1.7731946E-02
     +,   1.8720245E-02,   1.9650443E-02,   2.0599943E-02
     +,   2.1696605E-02,   2.3076134E-02,   2.4825064E-02
     +,   2.6917901E-02,   2.9234568E-02,   3.1697791E-02
     +,   3.4358840E-02,   3.7243757E-02,   4.0121883E-02
     +,   4.2632181E-02,   4.4760562E-02,   4.6978712E-02
     +,   4.9701858E-02,   5.2693758E-02,   5.5119008E-02
     +,   5.6106638E-02,   5.5141255E-02,   5.2108072E-02
     +,   4.7334552E-02,   4.1548748E-02,   3.5579413E-02
     +,   3.0057039E-02,   2.5264498E-02,   2.1125183E-02
     +,   1.7413786E-02,   1.4028459E-02,   1.1038405E-02
     +,   8.5433191E-03,   6.5627038E-03,   5.0359801E-03
     +,   3.8696816E-03,   2.9759924E-03,   2.2876782E-03
     +,   1.7577240E-03,   1.3524162E-03,   1.0454778E-03
     +,   8.1491028E-04,   6.4221770E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt1168 = Yx/0.3154375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.7783513E-06,   9.9774188E-06
     +,   1.0182007E-05,   1.0392458E-05,   1.0609128E-05
     +,   1.0832395E-05,   1.1062651E-05,   1.1300307E-05
     +,   1.1545785E-05,   1.1799542E-05,   1.2062035E-05
     +,   1.2333745E-05,   1.2615167E-05,   1.2906817E-05
     +,   1.3209225E-05,   1.3522937E-05,   1.3848517E-05
     +,   1.4186540E-05,   1.4537592E-05,   1.4902282E-05
     +,   1.5281221E-05,   1.5675038E-05,   1.6084356E-05
     +,   1.6509844E-05,   1.6952126E-05,   1.7411870E-05
     +,   1.7889732E-05,   1.8386367E-05,   1.8902438E-05
     +,   1.9438585E-05,   1.9995459E-05,   2.0573701E-05
     +,   2.1173926E-05,   2.1796744E-05,   2.2442746E-05
     +,   2.3112487E-05,   2.3806513E-05,   2.4525318E-05
     +,   2.5269404E-05,   2.6039164E-05,   2.6835016E-05
     +,   2.7657299E-05,   2.8506285E-05,   2.9382218E-05
     +,   3.0285266E-05,   3.1215524E-05,   3.2173019E-05
     +,   3.3157714E-05,   3.4169476E-05,   3.5208090E-05
     +,   3.6273250E-05,   3.7364560E-05,   3.8481503E-05
     +,   3.9623537E-05,   4.0789888E-05,   4.1979794E-05
     +,   4.3192322E-05,   4.4426433E-05,   4.5680987E-05
     +,   4.6954712E-05,   4.8246242E-05,   4.9554099E-05
     +,   5.0876628E-05,   5.2212148E-05,   5.3558888E-05
     +,   5.4914824E-05,   5.6278033E-05,   5.7646295E-05
     +,   5.9017479E-05,   6.0389211E-05,   6.1759209E-05
     +,   6.3124950E-05,   6.4484018E-05,   6.5833796E-05
     +,   6.7171750E-05,   6.8495297E-05,   6.9801790E-05
     +,   7.1088558E-05,   7.2353039E-05,   7.3592659E-05
     +,   7.4804797E-05,   7.5987053E-05,   7.7136880E-05
     +,   7.8252000E-05,   7.9330079E-05,   8.0369005E-05
     +,   8.1366677E-05,   8.2321210E-05,   8.3230800E-05
     +,   8.4093837E-05,   8.4908854E-05,   8.5674576E-05
     +,   8.6389853E-05,   8.7053770E-05,   8.7665649E-05
     +,   8.8224930E-05,   8.8731300E-05,   8.9184628E-05
     +,   8.9585054E-05,   8.9932852E-05,   9.0228554E-05
     +,   9.0472895E-05,   9.0666785E-05,   9.0811343E-05
     +,   9.0907917E-05,   9.0957947E-05,   9.0963178E-05
     +,   9.0925365E-05,   9.0846559E-05,   9.0728878E-05
     +,   9.0574569E-05,   9.0386049E-05,   9.0165740E-05
     +,   8.9916255E-05,   8.9640242E-05,   8.9340421E-05
     +,   8.9019530E-05,   8.8680397E-05,   8.8325825E-05
     +,   8.7958666E-05,   8.7581728E-05,   8.7197848E-05
     +,   8.6809887E-05,   8.6420565E-05,   8.6032691E-05
     +,   8.5648950E-05,   8.5272055E-05,   8.4904648E-05
     +,   8.4549349E-05,   8.4208776E-05,   8.3885418E-05
     +,   8.3581843E-05,   8.3300532E-05,   8.3043997E-05
     +,   8.2814746E-05,   8.2615254E-05,   8.2448103E-05
     +,   8.2315819E-05,   8.2220999E-05,   8.2166312E-05
     +,   8.2154482E-05,   8.2188264E-05,   8.2270577E-05
     +,   8.2404302E-05,   8.2592509E-05,   8.2838327E-05
     +,   8.3144914E-05,   8.3515610E-05,   8.3953724E-05
     +,   8.4462692E-05,   8.5045955E-05,   8.5707004E-05
     +,   8.6449327E-05,   8.7276414E-05,   8.8191744E-05
     +,   8.9198722E-05,   9.0300666E-05,   9.1500864E-05
     +,   9.2802533E-05,   9.4208706E-05,   9.5722382E-05
     +,   9.7346609E-05,   9.9084245E-05,   1.0093815E-04
     +,   1.0291142E-04,   1.0500734E-04,   1.0722937E-04
     +,   1.0958139E-04,   1.1206807E-04,   1.1469489E-04
     +,   1.1746812E-04,   1.2039547E-04,   1.2348623E-04
     +,   1.2675177E-04,   1.3020502E-04,   1.3386198E-04
     +,   1.3774124E-04,   1.4186429E-04,   1.4625596E-04
     +,   1.5094482E-04,   1.5596334E-04,   1.6134753E-04
     +,   1.6713736E-04,   1.7337725E-04,   1.8011608E-04
     +,   1.8740659E-04,   1.9530587E-04,   2.0387667E-04
     +,   2.1318725E-04,   2.2331146E-04,   2.3433198E-04
     +,   2.4634050E-04,   2.5944039E-04,   2.7374882E-04
     +,   2.8940153E-04,   3.0655556E-04,   3.2539130E-04
     +,   3.4611690E-04,   3.6897219E-04,   3.9422908E-04
     +,   4.2218991E-04,   4.5318541E-04,   4.8757225E-04
     +,   5.2572310E-04,   5.6800857E-04,   6.1479182E-04
     +,   6.6640385E-04,   7.2311930E-04,   7.8513409E-04
     +,   8.5254677E-04,   9.2533079E-04,   1.0033102E-03
     +,   1.0861473E-03,   1.1733484E-03,   1.2642612E-03
     +,   1.3580960E-03,   1.4539688E-03,   1.5509677E-03
     +,   1.6482198E-03,   1.7449656E-03,   1.8406567E-03
     +,   1.9350166E-03,   2.0280774E-03,   2.1201959E-03
     +,   2.2120327E-03,   2.3044958E-03,   2.3986774E-03
     +,   2.4958262E-03,   2.5973574E-03,   2.7049191E-03
     +,   2.8205095E-03,   2.9466322E-03,   3.0864638E-03
     +,   3.2439439E-03,   3.4237837E-03,   3.6313552E-03
     +,   3.8723417E-03,   4.1520330E-03,   4.4744485E-03
     +,   4.8414101E-03,   5.2521010E-03,   5.7036416E-03
     +,   6.1929123E-03,   6.7189313E-03,   7.2842729E-03
     +,   7.8940615E-03,   8.5522123E-03,   9.2565697E-03
     +,   9.9961627E-03,   1.0754189E-02,   1.1517363E-02
     +,   1.2286185E-02,   1.3078135E-02,   1.3917748E-02
     +,   1.4817752E-02,   1.5767016E-02,   1.6742328E-02
     +,   1.7742343E-02,   1.8811911E-02,   2.0022202E-02
     +,   2.1411050E-02,   2.2929184E-02,   2.4434419E-02
     +,   2.5741272E-02,   2.6700519E-02,   2.7275249E-02
     +,   2.7604688E-02,   2.8016526E-02,   2.8863501E-02
     +,   3.0223567E-02,   3.1826742E-02,   3.3390943E-02
     +,   3.4973506E-02,   3.6878619E-02,   3.9191667E-02
     +,   4.1525181E-02,   4.3394506E-02,   4.4636585E-02
     +,   4.5136079E-02,   4.4473011E-02,   4.2259008E-02
     +,   3.8617261E-02,   3.4188859E-02,   2.9776128E-02
     +,   2.5880625E-02,   2.2464147E-02,   1.9178199E-02
     +,   1.5820790E-02,   1.2534676E-02,   9.6309939E-03
     +,   7.3231254E-03,   5.6223776E-03,   4.4031767E-03
     +,   3.5106514E-03,   2.8254210E-03,   2.2753936E-03
     +,   1.8227038E-03,   1.4477557E-03,   1.1391670E-03
     +,   8.8860060E-04,   6.8864203E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt118 = Yx/0.29668085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.8617211E-06,   5.9090871E-06
     +,   5.9562990E-06,   6.0035140E-06,   6.0509055E-06
     +,   6.0986549E-06,   6.1469682E-06,   6.1960550E-06
     +,   6.2461490E-06,   6.2974937E-06,   6.3503494E-06
     +,   6.4049909E-06,   6.4617107E-06,   6.5208169E-06
     +,   6.5826266E-06,   6.6474795E-06,   6.7157293E-06
     +,   6.7877381E-06,   6.8638901E-06,   6.9445796E-06
     +,   7.0302131E-06,   7.1212125E-06,   7.2180105E-06
     +,   7.3210535E-06,   7.4307895E-06,   7.5476901E-06
     +,   7.6722235E-06,   7.8048697E-06,   7.9461151E-06
     +,   8.0964492E-06,   8.2563647E-06,   8.4263593E-06
     +,   8.6069249E-06,   8.7985582E-06,   9.0017502E-06
     +,   9.2169848E-06,   9.4447414E-06,   9.6854883E-06
     +,   9.9396930E-06,   1.0207789E-05,   1.0490220E-05
     +,   1.0787398E-05,   1.1099721E-05,   1.1427563E-05
     +,   1.1771279E-05,   1.2131198E-05,   1.2507628E-05
     +,   1.2900838E-05,   1.3311076E-05,   1.3738560E-05
     +,   1.4183470E-05,   1.4645952E-05,   1.5126114E-05
     +,   1.5624057E-05,   1.6139789E-05,   1.6673337E-05
     +,   1.7224662E-05,   1.7793680E-05,   1.8380295E-05
     +,   1.8984352E-05,   1.9605672E-05,   2.0244041E-05
     +,   2.0899166E-05,   2.1570784E-05,   2.2258593E-05
     +,   2.2962198E-05,   2.3681270E-05,   2.4415342E-05
     +,   2.5164039E-05,   2.5926858E-05,   2.6703379E-05
     +,   2.7493061E-05,   2.8295466E-05,   2.9110039E-05
     +,   2.9936282E-05,   3.0773717E-05,   3.1621796E-05
     +,   3.2479998E-05,   3.3347842E-05,   3.4224871E-05
     +,   3.5110555E-05,   3.6004487E-05,   3.6906204E-05
     +,   3.7815320E-05,   3.8731410E-05,   3.9654162E-05
     +,   4.0583200E-05,   4.1518280E-05,   4.2459080E-05
     +,   4.3405391E-05,   4.4357039E-05,   4.5313827E-05
     +,   4.6275592E-05,   4.7242251E-05,   4.8213744E-05
     +,   4.9189970E-05,   5.0170951E-05,   5.1156610E-05
     +,   5.2147025E-05,   5.3142150E-05,   5.4142067E-05
     +,   5.5146756E-05,   5.6156332E-05,   5.7170721E-05
     +,   5.8190024E-05,   5.9214257E-05,   6.0243387E-05
     +,   6.1277336E-05,   6.2316125E-05,   6.3359665E-05
     +,   6.4407788E-05,   6.5460423E-05,   6.6517314E-05
     +,   6.7578323E-05,   6.8643123E-05,   6.9711488E-05
     +,   7.0783040E-05,   7.1857503E-05,   7.2934425E-05
     +,   7.4013464E-05,   7.5094249E-05,   7.6176351E-05
     +,   7.7259305E-05,   7.8342840E-05,   7.9426565E-05
     +,   8.0510188E-05,   8.1593505E-05,   8.2676306E-05
     +,   8.3758590E-05,   8.4840351E-05,   8.5921885E-05
     +,   8.7003464E-05,   8.8085704E-05,   8.9169342E-05
     +,   9.0255417E-05,   9.1345319E-05,   9.2440641E-05
     +,   9.3543356E-05,   9.4655894E-05,   9.5781201E-05
     +,   9.6922624E-05,   9.8084129E-05,   9.9270430E-05
     +,   1.0048692E-04,   1.0173972E-04,   1.0303600E-04
     +,   1.0438389E-04,   1.0579257E-04,   1.0727248E-04
     +,   1.0883541E-04,   1.1049458E-04,   1.1226466E-04
     +,   1.1416194E-04,   1.1620452E-04,   1.1841225E-04
     +,   1.2080652E-04,   1.2341060E-04,   1.2624955E-04
     +,   1.2934995E-04,   1.3273963E-04,   1.3644781E-04
     +,   1.4050465E-04,   1.4494048E-04,   1.4978561E-04
     +,   1.5507014E-04,   1.6082298E-04,   1.6707090E-04
     +,   1.7383795E-04,   1.8114517E-04,   1.8900933E-04
     +,   1.9744177E-04,   2.0644790E-04,   2.1602683E-04
     +,   2.2617079E-04,   2.3686289E-04,   2.4807945E-04
     +,   2.5978850E-04,   2.7194931E-04,   2.8451378E-04
     +,   2.9742808E-04,   3.1063292E-04,   3.2406539E-04
     +,   3.3766110E-04,   3.5135829E-04,   3.6510077E-04
     +,   3.7884008E-04,   3.9254123E-04,   4.0618732E-04
     +,   4.1978454E-04,   4.3336369E-04,   4.4698812E-04
     +,   4.6075528E-04,   4.7479855E-04,   4.8928737E-04
     +,   5.0442899E-04,   5.2046141E-04,   5.3764862E-04
     +,   5.5627018E-04,   5.7661202E-04,   5.9895153E-04
     +,   6.2353961E-04,   6.5058697E-04,   6.8025058E-04
     +,   7.1262079E-04,   7.4771035E-04,   7.8546262E-04
     +,   8.2575605E-04,   8.6841924E-04,   9.1326260E-04
     +,   9.6011924E-04,   1.0088816E-03,   1.0595433E-03
     +,   1.1122392E-03,   1.1672748E-03,   1.2251302E-03
     +,   1.2864451E-03,   1.3519813E-03,   1.4225750E-03
     +,   1.4990629E-03,   1.5822081E-03,   1.6726538E-03
     +,   1.7708832E-03,   1.8771961E-03,   1.9917032E-03
     +,   2.1143449E-03,   2.2448634E-03,   2.3827555E-03
     +,   2.5272288E-03,   2.6771759E-03,   2.8311952E-03
     +,   2.9877489E-03,   3.1455359E-03,   3.3040352E-03
     +,   3.4641644E-03,   3.6288416E-03,   3.8033316E-03
     +,   3.9949659E-03,   4.2121983E-03,   4.4630622E-03
     +,   4.7534169E-03,   5.0856466E-03,   5.4586818E-03
     +,   5.8700969E-03,   6.3201841E-03,   6.8165464E-03
     +,   7.3766341E-03,   8.0253873E-03,   8.7865805E-03
     +,   9.6692136E-03,   1.0653202E-02,   1.1681151E-02
     +,   1.2661872E-02,   1.3490863E-02,   1.4087865E-02
     +,   1.4441274E-02,   1.4638684E-02,   1.4861201E-02
     +,   1.5329672E-02,   1.6212724E-02,   1.7538186E-02
     +,   1.9166099E-02,   2.0851742E-02,   2.2355698E-02
     +,   2.3533627E-02,   2.4386393E-02,   2.5071105E-02
     +,   2.5833346E-02,   2.6847478E-02,   2.8079806E-02
     +,   2.9345270E-02,   3.0549085E-02,   3.1841699E-02
     +,   3.3434495E-02,   3.5230167E-02,   3.6722265E-02
     +,   3.7348375E-02,   3.6957331E-02,   3.5924662E-02
     +,   3.4779206E-02,   3.3707675E-02,   3.2481857E-02
     +,   3.0799393E-02,   2.8558167E-02,   2.5852453E-02
     +,   2.2839552E-02,   1.9654816E-02,   1.6421923E-02
     +,   1.3295124E-02,   1.0450565E-02,   8.0253240E-03
     +,   6.0716495E-03,   4.5624711E-03,   3.4291667E-03
     +,   2.5939606E-03,   1.9860491E-03,   1.5459227E-03
     +,   1.2260377E-03,   9.9006947E-04,   8.1174995E-04
     +,   6.7301514E-04,   5.6203327E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt119 = Yx/0.267787234042553
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3697819E-06,   2.4673898E-06
     +,   2.5685915E-06,   2.6735202E-06,   2.7823144E-06
     +,   2.8951199E-06,   3.0120855E-06,   3.1333689E-06
     +,   3.2591288E-06,   3.3895383E-06,   3.5247701E-06
     +,   3.6650047E-06,   3.8104279E-06,   3.9612364E-06
     +,   4.1176272E-06,   4.2798088E-06,   4.4479930E-06
     +,   4.6224018E-06,   4.8032607E-06,   4.9908040E-06
     +,   5.1852699E-06,   5.3869062E-06,   5.5959626E-06
     +,   5.8127098E-06,   6.0374018E-06,   6.2703220E-06
     +,   6.5117488E-06,   6.7619703E-06,   7.0212809E-06
     +,   7.2899802E-06,   7.5683820E-06,   7.8567973E-06
     +,   8.1555545E-06,   8.4649810E-06,   8.7854178E-06
     +,   9.1172124E-06,   9.4607158E-06,   9.8162882E-06
     +,   1.0184321E-05,   1.0565163E-05,   1.0959226E-05
     +,   1.1366905E-05,   1.1788602E-05,   1.2224737E-05
     +,   1.2675740E-05,   1.3142040E-05,   1.3624092E-05
     +,   1.4122349E-05,   1.4637278E-05,   1.5169353E-05
     +,   1.5719066E-05,   1.6286907E-05,   1.6873379E-05
     +,   1.7479018E-05,   1.8104305E-05,   1.8749803E-05
     +,   1.9416027E-05,   2.0103524E-05,   2.0812822E-05
     +,   2.1544474E-05,   2.2299009E-05,   2.3076993E-05
     +,   2.3878894E-05,   2.4705276E-05,   2.5556672E-05
     +,   2.6433525E-05,   2.7336358E-05,   2.8265578E-05
     +,   2.9221657E-05,   3.0204934E-05,   3.1215845E-05
     +,   3.2254615E-05,   3.3321601E-05,   3.4416957E-05
     +,   3.5540867E-05,   3.6693473E-05,   3.7874775E-05
     +,   3.9084691E-05,   4.0323139E-05,   4.1589974E-05
     +,   4.2884785E-05,   4.4207314E-05,   4.5556968E-05
     +,   4.6933248E-05,   4.8335372E-05,   4.9762639E-05
     +,   5.1214018E-05,   5.2688600E-05,   5.4185108E-05
     +,   5.5702349E-05,   5.7238980E-05,   5.8793474E-05
     +,   6.0364149E-05,   6.1949344E-05,   6.3547268E-05
     +,   6.5155909E-05,   6.6773326E-05,   6.8397319E-05
     +,   7.0025773E-05,   7.1656359E-05,   7.3286821E-05
     +,   7.4914678E-05,   7.6537610E-05,   7.8153113E-05
     +,   7.9758735E-05,   8.1352118E-05,   8.2930754E-05
     +,   8.4492196E-05,   8.6034168E-05,   8.7554399E-05
     +,   8.9050598E-05,   9.0520734E-05,   9.1962705E-05
     +,   9.3374743E-05,   9.4755007E-05,   9.6101983E-05
     +,   9.7414180E-05,   9.8690449E-05,   9.9929646E-05
     +,   1.0113099E-04,   1.0229382E-04,   1.0341775E-04
     +,   1.0450253E-04,   1.0554831E-04,   1.0655532E-04
     +,   1.0752415E-04,   1.0845562E-04,   1.0935077E-04
     +,   1.1021103E-04,   1.1103797E-04,   1.1183357E-04
     +,   1.1260005E-04,   1.1334000E-04,   1.1405616E-04
     +,   1.1475178E-04,   1.1543046E-04,   1.1609607E-04
     +,   1.1675290E-04,   1.1740565E-04,   1.1805948E-04
     +,   1.1871992E-04,   1.1939304E-04,   1.2008534E-04
     +,   1.2080398E-04,   1.2155648E-04,   1.2235100E-04
     +,   1.2319643E-04,   1.2410205E-04,   1.2507786E-04
     +,   1.2613450E-04,   1.2728327E-04,   1.2853606E-04
     +,   1.2990531E-04,   1.3140414E-04,   1.3304631E-04
     +,   1.3484592E-04,   1.3681751E-04,   1.3897601E-04
     +,   1.4133679E-04,   1.4391493E-04,   1.4672588E-04
     +,   1.4978471E-04,   1.5310608E-04,   1.5670405E-04
     +,   1.6059181E-04,   1.6478164E-04,   1.6928422E-04
     +,   1.7410840E-04,   1.7926132E-04,   1.8474789E-04
     +,   1.9057015E-04,   1.9672707E-04,   2.0321498E-04
     +,   2.1002680E-04,   2.1715138E-04,   2.2457441E-04
     +,   2.3227812E-04,   2.4024044E-04,   2.4843600E-04
     +,   2.5683656E-04,   2.6541128E-04,   2.7412621E-04
     +,   2.8294558E-04,   2.9183316E-04,   3.0075238E-04
     +,   3.0966665E-04,   3.1854055E-04,   3.2734149E-04
     +,   3.3604068E-04,   3.4461162E-04,   3.5303444E-04
     +,   3.6129481E-04,   3.6938442E-04,   3.7730215E-04
     +,   3.8505576E-04,   3.9266166E-04,   4.0014490E-04
     +,   4.0754193E-04,   4.1490022E-04,   4.2228081E-04
     +,   4.2975839E-04,   4.3742385E-04,   4.4538695E-04
     +,   4.5377816E-04,   4.6275047E-04,   4.7248296E-04
     +,   4.8318395E-04,   4.9509131E-04,   5.0847745E-04
     +,   5.2365242E-04,   5.4096832E-04,   5.6082261E-04
     +,   5.8366550E-04,   6.1000913E-04,   6.4043590E-04
     +,   6.7560218E-04,   7.1624893E-04,   7.6320377E-04
     +,   8.1737753E-04,   8.7974168E-04,   9.5131708E-04
     +,   1.0331321E-03,   1.1261676E-03,   1.2313038E-03
     +,   1.3492623E-03,   1.4805397E-03,   1.6253568E-03
     +,   1.7836621E-03,   1.9552156E-03,   2.1397513E-03
     +,   2.3372511E-03,   2.5482948E-03,   2.7744093E-03
     +,   3.0182037E-03,   3.2831451E-03,   3.5730007E-03
     +,   3.8908096E-03,   4.2376406E-03,   4.6113618E-03
     +,   5.0056167E-03,   5.4090433E-03,   5.8051855E-03
     +,   6.1737574E-03,   6.4943763E-03,   6.7533874E-03
     +,   6.9531854E-03,   7.1211918E-03,   7.3133805E-03
     +,   7.6068272E-03,   8.0786217E-03,   8.7744370E-03
     +,   9.6783172E-03,   1.0701275E-02,   1.1703264E-02
     +,   1.2547391E-02,   1.3162438E-02,   1.3579431E-02
     +,   1.3920785E-02,   1.4348901E-02,   1.5003859E-02
     +,   1.5961509E-02,   1.7220249E-02,   1.8696519E-02
     +,   2.0226678E-02,   2.1639824E-02,   2.2930121E-02
     +,   2.4359114E-02,   2.6252657E-02,   2.8595785E-02
     +,   3.0896481E-02,   3.2549091E-02,   3.3276577E-02
     +,   3.3159502E-02,   3.2438923E-02,   3.1500679E-02
     +,   3.0844767E-02,   3.0750789E-02,   3.1005675E-02
     +,   3.1115644E-02,   3.0725768E-02,   2.9732902E-02
     +,   2.8146267E-02,   2.6060591E-02,   2.3705162E-02
     +,   2.1329330E-02,   1.9032024E-02,   1.6770972E-02
     +,   1.4508931E-02,   1.2296290E-02,   1.0229042E-02
     +,   8.3760461E-03,   6.7552961E-03,   5.3581866E-03
     +,   4.1754316E-03,   3.2023119E-03,   2.4292925E-03
     +,   1.8353929E-03,   1.3898192E-03,   1.0590955E-03
     +,   8.1329100E-04,   6.2907074E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt120 = Yx/0.246521739130435
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.2208164E-05,   6.4622960E-05
     +,   6.7128713E-05,   6.9728339E-05,   7.2424802E-05
     +,   7.5220792E-05,   7.8118923E-05,   8.1121601E-05
     +,   8.4230975E-05,   8.7449109E-05,   9.0777627E-05
     +,   9.4217990E-05,   9.7771364E-05,   1.0143864E-04
     +,   1.0522042E-04,   1.0911720E-04,   1.1312921E-04
     +,   1.1725658E-04,   1.2149943E-04,   1.2585794E-04
     +,   1.3033256E-04,   1.3492402E-04,   1.3963362E-04
     +,   1.4446366E-04,   1.4941688E-04,   1.5449805E-04
     +,   1.5971302E-04,   1.6506968E-04,   1.7057841E-04
     +,   1.7625217E-04,   1.8210706E-04,   1.8816293E-04
     +,   1.9444358E-04,   2.0097749E-04,   2.0779826E-04
     +,   2.1494509E-04,   2.2246325E-04,   2.3040468E-04
     +,   2.3882893E-04,   2.4780200E-04,   2.5739893E-04
     +,   2.6770277E-04,   2.7880483E-04,   2.9080568E-04
     +,   3.0381462E-04,   3.1794983E-04,   3.3333901E-04
     +,   3.5011864E-04,   3.6843496E-04,   3.8844440E-04
     +,   4.1031503E-04,   4.3422918E-04,   4.6038657E-04
     +,   4.8901141E-04,   5.2035664E-04,   5.5471854E-04
     +,   5.9244409E-04,   6.3394604E-04,   6.7971437E-04
     +,   7.3032791E-04,   7.8646088E-04,   8.4888533E-04
     +,   9.1845944E-04,   9.9612924E-04,   1.0829042E-03
     +,   1.1798355E-03,   1.2880298E-03,   1.4086273E-03
     +,   1.5428578E-03,   1.6920597E-03,   1.8577980E-03
     +,   2.0419275E-03,   2.2467596E-03,   2.4751478E-03
     +,   2.7306266E-03,   3.0174733E-03,   3.3406825E-03
     +,   3.7058976E-03,   4.1192863E-03,   4.5873015E-03
     +,   5.1163072E-03,   5.7121716E-03,   6.3794386E-03
     +,   7.1205692E-03,   7.9351151E-03,   8.8199498E-03
     +,   9.7703617E-03,   1.0782551E-02,   1.1856057E-02
     +,   1.2996855E-02,   1.4221017E-02,   1.5560518E-02
     +,   1.7069073E-02,   1.8821482E-02,   2.0898912E-02
     +,   2.3362502E-02,   2.6226470E-02,   2.9438829E-02
     +,   3.2869440E-02,   3.6303718E-02,   3.9464306E-02
     +,   4.2078376E-02,   4.3977506E-02,   4.5175195E-02
     +,   4.5872495E-02,   4.6363465E-02,   4.6874627E-02
     +,   4.7440436E-02,   4.7912199E-02,   4.8085805E-02
     +,   4.7817044E-02,   4.7031991E-02,   4.5664854E-02
     +,   4.3629460E-02,   4.0885687E-02,   3.7556395E-02
     +,   3.3974279E-02,   3.0579794E-02,   2.7726768E-02
     +,   2.5540026E-02,   2.3919765E-02,   2.2660693E-02
     +,   2.1580543E-02,   2.0579889E-02,   1.9627908E-02
     +,   1.8718889E-02,   1.7843429E-02,   1.6988434E-02
     +,   1.6149651E-02,   1.5338184E-02,   1.4573064E-02
     +,   1.3867426E-02,   1.3218407E-02,   1.2607342E-02
     +,   1.2008335E-02,   1.1399147E-02,   1.0768911E-02
     +,   1.0119996E-02,   9.4650686E-03,   8.8219391E-03
     +,   8.2084704E-03,   7.6388875E-03,   7.1220379E-03
     +,   6.6614090E-03,   6.2560290E-03,   5.9017660E-03
     +,   5.5926722E-03,   5.3220484E-03,   5.0830841E-03
     +,   4.8692697E-03,   4.6745739E-03,   4.4935704E-03
     +,   4.3214848E-03,   4.1542724E-03,   3.9887344E-03
     +,   3.8225891E-03,   3.6545142E-03,   3.4841038E-03
     +,   3.3117866E-03,   3.1387005E-03,   2.9664701E-03
     +,   2.7970190E-03,   2.6323861E-03,   2.4745439E-03
     +,   2.3252526E-03,   2.1859750E-03,   2.0578343E-03
     +,   1.9415865E-03,   1.8376351E-03,   1.7460753E-03
     +,   1.6667412E-03,   1.5992576E-03,   1.5430819E-03
     +,   1.4975624E-03,   1.4619698E-03,   1.4355265E-03
     +,   1.4174287E-03,   1.4068614E-03,   1.4030121E-03
     +,   1.4050739E-03,   1.4122537E-03,   1.4237785E-03
     +,   1.4388949E-03,   1.4568785E-03,   1.4770404E-03
     +,   1.4987306E-03,   1.5213428E-03,   1.5443268E-03
     +,   1.5671878E-03,   1.5894929E-03,   1.6108713E-03
     +,   1.6310191E-03,   1.6496945E-03,   1.6667162E-03
     +,   1.6819566E-03,   1.6953440E-03,   1.7068414E-03
     +,   1.7164522E-03,   1.7242056E-03,   1.7301489E-03
     +,   1.7343429E-03,   1.7368551E-03,   1.7377550E-03
     +,   1.7371076E-03,   1.7349765E-03,   1.7314177E-03
     +,   1.7264796E-03,   1.7202081E-03,   1.7126452E-03
     +,   1.7038264E-03,   1.6937917E-03,   1.6825792E-03
     +,   1.6702295E-03,   1.6567854E-03,   1.6422968E-03
     +,   1.6268115E-03,   1.6103860E-03,   1.5930771E-03
     +,   1.5749423E-03,   1.5560419E-03,   1.5364342E-03
     +,   1.5161738E-03,   1.4953157E-03,   1.4739123E-03
     +,   1.4520080E-03,   1.4296480E-03,   1.4068701E-03
     +,   1.3837115E-03,   1.3602038E-03,   1.3363749E-03
     +,   1.3122547E-03,   1.2878684E-03,   1.2632411E-03
     +,   1.2383956E-03,   1.2133584E-03,   1.1881521E-03
     +,   1.1628030E-03,   1.1373376E-03,   1.1117849E-03
     +,   1.0861746E-03,   1.0605354E-03,   1.0349015E-03
     +,   1.0093090E-03,   9.8379247E-04,   9.5838727E-04
     +,   9.3313458E-04,   9.0807205E-04,   8.8323932E-04
     +,   8.5867371E-04,   8.3441567E-04,   8.1050035E-04
     +,   7.8696158E-04,   7.6383277E-04,   7.4114220E-04
     +,   7.1891502E-04,   6.9717143E-04,   6.7592814E-04
     +,   6.5519736E-04,   6.3498592E-04,   6.1529485E-04
     +,   5.9612287E-04,   5.7746301E-04,   5.5930472E-04
     +,   5.4163340E-04,   5.2443316E-04,   5.0768425E-04
     +,   4.9136567E-04,   4.7545604E-04,   4.5993383E-04
     +,   4.4477734E-04,   4.2996442E-04,   4.1547575E-04
     +,   4.0129398E-04,   3.8740199E-04,   3.7378527E-04
     +,   3.6043284E-04,   3.4733396E-04,   3.3448267E-04
     +,   3.2187265E-04,   3.0950180E-04,   2.9736827E-04
     +,   2.8547339E-04,   2.7381870E-04,   2.6240814E-04
     +,   2.5124539E-04,   2.4033591E-04,   2.2968499E-04
     +,   2.1929821E-04,   2.0918157E-04,   1.9934018E-04
     +,   1.8977989E-04,   1.8050468E-04,   1.7151947E-04
     +,   1.6282685E-04,   1.5443013E-04,   1.4633038E-04
     +,   1.3852914E-04,   1.3102588E-04,   1.2382018E-04
     +,   1.1690983E-04,   1.1029267E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt75 = Yx/0.4165
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4790973E-05,   4.6097655E-05
     +,   4.7430127E-05,   4.8789097E-05,   5.0175429E-05
     +,   5.1590079E-05,   5.3034200E-05,   5.4509095E-05
     +,   5.6016252E-05,   5.7557449E-05,   5.9134651E-05
     +,   6.0750092E-05,   6.2406354E-05,   6.4106345E-05
     +,   6.5853383E-05,   6.7651134E-05,   6.9503818E-05
     +,   7.1416078E-05,   7.3393188E-05,   7.5440978E-05
     +,   7.7565870E-05,   7.9775120E-05,   8.2076564E-05
     +,   8.4479041E-05,   8.6992011E-05,   8.9626061E-05
     +,   9.2392591E-05,   9.5303963E-05,   9.8373654E-05
     +,   1.0161622E-04,   1.0504726E-04,   1.0868356E-04
     +,   1.1254306E-04,   1.1664483E-04,   1.2100926E-04
     +,   1.2565772E-04,   1.3061300E-04,   1.3589884E-04
     +,   1.4154051E-04,   1.4756396E-04,   1.5399675E-04
     +,   1.6086713E-04,   1.6820470E-04,   1.7603992E-04
     +,   1.8440413E-04,   1.9332962E-04,   2.0284941E-04
     +,   2.1299721E-04,   2.2380726E-04,   2.3531413E-04
     +,   2.4755261E-04,   2.6055731E-04,   2.7436254E-04
     +,   2.8900270E-04,   3.0450986E-04,   3.2091630E-04
     +,   3.3825173E-04,   3.5654433E-04,   3.7581971E-04
     +,   3.9610089E-04,   4.1740786E-04,   4.3975768E-04
     +,   4.6316281E-04,   4.8763343E-04,   5.1317672E-04
     +,   5.3979410E-04,   5.6748668E-04,   5.9625023E-04
     +,   6.2608154E-04,   6.5697450E-04,   6.8892882E-04
     +,   7.2194508E-04,   7.5603899E-04,   7.9124072E-04
     +,   8.2760950E-04,   8.6524594E-04,   9.0430293E-04
     +,   9.4500900E-04,   9.8769192E-04,   1.0328031E-03
     +,   1.0809356E-03,   1.1328626E-03,   1.1895468E-03
     +,   1.2521722E-03,   1.3221398E-03,   1.4010840E-03
     +,   1.4908480E-03,   1.5934807E-03,   1.7111938E-03
     +,   1.8463597E-03,   2.0015081E-03,   2.1793651E-03
     +,   2.3829741E-03,   2.6159270E-03,   2.8826355E-03
     +,   3.1886117E-03,   3.5407490E-03,   3.9471504E-03
     +,   4.4167414E-03,   4.9581435E-03,   5.5784364E-03
     +,   6.2815971E-03,   7.0676245E-03,   7.9321489E-03
     +,   8.8673513E-03,   9.8635703E-03,   1.0911555E-02
     +,   1.2004958E-02,   1.3142668E-02,   1.4330006E-02
     +,   1.5579483E-02,   1.6911699E-02,   1.8355733E-02
     +,   1.9948568E-02,   2.1729829E-02,   2.3734506E-02
     +,   2.5988568E-02,   2.8509997E-02,   3.1301890E-02
     +,   3.4329850E-02,   3.7506804E-02,   4.0712640E-02
     +,   4.3822419E-02,   4.6693388E-02,   4.9140096E-02
     +,   5.0990485E-02,   5.2198835E-02,   5.2868389E-02
     +,   5.3139213E-02,   5.3072982E-02,   5.2657865E-02
     +,   5.1874135E-02,   5.0709974E-02,   4.9132358E-02
     +,   4.7094278E-02,   4.4583943E-02,   4.1656204E-02
     +,   3.8430318E-02,   3.5088897E-02,   3.1868093E-02
     +,   2.8996591E-02,   2.6599223E-02,   2.4651652E-02
     +,   2.3029691E-02,   2.1600962E-02,   2.0281890E-02
     +,   1.9037489E-02,   1.7853662E-02,   1.6717339E-02
     +,   1.5612957E-02,   1.4527041E-02,   1.3453222E-02
     +,   1.2394612E-02,   1.1364010E-02,   1.0381723E-02
     +,   9.4706565E-03,   8.6498940E-03,   7.9294434E-03
     +,   7.3079919E-03,   6.7740604E-03,   6.3096173E-03
     +,   5.8946940E-03,   5.5114538E-03,   5.1467279E-03
     +,   4.7929725E-03,   4.4479230E-03,   4.1133673E-03
     +,   3.7935390E-03,   3.4935335E-03,   3.2180690E-03
     +,   2.9707330E-03,   2.7535665E-03,   2.5670866E-03
     +,   2.4105483E-03,   2.2823294E-03,   2.1802750E-03
     +,   2.1020300E-03,   2.0452801E-03,   2.0078558E-03
     +,   1.9878161E-03,   1.9834421E-03,   1.9932184E-03
     +,   2.0157753E-03,   2.0498557E-03,   2.0942497E-03
     +,   2.1477579E-03,   2.2091465E-03,   2.2771237E-03
     +,   2.3503231E-03,   2.4272767E-03,   2.5064507E-03
     +,   2.5862467E-03,   2.6650350E-03,   2.7412006E-03
     +,   2.8132009E-03,   2.8796068E-03,   2.9391511E-03
     +,   2.9907802E-03,   3.0336790E-03,   3.0673034E-03
     +,   3.0913639E-03,   3.1058220E-03,   3.1108749E-03
     +,   3.1069012E-03,   3.0944294E-03,   3.0740860E-03
     +,   3.0465631E-03,   3.0125622E-03,   2.9727833E-03
     +,   2.9278970E-03,   2.8785355E-03,   2.8253100E-03
     +,   2.7687985E-03,   2.7095661E-03,   2.6481748E-03
     +,   2.5851999E-03,   2.5212259E-03,   2.4568476E-03
     +,   2.3926604E-03,   2.3292471E-03,   2.2671565E-03
     +,   2.2068825E-03,   2.1488445E-03,   2.0933719E-03
     +,   2.0406798E-03,   1.9908710E-03,   1.9439346E-03
     +,   1.8997482E-03,   1.8580890E-03,   1.8186524E-03
     +,   1.7810832E-03,   1.7449821E-03,   1.7099412E-03
     +,   1.6755599E-03,   1.6414714E-03,   1.6073537E-03
     +,   1.5729399E-03,   1.5380358E-03,   1.5025138E-03
     +,   1.4663141E-03,   1.4294437E-03,   1.3919640E-03
     +,   1.3539881E-03,   1.3156618E-03,   1.2771566E-03
     +,   1.2386617E-03,   1.2003677E-03,   1.1624577E-03
     +,   1.1251026E-03,   1.0884552E-03,   1.0526421E-03
     +,   1.0177625E-03,   9.8388898E-04,   9.5106807E-04
     +,   9.1931765E-04,   8.8863162E-04,   8.5898640E-04
     +,   8.3034008E-04,   8.0263754E-04,   7.7581359E-04
     +,   7.4979808E-04,   7.2452059E-04,   6.9990702E-04
     +,   6.7588867E-04,   6.5240246E-04,   6.2939088E-04
     +,   6.0680415E-04,   5.8460154E-04,   5.6275248E-04
     +,   5.4123299E-04,   5.2002759E-04,   4.9913110E-04
     +,   4.7854509E-04,   4.5827596E-04,   4.3833611E-04
     +,   4.1874417E-04,   3.9951957E-04,   3.8068678E-04
     +,   3.6226903E-04,   3.4429299E-04,   3.2678206E-04
     +,   3.0976121E-04,   2.9325119E-04,   2.7727318E-04
     +,   2.6184326E-04,   2.4697671E-04,   2.3268405E-04
     +,   2.1897278E-04,   2.0584829E-04,   1.9331099E-04
     +,   1.8135978E-04,   1.6998904E-04,   1.5919184E-04
     +,   1.4895744E-04,   1.3927395E-04,   1.3012644E-04
     +,   1.2149928E-04,   1.1337453E-04,   1.0573398E-04
     +,   9.8557735E-05,   9.1826085E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt80 = Yx/0.44156
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9407485E-05,   4.0618786E-05
     +,   4.1899759E-05,   4.3255684E-05,   4.4691951E-05
     +,   4.6214122E-05,   4.7827842E-05,   4.9538867E-05
     +,   5.1352927E-05,   5.3275853E-05,   5.5313314E-05
     +,   5.7470923E-05,   5.9754100E-05,   6.2168052E-05
     +,   6.4717671E-05,   6.7407520E-05,   7.0241738E-05
     +,   7.3223971E-05,   7.6357275E-05,   7.9644124E-05
     +,   8.3086328E-05,   8.6684864E-05,   9.0439986E-05
     +,   9.4351250E-05,   9.8416953E-05,   1.0263489E-04
     +,   1.0700164E-04,   1.1151306E-04,   1.1616393E-04
     +,   1.2094819E-04,   1.2585883E-04,   1.3088819E-04
     +,   1.3602774E-04,   1.4126828E-04,   1.4660017E-04
     +,   1.5201322E-04,   1.5749708E-04,   1.6304106E-04
     +,   1.6863487E-04,   1.7426808E-04,   1.7993094E-04
     +,   1.8561428E-04,   1.9130985E-04,   1.9701043E-04
     +,   2.0271013E-04,   2.0840490E-04,   2.1409210E-04
     +,   2.1977151E-04,   2.2544483E-04,   2.3111669E-04
     +,   2.3679402E-04,   2.4248686E-04,   2.4820815E-04
     +,   2.5397420E-04,   2.5980419E-04,   2.6572164E-04
     +,   2.7175256E-04,   2.7792723E-04,   2.8427906E-04
     +,   2.9084535E-04,   2.9766720E-04,   3.0478899E-04
     +,   3.1225829E-04,   3.2012674E-04,   3.2844947E-04
     +,   3.3728385E-04,   3.4669164E-04,   3.5673604E-04
     +,   3.6748458E-04,   3.7900565E-04,   3.9137102E-04
     +,   4.0465375E-04,   4.1892860E-04,   4.3427054E-04
     +,   4.5075637E-04,   4.6846262E-04,   4.8746413E-04
     +,   5.0783495E-04,   5.2964734E-04,   5.5297185E-04
     +,   5.7787332E-04,   6.0441560E-04,   6.3265429E-04
     +,   6.6264410E-04,   6.9442979E-04,   7.2805618E-04
     +,   7.6355838E-04,   8.0097123E-04,   8.4032340E-04
     +,   8.8164414E-04,   9.2496508E-04,   9.7031880E-04
     +,   1.0177456E-03,   1.0673030E-03,   1.1190658E-03
     +,   1.1731343E-03,   1.2296588E-03,   1.2888383E-03
     +,   1.3509617E-03,   1.4164237E-03,   1.4857727E-03
     +,   1.5597383E-03,   1.6392984E-03,   1.7256982E-03
     +,   1.8205128E-03,   1.9256653E-03,   2.0434260E-03
     +,   2.1764087E-03,   2.3275523E-03,   2.5000770E-03
     +,   2.6974105E-03,   2.9231671E-03,   3.1810170E-03
     +,   3.4746171E-03,   3.8073133E-03,   4.1819122E-03
     +,   4.6001798E-03,   5.0624628E-03,   5.5672228E-03
     +,   6.1110226E-03,   6.6887997E-03,   7.2948420E-03
     +,   7.9245549E-03,   8.5769463E-03,   9.2573622E-03
     +,   9.9795563E-03,   1.0766369E-02,   1.1647698E-02
     +,   1.2656889E-02,   1.3826058E-02,   1.5182482E-02
     +,   1.6744245E-02,   1.8516315E-02,   2.0487558E-02
     +,   2.2636341E-02,   2.4944266E-02,   2.7406914E-02
     +,   3.0024607E-02,   3.2774393E-02,   3.5588376E-02
     +,   3.8363714E-02,   4.0998623E-02,   4.3429092E-02
     +,   4.5641918E-02,   4.7667287E-02,   4.9587172E-02
     +,   5.1542569E-02,   5.3647760E-02,   5.5814672E-02
     +,   5.7680048E-02,   5.8759667E-02,   5.8685321E-02
     +,   5.7339922E-02,   5.4851916E-02,   5.1505428E-02
     +,   4.7643326E-02,   4.3610457E-02,   3.9700817E-02
     +,   3.6086604E-02,   3.2796018E-02,   2.9776232E-02
     +,   2.6970644E-02,   2.4338245E-02,   2.1838436E-02
     +,   1.9435458E-02,   1.7126637E-02,   1.4954335E-02
     +,   1.2982535E-02,   1.1259059E-02,   9.7945603E-03
     +,   8.5669290E-03,   7.5396579E-03,   6.6787913E-03
     +,   5.9608789E-03,   5.3724688E-03,   4.9055293E-03
     +,   4.5529990E-03,   4.3059941E-03,   4.1528461E-03
     +,   4.0795929E-03,   4.0710792E-03,   4.1121808E-03
     +,   4.1888705E-03,   4.2890194E-03,   4.4028754E-03
     +,   4.5232773E-03,   4.6455804E-03,   4.7674305E-03
     +,   4.8883017E-03,   5.0089215E-03,   5.1306365E-03
     +,   5.2547655E-03,   5.3820154E-03,   5.5120313E-03
     +,   5.6432020E-03,   5.7726041E-03,   5.8961967E-03
     +,   6.0092271E-03,   6.1067538E-03,   6.1841304E-03
     +,   6.2375204E-03,   6.2641846E-03,   6.2626852E-03
     +,   6.2328447E-03,   6.1755804E-03,   6.0926522E-03
     +,   5.9863590E-03,   5.8593126E-03,   5.7141925E-03
     +,   5.5536162E-03,   5.3801169E-03,   5.1961369E-03
     +,   5.0040279E-03,   4.8061446E-03,   4.6048309E-03
     +,   4.4024861E-03,   4.2015146E-03,   4.0042819E-03
     +,   3.8130356E-03,   3.6298709E-03,   3.4565672E-03
     +,   3.2945538E-03,   3.1448579E-03,   3.0080460E-03
     +,   2.8842227E-03,   2.7730786E-03,   2.6739396E-03
     +,   2.5858385E-03,   2.5075898E-03,   2.4378942E-03
     +,   2.3753995E-03,   2.3187848E-03,   2.2668024E-03
     +,   2.2183110E-03,   2.1723199E-03,   2.1279785E-03
     +,   2.0845900E-03,   2.0415967E-03,   1.9985745E-03
     +,   1.9552107E-03,   1.9112867E-03,   1.8666668E-03
     +,   1.8212767E-03,   1.7750860E-03,   1.7280990E-03
     +,   1.6803484E-03,   1.6318833E-03,   1.5827600E-03
     +,   1.5330481E-03,   1.4828276E-03,   1.4321844E-03
     +,   1.3812147E-03,   1.3300296E-03,   1.2787515E-03
     +,   1.2275164E-03,   1.1764687E-03,   1.1257695E-03
     +,   1.0755893E-03,   1.0261002E-03,   9.7747613E-04
     +,   9.2989235E-04,   8.8351668E-04,   8.3850167E-04
     +,   7.9498609E-04,   7.5309223E-04,   7.1291719E-04
     +,   6.7453395E-04,   6.3799426E-04,   6.0332363E-04
     +,   5.7052221E-04,   5.3956796E-04,   5.1042036E-04
     +,   4.8302053E-04,   4.5729490E-04,   4.3315734E-04
     +,   4.1051660E-04,   3.8927334E-04,   3.6932874E-04
     +,   3.5058195E-04,   3.3293688E-04,   3.1630002E-04
     +,   3.0058500E-04,   2.8571073E-04,   2.7160483E-04
     +,   2.5820080E-04,   2.4544151E-04,   2.3327547E-04
     +,   2.2165815E-04,   2.1055246E-04,   1.9992518E-04
     +,   1.8974979E-04,   1.8000227E-04,   1.7066377E-04
     +,   1.6171680E-04,   1.5314764E-04,   1.4494327E-04
     +,   1.3709298E-04,   1.2958629E-04,   1.2241425E-04
     +,   1.1556742E-04,   1.0903760E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt85 = Yx/0.45598
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1230174E-05,   6.2639017E-05
     +,   6.4056068E-05,   6.5480490E-05,   6.6911387E-05
     +,   6.8347872E-05,   6.9788963E-05,   7.1233757E-05
     +,   7.2681229E-05,   7.4130388E-05,   7.5580210E-05
     +,   7.7029668E-05,   7.8477671E-05,   7.9923171E-05
     +,   8.1365135E-05,   8.2802464E-05,   8.4234161E-05
     +,   8.5659121E-05,   8.7076412E-05,   8.8485031E-05
     +,   8.9884088E-05,   9.1272734E-05,   9.2650189E-05
     +,   9.4015857E-05,   9.5369120E-05,   9.6709606E-05
     +,   9.8037155E-05,   9.9351688E-05,   1.0065347E-04
     +,   1.0194292E-04,   1.0322095E-04,   1.0448859E-04
     +,   1.0574748E-04,   1.0699961E-04,   1.0824747E-04
     +,   1.0949418E-04,   1.1074334E-04,   1.1199940E-04
     +,   1.1326749E-04,   1.1455343E-04,   1.1586410E-04
     +,   1.1720715E-04,   1.1859133E-04,   1.2002630E-04
     +,   1.2152291E-04,   1.2309304E-04,   1.2474979E-04
     +,   1.2650731E-04,   1.2838100E-04,   1.3038726E-04
     +,   1.3254369E-04,   1.3486878E-04,   1.3738203E-04
     +,   1.4010385E-04,   1.4305502E-04,   1.4625720E-04
     +,   1.4973215E-04,   1.5350191E-04,   1.5758819E-04
     +,   1.6201267E-04,   1.6679622E-04,   1.7195888E-04
     +,   1.7751947E-04,   1.8349581E-04,   1.8990396E-04
     +,   1.9675810E-04,   2.0407082E-04,   2.1185215E-04
     +,   2.2011105E-04,   2.2885342E-04,   2.3808458E-04
     +,   2.4780698E-04,   2.5802333E-04,   2.6873412E-04
     +,   2.7994090E-04,   2.9164567E-04,   3.0385097E-04
     +,   3.1656158E-04,   3.2978610E-04,   3.4353731E-04
     +,   3.5783215E-04,   3.7269449E-04,   3.8815435E-04
     +,   4.0425084E-04,   4.2102984E-04,   4.3854798E-04
     +,   4.5686905E-04,   4.7606791E-04,   4.9622578E-04
     +,   5.1743333E-04,   5.3978781E-04,   5.6338910E-04
     +,   5.8833993E-04,   6.1474461E-04,   6.4270239E-04
     +,   6.7230436E-04,   7.0363341E-04,   7.3675375E-04
     +,   7.7171286E-04,   8.0853142E-04,   8.4720564E-04
     +,   8.8769733E-04,   9.2993787E-04,   9.7381801E-04
     +,   1.0191982E-03,   1.0659052E-03,   1.1137328E-03
     +,   1.1624541E-03,   1.2118310E-03,   1.2616260E-03
     +,   1.3116112E-03,   1.3615985E-03,   1.4114488E-03
     +,   1.4611019E-03,   1.5105881E-03,   1.5600607E-03
     +,   1.6098042E-03,   1.6602596E-03,   1.7120260E-03
     +,   1.7658849E-03,   1.8227989E-03,   1.8839177E-03
     +,   1.9505922E-03,   2.0243826E-03,   2.1070784E-03
     +,   2.2006792E-03,   2.3074171E-03,   2.4296900E-03
     +,   2.5700261E-03,   2.7309326E-03,   2.9147889E-03
     +,   3.1236645E-03,   3.3592808E-03,   3.6229771E-03
     +,   3.9159721E-03,   4.2396910E-03,   4.5962180E-03
     +,   4.9887579E-03,   5.4220231E-03,   5.9024524E-03
     +,   6.4384430E-03,   7.0408187E-03,   7.7234837E-03
     +,   8.5038794E-03,   9.4024623E-03,   1.0441326E-02
     +,   1.1641469E-02,   1.3020644E-02,   1.4592388E-02
     +,   1.6364446E-02,   1.8334456E-02,   2.0485949E-02
     +,   2.2795511E-02,   2.5253681E-02,   2.7878432E-02
     +,   3.0687453E-02,   3.3634141E-02,   3.6566794E-02
     +,   3.9277058E-02,   4.1625887E-02,   4.3632593E-02
     +,   4.5404054E-02,   4.6946868E-02,   4.8071753E-02
     +,   4.8516642E-02,   4.8143737E-02,   4.6990708E-02
     +,   4.5180600E-02,   4.2841952E-02,   4.0096574E-02
     +,   3.7051070E-02,   3.3792056E-02,   3.0425232E-02
     +,   2.7128968E-02,   2.4147840E-02,   2.1723386E-02
     +,   2.0019159E-02,   1.9079002E-02,   1.8825084E-02
     +,   1.9091880E-02,   1.9683665E-02,   2.0429261E-02
     +,   2.1211421E-02,   2.1964036E-02,   2.2649039E-02
     +,   2.3233168E-02,   2.3677804E-02,   2.3943145E-02
     +,   2.3997346E-02,   2.3822650E-02,   2.3417123E-02
     +,   2.2794733E-02,   2.1987280E-02,   2.1044215E-02
     +,   2.0027885E-02,   1.9002886E-02,   1.8024959E-02
     +,   1.7132072E-02,   1.6340893E-02,   1.5646998E-02
     +,   1.5027757E-02,   1.4447780E-02,   1.3867505E-02
     +,   1.3253662E-02,   1.2588489E-02,   1.1874016E-02
     +,   1.1129836E-02,   1.0385782E-02,   9.6727246E-03
     +,   9.0151411E-03,   8.4277699E-03,   7.9158880E-03
     +,   7.4778325E-03,   7.1079098E-03,   6.7986343E-03
     +,   6.5417248E-03,   6.3282293E-03,   6.1484254E-03
     +,   5.9919441E-03,   5.8482834E-03,   5.7076411E-03
     +,   5.5618668E-03,   5.4052481E-03,   5.2349032E-03
     +,   5.0507411E-03,   4.8550800E-03,   4.6519493E-03
     +,   4.4462909E-03,   4.2431471E-03,   4.0470865E-03
     +,   3.8617165E-03,   3.6895217E-03,   3.5317824E-03
     +,   3.3887415E-03,   3.2598174E-03,   3.1438316E-03
     +,   3.0392443E-03,   2.9443880E-03,   2.8575966E-03
     +,   2.7773050E-03,   2.7021200E-03,   2.6308470E-03
     +,   2.5624929E-03,   2.4962339E-03,   2.4314092E-03
     +,   2.3674956E-03,   2.3040713E-03,   2.2407947E-03
     +,   2.1773847E-03,   2.1136135E-03,   2.0492831E-03
     +,   1.9842314E-03,   1.9183365E-03,   1.8515164E-03
     +,   1.7837347E-03,   1.7150094E-03,   1.6454257E-03
     +,   1.5751272E-03,   1.5043225E-03,   1.4332725E-03
     +,   1.3622903E-03,   1.2917276E-03,   1.2219492E-03
     +,   1.1533254E-03,   1.0862206E-03,   1.0209702E-03
     +,   9.5786905E-04,   8.9717162E-04,   8.3907921E-04
     +,   7.8373367E-04,   7.3122326E-04,   6.8158837E-04
     +,   6.3482142E-04,   5.9087400E-04,   5.4966361E-04
     +,   5.1108765E-04,   4.7502038E-04,   4.4133016E-04
     +,   4.0987474E-04,   3.8051669E-04,   3.5311692E-04
     +,   3.2754664E-04,   3.0368080E-04,   2.8140660E-04
     +,   2.6061755E-04,   2.4121896E-04,   2.2312178E-04
     +,   2.0624587E-04,   1.9051903E-04,   1.7587302E-04
     +,   1.6224659E-04,   1.4958109E-04,   1.3782279E-04
     +,   1.2691959E-04,   1.1682326E-04,   1.0748608E-04
     +,   9.8863529E-05,   9.0911512E-05,   8.3588347E-05
     +,   7.6852979E-05,   7.0666560E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt90 = Yx/0.46116
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5528492E-05,   2.6064938E-05
     +,   2.6603097E-05,   2.7142714E-05,   2.7683594E-05
     +,   2.8225550E-05,   2.8768454E-05,   2.9312201E-05
     +,   2.9856734E-05,   3.0402087E-05,   3.0948318E-05
     +,   3.1495580E-05,   3.2044089E-05,   3.2594180E-05
     +,   3.3146254E-05,   3.3700857E-05,   3.4258632E-05
     +,   3.4820376E-05,   3.5387031E-05,   3.5959678E-05
     +,   3.6539612E-05,   3.7128284E-05,   3.7727365E-05
     +,   3.8338774E-05,   3.8964597E-05,   3.9607261E-05
     +,   4.0269388E-05,   4.0953924E-05,   4.1664120E-05
     +,   4.2403484E-05,   4.3175929E-05,   4.3985663E-05
     +,   4.4837248E-05,   4.5735596E-05,   4.6686000E-05
     +,   4.7694117E-05,   4.8765942E-05,   4.9907831E-05
     +,   5.1126553E-05,   5.2429099E-05,   5.3822856E-05
     +,   5.5315468E-05,   5.6914854E-05,   5.8629121E-05
     +,   6.0466577E-05,   6.2435618E-05,   6.4544765E-05
     +,   6.6802430E-05,   6.9217087E-05,   7.1796974E-05
     +,   7.4550124E-05,   7.7484277E-05,   8.0606711E-05
     +,   8.3924395E-05,   8.7443434E-05,   9.1169517E-05
     +,   9.5107513E-05,   9.9261364E-05,   1.0363423E-04
     +,   1.0822825E-04,   1.1304449E-04,   1.1808312E-04
     +,   1.2334266E-04,   1.2882119E-04,   1.3451550E-04
     +,   1.4042082E-04,   1.4653183E-04,   1.5284169E-04
     +,   1.5934321E-04,   1.6602747E-04,   1.7288567E-04
     +,   1.7990744E-04,   1.8708264E-04,   1.9439989E-04
     +,   2.0184809E-04,   2.0941602E-04,   2.1709186E-04
     +,   2.2486389E-04,   2.3272124E-04,   2.4065313E-04
     +,   2.4864858E-04,   2.5669814E-04,   2.6479212E-04
     +,   2.7292231E-04,   2.8108046E-04,   2.8926024E-04
     +,   2.9745523E-04,   3.0566135E-04,   3.1387419E-04
     +,   3.2209209E-04,   3.3031483E-04,   3.3854321E-04
     +,   3.4678081E-04,   3.5503376E-04,   3.6331182E-04
     +,   3.7162719E-04,   3.7999786E-04,   3.8844603E-04
     +,   3.9700067E-04,   4.0569756E-04,   4.1458147E-04
     +,   4.2370567E-04,   4.3313560E-04,   4.4294706E-04
     +,   4.5323095E-04,   4.6409239E-04,   4.7565094E-04
     +,   4.8804277E-04,   5.0142134E-04,   5.1595678E-04
     +,   5.3183368E-04,   5.4925284E-04,   5.6842639E-04
     +,   5.8957754E-04,   6.1293261E-04,   6.3872256E-04
     +,   6.6716888E-04,   6.9848605E-04,   7.3286804E-04
     +,   7.7048386E-04,   8.1147341E-04,   8.5593411E-04
     +,   9.0391963E-04,   9.5544296E-04,   1.0104685E-03
     +,   1.0689144E-03,   1.1306700E-03,   1.1955933E-03
     +,   1.2635459E-03,   1.3343990E-03,   1.4080789E-03
     +,   1.4845844E-03,   1.5640432E-03,   1.6467290E-03
     +,   1.7331183E-03,   1.8239056E-03,   1.9200122E-03
     +,   2.0225816E-03,   2.1329490E-03,   2.2525548E-03
     +,   2.3828384E-03,   2.5251014E-03,   2.6803426E-03
     +,   2.8491078E-03,   3.0313013E-03,   3.2261235E-03
     +,   3.4320338E-03,   3.6467991E-03,   3.8676688E-03
     +,   4.0916605E-03,   4.3158666E-03,   4.5377822E-03
     +,   4.7555920E-03,   4.9683289E-03,   5.1758438E-03
     +,   5.3785453E-03,   5.5770371E-03,   5.7716328E-03
     +,   5.9619169E-03,   6.1464566E-03,   6.3228244E-03
     +,   6.4878589E-03,   6.6381567E-03,   6.7706597E-03
     +,   6.8831565E-03,   6.9744969E-03,   7.0445528E-03
     +,   7.0939655E-03,   7.1238750E-03,   7.1359952E-03
     +,   7.1334997E-03,   7.1230847E-03,   7.1182484E-03
     +,   7.1431361E-03,   7.2353184E-03,   7.4456972E-03
     +,   7.8352997E-03,   8.4711071E-03,   9.4242506E-03
     +,   1.0769081E-02,   1.2573228E-02,   1.4870767E-02
     +,   1.7632645E-02,   2.0774273E-02,   2.4222206E-02
     +,   2.7987476E-02,   3.2148264E-02,   3.6729898E-02
     +,   4.1603725E-02,   4.6490524E-02,   5.1013257E-02
     +,   5.4768354E-02,   5.7437621E-02,   5.8853414E-02
     +,   5.8999348E-02,   5.8104031E-02,   5.6667849E-02
     +,   5.5109147E-02,   5.3406157E-02,   5.1278315E-02
     +,   4.8602674E-02,   4.5554157E-02,   4.2468678E-02
     +,   3.9603990E-02,   3.6978591E-02,   3.4447700E-02
     +,   3.1920809E-02,   2.9473785E-02,   2.7280172E-02
     +,   2.5470709E-02,   2.4049586E-02,   2.2910703E-02
     +,   2.1908734E-02,   2.0922164E-02,   1.9882165E-02
     +,   1.8774701E-02,   1.7627675E-02,   1.6490078E-02
     +,   1.5409983E-02,   1.4419693E-02,   1.3530456E-02
     +,   1.2735536E-02,   1.2016330E-02,   1.1348518E-02
     +,   1.0708133E-02,   1.0077475E-02,   9.4494643E-03
     +,   8.8287275E-03,   8.2289828E-03,   7.6679098E-03
     +,   7.1616550E-03,   6.7209089E-03,   6.3494174E-03
     +,   6.0445145E-03,   5.7987361E-03,   5.6015365E-03
     +,   5.4407544E-03,   5.3037805E-03,   5.1784781E-03
     +,   5.0540064E-03,   4.9216095E-03,   4.7752284E-03
     +,   4.6118163E-03,   4.4313050E-03,   4.2362623E-03
     +,   4.0312116E-03,   3.8218289E-03,   3.6140531E-03
     +,   3.4133443E-03,   3.2241435E-03,   3.0494849E-03
     +,   2.8909275E-03,   2.7486570E-03,   2.6217191E-03
     +,   2.5083278E-03,   2.4062146E-03,   2.3129322E-03
     +,   2.2260861E-03,   2.1435164E-03,   2.0633833E-03
     +,   1.9842458E-03,   1.9050373E-03,   1.8250499E-03
     +,   1.7438923E-03,   1.6614594E-03,   1.5778613E-03
     +,   1.4933862E-03,   1.4084607E-03,   1.3236050E-03
     +,   1.2393848E-03,   1.1563842E-03,   1.0751808E-03
     +,   9.9631248E-04,   9.2025468E-04,   8.4740925E-04
     +,   7.7810517E-04,   7.1257766E-04,   6.5098878E-04
     +,   5.9341465E-04,   5.3987006E-04,   4.9030123E-04
     +,   4.4461296E-04,   4.0266346E-04,   3.6428709E-04
     +,   3.2929177E-04,   2.9747689E-04,   2.6863159E-04
     +,   2.4254351E-04,   2.1900506E-04,   1.9781095E-04
     +,   1.7876601E-04,   1.6168173E-04,   1.4638189E-04
     +,   1.3269868E-04,   1.2047742E-04,   1.0957209E-04
     +,   9.9849203E-05,   9.1184476E-05,   8.3464802E-05
     +,   7.6585951E-05,   7.0453956E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_htt95 = Yx/0.45038
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.5133428E-06,   5.7507991E-06
     +,   5.9926219E-06,   6.2385352E-06,   6.4882420E-06
     +,   6.7414321E-06,   6.9977773E-06,   7.2569378E-06
     +,   7.5185540E-06,   7.7822751E-06,   8.0477266E-06
     +,   8.3145351E-06,   8.5823285E-06,   8.8507322E-06
     +,   9.1193833E-06,   9.3879225E-06,   9.6560088E-06
     +,   9.9233184E-06,   1.0189546E-05,   1.0454414E-05
     +,   1.0717681E-05,   1.0979135E-05,   1.1238606E-05
     +,   1.1495983E-05,   1.1751177E-05,   1.2004184E-05
     +,   1.2255042E-05,   1.2503859E-05,   1.2750810E-05
     +,   1.2996141E-05,   1.3240174E-05,   1.3483309E-05
     +,   1.3726024E-05,   1.3968881E-05,   1.4212525E-05
     +,   1.4457676E-05,   1.4705146E-05,   1.4955814E-05
     +,   1.5210655E-05,   1.5470683E-05,   1.5737020E-05
     +,   1.6010817E-05,   1.6293292E-05,   1.6585705E-05
     +,   1.6889351E-05,   1.7205546E-05,   1.7535620E-05
     +,   1.7880902E-05,   1.8242694E-05,   1.8622282E-05
     +,   1.9020892E-05,   1.9439687E-05,   1.9879748E-05
     +,   2.0342082E-05,   2.0827525E-05,   2.1336835E-05
     +,   2.1870590E-05,   2.2429213E-05,   2.3012939E-05
     +,   2.3621807E-05,   2.4255662E-05,   2.4914136E-05
     +,   2.5596575E-05,   2.6302179E-05,   2.7029886E-05
     +,   2.7778340E-05,   2.8546048E-05,   2.9331177E-05
     +,   3.0131790E-05,   3.0945623E-05,   3.1770331E-05
     +,   3.2603271E-05,   3.3441767E-05,   3.4282890E-05
     +,   3.5123689E-05,   3.5961140E-05,   3.6792098E-05
     +,   3.7613419E-05,   3.8422037E-05,   3.9214920E-05
     +,   3.9989063E-05,   4.0741674E-05,   4.1470033E-05
     +,   4.2171698E-05,   4.2844356E-05,   4.3486045E-05
     +,   4.4094981E-05,   4.4669778E-05,   4.5209279E-05
     +,   4.5712713E-05,   4.6179663E-05,   4.6610025E-05
     +,   4.7004036E-05,   4.7362311E-05,   4.7685782E-05
     +,   4.7975675E-05,   4.8233531E-05,   4.8461145E-05
     +,   4.8660560E-05,   4.8833976E-05,   4.8983806E-05
     +,   4.9112543E-05,   4.9222745E-05,   4.9317030E-05
     +,   4.9397946E-05,   4.9468024E-05,   4.9529626E-05
     +,   4.9585004E-05,   4.9636175E-05,   4.9684950E-05
     +,   4.9732847E-05,   4.9781138E-05,   4.9830778E-05
     +,   4.9882423E-05,   4.9936425E-05,   4.9992897E-05
     +,   5.0051662E-05,   5.0112412E-05,   5.0174651E-05
     +,   5.0237893E-05,   5.0301674E-05,   5.0365750E-05
     +,   5.0430168E-05,   5.0495502E-05,   5.0562998E-05
     +,   5.0634804E-05,   5.0714225E-05,   5.0805931E-05
     +,   5.0916289E-05,   5.1053605E-05,   5.1228461E-05
     +,   5.1453953E-05,   5.1746039E-05,   5.2123723E-05
     +,   5.2609317E-05,   5.3228574E-05,   5.4010743E-05
     +,   5.4988461E-05,   5.6197670E-05,   5.7677280E-05
     +,   5.9468450E-05,   6.1613915E-05,   6.4157190E-05
     +,   6.7141271E-05,   7.0606780E-05,   7.4590964E-05
     +,   7.9125493E-05,   8.4234140E-05,   8.9930785E-05
     +,   9.6217715E-05,   1.0308329E-04,   1.1049962E-04
     +,   1.1842150E-04,   1.2678605E-04,   1.3551234E-04
     +,   1.4450136E-04,   1.5363852E-04,   1.6279743E-04
     +,   1.7184312E-04,   1.8063652E-04,   1.8904217E-04
     +,   1.9693362E-04,   2.0419975E-04,   2.1075206E-04
     +,   2.1653154E-04,   2.2151510E-04,   2.2572250E-04
     +,   2.2922608E-04,   2.3216214E-04,   2.3474541E-04
     +,   2.3728644E-04,   2.4021274E-04,   2.4408980E-04
     +,   2.4963976E-04,   2.5775278E-04,   2.6949061E-04
     +,   2.8607584E-04,   3.0886696E-04,   3.3932607E-04
     +,   3.7898429E-04,   4.2940996E-04,   4.9218134E-04
     +,   5.6887255E-04,   6.6103879E-04,   7.7016093E-04
     +,   8.9751516E-04,   1.0439536E-03,   1.2095639E-03
     +,   1.3932151E-03,   1.5920498E-03,   1.8011281E-03
     +,   2.0132698E-03,   2.2192781E-03,   2.4086696E-03
     +,   2.5707989E-03,   2.6961933E-03,   2.7778337E-03
     +,   2.8121073E-03,   2.7991734E-03,   2.7426798E-03
     +,   2.6489999E-03,   2.5261641E-03,   2.3827718E-03
     +,   2.2270798E-03,   2.0663929E-03,   1.9066633E-03
     +,   1.7523599E-03,   1.6064985E-03,   1.4707705E-03
     +,   1.3457808E-03,   1.2313613E-03,   1.1268968E-03
     +,   1.0315864E-03,   9.4461557E-04,   8.6523435E-04
     +,   7.9275045E-04,   7.2647084E-04,   6.6565833E-04
     +,   6.0953654E-04,   5.5733672E-04,   5.0835864E-04
     +,   4.6204511E-04,   4.1803130E-04,   3.7615103E-04
     +,   3.3640827E-04,   2.9892763E-04,   2.6389456E-04
     +,   2.3149392E-04,   2.0186251E-04,   1.7506414E-04
     +,   1.5108223E-04,   1.2982241E-04,   1.1112594E-04
     +,   9.4791285E-05,   8.0594502E-05,   6.8303561E-05
     +,   5.7693527E-05,   4.8555907E-05,   4.0702667E-05
     +,   3.3967372E-05,   2.8205250E-05,   2.3291328E-05
     +,   1.9117211E-05,   1.5588148E-05,   1.2620965E-05
     +,   1.0142135E-05,   8.0860063E-06,   6.3936050E-06
     +,   5.0120898E-06,   3.8943240E-06,   2.9982345E-06
     +,   2.2867071E-06,   1.7273252E-06,   1.2920320E-06
     +,   9.5680662E-07,   7.0137372E-07,   5.0884779E-07
     +,   3.6532899E-07,   2.5952539E-07,   1.8239868E-07
     +,   1.2681546E-07,   8.7216485E-08,   5.9328375E-08
     +,   3.9914415E-08,   2.6557437E-08,   1.7474511E-08
     +,   1.1370031E-08,   7.3155344E-09,   4.6542863E-09
     +,   2.9279554E-09,   1.8212285E-09,   1.1200898E-09
     +,   6.8113049E-10,   4.0952938E-10,   2.4344829E-10
     +,   1.4308922E-10,   8.3151160E-11,   4.7775478E-11
     +,   2.7139409E-11,   1.5243065E-11,   8.4645520E-12
     +,   4.6474526E-12,   2.5228524E-12,   1.3541259E-12
     +,   7.1863224E-13,   3.7710850E-13,   1.9568106E-13
     +,   1.0040970E-13,   5.0957726E-14,   2.5579900E-14
     +,   1.2704773E-14,   6.2452235E-15,   3.0402208E-15
     +,   1.4668525E-15,   7.0239270E-16,   3.3445218E-16
     +,   1.5884950E-16,   7.5590497E-17,   3.6273213E-17
     +,   1.7703900E-17,   8.8818493E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt100 = Yx/0.01825
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8959930E-05,   2.9259885E-05
     +,   2.9551669E-05,   2.9835317E-05,   3.0110901E-05
     +,   3.0378520E-05,   3.0638319E-05,   3.0890467E-05
     +,   3.1135169E-05,   3.1372678E-05,   3.1603271E-05
     +,   3.1827258E-05,   3.2044991E-05,   3.2256841E-05
     +,   3.2463224E-05,   3.2664579E-05,   3.2861386E-05
     +,   3.3054130E-05,   3.3243352E-05,   3.3429584E-05
     +,   3.3613411E-05,   3.3795422E-05,   3.3976219E-05
     +,   3.4156441E-05,   3.4336699E-05,   3.4517667E-05
     +,   3.4699984E-05,   3.4884302E-05,   3.5071280E-05
     +,   3.5261568E-05,   3.5455814E-05,   3.5654648E-05
     +,   3.5858691E-05,   3.6068541E-05,   3.6284790E-05
     +,   3.6507987E-05,   3.6738660E-05,   3.6977312E-05
     +,   3.7224399E-05,   3.7480339E-05,   3.7745525E-05
     +,   3.8020280E-05,   3.8304905E-05,   3.8599628E-05
     +,   3.8904644E-05,   3.9220075E-05,   3.9545994E-05
     +,   3.9882427E-05,   4.0229319E-05,   4.0586572E-05
     +,   4.0954023E-05,   4.1331437E-05,   4.1718526E-05
     +,   4.2114945E-05,   4.2520282E-05,   4.2934069E-05
     +,   4.3355776E-05,   4.3784818E-05,   4.4220564E-05
     +,   4.4662320E-05,   4.5109347E-05,   4.5560879E-05
     +,   4.6016063E-05,   4.6474051E-05,   4.6933961E-05
     +,   4.7394846E-05,   4.7855767E-05,   4.8315738E-05
     +,   4.8773793E-05,   4.9228896E-05,   4.9680075E-05
     +,   5.0126284E-05,   5.0566548E-05,   5.0999839E-05
     +,   5.1425191E-05,   5.1841635E-05,   5.2248241E-05
     +,   5.2644049E-05,   5.3028216E-05,   5.3399894E-05
     +,   5.3758264E-05,   5.4102609E-05,   5.4432196E-05
     +,   5.4746415E-05,   5.5044675E-05,   5.5326494E-05
     +,   5.5591419E-05,   5.5839137E-05,   5.6069352E-05
     +,   5.6281926E-05,   5.6476794E-05,   5.6653975E-05
     +,   5.6813635E-05,   5.6956029E-05,   5.7081557E-05
     +,   5.7190762E-05,   5.7284295E-05,   5.7362944E-05
     +,   5.7427696E-05,   5.7479650E-05,   5.7520072E-05
     +,   5.7550395E-05,   5.7572222E-05,   5.7587305E-05
     +,   5.7597568E-05,   5.7605106E-05,   5.7612138E-05
     +,   5.7621055E-05,   5.7634352E-05,   5.7654688E-05
     +,   5.7684763E-05,   5.7727397E-05,   5.7785448E-05
     +,   5.7861787E-05,   5.7959285E-05,   5.8080754E-05
     +,   5.8228903E-05,   5.8406335E-05,   5.8615435E-05
     +,   5.8858361E-05,   5.9137023E-05,   5.9452941E-05
     +,   5.9807251E-05,   6.0200666E-05,   6.0633414E-05
     +,   6.1105144E-05,   6.1614977E-05,   6.2161322E-05
     +,   6.2742045E-05,   6.3354259E-05,   6.3994448E-05
     +,   6.4658321E-05,   6.5341010E-05,   6.6036853E-05
     +,   6.6739667E-05,   6.7442648E-05,   6.8138448E-05
     +,   6.8819230E-05,   6.9476868E-05,   7.0102942E-05
     +,   7.0688890E-05,   7.1226117E-05,   7.1706258E-05
     +,   7.2121198E-05,   7.2463306E-05,   7.2725685E-05
     +,   7.2902294E-05,   7.2988165E-05,   7.2979725E-05
     +,   7.2874907E-05,   7.2673378E-05,   7.2376832E-05
     +,   7.1989132E-05,   7.1516472E-05,   7.0967537E-05
     +,   7.0353657E-05,   6.9688867E-05,   6.8989852E-05
     +,   6.8276080E-05,   6.7569788E-05,   6.6895926E-05
     +,   6.6282133E-05,   6.5759123E-05,   6.5360808E-05
     +,   6.5124885E-05,   6.5093707E-05,   6.5315515E-05
     +,   6.5846383E-05,   6.6752320E-05,   6.8112240E-05
     +,   7.0021459E-05,   7.2595489E-05,   7.5974560E-05
     +,   8.0327925E-05,   8.5857326E-05,   9.2801303E-05
     +,   1.0143709E-04,   1.1208021E-04,   1.2508279E-04
     +,   1.4082948E-04,   1.5972882E-04,   1.8219939E-04
     +,   2.0865457E-04,   2.3948519E-04,   2.7503507E-04
     +,   3.1557371E-04,   3.6127109E-04,   4.1217523E-04
     +,   4.6818575E-04,   5.2902848E-04,   5.9425097E-04
     +,   6.6321139E-04,   7.3507632E-04,   8.0883468E-04
     +,   8.8332751E-04,   9.5727178E-04,   1.0292990E-03
     +,   1.0980048E-03,   1.1620066E-03,   1.2199908E-03
     +,   1.2707590E-03,   1.3132842E-03,   1.3467461E-03
     +,   1.3705608E-03,   1.3843937E-03,   1.3881718E-03
     +,   1.3820699E-03,   1.3664941E-03,   1.3420553E-03
     +,   1.3095300E-03,   1.2698201E-03,   1.2239154E-03
     +,   1.1728501E-03,   1.1176615E-03,   1.0593610E-03
     +,   9.9891017E-04,   9.3719969E-04,   8.7503000E-04
     +,   8.1311009E-04,   7.5206085E-04,   6.9240469E-04
     +,   6.3457753E-04,   5.7893898E-04,   5.2577525E-04
     +,   4.7530339E-04,   4.2768335E-04,   3.8302579E-04
     +,   3.4139529E-04,   3.0281243E-04,   2.6726202E-04
     +,   2.3469864E-04,   2.0504797E-04,   1.7820923E-04
     +,   1.5406068E-04,   1.3246595E-04,   1.1327258E-04
     +,   9.6318647E-05,   8.1437065E-05,   6.8457455E-05
     +,   5.7208694E-05,   4.7522615E-05,   3.9236849E-05
     +,   3.2196003E-05,   2.6252788E-05,   2.1269921E-05
     +,   1.7121007E-05,   1.3690580E-05,   1.0874091E-05
     +,   8.5781194E-06,   6.7201454E-06,   5.2276018E-06
     +,   4.0375107E-06,   3.0957790E-06,   2.3562991E-06
     +,   1.7801149E-06,   1.3346760E-06,   9.9306328E-07
     +,   7.3318824E-07,   5.3709289E-07,   3.9033432E-07
     +,   2.8141505E-07,   2.0125755E-07,   1.4276272E-07
     +,   1.0043858E-07,   7.0079501E-08,   4.8490378E-08
     +,   3.3270897E-08,   2.2636103E-08,   1.5270503E-08
     +,   1.0214072E-08,   6.7736021E-09,   4.4536157E-09
     +,   2.9032401E-09,   1.8764057E-09,   1.2024073E-09
     +,   7.6400469E-10,   4.8137788E-10,   3.0081512E-10
     +,   1.8647310E-10,   1.1470506E-10,   7.0045032E-11
     +,   4.2489991E-11,   2.5625784E-11,   1.5384896E-11
     +,   9.2098959E-12,   5.5101193E-12,   3.3045461E-12
     +,   1.9941919E-12,   1.2166423E-12,   7.5433713E-13
     +,   4.7786428E-13,   3.1072123E-13,   2.0801019E-13
     +,   1.4346967E-13,   1.0179141E-13,   7.4032408E-14
     +,   5.4948664E-14,   4.1427382E-14,   3.1592601E-14
     +,   2.4283970E-14,   1.8763553E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt104 = Yx/0.0123846153846154
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9134306E-09,   3.4619299E-09
     +,   4.1067230E-09,   4.8633528E-09,   5.7496332E-09
     +,   6.7859105E-09,   7.9953866E-09,   9.4044807E-09
     +,   1.1043134E-08,   1.2945375E-08,   1.5149588E-08
     +,   1.7699067E-08,   2.0642569E-08,   2.4034787E-08
     +,   2.7937064E-08,   3.2417901E-08,   3.7553711E-08
     +,   4.3429409E-08,   5.0139391E-08,   5.7787961E-08
     +,   6.6490479E-08,   7.6373979E-08,   8.7577725E-08
     +,   1.0025540E-07,   1.1457331E-07,   1.3071444E-07
     +,   1.4887694E-07,   1.6927582E-07,   1.9214372E-07
     +,   2.1773133E-07,   2.4630842E-07,   2.7816424E-07
     +,   3.1360776E-07,   3.5296856E-07,   3.9659642E-07
     +,   4.4486191E-07,   4.9815577E-07,   5.5688832E-07
     +,   6.2149309E-07,   6.9241503E-07,   7.7012464E-07
     +,   8.5510464E-07,   9.4785372E-07,   1.0488825E-06
     +,   1.1587138E-06,   1.2778771E-06,   1.4069084E-06
     +,   1.5463444E-06,   1.6967214E-06,   1.8585685E-06
     +,   2.0324067E-06,   2.2187405E-06,   2.4180536E-06
     +,   2.6308178E-06,   2.8574507E-06,   3.0983592E-06
     +,   3.3538943E-06,   3.6243648E-06,   3.9100264E-06
     +,   4.2110764E-06,   4.5276456E-06,   4.8598058E-06
     +,   5.2075275E-06,   5.5707337E-06,   5.9492609E-06
     +,   6.3428279E-06,   6.7511091E-06,   7.1736413E-06
     +,   7.6099200E-06,   8.0592963E-06,   8.5210877E-06
     +,   8.9944697E-06,   9.4786001E-06,   9.9724930E-06
     +,   1.0475153E-05,   1.0985526E-05,   1.1502492E-05
     +,   1.2024892E-05,   1.2551600E-05,   1.3081497E-05
     +,   1.3613448E-05,   1.4146440E-05,   1.4679476E-05
     +,   1.5211735E-05,   1.5742467E-05,   1.6271166E-05
     +,   1.6797452E-05,   1.7321259E-05,   1.7842709E-05
     +,   1.8362281E-05,   1.8880783E-05,   1.9399347E-05
     +,   1.9919480E-05,   2.0443129E-05,   2.0972657E-05
     +,   2.1510808E-05,   2.2060818E-05,   2.2626267E-05
     +,   2.3211222E-05,   2.3820052E-05,   2.4457542E-05
     +,   2.5128695E-05,   2.5838826E-05,   2.6593336E-05
     +,   2.7397766E-05,   2.8257660E-05,   2.9178394E-05
     +,   3.0165116E-05,   3.1222702E-05,   3.2355572E-05
     +,   3.3567474E-05,   3.4861612E-05,   3.6240206E-05
     +,   3.7704755E-05,   3.9255563E-05,   4.0892039E-05
     +,   4.2612242E-05,   4.4413260E-05,   4.6290745E-05
     +,   4.8239326E-05,   5.0252467E-05,   5.2322401E-05
     +,   5.4440316E-05,   5.6596655E-05,   5.8781050E-05
     +,   6.0982304E-05,   6.3189043E-05,   6.5389358E-05
     +,   6.7571462E-05,   6.9723465E-05,   7.1834002E-05
     +,   7.3891861E-05,   7.5886768E-05,   7.7808916E-05
     +,   7.9649559E-05,   8.1400896E-05,   8.3056017E-05
     +,   8.4609026E-05,   8.6055181E-05,   8.7390647E-05
     +,   8.8612433E-05,   8.9718305E-05,   9.0706810E-05
     +,   9.1576963E-05,   9.2328090E-05,   9.2959817E-05
     +,   9.3471834E-05,   9.3863724E-05,   9.4134914E-05
     +,   9.4284522E-05,   9.4311355E-05,   9.4213836E-05
     +,   9.3989947E-05,   9.3637362E-05,   9.3153445E-05
     +,   9.2535396E-05,   9.1780377E-05,   9.0885580E-05
     +,   8.9848487E-05,   8.8667141E-05,   8.7340071E-05
     +,   8.5866683E-05,   8.4247440E-05,   8.2484003E-05
     +,   8.0579230E-05,   7.8537407E-05,   7.6364522E-05
     +,   7.4068274E-05,   7.1658083E-05,   6.9145535E-05
     +,   6.6544977E-05,   6.3874104E-05,   6.1154948E-05
     +,   5.8415881E-05,   5.5694385E-05,   5.3040159E-05
     +,   5.0520161E-05,   4.8224771E-05,   4.6275105E-05
     +,   4.4831522E-05,   4.4103701E-05,   4.4361455E-05
     +,   4.5945682E-05,   4.9279421E-05,   5.4877597E-05
     +,   6.3352993E-05,   7.5416559E-05,   9.1870395E-05
     +,   1.1358759E-04,   1.4147646E-04,   1.7643972E-04
     +,   2.1932280E-04,   2.7086382E-04,   3.3166466E-04
     +,   4.0218988E-04,   4.8278132E-04,   5.7367113E-04
     +,   6.7497027E-04,   7.8657904E-04,   9.0796244E-04
     +,   1.0377988E-03,   1.1735712E-03,   1.3112172E-03
     +,   1.4449790E-03,   1.5676296E-03,   1.6712038E-03
     +,   1.7481045E-03,   1.7924190E-03,   1.8011254E-03
     +,   1.7748175E-03,   1.7176971E-03,   1.6368337E-03
     +,   1.5408329E-03,   1.4382818E-03,   1.3363906E-03
     +,   1.2401381E-03,   1.1520266E-03,   1.0723994E-03
     +,   1.0001203E-03,   9.3334570E-04,   8.7015511E-04
     +,   8.0897840E-04,   7.4877369E-04,   6.8902312E-04
     +,   6.2963058E-04,   5.7080516E-04,   5.1295949E-04
     +,   4.5662656E-04,   4.0239608E-04,   3.5086751E-04
     +,   3.0260257E-04,   2.5807504E-04,   2.1762922E-04
     +,   1.8146067E-04,   1.4961300E-04,   1.2198342E-04
     +,   9.8351637E-05,   7.8412879E-05,   6.1808554E-05
     +,   4.8154714E-05,   3.7066664E-05,   2.8175737E-05
     +,   2.1138723E-05,   1.5643494E-05,   1.1412335E-05
     +,   8.2025381E-06,   5.8051737E-06,   4.0433629E-06
     +,   2.7702324E-06,   1.8661974E-06,   1.2356413E-06
     +,   8.0382910E-07,   5.1362218E-07,   3.2227092E-07
     +,   1.9851109E-07,   1.2001503E-07,   7.1203225E-08
     +,   4.1448875E-08,   2.3670376E-08,   1.3259122E-08
     +,   7.2845316E-09,   3.9249475E-09,   2.0738109E-09
     +,   1.0744071E-09,   5.4579319E-10,   2.7184346E-10
     +,   1.3274547E-10,   6.3552531E-11,   2.9831262E-11
     +,   1.3728988E-11,   6.1951468E-12,   2.7414412E-12
     +,   1.1899555E-12,   5.0683622E-13,   2.1197088E-13
     +,   8.7155828E-14,   3.5302531E-14,   1.4138372E-14
     +,   5.6332282E-15,   2.2564843E-15,   9.2364485E-16
     +,   3.9523640E-16,   1.8130690E-16,   9.0805995E-17
     +,   4.9741100E-17,   2.9371880E-17,   1.8301421E-17
     +,   1.1806293E-17,   7.7824146E-18,   5.2006789E-18
     +,   3.5082086E-18,   2.3833673E-18,   1.6287421E-18
     +,   1.1187647E-18,   7.7201180E-19,   5.3492142E-19
     +,   3.7199912E-19,   2.5951406E-19,   1.8152839E-19
     +,   1.2725604E-19,   8.9365427E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt106 = Yx/0.0110833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0479716E-07,   4.4512214E-07
     +,   4.8885863E-07,   5.3622875E-07,   5.8746087E-07
     +,   6.4279220E-07,   7.0246512E-07,   7.6672814E-07
     +,   8.3583416E-07,   9.1004324E-07,   9.8961596E-07
     +,   1.0748164E-06,   1.1659089E-06,   1.2631593E-06
     +,   1.3668302E-06,   1.4771833E-06,   1.5944739E-06
     +,   1.7189534E-06,   1.8508641E-06,   1.9904394E-06
     +,   2.1379010E-06,   2.2934573E-06,   2.4573008E-06
     +,   2.6296138E-06,   2.8105439E-06,   3.0002368E-06
     +,   3.1988018E-06,   3.4063276E-06,   3.6228780E-06
     +,   3.8484850E-06,   4.0831537E-06,   4.3268574E-06
     +,   4.5795341E-06,   4.8410939E-06,   5.1114066E-06
     +,   5.3903123E-06,   5.6776107E-06,   5.9730683E-06
     +,   6.2764320E-06,   6.5873833E-06,   6.9056050E-06
     +,   7.2307289E-06,   7.5623630E-06,   7.9000947E-06
     +,   8.2434835E-06,   8.5920701E-06,   8.9453843E-06
     +,   9.3029430E-06,   9.6642561E-06,   1.0028840E-05
     +,   1.0396209E-05,   1.0765899E-05,   1.1137455E-05
     +,   1.1510471E-05,   1.1884539E-05,   1.2259326E-05
     +,   1.2634533E-05,   1.3009921E-05,   1.3385313E-05
     +,   1.3760608E-05,   1.4135779E-05,   1.4510894E-05
     +,   1.4886093E-05,   1.5261639E-05,   1.5637897E-05
     +,   1.6015305E-05,   1.6394453E-05,   1.6775995E-05
     +,   1.7160750E-05,   1.7549582E-05,   1.7943523E-05
     +,   1.8343650E-05,   1.8751181E-05,   1.9167373E-05
     +,   1.9593595E-05,   2.0031282E-05,   2.0481886E-05
     +,   2.0946887E-05,   2.1427819E-05,   2.1926206E-05
     +,   2.2443499E-05,   2.2981167E-05,   2.3540540E-05
     +,   2.4122932E-05,   2.4729452E-05,   2.5361152E-05
     +,   2.6018830E-05,   2.6703186E-05,   2.7414606E-05
     +,   2.8153332E-05,   2.8919336E-05,   2.9712277E-05
     +,   3.0531533E-05,   3.1376239E-05,   3.2245240E-05
     +,   3.3136974E-05,   3.4049714E-05,   3.4981305E-05
     +,   3.5929435E-05,   3.6891386E-05,   3.7864342E-05
     +,   3.8845090E-05,   3.9830382E-05,   4.0816656E-05
     +,   4.1800326E-05,   4.2777705E-05,   4.3745003E-05
     +,   4.4698434E-05,   4.5634293E-05,   4.6549001E-05
     +,   4.7439000E-05,   4.8301044E-05,   4.9132002E-05
     +,   4.9929135E-05,   5.0689890E-05,   5.1412175E-05
     +,   5.2094194E-05,   5.2734598E-05,   5.3332406E-05
     +,   5.3887121E-05,   5.4398683E-05,   5.4867400E-05
     +,   5.5294011E-05,   5.5679691E-05,   5.6025990E-05
     +,   5.6334735E-05,   5.6608100E-05,   5.6848476E-05
     +,   5.7058482E-05,   5.7240828E-05,   5.7398360E-05
     +,   5.7533874E-05,   5.7650166E-05,   5.7749890E-05
     +,   5.7835528E-05,   5.7909325E-05,   5.7973240E-05
     +,   5.8028847E-05,   5.8077359E-05,   5.8119560E-05
     +,   5.8155740E-05,   5.8185749E-05,   5.8208898E-05
     +,   5.8224021E-05,   5.8229474E-05,   5.8223104E-05
     +,   5.8202342E-05,   5.8164213E-05,   5.8105368E-05
     +,   5.8022160E-05,   5.7910682E-05,   5.7766872E-05
     +,   5.7586552E-05,   5.7365523E-05,   5.7099616E-05
     +,   5.6784815E-05,   5.6417328E-05,   5.5993642E-05
     +,   5.5510623E-05,   5.4965640E-05,   5.4356631E-05
     +,   5.3682219E-05,   5.2941916E-05,   5.2136318E-05
     +,   5.1267281E-05,   5.0338393E-05,   4.9355473E-05
     +,   4.8327256E-05,   4.7266192E-05,   4.6189580E-05
     +,   4.5121073E-05,   4.4092205E-05,   4.3144148E-05
     +,   4.2329779E-05,   4.1715666E-05,   4.1383704E-05
     +,   4.1432551E-05,   4.1978168E-05,   4.3153312E-05
     +,   4.5105724E-05,   4.7994643E-05,   5.1985011E-05
     +,   5.7239966E-05,   6.3911910E-05,   7.2131894E-05
     +,   8.1998267E-05,   9.3568335E-05,   1.0685534E-04
     +,   1.2183289E-04,   1.3845151E-04,   1.5667839E-04
     +,   1.7655494E-04,   1.9827804E-04,   2.2230312E-04
     +,   2.4945699E-04,   2.8103765E-04,   3.1887519E-04
     +,   3.6532819E-04,   4.2318419E-04,   4.9543771E-04
     +,   5.8494351E-04,   6.9397624E-04,   8.2374050E-04
     +,   9.7387913E-04,   1.1420579E-03,   1.3237795E-03
     +,   1.5124051E-03,   1.6994922E-03,   1.8754643E-03
     +,   2.0305496E-03,   2.1558306E-03,   2.2442723E-03
     +,   2.2915567E-03,   2.2965295E-03,   2.2611751E-03
     +,   2.1901631E-03,   2.0900487E-03,   1.9682937E-03
     +,   1.8323242E-03,   1.6887800E-03,   1.5430129E-03
     +,   1.3989256E-03,   1.2590851E-03,   1.1249982E-03
     +,   9.9746464E-04,   8.7692769E-04,   7.6373050E-04
     +,   6.5823930E-04,   5.6085846E-04,   4.7198706E-04
     +,   3.9194484E-04,   3.2089264E-04,   2.5878847E-04
     +,   2.0538394E-04,   1.6024696E-04,   1.2278324E-04
     +,   9.2282076E-05,   6.7956418E-05,   4.8977668E-05
     +,   3.4511162E-05,   2.3751734E-05,   1.5953154E-05
     +,   1.0449871E-05,   6.6716129E-06,   4.1495632E-06
     +,   2.5135573E-06,   1.4825531E-06,   8.5139129E-07
     +,   4.7607753E-07,   2.5930197E-07,   1.3765143E-07
     +,   7.1301123E-08,   3.6111995E-08,   1.7947610E-08
     +,   8.8068353E-09,   4.3106292E-09,   2.1388948E-09
     +,   1.1004484E-09,   6.0212846E-10,   3.5705425E-10
     +,   2.3006656E-10,   1.5883737E-10,   1.1500448E-10
     +,   8.5645581E-11,   6.4718321E-11,   4.9217654E-11
     +,   3.7499663E-11,   2.8558910E-11,   2.1715412E-11
     +,   1.6476501E-11,   1.2471520E-11,   9.4164008E-12
     +,   7.0916116E-12,   5.3270487E-12,   3.9911889E-12
     +,   2.9826330E-12,   2.2231531E-12,   1.6528048E-12
     +,   1.2255933E-12,   9.0646929E-13,   6.6870587E-13
     +,   4.9204027E-13,   3.6111191E-13,   2.6434261E-13
     +,   1.9300524E-13,   1.4055867E-13,   1.0210069E-13
     +,   7.3973766E-14,   5.3458414E-14,   3.8533097E-14
     +,   2.7703949E-14,   1.9866934E-14,   1.4210584E-14
     +,   1.0138542E-14,   7.2149487E-15,   5.1212544E-15
     +,   3.6258884E-15,   2.5605870E-15,   1.8036914E-15
     +,   1.2672854E-15,   8.8814994E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt108 = Yx/0.0126538461538462
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2123645E-16,   4.8513171E-16
     +,   7.3015775E-16,   1.0952104E-15,   1.6371930E-15
     +,   2.4390754E-15,   3.6213835E-15,   5.3585341E-15
     +,   7.9020026E-15,   1.1613254E-14,   1.7009616E-14
     +,   2.4828845E-14,   3.6119555E-14,   5.2366128E-14
     +,   7.5662526E-14,   1.0895196E-13,   1.5635490E-13
     +,   2.2362019E-13,   3.1873777E-13,   4.5277071E-13
     +,   6.4098358E-13,   9.0434919E-13,   1.2715914E-12
     +,   1.7819154E-12,   2.4885354E-12,   3.4635803E-12
     +,   4.8043015E-12,   6.6413719E-12,   9.1497235E-12
     +,   1.2562653E-11,   1.7190057E-11,   2.3442092E-11
     +,   3.1859404E-11,   4.3152155E-11,   5.8249197E-11
     +,   7.8361040E-11,   1.0505906E-10,   1.4037413E-10
     +,   1.8692541E-10,   2.4806660E-10,   3.2809006E-10
     +,   4.3245510E-10,   5.6808319E-10,   7.4371348E-10
     +,   9.7033837E-10,   1.2617213E-09,   1.6350337E-09
     +,   2.1116116E-09,   2.7178395E-09,   3.4862480E-09
     +,   4.4567261E-09,   5.6780305E-09,   7.2094477E-09
     +,   9.1229264E-09,   1.1505019E-08,   1.4459969E-08
     +,   1.8112280E-08,   2.2610232E-08,   2.8129580E-08
     +,   3.4877782E-08,   4.3098549E-08,   5.3077073E-08
     +,   6.5144590E-08,   7.9685890E-08,   9.7144891E-08
     +,   1.1802949E-07,   1.4292249E-07,   1.7248317E-07
     +,   2.0746123E-07,   2.4869641E-07,   2.9713414E-07
     +,   3.5382237E-07,   4.1992993E-07,   4.9673861E-07
     +,   5.8566144E-07,   6.8824340E-07,   8.0615632E-07
     +,   9.4120543E-07,   1.0953415E-06,   1.2706539E-06
     +,   1.4693497E-06,   1.6937943E-06,   1.9464551E-06
     +,   2.2299569E-06,   2.5470101E-06,   2.9004846E-06
     +,   3.2933162E-06,   3.7286027E-06,   4.2094953E-06
     +,   4.7392950E-06,   5.3214194E-06,   5.9593626E-06
     +,   6.6567359E-06,   7.4173172E-06,   8.2450379E-06
     +,   9.1438988E-06,   1.0118173E-05,   1.1172190E-05
     +,   1.2310597E-05,   1.3538074E-05,   1.4859639E-05
     +,   1.6280314E-05,   1.7805414E-05,   1.9440160E-05
     +,   2.1189935E-05,   2.3060060E-05,   2.5055557E-05
     +,   2.7181084E-05,   2.9440947E-05,   3.1838765E-05
     +,   3.4377004E-05,   3.7057293E-05,   3.9879498E-05
     +,   4.2842155E-05,   4.5941480E-05,   4.9171846E-05
     +,   5.2524763E-05,   5.5989512E-05,   5.9552076E-05
     +,   6.3195817E-05,   6.6901135E-05,   7.0645183E-05
     +,   7.4402269E-05,   7.8144265E-05,   8.1840677E-05
     +,   8.5458632E-05,   8.8964247E-05,   9.2322160E-05
     +,   9.5497082E-05,   9.8453595E-05,   1.0115765E-04
     +,   1.0357653E-04,   1.0568026E-04,   1.0744160E-04
     +,   1.0883720E-04,   1.0984796E-04,   1.1045924E-04
     +,   1.1066167E-04,   1.1045099E-04,   1.0982835E-04
     +,   1.0880028E-04,   1.0737846E-04,   1.0557945E-04
     +,   1.0342431E-04,   1.0093828E-04,   9.8149954E-05
     +,   9.5090632E-05,   9.1794042E-05,   8.8295419E-05
     +,   8.4630570E-05,   8.0835394E-05,   7.6945558E-05
     +,   7.2995674E-05,   6.9018526E-05,   6.5044856E-05
     +,   6.1103347E-05,   5.7220001E-05,   5.3417789E-05
     +,   4.9716760E-05,   4.6134362E-05,   4.2684780E-05
     +,   3.9379371E-05,   3.6227040E-05,   3.3234148E-05
     +,   3.0404568E-05,   2.7740101E-05,   2.5240895E-05
     +,   2.2905460E-05,   2.0730773E-05,   1.8712701E-05
     +,   1.6846298E-05,   1.5125892E-05,   1.3545177E-05
     +,   1.2097569E-05,   1.0776568E-05,   9.5757787E-06
     +,   8.4894791E-06,   7.5132680E-06,   6.6448215E-06
     +,   5.8850383E-06,   5.2397618E-06,   4.7219683E-06
     +,   4.3543273E-06,   4.1721682E-06,   4.2264792E-06
     +,   4.5862530E-06,   5.3394101E-06,   6.5915206E-06
     +,   8.4614176E-06,   1.1073165E-05,   1.4546067E-05
     +,   1.8984170E-05,   2.4469889E-05,   3.1069314E-05
     +,   3.8856990E-05,   4.7966128E-05,   5.8667021E-05
     +,   7.1469010E-05,   8.7227039E-05,   1.0722079E-04
     +,   1.3317072E-04,   1.6716833E-04,   2.1152168E-04
     +,   2.6855228E-04,   3.4041653E-04,   4.2905490E-04
     +,   5.3626561E-04,   6.6383590E-04,   8.1356085E-04
     +,   9.8690810E-04,   1.1841480E-03,   1.4030425E-03
     +,   1.6375121E-03,   1.8768761E-03,   2.1062009E-03
     +,   2.3080409E-03,   2.4653082E-03,   2.5644447E-03
     +,   2.5979031E-03,   2.5652209E-03,   2.4724458E-03
     +,   2.3302529E-03,   2.1515454E-03,   1.9492637E-03
     +,   1.7349153E-03,   1.5179712E-03,   1.3058976E-03
     +,   1.1044423E-03,   9.1792305E-04,   7.4941316E-04
     +,   6.0080882E-04,   4.7284586E-04,   3.6519120E-04
     +,   2.7664425E-04,   2.0540148E-04,   1.4930886E-04
     +,   1.0610458E-04,   7.3586358E-05,   4.9710012E-05
     +,   3.2644097E-05,   2.0798529E-05,   1.2833805E-05
     +,   7.6575416E-06,   4.4119856E-06,   2.4517994E-06
     +,   1.3129398E-06,   6.7701689E-07,   3.3595805E-07
     +,   1.6035854E-07,   7.3601989E-08,   3.2475228E-08
     +,   1.3771473E-08,   5.6120459E-09,   2.1975617E-09
     +,   8.2678780E-10,   2.9884153E-10,   1.0377230E-10
     +,   3.4619738E-11,   1.1095791E-11,   3.4165691E-12
     +,   1.0108832E-12,   2.8752264E-13,   7.8687531E-14
     +,   2.0771892E-14,   5.3249298E-15,   1.3490771E-15
     +,   3.5284195E-16,   1.0407332E-16,   3.8522360E-17
     +,   1.8260738E-17,   1.0160764E-17,   6.0633323E-18
     +,   3.7024683E-18,   2.2719310E-18,   1.3924137E-18
     +,   8.5073437E-19,   5.1785663E-19,   3.1401976E-19
     +,   1.8967210E-19,   1.1411916E-19,   6.8391855E-20
     +,   4.0827929E-20,   2.4277312E-20,   1.4379734E-20
     +,   8.4838503E-21,   4.9858643E-21,   2.9186910E-21
     +,   1.7018625E-21,   9.8848346E-22,   5.7187968E-22
     +,   3.2956932E-22,   1.8918173E-22,   1.0817292E-22
     +,   6.1609822E-23,   3.4953294E-23,   1.9752178E-23
     +,   1.1118608E-23,   6.2341106E-24,   3.4818392E-24
     +,   1.9370164E-24,   1.0733997E-24
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt110 = Yx/0.01148
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.6657699E-06,   6.5476606E-06
     +,   6.4303877E-06,   6.3141242E-06,   6.1990518E-06
     +,   6.0853490E-06,   5.9732015E-06,   5.8627948E-06
     +,   5.7543211E-06,   5.6479680E-06,   5.5439345E-06
     +,   5.4424181E-06,   5.3436215E-06,   5.2477494E-06
     +,   5.1550123E-06,   5.0656204E-06,   4.9797909E-06
     +,   4.8977431E-06,   4.8197003E-06,   4.7458902E-06
     +,   4.6765431E-06,   4.6118939E-06,   4.5521815E-06
     +,   4.4976459E-06,   4.4485355E-06,   4.4050976E-06
     +,   4.3675846E-06,   4.3362520E-06,   4.3113596E-06
     +,   4.2931670E-06,   4.2819383E-06,   4.2779384E-06
     +,   4.2814354E-06,   4.2926968E-06,   4.3119899E-06
     +,   4.3395862E-06,   4.3757536E-06,   4.4207573E-06
     +,   4.4748658E-06,   4.5383367E-06,   4.6114342E-06
     +,   4.6944128E-06,   4.7875192E-06,   4.8909992E-06
     +,   5.0050867E-06,   5.1300103E-06,   5.2659893E-06
     +,   5.4132297E-06,   5.5719274E-06,   5.7422644E-06
     +,   5.9244089E-06,   6.1185137E-06,   6.3247094E-06
     +,   6.5431236E-06,   6.7738388E-06,   7.0169413E-06
     +,   7.2724815E-06,   7.5404869E-06,   7.8209659E-06
     +,   8.1138915E-06,   8.4192161E-06,   8.7368653E-06
     +,   9.0667145E-06,   9.4086326E-06,   9.7624616E-06
     +,   1.0127968E-05,   1.0504938E-05,   1.0893074E-05
     +,   1.1292089E-05,   1.1701611E-05,   1.2121281E-05
     +,   1.2550655E-05,   1.2989304E-05,   1.3436703E-05
     +,   1.3892338E-05,   1.4355657E-05,   1.4826038E-05
     +,   1.5302832E-05,   1.5785374E-05,   1.6272979E-05
     +,   1.6764869E-05,   1.7260309E-05,   1.7758462E-05
     +,   1.8258530E-05,   1.8759627E-05,   1.9260900E-05
     +,   1.9761421E-05,   2.0260293E-05,   2.0756543E-05
     +,   2.1249230E-05,   2.1737404E-05,   2.2220069E-05
     +,   2.2696222E-05,   2.3164894E-05,   2.3625114E-05
     +,   2.4075855E-05,   2.4516177E-05,   2.4945071E-05
     +,   2.5361613E-05,   2.5764828E-05,   2.6153821E-05
     +,   2.6527659E-05,   2.6885496E-05,   2.7226468E-05
     +,   2.7549759E-05,   2.7854605E-05,   2.8140254E-05
     +,   2.8405992E-05,   2.8651180E-05,   2.8875202E-05
     +,   2.9077486E-05,   2.9257535E-05,   2.9414874E-05
     +,   2.9549105E-05,   2.9659874E-05,   2.9746892E-05
     +,   2.9809928E-05,   2.9848803E-05,   2.9863404E-05
     +,   2.9853680E-05,   2.9819632E-05,   2.9761331E-05
     +,   2.9678908E-05,   2.9572549E-05,   2.9442495E-05
     +,   2.9289062E-05,   2.9112596E-05,   2.8913530E-05
     +,   2.8692315E-05,   2.8449496E-05,   2.8185623E-05
     +,   2.7901327E-05,   2.7597262E-05,   2.7274138E-05
     +,   2.6932701E-05,   2.6573714E-05,   2.6198006E-05
     +,   2.5806426E-05,   2.5399839E-05,   2.4979121E-05
     +,   2.4545203E-05,   2.4099028E-05,   2.3641529E-05
     +,   2.3173652E-05,   2.2696382E-05,   2.2210683E-05
     +,   2.1717491E-05,   2.1217798E-05,   2.0712576E-05
     +,   2.0202768E-05,   1.9689285E-05,   1.9173087E-05
     +,   1.8655093E-05,   1.8136187E-05,   1.7617234E-05
     +,   1.7099112E-05,   1.6582680E-05,   1.6068767E-05
     +,   1.5558171E-05,   1.5051758E-05,   1.4550354E-05
     +,   1.4054808E-05,   1.3566065E-05,   1.3085158E-05
     +,   1.2613217E-05,   1.2151562E-05,   1.1701834E-05
     +,   1.1266027E-05,   1.0846615E-05,   1.0446738E-05
     +,   1.0070441E-05,   9.7228649E-06,   9.4105644E-06
     +,   9.1418815E-06,   8.9274154E-06,   8.7804692E-06
     +,   8.7177013E-06,   8.7597991E-06,   8.9322466E-06
     +,   9.2662167E-06,   9.7995644E-06,   1.0577850E-05
     +,   1.1655467E-05,   1.3096962E-05,   1.4978280E-05
     +,   1.7387883E-05,   2.0428046E-05,   2.4216228E-05
     +,   2.8886012E-05,   3.4587272E-05,   4.1487474E-05
     +,   4.9771210E-05,   5.9638867E-05,   7.1305192E-05
     +,   8.4997722E-05,   1.0095247E-04,   1.1940765E-04
     +,   1.4059771E-04,   1.6474692E-04,   1.9205865E-04
     +,   2.2270251E-04,   2.5680303E-04,   2.9442919E-04
     +,   3.3557924E-04,   3.8016267E-04,   4.2799645E-04
     +,   4.7879046E-04,   5.3213688E-04,   5.8750849E-04
     +,   6.4426340E-04,   7.0164702E-04,   7.5880002E-04
     +,   8.1477792E-04,   8.6857844E-04,   9.1916445E-04
     +,   9.6549303E-04,   1.0065535E-03,   1.0414065E-03
     +,   1.0692149E-03,   1.0892762E-03,   1.1010559E-03
     +,   1.1042089E-03,   1.0985939E-03,   1.0842843E-03
     +,   1.0615655E-03,   1.0309243E-03,   9.9303422E-04
     +,   9.4872830E-04,   8.9896505E-04,   8.4479427E-04
     +,   7.8732299E-04,   7.2767382E-04,   6.6694414E-04
     +,   6.0617604E-04,   5.4633216E-04,   4.8826160E-04
     +,   4.3268889E-04,   3.8020653E-04,   3.3126699E-04
     +,   2.8618245E-04,   2.4513478E-04,   2.0819009E-04
     +,   1.7530934E-04,   1.4636343E-04,   1.2115315E-04
     +,   9.9428224E-05,   8.0901445E-05,   6.5263135E-05
     +,   5.2196101E-05,   4.1387601E-05,   3.2535572E-05
     +,   2.5356978E-05,   1.9592466E-05,   1.5008471E-05
     +,   1.1398198E-05,   8.5819402E-06,   6.4060596E-06
     +,   4.7409053E-06,   3.4785621E-06,   2.5305326E-06
     +,   1.8252267E-06,   1.3053884E-06,   9.2577397E-07
     +,   6.5109919E-07,   4.5418355E-07,   3.1428846E-07
     +,   2.1579372E-07,   1.4706622E-07,   9.9531050E-08
     +,   6.6934440E-08,   4.4767901E-08,   2.9815752E-08
     +,   1.9806810E-08,   1.3153357E-08,   8.7574419E-09
     +,   5.8675962E-09,   3.9739390E-09,   2.7344078E-09
     +,   1.9213451E-09,   1.3848538E-09,   1.0269569E-09
     +,   7.8423112E-10,   6.1586375E-10,   4.9579707E-10
     +,   4.0744219E-10,   3.4028294E-10,   2.8763078E-10
     +,   2.4521543E-10,   2.1028065E-10,   1.8100900E-10
     +,   1.5617559E-10,   1.3492223E-10,   1.1662846E-10
     +,   1.0082353E-10,   8.7140274E-11,   7.5279935E-11
     +,   6.4995925E-11,   5.6078565E-11,   4.8349325E-11
     +,   4.1653066E-11,   3.5855919E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt112 = Yx/0.00821739130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   2.4404857E-38
     +,   8.1162843E-38,   2.6760787E-37,   8.7327521E-37
     +,   2.8228816E-36,   9.0386504E-36,   2.8668218E-35
     +,   9.0069425E-35,   2.8030682E-34,   8.6410470E-34
     +,   2.6386526E-33,   7.9813804E-33,   2.3913994E-32
     +,   7.0975426E-32,   2.0866158E-31,   6.0765770E-31
     +,   1.7528885E-30,   5.0087600E-30,   1.4176868E-29
     +,   3.9748991E-29,   1.1039172E-28,   3.0369412E-28
     +,   8.2759136E-28,   2.2339853E-27,   5.9734243E-27
     +,   1.5821582E-26,   4.1510409E-26,   1.0788345E-25
     +,   2.7772948E-25,   7.0822374E-25,   1.7890208E-24
     +,   4.4764165E-24,   1.1095434E-23,   2.7241263E-23
     +,   6.6253360E-23,   1.5960999E-22,   3.8089966E-22
     +,   9.0039559E-22,   2.1084115E-21,   4.8904687E-21
     +,   1.1236537E-20,   2.5574964E-20,   5.7661216E-20
     +,   1.2877433E-19,   2.8488118E-19,   6.2430976E-19
     +,   1.3552342E-18,   2.9142721E-18,   6.2076538E-18
     +,   1.3098668E-17,   2.7378464E-17,   5.6688481E-17
     +,   1.1626962E-16,   2.3623407E-16,   4.7544976E-16
     +,   9.4790748E-16,   1.8721232E-15,   3.6627187E-15
     +,   7.0984389E-15,   1.3627788E-14,   2.5917941E-14
     +,   4.8828288E-14,   9.1129137E-14,   1.6847778E-13
     +,   3.0856445E-13,   5.5982459E-13,   1.0061886E-12
     +,   1.7914824E-12,   3.1598819E-12,   5.5212887E-12
     +,   9.5571996E-12,   1.6388951E-11,   2.7841821E-11
     +,   4.6855946E-11,   7.8120108E-11,   1.2903294E-10
     +,   2.1113848E-10,   3.4227920E-10,   5.4970428E-10
     +,   8.7464030E-10,   1.3787069E-09,   2.1531459E-09
     +,   3.3313809E-09,   5.1067102E-09,   7.7555979E-09
     +,   1.1669645E-08,   1.7397147E-08,   2.5696544E-08
     +,   3.7605119E-08,   5.4526193E-08,   7.8335681E-08
     +,   1.1150772E-07,   1.5727380E-07,   2.1979093E-07
     +,   3.0435478E-07,   4.1760313E-07,   5.6777441E-07
     +,   7.6491551E-07,   1.0211543E-06,   1.3508521E-06
     +,   1.7708149E-06,   2.3003697E-06,   2.9613129E-06
     +,   3.7777759E-06,   4.7759927E-06,   5.9837980E-06
     +,   7.4298423E-06,   9.1427219E-06,   1.1149998E-05
     +,   1.3476809E-05,   1.6144095E-05,   1.9167450E-05
     +,   2.2555259E-05,   2.6306820E-05,   3.0410974E-05
     +,   3.4845136E-05,   3.9574174E-05,   4.4549539E-05
     +,   4.9709586E-05,   5.4980661E-05,   6.0277987E-05
     +,   6.5507294E-05,   7.0567723E-05,   7.5355194E-05
     +,   7.9765523E-05,   8.3697734E-05,   8.7058710E-05
     +,   8.9766356E-05,   9.1752750E-05,   9.2967304E-05
     +,   9.3378927E-05,   9.2977170E-05,   9.1772818E-05
     +,   8.9797693E-05,   8.7103028E-05,   8.3757674E-05
     +,   7.9845602E-05,   7.5462711E-05,   7.0713104E-05
     +,   6.5705826E-05,   6.0552091E-05,   5.5361204E-05
     +,   5.0238454E-05,   4.5283385E-05,   4.0587831E-05
     +,   3.6234655E-05,   3.2297550E-05,   2.8841087E-05
     +,   2.5920368E-05,   2.3580906E-05,   2.1858827E-05
     +,   2.0780646E-05,   2.0362517E-05,   2.0609636E-05
     +,   2.1515925E-05,   2.3063969E-05,   2.5226602E-05
     +,   2.7970218E-05,   3.1260421E-05,   3.5070687E-05
     +,   3.9393381E-05,   4.4250501E-05,   4.9701001E-05
     +,   5.5840996E-05,   6.2791325E-05,   7.0667898E-05
     +,   7.9534992E-05,   8.9347996E-05,   9.9897268E-05
     +,   1.1077002E-04,   1.2135508E-04,   1.3092448E-04
     +,   1.3882332E-04,   1.4481973E-04,   1.4966031E-04
     +,   1.5582096E-04,   1.6830671E-04,   1.9515601E-04
     +,   2.4722930E-04,   3.3719654E-04,   4.7837626E-04
     +,   6.8446237E-04,   9.6985075E-04,   1.3470859E-03
     +,   1.8166506E-03,   2.3505723E-03,   2.8831977E-03
     +,   3.3245634E-03,   3.5950518E-03,   3.6577343E-03
     +,   3.5250990E-03,   3.2412170E-03,   2.8585973E-03
     +,   2.4240012E-03,   1.9743980E-03,   1.5386406E-03
     +,   1.1403809E-03,   7.9867523E-04,   5.2558642E-04
     +,   3.2357624E-04,   1.8573384E-04,   9.9077362E-05
     +,   4.8940605E-05,   2.2298003E-05,   9.3327217E-06
     +,   3.5747216E-06,   1.2490717E-06,   3.9729983E-07
     +,   1.1497136E-07,   3.0344104E-08,   7.3789055E-09
     +,   1.7050945E-09,   4.0537299E-10,   1.1446258E-10
     +,   4.2565510E-11,   1.9528202E-11,   9.7694439E-12
     +,   4.9780666E-12,   2.5233810E-12,   1.2641633E-12
     +,   6.2491662E-13,   3.0470540E-13,   1.4654058E-13
     +,   6.9512179E-14,   3.2521959E-14,   1.5007106E-14
     +,   6.8301442E-15,   3.0661110E-15,   1.3575637E-15
     +,   5.9283709E-16,   2.5534933E-16,   1.0847969E-16
     +,   4.5453072E-17,   1.8784186E-17,   7.6567874E-18
     +,   3.0783299E-18,   1.2206344E-18,   4.7738594E-19
     +,   1.8415262E-19,   7.0065429E-20,   2.6292133E-20
     +,   9.7314778E-21,   3.5524624E-21,   1.2791145E-21
     +,   4.5424181E-22,   1.5910874E-22,   5.4966799E-23
     +,   1.8729855E-23,   6.2945953E-24,   2.0865582E-24
     +,   6.8216727E-25,   2.1997865E-25,   6.9965590E-26
     +,   2.1947479E-26,   6.7907435E-27,   2.0722609E-27
     +,   6.2374077E-28,   1.8516473E-28,   5.4218389E-29
     +,   1.5657693E-29,   4.4600678E-30,   1.2530053E-30
     +,   3.4721244E-31,   9.4892557E-32,   2.5580059E-32
     +,   6.8008843E-33,   1.7834536E-33
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt113 = Yx/0.0105
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   1.3589710E-38,   4.3937932E-38,   1.4005168E-37
     +,   4.4246006E-37,   1.3854806E-36,   4.2999578E-36
     +,   1.3227226E-35,   4.0328407E-35,   1.2186752E-34
     +,   3.6502514E-34,   1.0836175E-33,   3.1884840E-33
     +,   9.2988899E-33,   2.6879230E-32,   7.7009926E-32
     +,   2.1868337E-31,   6.1549961E-31,   1.7170435E-30
     +,   4.7476438E-30,   1.3011184E-29,   3.5342551E-29
     +,   9.5153151E-29,   2.5391665E-28,   6.7157447E-28
     +,   1.7605787E-27,   4.5745559E-27,   1.1781297E-26
     +,   3.0073353E-26,   7.6088167E-26,   1.9080844E-25
     +,   4.7426786E-25,   1.1684117E-24,   2.8531492E-24
     +,   6.9053137E-24,   1.6565123E-23,   3.9387834E-23
     +,   9.2825976E-23,   2.1683822E-22,   5.0204557E-22
     +,   1.1521537E-21,   2.6207055E-21,   5.9086561E-21
     +,   1.3203812E-20,   2.9246606E-20,   6.4208583E-20
     +,   1.3972184E-19,   3.0137209E-19,   6.4431202E-19
     +,   1.3653198E-18,   2.8676755E-18,   5.9702898E-18
     +,   1.2319907E-17,   2.5199402E-17,   5.1088584E-17
     +,   1.0266639E-16,   2.0449594E-16,   4.0375191E-16
     +,   7.9013266E-16,   1.5327082E-15,   2.9469644E-15
     +,   5.6164222E-15,   1.0610162E-14,   1.9867974E-14
     +,   3.6876301E-14,   6.7844371E-14,   1.2372643E-13
     +,   2.2365428E-13,   4.0075308E-13,   7.1177932E-13
     +,   1.2531461E-12,   2.1869078E-12,   3.7831127E-12
     +,   6.4870023E-12,   1.1026332E-11,   1.8577974E-11
     +,   3.1027989E-11,   5.1369700E-11,   8.4304806E-11
     +,   1.3714627E-10,   2.2116274E-10,   3.5354436E-10
     +,   5.6023336E-10,   8.8003926E-10,   1.3703509E-09
     +,   2.1153088E-09,   3.2368110E-09,   4.9099387E-09
     +,   7.3831425E-09,   1.1005918E-08,   1.6263796E-08
     +,   2.3825196E-08,   3.4600067E-08,   4.9812748E-08
     +,   7.1092622E-08,   1.0058579E-07,   1.4108586E-07
     +,   1.9618182E-07,   2.7044157E-07,   3.6959074E-07
     +,   5.0074107E-07,   6.7257918E-07,   8.9561780E-07
     +,   1.1823478E-06,   1.5474666E-06,   2.0079178E-06
     +,   2.5830050E-06,   3.2943151E-06,   4.1654725E-06
     +,   5.2218220E-06,   6.4899900E-06,   7.9971569E-06
     +,   9.7700276E-06,   1.1833798E-05,   1.4211041E-05
     +,   1.6920201E-05,   1.9973779E-05,   2.3377328E-05
     +,   2.7127719E-05,   3.1211559E-05,   3.5604233E-05
     +,   4.0269486E-05,   4.5158809E-05,   5.0211296E-05
     +,   5.5354682E-05,   6.0507013E-05,   6.5578271E-05
     +,   7.0472575E-05,   7.5091441E-05,   7.9337522E-05
     +,   8.3117753E-05,   8.6346707E-05,   8.8950845E-05
     +,   9.0871283E-05,   9.2066366E-05,   9.2514179E-05
     +,   9.2213668E-05,   9.1185175E-05,   8.9470137E-05
     +,   8.7129934E-05,   8.4243722E-05,   8.0905709E-05
     +,   7.7222277E-05,   7.3308089E-05,   6.9281981E-05
     +,   6.5263353E-05,   6.1368934E-05,   5.7708792E-05
     +,   5.4384142E-05,   5.1485753E-05,   4.9092763E-05
     +,   4.7272639E-05,   4.6082572E-05,   4.5571436E-05
     +,   4.5782293E-05,   4.6755351E-05,   4.8530783E-05
     +,   5.1150280E-05,   5.4657230E-05,   5.9094858E-05
     +,   6.4501291E-05,   7.0900875E-05,   7.8294506E-05
     +,   8.6646491E-05,   9.5870433E-05,   1.0581748E-04
     +,   1.1626834E-04,   1.2692960E-04,   1.3743772E-04
     +,   1.4737280E-04,   1.5628191E-04,   1.6370791E-04
     +,   1.6922576E-04,   1.7248369E-04,   1.7324973E-04
     +,   1.7146801E-04,   1.6734211E-04,   1.6146399E-04
     +,   1.5501372E-04,   1.5004232E-04,   1.4982602E-04
     +,   1.5927016E-04,   1.8532322E-04,   2.3726655E-04
     +,   3.2645816E-04,   4.6465482E-04,   6.5991073E-04
     +,   9.1019843E-04,   1.1975729E-03,   1.4880861E-03
     +,   1.7417992E-03,   1.9317355E-03,   2.0627368E-03
     +,   2.1764461E-03,   2.3330108E-03,   2.5731304E-03
     +,   2.8802035E-03,   3.1694782E-03,   3.3192278E-03
     +,   3.2312013E-03,   2.8836261E-03,   2.3427121E-03
     +,   1.7278544E-03,   1.1565699E-03,   7.0329272E-04
     +,   3.8909545E-04,   1.9616331E-04,   9.0222398E-05
     +,   3.7875296E-05,   1.4509731E-05,   5.0683293E-06
     +,   1.6121716E-06,   4.6640261E-07,   1.2270124E-07
     +,   2.9453229E-08,   6.5444876E-09,   1.4135710E-09
     +,   3.3887018E-10,   1.1015359E-10,   5.0198672E-11
     +,   2.7189306E-11,   1.5464166E-11,   8.8418908E-12
     +,   5.0251929E-12,   2.8315332E-12,   1.5808058E-12
     +,   8.7420376E-13,   4.7880498E-13,   2.5970727E-13
     +,   1.3949825E-13,   7.4196563E-14,   3.9075348E-14
     +,   2.0376284E-14,   1.0520859E-14,   5.3785720E-15
     +,   2.7224456E-15,   1.3644009E-15,   6.7702962E-16
     +,   3.3261621E-16,   1.6179213E-16,   7.7921823E-17
     +,   3.7157023E-17,   1.7542406E-17,   8.1999953E-18
     +,   3.7951522E-18,   1.7390815E-18,   7.8900431E-19
     +,   3.5442601E-19,   1.5762997E-19,   6.9413333E-20
     +,   3.0262842E-20,   1.3063739E-20,   5.5832842E-21
     +,   2.3626688E-21,   9.8987498E-22,   4.1062664E-22
     +,   1.6864751E-22,   6.8580721E-23,   2.7612356E-23
     +,   1.1006968E-23,   4.3443296E-24,   1.6976336E-24
     +,   6.5682960E-25,   2.5160980E-25,   9.5431850E-26
     +,   3.5836191E-26,   1.3324203E-26,   4.9048802E-27
     +,   1.7877352E-27,   6.4512273E-28,   2.3050081E-28
     +,   8.1539294E-29,   2.8559618E-29
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt114 = Yx/0.0107916666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.3192809E-07,   5.8726613E-07
     +,   6.4745637E-07,   7.1281971E-07,   7.8368623E-07
     +,   8.6039540E-07,   9.4329516E-07,   1.0327391E-06
     +,   1.1290841E-06,   1.2326967E-06,   1.3439393E-06
     +,   1.4631757E-06,   1.5907677E-06,   1.7270729E-06
     +,   1.8724402E-06,   2.0272107E-06,   2.1917108E-06
     +,   2.3662526E-06,   2.5511295E-06,   2.7466128E-06
     +,   2.9529479E-06,   3.1703541E-06,   3.3990134E-06
     +,   3.6390873E-06,   3.8906724E-06,   4.1538519E-06
     +,   4.4286458E-06,   4.7150302E-06,   5.0129306E-06
     +,   5.3222179E-06,   5.6427039E-06,   5.9741442E-06
     +,   6.3162279E-06,   6.6685870E-06,   7.0307833E-06
     +,   7.4023142E-06,   7.7826107E-06,   8.1710295E-06
     +,   8.5668889E-06,   8.9693913E-06,   9.3777244E-06
     +,   9.7909851E-06,   1.0208216E-05,   1.0628401E-05
     +,   1.1050474E-05,   1.1473314E-05,   1.1895755E-05
     +,   1.2316594E-05,   1.2734585E-05,   1.3148459E-05
     +,   1.3556928E-05,   1.3958677E-05,   1.4352384E-05
     +,   1.4736748E-05,   1.5110430E-05,   1.5472151E-05
     +,   1.5820628E-05,   1.6154610E-05,   1.6472897E-05
     +,   1.6774326E-05,   1.7057788E-05,   1.7322243E-05
     +,   1.7566706E-05,   1.7790295E-05,   1.7992194E-05
     +,   1.8171671E-05,   1.8328112E-05,   1.8460982E-05
     +,   1.8569872E-05,   1.8654462E-05,   1.8714565E-05
     +,   1.8750101E-05,   1.8761104E-05,   1.8747738E-05
     +,   1.8710281E-05,   1.8649120E-05,   1.8564780E-05
     +,   1.8457886E-05,   1.8329185E-05,   1.8179519E-05
     +,   1.8009861E-05,   1.7821256E-05,   1.7614870E-05
     +,   1.7391931E-05,   1.7153778E-05,   1.6901795E-05
     +,   1.6637465E-05,   1.6362295E-05,   1.6077885E-05
     +,   1.5785841E-05,   1.5487811E-05,   1.5185481E-05
     +,   1.4880553E-05,   1.4574723E-05,   1.4269675E-05
     +,   1.3967120E-05,   1.3668702E-05,   1.3376081E-05
     +,   1.3090841E-05,   1.2814553E-05,   1.2548702E-05
     +,   1.2294746E-05,   1.2054044E-05,   1.1827905E-05
     +,   1.1617542E-05,   1.1424076E-05,   1.1248551E-05
     +,   1.1091912E-05,   1.0954988E-05,   1.0838507E-05
     +,   1.0743097E-05,   1.0669258E-05,   1.0617391E-05
     +,   1.0587766E-05,   1.0580545E-05,   1.0595765E-05
     +,   1.0633347E-05,   1.0693097E-05,   1.0774689E-05
     +,   1.0877698E-05,   1.1001577E-05,   1.1145667E-05
     +,   1.1309196E-05,   1.1491295E-05,   1.1690997E-05
     +,   1.1907221E-05,   1.2138820E-05,   1.2384534E-05
     +,   1.2643053E-05,   1.2912961E-05,   1.3192815E-05
     +,   1.3481070E-05,   1.3776177E-05,   1.4076494E-05
     +,   1.4380386E-05,   1.4686184E-05,   1.4992184E-05
     +,   1.5296673E-05,   1.5597961E-05,   1.5894366E-05
     +,   1.6184204E-05,   1.6465823E-05,   1.6737624E-05
     +,   1.6998054E-05,   1.7245586E-05,   1.7478784E-05
     +,   1.7696275E-05,   1.7896760E-05,   1.8079018E-05
     +,   1.8241930E-05,   1.8384477E-05,   1.8505731E-05
     +,   1.8604873E-05,   1.8681201E-05,   1.8734128E-05
     +,   1.8763176E-05,   1.8767991E-05,   1.8748338E-05
     +,   1.8704101E-05,   1.8635277E-05,   1.8541994E-05
     +,   1.8424485E-05,   1.8283095E-05,   1.8118291E-05
     +,   1.7930630E-05,   1.7720768E-05,   1.7489463E-05
     +,   1.7237573E-05,   1.6966014E-05,   1.6675780E-05
     +,   1.6367949E-05,   1.6043656E-05,   1.5704074E-05
     +,   1.5350415E-05,   1.4983964E-05,   1.4605994E-05
     +,   1.4217802E-05,   1.3820717E-05,   1.3416074E-05
     +,   1.3005179E-05,   1.2589324E-05,   1.2169811E-05
     +,   1.1747917E-05,   1.1324857E-05,   1.0901811E-05
     +,   1.0479949E-05,   1.0060385E-05,   9.6441609E-06
     +,   9.2322698E-06,   8.8257057E-06,   8.4254016E-06
     +,   8.0323334E-06,   7.6476781E-06,   7.2730800E-06
     +,   6.9112193E-06,   6.5670201E-06,   6.2498634E-06
     +,   5.9774920E-06,   5.7826551E-06,   5.7238485E-06
     +,   5.9015806E-06,   6.4814412E-06,   7.7247450E-06
     +,   1.0025756E-05,   1.3951855E-05,   2.0281843E-05
     +,   3.0033087E-05,   4.4468274E-05,   6.5076951E-05
     +,   9.3533607E-05,   1.3163777E-04,   1.8125300E-04
     +,   2.4427054E-04,   3.2261043E-04,   4.1823552E-04
     +,   5.3313258E-04,   6.6920003E-04,   8.2794827E-04
     +,   1.0099285E-03,   1.2139044E-03,   1.4359625E-03
     +,   1.6687011E-03,   1.9008503E-03,   2.1176594E-03
     +,   2.3021747E-03,   2.4372987E-03,   2.5083593E-03
     +,   2.5056708E-03,   2.4264399E-03,   2.2755417E-03
     +,   2.0649876E-03,   1.8121314E-03,   1.5370151E-03
     +,   1.2595159E-03,   9.9685462E-04,   7.6181203E-04
     +,   5.6202558E-04,   4.0020829E-04,   2.7503213E-04
     +,   1.8238781E-04,   1.1670314E-04,   7.2049661E-05
     +,   4.2920132E-05,   2.4672809E-05,   1.3690998E-05
     +,   7.3386818E-06,   3.8053331E-06,   1.9142192E-06
     +,   9.3949023E-07,   4.5500036E-07,   2.2208388E-07
     +,   1.1316247E-07,   6.3031251E-08,   3.9786876E-08
     +,   2.8472520E-08,   2.2359416E-08,   1.8533566E-08
     +,   1.5772748E-08,   1.3573656E-08,   1.1726677E-08
     +,   1.0138348E-08,   8.7600647E-09,   7.5608515E-09
     +,   6.5173440E-09,   5.6102363E-09,   4.8226951E-09
     +,   4.1399129E-09,   3.5488361E-09,   3.0379153E-09
     +,   2.5969209E-09,   2.2168285E-09,   1.8897270E-09
     +,   1.6086481E-09,   1.3674637E-09,   1.1608102E-09
     +,   9.8401665E-10,   8.3297885E-10,   7.0414219E-10
     +,   5.9439881E-10,   5.0106130E-10,   4.2178783E-10
     +,   3.5456232E-10,   2.9763353E-10,   2.4949762E-10
     +,   2.0885350E-10,   1.7458719E-10,   1.4573900E-10
     +,   1.2148693E-10,   1.0112989E-10,   8.4065796E-11
     +,   6.9783845E-11,   5.7846995E-11,   4.7885317E-11
     +,   3.9583472E-11,   3.2675446E-11,   2.6935133E-11
     +,   2.2172406E-11,   1.8226197E-11,   1.4961523E-11
     +,   1.2264365E-11,   1.0039452E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt115 = Yx/0.00933333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6986365E-07,   1.8822799E-07
     +,   2.0833637E-07,   2.3032624E-07,   2.5434261E-07
     +,   2.8053833E-07,   3.0907393E-07,   3.4011833E-07
     +,   3.7384731E-07,   4.1044652E-07,   4.5010745E-07
     +,   4.9302980E-07,   5.3942051E-07,   5.8949365E-07
     +,   6.4346960E-07,   7.0157552E-07,   7.6404365E-07
     +,   8.3111098E-07,   9.0302007E-07,   9.8001635E-07
     +,   1.0623470E-06,   1.1502624E-06,   1.2440113E-06
     +,   1.3438482E-06,   1.4500151E-06,   1.5627619E-06
     +,   1.6823275E-06,   1.8089472E-06,   1.9428478E-06
     +,   2.0842474E-06,   2.2333543E-06,   2.3903608E-06
     +,   2.5554502E-06,   2.7287833E-06,   2.9105088E-06
     +,   3.1007507E-06,   3.2996143E-06,   3.5071762E-06
     +,   3.7235018E-06,   3.9486049E-06,   4.1824956E-06
     +,   4.4251387E-06,   4.6764721E-06,   4.9363985E-06
     +,   5.2047899E-06,   5.4814782E-06,   5.7662637E-06
     +,   6.0589109E-06,   6.3591447E-06,   6.6666557E-06
     +,   6.9810994E-06,   7.3020956E-06,   7.6292254E-06
     +,   7.9620586E-06,   8.3001014E-06,   8.6428645E-06
     +,   8.9898185E-06,   9.3404169E-06,   9.6940958E-06
     +,   1.0050275E-05,   1.0408378E-05,   1.0767825E-05
     +,   1.1128020E-05,   1.1488411E-05,   1.1848462E-05
     +,   1.2207625E-05,   1.2565446E-05,   1.2921452E-05
     +,   1.3275288E-05,   1.3626601E-05,   1.3975160E-05
     +,   1.4320773E-05,   1.4663377E-05,   1.5002977E-05
     +,   1.5339710E-05,   1.5673844E-05,   1.6005743E-05
     +,   1.6335909E-05,   1.6665015E-05,   1.6993878E-05
     +,   1.7323438E-05,   1.7654833E-05,   1.7989321E-05
     +,   1.8328361E-05,   1.8673518E-05,   1.9026565E-05
     +,   1.9389367E-05,   1.9763966E-05,   2.0152493E-05
     +,   2.0557216E-05,   2.0980495E-05,   2.1424736E-05
     +,   2.1892392E-05,   2.2385955E-05,   2.2907931E-05
     +,   2.3460718E-05,   2.4046723E-05,   2.4668165E-05
     +,   2.5327192E-05,   2.6025706E-05,   2.6765447E-05
     +,   2.7547831E-05,   2.8374056E-05,   2.9244886E-05
     +,   3.0160796E-05,   3.1121861E-05,   3.2127671E-05
     +,   3.3177337E-05,   3.4269568E-05,   3.5402580E-05
     +,   3.6573969E-05,   3.7780959E-05,   3.9020128E-05
     +,   4.0287698E-05,   4.1579231E-05,   4.2890017E-05
     +,   4.4214710E-05,   4.5547771E-05,   4.6883106E-05
     +,   4.8214468E-05,   4.9535342E-05,   5.0838964E-05
     +,   5.2118441E-05,   5.3366919E-05,   5.4577558E-05
     +,   5.5743509E-05,   5.6858236E-05,   5.7915331E-05
     +,   5.8908856E-05,   5.9833103E-05,   6.0682993E-05
     +,   6.1453859E-05,   6.2141735E-05,   6.2743202E-05
     +,   6.3255618E-05,   6.3677064E-05,   6.4006359E-05
     +,   6.4243133E-05,   6.4387837E-05,   6.4441716E-05
     +,   6.4406879E-05,   6.4286156E-05,   6.4083230E-05
     +,   6.3802479E-05,   6.3449028E-05,   6.3028652E-05
     +,   6.2547711E-05,   6.2013132E-05,   6.1432314E-05
     +,   6.0813010E-05,   6.0163264E-05,   5.9491369E-05
     +,   5.8805723E-05,   5.8114674E-05,   5.7426460E-05
     +,   5.6749141E-05,   5.6090437E-05,   5.5457571E-05
     +,   5.4857195E-05,   5.4295335E-05,   5.3777163E-05
     +,   5.3306980E-05,   5.2888114E-05,   5.2522821E-05
     +,   5.2212206E-05,   5.1956176E-05,   5.1753428E-05
     +,   5.1601422E-05,   5.1496369E-05,   5.1433257E-05
     +,   5.1405976E-05,   5.1407285E-05,   5.1429004E-05
     +,   5.1462139E-05,   5.1497020E-05,   5.1523504E-05
     +,   5.1531242E-05,   5.1509931E-05,   5.1449657E-05
     +,   5.1341332E-05,   5.1177147E-05,   5.0951228E-05
     +,   5.0660365E-05,   5.0304916E-05,   4.9889848E-05
     +,   4.9425980E-05,   4.8931302E-05,   4.8432186E-05
     +,   4.7964670E-05,   4.7575359E-05,   4.7321679E-05
     +,   4.7271595E-05,   4.7502373E-05,   4.8098300E-05
     +,   4.9147933E-05,   5.0740862E-05,   5.2964937E-05
     +,   5.5905173E-05,   5.9645976E-05,   6.4277694E-05
     +,   6.9909023E-05,   7.6687276E-05,   8.4826759E-05
     +,   9.4643794E-05,   1.0659578E-04,   1.2132458E-04
     +,   1.3969299E-04,   1.6280824E-04,   1.9202555E-04
     +,   2.2892315E-04,   2.7523426E-04,   3.3273039E-04
     +,   4.0306244E-04,   4.8756375E-04,   5.8701704E-04
     +,   7.0140866E-04,   8.2971394E-04,   9.6974376E-04
     +,   1.1180551E-03,   1.2699660E-03,   1.4197417E-03
     +,   1.5608688E-03,   1.6864528E-03,   1.7897289E-03
     +,   1.8646142E-03,   1.9062371E-03,   1.9114116E-03
     +,   1.8789987E-03,   1.8100773E-03,   1.7079113E-03
     +,   1.5777157E-03,   1.4262141E-03,   1.2610384E-03
     +,   1.0900737E-03,   9.2082057E-04,   7.5979007E-04
     +,   6.1210687E-04,   4.8128990E-04,   3.6921186E-04
     +,   2.7623712E-04,   2.0150442E-04,   1.4327276E-04
     +,   9.9268917E-05,   6.7008739E-05,   4.4058354E-05
     +,   2.8212491E-05,   1.7592549E-05,   1.0682150E-05
     +,   6.3158441E-06,   3.6368053E-06,   2.0401101E-06
     +,   1.1155548E-06,   5.9529054E-07,   3.1063473E-07
     +,   1.5906755E-07,   8.0422410E-08,   4.0562682E-08
     +,   2.0745487E-08,   1.1007884E-08,   6.2188250E-09
     +,   3.8138368E-09,   2.5462346E-09,   1.8245523E-09
     +,   1.3731898E-09,   1.0645227E-09,   8.3854845E-10
     +,   6.6575967E-10,   5.3039301E-10,   4.2303500E-10
     +,   3.3740327E-10,   2.6894612E-10,   2.1419039E-10
     +,   1.7040522E-10,   1.3541425E-10,   1.0747433E-10
     +,   8.5188370E-11,   6.7430471E-11,   5.3298234E-11
     +,   4.2064838E-11,   3.3148099E-11,   2.6079694E-11
     +,   2.0485079E-11,   1.6063430E-11,   1.2574598E-11
     +,   9.8261234E-12,   7.6646979E-12,   5.9678265E-12
     +,   4.6379814E-12,   3.5977517E-12,   2.7855183E-12
     +,   2.1525405E-12,   1.6601648E-12,   1.2779344E-12
     +,   9.8176773E-13,   7.5275295E-13,   5.7601097E-13
     +,   4.3988963E-13,   3.3526025E-13,   2.5500581E-13
     +,   1.9356980E-13,   1.4663909E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt116 = Yx/0.009625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt1168(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2562421E-12,   4.2428166E-12
     +,   5.5159935E-12,   7.1552686E-12,   9.2610459E-12
     +,   1.1959872E-11,   1.5410824E-11,   1.9813338E-11
     +,   2.5416762E-11,   3.2532480E-11,   4.1547665E-11
     +,   5.2943035E-11,   6.7313745E-11,   8.5394899E-11
     +,   1.0809175E-10,   1.3651683E-10,   1.7203358E-10
     +,   2.1630825E-10,   2.7137292E-10,   3.3969788E-10
     +,   4.2428044E-10,   5.2874499E-10,   6.5746458E-10
     +,   8.1570800E-10,   1.0097841E-09,   1.2472616E-09
     +,   1.5371661E-09,   1.8902462E-09,   2.3192674E-09
     +,   2.8393385E-09,   3.4683201E-09,   4.2272292E-09
     +,   5.1407700E-09,   6.2378591E-09,   7.5522983E-09
     +,   9.1234318E-09,   1.0996993E-08,   1.3225886E-08
     +,   1.5871404E-08,   1.9003783E-08,   2.2704084E-08
     +,   2.7064823E-08,   3.2191789E-08,   3.8205279E-08
     +,   4.5241904E-08,   5.3456144E-08,   6.3022313E-08
     +,   7.4136430E-08,   8.7018179E-08,   1.0191305E-07
     +,   1.1909459E-07,   1.3886627E-07,   1.6156388E-07
     +,   1.8755888E-07,   2.1725721E-07,   2.5110620E-07
     +,   2.8959249E-07,   3.3324571E-07,   3.8263994E-07
     +,   4.3839512E-07,   5.0117740E-07,   5.7170212E-07
     +,   6.5072754E-07,   7.3906506E-07,   8.3757448E-07
     +,   9.4715102E-07,   1.0687477E-06,   1.2033428E-06
     +,   1.3519691E-06,   1.5156741E-06,   1.6955549E-06
     +,   1.8927071E-06,   2.1082678E-06,   2.3433556E-06
     +,   2.5991080E-06,   2.8766569E-06,   3.1770978E-06
     +,   3.5014918E-06,   3.8508792E-06,   4.2262513E-06
     +,   4.6284968E-06,   5.0584740E-06,   5.5169003E-06
     +,   6.0044431E-06,   6.5215950E-06,   7.0687843E-06
     +,   7.6462320E-06,   8.2540764E-06,   8.8922261E-06
     +,   9.5604655E-06,   1.0258418E-05,   1.0985469E-05
     +,   1.1740816E-05,   1.2523511E-05,   1.3332415E-05
     +,   1.4166114E-05,   1.5023114E-05,   1.5901622E-05
     +,   1.6799779E-05,   1.7715436E-05,   1.8646399E-05
     +,   1.9590207E-05,   2.0544372E-05,   2.1506181E-05
     +,   2.2472885E-05,   2.3441657E-05,   2.4409532E-05
     +,   2.5373485E-05,   2.6330532E-05,   2.7277658E-05
     +,   2.8211760E-05,   2.9129886E-05,   3.0028988E-05
     +,   3.0906202E-05,   3.1758602E-05,   3.2583477E-05
     +,   3.3378088E-05,   3.4139928E-05,   3.4866491E-05
     +,   3.5555491E-05,   3.6204758E-05,   3.6812231E-05
     +,   3.7376001E-05,   3.7894344E-05,   3.8365702E-05
     +,   3.8788607E-05,   3.9161816E-05,   3.9484199E-05
     +,   3.9754814E-05,   3.9972871E-05,   4.0137722E-05
     +,   4.0248906E-05,   4.0306109E-05,   4.0309173E-05
     +,   4.0258124E-05,   4.0153136E-05,   3.9994546E-05
     +,   3.9782910E-05,   3.9518920E-05,   3.9203478E-05
     +,   3.8837694E-05,   3.8422881E-05,   3.7960581E-05
     +,   3.7452559E-05,   3.6900892E-05,   3.6307880E-05
     +,   3.5676137E-05,   3.5008637E-05,   3.4308716E-05
     +,   3.3580051E-05,   3.2826734E-05,   3.2053365E-05
     +,   3.1265019E-05,   3.0467234E-05,   2.9666075E-05
     +,   2.8868239E-05,   2.8080956E-05,   2.7312000E-05
     +,   2.6569694E-05,   2.5862948E-05,   2.5201065E-05
     +,   2.4593744E-05,   2.4051009E-05,   2.3583008E-05
     +,   2.3199842E-05,   2.2911390E-05,   2.2727103E-05
     +,   2.2655699E-05,   2.2704897E-05,   2.2881131E-05
     +,   2.3189226E-05,   2.3632105E-05,   2.4210538E-05
     +,   2.4922898E-05,   2.5764881E-05,   2.6729584E-05
     +,   2.7807429E-05,   2.8986284E-05,   3.0251838E-05
     +,   3.1588315E-05,   3.2979195E-05,   3.4408284E-05
     +,   3.5861256E-05,   3.7327482E-05,   3.8801954E-05
     +,   4.0287297E-05,   4.1795975E-05,   4.3352116E-05
     +,   4.4992645E-05,   4.6767374E-05,   4.8738395E-05
     +,   5.0977887E-05,   5.3564709E-05,   5.6580855E-05
     +,   6.0108363E-05,   6.4227614E-05,   6.9018344E-05
     +,   7.4565149E-05,   8.0967511E-05,   8.8352317E-05
     +,   9.6887125E-05,   1.0679158E-04,   1.1834285E-04
     +,   1.3187091E-04,   1.4774373E-04,   1.6635176E-04
     +,   1.8809231E-04,   2.1336639E-04,   2.4259950E-04
     +,   2.7628575E-04,   3.1503971E-04,   3.5963469E-04
     +,   4.1100333E-04,   4.7017093E-04,   5.3810579E-04
     +,   6.1550527E-04,   7.0257677E-04,   7.9886516E-04
     +,   9.0316468E-04,   1.0135249E-03,   1.1273579E-03
     +,   1.2415121E-03,   1.3522811E-03,   1.4553425E-03
     +,   1.5456758E-03,   1.6175692E-03,   1.6648901E-03
     +,   1.6817128E-03,   1.6632403E-03,   1.6068474E-03
     +,   1.5129759E-03,   1.3855754E-03,   1.2318954E-03
     +,   1.0616403E-03,   8.8566635E-04,   7.1445329E-04
     +,   5.5679376E-04,   4.1890537E-04,   3.0407775E-04
     +,   2.1285599E-04,   1.4362874E-04,   9.3392984E-05
     +,   5.8505189E-05,   3.5300342E-05,   2.0510670E-05
     +,   1.1474626E-05,   6.1803526E-06,   3.2045070E-06
     +,   1.5994046E-06,   7.6849744E-07,   3.5552810E-07
     +,   1.5841836E-07,   6.8043789E-08,   2.8217425E-08
     +,   1.1332694E-08,   4.4350372E-09,   1.7117067E-09
     +,   6.6615891E-10,   2.7109442E-10,   1.2081484E-10
     +,   6.1035017E-11,   3.4901176E-11,   2.1863501E-11
     +,   1.4456489E-11,   9.8340763E-12,   6.7890667E-12
     +,   4.7274949E-12,   3.3126002E-12,   2.3339340E-12
     +,   1.6530730E-12,   1.1768809E-12,   8.4206654E-13
     +,   6.0536911E-13,   4.3709871E-13,   3.1681702E-13
     +,   2.3039697E-13,   1.6800451E-13,   1.2277000E-13
     +,   8.9853092E-14,   6.5829117E-14,   4.8252726E-14
     +,   3.5372137E-14,   2.5921387E-14,   1.8983421E-14
     +,   1.3889141E-14,   1.0149970E-14,   7.4071608E-15
     +,   5.3970466E-15,   3.9258008E-15,   2.8504338E-15
     +,   2.0657260E-15,   1.4940849E-15,   1.0784525E-15
     +,   7.7682106E-16,   5.5837831E-16,   4.0050047E-16
     +,   2.8664474E-16,   2.0470757E-16,   1.4587346E-16
     +,   1.0371881E-16,   7.3584115E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt1168 = Yx/0.00821739130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7359950E-09,   3.2889684E-09
     +,   3.9464036E-09,   4.7265050E-09,   5.6503748E-09
     +,   6.7423622E-09,   8.0305522E-09,   9.5472457E-09
     +,   1.1329456E-08,   1.3419654E-08,   1.5866238E-08
     +,   1.8724389E-08,   2.2056806E-08,   2.5934613E-08
     +,   3.0438230E-08,   3.5658445E-08,   4.1697422E-08
     +,   4.8669857E-08,   5.6704362E-08,   6.5944441E-08
     +,   7.6550251E-08,   8.8699643E-08,   1.0258976E-07
     +,   1.1843954E-07,   1.3648877E-07,   1.5700313E-07
     +,   1.8027292E-07,   2.0661642E-07,   2.3638046E-07
     +,   2.6994292E-07,   3.0771389E-07,   3.5013684E-07
     +,   3.9769023E-07,   4.5088916E-07,   5.1028547E-07
     +,   5.7646929E-07,   6.5007021E-07,   7.3175454E-07
     +,   8.2223380E-07,   9.2224860E-07,   1.0325887E-06
     +,   1.1540733E-06,   1.2875614E-06,   1.4339431E-06
     +,   1.5941423E-06,   1.7691088E-06,   1.9598194E-06
     +,   2.1672699E-06,   2.3924715E-06,   2.6364489E-06
     +,   2.9002263E-06,   3.1848306E-06,   3.4912709E-06
     +,   3.8205631E-06,   4.1736571E-06,   4.5515112E-06
     +,   4.9550158E-06,   5.3850149E-06,   5.8422911E-06
     +,   6.3275525E-06,   6.8414238E-06,   7.3844476E-06
     +,   7.9570273E-06,   8.5594893E-06,   9.1920510E-06
     +,   9.8547207E-06,   1.0547462E-05,   1.1269984E-05
     +,   1.2021940E-05,   1.2802713E-05,   1.3611617E-05
     +,   1.4447680E-05,   1.5309854E-05,   1.6196800E-05
     +,   1.7107070E-05,   1.8039034E-05,   1.8990819E-05
     +,   1.9960356E-05,   2.0945468E-05,   2.1943808E-05
     +,   2.2952754E-05,   2.3969669E-05,   2.4991632E-05
     +,   2.6015719E-05,   2.7038752E-05,   2.8057580E-05
     +,   2.9068833E-05,   3.0069188E-05,   3.1055137E-05
     +,   3.2023239E-05,   3.2970034E-05,   3.3892000E-05
     +,   3.4785633E-05,   3.5647550E-05,   3.6474412E-05
     +,   3.7262900E-05,   3.8009894E-05,   3.8712322E-05
     +,   3.9367325E-05,   3.9972161E-05,   4.0524308E-05
     +,   4.1021409E-05,   4.1461371E-05,   4.1842279E-05
     +,   4.2162508E-05,   4.2420674E-05,   4.2615644E-05
     +,   4.2746553E-05,   4.2812844E-05,   4.2814238E-05
     +,   4.2750704E-05,   4.2622534E-05,   4.2430289E-05
     +,   4.2174801E-05,   4.1857198E-05,   4.1478830E-05
     +,   4.1041367E-05,   4.0546642E-05,   3.9996808E-05
     +,   3.9394181E-05,   3.8741255E-05,   3.8040769E-05
     +,   3.7295638E-05,   3.6508856E-05,   3.5683563E-05
     +,   3.4823075E-05,   3.3930693E-05,   3.3009892E-05
     +,   3.2064083E-05,   3.1096817E-05,   3.0111523E-05
     +,   2.9111741E-05,   2.8100854E-05,   2.7082309E-05
     +,   2.6059388E-05,   2.5035277E-05,   2.4013128E-05
     +,   2.2995970E-05,   2.1986623E-05,   2.0987776E-05
     +,   2.0002019E-05,   1.9031768E-05,   1.8079212E-05
     +,   1.7146363E-05,   1.6235132E-05,   1.5347159E-05
     +,   1.4483895E-05,   1.3646669E-05,   1.2836613E-05
     +,   1.2054623E-05,   1.1301424E-05,   1.0577613E-05
     +,   9.8836199E-06,   9.2196624E-06,   8.5858192E-06
     +,   7.9820575E-06,   7.4082109E-06,   6.8639515E-06
     +,   6.3488392E-06,   5.8623787E-06,   5.4039315E-06
     +,   4.9727782E-06,   4.5681550E-06,   4.1892340E-06
     +,   3.8351072E-06,   3.5048279E-06,   3.1974391E-06
     +,   2.9119569E-06,   2.6473697E-06,   2.4026665E-06
     +,   2.1768678E-06,   1.9690272E-06,   1.7782436E-06
     +,   1.6037181E-06,   1.4448253E-06,   1.3011637E-06
     +,   1.1727002E-06,   1.0599601E-06,   9.6427743E-07
     +,   8.8815756E-07,   8.3579101E-07,   8.1373122E-07
     +,   8.3177304E-07,   9.0408582E-07,   1.0506240E-06
     +,   1.2988066E-06,   1.6854855E-06,   2.2591869E-06
     +,   3.0825106E-06,   4.2344359E-06,   5.8127494E-06
     +,   7.9358733E-06,   1.0743829E-05,   1.4398238E-05
     +,   1.9081073E-05,   2.4991074E-05,   3.2337419E-05
     +,   4.1331521E-05,   5.2176892E-05,   6.5055909E-05
     +,   8.0115024E-05,   9.7451593E-05,   1.1710459E-04
     +,   1.3904806E-04,   1.6319154E-04,   1.8939743E-04
     +,   2.1750476E-04,   2.4736577E-04,   2.7889531E-04
     +,   3.1212679E-04,   3.4725995E-04,   3.8469446E-04
     +,   4.2504093E-04,   4.6909577E-04,   5.1776477E-04
     +,   5.7193742E-04,   6.3232414E-04,   6.9927005E-04
     +,   7.7255780E-04,   8.5123378E-04,   9.3351648E-04
     +,   1.0167731E-03,   1.0976050E-03,   1.1720565E-03
     +,   1.2359215E-03,   1.2851073E-03,   1.3160268E-03
     +,   1.3259738E-03,   1.3134151E-03,   1.2781653E-03
     +,   1.2214279E-03,   1.1456929E-03,   1.0544973E-03
     +,   9.5209869E-04,   8.4311049E-04,   7.3209987E-04
     +,   6.2325498E-04,   5.2012672E-04,   4.2544623E-04
     +,   3.4104774E-04,   2.6789468E-04,   2.0617856E-04
     +,   1.5545607E-04,   1.1481649E-04,   8.3057821E-05
     +,   5.8842856E-05,   4.0822863E-05,   2.7730659E-05
     +,   1.8442288E-05,   1.2007074E-05,   7.6521119E-06
     +,   4.7731191E-06,   2.9138657E-06,   1.7408278E-06
     +,   1.0177038E-06,   5.8213976E-07,   3.2580050E-07
     +,   1.7839240E-07,   9.5558043E-08,   5.0071606E-08
     +,   2.5664665E-08,   1.2867353E-08,   6.3099166E-09
     +,   3.0262957E-09,   1.4195723E-09,   6.5123640E-10
     +,   2.9216793E-10,   1.2818721E-10,   5.5003165E-11
     +,   2.3081616E-11,   9.4734750E-12,   3.8038604E-12
     +,   1.4949615E-12,   5.7563654E-13,   2.1761096E-13
     +,   8.1131032E-14,   3.0106932E-14,   1.1329190E-14
     +,   4.4698450E-15,   1.9408871E-15,   9.6928479E-16
     +,   5.6072618E-16,   3.6294388E-16,   2.5103531E-16
     +,   1.7937679E-16,   1.2996499E-16,   9.4628066E-17
     +,   6.8963609E-17,   5.0223359E-17,   3.6523200E-17
     +,   2.6515385E-17,   1.9214871E-17,   1.3898894E-17
     +,   1.0034789E-17,   7.2315206E-18,   5.2015694E-18
     +,   3.7344909E-18,   2.6761512E-18,   1.9141762E-18
     +,   1.3665805E-18,   9.7382423E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt118 = Yx/0.00731818181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5323391E-06,   4.7540457E-06
     +,   4.9828050E-06,   5.2186278E-06,   5.4615148E-06
     +,   5.7114521E-06,   5.9684194E-06,   6.2323843E-06
     +,   6.5033005E-06,   6.7811238E-06,   7.0657879E-06
     +,   7.3572228E-06,   7.6553524E-06,   7.9600841E-06
     +,   8.2713304E-06,   8.5889860E-06,   8.9129517E-06
     +,   9.2431146E-06,   9.5793621E-06,   9.9215758E-06
     +,   1.0269643E-05,   1.0623443E-05,   1.0982853E-05
     +,   1.1347776E-05,   1.1718074E-05,   1.2093656E-05
     +,   1.2474412E-05,   1.2860239E-05,   1.3251050E-05
     +,   1.3646756E-05,   1.4047281E-05,   1.4452556E-05
     +,   1.4862524E-05,   1.5277132E-05,   1.5696345E-05
     +,   1.6120130E-05,   1.6548473E-05,   1.6981354E-05
     +,   1.7418795E-05,   1.7860781E-05,   1.8307348E-05
     +,   1.8758523E-05,   1.9214336E-05,   1.9674822E-05
     +,   2.0140031E-05,   2.0609999E-05,   2.1084785E-05
     +,   2.1564430E-05,   2.2048973E-05,   2.2538456E-05
     +,   2.3032908E-05,   2.3532350E-05,   2.4036777E-05
     +,   2.4546214E-05,   2.5060595E-05,   2.5579906E-05
     +,   2.6104070E-05,   2.6632995E-05,   2.7166558E-05
     +,   2.7704611E-05,   2.8246966E-05,   2.8793422E-05
     +,   2.9343695E-05,   2.9897508E-05,   3.0454552E-05
     +,   3.1014413E-05,   3.1576717E-05,   3.2140975E-05
     +,   3.2706717E-05,   3.3273373E-05,   3.3840395E-05
     +,   3.4407123E-05,   3.4972934E-05,   3.5537087E-05
     +,   3.6098871E-05,   3.6657544E-05,   3.7212281E-05
     +,   3.7762253E-05,   3.8306629E-05,   3.8844573E-05
     +,   3.9375172E-05,   3.9897590E-05,   4.0410909E-05
     +,   4.0914285E-05,   4.1406809E-05,   4.1887666E-05
     +,   4.2355998E-05,   4.2811022E-05,   4.3251934E-05
     +,   4.3678032E-05,   4.4088607E-05,   4.4483037E-05
     +,   4.4860710E-05,   4.5221102E-05,   4.5563775E-05
     +,   4.5888301E-05,   4.6194371E-05,   4.6481702E-05
     +,   4.6750145E-05,   4.6999554E-05,   4.7229922E-05
     +,   4.7441255E-05,   4.7633686E-05,   4.7807371E-05
     +,   4.7962556E-05,   4.8099555E-05,   4.8218728E-05
     +,   4.8320475E-05,   4.8405269E-05,   4.8473608E-05
     +,   4.8526050E-05,   4.8563157E-05,   4.8585531E-05
     +,   4.8593778E-05,   4.8588547E-05,   4.8570477E-05
     +,   4.8540231E-05,   4.8498467E-05,   4.8445865E-05
     +,   4.8383092E-05,   4.8310849E-05,   4.8229842E-05
     +,   4.8140810E-05,   4.8044491E-05,   4.7941703E-05
     +,   4.7833280E-05,   4.7720150E-05,   4.7603291E-05
     +,   4.7483769E-05,   4.7362781E-05,   4.7241614E-05
     +,   4.7121692E-05,   4.7004582E-05,   4.6892001E-05
     +,   4.6785819E-05,   4.6688048E-05,   4.6600893E-05
     +,   4.6526660E-05,   4.6467827E-05,   4.6426965E-05
     +,   4.6406771E-05,   4.6409983E-05,   4.6439392E-05
     +,   4.6497807E-05,   4.6587989E-05,   4.6712652E-05
     +,   4.6874422E-05,   4.7075788E-05,   4.7319110E-05
     +,   4.7606609E-05,   4.7940401E-05,   4.8322447E-05
     +,   4.8754671E-05,   4.9239021E-05,   4.9777555E-05
     +,   5.0372553E-05,   5.1026625E-05,   5.1742969E-05
     +,   5.2525531E-05,   5.3379074E-05,   5.4309559E-05
     +,   5.5324275E-05,   5.6431934E-05,   5.7642897E-05
     +,   5.8969326E-05,   6.0425227E-05,   6.2026316E-05
     +,   6.3789987E-05,   6.5735236E-05,   6.7882356E-05
     +,   7.0252332E-05,   7.2866453E-05,   7.5746015E-05
     +,   7.8911413E-05,   8.2381128E-05,   8.6171545E-05
     +,   9.0295980E-05,   9.4763505E-05,   9.9578501E-05
     +,   1.0474049E-04,   1.1024334E-04,   1.1607458E-04
     +,   1.2221577E-04,   1.2864315E-04,   1.3532773E-04
     +,   1.4223580E-04,   1.4933042E-04,   1.5657349E-04
     +,   1.6392705E-04,   1.7135471E-04,   1.7882526E-04
     +,   1.8631452E-04,   1.9380733E-04,   2.0130025E-04
     +,   2.0880441E-04,   2.1634702E-04,   2.2397190E-04
     +,   2.3174119E-04,   2.3973543E-04,   2.4805262E-04
     +,   2.5680539E-04,   2.6611899E-04,   2.7612754E-04
     +,   2.8696877E-04,   2.9877643E-04,   3.1167592E-04
     +,   3.2577550E-04,   3.4115737E-04,   3.5787042E-04
     +,   3.7592341E-04,   3.9527711E-04,   4.1583693E-04
     +,   4.3744943E-04,   4.5990176E-04,   4.8291948E-04
     +,   5.0616823E-04,   5.2926014E-04,   5.5176317E-04
     +,   5.7321088E-04,   5.9311336E-04,   6.1097724E-04
     +,   6.2631944E-04,   6.3868455E-04,   6.4766337E-04
     +,   6.5290992E-04,   6.5415521E-04,   6.5121893E-04
     +,   6.4401980E-04,   6.3257926E-04,   6.1702164E-04
     +,   5.9757312E-04,   5.7455245E-04,   5.4835883E-04
     +,   5.1945762E-04,   4.8836775E-04,   4.5563679E-04
     +,   4.2182510E-04,   3.8749006E-04,   3.5316619E-04
     +,   3.1934836E-04,   2.8648079E-04,   2.5495005E-04
     +,   2.2507610E-04,   1.9710723E-04,   1.7122213E-04
     +,   1.4753400E-04,   1.2609304E-04,   1.0689221E-04
     +,   8.9876550E-05,   7.4953146E-05,   6.1996572E-05
     +,   5.0859395E-05,   4.1380725E-05,   3.3392331E-05
     +,   2.6724532E-05,   2.1211992E-05,   1.6697841E-05
     +,   1.3036087E-05,   1.0093377E-05,   7.7503537E-06
     +,   5.9020595E-06,   4.4574340E-06,   3.3385643E-06
     +,   2.4798308E-06,   1.8267476E-06,   1.3345154E-06
     +,   9.6683232E-07,   6.9464733E-07,   4.9495645E-07
     +,   3.4974613E-07,   2.4508464E-07,   1.7031790E-07
     +,   1.1737892E-07,   8.0223131E-08,   5.4372880E-08
     +,   3.6546769E-08,   2.4360583E-08,   1.6103133E-08
     +,   1.0556141E-08,   6.8625399E-09,   4.4242401E-09
     +,   2.8286633E-09,   1.7935065E-09,   1.1277732E-09
     +,   7.0328388E-10,   4.3496370E-10,   2.6680588E-10
     +,   1.6231867E-10,   9.7951723E-11,   5.8633633E-11
     +,   3.4820587E-11,   2.0517846E-11,   1.1998944E-11
     +,   6.9660115E-12,   4.0165501E-12,   2.3013609E-12
     +,   1.3114325E-12,   7.4405483E-13,   4.2095982E-13
     +,   2.3797706E-13,   1.3480121E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt119 = Yx/0.00733333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.6317056E-06,   7.9012370E-06
     +,   8.1741309E-06,   8.4500853E-06,   8.7287835E-06
     +,   9.0098856E-06,   9.2930422E-06,   9.5778832E-06
     +,   9.8640230E-06,   1.0151070E-05,   1.0438609E-05
     +,   1.0726214E-05,   1.1013450E-05,   1.1299866E-05
     +,   1.1585006E-05,   1.1868404E-05,   1.2149585E-05
     +,   1.2428070E-05,   1.2703372E-05,   1.2975000E-05
     +,   1.3242465E-05,   1.3505278E-05,   1.3762937E-05
     +,   1.4014971E-05,   1.4260877E-05,   1.4500188E-05
     +,   1.4732427E-05,   1.4957127E-05,   1.5173840E-05
     +,   1.5382120E-05,   1.5581540E-05,   1.5771684E-05
     +,   1.5952159E-05,   1.6122580E-05,   1.6282591E-05
     +,   1.6431852E-05,   1.6570042E-05,   1.6696869E-05
     +,   1.6812071E-05,   1.6915395E-05,   1.7006629E-05
     +,   1.7085578E-05,   1.7152097E-05,   1.7206041E-05
     +,   1.7247317E-05,   1.7275859E-05,   1.7291630E-05
     +,   1.7294626E-05,   1.7284876E-05,   1.7262450E-05
     +,   1.7227434E-05,   1.7179971E-05,   1.7120225E-05
     +,   1.7048393E-05,   1.6964712E-05,   1.6869450E-05
     +,   1.6762911E-05,   1.6645437E-05,   1.6517401E-05
     +,   1.6379205E-05,   1.6231294E-05,   1.6074135E-05
     +,   1.5908245E-05,   1.5734156E-05,   1.5552432E-05
     +,   1.5363690E-05,   1.5168551E-05,   1.4967684E-05
     +,   1.4761773E-05,   1.4551551E-05,   1.4337756E-05
     +,   1.4121171E-05,   1.3902587E-05,   1.3682843E-05
     +,   1.3462782E-05,   1.3243264E-05,   1.3025192E-05
     +,   1.2809484E-05,   1.2597059E-05,   1.2388854E-05
     +,   1.2185840E-05,   1.1988972E-05,   1.1799239E-05
     +,   1.1617612E-05,   1.1445088E-05,   1.1282639E-05
     +,   1.1131259E-05,   1.0991913E-05,   1.0865572E-05
     +,   1.0753181E-05,   1.0655664E-05,   1.0573929E-05
     +,   1.0508854E-05,   1.0461277E-05,   1.0432001E-05
     +,   1.0421782E-05,   1.0431330E-05,   1.0461297E-05
     +,   1.0512275E-05,   1.0584788E-05,   1.0679291E-05
     +,   1.0796159E-05,   1.0935696E-05,   1.1098103E-05
     +,   1.1283505E-05,   1.1491939E-05,   1.1723331E-05
     +,   1.1977511E-05,   1.2254223E-05,   1.2553115E-05
     +,   1.2873718E-05,   1.3215502E-05,   1.3577804E-05
     +,   1.3959925E-05,   1.4361046E-05,   1.4780325E-05
     +,   1.5216813E-05,   1.5669573E-05,   1.6137577E-05
     +,   1.6619837E-05,   1.7115357E-05,   1.7623144E-05
     +,   1.8142235E-05,   1.8671775E-05,   1.9210991E-05
     +,   1.9759171E-05,   2.0315794E-05,   2.0880429E-05
     +,   2.1452879E-05,   2.2033062E-05,   2.2621183E-05
     +,   2.3217577E-05,   2.3822869E-05,   2.4437846E-05
     +,   2.5063551E-05,   2.5701245E-05,   2.6352342E-05
     +,   2.7018406E-05,   2.7701179E-05,   2.8402499E-05
     +,   2.9124190E-05,   2.9868062E-05,   3.0635889E-05
     +,   3.1429310E-05,   3.2249660E-05,   3.3098040E-05
     +,   3.3975208E-05,   3.4881392E-05,   3.5816316E-05
     +,   3.6779176E-05,   3.7768532E-05,   3.8782218E-05
     +,   3.9817380E-05,   4.0870520E-05,   4.1937488E-05
     +,   4.3013442E-05,   4.4093038E-05,   4.5170567E-05
     +,   4.6240064E-05,   4.7295413E-05,   4.8330734E-05
     +,   4.9340590E-05,   5.0320199E-05,   5.1265823E-05
     +,   5.2175208E-05,   5.3047879E-05,   5.3885437E-05
     +,   5.4692122E-05,   5.5475099E-05,   5.6244884E-05
     +,   5.7015546E-05,   5.7805060E-05,   5.8635560E-05
     +,   5.9533402E-05,   6.0529121E-05,   6.1657454E-05
     +,   6.2957122E-05,   6.4470318E-05,   6.6242217E-05
     +,   6.8320514E-05,   7.0754482E-05,   7.3593859E-05
     +,   7.6887809E-05,   8.0684062E-05,   8.5027503E-05
     +,   8.9958579E-05,   9.5512252E-05,   1.0171735E-04
     +,   1.0859521E-04,   1.1615828E-04,   1.2441083E-04
     +,   1.3334844E-04,   1.4295726E-04,   1.5321531E-04
     +,   1.6409412E-04,   1.7555930E-04,   1.8757142E-04
     +,   2.0008838E-04,   2.1306791E-04,   2.2646853E-04
     +,   2.4024992E-04,   2.5437452E-04,   2.6880903E-04
     +,   2.8352268E-04,   2.9848478E-04,   3.1366540E-04
     +,   3.2903111E-04,   3.4454043E-04,   3.6014113E-04
     +,   3.7576686E-04,   3.9133226E-04,   4.0672903E-04
     +,   4.2182396E-04,   4.3645888E-04,   4.5045017E-04
     +,   4.6358959E-04,   4.7564920E-04,   4.8638790E-04
     +,   4.9555767E-04,   5.0291151E-04,   5.0821458E-04
     +,   5.1125331E-04,   5.1184476E-04,   5.0984678E-04
     +,   5.0516537E-04,   4.9776048E-04,   4.8765063E-04
     +,   4.7491514E-04,   4.5969099E-04,   4.4217109E-04
     +,   4.2259888E-04,   4.0126077E-04,   3.7847451E-04
     +,   3.5458038E-04,   3.2993258E-04,   3.0488384E-04
     +,   2.7977719E-04,   2.5493803E-04,   2.3066452E-04
     +,   2.0721926E-04,   1.8482641E-04,   1.6366993E-04
     +,   1.4389104E-04,   1.2558709E-04,   1.0881538E-04
     +,   9.3597024E-05,   7.9919773E-05,   6.7741828E-05
     +,   5.6998098E-05,   4.7606140E-05,   3.9468970E-05
     +,   3.2481061E-05,   2.6532793E-05,   2.1513513E-05
     +,   1.7314389E-05,   1.3831263E-05,   1.0966625E-05
     +,   8.6305599E-06,   6.7414167E-06,   5.2263786E-06
     +,   4.0214859E-06,   3.0711915E-06,   2.3278410E-06
     +,   1.7511237E-06,   1.3073767E-06,   9.6871622E-07
     +,   7.1235303E-07,   5.1987257E-07,   3.7653211E-07
     +,   2.7064650E-07,   1.9305899E-07,   1.3666796E-07
     +,   9.6014148E-08,   6.6940494E-08,   4.6315055E-08
     +,   3.1801374E-08,   2.1669614E-08,   1.4653897E-08
     +,   9.8343778E-09,   6.5501831E-09,   4.3298716E-09
     +,   2.8408151E-09,   1.8499992E-09,   1.1959425E-09
     +,   7.6753265E-10,   4.8911580E-10,   3.0955666E-10
     +,   1.9462572E-10,   1.2161110E-10,   7.5556478E-11
     +,   4.6710327E-11,   2.8760104E-11,   1.7658611E-11
     +,   1.0829366E-11,   6.6474092E-12,   4.0947736E-12
     +,   2.5393572E-12,   1.5911150E-12,   1.0112671E-12
     +,   6.5439668E-13,   4.3251676E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt120 = Yx/0.00552631578947368
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0286147E-06,   1.1975349E-06
     +,   1.3908626E-06,   1.6116433E-06,   1.8632526E-06
     +,   2.1494247E-06,   2.4742899E-06,   2.8424115E-06
     +,   3.2588218E-06,   3.7290949E-06,   4.2593488E-06
     +,   4.8563224E-06,   5.5274240E-06,   6.2807721E-06
     +,   7.1252480E-06,   8.0705404E-06,   9.1271813E-06
     +,   1.0306572E-05,   1.1621005E-05,   1.3083661E-05
     +,   1.4708577E-05,   1.6510627E-05,   1.8505378E-05
     +,   2.0709183E-05,   2.3138633E-05,   2.5810883E-05
     +,   2.8743003E-05,   3.1951895E-05,   3.5453937E-05
     +,   3.9264614E-05,   4.3398129E-05,   4.7866954E-05
     +,   5.2681371E-05,   5.7849051E-05,   6.3374537E-05
     +,   6.9258829E-05,   7.5499054E-05,   8.2087892E-05
     +,   8.9013956E-05,   9.6260432E-05,   1.0380661E-04
     +,   1.1162667E-04,   1.1969056E-04,   1.2796427E-04
     +,   1.3641037E-04,   1.4498859E-04,   1.5365683E-04
     +,   1.6237187E-04,   1.7109043E-04,   1.7977020E-04
     +,   1.8837077E-04,   1.9685471E-04,   2.0518815E-04
     +,   2.1334233E-04,   2.2129265E-04,   2.2902094E-04
     +,   2.3651408E-04,   2.4376495E-04,   2.5077138E-04
     +,   2.5753654E-04,   2.6406755E-04,   2.7037549E-04
     +,   2.7647344E-04,   2.8237715E-04,   2.8810330E-04
     +,   2.9366839E-04,   2.9908947E-04,   3.0438279E-04
     +,   3.0956432E-04,   3.1464928E-04,   3.1965380E-04
     +,   3.2459415E-04,   3.2948941E-04,   3.3436104E-04
     +,   3.3923541E-04,   3.4414433E-04,   3.4912606E-04
     +,   3.5422601E-04,   3.5949785E-04,   3.6500240E-04
     +,   3.7080602E-04,   3.7698075E-04,   3.8359934E-04
     +,   3.9073374E-04,   3.9844922E-04,   4.0680135E-04
     +,   4.1582927E-04,   4.2555309E-04,   4.3596674E-04
     +,   4.4703693E-04,   4.5869983E-04,   4.7085938E-04
     +,   4.8338948E-04,   4.9613690E-04,   5.0892605E-04
     +,   5.2156427E-04,   5.3385133E-04,   5.4558739E-04
     +,   5.5658311E-04,   5.6666724E-04,   5.7569775E-04
     +,   5.8356673E-04,   5.9020834E-04,   5.9560128E-04
     +,   5.9977209E-04,   6.0279499E-04,   6.0478813E-04
     +,   6.0591148E-04,   6.0635962E-04,   6.0635444E-04
     +,   6.0613488E-04,   6.0594879E-04,   6.0603977E-04
     +,   6.0663716E-04,   6.0794619E-04,   6.1013707E-04
     +,   6.1333994E-04,   6.1763969E-04,   6.2307552E-04
     +,   6.2964548E-04,   6.3731434E-04,   6.4602518E-04
     +,   6.5571314E-04,   6.6632248E-04,   6.7782018E-04
     +,   6.9020683E-04,   7.0352561E-04,   7.1785803E-04
     +,   7.3331955E-04,   7.5004034E-04,   7.6814619E-04
     +,   7.8772579E-04,   8.0880639E-04,   8.3132344E-04
     +,   8.5510011E-04,   8.7983347E-04,   9.0508885E-04
     +,   9.3031127E-04,   9.5484656E-04,   9.7797008E-04
     +,   9.9892309E-04,   1.0169555E-03,   1.0313672E-03
     +,   1.0415450E-03,   1.0469905E-03,   1.0473470E-03
     +,   1.0424068E-03,   1.0321167E-03,   1.0165715E-03
     +,   9.9600025E-04,   9.7074872E-04,   9.4126177E-04
     +,   9.0806099E-04,   8.7172299E-04,   8.3286158E-04
     +,   7.9211371E-04,   7.5012317E-04,   7.0752227E-04
     +,   6.6492351E-04,   6.2291179E-04,   5.8202399E-04
     +,   5.4274267E-04,   5.0548982E-04,   4.7061426E-04
     +,   4.3838430E-04,   4.0898641E-04,   3.8252599E-04
     +,   3.5902834E-04,   3.3844309E-04,   3.2065474E-04
     +,   3.0549488E-04,   2.9275299E-04,   2.8219027E-04
     +,   2.7355296E-04,   2.6658547E-04,   2.6103941E-04
     +,   2.5668289E-04,   2.5330673E-04,   2.5072737E-04
     +,   2.4878859E-04,   2.4736056E-04,   2.4633782E-04
     +,   2.4563583E-04,   2.4518670E-04,   2.4493472E-04
     +,   2.4483292E-04,   2.4483845E-04,   2.4491045E-04
     +,   2.4500705E-04,   2.4508458E-04,   2.4509657E-04
     +,   2.4499409E-04,   2.4472628E-04,   2.4424162E-04
     +,   2.4348932E-04,   2.4242073E-04,   2.4099121E-04
     +,   2.3916134E-04,   2.3689814E-04,   2.3417620E-04
     +,   2.3097842E-04,   2.2729627E-04,   2.2312990E-04
     +,   2.1848762E-04,   2.1338642E-04,   2.0785007E-04
     +,   2.0190880E-04,   1.9559883E-04,   1.8896093E-04
     +,   1.8203899E-04,   1.7487933E-04,   1.6753018E-04
     +,   1.6004032E-04,   1.5245769E-04,   1.4482909E-04
     +,   1.3720007E-04,   1.2961387E-04,   1.2211030E-04
     +,   1.1472612E-04,   1.0749534E-04,   1.0044761E-04
     +,   9.3608964E-05,   8.7002103E-05,   8.0646045E-05
     +,   7.4555785E-05,   6.8742884E-05,   6.3216066E-05
     +,   5.7980920E-05,   5.3039850E-05,   4.8392707E-05
     +,   4.4037326E-05,   3.9969418E-05,   3.6182591E-05
     +,   3.2668948E-05,   2.9419571E-05,   2.6424130E-05
     +,   2.3671459E-05,   2.1149908E-05,   1.8847342E-05
     +,   1.6751172E-05,   1.4848699E-05,   1.3127356E-05
     +,   1.1574688E-05,   1.0178369E-05,   8.9264086E-06
     +,   7.8073126E-06,   6.8100303E-06,   5.9239505E-06
     +,   5.1390261E-06,   4.4458534E-06,   3.8355352E-06
     +,   3.2997807E-06,   2.8309225E-06,   2.4218689E-06
     +,   2.0660675E-06,   1.7575219E-06,   1.4907863E-06
     +,   1.2609119E-06,   1.0634083E-06,   8.9423736E-07
     +,   7.4978976E-07,   6.2684018E-07,   5.2251227E-07
     +,   4.3426058E-07,   3.5984743E-07,   2.9729819E-07
     +,   2.4488619E-07,   2.0110929E-07,   1.6466203E-07
     +,   1.3441301E-07,   1.0938744E-07,   8.8750468E-08
     +,   7.1787596E-08,   5.7889025E-08,   4.6537661E-08
     +,   3.7297170E-08,   2.9798896E-08,   2.3734502E-08
     +,   1.8845391E-08,   1.4916898E-08,   1.1770362E-08
     +,   9.2585370E-09,   7.2598216E-09,   5.6747069E-09
     +,   4.4216639E-09,   3.4344412E-09,   2.6591764E-09
     +,   2.0523601E-09,   1.5789877E-09,   1.2109097E-09
     +,   9.2567537E-10,   7.0535500E-10,   5.3575216E-10
     +,   4.0561834E-10,   3.0610683E-10,   2.3026096E-10
     +,   1.7264896E-10,   1.2903108E-10,   9.6120563E-11
     +,   7.1370590E-11,   5.2821358E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt75 = Yx/0.0193103448275862
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.6877310E-05,   7.9194659E-05
     +,   8.1494160E-05,   8.3771294E-05,   8.6021733E-05
     +,   8.8241315E-05,   9.0426176E-05,   9.2572685E-05
     +,   9.4677504E-05,   9.6737771E-05,   9.8750897E-05
     +,   1.0071473E-04,   1.0262753E-04,   1.0448803E-04
     +,   1.0629542E-04,   1.0804929E-04,   1.0974971E-04
     +,   1.1139719E-04,   1.1299267E-04,   1.1453740E-04
     +,   1.1603306E-04,   1.1748164E-04,   1.1888528E-04
     +,   1.2024651E-04,   1.2156781E-04,   1.2285190E-04
     +,   1.2410141E-04,   1.2531897E-04,   1.2650709E-04
     +,   1.2766806E-04,   1.2880396E-04,   1.2991653E-04
     +,   1.3100712E-04,   1.3207670E-04,   1.3312575E-04
     +,   1.3415425E-04,   1.3516170E-04,   1.3614698E-04
     +,   1.3710863E-04,   1.3804447E-04,   1.3895205E-04
     +,   1.3982831E-04,   1.4066996E-04,   1.4147333E-04
     +,   1.4223449E-04,   1.4294956E-04,   1.4361442E-04
     +,   1.4422521E-04,   1.4477820E-04,   1.4526999E-04
     +,   1.4569769E-04,   1.4605900E-04,   1.4635225E-04
     +,   1.4657668E-04,   1.4673235E-04,   1.4682050E-04
     +,   1.4684329E-04,   1.4680426E-04,   1.4670812E-04
     +,   1.4656068E-04,   1.4636928E-04,   1.4614224E-04
     +,   1.4588941E-04,   1.4562155E-04,   1.4535066E-04
     +,   1.4508962E-04,   1.4485225E-04,   1.4465312E-04
     +,   1.4450724E-04,   1.4443000E-04,   1.4443704E-04
     +,   1.4454403E-04,   1.4476627E-04,   1.4511874E-04
     +,   1.4561576E-04,   1.4627076E-04,   1.4709627E-04
     +,   1.4810343E-04,   1.4930221E-04,   1.5070097E-04
     +,   1.5230657E-04,   1.5412417E-04,   1.5615701E-04
     +,   1.5840700E-04,   1.6087387E-04,   1.6355622E-04
     +,   1.6645047E-04,   1.6955221E-04,   1.7285516E-04
     +,   1.7635225E-04,   1.8003539E-04,   1.8389561E-04
     +,   1.8792317E-04,   1.9210829E-04,   1.9644097E-04
     +,   2.0091071E-04,   2.0550782E-04,   2.1022205E-04
     +,   2.1504439E-04,   2.1996532E-04,   2.2497668E-04
     +,   2.3007015E-04,   2.3523833E-04,   2.4047392E-04
     +,   2.4577029E-04,   2.5112135E-04,   2.5652078E-04
     +,   2.6196259E-04,   2.6744121E-04,   2.7295109E-04
     +,   2.7848632E-04,   2.8404148E-04,   2.8961094E-04
     +,   2.9518970E-04,   3.0077263E-04,   3.0635612E-04
     +,   3.1193678E-04,   3.1751386E-04,   3.2308811E-04
     +,   3.2866397E-04,   3.3424934E-04,   3.3985695E-04
     +,   3.4550441E-04,   3.5121621E-04,   3.5702332E-04
     +,   3.6296365E-04,   3.6908270E-04,   3.7543266E-04
     +,   3.8207235E-04,   3.8906539E-04,   3.9647997E-04
     +,   4.0438568E-04,   4.1285271E-04,   4.2194792E-04
     +,   4.3173390E-04,   4.4226611E-04,   4.5358937E-04
     +,   4.6573658E-04,   4.7872751E-04,   4.9256656E-04
     +,   5.0724135E-04,   5.2272133E-04,   5.3895969E-04
     +,   5.5589085E-04,   5.7342945E-04,   5.9147261E-04
     +,   6.0989923E-04,   6.2856701E-04,   6.4731605E-04
     +,   6.6596689E-04,   6.8432343E-04,   7.0217071E-04
     +,   7.1927893E-04,   7.3540810E-04,   7.5031014E-04
     +,   7.6373370E-04,   7.7543251E-04,   7.8517222E-04
     +,   7.9273834E-04,   7.9794269E-04,   8.0063462E-04
     +,   8.0070528E-04,   7.9809397E-04,   7.9279335E-04
     +,   7.8484957E-04,   7.7436253E-04,   7.6148339E-04
     +,   7.4640912E-04,   7.2937523E-04,   7.1064592E-04
     +,   6.9050741E-04,   6.6925550E-04,   6.4718496E-04
     +,   6.2458048E-04,   6.0171110E-04,   5.7881878E-04
     +,   5.5611611E-04,   5.3378381E-04,   5.1196868E-04
     +,   4.9078208E-04,   4.7030390E-04,   4.5058614E-04
     +,   4.3165626E-04,   4.1351936E-04,   3.9616518E-04
     +,   3.7957265E-04,   3.6371301E-04,   3.4855251E-04
     +,   3.3405589E-04,   3.2019024E-04,   3.0692335E-04
     +,   2.9422602E-04,   2.8207336E-04,   2.7044307E-04
     +,   2.5931478E-04,   2.4867037E-04,   2.3849307E-04
     +,   2.2876660E-04,   2.1947372E-04,   2.1059645E-04
     +,   2.0211602E-04,   1.9401259E-04,   1.8626424E-04
     +,   1.7884797E-04,   1.7174077E-04,   1.6491847E-04
     +,   1.5835713E-04,   1.5203372E-04,   1.4592639E-04
     +,   1.4001447E-04,   1.3427912E-04,   1.2870441E-04
     +,   1.2327661E-04,   1.1798443E-04,   1.1281908E-04
     +,   1.0777478E-04,   1.0284802E-04,   9.8037184E-05
     +,   9.3342467E-05,   8.8766290E-05,   8.4311672E-05
     +,   7.9982638E-05,   7.5784010E-05,   7.1720868E-05
     +,   6.7797948E-05,   6.4019703E-05,   6.0390306E-05
     +,   5.6913177E-05,   5.3590669E-05,   5.0424194E-05
     +,   4.7414378E-05,   4.4560802E-05,   4.1861851E-05
     +,   3.9314946E-05,   3.6916870E-05,   3.4663321E-05
     +,   3.2549317E-05,   3.0569394E-05,   2.8717583E-05
     +,   2.6987396E-05,   2.5372106E-05,   2.3864937E-05
     +,   2.2459024E-05,   2.1147458E-05,   1.9923458E-05
     +,   1.8780507E-05,   1.7712342E-05,   1.6712911E-05
     +,   1.5776526E-05,   1.4897945E-05,   1.4072220E-05
     +,   1.3294803E-05,   1.2561591E-05,   1.1868864E-05
     +,   1.1213227E-05,   1.0591656E-05,   1.0001500E-05
     +,   9.4404204E-06,   8.9063333E-06,   8.3974192E-06
     +,   7.9121273E-06,   7.4491163E-06,   7.0071947E-06
     +,   6.5853337E-06,   6.1826781E-06,   5.7984466E-06
     +,   5.4319544E-06,   5.0826134E-06,   4.7498957E-06
     +,   4.4332946E-06,   4.1323406E-06,   3.8466055E-06
     +,   3.5756764E-06,   3.3191291E-06,   3.0765441E-06
     +,   2.8475235E-06,   2.6316350E-06,   2.4284707E-06
     +,   2.2375846E-06,   2.0585521E-06,   1.8909178E-06
     +,   1.7342412E-06,   1.5880566E-06,   1.4519144E-06
     +,   1.3253459E-06,   1.2078988E-06,   1.0991108E-06
     +,   9.9852411E-07,   9.0569711E-07,   8.2018249E-07
     +,   7.4155383E-07,   6.6938458E-07,   6.0326977E-07
     +,   5.4280821E-07,   4.8762138E-07,   4.3733763E-07
     +,   3.9160795E-07,   3.5009262E-07,   3.1247433E-07
     +,   2.7844675E-07,   2.4772456E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt80 = Yx/0.0155555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7472779E-06,   2.9188138E-06
     +,   3.0976942E-06,   3.2839876E-06,   3.4777520E-06
     +,   3.6790307E-06,   3.8878561E-06,   4.1042490E-06
     +,   4.3282180E-06,   4.5597762E-06,   4.7989224E-06
     +,   5.0456601E-06,   5.2999958E-06,   5.5619480E-06
     +,   5.8315509E-06,   6.1088604E-06,   6.3939683E-06
     +,   6.6870016E-06,   6.9881439E-06,   7.2976386E-06
     +,   7.6158026E-06,   7.9430465E-06,   8.2798724E-06
     +,   8.6269283E-06,   8.9849582E-06,   9.3548942E-06
     +,   9.7378206E-06,   1.0135009E-05,   1.0547945E-05
     +,   1.0978330E-05,   1.1428108E-05,   1.1899482E-05
     +,   1.2394918E-05,   1.2917165E-05,   1.3469259E-05
     +,   1.4054528E-05,   1.4676598E-05,   1.5339370E-05
     +,   1.6047066E-05,   1.6804097E-05,   1.7615190E-05
     +,   1.8485227E-05,   1.9419278E-05,   2.0422531E-05
     +,   2.1500229E-05,   2.2657619E-05,   2.3899864E-05
     +,   2.5231973E-05,   2.6658689E-05,   2.8184411E-05
     +,   2.9813080E-05,   3.1548061E-05,   3.3392014E-05
     +,   3.5346926E-05,   3.7413647E-05,   3.9592236E-05
     +,   4.1881507E-05,   4.4279070E-05,   4.6781232E-05
     +,   4.9382965E-05,   5.2077779E-05,   5.4857817E-05
     +,   5.7713562E-05,   6.0634313E-05,   6.3607986E-05
     +,   6.6620938E-05,   6.9658694E-05,   7.2705385E-05
     +,   7.5744625E-05,   7.8759047E-05,   8.1731188E-05
     +,   8.4643092E-05,   8.7477281E-05,   9.0216345E-05
     +,   9.2843955E-05,   9.5344789E-05,   9.7704862E-05
     +,   9.9911915E-05,   1.0195600E-04,   1.0382953E-04
     +,   1.0552753E-04,   1.0704827E-04,   1.0839309E-04
     +,   1.0956705E-04,   1.1057883E-04,   1.1144111E-04
     +,   1.1217054E-04,   1.1278797E-04,   1.1331846E-04
     +,   1.1379129E-04,   1.1424006E-04,   1.1470246E-04
     +,   1.1522035E-04,   1.1583964E-04,   1.1661010E-04
     +,   1.1758511E-04,   1.1882154E-04,   1.2037929E-04
     +,   1.2232101E-04,   1.2471143E-04,   1.2761696E-04
     +,   1.3110452E-04,   1.3524112E-04,   1.4009178E-04
     +,   1.4571917E-04,   1.5218151E-04,   1.5953026E-04
     +,   1.6780841E-04,   1.7704883E-04,   1.8727168E-04
     +,   1.9848094E-04,   2.1066450E-04,   2.2378948E-04
     +,   2.3780383E-04,   2.5263152E-04,   2.6817620E-04
     +,   2.8431756E-04,   3.0091676E-04,   3.1781485E-04
     +,   3.3484041E-04,   3.5181260E-04,   3.6854629E-04
     +,   3.8486021E-04,   4.0058541E-04,   4.1557266E-04
     +,   4.2969800E-04,   4.4287331E-04,   4.5504776E-04
     +,   4.6621478E-04,   4.7640924E-04,   4.8570972E-04
     +,   4.9423106E-04,   5.0212245E-04,   5.0955737E-04
     +,   5.1672937E-04,   5.2384427E-04,   5.3111481E-04
     +,   5.3875707E-04,   5.4698775E-04,   5.5602362E-04
     +,   5.6607864E-04,   5.7736482E-04,   5.9009268E-04
     +,   6.0447142E-04,   6.2070979E-04,   6.3902076E-04
     +,   6.5962574E-04,   6.8275502E-04,   7.0865068E-04
     +,   7.3756214E-04,   7.6972693E-04,   8.0534094E-04
     +,   8.4451435E-04,   8.8721816E-04,   9.3322113E-04
     +,   9.8202564E-04,   1.0328247E-03,   1.0844852E-03
     +,   1.1355593E-03,   1.1843306E-03,   1.2289180E-03
     +,   1.2673921E-03,   1.2979143E-03,   1.3188892E-03
     +,   1.3290996E-03,   1.3278109E-03,   1.3148442E-03
     +,   1.2906039E-03,   1.2560554E-03,   1.2126642E-03
     +,   1.1623019E-03,   1.1071195E-03,   1.0494032E-03
     +,   9.9143188E-04,   9.3534280E-04,   8.8299788E-04
     +,   8.3589013E-04,   7.9507934E-04,   7.6115463E-04
     +,   7.3423440E-04,   7.1400771E-04,   6.9979520E-04
     +,   6.9063395E-04,   6.8537192E-04,   6.8276917E-04
     +,   6.8159081E-04,   6.8068999E-04,   6.7906943E-04
     +,   6.7592884E-04,   6.7068759E-04,   6.6298991E-04
     +,   6.5269280E-04,   6.3984201E-04,   6.2463834E-04
     +,   6.0739764E-04,   5.8851152E-04,   5.6841061E-04
     +,   5.4753083E-04,   5.2628346E-04,   5.0503592E-04
     +,   4.8410005E-04,   4.6372187E-04,   4.4407960E-04
     +,   4.2528679E-04,   4.0739990E-04,   3.9042288E-04
     +,   3.7431758E-04,   3.5901420E-04,   3.4442003E-04
     +,   3.3042682E-04,   3.1692092E-04,   3.0379061E-04
     +,   2.9093210E-04,   2.7825381E-04,   2.6568095E-04
     +,   2.5315955E-04,   2.4065665E-04,   2.2816000E-04
     +,   2.1567734E-04,   2.0323617E-04,   1.9087779E-04
     +,   1.7865539E-04,   1.6663106E-04,   1.5487072E-04
     +,   1.4344011E-04,   1.3240197E-04,   1.2181392E-04
     +,   1.1172566E-04,   1.0217657E-04,   9.3195726E-05
     +,   8.4802028E-05,   7.7003715E-05,   6.9798683E-05
     +,   6.3175961E-05,   5.7117617E-05,   5.1598676E-05
     +,   4.6589415E-05,   4.2056901E-05,   3.7965990E-05
     +,   3.4280216E-05,   3.0963209E-05,   2.7979706E-05
     +,   2.5295973E-05,   2.2880180E-05,   2.0702955E-05
     +,   1.8737721E-05,   1.6960585E-05,   1.5350224E-05
     +,   1.3887935E-05,   1.2557558E-05,   1.1345005E-05
     +,   1.0238180E-05,   9.2267837E-06,   8.3019941E-06
     +,   7.4561840E-06,   6.6827797E-06,   5.9761087E-06
     +,   5.3311774E-06,   4.7434905E-06,   4.2089860E-06
     +,   3.7239747E-06,   3.2850144E-06,   2.8888437E-06
     +,   2.5323700E-06,   2.2126728E-06,   1.9269223E-06
     +,   1.6724065E-06,   1.4465423E-06,   1.2468570E-06
     +,   1.0709801E-06,   9.1666465E-07,   7.8179966E-07
     +,   6.6439998E-07,   5.6260416E-07,   4.7468683E-07
     +,   3.9906331E-07,   3.3427025E-07,   2.7898184E-07
     +,   2.3198967E-07,   1.9221123E-07,   1.5867141E-07
     +,   1.3050656E-07,   1.0694807E-07,   8.7322277E-08
     +,   7.1036574E-08,   5.7576987E-08,   4.6496691E-08
     +,   3.7410910E-08,   2.9990442E-08,   2.3953563E-08
     +,   1.9061861E-08,   1.5113409E-08,   1.1938980E-08
     +,   9.3966577E-09,   7.3686488E-09,   5.7570841E-09
     +,   4.4815254E-09,   3.4757590E-09,   2.6858489E-09
     +,   2.0678259E-09,   1.5861871E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt85 = Yx/0.01825
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2358956E-05,   2.3296245E-05
     +,   2.4275332E-05,   2.5297484E-05,   2.6363921E-05
     +,   2.7475828E-05,   2.8634329E-05,   2.9840490E-05
     +,   3.1095286E-05,   3.2399672E-05,   3.3754441E-05
     +,   3.5160308E-05,   3.6617865E-05,   3.8127568E-05
     +,   3.9689716E-05,   4.1304462E-05,   4.2971751E-05
     +,   4.4691336E-05,   4.6462752E-05,   4.8285288E-05
     +,   5.0157974E-05,   5.2079577E-05,   5.4048513E-05
     +,   5.6063025E-05,   5.8120804E-05,   6.0219420E-05
     +,   6.2355939E-05,   6.4527121E-05,   6.6729306E-05
     +,   6.8958492E-05,   7.1210270E-05,   7.3479860E-05
     +,   7.5762080E-05,   7.8051416E-05,   8.0341990E-05
     +,   8.2627572E-05,   8.4901665E-05,   8.7157452E-05
     +,   8.9388013E-05,   9.1585964E-05,   9.3744064E-05
     +,   9.5854768E-05,   9.7910546E-05,   9.9903897E-05
     +,   1.0182733E-04,   1.0367348E-04,   1.0543524E-04
     +,   1.0710565E-04,   1.0867815E-04,   1.1014644E-04
     +,   1.1150477E-04,   1.1274781E-04,   1.1387072E-04
     +,   1.1486939E-04,   1.1574016E-04,   1.1648012E-04
     +,   1.1708704E-04,   1.1755942E-04,   1.1789644E-04
     +,   1.1809803E-04,   1.1816483E-04,   1.1809827E-04
     +,   1.1790047E-04,   1.1757421E-04,   1.1712292E-04
     +,   1.1655077E-04,   1.1586237E-04,   1.1506305E-04
     +,   1.1415847E-04,   1.1315494E-04,   1.1205903E-04
     +,   1.1087785E-04,   1.0961870E-04,   1.0828931E-04
     +,   1.0689760E-04,   1.0545166E-04,   1.0395996E-04
     +,   1.0243108E-04,   1.0087380E-04,   9.9297024E-05
     +,   9.7709992E-05,   9.6122007E-05,   9.4542767E-05
     +,   9.2982074E-05,   9.1450114E-05,   8.9957321E-05
     +,   8.8514658E-05,   8.7133201E-05,   8.5824722E-05
     +,   8.4601299E-05,   8.3475410E-05,   8.2460137E-05
     +,   8.1568942E-05,   8.0815676E-05,   8.0214508E-05
     +,   7.9779973E-05,   7.9526690E-05,   7.9469290E-05
     +,   7.9622318E-05,   7.9999903E-05,   8.0615697E-05
     +,   8.1482438E-05,   8.2611892E-05,   8.4014297E-05
     +,   8.5698412E-05,   8.7671076E-05,   8.9936919E-05
     +,   9.2498012E-05,   9.5354211E-05,   9.8502664E-05
     +,   1.0193763E-04,   1.0565122E-04,   1.0963275E-04
     +,   1.1387009E-04,   1.1834889E-04,   1.2305460E-04
     +,   1.2797149E-04,   1.3308493E-04,   1.3838086E-04
     +,   1.4384744E-04,   1.4947559E-04,   1.5525885E-04
     +,   1.6119433E-04,   1.6728329E-04,   1.7353079E-04
     +,   1.7994471E-04,   1.8653707E-04,   1.9332174E-04
     +,   2.0031568E-04,   2.0753698E-04,   2.1500677E-04
     +,   2.2274752E-04,   2.3078614E-04,   2.3915317E-04
     +,   2.4788710E-04,   2.5703525E-04,   2.6665634E-04
     +,   2.7682263E-04,   2.8762294E-04,   2.9916174E-04
     +,   3.1155828E-04,   3.2494392E-04,   3.3945846E-04
     +,   3.5524330E-04,   3.7243243E-04,   3.9114847E-04
     +,   4.1149551E-04,   4.3355583E-04,   4.5739484E-04
     +,   4.8307198E-04,   5.1065773E-04,   5.4025720E-04
     +,   5.7203788E-04,   6.0626189E-04,   6.4330437E-04
     +,   6.8365963E-04,   7.2793313E-04,   7.7680976E-04
     +,   8.3099818E-04,   8.9114846E-04,   9.5778372E-04
     +,   1.0312150E-03,   1.1114725E-03,   1.1982752E-03
     +,   1.2910410E-03,   1.3889159E-03,   1.4908391E-03
     +,   1.5956274E-03,   1.7020658E-03,   1.8089525E-03
     +,   1.9151069E-03,   2.0193304E-03,   2.1203279E-03
     +,   2.2165698E-03,   2.3061605E-03,   2.3867667E-03
     +,   2.4555982E-03,   2.5095011E-03,   2.5451877E-03
     +,   2.5595566E-03,   2.5500765E-03,   2.5151649E-03
     +,   2.4545037E-03,   2.3692001E-03,   2.2617860E-03
     +,   2.1360265E-03,   1.9965831E-03,   1.8485469E-03
     +,   1.6969836E-03,   1.5465266E-03,   1.4010327E-03
     +,   1.2634137E-03,   1.1356112E-03,   1.0186603E-03
     +,   9.1284001E-04,   8.1788114E-04,   7.3316460E-04
     +,   6.5787887E-04,   5.9113826E-04,   5.3206814E-04
     +,   4.7984568E-04,   4.3371008E-04,   3.9295913E-04
     +,   3.5694704E-04,   3.2508399E-04,   2.9682714E-04
     +,   2.7168801E-04,   2.4923743E-04,   2.2910615E-04
     +,   2.1098445E-04,   1.9462028E-04,   1.7981351E-04
     +,   1.6640566E-04,   1.5426865E-04,   1.4329559E-04
     +,   1.3339215E-04,   1.2446905E-04,   1.1643655E-04
     +,   1.0920320E-04,   1.0267644E-04,   9.6762327E-05
     +,   9.1368805E-05,   8.6408843E-05,   8.1802544E-05
     +,   7.7479010E-05,   7.3378273E-05,   6.9452151E-05
     +,   6.5663990E-05,   6.1987681E-05,   5.8406800E-05
     +,   5.4913387E-05,   5.1505958E-05,   4.8187710E-05
     +,   4.4965069E-05,   4.1846717E-05,   3.8841641E-05
     +,   3.5958583E-05,   3.3205499E-05,   3.0588835E-05
     +,   2.8113129E-05,   2.5781039E-05,   2.3593513E-05
     +,   2.1549737E-05,   1.9647172E-05,   1.7881952E-05
     +,   1.6249214E-05,   1.4743227E-05,   1.3357519E-05
     +,   1.2085242E-05,   1.0919451E-05,   9.8530300E-06
     +,   8.8789602E-06,   7.9904894E-06,   7.1811173E-06
     +,   6.4446285E-06,   5.7751708E-06,   5.1673219E-06
     +,   4.6160344E-06,   4.1165990E-06,   3.6646727E-06
     +,   3.2562834E-06,   2.8877701E-06,   2.5557374E-06
     +,   2.2570625E-06,   1.9888964E-06,   1.7485779E-06
     +,   1.5336540E-06,   1.3418696E-06,   1.1711345E-06
     +,   1.0195035E-06,   8.8517623E-07,   7.6649542E-07
     +,   6.6192734E-07,   5.7004888E-07,   4.8954951E-07
     +,   4.1923167E-07,   3.5798672E-07,   3.0480984E-07
     +,   2.5877688E-07,   2.1905488E-07,   1.8488379E-07
     +,   1.5558288E-07,   1.3053618E-07,   1.0919602E-07
     +,   9.1071016E-08,   7.5727279E-08,   6.2779556E-08
     +,   5.1888662E-08,   4.2758057E-08,   3.5127570E-08
     +,   2.8771739E-08,   2.3494465E-08,   1.9127189E-08
     +,   1.5524439E-08,   1.2562190E-08,   1.0134267E-08
     +,   8.1508551E-09,   6.5356787E-09,   5.2246913E-09
     +,   4.1639665E-09,   3.3085370E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt90 = Yx/0.0231
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3651855E-07,   1.5599832E-07
     +,   1.7793660E-07,   2.0259520E-07,   2.3025700E-07
     +,   2.6122731E-07,   2.9583413E-07,   3.3442907E-07
     +,   3.7738744E-07,   4.2511158E-07,   4.7802695E-07
     +,   5.3658550E-07,   6.0126490E-07,   6.7256929E-07
     +,   7.5102827E-07,   8.3719726E-07,   9.3165801E-07
     +,   1.0350162E-06,   1.1479030E-06,   1.2709728E-06
     +,   1.4049037E-06,   1.5503962E-06,   1.7081694E-06
     +,   1.8789739E-06,   2.0635609E-06,   2.2627205E-06
     +,   2.4772492E-06,   2.7079629E-06,   2.9556957E-06
     +,   3.2212970E-06,   3.5056314E-06,   3.8095786E-06
     +,   4.1340354E-06,   4.4799099E-06,   4.8481261E-06
     +,   5.2396244E-06,   5.6553563E-06,   6.0962807E-06
     +,   6.5633999E-06,   7.0576734E-06,   7.5801277E-06
     +,   8.1317630E-06,   8.7135932E-06,   9.3266353E-06
     +,   9.9719000E-06,   1.0650388E-05,   1.1363079E-05
     +,   1.2110927E-05,   1.2894845E-05,   1.3715692E-05
     +,   1.4574256E-05,   1.5471245E-05,   1.6407233E-05
     +,   1.7382741E-05,   1.8398025E-05,   1.9453264E-05
     +,   2.0548396E-05,   2.1683110E-05,   2.2856868E-05
     +,   2.4068819E-05,   2.5317815E-05,   2.6602367E-05
     +,   2.7920549E-05,   2.9270133E-05,   3.0648491E-05
     +,   3.2052434E-05,   3.3478496E-05,   3.4922592E-05
     +,   3.6380377E-05,   3.7846872E-05,   3.9316852E-05
     +,   4.0784507E-05,   4.2243824E-05,   4.3688269E-05
     +,   4.5111159E-05,   4.6505527E-05,   4.7864189E-05
     +,   4.9179806E-05,   5.0445098E-05,   5.1652809E-05
     +,   5.2795695E-05,   5.3866868E-05,   5.4859578E-05
     +,   5.5767599E-05,   5.6585061E-05,   5.7306734E-05
     +,   5.7927940E-05,   5.8444781E-05,   5.8854053E-05
     +,   5.9153437E-05,   5.9341466E-05,   5.9417562E-05
     +,   5.9382091E-05,   5.9236354E-05,   5.8982565E-05
     +,   5.8623886E-05,   5.8164307E-05,   5.7608715E-05
     +,   5.6962694E-05,   5.6232628E-05,   5.5425429E-05
     +,   5.4548636E-05,   5.3610125E-05,   5.2618219E-05
     +,   5.1581355E-05,   5.0508086E-05,   4.9407048E-05
     +,   4.8286751E-05,   4.7155419E-05,   4.6020952E-05
     +,   4.4890934E-05,   4.3772332E-05,   4.2671669E-05
     +,   4.1594674E-05,   4.0546573E-05,   3.9531729E-05
     +,   3.8553957E-05,   3.7616253E-05,   3.6721136E-05
     +,   3.5870511E-05,   3.5065987E-05,   3.4309087E-05
     +,   3.3601569E-05,   3.2945794E-05,   3.2345346E-05
     +,   3.1805841E-05,   3.1335658E-05,   3.0947227E-05
     +,   3.0658222E-05,   3.0493149E-05,   3.0484998E-05
     +,   3.0677085E-05,   3.1124902E-05,   3.1897805E-05
     +,   3.3080625E-05,   3.4774755E-05,   3.7098478E-05
     +,   4.0186460E-05,   4.4188506E-05,   4.9266600E-05
     +,   5.5590048E-05,   6.3329549E-05,   7.2649957E-05
     +,   8.3700572E-05,   9.6602867E-05,   1.1144063E-04
     +,   1.2824681E-04,   1.4699069E-04,   1.6756894E-04
     +,   1.8980193E-04,   2.1343310E-04,   2.3813678E-04
     +,   2.6353952E-04,   2.8925430E-04,   3.1492306E-04
     +,   3.4026860E-04,   3.6515325E-04,   3.8963152E-04
     +,   4.1398068E-04,   4.3869851E-04,   4.6446139E-04
     +,   4.9202400E-04,   5.2206736E-04,   5.5501651E-04
     +,   5.9085828E-04,   6.2899973E-04,   6.6822849E-04
     +,   7.0683076E-04,   7.4289727E-04,   7.7480386E-04
     +,   8.0181850E-04,   8.2472537E-04,   8.4630912E-04
     +,   8.7152747E-04,   9.0724742E-04,   9.6149708E-04
     +,   1.0422826E-03,   1.1561310E-03,   1.3066123E-03
     +,   1.4931173E-03,   1.7100940E-03,   1.9469364E-03
     +,   2.1886637E-03,   2.4173905E-03,   2.6144038E-03
     +,   2.7626178E-03,   2.8490191E-03,   2.8665583E-03
     +,   2.8151018E-03,   2.7012853E-03,   2.5372815E-03
     +,   2.3388045E-03,   2.1228071E-03,   1.9052274E-03
     +,   1.6991957E-03,   1.5139531E-03,   1.3545299E-03
     +,   1.2221055E-03,   1.1148702E-03,   1.0291595E-03
     +,   9.6052804E-04,   9.0456649E-04,   8.5738965E-04
     +,   8.1581867E-04,   7.7736541E-04,   7.4013241E-04
     +,   7.0273480E-04,   6.6426775E-04,   6.2429474E-04
     +,   5.8281882E-04,   5.4022175E-04,   4.9715501E-04
     +,   4.5439901E-04,   4.1272514E-04,   3.7279376E-04
     +,   3.3509836E-04,   2.9994897E-04,   2.6749115E-04
     +,   2.3774811E-04,   2.1066627E-04,   1.8614507E-04
     +,   1.6406429E-04,   1.4429790E-04,   1.2671601E-04
     +,   1.1118324E-04,   9.7557786E-05,   8.5690670E-05
     +,   7.5424927E-05,   6.6597269E-05,   5.9042657E-05
     +,   5.2598774E-05,   4.7109635E-05,   4.2428888E-05
     +,   3.8423052E-05,   3.4973629E-05,   3.1977044E-05
     +,   2.9345227E-05,   2.7005026E-05,   2.4896946E-05
     +,   2.2973631E-05,   2.1198462E-05,   1.9544088E-05
     +,   1.7990667E-05,   1.6524360E-05,   1.5136068E-05
     +,   1.3820344E-05,   1.2574278E-05,   1.1396574E-05
     +,   1.0286951E-05,   9.2457094E-06,   8.2731040E-06
     +,   7.3691822E-06,   6.5336430E-06,   5.7656594E-06
     +,   5.0637955E-06,   4.4260692E-06,   3.8500343E-06
     +,   3.3327933E-06,   2.8710517E-06,   2.4612500E-06
     +,   2.0996702E-06,   1.7824898E-06,   1.5058440E-06
     +,   1.2659198E-06,   1.0590333E-06,   8.8163199E-07
     +,   7.3035920E-07,   6.0208731E-07,   4.9392219E-07
     +,   4.0320995E-07,   3.2754755E-07,   2.6478352E-07
     +,   2.1300201E-07,   1.7051002E-07,   1.3582711E-07
     +,   1.0767113E-07,   8.4934129E-08,   6.6671760E-08
     +,   5.2080033E-08,   4.0483435E-08,   3.1315086E-08
     +,   2.4104954E-08,   1.8464124E-08,   1.4074354E-08
     +,   1.0675723E-08,   8.0583087E-09,   6.0528946E-09
     +,   4.5243085E-09,   3.3652570E-09,   2.4908853E-09
     +,   1.8347065E-09,   1.3447714E-09,   9.8086161E-10
     +,   7.1192807E-10,   5.1421251E-10,   3.6958758E-10
     +,   2.6434449E-10,   1.8814447E-10,   1.3325738E-10
     +,   9.3920247E-11,   6.5872696E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_htt95 = Yx/0.0185
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1926597E-05,   1.2205775E-05
     +,   1.2489824E-05,   1.2778853E-05,   1.3072980E-05
     +,   1.3372339E-05,   1.3677082E-05,   1.3987376E-05
     +,   1.4303399E-05,   1.4625371E-05,   1.4953506E-05
     +,   1.5288053E-05,   1.5629284E-05,   1.5977492E-05
     +,   1.6333004E-05,   1.6696156E-05,   1.7067334E-05
     +,   1.7446935E-05,   1.7835404E-05,   1.8233193E-05
     +,   1.8640801E-05,   1.9058758E-05,   1.9487610E-05
     +,   1.9927971E-05,   2.0380428E-05,   2.0845655E-05
     +,   2.1324317E-05,   2.1817123E-05,   2.2324801E-05
     +,   2.2848108E-05,   2.3387816E-05,   2.3944722E-05
     +,   2.4519630E-05,   2.5113364E-05,   2.5726747E-05
     +,   2.6360609E-05,   2.7015771E-05,   2.7693040E-05
     +,   2.8393248E-05,   2.9117135E-05,   2.9865478E-05
     +,   3.0639003E-05,   3.1438358E-05,   3.2264175E-05
     +,   3.3117034E-05,   3.3997414E-05,   3.4905755E-05
     +,   3.5842393E-05,   3.6807578E-05,   3.7801481E-05
     +,   3.8824146E-05,   3.9875522E-05,   4.0955420E-05
     +,   4.2063610E-05,   4.3199627E-05,   4.4362998E-05
     +,   4.5553053E-05,   4.6769070E-05,   4.8010163E-05
     +,   4.9275412E-05,   5.0563765E-05,   5.1874194E-05
     +,   5.3205473E-05,   5.4556564E-05,   5.5926408E-05
     +,   5.7313915E-05,   5.8718277E-05,   6.0138718E-05
     +,   6.1574894E-05,   6.3026586E-05,   6.4494197E-05
     +,   6.5978449E-05,   6.7480840E-05,   6.9003436E-05
     +,   7.0549257E-05,   7.2122333E-05,   7.3727664E-05
     +,   7.5371492E-05,   7.7061515E-05,   7.8806952E-05
     +,   8.0618476E-05,   8.2508719E-05,   8.4491898E-05
     +,   8.6584376E-05,   8.8804183E-05,   9.1171678E-05
     +,   9.3708666E-05,   9.6439246E-05,   9.9388802E-05
     +,   1.0258448E-04,   1.0605469E-04,   1.0982850E-04
     +,   1.1393542E-04,   1.1840511E-04,   1.2326689E-04
     +,   1.2854820E-04,   1.3427548E-04,   1.4047159E-04
     +,   1.4715707E-04,   1.5434729E-04,   1.6205372E-04
     +,   1.7028122E-04,   1.7902935E-04,   1.8828953E-04
     +,   1.9804690E-04,   2.0827862E-04,   2.1895347E-04
     +,   2.3003225E-04,   2.4146892E-04,   2.5321011E-04
     +,   2.6519521E-04,   2.7735953E-04,   2.8963247E-04
     +,   3.0194281E-04,   3.1421633E-04,   3.2638150E-04
     +,   3.3836806E-04,   3.5011212E-04,   3.6155575E-04
     +,   3.7265138E-04,   3.8336220E-04,   3.9366423E-04
     +,   4.0354760E-04,   4.1301909E-04,   4.2210126E-04
     +,   4.3083285E-04,   4.3926982E-04,   4.4748254E-04
     +,   4.5555588E-04,   4.6358621E-04,   4.7167987E-04
     +,   4.7994882E-04,   4.8850861E-04,   4.9747346E-04
     +,   5.0695438E-04,   5.1705365E-04,   5.2786298E-04
     +,   5.3945894E-04,   5.5190263E-04,   5.6523766E-04
     +,   5.7948806E-04,   5.9465878E-04,   6.1073905E-04
     +,   6.2770321E-04,   6.4551132E-04,   6.6411612E-04
     +,   6.8346539E-04,   7.0350437E-04,   7.2418031E-04
     +,   7.4544590E-04,   7.6726056E-04,   7.8958977E-04
     +,   8.1240339E-04,   8.3567743E-04,   8.5938786E-04
     +,   8.8350411E-04,   9.0798573E-04,   9.3277986E-04
     +,   9.5781556E-04,   9.8300027E-04,   1.0082247E-03
     +,   1.0333683E-03,   1.0583046E-03,   1.0829172E-03
     +,   1.1071232E-03,   1.1308902E-03,   1.1542604E-03
     +,   1.1773749E-03,   1.2004985E-03,   1.2240361E-03
     +,   1.2485367E-03,   1.2747026E-03,   1.3033799E-03
     +,   1.3355502E-03,   1.3723056E-03,   1.4148465E-03
     +,   1.4644670E-03,   1.5225449E-03,   1.5905520E-03
     +,   1.6700581E-03,   1.7627274E-03,   1.8702783E-03
     +,   1.9944389E-03,   2.1368605E-03,   2.2989889E-03
     +,   2.4819120E-03,   2.6862465E-03,   2.9120417E-03
     +,   3.1587346E-03,   3.4251329E-03,   3.7095500E-03
     +,   4.0099439E-03,   4.3241642E-03,   4.6503670E-03
     +,   4.9876724E-03,   5.3370167E-03,   5.7022283E-03
     +,   6.0909097E-03,   6.5144352E-03,   6.9860299E-03
     +,   7.5165019E-03,   8.1083812E-03,   8.7510748E-03
     +,   9.4197011E-03,   1.0079969E-02,   1.0698033E-02
     +,   1.1251019E-02,   1.1733507E-02,   1.2156960E-02
     +,   1.2542093E-02,   1.2907289E-02,   1.3258025E-02
     +,   1.3582834E-02,   1.3859125E-02,   1.4066550E-02
     +,   1.4199159E-02,   1.4266646E-02,   1.4282357E-02
     +,   1.4246531E-02,   1.4138598E-02,   1.3926400E-02
     +,   1.3587220E-02,   1.3127262E-02,   1.2586355E-02
     +,   1.2024529E-02,   1.1498605E-02,   1.1042058E-02
     +,   1.0657826E-02,   1.0325822E-02,   1.0017890E-02
     +,   9.7116632E-03,   9.3971035E-03,   9.0750847E-03
     +,   8.7513998E-03,   8.4304679E-03,   8.1121456E-03
     +,   7.7924142E-03,   7.4667344E-03,   7.1335314E-03
     +,   6.7958608E-03,   6.4605325E-03,   6.1356267E-03
     +,   5.8276076E-03,   5.5396697E-03,   5.2716341E-03
     +,   5.0212219E-03,   4.7856751E-03,   4.5630722E-03
     +,   4.3528806E-03,   4.1557155E-03,   3.9725592E-03
     +,   3.8039901E-03,   3.6496338E-03,   3.5079934E-03
     +,   3.3766630E-03,   3.2527663E-03,   3.1334606E-03
     +,   3.0163417E-03,   2.8996971E-03,   2.7826151E-03
     +,   2.6649486E-03,   2.5471617E-03,   2.4301363E-03
     +,   2.3149841E-03,   2.2028596E-03,   2.0947875E-03
     +,   1.9915537E-03,   1.8936353E-03,   1.8011776E-03
     +,   1.7140039E-03,   1.6316883E-03,   1.5536378E-03
     +,   1.4791854E-03,   1.4076718E-03,   1.3385213E-03
     +,   1.2712959E-03,   1.2057032E-03,   1.1416090E-03
     +,   1.0790039E-03,   1.0179866E-03,   9.5871201E-04
     +,   9.0137200E-04,   8.4615208E-04,   7.9322117E-04
     +,   7.4270635E-04,   6.9469644E-04,   6.4923143E-04
     +,   6.0631026E-04,   5.6590041E-04,   5.2793638E-04
     +,   4.9233710E-04,   4.5900175E-04,   4.2782628E-04
     +,   3.9869762E-04,   3.7150606E-04,   3.4613945E-04
     +,   3.2249177E-04,   3.0045793E-04,   2.7994026E-04
     +,   2.6084296E-04,   2.4307796E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt100 = Yx/0.167045454545455
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.5720760E-05,   5.6965364E-05
     +,   5.8201120E-05,   5.9426307E-05,   6.0639195E-05
     +,   6.1838051E-05,   6.3021151E-05,   6.4186803E-05
     +,   6.5333261E-05,   6.6458968E-05,   6.7562236E-05
     +,   6.8641493E-05,   6.9695212E-05,   7.0721908E-05
     +,   7.1720184E-05,   7.2688665E-05,   7.3626121E-05
     +,   7.4531359E-05,   7.5403303E-05,   7.6240947E-05
     +,   7.7043456E-05,   7.7810037E-05,   7.8540063E-05
     +,   7.9233054E-05,   7.9888596E-05,   8.0506514E-05
     +,   8.1086720E-05,   8.1629289E-05,   8.2134458E-05
     +,   8.2602644E-05,   8.3034443E-05,   8.3430612E-05
     +,   8.3792089E-05,   8.4119987E-05,   8.4415631E-05
     +,   8.4680527E-05,   8.4916370E-05,   8.5125022E-05
     +,   8.5308558E-05,   8.5469255E-05,   8.5609543E-05
     +,   8.5732077E-05,   8.5839660E-05,   8.5935251E-05
     +,   8.6022010E-05,   8.6103260E-05,   8.6182459E-05
     +,   8.6263201E-05,   8.6349195E-05,   8.6444299E-05
     +,   8.6552427E-05,   8.6677632E-05,   8.6823988E-05
     +,   8.6995606E-05,   8.7196662E-05,   8.7431348E-05
     +,   8.7703767E-05,   8.8018045E-05,   8.8378249E-05
     +,   8.8788336E-05,   8.9252171E-05,   8.9773421E-05
     +,   9.0355643E-05,   9.1002206E-05,   9.1716254E-05
     +,   9.2500617E-05,   9.3357972E-05,   9.4290626E-05
     +,   9.5300646E-05,   9.6389616E-05,   9.7558950E-05
     +,   9.8809505E-05,   1.0014193E-04,   1.0155628E-04
     +,   1.0305231E-04,   1.0462938E-04,   1.0628637E-04
     +,   1.0802158E-04,   1.0983314E-04,   1.1171868E-04
     +,   1.1367518E-04,   1.1569961E-04,   1.1778808E-04
     +,   1.1993678E-04,   1.2214114E-04,   1.2439658E-04
     +,   1.2669800E-04,   1.2904008E-04,   1.3141723E-04
     +,   1.3382378E-04,   1.3625382E-04,   1.3870122E-04
     +,   1.4115970E-04,   1.4362317E-04,   1.4608548E-04
     +,   1.4854029E-04,   1.5098172E-04,   1.5340357E-04
     +,   1.5580027E-04,   1.5816605E-04,   1.6049587E-04
     +,   1.6278449E-04,   1.6502752E-04,   1.6722055E-04
     +,   1.6935993E-04,   1.7144240E-04,   1.7346522E-04
     +,   1.7542613E-04,   1.7732363E-04,   1.7915681E-04
     +,   1.8092540E-04,   1.8262998E-04,   1.8427172E-04
     +,   1.8585278E-04,   1.8737593E-04,   1.8884496E-04
     +,   1.9026456E-04,   1.9164027E-04,   1.9297861E-04
     +,   1.9428710E-04,   1.9557438E-04,   1.9684996E-04
     +,   1.9812456E-04,   1.9940993E-04,   2.0071909E-04
     +,   2.0206613E-04,   2.0346645E-04,   2.0493648E-04
     +,   2.0649421E-04,   2.0815854E-04,   2.0995006E-04
     +,   2.1189050E-04,   2.1400301E-04,   2.1631194E-04
     +,   2.1884324E-04,   2.2162407E-04,   2.2468285E-04
     +,   2.2804899E-04,   2.3175331E-04,   2.3582748E-04
     +,   2.4030390E-04,   2.4521488E-04,   2.5059353E-04
     +,   2.5647250E-04,   2.6288314E-04,   2.6985569E-04
     +,   2.7741905E-04,   2.8559801E-04,   2.9441441E-04
     +,   3.0388596E-04,   3.1402527E-04,   3.2483871E-04
     +,   3.3632532E-04,   3.4847829E-04,   3.6128293E-04
     +,   3.7471656E-04,   3.8874862E-04,   4.0334370E-04
     +,   4.1846110E-04,   4.3405546E-04,   4.5008297E-04
     +,   4.6650221E-04,   4.8327891E-04,   5.0039066E-04
     +,   5.1783456E-04,   5.3563330E-04,   5.5384106E-04
     +,   5.7255151E-04,   5.9190823E-04,   6.1211089E-04
     +,   6.3342130E-04,   6.5616996E-04,   6.8076258E-04
     +,   7.0767920E-04,   7.3746982E-04,   7.7075633E-04
     +,   8.0821780E-04,   8.5057894E-04,   8.9859334E-04
     +,   9.5303223E-04,   1.0146587E-03,   1.0842101E-03
     +,   1.1623711E-03,   1.2497673E-03,   1.3469262E-03
     +,   1.4542508E-03,   1.5719857E-03,   1.7001944E-03
     +,   1.8387168E-03,   1.9871315E-03,   2.1447681E-03
     +,   2.3107121E-03,   2.4838375E-03,   2.6628950E-03
     +,   2.8466291E-03,   3.0338983E-03,   3.2237801E-03
     +,   3.4156770E-03,   3.6093472E-03,   3.8048108E-03
     +,   4.0021529E-03,   4.2012385E-03,   4.4014528E-03
     +,   4.6015317E-03,   4.7997786E-03,   4.9947840E-03
     +,   5.1865950E-03,   5.3780884E-03,   5.5760373E-03
     +,   5.7912846E-03,   6.0377051E-03,   6.3302647E-03
     +,   6.6830716E-03,   7.1084243E-03,   7.6170466E-03
     +,   8.2185464E-03,   8.9203762E-03,   9.7241681E-03
     +,   1.0620044E-02,   1.1581979E-02,   1.2568304E-02
     +,   1.3527629E-02,   1.4408397E-02,   1.5167725E-02
     +,   1.5776008E-02,   1.6216669E-02,   1.6485358E-02
     +,   1.6591169E-02,   1.6560325E-02,   1.6437847E-02
     +,   1.6281435E-02,   1.6145887E-02,   1.6063152E-02
     +,   1.6028468E-02,   1.6000912E-02,   1.5919825E-02
     +,   1.5730871E-02,   1.5410060E-02,   1.4973833E-02
     +,   1.4469889E-02,   1.3953504E-02,   1.3462910E-02
     +,   1.3005969E-02,   1.2563875E-02,   1.2105866E-02
     +,   1.1606171E-02,   1.1054843E-02,   1.0460139E-02
     +,   9.8437676E-03,   9.2325592E-03,   8.6501921E-03
     +,   8.1122834E-03,   7.6252501E-03,   7.1882661E-03
     +,   6.7961435E-03,   6.4417846E-03,   6.1173993E-03
     +,   5.8148545E-03,   5.5260141E-03,   5.2435570E-03
     +,   4.9620545E-03,   4.6789148E-03,   4.3946458E-03
     +,   4.1123694E-03,   3.8367196E-03,   3.5724689E-03
     +,   3.3235028E-03,   3.0922429E-03,   2.8795935E-03
     +,   2.6852228E-03,   2.5080445E-03,   2.3466577E-03
     +,   2.1996154E-03,   2.0655363E-03,   1.9431319E-03
     +,   1.8311547E-03,   1.7283220E-03,   1.6333279E-03
     +,   1.5448378E-03,   1.4615782E-03,   1.3823801E-03
     +,   1.3062770E-03,   1.2325275E-03,   1.1606573E-03
     +,   1.0904277E-03,   1.0218251E-03,   9.5499179E-04
     +,   8.9017762E-04,   8.2769414E-04,   7.6784758E-04
     +,   7.1092171E-04,   6.5713783E-04,   6.0665217E-04
     +,   5.5954256E-04,   5.1582215E-04,   4.7543721E-04
     +,   4.3829030E-04,   4.0424027E-04,   3.7312458E-04
     +,   3.4476051E-04,   3.1896069E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt104 = Yx/0.183909090909091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0829626E-05,   4.2010095E-05
     +,   4.3217773E-05,   4.4452558E-05,   4.5714332E-05
     +,   4.7002846E-05,   4.8317772E-05,   4.9658702E-05
     +,   5.1025087E-05,   5.2416362E-05,   5.3831784E-05
     +,   5.5270502E-05,   5.6731580E-05,   5.8213933E-05
     +,   5.9716411E-05,   6.1237704E-05,   6.2776402E-05
     +,   6.4330961E-05,   6.5899738E-05,   6.7480978E-05
     +,   6.9072761E-05,   7.0673159E-05,   7.2280025E-05
     +,   7.3891242E-05,   7.5504460E-05,   7.7117358E-05
     +,   7.8727477E-05,   8.0332291E-05,   8.1929262E-05
     +,   8.3515748E-05,   8.5089094E-05,   8.6646643E-05
     +,   8.8185727E-05,   8.9703637E-05,   9.1197719E-05
     +,   9.2665345E-05,   9.4103969E-05,   9.5511052E-05
     +,   9.6884214E-05,   9.8221055E-05,   9.9519442E-05
     +,   1.0077729E-04,   1.0199265E-04,   1.0316374E-04
     +,   1.0428908E-04,   1.0536717E-04,   1.0639692E-04
     +,   1.0737737E-04,   1.0830777E-04,   1.0918772E-04
     +,   1.1001699E-04,   1.1079567E-04,   1.1152413E-04
     +,   1.1220302E-04,   1.1283321E-04,   1.1341599E-04
     +,   1.1395286E-04,   1.1444563E-04,   1.1489643E-04
     +,   1.1530762E-04,   1.1568191E-04,   1.1602227E-04
     +,   1.1633191E-04,   1.1661431E-04,   1.1687320E-04
     +,   1.1711249E-04,   1.1733641E-04,   1.1754921E-04
     +,   1.1775542E-04,   1.1795969E-04,   1.1816677E-04
     +,   1.1838146E-04,   1.1860873E-04,   1.1885346E-04
     +,   1.1912059E-04,   1.1941507E-04,   1.1974163E-04
     +,   1.2010508E-04,   1.2050993E-04,   1.2096069E-04
     +,   1.2146147E-04,   1.2201633E-04,   1.2262893E-04
     +,   1.2330267E-04,   1.2404058E-04,   1.2484539E-04
     +,   1.2571923E-04,   1.2666413E-04,   1.2768134E-04
     +,   1.2877180E-04,   1.2993594E-04,   1.3117363E-04
     +,   1.3248411E-04,   1.3386631E-04,   1.3531845E-04
     +,   1.3683818E-04,   1.3842272E-04,   1.4006853E-04
     +,   1.4177177E-04,   1.4352797E-04,   1.4533212E-04
     +,   1.4717875E-04,   1.4906206E-04,   1.5097571E-04
     +,   1.5291301E-04,   1.5486711E-04,   1.5683071E-04
     +,   1.5879638E-04,   1.6075648E-04,   1.6270348E-04
     +,   1.6462970E-04,   1.6652764E-04,   1.6838964E-04
     +,   1.7020880E-04,   1.7197810E-04,   1.7369121E-04
     +,   1.7534211E-04,   1.7692550E-04,   1.7843675E-04
     +,   1.7987202E-04,   1.8122834E-04,   1.8250362E-04
     +,   1.8369690E-04,   1.8480845E-04,   1.8583961E-04
     +,   1.8679306E-04,   1.8767286E-04,   1.8848444E-04
     +,   1.8923469E-04,   1.8993208E-04,   1.9058649E-04
     +,   1.9120927E-04,   1.9181352E-04,   1.9241350E-04
     +,   1.9302520E-04,   1.9366574E-04,   1.9435365E-04
     +,   1.9510860E-04,   1.9595130E-04,   1.9690346E-04
     +,   1.9798733E-04,   1.9922580E-04,   2.0064217E-04
     +,   2.0225994E-04,   2.0410254E-04,   2.0619329E-04
     +,   2.0855502E-04,   2.1121030E-04,   2.1418069E-04
     +,   2.1748772E-04,   2.2115195E-04,   2.2519362E-04
     +,   2.2963242E-04,   2.3448859E-04,   2.3978265E-04
     +,   2.4553607E-04,   2.5177214E-04,   2.5851655E-04
     +,   2.6579978E-04,   2.7365561E-04,   2.8212508E-04
     +,   2.9125653E-04,   3.0110733E-04,   3.1174542E-04
     +,   3.2325133E-04,   3.3571999E-04,   3.4926069E-04
     +,   3.6399913E-04,   3.8007877E-04,   3.9766068E-04
     +,   4.1692180E-04,   4.3805357E-04,   4.6126181E-04
     +,   4.8676046E-04,   5.1476486E-04,   5.4548826E-04
     +,   5.7913340E-04,   6.1587838E-04,   6.5587077E-04
     +,   6.9921953E-04,   7.4598333E-04,   7.9616136E-04
     +,   8.4968860E-04,   9.0644212E-04,   9.6623885E-04
     +,   1.0288419E-03,   1.0939781E-03,   1.1613591E-03
     +,   1.2307008E-03,   1.3017381E-03,   1.3742634E-03
     +,   1.4481336E-03,   1.5232812E-03,   1.5997131E-03
     +,   1.6775058E-03,   1.7567632E-03,   1.8375671E-03
     +,   1.9199140E-03,   2.0036499E-03,   2.0883987E-03
     +,   2.1735069E-03,   2.2580479E-03,   2.3409056E-03
     +,   2.4209148E-03,   2.4971513E-03,   2.5693157E-03
     +,   2.6382043E-03,   2.7061906E-03,   2.7776225E-03
     +,   2.8590173E-03,   2.9588600E-03,   3.0869395E-03
     +,   3.2531847E-03,   3.4660953E-03,   3.7310142E-03
     +,   4.0486534E-03,   4.4143558E-03,   4.8185475E-03
     +,   5.2484684E-03,   5.6910636E-03,   6.1366479E-03
     +,   6.5823393E-03,   7.0345947E-03,   7.5099436E-03
     +,   8.0330037E-03,   8.6308997E-03,   9.3243383E-03
     +,   1.0118040E-02,   1.0996169E-02,   1.1928155E-02
     +,   1.2884866E-02,   1.3856846E-02,   1.4860297E-02
     +,   1.5921740E-02,   1.7046761E-02,   1.8191710E-02
     +,   1.9257339E-02,   2.0113561E-02,   2.0647308E-02
     +,   2.0811362E-02,   2.0647651E-02,   2.0267172E-02
     +,   1.9793401E-02,   1.9302551E-02,   1.8800762E-02
     +,   1.8251220E-02,   1.7625878E-02,   1.6940942E-02
     +,   1.6253507E-02,   1.5628126E-02,   1.5098920E-02
     +,   1.4649380E-02,   1.4216526E-02,   1.3715443E-02
     +,   1.3072946E-02,   1.2257000E-02,   1.1289829E-02
     +,   1.0239218E-02,   9.1933236E-03,   8.2317283E-03
     +,   7.4050501E-03,   6.7287269E-03,   6.1892164E-03
     +,   5.7565235E-03,   5.3965333E-03,   5.0796461E-03
     +,   4.7849510E-03,   4.5007635E-03,   4.2230147E-03
     +,   3.9527258E-03,   3.6934975E-03,   3.4494540E-03
     +,   3.2238008E-03,   3.0181452E-03,   2.8324293E-03
     +,   2.6652820E-03,   2.5145006E-03,   2.3775850E-03
     +,   2.2520504E-03,   2.1356642E-03,   2.0264622E-03
     +,   1.9227705E-03,   1.8231407E-03,   1.7263715E-03
     +,   1.6314884E-03,   1.5378000E-03,   1.4448997E-03
     +,   1.3526857E-03,   1.2613480E-03,   1.1713066E-03
     +,   1.0831672E-03,   9.9762273E-04,   9.1539882E-04
     +,   8.3716185E-04,   7.6348457E-04,   6.9479179E-04
     +,   6.3135795E-04,   5.7328853E-04,   5.2054803E-04
     +,   4.7296486E-04,   4.3027176E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt106 = Yx/0.186931818181818
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5308025E-05,   3.6026922E-05
     +,   3.6745958E-05,   3.7464608E-05,   3.8182374E-05
     +,   3.8898732E-05,   3.9613176E-05,   4.0325209E-05
     +,   4.1034302E-05,   4.1740004E-05,   4.2441814E-05
     +,   4.3139247E-05,   4.3831860E-05,   4.4519169E-05
     +,   4.5200759E-05,   4.5876204E-05,   4.6545087E-05
     +,   4.7207021E-05,   4.7861642E-05,   4.8508591E-05
     +,   4.9147529E-05,   4.9778166E-05,   5.0400191E-05
     +,   5.1013383E-05,   5.1617459E-05,   5.2212221E-05
     +,   5.2797521E-05,   5.3373151E-05,   5.3939024E-05
     +,   5.4495013E-05,   5.5041095E-05,   5.5577173E-05
     +,   5.6103279E-05,   5.6619443E-05,   5.7125733E-05
     +,   5.7622226E-05,   5.8109075E-05,   5.8586425E-05
     +,   5.9054506E-05,   5.9513517E-05,   5.9963804E-05
     +,   6.0405629E-05,   6.0839382E-05,   6.1265455E-05
     +,   6.1684288E-05,   6.2096355E-05,   6.2502193E-05
     +,   6.2902385E-05,   6.3297557E-05,   6.3688349E-05
     +,   6.4075517E-05,   6.4459797E-05,   6.4842017E-05
     +,   6.5223066E-05,   6.5603839E-05,   6.5985376E-05
     +,   6.6368688E-05,   6.6754859E-05,   6.7145113E-05
     +,   6.7540648E-05,   6.7942776E-05,   6.8352878E-05
     +,   6.8772373E-05,   6.9202775E-05,   6.9645728E-05
     +,   7.0102848E-05,   7.0575959E-05,   7.1066854E-05
     +,   7.1577495E-05,   7.2109870E-05,   7.2666131E-05
     +,   7.3248455E-05,   7.3859221E-05,   7.4500764E-05
     +,   7.5175631E-05,   7.5886477E-05,   7.6636010E-05
     +,   7.7427030E-05,   7.8262514E-05,   7.9145539E-05
     +,   8.0079219E-05,   8.1066828E-05,   8.2111677E-05
     +,   8.3217303E-05,   8.4387117E-05,   8.5624808E-05
     +,   8.6933986E-05,   8.8318433E-05,   8.9781781E-05
     +,   9.1327849E-05,   9.2960472E-05,   9.4683244E-05
     +,   9.6499825E-05,   9.8413817E-05,   1.0042874E-04
     +,   1.0254769E-04,   1.0477394E-04,   1.0711017E-04
     +,   1.0955911E-04,   1.1212279E-04,   1.1480323E-04
     +,   1.1760174E-04,   1.2051939E-04,   1.2355644E-04
     +,   1.2671285E-04,   1.2998795E-04,   1.3338029E-04
     +,   1.3688758E-04,   1.4050712E-04,   1.4423535E-04
     +,   1.4806766E-04,   1.5199909E-04,   1.5602332E-04
     +,   1.6013373E-04,   1.6432229E-04,   1.6858082E-04
     +,   1.7289974E-04,   1.7726926E-04,   1.8167828E-04
     +,   1.8611563E-04,   1.9056934E-04,   1.9502672E-04
     +,   1.9947474E-04,   2.0390013E-04,   2.0828955E-04
     +,   2.1262896E-04,   2.1690504E-04,   2.2110374E-04
     +,   2.2521199E-04,   2.2921637E-04,   2.3310458E-04
     +,   2.3686433E-04,   2.4048447E-04,   2.4395420E-04
     +,   2.4726405E-04,   2.5040546E-04,   2.5337076E-04
     +,   2.5615349E-04,   2.5874871E-04,   2.6115248E-04
     +,   2.6336225E-04,   2.6537685E-04,   2.6719642E-04
     +,   2.6882239E-04,   2.7025765E-04,   2.7150620E-04
     +,   2.7257338E-04,   2.7346556E-04,   2.7419033E-04
     +,   2.7475631E-04,   2.7517296E-04,   2.7545064E-04
     +,   2.7560056E-04,   2.7563461E-04,   2.7556560E-04
     +,   2.7540652E-04,   2.7517177E-04,   2.7487558E-04
     +,   2.7453367E-04,   2.7416230E-04,   2.7377842E-04
     +,   2.7340034E-04,   2.7304763E-04,   2.7274105E-04
     +,   2.7250315E-04,   2.7235853E-04,   2.7233348E-04
     +,   2.7245699E-04,   2.7276075E-04,   2.7327906E-04
     +,   2.7404982E-04,   2.7511467E-04,   2.7651913E-04
     +,   2.7831396E-04,   2.8055531E-04,   2.8330626E-04
     +,   2.8663810E-04,   2.9063181E-04,   2.9538010E-04
     +,   3.0099018E-04,   3.0758607E-04,   3.1531122E-04
     +,   3.2433047E-04,   3.3483398E-04,   3.4703768E-04
     +,   3.6118357E-04,   3.7754039E-04,   3.9640148E-04
     +,   4.1808348E-04,   4.4291766E-04,   4.7125097E-04
     +,   5.0343823E-04,   5.3983612E-04,   5.8079994E-04
     +,   6.2668649E-04,   6.7785144E-04,   7.3464925E-04
     +,   7.9744007E-04,   8.6659531E-04,   9.4250211E-04
     +,   1.0255517E-03,   1.1161385E-03,   1.2146465E-03
     +,   1.3214239E-03,   1.4367239E-03,   1.5606883E-03
     +,   1.6932737E-03,   1.8341942E-03,   1.9828933E-03
     +,   2.1385576E-03,   2.3001865E-03,   2.4667457E-03
     +,   2.6374580E-03,   2.8121911E-03,   2.9918521E-03
     +,   3.1786896E-03,   3.3763857E-03,   3.5897705E-03
     +,   3.8240373E-03,   4.0835720E-03,   4.3707564E-03
     +,   4.6850881E-03,   5.0231870E-03,   5.3801080E-03
     +,   5.7517621E-03,   6.1377916E-03,   6.5434966E-03
     +,   6.9797020E-03,   7.4596396E-03,   7.9939663E-03
     +,   8.5865930E-03,   9.2347693E-03,   9.9340770E-03
     +,   1.0684636E-02,   1.1491762E-02,   1.2358441E-02
     +,   1.3274658E-02,   1.4215457E-02,   1.5153874E-02
     +,   1.6080726E-02,   1.7013740E-02,   1.7984206E-02
     +,   1.9005604E-02,   2.0043850E-02,   2.1012288E-02
     +,   2.1803608E-02,   2.2343626E-02,   2.2627763E-02
     +,   2.2704603E-02,   2.2613810E-02,   2.2336585E-02
     +,   2.1814661E-02,   2.1025797E-02,   2.0038059E-02
     +,   1.8982453E-02,   1.7970275E-02,   1.7036820E-02
     +,   1.6156282E-02,   1.5296565E-02,   1.4455178E-02
     +,   1.3651999E-02,   1.2903322E-02,   1.2208603E-02
     +,   1.1556963E-02,   1.0938185E-02,   1.0345006E-02
     +,   9.7678760E-03,   9.1910791E-03,   8.5961279E-03
     +,   7.9703555E-03,   7.3145414E-03,   6.6446569E-03
     +,   5.9868125E-03,   5.3684898E-03,   4.8104511E-03
     +,   4.3223361E-03,   3.9025247E-03,   3.5415664E-03
     +,   3.2265161E-03,   2.9449312E-03,   2.6871450E-03
     +,   2.4471213E-03,   2.2220025E-03,   2.0111818E-03
     +,   1.8151464E-03,   1.6346389E-03,   1.4700390E-03
     +,   1.3211552E-03,   1.1872526E-03,   1.0671907E-03
     +,   9.5966330E-04,   8.6335122E-04,   7.7706546E-04
     +,   6.9977442E-04,   6.3062087E-04,   5.6887034E-04
     +,   5.1388319E-04,   4.6506265E-04,   4.2184474E-04
     +,   3.8367350E-04,   3.5001212E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt108 = Yx/0.196466666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8484070E-05,   1.9123963E-05
     +,   1.9790225E-05,   2.0483503E-05,   2.1204416E-05
     +,   2.1953545E-05,   2.2731416E-05,   2.3538509E-05
     +,   2.4375229E-05,   2.5241970E-05,   2.6139000E-05
     +,   2.7066551E-05,   2.8024766E-05,   2.9013712E-05
     +,   3.0033361E-05,   3.1083615E-05,   3.2164262E-05
     +,   3.3274984E-05,   3.4415385E-05,   3.5584973E-05
     +,   3.6783091E-05,   3.8009039E-05,   3.9261944E-05
     +,   4.0540901E-05,   4.1844767E-05,   4.3172411E-05
     +,   4.4522523E-05,   4.5893659E-05,   4.7284320E-05
     +,   4.8692869E-05,   5.0117535E-05,   5.1556497E-05
     +,   5.3007800E-05,   5.4469416E-05,   5.5939217E-05
     +,   5.7415004E-05,   5.8894519E-05,   6.0375420E-05
     +,   6.1855368E-05,   6.3331870E-05,   6.4802531E-05
     +,   6.6264860E-05,   6.7716384E-05,   6.9154630E-05
     +,   7.0577145E-05,   7.1981536E-05,   7.3365409E-05
     +,   7.4726486E-05,   7.6062533E-05,   7.7371405E-05
     +,   7.8651079E-05,   7.9899670E-05,   8.1115366E-05
     +,   8.2296610E-05,   8.3441882E-05,   8.4549945E-05
     +,   8.5619664E-05,   8.6650187E-05,   8.7640830E-05
     +,   8.8591070E-05,   8.9500689E-05,   9.0369707E-05
     +,   9.1198301E-05,   9.1986971E-05,   9.2736431E-05
     +,   9.3447612E-05,   9.4121751E-05,   9.4760246E-05
     +,   9.5364783E-05,   9.5937270E-05,   9.6479816E-05
     +,   9.6994714E-05,   9.7484568E-05,   9.7951968E-05
     +,   9.8399869E-05,   9.8831282E-05,   9.9249293E-05
     +,   9.9657198E-05,   1.0005833E-04,   1.0045608E-04
     +,   1.0085388E-04,   1.0125521E-04,   1.0166350E-04
     +,   1.0208215E-04,   1.0251446E-04,   1.0296376E-04
     +,   1.0343308E-04,   1.0392551E-04,   1.0444374E-04
     +,   1.0499051E-04,   1.0556816E-04,   1.0617890E-04
     +,   1.0682456E-04,   1.0750684E-04,   1.0822714E-04
     +,   1.0898645E-04,   1.0978548E-04,   1.1062466E-04
     +,   1.1150409E-04,   1.1242350E-04,   1.1338235E-04
     +,   1.1437971E-04,   1.1541445E-04,   1.1648493E-04
     +,   1.1758942E-04,   1.1872590E-04,   1.1989202E-04
     +,   1.2108516E-04,   1.2230268E-04,   1.2354160E-04
     +,   1.2479885E-04,   1.2607132E-04,   1.2735580E-04
     +,   1.2864896E-04,   1.2994757E-04,   1.3124848E-04
     +,   1.3254843E-04,   1.3384456E-04,   1.3513380E-04
     +,   1.3641370E-04,   1.3768174E-04,   1.3893573E-04
     +,   1.4017377E-04,   1.4139428E-04,   1.4259602E-04
     +,   1.4377807E-04,   1.4493993E-04,   1.4608134E-04
     +,   1.4720268E-04,   1.4830436E-04,   1.4938744E-04
     +,   1.5045315E-04,   1.5150322E-04,   1.5253946E-04
     +,   1.5356416E-04,   1.5457990E-04,   1.5558924E-04
     +,   1.5659502E-04,   1.5760034E-04,   1.5860825E-04
     +,   1.5962175E-04,   1.6064408E-04,   1.6167818E-04
     +,   1.6272713E-04,   1.6379364E-04,   1.6488043E-04
     +,   1.6599000E-04,   1.6712464E-04,   1.6828638E-04
     +,   1.6947718E-04,   1.7069887E-04,   1.7195311E-04
     +,   1.7324148E-04,   1.7456571E-04,   1.7592774E-04
     +,   1.7732965E-04,   1.7877403E-04,   1.8026415E-04
     +,   1.8180416E-04,   1.8339904E-04,   1.8505519E-04
     +,   1.8678039E-04,   1.8858419E-04,   1.9047780E-04
     +,   1.9247492E-04,   1.9459134E-04,   1.9684504E-04
     +,   1.9925676E-04,   2.0184973E-04,   2.0464993E-04
     +,   2.0768553E-04,   2.1098740E-04,   2.1458883E-04
     +,   2.1852566E-04,   2.2283568E-04,   2.2755946E-04
     +,   2.3274023E-04,   2.3842377E-04,   2.4465926E-04
     +,   2.5150026E-04,   2.5900549E-04,   2.6723949E-04
     +,   2.7627387E-04,   2.8618993E-04,   2.9707971E-04
     +,   3.0904592E-04,   3.2220458E-04,   3.3668612E-04
     +,   3.5263551E-04,   3.7020983E-04,   3.8958073E-04
     +,   4.1093113E-04,   4.3445162E-04,   4.6033881E-04
     +,   4.8879447E-04,   5.2002288E-04,   5.5422686E-04
     +,   5.9161009E-04,   6.3238211E-04,   6.7676062E-04
     +,   7.2497624E-04,   7.7727763E-04,   8.3394482E-04
     +,   8.9528784E-04,   9.6163782E-04,   1.0333522E-03
     +,   1.1107940E-03,   1.1943093E-03,   1.2842200E-03
     +,   1.3808258E-03,   1.4844263E-03,   1.5953610E-03
     +,   1.7140936E-03,   1.8413138E-03,   1.9779911E-03
     +,   2.1253782E-03,   2.2849236E-03,   2.4580474E-03
     +,   2.6458034E-03,   2.8484538E-03,   3.0651691E-03
     +,   3.2938370E-03,   3.5311601E-03,   3.7731780E-03
     +,   4.0160473E-03,   4.2570732E-03,   4.4956938E-03
     +,   4.7342386E-03,   4.9781553E-03,   5.2355062E-03
     +,   5.5157361E-03,   5.8279904E-03,   6.1794594E-03
     +,   6.5742913E-03,   7.0135668E-03,   7.4964385E-03
     +,   8.0217067E-03,   8.5888840E-03,   9.1982167E-03
     +,   9.8495670E-03,   1.0541108E-02,   1.1268772E-02
     +,   1.2026709E-02,   1.2808749E-02,   1.3610427E-02
     +,   1.4431207E-02,   1.5276914E-02,   1.6162343E-02
     +,   1.7112792E-02,   1.8157592E-02,   1.9307228E-02
     +,   2.0518653E-02,   2.1676993E-02,   2.2626234E-02
     +,   2.3243247E-02,   2.3499550E-02,   2.3452893E-02
     +,   2.3177646E-02,   2.2713089E-02,   2.2085588E-02
     +,   2.1362938E-02,   2.0654820E-02,   2.0043166E-02
     +,   1.9514909E-02,   1.8963441E-02,   1.8251050E-02
     +,   1.7278994E-02,   1.6027749E-02,   1.4563765E-02
     +,   1.3017957E-02,   1.1542874E-02,   1.0262248E-02
     +,   9.2342431E-03,   8.4451959E-03,   7.8316424E-03
     +,   7.3143397E-03,   6.8262662E-03,   6.3268770E-03
     +,   5.8025178E-03,   5.2594785E-03,   4.7146217E-03
     +,   4.1875425E-03,   3.6950351E-03,   3.2484371E-03
     +,   2.8528310E-03,   2.5079336E-03,   2.2095637E-03
     +,   1.9514554E-03,   1.7268265E-03,   1.5294278E-03
     +,   1.3541952E-03,   1.1973707E-03,   1.0564119E-03
     +,   9.2966628E-04,   8.1608177E-04,   7.1488722E-04
     +,   6.2541023E-04,   5.4692529E-04,   4.7862303E-04
     +,   4.1958917E-04,   3.6885412E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt110 = Yx/0.195844444444444
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6308264E-05,   2.7106322E-05
     +,   2.7923445E-05,   2.8759801E-05,   2.9615563E-05
     +,   3.0490832E-05,   3.1385724E-05,   3.2300275E-05
     +,   3.3234504E-05,   3.4188397E-05,   3.5161895E-05
     +,   3.6154855E-05,   3.7167112E-05,   3.8198454E-05
     +,   3.9248578E-05,   4.0317140E-05,   4.1403746E-05
     +,   4.2507902E-05,   4.3629068E-05,   4.4766639E-05
     +,   4.5919907E-05,   4.7088117E-05,   4.8270398E-05
     +,   4.9465911E-05,   5.0673574E-05,   5.1892359E-05
     +,   5.3121119E-05,   5.4358617E-05,   5.5603541E-05
     +,   5.6854555E-05,   5.8110185E-05,   5.9368933E-05
     +,   6.0629241E-05,   6.1889485E-05,   6.3147963E-05
     +,   6.4402964E-05,   6.5652719E-05,   6.6895394E-05
     +,   6.8129222E-05,   6.9352274E-05,   7.0562746E-05
     +,   7.1758746E-05,   7.2938441E-05,   7.4099960E-05
     +,   7.5241493E-05,   7.6361241E-05,   7.7457458E-05
     +,   7.8528486E-05,   7.9572659E-05,   8.0588426E-05
     +,   8.1574341E-05,   8.2528990E-05,   8.3451087E-05
     +,   8.4339488E-05,   8.5193074E-05,   8.6010972E-05
     +,   8.6792330E-05,   8.7536486E-05,   8.8242901E-05
     +,   8.8911169E-05,   8.9541078E-05,   9.0132540E-05
     +,   9.0685578E-05,   9.1200433E-05,   9.1677510E-05
     +,   9.2117320E-05,   9.2520531E-05,   9.2887989E-05
     +,   9.3220689E-05,   9.3519746E-05,   9.3786432E-05
     +,   9.4022129E-05,   9.4228424E-05,   9.4406918E-05
     +,   9.4559422E-05,   9.4687792E-05,   9.4794057E-05
     +,   9.4880241E-05,   9.4948547E-05,   9.5001204E-05
     +,   9.5040552E-05,   9.5068957E-05,   9.5088835E-05
     +,   9.5102681E-05,   9.5113021E-05,   9.5122370E-05
     +,   9.5133328E-05,   9.5148469E-05,   9.5170355E-05
     +,   9.5201613E-05,   9.5244788E-05,   9.5302494E-05
     +,   9.5377196E-05,   9.5471441E-05,   9.5587704E-05
     +,   9.5728385E-05,   9.5895877E-05,   9.6092452E-05
     +,   9.6320364E-05,   9.6581753E-05,   9.6878684E-05
     +,   9.7213073E-05,   9.7586810E-05,   9.8001590E-05
     +,   9.8459008E-05,   9.8960532E-05,   9.9507430E-05
     +,   1.0010078E-04,   1.0074154E-04,   1.0143049E-04
     +,   1.0216812E-04,   1.0295477E-04,   1.0379047E-04
     +,   1.0467517E-04,   1.0560842E-04,   1.0658958E-04
     +,   1.0761774E-04,   1.0869175E-04,   1.0981020E-04
     +,   1.1097141E-04,   1.1217349E-04,   1.1341426E-04
     +,   1.1469131E-04,   1.1600212E-04,   1.1734396E-04
     +,   1.1871393E-04,   1.2010903E-04,   1.2152617E-04
     +,   1.2296234E-04,   1.2441445E-04,   1.2587960E-04
     +,   1.2735496E-04,   1.2883807E-04,   1.3032657E-04
     +,   1.3181864E-04,   1.3331295E-04,   1.3480865E-04
     +,   1.3630537E-04,   1.3780368E-04,   1.3930490E-04
     +,   1.4081107E-04,   1.4232531E-04,   1.4385159E-04
     +,   1.4539518E-04,   1.4696203E-04,   1.4855951E-04
     +,   1.5019602E-04,   1.5188090E-04,   1.5362466E-04
     +,   1.5543868E-04,   1.5733539E-04,   1.5932793E-04
     +,   1.6142978E-04,   1.6365534E-04,   1.6601903E-04
     +,   1.6853544E-04,   1.7121868E-04,   1.7408282E-04
     +,   1.7714112E-04,   1.8040565E-04,   1.8388758E-04
     +,   1.8759651E-04,   1.9154011E-04,   1.9572407E-04
     +,   2.0015222E-04,   2.0482608E-04,   2.0974463E-04
     +,   2.1490404E-04,   2.2029885E-04,   2.2592115E-04
     +,   2.3176041E-04,   2.3780463E-04,   2.4404045E-04
     +,   2.5045368E-04,   2.5702885E-04,   2.6375116E-04
     +,   2.7060707E-04,   2.7758352E-04,   2.8467010E-04
     +,   2.9185964E-04,   2.9914919E-04,   3.0653997E-04
     +,   3.1403865E-04,   3.2165897E-04,   3.2942175E-04
     +,   3.3735522E-04,   3.4549597E-04,   3.5389047E-04
     +,   3.6259467E-04,   3.7167390E-04,   3.8120433E-04
     +,   3.9127277E-04,   4.0197576E-04,   4.1342003E-04
     +,   4.2572294E-04,   4.3901132E-04,   4.5342004E-04
     +,   4.6909225E-04,   4.8617992E-04,   5.0484366E-04
     +,   5.2525161E-04,   5.4758153E-04,   5.7202583E-04
     +,   5.9879373E-04,   6.2811427E-04,   6.6024729E-04
     +,   6.9548987E-04,   7.3417940E-04,   7.7670492E-04
     +,   8.2351017E-04,   8.7509438E-04,   9.3200186E-04
     +,   9.9480967E-04,   1.0641130E-03,   1.1404912E-03
     +,   1.2244674E-03,   1.3164734E-03,   1.4168145E-03
     +,   1.5256290E-03,   1.6428481E-03,   1.7682040E-03
     +,   1.9012192E-03,   2.0412258E-03,   2.1874220E-03
     +,   2.3389661E-03,   2.4950763E-03,   2.6551676E-03
     +,   2.8190059E-03,   2.9868474E-03,   3.1595156E-03
     +,   3.3383695E-03,   3.5251628E-03,   3.7218083E-03
     +,   3.9300509E-03,   4.1512302E-03,   4.3863617E-03
     +,   4.6365838E-03,   4.9039545E-03,   5.1922142E-03
     +,   5.5068512E-03,   5.8537181E-03,   6.2361560E-03
     +,   6.6518467E-03,   7.0914989E-03,   7.5419233E-03
     +,   7.9945298E-03,   8.4567135E-03,   8.9598671E-03
     +,   9.5559759E-03,   1.0299885E-02,   1.1223692E-02
     +,   1.2317149E-02,   1.3526171E-02,   1.4769719E-02
     +,   1.5966821E-02,   1.7067555E-02,   1.8085970E-02
     +,   1.9117311E-02,   2.0303743E-02,   2.1737885E-02
     +,   2.3369217E-02,   2.5012890E-02,   2.6470510E-02
     +,   2.7638659E-02,   2.8489444E-02,   2.8974527E-02
     +,   2.8998116E-02,   2.8484870E-02,   2.7435429E-02
     +,   2.5910256E-02,   2.4005363E-02,   2.1861708E-02
     +,   1.9660408E-02,   1.7568892E-02,   1.5684506E-02
     +,   1.4028466E-02,   1.2579635E-02,   1.1305375E-02
     +,   1.0170680E-02,   9.1403490E-03,   8.1847645E-03
     +,   7.2875726E-03,   6.4465315E-03,   5.6680236E-03
     +,   4.9593057E-03,   4.3242117E-03,   3.7621832E-03
     +,   3.2696177E-03,   2.8413432E-03,   2.4714326E-03
     +,   2.1537249E-03,   1.8819812E-03,   1.6502027E-03
     +,   1.4527728E-03,   1.2846562E-03,   1.1413769E-03
     +,   1.0190250E-03,   9.1416563E-04,   8.2383602E-04
     +,   7.4550381E-04,   6.7708181E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt112 = Yx/0.199577777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7083696E-05,   1.7537874E-05
     +,   1.8010778E-05,   1.8503144E-05,   1.9015677E-05
     +,   1.9549088E-05,   2.0104057E-05,   2.0681251E-05
     +,   2.1281296E-05,   2.1904825E-05,   2.2552396E-05
     +,   2.3224557E-05,   2.3921786E-05,   2.4644529E-05
     +,   2.5393172E-05,   2.6168045E-05,   2.6969417E-05
     +,   2.7797481E-05,   2.8652363E-05,   2.9534109E-05
     +,   3.0442674E-05,   3.1377942E-05,   3.2339685E-05
     +,   3.3327633E-05,   3.4341323E-05,   3.5380293E-05
     +,   3.6443918E-05,   3.7531481E-05,   3.8642167E-05
     +,   3.9775041E-05,   4.0929062E-05,   4.2103093E-05
     +,   4.3295880E-05,   4.4506072E-05,   4.5732213E-05
     +,   4.6972731E-05,   4.8226018E-05,   4.9490271E-05
     +,   5.0763749E-05,   5.2044466E-05,   5.3330528E-05
     +,   5.4619868E-05,   5.5910419E-05,   5.7200046E-05
     +,   5.8486592E-05,   5.9767903E-05,   6.1041763E-05
     +,   6.2306026E-05,   6.3558509E-05,   6.4797096E-05
     +,   6.6019704E-05,   6.7224304E-05,   6.8408917E-05
     +,   6.9571754E-05,   7.0711001E-05,   7.1825038E-05
     +,   7.2912357E-05,   7.3971649E-05,   7.5001662E-05
     +,   7.6001408E-05,   7.6970056E-05,   7.7907003E-05
     +,   7.8811776E-05,   7.9684185E-05,   8.0524369E-05
     +,   8.1332510E-05,   8.2109174E-05,   8.2855098E-05
     +,   8.3571365E-05,   8.4259205E-05,   8.4920219E-05
     +,   8.5556159E-05,   8.6169144E-05,   8.6761378E-05
     +,   8.7335473E-05,   8.7894186E-05,   8.8440516E-05
     +,   8.8977642E-05,   8.9508940E-05,   9.0037982E-05
     +,   9.0568457E-05,   9.1104237E-05,   9.1649257E-05
     +,   9.2207476E-05,   9.2783026E-05,   9.3379982E-05
     +,   9.4002426E-05,   9.4654431E-05,   9.5339856E-05
     +,   9.6062620E-05,   9.6826443E-05,   9.7634766E-05
     +,   9.8490855E-05,   9.9397766E-05,   1.0035823E-04
     +,   1.0137454E-04,   1.0244876E-04,   1.0358240E-04
     +,   1.0477669E-04,   1.0603217E-04,   1.0734911E-04
     +,   1.0872700E-04,   1.1016503E-04,   1.1166157E-04
     +,   1.1321454E-04,   1.1482131E-04,   1.1647846E-04
     +,   1.1818200E-04,   1.1992745E-04,   1.2170969E-04
     +,   1.2352284E-04,   1.2536073E-04,   1.2721642E-04
     +,   1.2908266E-04,   1.3095148E-04,   1.3281476E-04
     +,   1.3466373E-04,   1.3648967E-04,   1.3828311E-04
     +,   1.4003486E-04,   1.4173544E-04,   1.4337517E-04
     +,   1.4494454E-04,   1.4643418E-04,   1.4783490E-04
     +,   1.4913768E-04,   1.5033397E-04,   1.5141565E-04
     +,   1.5237510E-04,   1.5320530E-04,   1.5389998E-04
     +,   1.5445364E-04,   1.5486157E-04,   1.5512007E-04
     +,   1.5522634E-04,   1.5517883E-04,   1.5497692E-04
     +,   1.5462130E-04,   1.5411388E-04,   1.5345789E-04
     +,   1.5265796E-04,   1.5172013E-04,   1.5065189E-04
     +,   1.4946221E-04,   1.4816178E-04,   1.4676270E-04
     +,   1.4527893E-04,   1.4372602E-04,   1.4212147E-04
     +,   1.4048444E-04,   1.3883605E-04,   1.3719939E-04
     +,   1.3559959E-04,   1.3406384E-04,   1.3262138E-04
     +,   1.3130379E-04,   1.3014500E-04,   1.2918102E-04
     +,   1.2845025E-04,   1.2799368E-04,   1.2785455E-04
     +,   1.2807842E-04,   1.2871328E-04,   1.2980922E-04
     +,   1.3141852E-04,   1.3359539E-04,   1.3639555E-04
     +,   1.3987593E-04,   1.4409462E-04,   1.4911011E-04
     +,   1.5498034E-04,   1.6176215E-04,   1.6951113E-04
     +,   1.7828001E-04,   1.8811706E-04,   1.9906623E-04
     +,   2.1116539E-04,   2.2444371E-04,   2.3892141E-04
     +,   2.5460887E-04,   2.7150425E-04,   2.8959112E-04
     +,   3.0883786E-04,   3.2919768E-04,   3.5060660E-04
     +,   3.7298090E-04,   3.9621844E-04,   4.2019945E-04
     +,   4.4478677E-04,   4.6982267E-04,   4.9513730E-04
     +,   5.2054744E-04,   5.4585852E-04,   5.7087012E-04
     +,   5.9538172E-04,   6.1919849E-04,   6.4213434E-04
     +,   6.6402165E-04,   6.8472052E-04,   7.0412573E-04
     +,   7.2217442E-04,   7.3885755E-04,   7.5422897E-04
     +,   7.6841435E-04,   7.8161719E-04,   7.9413026E-04
     +,   8.0633897E-04,   8.1872346E-04,   8.3186274E-04
     +,   8.4642920E-04,   8.6318085E-04,   8.8294846E-04
     +,   9.0661191E-04,   9.3507406E-04,   9.6922630E-04
     +,   1.0098976E-03,   1.0578124E-03,   1.1135449E-03
     +,   1.1774793E-03,   1.2497732E-03,   1.3303742E-03
     +,   1.4190421E-03,   1.5154140E-03,   1.6191166E-03
     +,   1.7299232E-03,   1.8479226E-03,   1.9736940E-03
     +,   2.1084829E-03,   2.2543275E-03,   2.4140598E-03
     +,   2.5911687E-03,   2.7895167E-03,   3.0128718E-03
     +,   3.2643590E-03,   3.5458354E-03,   3.8575283E-03
     +,   4.1978001E-03,   4.5632487E-03,   4.9491394E-03
     +,   5.3501986E-03,   5.7617128E-03,   6.1809034E-03
     +,   6.6084624E-03,   7.0493841E-03,   7.5122099E-03
     +,   8.0061313E-03,   8.5368147E-03,   9.1032991E-03
     +,   9.6983816E-03,   1.0313404E-02,   1.0944624E-02
     +,   1.1596194E-02,   1.2276568E-02,   1.2989054E-02
     +,   1.3721501E-02,   1.4443440E-02,   1.5119920E-02
     +,   1.5743753E-02,   1.6369466E-02,   1.7117690E-02
     +,   1.8129462E-02,   1.9486548E-02,   2.1149952E-02
     +,   2.2967728E-02,   2.4751388E-02,   2.6349163E-02
     +,   2.7644491E-02,   2.8514914E-02,   2.8857959E-02
     +,   2.8689016E-02,   2.8171493E-02,   2.7486769E-02
     +,   2.6660407E-02,   2.5550598E-02,   2.4024829E-02
     +,   2.2126578E-02,   2.0058298E-02,   1.8032087E-02
     +,   1.6158370E-02,   1.4450908E-02,   1.2886782E-02
     +,   1.1447007E-02,   1.0121145E-02,   8.9013008E-03
     +,   7.7796117E-03,   6.7498088E-03,   5.8074254E-03
     +,   4.9498472E-03,   4.1766036E-03,   3.4890904E-03
     +,   2.8893482E-03,   2.3775466E-03,   1.9501708E-03
     +,   1.5994785E-03,   1.3147899E-03,   1.0843565E-03
     +,   8.9724537E-04,   7.4435177E-04,   6.1872997E-04
     +,   5.1527540E-04,   4.3025802E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt113 = Yx/0.206733333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1430524E-05,   2.1887232E-05
     +,   2.2353041E-05,   2.2828272E-05,   2.3313301E-05
     +,   2.3808519E-05,   2.4314335E-05,   2.4831177E-05
     +,   2.5359519E-05,   2.5899863E-05,   2.6452713E-05
     +,   2.7018637E-05,   2.7598213E-05,   2.8192058E-05
     +,   2.8800832E-05,   2.9425219E-05,   3.0065943E-05
     +,   3.0723768E-05,   3.1399482E-05,   3.2093947E-05
     +,   3.2808024E-05,   3.3542627E-05,   3.4298697E-05
     +,   3.5077272E-05,   3.5879300E-05,   3.6705915E-05
     +,   3.7558169E-05,   3.8437192E-05,   3.9344133E-05
     +,   4.0280152E-05,   4.1246440E-05,   4.2244184E-05
     +,   4.3274606E-05,   4.4338889E-05,   4.5438224E-05
     +,   4.6573801E-05,   4.7746762E-05,   4.8958194E-05
     +,   5.0209212E-05,   5.1500756E-05,   5.2833795E-05
     +,   5.4209177E-05,   5.5627639E-05,   5.7089812E-05
     +,   5.8596208E-05,   6.0147198E-05,   6.1742969E-05
     +,   6.3383573E-05,   6.5068845E-05,   6.6798457E-05
     +,   6.8571804E-05,   7.0388116E-05,   7.2246316E-05
     +,   7.4145188E-05,   7.6083066E-05,   7.8058212E-05
     +,   8.0068487E-05,   8.2111495E-05,   8.4184569E-05
     +,   8.6284716E-05,   8.8408699E-05,   9.0553032E-05
     +,   9.2713773E-05,   9.4886913E-05,   9.7068187E-05
     +,   9.9252888E-05,   1.0143635E-04,   1.0361343E-04
     +,   1.0577909E-04,   1.0792790E-04,   1.1005445E-04
     +,   1.1215312E-04,   1.1421844E-04,   1.1624463E-04
     +,   1.1822607E-04,   1.2015729E-04,   1.2203270E-04
     +,   1.2384684E-04,   1.2559458E-04,   1.2727088E-04
     +,   1.2887092E-04,   1.3039020E-04,   1.3182445E-04
     +,   1.3316983E-04,   1.3442273E-04,   1.3558019E-04
     +,   1.3663937E-04,   1.3759809E-04,   1.3845447E-04
     +,   1.3920727E-04,   1.3985563E-04,   1.4039918E-04
     +,   1.4083808E-04,   1.4117299E-04,   1.4140505E-04
     +,   1.4153586E-04,   1.4156751E-04,   1.4150258E-04
     +,   1.4134389E-04,   1.4109493E-04,   1.4075935E-04
     +,   1.4034132E-04,   1.3984520E-04,   1.3927565E-04
     +,   1.3863765E-04,   1.3793629E-04,   1.3717687E-04
     +,   1.3636499E-04,   1.3550612E-04,   1.3460586E-04
     +,   1.3366992E-04,   1.3270392E-04,   1.3171356E-04
     +,   1.3070436E-04,   1.2968187E-04,   1.2865139E-04
     +,   1.2761830E-04,   1.2658758E-04,   1.2556424E-04
     +,   1.2455306E-04,   1.2355855E-04,   1.2258522E-04
     +,   1.2163727E-04,   1.2071874E-04,   1.1983341E-04
     +,   1.1898511E-04,   1.1817726E-04,   1.1741334E-04
     +,   1.1669652E-04,   1.1602999E-04,   1.1541681E-04
     +,   1.1486001E-04,   1.1436241E-04,   1.1392710E-04
     +,   1.1355687E-04,   1.1325482E-04,   1.1302389E-04
     +,   1.1286719E-04,   1.1278805E-04,   1.1278976E-04
     +,   1.1287595E-04,   1.1305028E-04,   1.1331680E-04
     +,   1.1367964E-04,   1.1414329E-04,   1.1471240E-04
     +,   1.1539202E-04,   1.1618740E-04,   1.1710398E-04
     +,   1.1814768E-04,   1.1932455E-04,   1.2064087E-04
     +,   1.2210310E-04,   1.2371801E-04,   1.2549253E-04
     +,   1.2743348E-04,   1.2954789E-04,   1.3184293E-04
     +,   1.3432580E-04,   1.3700343E-04,   1.3988292E-04
     +,   1.4297142E-04,   1.4627590E-04,   1.4980337E-04
     +,   1.5356124E-04,   1.5755706E-04,   1.6179893E-04
     +,   1.6629517E-04,   1.7105561E-04,   1.7609140E-04
     +,   1.8141494E-04,   1.8704087E-04,   1.9298676E-04
     +,   1.9927333E-04,   2.0592476E-04,   2.1296983E-04
     +,   2.2044282E-04,   2.2838269E-04,   2.3683500E-04
     +,   2.4585199E-04,   2.5549321E-04,   2.6582467E-04
     +,   2.7691943E-04,   2.8885837E-04,   3.0172849E-04
     +,   3.1562164E-04,   3.3063377E-04,   3.4686428E-04
     +,   3.6441279E-04,   3.8337515E-04,   4.0384373E-04
     +,   4.2590222E-04,   4.4962112E-04,   4.7505458E-04
     +,   5.0223916E-04,   5.3118903E-04,   5.6189211E-04
     +,   5.9430982E-04,   6.2838063E-04,   6.6401868E-04
     +,   7.0111599E-04,   7.3955039E-04,   7.7919581E-04
     +,   8.1992964E-04,   8.6163712E-04,   9.0423122E-04
     +,   9.4765803E-04,   9.9189871E-04,   1.0369801E-03
     +,   1.0829786E-03,   1.1300142E-03,   1.1782441E-03
     +,   1.2278572E-03,   1.2790730E-03,   1.3321292E-03
     +,   1.3872761E-03,   1.4447747E-03,   1.5049049E-03
     +,   1.5679534E-03,   1.6342106E-03,   1.7039626E-03
     +,   1.7774672E-03,   1.8549139E-03,   1.9363880E-03
     +,   2.0218275E-03,   2.1109928E-03,   2.2034347E-03
     +,   2.2985260E-03,   2.3955228E-03,   2.4936686E-03
     +,   2.5923508E-03,   2.6913015E-03,   2.7908424E-03
     +,   2.8921117E-03,   2.9972510E-03,   3.1095308E-03
     +,   3.2332735E-03,   3.3735840E-03,   3.5358055E-03
     +,   3.7247932E-03,   3.9440645E-03,   4.1950624E-03
     +,   4.4767852E-03,   4.7861063E-03,   5.1187831E-03
     +,   5.4711928E-03,   5.8424161E-03,   6.2359562E-03
     +,   6.6603492E-03,   7.1280627E-03,   7.6532126E-03
     +,   8.2490668E-03,   8.9267716E-03,   9.6958475E-03
     +,   1.0564316E-02,   1.1534153E-02,   1.2590565E-02
     +,   1.3690276E-02,   1.4762218E-02,   1.5731461E-02
     +,   1.6561477E-02,   1.7287949E-02,   1.8010158E-02
     +,   1.8831236E-02,   1.9783724E-02,   2.0802666E-02
     +,   2.1778425E-02,   2.2648359E-02,   2.3443710E-02
     +,   2.4252335E-02,   2.5140997E-02,   2.6104677E-02
     +,   2.7059615E-02,   2.7859917E-02,   2.8324144E-02
     +,   2.8273493E-02,   2.7576519E-02,   2.6191732E-02
     +,   2.4194943E-02,   2.1774016E-02,   1.9179700E-02
     +,   1.6649587E-02,   1.4341139E-02,   1.2309553E-02
     +,   1.0532921E-02,   8.9628147E-03,   7.5647100E-03
     +,   6.3307057E-03,   5.2681388E-03,   4.3809242E-03
     +,   3.6592090E-03,   3.0796863E-03,   2.6129400E-03
     +,   2.2308072E-03,   1.9109350E-03,   1.6377404E-03
     +,   1.4014434E-03,   1.1961946E-03,   1.0184587E-03
     +,   8.6569163E-04,   7.3562859E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt114 = Yx/0.202222222222222
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3077311E-05,   3.4066488E-05
     +,   3.5070429E-05,   3.6087935E-05,   3.7117679E-05
     +,   3.8158269E-05,   3.9208182E-05,   4.0265793E-05
     +,   4.1329393E-05,   4.2397183E-05,   4.3467298E-05
     +,   4.4537730E-05,   4.5606474E-05,   4.6671412E-05
     +,   4.7730395E-05,   4.8781221E-05,   4.9821650E-05
     +,   5.0849445E-05,   5.1862324E-05,   5.2858035E-05
     +,   5.3834341E-05,   5.4789030E-05,   5.5719916E-05
     +,   5.6624940E-05,   5.7502006E-05,   5.8349247E-05
     +,   5.9164809E-05,   5.9946989E-05,   6.0694216E-05
     +,   6.1405080E-05,   6.2078339E-05,   6.2712912E-05
     +,   6.3307954E-05,   6.3862790E-05,   6.4376982E-05
     +,   6.4850312E-05,   6.5282795E-05,   6.5674692E-05
     +,   6.6026565E-05,   6.6339140E-05,   6.6613502E-05
     +,   6.6850916E-05,   6.7052955E-05,   6.7221430E-05
     +,   6.7358400E-05,   6.7466215E-05,   6.7547400E-05
     +,   6.7604757E-05,   6.7641275E-05,   6.7660156E-05
     +,   6.7664791E-05,   6.7658708E-05,   6.7645618E-05
     +,   6.7629349E-05,   6.7613764E-05,   6.7602879E-05
     +,   6.7600711E-05,   6.7611298E-05,   6.7638677E-05
     +,   6.7686815E-05,   6.7759633E-05,   6.7860914E-05
     +,   6.7994319E-05,   6.8163332E-05,   6.8371250E-05
     +,   6.8621121E-05,   6.8915717E-05,   6.9257527E-05
     +,   6.9648748E-05,   7.0091191E-05,   7.0586313E-05
     +,   7.1135182E-05,   7.1738483E-05,   7.2396404E-05
     +,   7.3108793E-05,   7.3875002E-05,   7.4693970E-05
     +,   7.5564072E-05,   7.6483360E-05,   7.7449440E-05
     +,   7.8459379E-05,   7.9509962E-05,   8.0597412E-05
     +,   8.1717757E-05,   8.2866492E-05,   8.4038948E-05
     +,   8.5230015E-05,   8.6434469E-05,   8.7646775E-05
     +,   8.8861234E-05,   9.0072099E-05,   9.1273469E-05
     +,   9.2459326E-05,   9.3623828E-05,   9.4761148E-05
     +,   9.5865464E-05,   9.6931275E-05,   9.7953132E-05
     +,   9.8925979E-05,   9.9844947E-05,   1.0070563E-04
     +,   1.0150388E-04,   1.0223608E-04,   1.0289902E-04
     +,   1.0349001E-04,   1.0400685E-04,   1.0444788E-04
     +,   1.0481200E-04,   1.0509871E-04,   1.0530807E-04
     +,   1.0544075E-04,   1.0549798E-04,   1.0548158E-04
     +,   1.0539395E-04,   1.0523805E-04,   1.0501734E-04
     +,   1.0473587E-04,   1.0439815E-04,   1.0400914E-04
     +,   1.0357422E-04,   1.0309921E-04,   1.0259021E-04
     +,   1.0205376E-04,   1.0149655E-04,   1.0092552E-04
     +,   1.0034784E-04,   9.9770798E-05,   9.9201759E-05
     +,   9.8648132E-05,   9.8117365E-05,   9.7616772E-05
     +,   9.7153687E-05,   9.6735210E-05,   9.6368320E-05
     +,   9.6059768E-05,   9.5815994E-05,   9.5643212E-05
     +,   9.5547271E-05,   9.5533665E-05,   9.5607429E-05
     +,   9.5773306E-05,   9.6035430E-05,   9.6397554E-05
     +,   9.6862925E-05,   9.7434291E-05,   9.8113800E-05
     +,   9.8903241E-05,   9.9803663E-05,   1.0081568E-04
     +,   1.0193941E-04,   1.0317449E-04,   1.0451997E-04
     +,   1.0597446E-04,   1.0753625E-04,   1.0920327E-04
     +,   1.1097304E-04,   1.1284293E-04,   1.1481019E-04
     +,   1.1687214E-04,   1.1902596E-04,   1.2126938E-04
     +,   1.2360039E-04,   1.2601759E-04,   1.2852023E-04
     +,   1.3110883E-04,   1.3378501E-04,   1.3655181E-04
     +,   1.3941390E-04,   1.4237818E-04,   1.4545371E-04
     +,   1.4865170E-04,   1.5198607E-04,   1.5547374E-04
     +,   1.5913459E-04,   1.6299111E-04,   1.6706920E-04
     +,   1.7139754E-04,   1.7600764E-04,   1.8093329E-04
     +,   1.8621109E-04,   1.9187947E-04,   1.9797821E-04
     +,   2.0454773E-04,   2.1162983E-04,   2.1926640E-04
     +,   2.2749844E-04,   2.3636638E-04,   2.4591055E-04
     +,   2.5617026E-04,   2.6718303E-04,   2.7898690E-04
     +,   2.9162003E-04,   3.0511999E-04,   3.1952537E-04
     +,   3.3487781E-04,   3.5122188E-04,   3.6860464E-04
     +,   3.8707766E-04,   4.0669917E-04,   4.2753309E-04
     +,   4.4964979E-04,   4.7312601E-04,   4.9804867E-04
     +,   5.2451354E-04,   5.5262417E-04,   5.8249559E-04
     +,   6.1425520E-04,   6.4803939E-04,   6.8399619E-04
     +,   7.2228728E-04,   7.6308346E-04,   8.0656272E-04
     +,   8.5290568E-04,   9.0229599E-04,   9.5491100E-04
     +,   1.0109125E-03,   1.0704403E-03,   1.1336080E-03
     +,   1.2004945E-03,   1.2711256E-03,   1.3454859E-03
     +,   1.4235083E-03,   1.5050690E-03,   1.5900010E-03
     +,   1.6781066E-03,   1.7691738E-03,   1.8629954E-03
     +,   1.9594142E-03,   2.0583780E-03,   2.1600074E-03
     +,   2.2646710E-03,   2.3730781E-03,   2.4863866E-03
     +,   2.6062496E-03,   2.7348110E-03,   2.8746515E-03
     +,   3.0285979E-03,   3.1994542E-03,   3.3897057E-03
     +,   3.6013210E-03,   3.8357168E-03,   4.0940130E-03
     +,   4.3776152E-03,   4.6888622E-03,   5.0313473E-03
     +,   5.4094628E-03,   5.8269827E-03,   6.2849796E-03
     +,   6.7798342E-03,   7.3025259E-03,   7.8400997E-03
     +,   8.3783446E-03,   8.9041013E-03,   9.4056213E-03
     +,   9.8714931E-03,   1.0291514E-02,   1.0663284E-02
     +,   1.1003518E-02,   1.1356155E-02,   1.1788071E-02
     +,   1.2370162E-02,   1.3151465E-02,   1.4138318E-02
     +,   1.5287794E-02,   1.6520351E-02,   1.7753335E-02
     +,   1.8942798E-02,   2.0105947E-02,   2.1299675E-02
     +,   2.2567615E-02,   2.3900265E-02,   2.5239747E-02
     +,   2.6510432E-02,   2.7638709E-02,   2.8552959E-02
     +,   2.9182073E-02,   2.9462419E-02,   2.9345356E-02
     +,   2.8800435E-02,   2.7812459E-02,   2.6376033E-02
     +,   2.4501827E-02,   2.2240559E-02,   1.9706488E-02
     +,   1.7066503E-02,   1.4495966E-02,   1.2131521E-02
     +,   1.0052108E-02,   8.2853008E-03,   6.8217251E-03
     +,   5.6283968E-03,   4.6596671E-03,   3.8685936E-03
     +,   3.2155637E-03,   2.6721470E-03,   2.2193852E-03
     +,   1.8439253E-03,   1.5344087E-03,   1.2799923E-03
     +,   1.0703306E-03,   8.9633948E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt115 = Yx/0.2058
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2129909E-05,   3.3100510E-05
     +,   3.4078821E-05,   3.5063833E-05,   3.6054538E-05
     +,   3.7049896E-05,   3.8048853E-05,   3.9050345E-05
     +,   4.0053299E-05,   4.1056668E-05,   4.2059393E-05
     +,   4.3060412E-05,   4.4058706E-05,   4.5053275E-05
     +,   4.6043155E-05,   4.7027384E-05,   4.8005120E-05
     +,   4.8975475E-05,   4.9937698E-05,   5.0891067E-05
     +,   5.1834919E-05,   5.2768672E-05,   5.3691845E-05
     +,   5.4604050E-05,   5.5504916E-05,   5.6394270E-05
     +,   5.7271973E-05,   5.8137997E-05,   5.8992460E-05
     +,   5.9835522E-05,   6.0667542E-05,   6.1488914E-05
     +,   6.2300183E-05,   6.3102008E-05,   6.3895153E-05
     +,   6.4680484E-05,   6.5459026E-05,   6.6231827E-05
     +,   6.7000125E-05,   6.7765155E-05,   6.8528345E-05
     +,   6.9291149E-05,   7.0055103E-05,   7.0821814E-05
     +,   7.1592905E-05,   7.2370123E-05,   7.3155214E-05
     +,   7.3949916E-05,   7.4756055E-05,   7.5575364E-05
     +,   7.6409611E-05,   7.7260549E-05,   7.8129844E-05
     +,   7.9019221E-05,   7.9930091E-05,   8.0864091E-05
     +,   8.1822538E-05,   8.2806706E-05,   8.3817780E-05
     +,   8.4856758E-05,   8.5924527E-05,   8.7021828E-05
     +,   8.8149136E-05,   8.9306901E-05,   9.0495327E-05
     +,   9.1714341E-05,   9.2963899E-05,   9.4243478E-05
     +,   9.5552619E-05,   9.6890486E-05,   9.8256220E-05
     +,   9.9648561E-05,   1.0106625E-04,   1.0250774E-04
     +,   1.0397138E-04,   1.0545535E-04,   1.0695770E-04
     +,   1.0847621E-04,   1.1000867E-04,   1.1155286E-04
     +,   1.1310618E-04,   1.1466623E-04,   1.1623035E-04
     +,   1.1779602E-04,   1.1936048E-04,   1.2092120E-04
     +,   1.2247542E-04,   1.2402068E-04,   1.2555420E-04
     +,   1.2707361E-04,   1.2857642E-04,   1.3006026E-04
     +,   1.3152280E-04,   1.3296188E-04,   1.3437553E-04
     +,   1.3576161E-04,   1.3711851E-04,   1.3844435E-04
     +,   1.3973768E-04,   1.4099700E-04,   1.4222115E-04
     +,   1.4340880E-04,   1.4455910E-04,   1.4567105E-04
     +,   1.4674383E-04,   1.4777697E-04,   1.4876982E-04
     +,   1.4972201E-04,   1.5063326E-04,   1.5150338E-04
     +,   1.5233220E-04,   1.5311989E-04,   1.5386641E-04
     +,   1.5457210E-04,   1.5523717E-04,   1.5586210E-04
     +,   1.5644739E-04,   1.5699363E-04,   1.5750153E-04
     +,   1.5797204E-04,   1.5840604E-04,   1.5880473E-04
     +,   1.5916927E-04,   1.5950113E-04,   1.5980183E-04
     +,   1.6007319E-04,   1.6031708E-04,   1.6053578E-04
     +,   1.6073149E-04,   1.6090691E-04,   1.6106480E-04
     +,   1.6120826E-04,   1.6134058E-04,   1.6146527E-04
     +,   1.6158623E-04,   1.6170746E-04,   1.6183325E-04
     +,   1.6196817E-04,   1.6211707E-04,   1.6228497E-04
     +,   1.6247707E-04,   1.6269885E-04,   1.6295593E-04
     +,   1.6325408E-04,   1.6359925E-04,   1.6399744E-04
     +,   1.6445495E-04,   1.6497786E-04,   1.6557256E-04
     +,   1.6624524E-04,   1.6700238E-04,   1.6785017E-04
     +,   1.6879494E-04,   1.6984294E-04,   1.7100036E-04
     +,   1.7227336E-04,   1.7366793E-04,   1.7519009E-04
     +,   1.7684596E-04,   1.7864120E-04,   1.8058170E-04
     +,   1.8267348E-04,   1.8492238E-04,   1.8733408E-04
     +,   1.8991486E-04,   1.9267081E-04,   1.9560839E-04
     +,   1.9873405E-04,   2.0205487E-04,   2.0557862E-04
     +,   2.0931294E-04,   2.1326666E-04,   2.1744920E-04
     +,   2.2187131E-04,   2.2654411E-04,   2.3148053E-04
     +,   2.3669508E-04,   2.4220296E-04,   2.4802162E-04
     +,   2.5417001E-04,   2.6066930E-04,   2.6754185E-04
     +,   2.7481190E-04,   2.8250518E-04,   2.9064907E-04
     +,   2.9927146E-04,   3.0840019E-04,   3.1806392E-04
     +,   3.2829016E-04,   3.3910424E-04,   3.5052965E-04
     +,   3.6258731E-04,   3.7529375E-04,   3.8866070E-04
     +,   4.0269695E-04,   4.1740687E-04,   4.3278994E-04
     +,   4.4884326E-04,   4.6556315E-04,   4.8294791E-04
     +,   5.0099759E-04,   5.1971863E-04,   5.3912867E-04
     +,   5.5925857E-04,   5.8015372E-04,   6.0188025E-04
     +,   6.2452623E-04,   6.4819981E-04,   6.7303271E-04
     +,   6.9917861E-04,   7.2681246E-04,   7.5612630E-04
     +,   7.8732625E-04,   8.2063884E-04,   8.5630768E-04
     +,   8.9459569E-04,   9.3579607E-04,   9.8024460E-04
     +,   1.0283297E-03,   1.0805044E-03,   1.1373027E-03
     +,   1.1993401E-03,   1.2673060E-03,   1.3419444E-03
     +,   1.4240263E-03,   1.5142962E-03,   1.6133992E-03
     +,   1.7218117E-03,   1.8397779E-03,   1.9672324E-03
     +,   2.1037401E-03,   2.2484744E-03,   2.4002402E-03
     +,   2.5575161E-03,   2.7185432E-03,   2.8815283E-03
     +,   3.0448553E-03,   3.2073834E-03,   3.3688641E-03
     +,   3.5304215E-03,   3.6951089E-03,   3.8684423E-03
     +,   4.0587657E-03,   4.2772642E-03,   4.5372536E-03
     +,   4.8526651E-03,   5.2356962E-03,   5.6939474E-03
     +,   6.2274509E-03,   6.8262834E-03,   7.4696811E-03
     +,   8.1267934E-03,   8.7596364E-03,   9.3283216E-03
     +,   9.7983899E-03,   1.0149119E-02,   1.0381541E-02
     +,   1.0523030E-02,   1.0625629E-02,   1.0757009E-02
     +,   1.0986783E-02,   1.1375392E-02,   1.1970536E-02
     +,   1.2809544E-02,   1.3918450E-02,   1.5300916E-02
     +,   1.6918348E-02,   1.8674415E-02,   2.0420806E-02
     +,   2.1997752E-02,   2.3301991E-02,   2.4345623E-02
     +,   2.5256177E-02,   2.6203038E-02,   2.7289994E-02
     +,   2.8479772E-02,   2.9595457E-02,   3.0395629E-02
     +,   3.0679043E-02,   3.0355658E-02,   2.9450808E-02
     +,   2.8059060E-02,   2.6294192E-02,   2.4265382E-02
     +,   2.2069471E-02,   1.9782834E-02,   1.7452516E-02
     +,   1.5105989E-02,   1.2780424E-02,   1.0545366E-02
     +,   8.4961485E-03,   6.7198714E-03,   5.2629318E-03
     +,   4.1202777E-03,   3.2488701E-03,   2.5897957E-03
     +,   2.0868704E-03,   1.6955591E-03,   1.3846117E-03
     +,   1.1334842E-03,   9.2894264E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt116 = Yx/0.213266666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt1168(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8525465E-05,   2.9282586E-05
     +,   3.0049641E-05,   3.0826202E-05,   3.1611838E-05
     +,   3.2406107E-05,   3.3208551E-05,   3.4018696E-05
     +,   3.4836019E-05,   3.5660072E-05,   3.6490328E-05
     +,   3.7326274E-05,   3.8167400E-05,   3.9013190E-05
     +,   3.9863135E-05,   4.0716732E-05,   4.1573476E-05
     +,   4.2432879E-05,   4.3294469E-05,   4.4157798E-05
     +,   4.5022432E-05,   4.5887955E-05,   4.6753954E-05
     +,   4.7620124E-05,   4.8486083E-05,   4.9351598E-05
     +,   5.0216357E-05,   5.1080195E-05,   5.1942920E-05
     +,   5.2804407E-05,   5.3664578E-05,   5.4523403E-05
     +,   5.5380915E-05,   5.6237164E-05,   5.7092304E-05
     +,   5.7946494E-05,   5.8799982E-05,   5.9653015E-05
     +,   6.0506016E-05,   6.1359300E-05,   6.2213352E-05
     +,   6.3068677E-05,   6.3925821E-05,   6.4785367E-05
     +,   6.5647946E-05,   6.6514258E-05,   6.7385008E-05
     +,   6.8260946E-05,   6.9142858E-05,   7.0031521E-05
     +,   7.0927803E-05,   7.1832481E-05,   7.2746407E-05
     +,   7.3670461E-05,   7.4605414E-05,   7.5552154E-05
     +,   7.6511416E-05,   7.7484023E-05,   7.8470694E-05
     +,   7.9472113E-05,   8.0488964E-05,   8.1521830E-05
     +,   8.2571198E-05,   8.3637555E-05,   8.4721309E-05
     +,   8.5822714E-05,   8.6942040E-05,   8.8079330E-05
     +,   8.9234658E-05,   9.0407877E-05,   9.1598842E-05
     +,   9.2807190E-05,   9.4032592E-05,   9.5274379E-05
     +,   9.6531985E-05,   9.7804659E-05,   9.9091456E-05
     +,   1.0039136E-04,   1.0170330E-04,   1.0302610E-04
     +,   1.0435835E-04,   1.0569874E-04,   1.0704564E-04
     +,   1.0839757E-04,   1.0975280E-04,   1.1110964E-04
     +,   1.1246625E-04,   1.1382083E-04,   1.1517148E-04
     +,   1.1651633E-04,   1.1785349E-04,   1.1918101E-04
     +,   1.2049695E-04,   1.2179945E-04,   1.2308675E-04
     +,   1.2435690E-04,   1.2560829E-04,   1.2683914E-04
     +,   1.2804796E-04,   1.2923313E-04,   1.3039334E-04
     +,   1.3152727E-04,   1.3263372E-04,   1.3371167E-04
     +,   1.3476025E-04,   1.3577870E-04,   1.3676635E-04
     +,   1.3772277E-04,   1.3864767E-04,   1.3954096E-04
     +,   1.4040268E-04,   1.4123303E-04,   1.4203244E-04
     +,   1.4280144E-04,   1.4354085E-04,   1.4425161E-04
     +,   1.4493489E-04,   1.4559206E-04,   1.4622460E-04
     +,   1.4683434E-04,   1.4742328E-04,   1.4799363E-04
     +,   1.4854771E-04,   1.4908830E-04,   1.4961838E-04
     +,   1.5014102E-04,   1.5065981E-04,   1.5117839E-04
     +,   1.5170094E-04,   1.5223182E-04,   1.5277584E-04
     +,   1.5333803E-04,   1.5392389E-04,   1.5453933E-04
     +,   1.5519060E-04,   1.5588451E-04,   1.5662826E-04
     +,   1.5742936E-04,   1.5829600E-04,   1.5923682E-04
     +,   1.6026088E-04,   1.6137767E-04,   1.6259724E-04
     +,   1.6393015E-04,   1.6538725E-04,   1.6697991E-04
     +,   1.6871993E-04,   1.7061942E-04,   1.7269063E-04
     +,   1.7494636E-04,   1.7739942E-04,   1.8006285E-04
     +,   1.8294954E-04,   1.8607269E-04,   1.8944526E-04
     +,   1.9308012E-04,   1.9698965E-04,   2.0118630E-04
     +,   2.0568212E-04,   2.1048833E-04,   2.1561611E-04
     +,   2.2107606E-04,   2.2687795E-04,   2.3303082E-04
     +,   2.3954354E-04,   2.4642417E-04,   2.5368005E-04
     +,   2.6131724E-04,   2.6934207E-04,   2.7775991E-04
     +,   2.8657523E-04,   2.9579113E-04,   3.0541091E-04
     +,   3.1543712E-04,   3.2586991E-04,   3.3670952E-04
     +,   3.4795463E-04,   3.5960221E-04,   3.7164686E-04
     +,   3.8408235E-04,   3.9690000E-04,   4.1008767E-04
     +,   4.2363117E-04,   4.3751352E-04,   4.5171595E-04
     +,   4.6621609E-04,   4.8098940E-04,   4.9601210E-04
     +,   5.1125977E-04,   5.2670884E-04,   5.4234068E-04
     +,   5.5814389E-04,   5.7411450E-04,   5.9026177E-04
     +,   6.0661248E-04,   6.2321266E-04,   6.4013118E-04
     +,   6.5746304E-04,   6.7533262E-04,   6.9389533E-04
     +,   7.1333250E-04,   7.3385442E-04,   7.5569289E-04
     +,   7.7909743E-04,   8.0431986E-04,   8.3161111E-04
     +,   8.6120493E-04,   8.9330407E-04,   9.2806737E-04
     +,   9.6560339E-04,   1.0059607E-03,   1.0491197E-03
     +,   1.0949989E-03,   1.1434635E-03,   1.1943406E-03
     +,   1.2474294E-03,   1.3025304E-03,   1.3594736E-03
     +,   1.4181352E-03,   1.4784563E-03,   1.5404628E-03
     +,   1.6042656E-03,   1.6700487E-03,   1.7380641E-03
     +,   1.8086128E-03,   1.8820384E-03,   1.9587269E-03
     +,   2.0391529E-03,   2.1239594E-03,   2.2140867E-03
     +,   2.3109028E-03,   2.4163651E-03,   2.5331047E-03
     +,   2.6643900E-03,   2.8138866E-03,   2.9852770E-03
     +,   3.1816731E-03,   3.4050243E-03,   3.6557063E-03
     +,   3.9325431E-03,   4.2333147E-03,   4.5558061E-03
     +,   4.8990864E-03,   5.2645281E-03,   5.6557166E-03
     +,   6.0769049E-03,   6.5300479E-03,   7.0112105E-03
     +,   7.5079822E-03,   7.9995068E-03,   8.4606064E-03
     +,   8.8689411E-03,   9.2132613E-03,   9.4994260E-03
     +,   9.7513469E-03,   1.0006496E-02,   1.0308036E-02
     +,   1.0696739E-02,   1.1204459E-02,   1.1847718E-02
     +,   1.2620249E-02,   1.3486627E-02,   1.4385794E-02
     +,   1.5252128E-02,   1.6051084E-02,   1.6808864E-02
     +,   1.7609155E-02,   1.8548427E-02,   1.9675059E-02
     +,   2.0952787E-02,   2.2274587E-02,   2.3518408E-02
     +,   2.4610298E-02,   2.5554638E-02,   2.6409136E-02
     +,   2.7219955E-02,   2.7962346E-02,   2.8529808E-02
     +,   2.8781647E-02,   2.8610084E-02,   2.7976891E-02
     +,   2.6900331E-02,   2.5421314E-02,   2.3586206E-02
     +,   2.1454943E-02,   1.9116672E-02,   1.6690094E-02
     +,   1.4305606E-02,   1.2078929E-02,   1.0089098E-02
     +,   8.3719436E-03,   6.9261431E-03,   5.7272171E-03
     +,   4.7401227E-03,   3.9287345E-03,   3.2604486E-03
     +,   2.7083755E-03,   2.2512991E-03,   1.8730067E-03
     +,   1.5609352E-03,   1.3050230E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt1168 = Yx/0.219644444444444
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8188484E-05,   2.9130129E-05
     +,   3.0095418E-05,   3.1084764E-05,   3.2098560E-05
     +,   3.3137207E-05,   3.4201083E-05,   3.5290584E-05
     +,   3.6406065E-05,   3.7547929E-05,   3.8716509E-05
     +,   3.9912142E-05,   4.1135143E-05,   4.2385807E-05
     +,   4.3664411E-05,   4.4971184E-05,   4.6306355E-05
     +,   4.7670055E-05,   4.9062462E-05,   5.0483646E-05
     +,   5.1933672E-05,   5.3412510E-05,   5.4920114E-05
     +,   5.6456414E-05,   5.8021164E-05,   5.9614209E-05
     +,   6.1235245E-05,   6.2883890E-05,   6.4559754E-05
     +,   6.6262335E-05,   6.7991081E-05,   6.9745423E-05
     +,   7.1524621E-05,   7.3327945E-05,   7.5154639E-05
     +,   7.7003788E-05,   7.8874546E-05,   8.0765887E-05
     +,   8.2676903E-05,   8.4606501E-05,   8.6553664E-05
     +,   8.8517314E-05,   9.0496367E-05,   9.2489747E-05
     +,   9.4496398E-05,   9.6515265E-05,   9.8545366E-05
     +,   1.0058568E-04,   1.0263536E-04,   1.0469352E-04
     +,   1.0675942E-04,   1.0883236E-04,   1.1091174E-04
     +,   1.1299718E-04,   1.1508819E-04,   1.1718468E-04
     +,   1.1928647E-04,   1.2139357E-04,   1.2350615E-04
     +,   1.2562456E-04,   1.2774908E-04,   1.2988040E-04
     +,   1.3201903E-04,   1.3416584E-04,   1.3632173E-04
     +,   1.3848749E-04,   1.4066428E-04,   1.4285295E-04
     +,   1.4505477E-04,   1.4727059E-04,   1.4950160E-04
     +,   1.5174848E-04,   1.5401232E-04,   1.5629367E-04
     +,   1.5859309E-04,   1.6091100E-04,   1.6324742E-04
     +,   1.6560212E-04,   1.6797461E-04,   1.7036425E-04
     +,   1.7276967E-04,   1.7518930E-04,   1.7762111E-04
     +,   1.8006285E-04,   1.8251134E-04,   1.8496334E-04
     +,   1.8741490E-04,   1.8986197E-04,   1.9229938E-04
     +,   1.9472204E-04,   1.9712441E-04,   1.9950021E-04
     +,   2.0184289E-04,   2.0414575E-04,   2.0640167E-04
     +,   2.0860325E-04,   2.1074287E-04,   2.1281283E-04
     +,   2.1480556E-04,   2.1671316E-04,   2.1852819E-04
     +,   2.2024311E-04,   2.2185070E-04,   2.2334421E-04
     +,   2.2471711E-04,   2.2596373E-04,   2.2707861E-04
     +,   2.2805705E-04,   2.2889524E-04,   2.2959006E-04
     +,   2.3013941E-04,   2.3054189E-04,   2.3079738E-04
     +,   2.3090655E-04,   2.3087129E-04,   2.3069450E-04
     +,   2.3038016E-04,   2.2993353E-04,   2.2936080E-04
     +,   2.2866939E-04,   2.2786777E-04,   2.2696536E-04
     +,   2.2597275E-04,   2.2490147E-04,   2.2376385E-04
     +,   2.2257322E-04,   2.2134327E-04,   2.2008907E-04
     +,   2.1882568E-04,   2.1756908E-04,   2.1633554E-04
     +,   2.1514170E-04,   2.1400445E-04,   2.1294103E-04
     +,   2.1196847E-04,   2.1110407E-04,   2.1036490E-04
     +,   2.0976804E-04,   2.0933013E-04,   2.0906773E-04
     +,   2.0899679E-04,   2.0913300E-04,   2.0949153E-04
     +,   2.1008692E-04,   2.1093327E-04,   2.1204387E-04
     +,   2.1343156E-04,   2.1510817E-04,   2.1708489E-04
     +,   2.1937220E-04,   2.2197980E-04,   2.2491644E-04
     +,   2.2818964E-04,   2.3180657E-04,   2.3577326E-04
     +,   2.4009438E-04,   2.4477366E-04,   2.4981389E-04
     +,   2.5521684E-04,   2.6098249E-04,   2.6710992E-04
     +,   2.7359714E-04,   2.8044012E-04,   2.8763368E-04
     +,   2.9517102E-04,   3.0304465E-04,   3.1124454E-04
     +,   3.1975927E-04,   3.2857631E-04,   3.3768170E-04
     +,   3.4705983E-04,   3.5669329E-04,   3.6656435E-04
     +,   3.7665432E-04,   3.8694288E-04,   3.9740995E-04
     +,   4.0803550E-04,   4.1879906E-04,   4.2968060E-04
     +,   4.4066220E-04,   4.5172751E-04,   4.6286121E-04
     +,   4.7405178E-04,   4.8529133E-04,   4.9657637E-04
     +,   5.0790783E-04,   5.1929220E-04,   5.3074345E-04
     +,   5.4228288E-04,   5.5393885E-04,   5.6575023E-04
     +,   5.7776482E-04,   5.9004169E-04,   6.0265081E-04
     +,   6.1567564E-04,   6.2921463E-04,   6.4337911E-04
     +,   6.5829937E-04,   6.7412423E-04,   6.9102301E-04
     +,   7.0918805E-04,   7.2883395E-04,   7.5020239E-04
     +,   7.7356031E-04,   7.9919561E-04,   8.2741858E-04
     +,   8.5855566E-04,   8.9293951E-04,   9.3090744E-04
     +,   9.7279658E-04,   1.0189441E-03,   1.0696861E-03
     +,   1.1253782E-03,   1.1864221E-03,   1.2533003E-03
     +,   1.3266176E-03,   1.4071513E-03,   1.4959059E-03
     +,   1.5941382E-03,   1.7033477E-03,   1.8252615E-03
     +,   1.9617288E-03,   2.1145833E-03,   2.2854549E-03
     +,   2.4755690E-03,   2.6855352E-03,   2.9151365E-03
     +,   3.1632318E-03,   3.4277313E-03,   3.7056329E-03
     +,   3.9931373E-03,   4.2859023E-03,   4.5793275E-03
     +,   4.8689484E-03,   5.1508904E-03,   5.4224608E-03
     +,   5.6826579E-03,   5.9325891E-03,   6.1754989E-03
     +,   6.4163445E-03,   6.6607315E-03,   6.9134664E-03
     +,   7.1771853E-03,   7.4515846E-03,   7.7336798E-03
     +,   8.0191875E-03,   8.3045671E-03,   8.5887006E-03
     +,   8.8734273E-03,   9.1624642E-03,   9.4598448E-03
     +,   9.7686602E-03,   1.0091445E-02,   1.0431958E-02
     +,   1.0796814E-02,   1.1195213E-02,   1.1636004E-02
     +,   1.2122739E-02,   1.2649117E-02,   1.3197146E-02
     +,   1.3741063E-02,   1.4258557E-02,   1.4747337E-02
     +,   1.5238522E-02,   1.5793808E-02,   1.6478250E-02
     +,   1.7317342E-02,   1.8265661E-02,   1.9215256E-02
     +,   2.0048074E-02,   2.0701980E-02,   2.1204818E-02
     +,   2.1650987E-02,   2.2137111E-02,   2.2703828E-02
     +,   2.3320064E-02,   2.3908220E-02,   2.4376674E-02
     +,   2.4634734E-02,   2.4594279E-02,   2.4177892E-02
     +,   2.3339765E-02,   2.2085477E-02,   2.0476121E-02
     +,   1.8614534E-02,   1.6623365E-02,   1.4622753E-02
     +,   1.2712772E-02,   1.0962297E-02,   9.4055617E-03
     +,   8.0473479E-03,   6.8726363E-03,   5.8576483E-03
     +,   4.9778335E-03,   4.2127506E-03,   3.5471637E-03
     +,   2.9704173E-03,   2.4744796E-03,   2.0524068E-03
     +,   1.6971022E-03,   1.4010631E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt118 = Yx/0.2226
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0920581E-05,   2.1363212E-05
     +,   2.1806623E-05,   2.2250508E-05,   2.2694574E-05
     +,   2.3138538E-05,   2.3582126E-05,   2.4025067E-05
     +,   2.4467099E-05,   2.4907991E-05,   2.5347512E-05
     +,   2.5785446E-05,   2.6221598E-05,   2.6655794E-05
     +,   2.7087874E-05,   2.7517695E-05,   2.7945151E-05
     +,   2.8370139E-05,   2.8792590E-05,   2.9212464E-05
     +,   2.9629718E-05,   3.0044377E-05,   3.0456429E-05
     +,   3.0865962E-05,   3.1273026E-05,   3.1677722E-05
     +,   3.2080163E-05,   3.2480501E-05,   3.2878885E-05
     +,   3.3275501E-05,   3.3670560E-05,   3.4064276E-05
     +,   3.4456869E-05,   3.4848606E-05,   3.5239751E-05
     +,   3.5630554E-05,   3.6021313E-05,   3.6412304E-05
     +,   3.6803831E-05,   3.7196154E-05,   3.7589594E-05
     +,   3.7984413E-05,   3.8380898E-05,   3.8779326E-05
     +,   3.9179940E-05,   3.9582985E-05,   3.9988703E-05
     +,   4.0397299E-05,   4.0808951E-05,   4.1223844E-05
     +,   4.1642114E-05,   4.2063901E-05,   4.2489282E-05
     +,   4.2918346E-05,   4.3351123E-05,   4.3787666E-05
     +,   4.4227956E-05,   4.4671975E-05,   4.5119679E-05
     +,   4.5571003E-05,   4.6025889E-05,   4.6484252E-05
     +,   4.6945959E-05,   4.7410951E-05,   4.7879155E-05
     +,   4.8350434E-05,   4.8824775E-05,   4.9302103E-05
     +,   4.9782426E-05,   5.0265746E-05,   5.0752165E-05
     +,   5.1241776E-05,   5.1734809E-05,   5.2231509E-05
     +,   5.2732223E-05,   5.3237432E-05,   5.3747644E-05
     +,   5.4263499E-05,   5.4785785E-05,   5.5315413E-05
     +,   5.5853368E-05,   5.6400844E-05,   5.6959107E-05
     +,   5.7529629E-05,   5.8113979E-05,   5.8713886E-05
     +,   5.9331218E-05,   5.9968013E-05,   6.0626353E-05
     +,   6.1308565E-05,   6.2016981E-05,   6.2754109E-05
     +,   6.3522413E-05,   6.4324580E-05,   6.5163287E-05
     +,   6.6041197E-05,   6.6960980E-05,   6.7925292E-05
     +,   6.8936766E-05,   6.9997885E-05,   7.1111099E-05
     +,   7.2278621E-05,   7.3502611E-05,   7.4784912E-05
     +,   7.6127209E-05,   7.7530989E-05,   7.8997386E-05
     +,   8.0527163E-05,   8.2120969E-05,   8.3779058E-05
     +,   8.5501248E-05,   8.7287262E-05,   8.9136192E-05
     +,   9.1047179E-05,   9.3018723E-05,   9.5049349E-05
     +,   9.7137170E-05,   9.9280260E-05,   1.0147635E-04
     +,   1.0372332E-04,   1.0601898E-04,   1.0836110E-04
     +,   1.1074757E-04,   1.1317668E-04,   1.1564697E-04
     +,   1.1815719E-04,   1.2070689E-04,   1.2329593E-04
     +,   1.2592507E-04,   1.2859567E-04,   1.3131020E-04
     +,   1.3407170E-04,   1.3688470E-04,   1.3975427E-04
     +,   1.4268709E-04,   1.4569085E-04,   1.4877430E-04
     +,   1.5194736E-04,   1.5522118E-04,   1.5860822E-04
     +,   1.6212164E-04,   1.6577540E-04,   1.6958473E-04
     +,   1.7356525E-04,   1.7773283E-04,   1.8210390E-04
     +,   1.8669489E-04,   1.9152174E-04,   1.9659978E-04
     +,   2.0194378E-04,   2.0756743E-04,   2.1348274E-04
     +,   2.1969966E-04,   2.2622666E-04,   2.3306967E-04
     +,   2.4023162E-04,   2.4771254E-04,   2.5550960E-04
     +,   2.6361697E-04,   2.7202419E-04,   2.8071826E-04
     +,   2.8968291E-04,   2.9889747E-04,   3.0833803E-04
     +,   3.1797809E-04,   3.2778867E-04,   3.3773712E-04
     +,   3.4778909E-04,   3.5790939E-04,   3.6806238E-04
     +,   3.7821103E-04,   3.8831998E-04,   3.9835577E-04
     +,   4.0828812E-04,   4.1808980E-04,   4.2773984E-04
     +,   4.3722376E-04,   4.4653469E-04,   4.5567544E-04
     +,   4.6465991E-04,   4.7351478E-04,   4.8227960E-04
     +,   4.9100869E-04,   4.9977307E-04,   5.0866068E-04
     +,   5.1777565E-04,   5.2724004E-04,   5.3719291E-04
     +,   5.4779038E-04,   5.5920234E-04,   5.7161303E-04
     +,   5.8521872E-04,   6.0022261E-04,   6.1683333E-04
     +,   6.3526235E-04,   6.5571914E-04,   6.7840499E-04
     +,   7.0351147E-04,   7.3121500E-04,   7.6167629E-04
     +,   7.9503038E-04,   8.3139108E-04,   8.7085005E-04
     +,   9.1347954E-04,   9.5933006E-04,   1.0084481E-03
     +,   1.0608798E-03,   1.1166786E-03,   1.1759158E-03
     +,   1.2386931E-03,   1.3051376E-03,   1.3753895E-03
     +,   1.4495855E-03,   1.5278305E-03,   1.6101551E-03
     +,   1.6964610E-03,   1.7864916E-03,   1.8798189E-03
     +,   1.9758621E-03,   2.0739478E-03,   2.1734776E-03
     +,   2.2741018E-03,   2.3759759E-03,   2.4800005E-03
     +,   2.5880241E-03,   2.7029070E-03,   2.8283997E-03
     +,   2.9688124E-03,   3.1284830E-03,   3.3110874E-03
     +,   3.5189462E-03,   3.7524879E-03,   4.0100589E-03
     +,   4.2880890E-03,   4.5816996E-03,   4.8857392E-03
     +,   5.1959413E-03,   5.5100494E-03,   5.8285766E-03
     +,   6.1548757E-03,   6.4940234E-03,   6.8505933E-03
     +,   7.2258674E-03,   7.6156161E-03,   8.0100987E-03
     +,   8.3971210E-03,   8.7676924E-03,   9.1221547E-03
     +,   9.4735743E-03,   9.8462980E-03,   1.0269395E-02
     +,   1.0766828E-02,   1.1348749E-02,   1.2008549E-02
     +,   1.2727645E-02,   1.3484124E-02,   1.4257605E-02
     +,   1.5026386E-02,   1.5761707E-02,   1.6429605E-02
     +,   1.7003205E-02,   1.7475683E-02,   1.7859263E-02
     +,   1.8169682E-02,   1.8411312E-02,   1.8580487E-02
     +,   1.8688150E-02,   1.8782794E-02,   1.8948236E-02
     +,   1.9268855E-02,   1.9780593E-02,   2.0443244E-02
     +,   2.1157209E-02,   2.1814102E-02,   2.2344178E-02
     +,   2.2729188E-02,   2.2981983E-02,   2.3113932E-02
     +,   2.3108948E-02,   2.2912418E-02,   2.2443946E-02
     +,   2.1634139E-02,   2.0463657E-02,   1.8977009E-02
     +,   1.7263569E-02,   1.5427627E-02,   1.3566299E-02
     +,   1.1761534E-02,   1.0077874E-02,   8.5597355E-03
     +,   7.2296737E-03,   6.0889907E-03,   5.1234681E-03
     +,   4.3106694E-03,   3.6270549E-03,   3.0517566E-03
     +,   2.5678710E-03,   2.1617166E-03,   1.8219388E-03
     +,   1.5386282E-03,   1.3030376E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt119 = Yx/0.224155555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1927037E-05,   3.2715223E-05
     +,   3.3523320E-05,   3.4351917E-05,   3.5201625E-05
     +,   3.6073037E-05,   3.6966725E-05,   3.7883248E-05
     +,   3.8823149E-05,   3.9786944E-05,   4.0775125E-05
     +,   4.1788153E-05,   4.2826414E-05,   4.3890290E-05
     +,   4.4980101E-05,   4.6096131E-05,   4.7238576E-05
     +,   4.8407608E-05,   4.9603299E-05,   5.0825685E-05
     +,   5.2074720E-05,   5.3350268E-05,   5.4652101E-05
     +,   5.5979996E-05,   5.7333491E-05,   5.8712201E-05
     +,   6.0115548E-05,   6.1542887E-05,   6.2993509E-05
     +,   6.4466549E-05,   6.5961132E-05,   6.7476227E-05
     +,   6.9010726E-05,   7.0563430E-05,   7.2133094E-05
     +,   7.3718315E-05,   7.5317657E-05,   7.6929602E-05
     +,   7.8552577E-05,   8.0184807E-05,   8.1824670E-05
     +,   8.3470295E-05,   8.5119886E-05,   8.6771492E-05
     +,   8.8423185E-05,   9.0073016E-05,   9.1718954E-05
     +,   9.3358976E-05,   9.4991068E-05,   9.6613199E-05
     +,   9.8223303E-05,   9.9819423E-05,   1.0139948E-04
     +,   1.0296160E-04,   1.0450378E-04,   1.0602419E-04
     +,   1.0752095E-04,   1.0899234E-04,   1.1043659E-04
     +,   1.1185212E-04,   1.1323737E-04,   1.1459090E-04
     +,   1.1591128E-04,   1.1719723E-04,   1.1844769E-04
     +,   1.1966152E-04,   1.2083781E-04,   1.2197566E-04
     +,   1.2307447E-04,   1.2413354E-04,   1.2515251E-04
     +,   1.2613094E-04,   1.2706875E-04,   1.2796573E-04
     +,   1.2882204E-04,   1.2963780E-04,   1.3041342E-04
     +,   1.3114921E-04,   1.3184587E-04,   1.3250414E-04
     +,   1.3312481E-04,   1.3370891E-04,   1.3425748E-04
     +,   1.3477184E-04,   1.3525336E-04,   1.3570359E-04
     +,   1.3612409E-04,   1.3651662E-04,   1.3688314E-04
     +,   1.3722555E-04,   1.3754600E-04,   1.3784676E-04
     +,   1.3813014E-04,   1.3839855E-04,   1.3865459E-04
     +,   1.3890090E-04,   1.3914016E-04,   1.3937516E-04
     +,   1.3960891E-04,   1.3984420E-04,   1.4008406E-04
     +,   1.4033151E-04,   1.4058965E-04,   1.4086148E-04
     +,   1.4115013E-04,   1.4145859E-04,   1.4178987E-04
     +,   1.4214691E-04,   1.4253259E-04,   1.4294966E-04
     +,   1.4340080E-04,   1.4388855E-04,   1.4441516E-04
     +,   1.4498294E-04,   1.4559373E-04,   1.4624931E-04
     +,   1.4695121E-04,   1.4770064E-04,   1.4849860E-04
     +,   1.4934568E-04,   1.5024243E-04,   1.5118885E-04
     +,   1.5218467E-04,   1.5322951E-04,   1.5432257E-04
     +,   1.5546280E-04,   1.5664894E-04,   1.5787943E-04
     +,   1.5915280E-04,   1.6046714E-04,   1.6182075E-04
     +,   1.6321176E-04,   1.6463855E-04,   1.6609947E-04
     +,   1.6759335E-04,   1.6911926E-04,   1.7067669E-04
     +,   1.7226581E-04,   1.7388743E-04,   1.7554330E-04
     +,   1.7723601E-04,   1.7896917E-04,   1.8074761E-04
     +,   1.8257777E-04,   1.8446702E-04,   1.8642476E-04
     +,   1.8846175E-04,   1.9059042E-04,   1.9282501E-04
     +,   1.9518184E-04,   1.9767898E-04,   2.0033614E-04
     +,   2.0317514E-04,   2.0621947E-04,   2.0949470E-04
     +,   2.1302761E-04,   2.1684656E-04,   2.2098157E-04
     +,   2.2546359E-04,   2.3032425E-04,   2.3559624E-04
     +,   2.4131253E-04,   2.4750573E-04,   2.5420781E-04
     +,   2.6145068E-04,   2.6926486E-04,   2.7767860E-04
     +,   2.8671816E-04,   2.9640752E-04,   3.0676796E-04
     +,   3.1781691E-04,   3.2956802E-04,   3.4203159E-04
     +,   3.5521490E-04,   3.6911989E-04,   3.8374728E-04
     +,   3.9909454E-04,   4.1515729E-04,   4.3193024E-04
     +,   4.4940971E-04,   4.6759567E-04,   4.8649072E-04
     +,   5.0610391E-04,   5.2645401E-04,   5.4756936E-04
     +,   5.6948967E-04,   5.9226592E-04,   6.1596377E-04
     +,   6.4066157E-04,   6.6644611E-04,   6.9341378E-04
     +,   7.2166591E-04,   7.5130176E-04,   7.8241358E-04
     +,   8.1508327E-04,   8.4937486E-04,   8.8532275E-04
     +,   9.2293142E-04,   9.6217351E-04,   1.0029847E-03
     +,   1.0452602E-03,   1.0888624E-03,   1.1336263E-03
     +,   1.1793635E-03,   1.2258701E-03,   1.2729391E-03
     +,   1.3203683E-03,   1.3679666E-03,   1.4155662E-03
     +,   1.4630286E-03,   1.5102575E-03,   1.5572014E-03
     +,   1.6038688E-03,   1.6503489E-03,   1.6968288E-03
     +,   1.7436128E-03,   1.7911451E-03,   1.8400321E-03
     +,   1.8910514E-03,   1.9451415E-03,   2.0033929E-03
     +,   2.0670120E-03,   2.1372824E-03,   2.2155247E-03
     +,   2.3030916E-03,   2.4013685E-03,   2.5118275E-03
     +,   2.6361067E-03,   2.7761271E-03,   2.9341688E-03
     +,   3.1128998E-03,   3.3153186E-03,   3.5446004E-03
     +,   3.8037903E-03,   4.0953550E-03,   4.4207596E-03
     +,   4.7800248E-03,   5.1713982E-03,   5.5914563E-03
     +,   6.0355975E-03,   6.4988383E-03,   6.9767516E-03
     +,   7.4659889E-03,   7.9642236E-03,   8.4693041E-03
     +,   8.9782579E-03,   9.4870683E-03,   9.9916076E-03
     +,   1.0489011E-02,   1.0978448E-02,   1.1459961E-02
     +,   1.1931424E-02,   1.2385922E-02,   1.2812343E-02
     +,   1.3199962E-02,   1.3544924E-02,   1.3854626E-02
     +,   1.4147570E-02,   1.4448825E-02,   1.4783231E-02
     +,   1.5167933E-02,   1.5606282E-02,   1.6086489E-02
     +,   1.6589684E-02,   1.7106451E-02,   1.7652173E-02
     +,   1.8264566E-02,   1.8977465E-02,   1.9784700E-02
     +,   2.0622436E-02,   2.1388501E-02,   2.1986624E-02
     +,   2.2361359E-02,   2.2498522E-02,   2.2400860E-02
     +,   2.2072863E-02,   2.1535376E-02,   2.0852242E-02
     +,   2.0130282E-02,   1.9476514E-02,   1.8936995E-02
     +,   1.8465258E-02,   1.7944984E-02,   1.7253129E-02
     +,   1.6321214E-02,   1.5161588E-02,   1.3850437E-02
     +,   1.2487032E-02,   1.1155104E-02,   9.9025676E-03
     +,   8.7430868E-03,   7.6694749E-03,   6.6698706E-03
     +,   5.7379352E-03,   4.8762886E-03,   4.0935660E-03
     +,   3.3995938E-03,   2.8005731E-03,   2.2968540E-03
     +,   1.8826919E-03,   1.5479608E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt120 = Yx/0.224155555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2988551E-04,   1.3315711E-04
     +,   1.3639255E-04,   1.3958818E-04,   1.4274097E-04
     +,   1.4584846E-04,   1.4890920E-04,   1.5192253E-04
     +,   1.5488872E-04,   1.5780935E-04,   1.6068686E-04
     +,   1.6352510E-04,   1.6632931E-04,   1.6910597E-04
     +,   1.7186328E-04,   1.7461098E-04,   1.7736027E-04
     +,   1.8012448E-04,   1.8291855E-04,   1.8575948E-04
     +,   1.8866626E-04,   1.9166003E-04,   1.9476423E-04
     +,   1.9800452E-04,   2.0140890E-04,   2.0500805E-04
     +,   2.0883503E-04,   2.1292559E-04,   2.1731785E-04
     +,   2.2205278E-04,   2.2717378E-04,   2.3272654E-04
     +,   2.3875934E-04,   2.4532227E-04,   2.5246726E-04
     +,   2.6024808E-04,   2.6871942E-04,   2.7793690E-04
     +,   2.8795705E-04,   2.9883577E-04,   3.1063010E-04
     +,   3.2339609E-04,   3.3718967E-04,   3.5206694E-04
     +,   3.6808415E-04,   3.8529796E-04,   4.0376707E-04
     +,   4.2355238E-04,   4.4471867E-04,   4.6733549E-04
     +,   4.9147935E-04,   5.1723479E-04,   5.4469611E-04
     +,   5.7397096E-04,   6.0517737E-04,   6.3845020E-04
     +,   6.7393825E-04,   7.1180606E-04,   7.5223146E-04
     +,   7.9540594E-04,   8.4152922E-04,   8.9080783E-04
     +,   9.4344263E-04,   9.9963450E-04,   1.0595742E-03
     +,   1.1234367E-03,   1.1914024E-03,   1.2636528E-03
     +,   1.3404220E-03,   1.4220175E-03,   1.5088990E-03
     +,   1.6017278E-03,   1.7014623E-03,   1.8093947E-03
     +,   1.9272156E-03,   2.0570161E-03,   2.2012535E-03
     +,   2.3626825E-03,   2.5442890E-03,   2.7491935E-03
     +,   2.9805580E-03,   3.2415774E-03,   3.5353773E-03
     +,   3.8650152E-03,   4.2333221E-03,   4.6428125E-03
     +,   5.0954265E-03,   5.5925013E-03,   6.1346367E-03
     +,   6.7219054E-03,   7.3540709E-03,   8.0307582E-03
     +,   8.7513588E-03,   9.5145348E-03,   1.0316847E-02
     +,   1.1150673E-02,   1.2002108E-02,   1.2848898E-02
     +,   1.3660073E-02,   1.4397189E-02,   1.5018225E-02
     +,   1.5482902E-02,   1.5758811E-02,   1.5826525E-02
     +,   1.5682613E-02,   1.5339888E-02,   1.4825325E-02
     +,   1.4176086E-02,   1.3434641E-02,   1.2643888E-02
     +,   1.1842772E-02,   1.1062700E-02,   1.0325699E-02
     +,   9.6438294E-03,   9.0206824E-03,   8.4535694E-03
     +,   7.9367543E-03,   7.4638743E-03,   7.0299138E-03
     +,   6.6318382E-03,   6.2683867E-03,   5.9392918E-03
     +,   5.6442572E-03,   5.3821141E-03,   5.1503805E-03
     +,   4.9453229E-03,   4.7622132E-03,   4.5960415E-03
     +,   4.4420934E-03,   4.2965645E-03,   4.1568717E-03
     +,   4.0217689E-03,   3.8911761E-03,   3.7659113E-03
     +,   3.6472552E-03,   3.5366050E-03,   3.4351558E-03
     +,   3.3437153E-03,   3.2626064E-03,   3.1916928E-03
     +,   3.1304939E-03,   3.0782877E-03,   3.0342687E-03
     +,   2.9976440E-03,   2.9677306E-03,   2.9439705E-03
     +,   2.9259268E-03,   2.9132382E-03,   2.9055474E-03
     +,   2.9024158E-03,   2.9032645E-03,   2.9073083E-03
     +,   2.9135447E-03,   2.9207487E-03,   2.9275161E-03
     +,   2.9323127E-03,   2.9335779E-03,   2.9297911E-03
     +,   2.9195766E-03,   2.9017814E-03,   2.8755490E-03
     +,   2.8403581E-03,   2.7960583E-03,   2.7428749E-03
     +,   2.6813762E-03,   2.6124427E-03,   2.5372182E-03
     +,   2.4570427E-03,   2.3733648E-03,   2.2876845E-03
     +,   2.2014887E-03,   2.1161798E-03,   2.0330104E-03
     +,   1.9530666E-03,   1.8772230E-03,   1.8061328E-03
     +,   1.7402213E-03,   1.6797050E-03,   1.6246036E-03
     +,   1.5747616E-03,   1.5298867E-03,   1.4895845E-03
     +,   1.4533923E-03,   1.4208042E-03,   1.3913114E-03
     +,   1.3644233E-03,   1.3396894E-03,   1.3167066E-03
     +,   1.2951414E-03,   1.2747251E-03,   1.2552550E-03
     +,   1.2365921E-03,   1.2186543E-03,   1.2014080E-03
     +,   1.1848545E-03,   1.1690237E-03,   1.1539633E-03
     +,   1.1397294E-03,   1.1263774E-03,   1.1139566E-03
     +,   1.1025057E-03,   1.0920487E-03,   1.0825940E-03
     +,   1.0741324E-03,   1.0666394E-03,   1.0600750E-03
     +,   1.0543854E-03,   1.0495081E-03,   1.0453706E-03
     +,   1.0418961E-03,   1.0390006E-03,   1.0365986E-03
     +,   1.0346055E-03,   1.0329339E-03,   1.0314977E-03
     +,   1.0302115E-03,   1.0289903E-03,   1.0277487E-03
     +,   1.0264035E-03,   1.0248712E-03,   1.0230676E-03
     +,   1.0209099E-03,   1.0183163E-03,   1.0152053E-03
     +,   1.0114984E-03,   1.0071202E-03,   1.0019988E-03
     +,   9.9607010E-04,   9.8927377E-04,   9.8156079E-04
     +,   9.7289018E-04,   9.6323452E-04,   9.5257448E-04
     +,   9.4090740E-04,   9.2824193E-04,   9.1460027E-04
     +,   9.0001884E-04,   8.8454742E-04,   8.6824765E-04
     +,   8.5119146E-04,   8.3346025E-04,   8.1514614E-04
     +,   7.9634628E-04,   7.7716209E-04,   7.5769733E-04
     +,   7.3805760E-04,   7.1834814E-04,   6.9866917E-04
     +,   6.7911687E-04,   6.5978291E-04,   6.4075034E-04
     +,   6.2209275E-04,   6.0387683E-04,   5.8615895E-04
     +,   5.6898379E-04,   5.5238686E-04,   5.3639355E-04
     +,   5.2102061E-04,   5.0627382E-04,   4.9215049E-04
     +,   4.7864136E-04,   4.6573000E-04,   4.5339324E-04
     +,   4.4160304E-04,   4.3032825E-04,   4.1953352E-04
     +,   4.0918175E-04,   3.9923505E-04,   3.8965477E-04
     +,   3.8040234E-04,   3.7144014E-04,   3.6273204E-04
     +,   3.5424414E-04,   3.4594460E-04,   3.3780350E-04
     +,   3.2979518E-04,   3.2189535E-04,   3.1408400E-04
     +,   3.0634287E-04,   2.9865783E-04,   2.9101639E-04
     +,   2.8340987E-04,   2.7583117E-04,   2.6827661E-04
     +,   2.6074340E-04,   2.5323217E-04,   2.4574416E-04
     +,   2.3828229E-04,   2.3085176E-04,   2.2345770E-04
     +,   2.1610734E-04,   2.0880744E-04,   2.0156687E-04
     +,   1.9439327E-04,   1.8729601E-04,   1.8028353E-04
     +,   1.7336513E-04,   1.6654917E-04,   1.5984465E-04
     +,   1.5325940E-04,   1.4680182E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt75 = Yx/0.170227272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.5507589E-05,   5.7259800E-05
     +,   5.9047808E-05,   6.0870778E-05,   6.2727820E-05
     +,   6.4617852E-05,   6.6539695E-05,   6.8492089E-05
     +,   7.0473572E-05,   7.2482726E-05,   7.4517920E-05
     +,   7.6577468E-05,   7.8659679E-05,   8.0762744E-05
     +,   8.2884922E-05,   8.5024411E-05,   8.7179527E-05
     +,   8.9348548E-05,   9.1529975E-05,   9.3722389E-05
     +,   9.5924603E-05,   9.8135584E-05,   1.0035466E-04
     +,   1.0258154E-04,   1.0481608E-04,   1.0705885E-04
     +,   1.0931064E-04,   1.1157291E-04,   1.1384760E-04
     +,   1.1613721E-04,   1.1844499E-04,   1.2077468E-04
     +,   1.2313081E-04,   1.2551855E-04,   1.2794371E-04
     +,   1.3041284E-04,   1.3293324E-04,   1.3551270E-04
     +,   1.3815996E-04,   1.4088416E-04,   1.4369529E-04
     +,   1.4660403E-04,   1.4962176E-04,   1.5276074E-04
     +,   1.5603419E-04,   1.5945638E-04,   1.6304312E-04
     +,   1.6681170E-04,   1.7078152E-04,   1.7497446E-04
     +,   1.7941534E-04,   1.8413275E-04,   1.8915931E-04
     +,   1.9453331E-04,   2.0029802E-04,   2.0650400E-04
     +,   2.1320910E-04,   2.2047914E-04,   2.2838915E-04
     +,   2.3702359E-04,   2.4647641E-04,   2.5685233E-04
     +,   2.6826502E-04,   2.8083925E-04,   2.9470882E-04
     +,   3.1001458E-04,   3.2690659E-04,   3.4553820E-04
     +,   3.6606879E-04,   3.8865639E-04,   4.1346048E-04
     +,   4.4063345E-04,   4.7032343E-04,   5.0266407E-04
     +,   5.3777971E-04,   5.7577703E-04,   6.1674271E-04
     +,   6.6074397E-04,   7.0783083E-04,   7.5803808E-04
     +,   8.1138487E-04,   8.6789409E-04,   9.2759420E-04
     +,   9.9054934E-04,   1.0568715E-03,   1.1267585E-03
     +,   1.2005116E-03,   1.2785795E-03,   1.3615671E-03
     +,   1.4502609E-03,   1.5456198E-03,   1.6487446E-03
     +,   1.7608333E-03,   1.8831204E-03,   2.0168012E-03
     +,   2.1629368E-03,   2.3224398E-03,   2.4960118E-03
     +,   2.6842074E-03,   2.8874390E-03,   3.1060970E-03
     +,   3.3405402E-03,   3.5911652E-03,   3.8582964E-03
     +,   4.1421331E-03,   4.4426098E-03,   4.7593056E-03
     +,   5.0914534E-03,   5.4381262E-03,   5.7984022E-03
     +,   6.1714603E-03,   6.5566213E-03,   6.9528669E-03
     +,   7.3581738E-03,   7.7685658E-03,   8.1775645E-03
     +,   8.5759861E-03,   8.9528132E-03,   9.2966007E-03
     +,   9.5975092E-03,   9.8489160E-03,   1.0048195E-02
     +,   1.0196426E-02,   1.0297091E-02,   1.0354091E-02
     +,   1.0370223E-02,   1.0346211E-02,   1.0280802E-02
     +,   1.0171757E-02,   1.0017229E-02,   9.8170908E-03
     +,   9.5739020E-03,   9.2929797E-03,   8.9820549E-03
     +,   8.6501585E-03,   8.3063710E-03,   7.9587856E-03
     +,   7.6138428E-03,   7.2761183E-03,   6.9487998E-03
     +,   6.6344454E-03,   6.3356310E-03,   6.0554100E-03
     +,   5.7972632E-03,   5.5647544E-03,   5.3606913E-03
     +,   5.1865270E-03,   5.0418908E-03,   4.9245022E-03
     +,   4.8304941E-03,   4.7550066E-03,   4.6929256E-03
     +,   4.6395175E-03,   4.5908708E-03,   4.5441263E-03
     +,   4.4973991E-03,   4.4495757E-03,   4.3999720E-03
     +,   4.3480508E-03,   4.2932010E-03,   4.2346101E-03
     +,   4.1713044E-03,   4.1022631E-03,   4.0265759E-03
     +,   3.9436347E-03,   3.8532771E-03,   3.7558773E-03
     +,   3.6523442E-03,   3.5440431E-03,   3.4326857E-03
     +,   3.3201764E-03,   3.2084379E-03,   3.0992737E-03
     +,   2.9942491E-03,   2.8946549E-03,   2.8014614E-03
     +,   2.7153436E-03,   2.6367237E-03,   2.5658091E-03
     +,   2.5026486E-03,   2.4471516E-03,   2.3991405E-03
     +,   2.3583476E-03,   2.3244109E-03,   2.2968836E-03
     +,   2.2752252E-03,   2.2588049E-03,   2.2469002E-03
     +,   2.2387144E-03,   2.2333940E-03,   2.2300568E-03
     +,   2.2278107E-03,   2.2257874E-03,   2.2231652E-03
     +,   2.2191911E-03,   2.2132036E-03,   2.2046461E-03
     +,   2.1930807E-03,   2.1781956E-03,   2.1598078E-03
     +,   2.1378680E-03,   2.1124580E-03,   2.0837721E-03
     +,   2.0521178E-03,   2.0178952E-03,   1.9815718E-03
     +,   1.9436672E-03,   1.9047274E-03,   1.8652951E-03
     +,   1.8258883E-03,   1.7869768E-03,   1.7489726E-03
     +,   1.7122086E-03,   1.6769355E-03,   1.6433147E-03
     +,   1.6114356E-03,   1.5813104E-03,   1.5528932E-03
     +,   1.5260902E-03,   1.5007822E-03,   1.4768296E-03
     +,   1.4540930E-03,   1.4324456E-03,   1.4117751E-03
     +,   1.3919928E-03,   1.3730341E-03,   1.3548575E-03
     +,   1.3374438E-03,   1.3207820E-03,   1.3048741E-03
     +,   1.2897191E-03,   1.2753108E-03,   1.2616294E-03
     +,   1.2486391E-03,   1.2362854E-03,   1.2244922E-03
     +,   1.2131628E-03,   1.2021848E-03,   1.1914327E-03
     +,   1.1807699E-03,   1.1700586E-03,   1.1591627E-03
     +,   1.1479546E-03,   1.1363189E-03,   1.1241576E-03
     +,   1.1113946E-03,   1.0979749E-03,   1.0838674E-03
     +,   1.0690641E-03,   1.0535810E-03,   1.0374507E-03
     +,   1.0207238E-03,   1.0034642E-03,   9.8574592E-04
     +,   9.6764712E-04,   9.4924623E-04,   9.3062333E-04
     +,   9.1185077E-04,   8.9299423E-04,   8.7410904E-04
     +,   8.5524155E-04,   8.3642727E-04,   8.1768830E-04
     +,   7.9903781E-04,   7.8048016E-04,   7.6201069E-04
     +,   7.4361835E-04,   7.2528812E-04,   7.0700329E-04
     +,   6.8874488E-04,   6.7049474E-04,   6.5223844E-04
     +,   6.3396530E-04,   6.1566825E-04,   5.9734564E-04
     +,   5.7900330E-04,   5.6065148E-04,   5.4230727E-04
     +,   5.2399229E-04,   5.0573493E-04,   4.8756550E-04
     +,   4.6952011E-04,   4.5163490E-04,   4.3395034E-04
     +,   4.1650448E-04,   3.9933855E-04,   3.8248929E-04
     +,   3.6599278E-04,   3.4988375E-04,   3.3419143E-04
     +,   3.1894378E-04,   3.0416259E-04,   2.8986743E-04
     +,   2.7607181E-04,   2.6278681E-04,   2.5001742E-04
     +,   2.3776684E-04,   2.2603243E-04,   2.1480996E-04
     +,   2.0409070E-04,   1.9386466E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt80 = Yx/0.158720930232558
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.6846875E-05,   5.8408386E-05
     +,   5.9982744E-05,   6.1568993E-05,   6.3166182E-05
     +,   6.4773427E-05,   6.6389890E-05,   6.8014851E-05
     +,   6.9647664E-05,   7.1287839E-05,   7.2934919E-05
     +,   7.4588657E-05,   7.6248958E-05,   7.7915836E-05
     +,   7.9589481E-05,   8.1270344E-05,   8.2958999E-05
     +,   8.4656240E-05,   8.6363121E-05,   8.8080858E-05
     +,   8.9810936E-05,   9.1555063E-05,   9.3315241E-05
     +,   9.5093666E-05,   9.6892705E-05,   9.8715100E-05
     +,   1.0056379E-04,   1.0244193E-04,   1.0435288E-04
     +,   1.0630026E-04,   1.0828787E-04,   1.1031972E-04
     +,   1.1240000E-04,   1.1453310E-04,   1.1672352E-04
     +,   1.1897596E-04,   1.2129522E-04,   1.2368626E-04
     +,   1.2615429E-04,   1.2870436E-04,   1.3134198E-04
     +,   1.3407266E-04,   1.3690218E-04,   1.3983643E-04
     +,   1.4288172E-04,   1.4604465E-04,   1.4933212E-04
     +,   1.5275169E-04,   1.5631135E-04,   1.6001992E-04
     +,   1.6388709E-04,   1.6792340E-04,   1.7214056E-04
     +,   1.7655181E-04,   1.8117140E-04,   1.8601565E-04
     +,   1.9110231E-04,   1.9645128E-04,   2.0208432E-04
     +,   2.0802546E-04,   2.1430082E-04,   2.2093883E-04
     +,   2.2796965E-04,   2.3542611E-04,   2.4334267E-04
     +,   2.5175503E-04,   2.6070097E-04,   2.7021806E-04
     +,   2.8034550E-04,   2.9112105E-04,   3.0258278E-04
     +,   3.1476602E-04,   3.2770482E-04,   3.4142871E-04
     +,   3.5596383E-04,   3.7133170E-04,   3.8754608E-04
     +,   4.0461417E-04,   4.2253517E-04,   4.4130010E-04
     +,   4.6088689E-04,   4.8126560E-04,   5.0239131E-04
     +,   5.2420981E-04,   5.4665026E-04,   5.6963181E-04
     +,   5.9305789E-04,   6.1682146E-04,   6.4080115E-04
     +,   6.6486746E-04,   6.8888359E-04,   7.1270549E-04
     +,   7.3618954E-04,   7.5919763E-04,   7.8160199E-04
     +,   8.0329209E-04,   8.2418695E-04,   8.4424007E-04
     +,   8.6345570E-04,   8.8189478E-04,   8.9969282E-04
     +,   9.1706519E-04,   9.3432056E-04,   9.5186423E-04
     +,   9.7020541E-04,   9.8995038E-04,   1.0117963E-03
     +,   1.0365148E-03,   1.0649350E-03,   1.0979139E-03
     +,   1.1363116E-03,   1.1809707E-03,   1.2326946E-03
     +,   1.2922558E-03,   1.3603985E-03,   1.4378867E-03
     +,   1.5255359E-03,   1.6242913E-03,   1.7352615E-03
     +,   1.8597924E-03,   1.9994834E-03,   2.1562043E-03
     +,   2.3320795E-03,   2.5295019E-03,   2.7510971E-03
     +,   2.9996457E-03,   3.2780392E-03,   3.5890229E-03
     +,   3.9349142E-03,   4.3169926E-03,   4.7349147E-03
     +,   5.1858542E-03,   5.6639616E-03,   6.1599109E-03
     +,   6.6611972E-03,   7.1529592E-03,   7.6194732E-03
     +,   8.0462424E-03,   8.4221624E-03,   8.7413620E-03
     +,   9.0041589E-03,   9.2167556E-03,   9.3895588E-03
     +,   9.5341457E-03,   9.6595986E-03,   9.7692432E-03
     +,   9.8587191E-03,   9.9162543E-03,   9.9255787E-03
     +,   9.8706149E-03,   9.7408304E-03,   9.5354924E-03
     +,   9.2653483E-03,   8.9510987E-03,   8.6190980E-03
     +,   8.2956692E-03,   8.0016172E-03,   7.7484609E-03
     +,   7.5374465E-03,   7.3609627E-03,   7.2056358E-03
     +,   7.0562311E-03,   6.8991720E-03,   6.7249527E-03
     +,   6.5293685E-03,   6.3134851E-03,   6.0827727E-03
     +,   5.8456315E-03,   5.6117401E-03,   5.3905258E-03
     +,   5.1898728E-03,   5.0152359E-03,   4.8691970E-03
     +,   4.7515281E-03,   4.6596271E-03,   4.5891851E-03
     +,   4.5350511E-03,   4.4920552E-03,   4.4556204E-03
     +,   4.4221967E-03,   4.3893540E-03,   4.3556774E-03
     +,   4.3204478E-03,   4.2832624E-03,   4.2437194E-03
     +,   4.2011915E-03,   4.1547748E-03,   4.1033765E-03
     +,   4.0459121E-03,   3.9815642E-03,   3.9099925E-03
     +,   3.8314760E-03,   3.7469396E-03,   3.6578870E-03
     +,   3.5662132E-03,   3.4739801E-03,   3.3832088E-03
     +,   3.2956670E-03,   3.2127195E-03,   3.1352758E-03
     +,   3.0637910E-03,   2.9983060E-03,   2.9385323E-03
     +,   2.8839724E-03,   2.8340018E-03,   2.7879642E-03
     +,   2.7452239E-03,   2.7052208E-03,   2.6674680E-03
     +,   2.6315658E-03,   2.5971667E-03,   2.5639720E-03
     +,   2.5317026E-03,   2.5000710E-03,   2.4687678E-03
     +,   2.4374672E-03,   2.4058109E-03,   2.3734316E-03
     +,   2.3399643E-03,   2.3050776E-03,   2.2684862E-03
     +,   2.2299858E-03,   2.1894616E-03,   2.1469085E-03
     +,   2.1024223E-03,   2.0561966E-03,   2.0085198E-03
     +,   1.9597446E-03,   1.9102605E-03,   1.8604740E-03
     +,   1.8107860E-03,   1.7615635E-03,   1.7131208E-03
     +,   1.6657107E-03,   1.6195236E-03,   1.5746765E-03
     +,   1.5312211E-03,   1.4891640E-03,   1.4484636E-03
     +,   1.4090579E-03,   1.3708655E-03,   1.3338152E-03
     +,   1.2978478E-03,   1.2629261E-03,   1.2290432E-03
     +,   1.1962255E-03,   1.1645361E-03,   1.1340604E-03
     +,   1.1049104E-03,   1.0772158E-03,   1.0511085E-03
     +,   1.0267197E-03,   1.0041679E-03,   9.8355173E-04
     +,   9.6493855E-04,   9.4836130E-04,   9.3381637E-04
     +,   9.2125719E-04,   9.1059657E-04,   9.0170611E-04
     +,   8.9442136E-04,   8.8854675E-04,   8.8385754E-04
     +,   8.8010909E-04,   8.7704416E-04,   8.7439641E-04
     +,   8.7190198E-04,   8.6930051E-04,   8.6634513E-04
     +,   8.6280570E-04,   8.5847446E-04,   8.5316750E-04
     +,   8.4672944E-04,   8.3903433E-04,   8.2998618E-04
     +,   8.1952050E-04,   8.0760173E-04,   7.9422432E-04
     +,   7.7940908E-04,   7.6320278E-04,   7.4567372E-04
     +,   7.2691141E-04,   7.0702081E-04,   6.8612304E-04
     +,   6.6434691E-04,   6.4183248E-04,   6.1872252E-04
     +,   5.9516192E-04,   5.7129632E-04,   5.4726686E-04
     +,   5.2321138E-04,   4.9925846E-04,   4.7553109E-04
     +,   4.5213939E-04,   4.2918581E-04,   4.0675807E-04
     +,   3.8493579E-04,   3.6378321E-04,   3.4335564E-04
     +,   3.2369437E-04,   3.0483241E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt85 = Yx/0.154813953488372
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0186183E-04,   1.0526077E-04
     +,   1.0870722E-04,   1.1219854E-04,   1.1573184E-04
     +,   1.1930404E-04,   1.2291184E-04,   1.2655175E-04
     +,   1.3022008E-04,   1.3391301E-04,   1.3762648E-04
     +,   1.4135617E-04,   1.4509761E-04,   1.4884623E-04
     +,   1.5259726E-04,   1.5634582E-04,   1.6008683E-04
     +,   1.6381519E-04,   1.6752561E-04,   1.7121292E-04
     +,   1.7487172E-04,   1.7849678E-04,   1.8208276E-04
     +,   1.8562452E-04,   1.8911692E-04,   1.9255500E-04
     +,   1.9593410E-04,   1.9924949E-04,   2.0249703E-04
     +,   2.0567270E-04,   2.0877279E-04,   2.1179418E-04
     +,   2.1473401E-04,   2.1759003E-04,   2.2036025E-04
     +,   2.2304356E-04,   2.2563925E-04,   2.2814710E-04
     +,   2.3056784E-04,   2.3290278E-04,   2.3515348E-04
     +,   2.3732285E-04,   2.3941402E-04,   2.4143113E-04
     +,   2.4337873E-04,   2.4526234E-04,   2.4708806E-04
     +,   2.4886252E-04,   2.5059312E-04,   2.5228778E-04
     +,   2.5395505E-04,   2.5560390E-04,   2.5724369E-04
     +,   2.5888431E-04,   2.6053571E-04,   2.6220843E-04
     +,   2.6391266E-04,   2.6565907E-04,   2.6745806E-04
     +,   2.6931995E-04,   2.7125468E-04,   2.7327202E-04
     +,   2.7538097E-04,   2.7759038E-04,   2.7990801E-04
     +,   2.8234094E-04,   2.8489545E-04,   2.8757664E-04
     +,   2.9038871E-04,   2.9333451E-04,   2.9641585E-04
     +,   2.9963316E-04,   3.0298557E-04,   3.0647105E-04
     +,   3.1008627E-04,   3.1382672E-04,   3.1768667E-04
     +,   3.2165958E-04,   3.2573799E-04,   3.2991415E-04
     +,   3.3417932E-04,   3.3852542E-04,   3.4294411E-04
     +,   3.4742779E-04,   3.5197005E-04,   3.5656587E-04
     +,   3.6121221E-04,   3.6590869E-04,   3.7065771E-04
     +,   3.7546581E-04,   3.8034297E-04,   3.8530509E-04
     +,   3.9037265E-04,   3.9557295E-04,   4.0094001E-04
     +,   4.0651552E-04,   4.1234921E-04,   4.1849969E-04
     +,   4.2503580E-04,   4.3203568E-04,   4.3958914E-04
     +,   4.4779593E-04,   4.5676850E-04,   4.6662899E-04
     +,   4.7751103E-04,   4.8955745E-04,   5.0291920E-04
     +,   5.1775126E-04,   5.3421181E-04,   5.5245752E-04
     +,   5.7263538E-04,   5.9488276E-04,   6.1931351E-04
     +,   6.4601982E-04,   6.7505793E-04,   7.0645049E-04
     +,   7.4017409E-04,   7.7616842E-04,   8.1432605E-04
     +,   8.5450854E-04,   8.9655252E-04,   9.4027910E-04
     +,   9.8551600E-04,   1.0321223E-03,   1.0800089E-03
     +,   1.1291606E-03,   1.1796701E-03,   1.2317485E-03
     +,   1.2857554E-03,   1.3421947E-03,   1.4017326E-03
     +,   1.4651736E-03,   1.5334543E-03,   1.6075933E-03
     +,   1.6886625E-03,   1.7777205E-03,   1.8757377E-03
     +,   1.9835338E-03,   2.1017182E-03,   2.2306412E-03
     +,   2.3703643E-03,   2.5206923E-03,   2.6812670E-03
     +,   2.8516722E-03,   3.0315998E-03,   3.2210520E-03
     +,   3.4204999E-03,   3.6309892E-03,   3.8541560E-03
     +,   4.0921490E-03,   4.3473570E-03,   4.6219942E-03
     +,   4.9175965E-03,   5.2344641E-03,   5.5710333E-03
     +,   5.9234300E-03,   6.2852381E-03,   6.6476786E-03
     +,   7.0001795E-03,   7.3313052E-03,   7.6301703E-03
     +,   7.8876885E-03,   8.0977064E-03,   8.2575269E-03
     +,   8.3678095E-03,   8.4317625E-03,   8.4539503E-03
     +,   8.4391180E-03,   8.3914138E-03,   8.3141951E-03
     +,   8.2105426E-03,   8.0842599E-03,   7.9408465E-03
     +,   7.7882148E-03,   7.6367096E-03,   7.4982303E-03
     +,   7.3846676E-03,   7.3058559E-03,   7.2675138E-03
     +,   7.2696665E-03,   7.3061003E-03,   7.3648724E-03
     +,   7.4300095E-03,   7.4839708E-03,   7.5104064E-03
     +,   7.4965260E-03,   7.4347411E-03,   7.3232758E-03
     +,   7.1656494E-03,   6.9694803E-03,   6.7447713E-03
     +,   6.5022493E-03,   6.2519992E-03,   6.0025672E-03
     +,   5.7606031E-03,   5.5308528E-03,   5.3165341E-03
     +,   5.1196492E-03,   4.9412944E-03,   4.7818520E-03
     +,   4.6410728E-03,   4.5180484E-03,   4.4112066E-03
     +,   4.3183556E-03,   4.2368392E-03,   4.1637314E-03
     +,   4.0961024E-03,   4.0312479E-03,   3.9668879E-03
     +,   3.9012290E-03,   3.8329994E-03,   3.7613704E-03
     +,   3.6858609E-03,   3.6062191E-03,   3.5223546E-03
     +,   3.4343188E-03,   3.3423037E-03,   3.2466694E-03
     +,   3.1480049E-03,   3.0471697E-03,   2.9452867E-03
     +,   2.8437250E-03,   2.7440516E-03,   2.6479270E-03
     +,   2.5569906E-03,   2.4727699E-03,   2.3965621E-03
     +,   2.3293665E-03,   2.2718012E-03,   2.2241033E-03
     +,   2.1861191E-03,   2.1573403E-03,   2.1369432E-03
     +,   2.1238553E-03,   2.1168289E-03,   2.1145053E-03
     +,   2.1154836E-03,   2.1183821E-03,   2.1218883E-03
     +,   2.1247996E-03,   2.1260604E-03,   2.1247766E-03
     +,   2.1202341E-03,   2.1118987E-03,   2.0994188E-03
     +,   2.0826056E-03,   2.0614213E-03,   2.0359526E-03
     +,   2.0063920E-03,   1.9730022E-03,   1.9360972E-03
     +,   1.8960122E-03,   1.8530912E-03,   1.8076666E-03
     +,   1.7600484E-03,   1.7105211E-03,   1.6593513E-03
     +,   1.6067842E-03,   1.5530547E-03,   1.4983912E-03
     +,   1.4430297E-03,   1.3872202E-03,   1.3312211E-03
     +,   1.2753071E-03,   1.2197710E-03,   1.1649085E-03
     +,   1.1110145E-03,   1.0583801E-03,   1.0072797E-03
     +,   9.5795729E-04,   9.1062405E-04,   8.6545380E-04
     +,   8.2257658E-04,   7.8207348E-04,   7.4398110E-04
     +,   7.0829620E-04,   6.7497068E-04,   6.4392836E-04
     +,   6.1505911E-04,   5.8823545E-04,   5.6331040E-04
     +,   5.4013071E-04,   5.1853555E-04,   4.9836712E-04
     +,   4.7947007E-04,   4.6169784E-04,   4.4491293E-04
     +,   4.2898819E-04,   4.1381066E-04,   3.9927781E-04
     +,   3.8530154E-04,   3.7180382E-04,   3.5872019E-04
     +,   3.4599495E-04,   3.3358426E-04,   3.2145093E-04
     +,   3.0956775E-04,   2.9791298E-04,   2.8647273E-04
     +,   2.7523650E-04,   2.6420024E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt90 = Yx/0.149604651162791
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0586404E-05,   8.3091072E-05
     +,   8.5607382E-05,   8.8131375E-05,   9.0659109E-05
     +,   9.3186442E-05,   9.5709365E-05,   9.8223798E-05
     +,   1.0072569E-04,   1.0321118E-04,   1.0567642E-04
     +,   1.0811769E-04,   1.1053155E-04,   1.1291470E-04
     +,   1.1526419E-04,   1.1757726E-04,   1.1985157E-04
     +,   1.2208517E-04,   1.2427638E-04,   1.2642411E-04
     +,   1.2852771E-04,   1.3058694E-04,   1.3260209E-04
     +,   1.3457413E-04,   1.3650442E-04,   1.3839499E-04
     +,   1.4024838E-04,   1.4206774E-04,   1.4385681E-04
     +,   1.4561988E-04,   1.4736174E-04,   1.4908776E-04
     +,   1.5080380E-04,   1.5251605E-04,   1.5423141E-04
     +,   1.5595689E-04,   1.5770004E-04,   1.5946831E-04
     +,   1.6126974E-04,   1.6311226E-04,   1.6500398E-04
     +,   1.6695287E-04,   1.6896678E-04,   1.7105347E-04
     +,   1.7322025E-04,   1.7547421E-04,   1.7782189E-04
     +,   1.8026923E-04,   1.8282162E-04,   1.8548369E-04
     +,   1.8825925E-04,   1.9115128E-04,   1.9416174E-04
     +,   1.9729190E-04,   2.0054138E-04,   2.0390947E-04
     +,   2.0739391E-04,   2.1099146E-04,   2.1469775E-04
     +,   2.1850734E-04,   2.2241382E-04,   2.2640971E-04
     +,   2.3048639E-04,   2.3463473E-04,   2.3884464E-04
     +,   2.4310518E-04,   2.4740517E-04,   2.5173245E-04
     +,   2.5607526E-04,   2.6042078E-04,   2.6475696E-04
     +,   2.6907117E-04,   2.7335164E-04,   2.7758628E-04
     +,   2.8176428E-04,   2.8587511E-04,   2.8990905E-04
     +,   2.9385742E-04,   2.9771251E-04,   3.0146798E-04
     +,   3.0511833E-04,   3.0865986E-04,   3.1208992E-04
     +,   3.1540741E-04,   3.1861229E-04,   3.2170641E-04
     +,   3.2469264E-04,   3.2757540E-04,   3.3036005E-04
     +,   3.3305347E-04,   3.3566362E-04,   3.3819932E-04
     +,   3.4067035E-04,   3.4308725E-04,   3.4546142E-04
     +,   3.4780477E-04,   3.5013014E-04,   3.5245015E-04
     +,   3.5477892E-04,   3.5713031E-04,   3.5951933E-04
     +,   3.6196137E-04,   3.6447303E-04,   3.6707151E-04
     +,   3.6977610E-04,   3.7260738E-04,   3.7558805E-04
     +,   3.7874302E-04,   3.8210084E-04,   3.8569336E-04
     +,   3.8955588E-04,   3.9372899E-04,   3.9825789E-04
     +,   4.0319326E-04,   4.0859130E-04,   4.1451477E-04
     +,   4.2103170E-04,   4.2821668E-04,   4.3614878E-04
     +,   4.4491238E-04,   4.5459525E-04,   4.6528745E-04
     +,   4.7707855E-04,   4.9005734E-04,   5.0430850E-04
     +,   5.1990832E-04,   5.3692487E-04,   5.5541086E-04
     +,   5.7540584E-04,   5.9692713E-04,   6.1997387E-04
     +,   6.4451917E-04,   6.7051506E-04,   6.9788581E-04
     +,   7.2653615E-04,   7.5634831E-04,   7.8718655E-04
     +,   8.1890129E-04,   8.5133832E-04,   8.8434044E-04
     +,   9.1775617E-04,   9.5144496E-04,   9.8528864E-04
     +,   1.0191968E-03,   1.0531087E-03,   1.0870090E-03
     +,   1.1209316E-03,   1.1549622E-03,   1.1892524E-03
     +,   1.2240278E-03,   1.2595925E-03,   1.2963365E-03
     +,   1.3347426E-03,   1.3753903E-03,   1.4189557E-03
     +,   1.4662009E-03,   1.5179679E-03,   1.5751591E-03
     +,   1.6387264E-03,   1.7096259E-03,   1.7888275E-03
     +,   1.8772718E-03,   1.9758590E-03,   2.0854385E-03
     +,   2.2067938E-03,   2.3406246E-03,   2.4874923E-03
     +,   2.6477769E-03,   2.8216538E-03,   3.0090467E-03
     +,   3.2096463E-03,   3.4230244E-03,   3.6488029E-03
     +,   3.8868687E-03,   4.1375277E-03,   4.4016638E-03
     +,   4.6806624E-03,   4.9761995E-03,   5.2899076E-03
     +,   5.6230030E-03,   5.9758346E-03,   6.3475193E-03
     +,   6.7356722E-03,   7.1363919E-03,   7.5446661E-03
     +,   7.9553779E-03,   8.3650863E-03,   8.7739797E-03
     +,   9.1869934E-03,   9.6129887E-03,   1.0061182E-02
     +,   1.0535245E-02,   1.1026949E-02,   1.1512640E-02
     +,   1.1955122E-02,   1.2311596E-02,   1.2545595E-02
     +,   1.2638295E-02,   1.2594612E-02,   1.2441150E-02
     +,   1.2216992E-02,   1.1961236E-02,   1.1702347E-02
     +,   1.1452720E-02,   1.1209518E-02,   1.0959577E-02
     +,   1.0685759E-02,   1.0372158E-02,   1.0007229E-02
     +,   9.5853759E-03,   9.1077816E-03,   8.5830279E-03
     +,   8.0267787E-03,   7.4604121E-03,   6.9081490E-03
     +,   6.3933949E-03,   5.9350547E-03,   5.5450667E-03
     +,   5.2275350E-03,   4.9794042E-03,   4.7919685E-03
     +,   4.6529323E-03,   4.5483634E-03,   4.4643669E-03
     +,   4.3884488E-03,   4.3105236E-03,   4.2234897E-03
     +,   4.1234391E-03,   4.0094121E-03,   3.8829381E-03
     +,   3.7472972E-03,   3.6067774E-03,   3.4659402E-03
     +,   3.3290577E-03,   3.1997128E-03,   3.0805331E-03
     +,   2.9731030E-03,   2.8780012E-03,   2.7948823E-03
     +,   2.7226498E-03,   2.6596345E-03,   2.6038114E-03
     +,   2.5529824E-03,   2.5049620E-03,   2.4577288E-03
     +,   2.4095662E-03,   2.3591467E-03,   2.3055801E-03
     +,   2.2484330E-03,   2.1877110E-03,   2.1237920E-03
     +,   2.0573472E-03,   1.9892647E-03,   1.9205370E-03
     +,   1.8521645E-03,   1.7850864E-03,   1.7201151E-03
     +,   1.6578927E-03,   1.5988656E-03,   1.5432858E-03
     +,   1.4912254E-03,   1.4425971E-03,   1.3971854E-03
     +,   1.3546778E-03,   1.3147081E-03,   1.2768754E-03
     +,   1.2407785E-03,   1.2060318E-03,   1.1722858E-03
     +,   1.1392311E-03,   1.1066062E-03,   1.0742024E-03
     +,   1.0418589E-03,   1.0094598E-03,   9.7692967E-04
     +,   9.4423152E-04,   9.1135566E-04,   8.7832077E-04
     +,   8.4516208E-04,   8.1193418E-04,   7.7869947E-04
     +,   7.4553315E-04,   7.1251241E-04,   6.7972229E-04
     +,   6.4724451E-04,   6.1516761E-04,   5.8357412E-04
     +,   5.5254687E-04,   5.2216800E-04,   4.9251277E-04
     +,   4.6365618E-04,   4.3566461E-04,   4.0860186E-04
     +,   3.8252200E-04,   3.5747560E-04,   3.3350175E-04
     +,   3.1063435E-04,   2.8889591E-04,   2.6830283E-04
     +,   2.4885990E-04,   2.3056584E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_htt95 = Yx/0.154488372093023
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2209788E-05,   3.2444219E-05
     +,   3.2649867E-05,   3.2826516E-05,   3.2974061E-05
     +,   3.3092496E-05,   3.3181928E-05,   3.3242581E-05
     +,   3.3274773E-05,   3.3278942E-05,   3.3255608E-05
     +,   3.3205422E-05,   3.3129112E-05,   3.3027507E-05
     +,   3.2901527E-05,   3.2752178E-05,   3.2580541E-05
     +,   3.2387790E-05,   3.2175158E-05,   3.1943931E-05
     +,   3.1695479E-05,   3.1431202E-05,   3.1152562E-05
     +,   3.0861043E-05,   3.0558185E-05,   3.0245537E-05
     +,   2.9924668E-05,   2.9597162E-05,   2.9264611E-05
     +,   2.8928620E-05,   2.8590764E-05,   2.8252618E-05
     +,   2.7915747E-05,   2.7581678E-05,   2.7251926E-05
     +,   2.6927959E-05,   2.6611213E-05,   2.6303087E-05
     +,   2.6004911E-05,   2.5718007E-05,   2.5443600E-05
     +,   2.5182879E-05,   2.4936971E-05,   2.4706946E-05
     +,   2.4493804E-05,   2.4298475E-05,   2.4121831E-05
     +,   2.3964672E-05,   2.3827719E-05,   2.3711647E-05
     +,   2.3617031E-05,   2.3544393E-05,   2.3494187E-05
     +,   2.3466790E-05,   2.3462515E-05,   2.3481603E-05
     +,   2.3524239E-05,   2.3590545E-05,   2.3680572E-05
     +,   2.3794328E-05,   2.3931765E-05,   2.4092775E-05
     +,   2.4277213E-05,   2.4484907E-05,   2.4715639E-05
     +,   2.4969158E-05,   2.5245219E-05,   2.5543535E-05
     +,   2.5863847E-05,   2.6205873E-05,   2.6569383E-05
     +,   2.6954158E-05,   2.7360034E-05,   2.7786891E-05
     +,   2.8234701E-05,   2.8703531E-05,   2.9193552E-05
     +,   2.9705043E-05,   3.0238467E-05,   3.0794494E-05
     +,   3.1373915E-05,   3.1977841E-05,   3.2607590E-05
     +,   3.3264812E-05,   3.3951441E-05,   3.4669873E-05
     +,   3.5422818E-05,   3.6213543E-05,   3.7045735E-05
     +,   3.7923746E-05,   3.8852544E-05,   3.9837763E-05
     +,   4.0885814E-05,   4.2004027E-05,   4.3200736E-05
     +,   4.4485212E-05,   4.5868073E-05,   4.7361118E-05
     +,   4.8977759E-05,   5.0732833E-05,   5.2643223E-05
     +,   5.4727490E-05,   5.7006611E-05,   5.9503578E-05
     +,   6.2244115E-05,   6.5256609E-05,   6.8572059E-05
     +,   7.2224211E-05,   7.6249955E-05,   8.0689082E-05
     +,   8.5583517E-05,   9.0978239E-05,   9.6919517E-05
     +,   1.0345566E-04,   1.1063485E-04,   1.1850576E-04
     +,   1.2711446E-04,   1.3650530E-04,   1.4671680E-04
     +,   1.5778230E-04,   1.6972696E-04,   1.8256526E-04
     +,   1.9629953E-04,   2.1091886E-04,   2.2639694E-04
     +,   2.4268862E-04,   2.5973248E-04,   2.7744571E-04
     +,   2.9572874E-04,   3.1446072E-04,   3.3350539E-04
     +,   3.5270824E-04,   3.7190382E-04,   3.9091427E-04
     +,   4.0955711E-04,   4.2764749E-04,   4.4500260E-04
     +,   4.6144746E-04,   4.7682051E-04,   4.9097795E-04
     +,   5.0379673E-04,   5.1518035E-04,   5.2506244E-04
     +,   5.3340819E-04,   5.4021517E-04,   5.4551585E-04
     +,   5.4937584E-04,   5.5189221E-04,   5.5319158E-04
     +,   5.5342657E-04,   5.5277225E-04,   5.5142143E-04
     +,   5.4957974E-04,   5.4746121E-04,   5.4528355E-04
     +,   5.4326316E-04,   5.4161216E-04,   5.4053392E-04
     +,   5.4022134E-04,   5.4085389E-04,   5.4259785E-04
     +,   5.4560526E-04,   5.5001362E-04,   5.5594824E-04
     +,   5.6352245E-04,   5.7284004E-04,   5.8399473E-04
     +,   5.9707381E-04,   6.1215652E-04,   6.2931684E-04
     +,   6.4862083E-04,   6.7012530E-04,   6.9388404E-04
     +,   7.1994500E-04,   7.4835698E-04,   7.7918998E-04
     +,   8.1255788E-04,   8.4865635E-04,   8.8782067E-04
     +,   9.3059475E-04,   9.7780046E-04,   1.0306030E-03
     +,   1.0905660E-03,   1.1597077E-03,   1.2405588E-03
     +,   1.3362889E-03,   1.4509344E-03,   1.5897242E-03
     +,   1.7593484E-03,   1.9678713E-03,   2.2239552E-03
     +,   2.5350677E-03,   2.9048542E-03,   3.3306906E-03
     +,   3.8028175E-03,   4.3062102E-03,   4.8253867E-03
     +,   5.3507234E-03,   5.8836127E-03,   6.4378730E-03
     +,   7.0360443E-03,   7.7009271E-03,   8.4450636E-03
     +,   9.2642251E-03,   1.0142432E-02,   1.1070164E-02
     +,   1.2061537E-02,   1.3147568E-02,   1.4340034E-02
     +,   1.5599621E-02,   1.6853299E-02,   1.8052351E-02
     +,   1.9195763E-02,   2.0274201E-02,   2.1207104E-02
     +,   2.1875639E-02,   2.2215730E-02,   2.2233179E-02
     +,   2.1914270E-02,   2.1174479E-02,   1.9944642E-02
     +,   1.8303351E-02,   1.6497400E-02,   1.4817587E-02
     +,   1.3444349E-02,   1.2386987E-02,   1.1536529E-02
     +,   1.0763007E-02,   9.9843619E-03,   9.1834087E-03
     +,   8.3894832E-03,   7.6488955E-03,   6.9995280E-03
     +,   6.4564492E-03,   6.0103731E-03,   5.6360611E-03
     +,   5.3044199E-03,   4.9917097E-03,   4.6832454E-03
     +,   4.3727858E-03,   4.0602633E-03,   3.7494756E-03
     +,   3.4461687E-03,   3.1564108E-03,   2.8852981E-03
     +,   2.6361267E-03,   2.4101213E-03,   2.2067714E-03
     +,   2.0245055E-03,   1.8613891E-03,   1.7155389E-03
     +,   1.5853448E-03,   1.4694276E-03,   1.3664875E-03
     +,   1.2751645E-03,   1.1939771E-03,   1.1213467E-03
     +,   1.0556802E-03,   9.9548069E-04,   9.3945157E-04
     +,   8.8656909E-04,   8.3609723E-04,   7.8757131E-04
     +,   7.4075517E-04,   6.9558818E-04,   6.5211608E-04
     +,   6.1044359E-04,   5.7069585E-04,   5.3298706E-04
     +,   4.9739983E-04,   4.6398054E-04,   4.3273956E-04
     +,   4.0364967E-04,   3.7665022E-04,   3.5165431E-04
     +,   3.2855629E-04,   3.0723205E-04,   2.8755039E-04
     +,   2.6937170E-04,   2.5255742E-04,   2.3696950E-04
     +,   2.2247768E-04,   2.0895828E-04,   1.9629978E-04
     +,   1.8440129E-04,   1.7317614E-04,   1.6254971E-04
     +,   1.5246007E-04,   1.4285835E-04,   1.3370502E-04
     +,   1.2497127E-04,   1.1663493E-04,   1.0868124E-04
     +,   1.0109924E-04,   9.3882205E-05,   8.7024651E-05
     +,   8.0523067E-05,   7.4373304E-05,   6.8571557E-05
     +,   6.3112369E-05,   5.7989768E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz100 = Yx/0.153511627906977
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9593447E-06,   8.0555901E-06
     +,   8.1512435E-06,   8.2463503E-06,   8.3409795E-06
     +,   8.4352114E-06,   8.5291513E-06,   8.6229229E-06
     +,   8.7166736E-06,   8.8105871E-06,   8.9048635E-06
     +,   8.9997511E-06,   9.0955209E-06,   9.1924885E-06
     +,   9.2910223E-06,   9.3915278E-06,   9.4944680E-06
     +,   9.6003650E-06,   9.7098064E-06,   9.8234359E-06
     +,   9.9419822E-06,   1.0066250E-05,   1.0197127E-05
     +,   1.0335605E-05,   1.0482758E-05,   1.0639779E-05
     +,   1.0807973E-05,   1.0988766E-05,   1.1183710E-05
     +,   1.1394499E-05,   1.1622977E-05,   1.1871130E-05
     +,   1.2141126E-05,   1.2435284E-05,   1.2756122E-05
     +,   1.3106334E-05,   1.3488822E-05,   1.3906681E-05
     +,   1.4363248E-05,   1.4862037E-05,   1.5406838E-05
     +,   1.6001652E-05,   1.6650729E-05,   1.7358565E-05
     +,   1.8129916E-05,   1.8969795E-05,   1.9883468E-05
     +,   2.0876472E-05,   2.1954600E-05,   2.3123912E-05
     +,   2.4390718E-05,   2.5761585E-05,   2.7243283E-05
     +,   2.8842927E-05,   3.0567648E-05,   3.2424974E-05
     +,   3.4422475E-05,   3.6567890E-05,   3.8869064E-05
     +,   4.1333875E-05,   4.3970227E-05,   4.6786005E-05
     +,   4.9788792E-05,   5.2986175E-05,   5.6385463E-05
     +,   5.9993301E-05,   6.3816202E-05,   6.7859633E-05
     +,   7.2128802E-05,   7.6627439E-05,   8.1358863E-05
     +,   8.6324537E-05,   9.1525180E-05,   9.6959360E-05
     +,   1.0262441E-04,   1.0851581E-04,   1.1462669E-04
     +,   1.2094789E-04,   1.2746840E-04,   1.3417481E-04
     +,   1.4105048E-04,   1.4807712E-04,   1.5523295E-04
     +,   1.6249437E-04,   1.6983447E-04,   1.7722475E-04
     +,   1.8463341E-04,   1.9202742E-04,   1.9937110E-04
     +,   2.0662774E-04,   2.1375944E-04,   2.2072684E-04
     +,   2.2749025E-04,   2.3401047E-04,   2.4024857E-04
     +,   2.4616614E-04,   2.5172709E-04,   2.5689648E-04
     +,   2.6164253E-04,   2.6593596E-04,   2.6975136E-04
     +,   2.7306672E-04,   2.7586462E-04,   2.7813169E-04
     +,   2.7985967E-04,   2.8104492E-04,   2.8168879E-04
     +,   2.8179749E-04,   2.8138221E-04,   2.8045860E-04
     +,   2.7904700E-04,   2.7717149E-04,   2.7486027E-04
     +,   2.7214459E-04,   2.6905866E-04,   2.6563881E-04
     +,   2.6192350E-04,   2.5795194E-04,   2.5376453E-04
     +,   2.4940149E-04,   2.4490259E-04,   2.4030718E-04
     +,   2.3565318E-04,   2.3097667E-04,   2.2631192E-04
     +,   2.2169111E-04,   2.1714371E-04,   2.1269696E-04
     +,   2.0837507E-04,   2.0420013E-04,   2.0019090E-04
     +,   1.9636450E-04,   1.9273498E-04,   1.8931477E-04
     +,   1.8611398E-04,   1.8314114E-04,   1.8040345E-04
     +,   1.7790709E-04,   1.7565701E-04,   1.7365793E-04
     +,   1.7191417E-04,   1.7043017E-04,   1.6921030E-04
     +,   1.6825978E-04,   1.6758435E-04,   1.6719069E-04
     +,   1.6708669E-04,   1.6728125E-04,   1.6778482E-04
     +,   1.6860945E-04,   1.6976871E-04,   1.7127773E-04
     +,   1.7315353E-04,   1.7541475E-04,   1.7808203E-04
     +,   1.8117754E-04,   1.8472520E-04,   1.8875061E-04
     +,   1.9328124E-04,   1.9834546E-04,   2.0397358E-04
     +,   2.1019703E-04,   2.1704813E-04,   2.2455989E-04
     +,   2.3276650E-04,   2.4170270E-04,   2.5140255E-04
     +,   2.6189993E-04,   2.7322807E-04,   2.8541897E-04
     +,   2.9850099E-04,   3.1249854E-04,   3.2743099E-04
     +,   3.4331079E-04,   3.6013869E-04,   3.7790413E-04
     +,   3.9658175E-04,   4.1612651E-04,   4.3647186E-04
     +,   4.5752979E-04,   4.7918822E-04,   5.0130970E-04
     +,   5.2373507E-04,   5.4629083E-04,   5.6879473E-04
     +,   5.9106684E-04,   6.1294710E-04,   6.3431851E-04
     +,   6.5513159E-04,   6.7543844E-04,   6.9543940E-04
     +,   7.1553123E-04,   7.3636440E-04,   7.5890985E-04
     +,   7.8452192E-04,   8.1498956E-04,   8.5256610E-04
     +,   8.9996232E-04,   9.6029160E-04,   1.0369492E-03
     +,   1.1334263E-03,   1.2530808E-03,   1.3988963E-03
     +,   1.5732455E-03,   1.7777113E-03,   2.0130817E-03
     +,   2.2794604E-03,   2.5765356E-03,   2.9039979E-03
     +,   3.2620388E-03,   3.6517475E-03,   4.0753568E-03
     +,   4.5362744E-03,   5.0387178E-03,   5.5866297E-03
     +,   6.1816936E-03,   6.8209306E-03,   7.4949050E-03
     +,   8.1885112E-03,   8.8862497E-03,   9.5826685E-03
     +,   1.0294362E-02,   1.1066026E-02,   1.1961198E-02
     +,   1.3033924E-02,   1.4290545E-02,   1.5660468E-02
     +,   1.6992856E-02,   1.8087257E-02,   1.8756781E-02
     +,   1.8908681E-02,   1.8599637E-02,   1.8016227E-02
     +,   1.7378280E-02,   1.6830316E-02,   1.6395167E-02
     +,   1.6003486E-02,   1.5553894E-02,   1.4961652E-02
     +,   1.4187524E-02,   1.3249718E-02,   1.2218120E-02
     +,   1.1190161E-02,   1.0258771E-02,   9.4856713E-03
     +,   8.8881478E-03,   8.4408773E-03,   8.0901431E-03
     +,   7.7743260E-03,   7.4428995E-03,   7.0676100E-03
     +,   6.6436785E-03,   6.1835647E-03,   5.7076481E-03
     +,   5.2361549E-03,   4.7843722E-03,   4.3612211E-03
     +,   3.9701294E-03,   3.6110273E-03,   3.2823903E-03
     +,   2.9826160E-03,   2.7105287E-03,   2.4652504E-03
     +,   2.2458069E-03,   2.0507579E-03,   1.8779759E-03
     +,   1.7247309E-03,   1.5879463E-03,   1.4645031E-03
     +,   1.3515466E-03,   1.2467079E-03,   1.1482298E-03
     +,   1.0549518E-03,   9.6622866E-04,   8.8181015E-04
     +,   8.0171030E-04,   7.2606327E-04,   6.5505080E-04
     +,   5.8881723E-04,   5.2745553E-04,   4.7097518E-04
     +,   4.1932103E-04,   3.7236555E-04,   3.2993243E-04
     +,   2.9179722E-04,   2.5770697E-04,   2.2738174E-04
     +,   2.0052656E-04,   1.7684142E-04,   1.5602224E-04
     +,   1.3777340E-04,   1.2180779E-04,   1.0785594E-04
     +,   9.5665455E-05,   8.5007050E-05,   7.5672760E-05
     +,   6.7479166E-05,   6.0264487E-05,   5.3889758E-05
     +,   4.8235306E-05,   4.3200500E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz104 = Yx/0.142
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5443318E-05,   1.5614680E-05
     +,   1.5776748E-05,   1.5929392E-05,   1.6072527E-05
     +,   1.6206111E-05,   1.6330161E-05,   1.6444734E-05
     +,   1.6549951E-05,   1.6645989E-05,   1.6733080E-05
     +,   1.6811511E-05,   1.6881640E-05,   1.6943883E-05
     +,   1.6998718E-05,   1.7046692E-05,   1.7088412E-05
     +,   1.7124556E-05,   1.7155866E-05,   1.7183140E-05
     +,   1.7207252E-05,   1.7229137E-05,   1.7249778E-05
     +,   1.7270240E-05,   1.7291615E-05,   1.7315075E-05
     +,   1.7341828E-05,   1.7373128E-05,   1.7410273E-05
     +,   1.7454595E-05,   1.7507455E-05,   1.7570246E-05
     +,   1.7644363E-05,   1.7731227E-05,   1.7832257E-05
     +,   1.7948860E-05,   1.8082437E-05,   1.8234361E-05
     +,   1.8405986E-05,   1.8598601E-05,   1.8813464E-05
     +,   1.9051771E-05,   1.9314641E-05,   1.9603120E-05
     +,   1.9918158E-05,   2.0260617E-05,   2.0631236E-05
     +,   2.1030661E-05,   2.1459391E-05,   2.1917813E-05
     +,   2.2406162E-05,   2.2924545E-05,   2.3472900E-05
     +,   2.4051060E-05,   2.4658635E-05,   2.5295141E-05
     +,   2.5959931E-05,   2.6652178E-05,   2.7370941E-05
     +,   2.8115102E-05,   2.8883445E-05,   2.9674613E-05
     +,   3.0487088E-05,   3.1319309E-05,   3.2169621E-05
     +,   3.3036224E-05,   3.3917335E-05,   3.4811044E-05
     +,   3.5715508E-05,   3.6628775E-05,   3.7549009E-05
     +,   3.8474300E-05,   3.9402894E-05,   4.0333023E-05
     +,   4.1263065E-05,   4.2191565E-05,   4.3117107E-05
     +,   4.4038443E-05,   4.4954577E-05,   4.5864694E-05
     +,   4.6768117E-05,   4.7664482E-05,   4.8553582E-05
     +,   4.9435537E-05,   5.0310642E-05,   5.1179541E-05
     +,   5.2043040E-05,   5.2902316E-05,   5.3758678E-05
     +,   5.4613814E-05,   5.5469613E-05,   5.6328146E-05
     +,   5.7191730E-05,   5.8062924E-05,   5.8944472E-05
     +,   5.9839174E-05,   6.0750132E-05,   6.1680381E-05
     +,   6.2633248E-05,   6.3611915E-05,   6.4619802E-05
     +,   6.5660162E-05,   6.6736364E-05,   6.7851608E-05
     +,   6.9009126E-05,   7.0212074E-05,   7.1463393E-05
     +,   7.2765884E-05,   7.4122239E-05,   7.5535019E-05
     +,   7.7006443E-05,   7.8538673E-05,   8.0133475E-05
     +,   8.1792539E-05,   8.3517210E-05,   8.5308675E-05
     +,   8.7167609E-05,   8.9094814E-05,   9.1090384E-05
     +,   9.3154427E-05,   9.5286763E-05,   9.7486751E-05
     +,   9.9753444E-05,   1.0208576E-04,   1.0448227E-04
     +,   1.0694104E-04,   1.0946011E-04,   1.1203681E-04
     +,   1.1466851E-04,   1.1735185E-04,   1.2008352E-04
     +,   1.2285936E-04,   1.2567530E-04,   1.2852655E-04
     +,   1.3140804E-04,   1.3431454E-04,   1.3724013E-04
     +,   1.4017856E-04,   1.4312344E-04,   1.4606805E-04
     +,   1.4900528E-04,   1.5192758E-04,   1.5482755E-04
     +,   1.5769759E-04,   1.6052979E-04,   1.6331630E-04
     +,   1.6604952E-04,   1.6872157E-04,   1.7132491E-04
     +,   1.7385236E-04,   1.7629704E-04,   1.7865242E-04
     +,   1.8091232E-04,   1.8307137E-04,   1.8512484E-04
     +,   1.8706849E-04,   1.8889883E-04,   1.9061343E-04
     +,   1.9221044E-04,   1.9368908E-04,   1.9504942E-04
     +,   1.9629252E-04,   1.9742051E-04,   1.9843644E-04
     +,   1.9934442E-04,   2.0014992E-04,   2.0085933E-04
     +,   2.0148049E-04,   2.0202264E-04,   2.0249658E-04
     +,   2.0291506E-04,   2.0329312E-04,   2.0364839E-04
     +,   2.0400216E-04,   2.0437989E-04,   2.0481243E-04
     +,   2.0533786E-04,   2.0600265E-04,   2.0686432E-04
     +,   2.0799442E-04,   2.0948121E-04,   2.1143346E-04
     +,   2.1398471E-04,   2.1729732E-04,   2.2156730E-04
     +,   2.2702734E-04,   2.3395065E-04,   2.4265265E-04
     +,   2.5349154E-04,   2.6686370E-04,   2.8320123E-04
     +,   3.0296276E-04,   3.2662106E-04,   3.5465090E-04
     +,   3.8751730E-04,   4.2566049E-04,   4.6948108E-04
     +,   5.1933358E-04,   5.7552592E-04,   6.3832122E-04
     +,   7.0794648E-04,   7.8461878E-04,   8.6859125E-04
     +,   9.6020201E-04,   1.0599332E-03,   1.1684987E-03
     +,   1.2868907E-03,   1.4163808E-03,   1.5584399E-03
     +,   1.7145459E-03,   1.8858425E-03,   2.0727285E-03
     +,   2.2745486E-03,   2.4896157E-03,   2.7157359E-03
     +,   2.9513687E-03,   3.1971568E-03,   3.4571991E-03
     +,   3.7392015E-03,   4.0529585E-03,   4.4073816E-03
     +,   4.8068915E-03,   5.2487357E-03,   5.7226778E-03
     +,   6.2138038E-03,   6.7080203E-03,   7.1988846E-03
     +,   7.6928781E-03,   8.2090180E-03,   8.7705189E-03
     +,   9.3935765E-03,   1.0084532E-02,   1.0850510E-02
     +,   1.1708967E-02,   1.2677311E-02,   1.3751290E-02
     +,   1.4902981E-02,   1.6100409E-02,   1.7309122E-02
     +,   1.8458867E-02,   1.9423870E-02,   2.0060984E-02
     +,   2.0277373E-02,   2.0065406E-02,   1.9488011E-02
     +,   1.8640885E-02,   1.7613186E-02,   1.6460769E-02
     +,   1.5214844E-02,   1.3927318E-02,   1.2701475E-02
     +,   1.1658523E-02,   1.0861343E-02,   1.0270158E-02
     +,   9.7709103E-03,   9.2465291E-03,   8.6346399E-03
     +,   7.9408530E-03,   7.2144046E-03,   6.5116989E-03
     +,   5.8701611E-03,   5.3008338E-03,   4.7956184E-03
     +,   4.3395059E-03,   3.9198454E-03,   3.5298395E-03
     +,   3.1677948E-03,   2.8345645E-03,   2.5311862E-03
     +,   2.2575860E-03,   2.0123424E-03,   1.7930453E-03
     +,   1.5967964E-03,   1.4206489E-03,   1.2619246E-03
     +,   1.1183618E-03,   9.8812662E-04,   8.6983020E-04
     +,   7.6244399E-04,   6.6525245E-04,   5.7773787E-04
     +,   4.9950986E-04,   4.3019524E-04,   3.6939044E-04
     +,   3.1659959E-04,   2.7123559E-04,   2.3261612E-04
     +,   1.9999694E-04,   1.7260981E-04,   1.4969266E-04
     +,   1.3052947E-04,   1.1446873E-04,   1.0094286E-04
     +,   8.9470093E-05,   7.9655729E-05,   7.1182061E-05
     +,   6.3800369E-05,   5.7317080E-05,   5.1584062E-05
     +,   4.6486672E-05,   4.1936302E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz106 = Yx/0.1385
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4414866E-05,   1.4938994E-05
     +,   1.5478423E-05,   1.6033524E-05,   1.6604656E-05
     +,   1.7192182E-05,   1.7796450E-05,   1.8417806E-05
     +,   1.9056566E-05,   1.9713068E-05,   2.0387599E-05
     +,   2.1080430E-05,   2.1791810E-05,   2.2521965E-05
     +,   2.3271081E-05,   2.4039316E-05,   2.4826795E-05
     +,   2.5633590E-05,   2.6459738E-05,   2.7305225E-05
     +,   2.8169990E-05,   2.9053932E-05,   2.9956856E-05
     +,   3.0878589E-05,   3.1818803E-05,   3.2777196E-05
     +,   3.3753367E-05,   3.4746856E-05,   3.5757166E-05
     +,   3.6783709E-05,   3.7825896E-05,   3.8883027E-05
     +,   3.9954401E-05,   4.1039228E-05,   4.2136715E-05
     +,   4.3246011E-05,   4.4366239E-05,   4.5496468E-05
     +,   4.6635858E-05,   4.7783396E-05,   4.8938211E-05
     +,   5.0099356E-05,   5.1265921E-05,   5.2437052E-05
     +,   5.3611868E-05,   5.4789605E-05,   5.5969485E-05
     +,   5.7150861E-05,   5.8333091E-05,   5.9515689E-05
     +,   6.0698214E-05,   6.1880353E-05,   6.3061882E-05
     +,   6.4242748E-05,   6.5422901E-05,   6.6602573E-05
     +,   6.7782035E-05,   6.8961745E-05,   7.0142225E-05
     +,   7.1324226E-05,   7.2508563E-05,   7.3696239E-05
     +,   7.4888303E-05,   7.6085984E-05,   7.7290671E-05
     +,   7.8503690E-05,   7.9726604E-05,   8.0960934E-05
     +,   8.2208346E-05,   8.3470419E-05,   8.4748877E-05
     +,   8.6045249E-05,   8.7361244E-05,   8.8698238E-05
     +,   9.0057794E-05,   9.1441230E-05,   9.2849652E-05
     +,   9.4283991E-05,   9.5745170E-05,   9.7233693E-05
     +,   9.8749857E-05,   1.0029374E-04,   1.0186504E-04
     +,   1.0346326E-04,   1.0508743E-04,   1.0673637E-04
     +,   1.0840843E-04,   1.1010173E-04,   1.1181392E-04
     +,   1.1354237E-04,   1.1528416E-04,   1.1703596E-04
     +,   1.1879405E-04,   1.2055465E-04,   1.2231365E-04
     +,   1.2406662E-04,   1.2580906E-04,   1.2753633E-04
     +,   1.2924381E-04,   1.3092661E-04,   1.3258013E-04
     +,   1.3419965E-04,   1.3578081E-04,   1.3731935E-04
     +,   1.3881124E-04,   1.4025296E-04,   1.4164120E-04
     +,   1.4297316E-04,   1.4424666E-04,   1.4545991E-04
     +,   1.4661180E-04,   1.4770182E-04,   1.4873005E-04
     +,   1.4969743E-04,   1.5060534E-04,   1.5145590E-04
     +,   1.5225196E-04,   1.5299699E-04,   1.5369488E-04
     +,   1.5435030E-04,   1.5496829E-04,   1.5555425E-04
     +,   1.5611398E-04,   1.5665352E-04,   1.5717915E-04
     +,   1.5769700E-04,   1.5821331E-04,   1.5873408E-04
     +,   1.5926508E-04,   1.5981164E-04,   1.6037864E-04
     +,   1.6097035E-04,   1.6159040E-04,   1.6224165E-04
     +,   1.6292594E-04,   1.6364454E-04,   1.6439750E-04
     +,   1.6518397E-04,   1.6600230E-04,   1.6684966E-04
     +,   1.6772249E-04,   1.6861626E-04,   1.6952569E-04
     +,   1.7044488E-04,   1.7136730E-04,   1.7228612E-04
     +,   1.7319416E-04,   1.7408439E-04,   1.7494957E-04
     +,   1.7578319E-04,   1.7657918E-04,   1.7733221E-04
     +,   1.7803808E-04,   1.7869382E-04,   1.7929821E-04
     +,   1.7985137E-04,   1.8035575E-04,   1.8081574E-04
     +,   1.8123815E-04,   1.8163225E-04,   1.8200986E-04
     +,   1.8238557E-04,   1.8277639E-04,   1.8320225E-04
     +,   1.8368546E-04,   1.8425081E-04,   1.8492526E-04
     +,   1.8573768E-04,   1.8671862E-04,   1.8789998E-04
     +,   1.8931429E-04,   1.9099457E-04,   1.9297389E-04
     +,   1.9528488E-04,   1.9795935E-04,   2.0102834E-04
     +,   2.0452178E-04,   2.0846841E-04,   2.1289631E-04
     +,   2.1783343E-04,   2.2330858E-04,   2.2935160E-04
     +,   2.3599538E-04,   2.4327726E-04,   2.5124082E-04
     +,   2.5993638E-04,   2.6942341E-04,   2.7977195E-04
     +,   2.9106380E-04,   3.0339093E-04,   3.1685803E-04
     +,   3.3158070E-04,   3.4768271E-04,   3.6529556E-04
     +,   3.8455665E-04,   4.0560745E-04,   4.2858964E-04
     +,   4.5364612E-04,   4.8092342E-04,   5.1057257E-04
     +,   5.4275274E-04,   5.7763845E-04,   6.1543100E-04
     +,   6.5636385E-04,   7.0070697E-04,   7.4877654E-04
     +,   8.0092758E-04,   8.5753627E-04,   9.1897493E-04
     +,   9.8557502E-04,   1.0575764E-03,   1.1350734E-03
     +,   1.2179947E-03,   1.3061285E-03,   1.3992095E-03
     +,   1.4970894E-03,   1.6000046E-03,   1.7088680E-03
     +,   1.8255146E-03,   1.9527543E-03,   2.0942097E-03
     +,   2.2538165E-03,   2.4351017E-03,   2.6405398E-03
     +,   2.8713210E-03,   3.1278455E-03,   3.4110753E-03
     +,   3.7243606E-03,   4.0748622E-03,   4.4734241E-03
     +,   4.9323174E-03,   5.4613692E-03,   6.0640089E-03
     +,   6.7351749E-03,   7.4624135E-03,   8.2302243E-03
     +,   9.0250457E-03,   9.8374849E-03,   1.0658978E-02
     +,   1.1475296E-02,   1.2265223E-02,   1.3013708E-02
     +,   1.3735683E-02,   1.4488521E-02,   1.5346716E-02
     +,   1.6339928E-02,   1.7395495E-02,   1.8343002E-02
     +,   1.8995829E-02,   1.9256685E-02,   1.9164616E-02
     +,   1.8849788E-02,   1.8439846E-02,   1.7989142E-02
     +,   1.7465614E-02,   1.6786354E-02,   1.5875509E-02
     +,   1.4716770E-02,   1.3374013E-02,   1.1967506E-02
     +,   1.0621936E-02,   9.4205877E-03,   8.3907414E-03
     +,   7.5180158E-03,   6.7706937E-03,   6.1173672E-03
     +,   5.5340882E-03,   5.0045098E-03,   4.5180866E-03
     +,   4.0687788E-03,   3.6542476E-03,   3.2746750E-03
     +,   2.9310321E-03,   2.6234230E-03,   2.3501781E-03
     +,   2.1079087E-03,   1.8921649E-03,   1.6984342E-03
     +,   1.5228286E-03,   1.3624917E-03,   1.2155478E-03
     +,   1.0809207E-03,   9.5798844E-04,   8.4634760E-04
     +,   7.4559334E-04,   6.5524789E-04,   5.7471014E-04
     +,   5.0328090E-04,   4.4020399E-04,   3.8468905E-04
     +,   3.3596077E-04,   2.9326885E-04,   2.5591659E-04
     +,   2.2325999E-04,   1.9472103E-04,   1.6977974E-04
     +,   1.4797984E-04,   1.2891814E-04,   1.1224539E-04
     +,   9.7655880E-05,   8.4886407E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz108 = Yx/0.1365
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.6257405E-06,   4.8446254E-06
     +,   5.0737708E-06,   5.3137196E-06,   5.5650439E-06
     +,   5.8283517E-06,   6.1042779E-06,   6.3934926E-06
     +,   6.6966959E-06,   7.0146325E-06,   7.3480728E-06
     +,   7.6978195E-06,   8.0647133E-06,   8.4496232E-06
     +,   8.8534534E-06,   9.2771361E-06,   9.7216362E-06
     +,   1.0187936E-05,   1.0677050E-05,   1.1190011E-05
     +,   1.1727865E-05,   1.2291675E-05,   1.2882501E-05
     +,   1.3501449E-05,   1.4149554E-05,   1.4827907E-05
     +,   1.5537556E-05,   1.6279526E-05,   1.7054830E-05
     +,   1.7864430E-05,   1.8709254E-05,   1.9590179E-05
     +,   2.0508023E-05,   2.1463535E-05,   2.2457378E-05
     +,   2.3490151E-05,   2.4562345E-05,   2.5674322E-05
     +,   2.6826423E-05,   2.8018734E-05,   2.9251345E-05
     +,   3.0524137E-05,   3.1836873E-05,   3.3189164E-05
     +,   3.4580458E-05,   3.6010082E-05,   3.7477177E-05
     +,   3.8980717E-05,   4.0519531E-05,   4.2092284E-05
     +,   4.3697477E-05,   4.5333432E-05,   4.6998313E-05
     +,   4.8690243E-05,   5.0407001E-05,   5.2146417E-05
     +,   5.3906078E-05,   5.5683540E-05,   5.7476169E-05
     +,   5.9281294E-05,   6.1096136E-05,   6.2917919E-05
     +,   6.4743668E-05,   6.6570523E-05,   6.8395639E-05
     +,   7.0215974E-05,   7.2028728E-05,   7.3830917E-05
     +,   7.5619850E-05,   7.7392680E-05,   7.9146819E-05
     +,   8.0879632E-05,   8.2588806E-05,   8.4271851E-05
     +,   8.5926717E-05,   8.7551387E-05,   8.9143963E-05
     +,   9.0702684E-05,   9.2226095E-05,   9.3712879E-05
     +,   9.5161784E-05,   9.6571886E-05,   9.7942277E-05
     +,   9.9272387E-05,   1.0056164E-04,   1.0180980E-04
     +,   1.0301653E-04,   1.0418184E-04,   1.0530573E-04
     +,   1.0638838E-04,   1.0742999E-04,   1.0843086E-04
     +,   1.0939125E-04,   1.1031159E-04,   1.1119230E-04
     +,   1.1203360E-04,   1.1283594E-04,   1.1359953E-04
     +,   1.1432466E-04,   1.1501143E-04,   1.1565992E-04
     +,   1.1627004E-04,   1.1684172E-04,   1.1737461E-04
     +,   1.1786834E-04,   1.1832241E-04,   1.1873616E-04
     +,   1.1910879E-04,   1.1943946E-04,   1.1972721E-04
     +,   1.1997094E-04,   1.2016951E-04,   1.2032177E-04
     +,   1.2042646E-04,   1.2048239E-04,   1.2048833E-04
     +,   1.2044315E-04,   1.2034578E-04,   1.2019528E-04
     +,   1.1999088E-04,   1.1973197E-04,   1.1941819E-04
     +,   1.1904947E-04,   1.1862601E-04,   1.1814835E-04
     +,   1.1761748E-04,   1.1703478E-04,   1.1640207E-04
     +,   1.1572164E-04,   1.1499642E-04,   1.1422976E-04
     +,   1.1342570E-04,   1.1258879E-04,   1.1172435E-04
     +,   1.1083816E-04,   1.0993672E-04,   1.0902722E-04
     +,   1.0811754E-04,   1.0721600E-04,   1.0633167E-04
     +,   1.0547422E-04,   1.0465381E-04,   1.0388115E-04
     +,   1.0316728E-04,   1.0252377E-04,   1.0196243E-04
     +,   1.0149516E-04,   1.0113418E-04,   1.0089156E-04
     +,   1.0077926E-04,   1.0080901E-04,   1.0099220E-04
     +,   1.0133954E-04,   1.0186122E-04,   1.0256643E-04
     +,   1.0346352E-04,   1.0455951E-04,   1.0586025E-04
     +,   1.0737011E-04,   1.0909181E-04,   1.1102643E-04
     +,   1.1317332E-04,   1.1552984E-04,   1.1809138E-04
     +,   1.2085147E-04,   1.2380187E-04,   1.2693221E-04
     +,   1.3023034E-04,   1.3368277E-04,   1.3727458E-04
     +,   1.4098952E-04,   1.4481075E-04,   1.4872113E-04
     +,   1.5270388E-04,   1.5674259E-04,   1.6082269E-04
     +,   1.6493184E-04,   1.6906059E-04,   1.7320357E-04
     +,   1.7736081E-04,   1.8153862E-04,   1.8575038E-04
     +,   1.9001811E-04,   1.9437373E-04,   1.9886042E-04
     +,   2.0353282E-04,   2.0845860E-04,   2.1371915E-04
     +,   2.1940997E-04,   2.2563968E-04,   2.3253117E-04
     +,   2.4021966E-04,   2.4885096E-04,   2.5857956E-04
     +,   2.6956672E-04,   2.8197659E-04,   2.9597193E-04
     +,   3.1171006E-04,   3.2934014E-04,   3.4899669E-04
     +,   3.7079511E-04,   3.9482629E-04,   4.2115466E-04
     +,   4.4981245E-04,   4.8079193E-04,   5.1404716E-04
     +,   5.4948771E-04,   5.8697350E-04,   6.2631397E-04
     +,   6.6727086E-04,   7.0955674E-04,   7.5283932E-04
     +,   7.9675246E-04,   8.4091758E-04,   8.8496564E-04
     +,   9.2857005E-04,   9.7149512E-04,   1.0136504E-03
     +,   1.0551477E-03,   1.0963519E-03,   1.1379340E-03
     +,   1.1808919E-03,   1.2265292E-03,   1.2764010E-03
     +,   1.3321983E-03,   1.3955738E-03,   1.4679146E-03
     +,   1.5501088E-03,   1.6423520E-03,   1.7440473E-03
     +,   1.8539049E-03,   1.9703524E-03,   2.0923275E-03
     +,   2.2205107E-03,   2.3589940E-03,   2.5172979E-03
     +,   2.7121520E-03,   2.9680997E-03,   3.3155426E-03
     +,   3.7851471E-03,   4.3990081E-03,   5.1615476E-03
     +,   6.0551590E-03,   7.0445319E-03,   8.0884919E-03
     +,   9.1527086E-03,   1.0214800E-02,   1.1260049E-02
     +,   1.2276989E-02,   1.3266077E-02,   1.4260477E-02
     +,   1.5332368E-02,   1.6551549E-02,   1.7898574E-02
     +,   1.9196508E-02,   2.0144872E-02,   2.0467194E-02
     +,   2.0072423E-02,   1.9106461E-02,   1.7865309E-02
     +,   1.6649406E-02,   1.5649855E-02,   1.4903312E-02
     +,   1.4312380E-02,   1.3717148E-02,   1.2989127E-02
     +,   1.2098416E-02,   1.1116198E-02,   1.0157603E-02
     +,   9.3095768E-03,   8.5902121E-03,   7.9558007E-03
     +,   7.3394659E-03,   6.6915816E-03,   5.9998822E-03
     +,   5.2853879E-03,   4.5844219E-03,   3.9309268E-03
     +,   3.3463568E-03,   2.8383632E-03,   2.4041650E-03
     +,   2.0354730E-03,   1.7222628E-03,   1.4552471E-03
     +,   1.2267968E-03,   1.0310947E-03,   8.6369214E-04
     +,   7.2103558E-04,   6.0007675E-04,   4.9801957E-04
     +,   4.1228381E-04,   3.4049564E-04,   2.8055022E-04
     +,   2.3061418E-04,   1.8913517E-04,   1.5479742E-04
     +,   1.2649152E-04,   1.0326588E-04,   8.4301457E-05
     +,   6.8883855E-05,   5.6394430E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz110 = Yx/0.126833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.1581302E-06,   8.5754218E-06
     +,   9.0069434E-06,   9.4527804E-06,   9.9130011E-06
     +,   1.0387654E-05,   1.0876773E-05,   1.1380368E-05
     +,   1.1898434E-05,   1.2430971E-05,   1.2977934E-05
     +,   1.3539277E-05,   1.4114939E-05,   1.4704843E-05
     +,   1.5308908E-05,   1.5927033E-05,   1.6559105E-05
     +,   1.7205017E-05,   1.7864637E-05,   1.8537829E-05
     +,   1.9224464E-05,   1.9924391E-05,   2.0637452E-05
     +,   2.1363530E-05,   2.2102422E-05,   2.2854005E-05
     +,   2.3618100E-05,   2.4394554E-05,   2.5183192E-05
     +,   2.5983845E-05,   2.6796335E-05,   2.7620494E-05
     +,   2.8456134E-05,   2.9303070E-05,   3.0161103E-05
     +,   3.1030031E-05,   3.1909647E-05,   3.2799704E-05
     +,   3.3700020E-05,   3.4610279E-05,   3.5530251E-05
     +,   3.6459660E-05,   3.7398182E-05,   3.8345504E-05
     +,   3.9301296E-05,   4.0265175E-05,   4.1236770E-05
     +,   4.2215670E-05,   4.3201439E-05,   4.4193646E-05
     +,   4.5191813E-05,   4.6195459E-05,   4.7204074E-05
     +,   4.8217196E-05,   4.9234251E-05,   5.0254777E-05
     +,   5.1278239E-05,   5.2304156E-05,   5.3332027E-05
     +,   5.4361415E-05,   5.5391891E-05,   5.6423094E-05
     +,   5.7454636E-05,   5.8486297E-05,   5.9517886E-05
     +,   6.0549228E-05,   6.1580351E-05,   6.2611260E-05
     +,   6.3642168E-05,   6.4673288E-05,   6.5705091E-05
     +,   6.6737986E-05,   6.7772722E-05,   6.8809983E-05
     +,   6.9850685E-05,   7.0895898E-05,   7.1946735E-05
     +,   7.3004405E-05,   7.4070325E-05,   7.5145981E-05
     +,   7.6232849E-05,   7.7332639E-05,   7.8446879E-05
     +,   7.9577381E-05,   8.0725731E-05,   8.1893610E-05
     +,   8.3082610E-05,   8.4294283E-05,   8.5529959E-05
     +,   8.6790889E-05,   8.8078217E-05,   8.9392692E-05
     +,   9.0734895E-05,   9.2105147E-05,   9.3503433E-05
     +,   9.4929339E-05,   9.6382173E-05,   9.7860655E-05
     +,   9.9363358E-05,   1.0088808E-04,   1.0243247E-04
     +,   1.0399345E-04,   1.0556770E-04,   1.0715119E-04
     +,   1.0873963E-04,   1.1032826E-04,   1.1191179E-04
     +,   1.1348449E-04,   1.1504046E-04,   1.1657336E-04
     +,   1.1807651E-04,   1.1954310E-04,   1.2096603E-04
     +,   1.2233817E-04,   1.2365224E-04,   1.2490111E-04
     +,   1.2607752E-04,   1.2717456E-04,   1.2818535E-04
     +,   1.2910344E-04,   1.2992274E-04,   1.3063745E-04
     +,   1.3124237E-04,   1.3173289E-04,   1.3210495E-04
     +,   1.3235518E-04,   1.3248099E-04,   1.3248053E-04
     +,   1.3235275E-04,   1.3209751E-04,   1.3171550E-04
     +,   1.3120839E-04,   1.3057864E-04,   1.2982984E-04
     +,   1.2896635E-04,   1.2799345E-04,   1.2691750E-04
     +,   1.2574569E-04,   1.2448603E-04,   1.2314740E-04
     +,   1.2173960E-04,   1.2027317E-04,   1.1875941E-04
     +,   1.1721017E-04,   1.1563821E-04,   1.1405670E-04
     +,   1.1247929E-04,   1.1092019E-04,   1.0939415E-04
     +,   1.0791594E-04,   1.0650068E-04,   1.0516375E-04
     +,   1.0392057E-04,   1.0278649E-04,   1.0177674E-04
     +,   1.0090646E-04,   1.0019046E-04,   9.9643163E-05
     +,   9.9278441E-05,   9.9109733E-05,   9.9149707E-05
     +,   9.9410325E-05,   9.9902689E-05,   1.0063696E-04
     +,   1.0162234E-04,   1.0286702E-04,   1.0437795E-04
     +,   1.0616099E-04,   1.0822083E-04,   1.1056098E-04
     +,   1.1318369E-04,   1.1608987E-04,   1.1927939E-04
     +,   1.2275111E-04,   1.2650226E-04,   1.3052947E-04
     +,   1.3482828E-04,   1.3939309E-04,   1.4421724E-04
     +,   1.4929364E-04,   1.5461436E-04,   1.6017056E-04
     +,   1.6595256E-04,   1.7195051E-04,   1.7815400E-04
     +,   1.8455186E-04,   1.9113223E-04,   1.9788354E-04
     +,   2.0479382E-04,   2.1185054E-04,   2.1904189E-04
     +,   2.2635648E-04,   2.3378362E-04,   2.4131390E-04
     +,   2.4894072E-04,   2.5666077E-04,   2.6447474E-04
     +,   2.7238941E-04,   2.8041957E-04,   2.8859050E-04
     +,   2.9693890E-04,   3.0551702E-04,   3.1439617E-04
     +,   3.2366917E-04,   3.3345350E-04,   3.4389662E-04
     +,   3.5517837E-04,   3.6751328E-04,   3.8115311E-04
     +,   3.9638873E-04,   4.1354776E-04,   4.3298915E-04
     +,   4.5509680E-04,   4.8026838E-04,   5.0889904E-04
     +,   5.4135831E-04,   5.7796721E-04,   6.1897747E-04
     +,   6.6454423E-04,   7.1470556E-04,   7.6938252E-04
     +,   8.2838198E-04,   8.9141587E-04,   9.5814356E-04
     +,   1.0282287E-03,   1.1013910E-03,   1.1774530E-03
     +,   1.2563688E-03,   1.3382282E-03,   1.4232075E-03
     +,   1.5114832E-03,   1.6031335E-03,   1.6980368E-03
     +,   1.7957927E-03,   1.8957044E-03,   1.9968860E-03
     +,   2.0984632E-03,   2.1999180E-03,   2.3015586E-03
     +,   2.4050623E-03,   2.5139619E-03,   2.6339150E-03
     +,   2.7725636E-03,   2.9388261E-03,   3.1416281E-03
     +,   3.3883634E-03,   3.6837345E-03,   4.0296069E-03
     +,   4.4263075E-03,   4.8751850E-03,   5.3817253E-03
     +,   5.9574940E-03,   6.6194041E-03,   7.3851896E-03
     +,   8.2660029E-03,   9.2598032E-03,   1.0351443E-02
     +,   1.1522779E-02,   1.2767501E-02,   1.4095896E-02
     +,   1.5515022E-02,   1.6984774E-02,   1.8378375E-02
     +,   1.9491341E-02,   2.0116087E-02,   2.0141056E-02
     +,   1.9604227E-02,   1.8671803E-02,   1.7566882E-02
     +,   1.6488215E-02,   1.5544637E-02,   1.4727949E-02
     +,   1.3943681E-02,   1.3085307E-02,   1.2101691E-02
     +,   1.1015598E-02,   9.8939259E-03,   8.8044163E-03
     +,   7.7877035E-03,   6.8538352E-03,   5.9932801E-03
     +,   5.1917722E-03,   4.4405935E-03,   3.7405693E-03
     +,   3.0998343E-03,   2.5287890E-03,   2.0348744E-03
     +,   1.6198008E-03,   1.2794730E-03,   1.0055878E-03
     +,   7.8795780E-04,   6.1629136E-04,   4.8137951E-04
     +,   3.7551534E-04,   2.9255127E-04,   2.2766490E-04
     +,   1.7710472E-04,   1.3791067E-04,   1.0772102E-04
     +,   8.4616215E-05,   6.7032466E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz112 = Yx/0.12019512195122
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5791451E-05,   1.6300268E-05
     +,   1.6820064E-05,   1.7350379E-05,   1.7890696E-05
     +,   1.8440431E-05,   1.8998950E-05,   1.9565547E-05
     +,   2.0139452E-05,   2.0719855E-05,   2.1305877E-05
     +,   2.1896576E-05,   2.2490951E-05,   2.3087963E-05
     +,   2.3686520E-05,   2.4285488E-05,   2.4883679E-05
     +,   2.5479880E-05,   2.6072841E-05,   2.6661288E-05
     +,   2.7243916E-05,   2.7819418E-05,   2.8386467E-05
     +,   2.8943748E-05,   2.9489918E-05,   3.0023677E-05
     +,   3.0543735E-05,   3.1048803E-05,   3.1537656E-05
     +,   3.2009080E-05,   3.2461936E-05,   3.2895103E-05
     +,   3.3307544E-05,   3.3698299E-05,   3.4066448E-05
     +,   3.4411169E-05,   3.4731736E-05,   3.5027497E-05
     +,   3.5297919E-05,   3.5542544E-05,   3.5761037E-05
     +,   3.5953173E-05,   3.6118850E-05,   3.6258069E-05
     +,   3.6370951E-05,   3.6457765E-05,   3.6518883E-05
     +,   3.6554808E-05,   3.6566176E-05,   3.6553742E-05
     +,   3.6518410E-05,   3.6461181E-05,   3.6383211E-05
     +,   3.6285765E-05,   3.6170251E-05,   3.6038175E-05
     +,   3.5891186E-05,   3.5731038E-05,   3.5559624E-05
     +,   3.5378915E-05,   3.5191024E-05,   3.4998156E-05
     +,   3.4802637E-05,   3.4606874E-05,   3.4413388E-05
     +,   3.4224795E-05,   3.4043784E-05,   3.3873166E-05
     +,   3.3715798E-05,   3.3574637E-05,   3.3452707E-05
     +,   3.3353099E-05,   3.3278968E-05,   3.3233518E-05
     +,   3.3220003E-05,   3.3241708E-05,   3.3301963E-05
     +,   3.3404081E-05,   3.3551420E-05,   3.3747314E-05
     +,   3.3995046E-05,   3.4297918E-05,   3.4659104E-05
     +,   3.5081757E-05,   3.5568894E-05,   3.6123449E-05
     +,   3.6748163E-05,   3.7445654E-05,   3.8218281E-05
     +,   3.9068229E-05,   3.9997441E-05,   4.1007512E-05
     +,   4.2099706E-05,   4.3275009E-05,   4.4534027E-05
     +,   4.5876874E-05,   4.7303343E-05,   4.8812588E-05
     +,   5.0403483E-05,   5.2074189E-05,   5.3822507E-05
     +,   5.5645509E-05,   5.7539884E-05,   5.9501555E-05
     +,   6.1526014E-05,   6.3608219E-05,   6.5742403E-05
     +,   6.7922265E-05,   7.0141083E-05,   7.2391689E-05
     +,   7.4666154E-05,   7.6956465E-05,   7.9253907E-05
     +,   8.1549762E-05,   8.3834675E-05,   8.6099462E-05
     +,   8.8334462E-05,   9.0530208E-05,   9.2677015E-05
     +,   9.4765477E-05,   9.6786338E-05,   9.8730452E-05
     +,   1.0058907E-04,   1.0235393E-04,   1.0401726E-04
     +,   1.0557170E-04,   1.0701075E-04,   1.0832842E-04
     +,   1.0951963E-04,   1.1058005E-04,   1.1150626E-04
     +,   1.1229569E-04,   1.1294680E-04,   1.1345890E-04
     +,   1.1383236E-04,   1.1406849E-04,   1.1416958E-04
     +,   1.1413888E-04,   1.1398053E-04,   1.1369961E-04
     +,   1.1330202E-04,   1.1279456E-04,   1.1218467E-04
     +,   1.1148051E-04,   1.1069098E-04,   1.0982543E-04
     +,   1.0889368E-04,   1.0790610E-04,   1.0687335E-04
     +,   1.0580636E-04,   1.0471618E-04,   1.0361411E-04
     +,   1.0251151E-04,   1.0141968E-04,   1.0034980E-04
     +,   9.9313052E-05,   9.8320408E-05,   9.7382544E-05
     +,   9.6509852E-05,   9.5712516E-05,   9.5000243E-05
     +,   9.4382398E-05,   9.3867893E-05,   9.3465249E-05
     +,   9.3182432E-05,   9.3026880E-05,   9.3005561E-05
     +,   9.3124858E-05,   9.3390554E-05,   9.3807867E-05
     +,   9.4381365E-05,   9.5114920E-05,   9.6011878E-05
     +,   9.7074830E-05,   9.8305638E-05,   9.9705569E-05
     +,   1.0127522E-04,   1.0301446E-04,   1.0492248E-04
     +,   1.0699801E-04,   1.0923928E-04,   1.1164395E-04
     +,   1.1420938E-04,   1.1693291E-04,   1.1981193E-04
     +,   1.2284389E-04,   1.2602685E-04,   1.2935973E-04
     +,   1.3284282E-04,   1.3647764E-04,   1.4026805E-04
     +,   1.4422051E-04,   1.4834425E-04,   1.5265224E-04
     +,   1.5716204E-04,   1.6189637E-04,   1.6688339E-04
     +,   1.7215816E-04,   1.7776439E-04,   1.8375478E-04
     +,   1.9019302E-04,   1.9715571E-04,   2.0473541E-04
     +,   2.1304269E-04,   2.2220852E-04,   2.3238915E-04
     +,   2.4376871E-04,   2.5656135E-04,   2.7101504E-04
     +,   2.8741371E-04,   3.0607861E-04,   3.2736530E-04
     +,   3.5166234E-04,   3.7938813E-04,   4.1098165E-04
     +,   4.4688888E-04,   4.8754827E-04,   5.3337304E-04
     +,   5.8472098E-04,   6.4185838E-04,   7.0492754E-04
     +,   7.7390147E-04,   8.4853242E-04,   9.2831580E-04
     +,   1.0124642E-03,   1.0998931E-03,   1.1892291E-03
     +,   1.2788660E-03,   1.3670621E-03,   1.4520643E-03
     +,   1.5322601E-03,   1.6063711E-03,   1.6736381E-03
     +,   1.7339705E-03,   1.7880459E-03,   1.8373451E-03
     +,   1.8840663E-03,   1.9309394E-03,   1.9809629E-03
     +,   2.0370889E-03,   2.1019385E-03,   2.1776150E-03
     +,   2.2656773E-03,   2.3672709E-03,   2.4833630E-03
     +,   2.6149093E-03,   2.7629912E-03,   2.9289967E-03
     +,   3.1151876E-03,   3.3260905E-03,   3.5708288E-03
     +,   3.8655002E-03,   4.2340639E-03,   4.7058794E-03
     +,   5.3090299E-03,   6.0603493E-03,   6.9552027E-03
     +,   7.9618143E-03,   9.0247300E-03,   1.0079735E-02
     +,   1.1077870E-02,   1.2011247E-02,   1.2929403E-02
     +,   1.3934041E-02,   1.5140749E-02,   1.6607773E-02
     +,   1.8260410E-02,   1.9869674E-02,   2.1126889E-02
     +,   2.1779450E-02,   2.1732636E-02,   2.1054218E-02
     +,   1.9909931E-02,   1.8492218E-02,   1.6968522E-02
     +,   1.5444090E-02,   1.3949724E-02,   1.2468868E-02
     +,   1.0984627E-02,   9.5110061E-03,   8.0906814E-03
     +,   6.7743710E-03,   5.6005903E-03,   4.5863697E-03
     +,   3.7276933E-03,   3.0070678E-03,   2.4027131E-03
     +,   1.8957228E-03,   1.4727266E-03,   1.1246538E-03
     +,   8.4427680E-04,   6.2410306E-04,   4.5572600E-04
     +,   3.3008817E-04,   2.3827970E-04,   1.7220720E-04
     +,   1.2505730E-04,   9.1427988E-05,   6.7274312E-05
     +,   4.9702259E-05,   3.6726418E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz113 = Yx/0.117292682926829
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.5938567E-06,   9.8989849E-06
     +,   1.0209111E-05,   1.0524105E-05,   1.0843836E-05
     +,   1.1168161E-05,   1.1496930E-05,   1.1829990E-05
     +,   1.2167166E-05,   1.2508300E-05,   1.2853209E-05
     +,   1.3201711E-05,   1.3553623E-05,   1.3908751E-05
     +,   1.4266901E-05,   1.4627884E-05,   1.4991504E-05
     +,   1.5357566E-05,   1.5725876E-05,   1.6096243E-05
     +,   1.6468486E-05,   1.6842423E-05,   1.7217879E-05
     +,   1.7594713E-05,   1.7972747E-05,   1.8351859E-05
     +,   1.8731920E-05,   1.9112827E-05,   1.9494488E-05
     +,   1.9876834E-05,   2.0259818E-05,   2.0643422E-05
     +,   2.1027645E-05,   2.1412519E-05,   2.1798109E-05
     +,   2.2184509E-05,   2.2571845E-05,   2.2960279E-05
     +,   2.3350021E-05,   2.3741286E-05,   2.4134371E-05
     +,   2.4529598E-05,   2.4927322E-05,   2.5327952E-05
     +,   2.5731933E-05,   2.6139756E-05,   2.6551963E-05
     +,   2.6969134E-05,   2.7391896E-05,   2.7820921E-05
     +,   2.8256911E-05,   2.8700622E-05,   2.9152839E-05
     +,   2.9614415E-05,   3.0086183E-05,   3.0569059E-05
     +,   3.1063966E-05,   3.1571850E-05,   3.2093689E-05
     +,   3.2630483E-05,   3.3183227E-05,   3.3752949E-05
     +,   3.4340654E-05,   3.4947363E-05,   3.5574132E-05
     +,   3.6221914E-05,   3.6891735E-05,   3.7584530E-05
     +,   3.8301281E-05,   3.9042843E-05,   3.9810129E-05
     +,   4.0603914E-05,   4.1425017E-05,   4.2274096E-05
     +,   4.3151838E-05,   4.4058874E-05,   4.4995690E-05
     +,   4.5962697E-05,   4.6960304E-05,   4.7988829E-05
     +,   4.9048431E-05,   5.0139293E-05,   5.1261399E-05
     +,   5.2414784E-05,   5.3599237E-05,   5.4814624E-05
     +,   5.6060584E-05,   5.7336820E-05,   5.8642810E-05
     +,   5.9978065E-05,   6.1342042E-05,   6.2734041E-05
     +,   6.4153290E-05,   6.5599073E-05,   6.7070621E-05
     +,   6.8566980E-05,   7.0087321E-05,   7.1630639E-05
     +,   7.3196061E-05,   7.4782525E-05,   7.6389129E-05
     +,   7.8014804E-05,   7.9658595E-05,   8.1319427E-05
     +,   8.2996325E-05,   8.4688334E-05,   8.6394357E-05
     +,   8.8113375E-05,   8.9844405E-05,   9.1586429E-05
     +,   9.3338342E-05,   9.5099153E-05,   9.6867654E-05
     +,   9.8642813E-05,   1.0042331E-04,   1.0220797E-04
     +,   1.0399535E-04,   1.0578409E-04,   1.0757253E-04
     +,   1.0935901E-04,   1.1114176E-04,   1.1291870E-04
     +,   1.1468764E-04,   1.1644624E-04,   1.1819201E-04
     +,   1.1992203E-04,   1.2163345E-04,   1.2332294E-04
     +,   1.2498713E-04,   1.2662228E-04,   1.2822459E-04
     +,   1.2978991E-04,   1.3131405E-04,   1.3279240E-04
     +,   1.3422048E-04,   1.3559358E-04,   1.3690685E-04
     +,   1.3815545E-04,   1.3933454E-04,   1.4043938E-04
     +,   1.4146524E-04,   1.4240749E-04,   1.4326198E-04
     +,   1.4402454E-04,   1.4469142E-04,   1.4525942E-04
     +,   1.4572557E-04,   1.4608764E-04,   1.4634366E-04
     +,   1.4649268E-04,   1.4653409E-04,   1.4646827E-04
     +,   1.4629617E-04,   1.4601964E-04,   1.4564129E-04
     +,   1.4516455E-04,   1.4459385E-04,   1.4393426E-04
     +,   1.4319175E-04,   1.4237320E-04,   1.4148610E-04
     +,   1.4053867E-04,   1.3953999E-04,   1.3849960E-04
     +,   1.3742765E-04,   1.3633468E-04,   1.3523173E-04
     +,   1.3413008E-04,   1.3304115E-04,   1.3197651E-04
     +,   1.3094774E-04,   1.2996633E-04,   1.2904337E-04
     +,   1.2818987E-04,   1.2741632E-04,   1.2673272E-04
     +,   1.2614838E-04,   1.2567212E-04,   1.2531191E-04
     +,   1.2507504E-04,   1.2496796E-04,   1.2499634E-04
     +,   1.2516500E-04,   1.2547805E-04,   1.2593897E-04
     +,   1.2655061E-04,   1.2731527E-04,   1.2823520E-04
     +,   1.2931248E-04,   1.3054938E-04,   1.3194876E-04
     +,   1.3351436E-04,   1.3525136E-04,   1.3716641E-04
     +,   1.3926874E-04,   1.4157048E-04,   1.4408682E-04
     +,   1.4683699E-04,   1.4984480E-04,   1.5313894E-04
     +,   1.5675309E-04,   1.6072618E-04,   1.6510293E-04
     +,   1.6993302E-04,   1.7527015E-04,   1.8117219E-04
     +,   1.8769973E-04,   1.9491419E-04,   2.0287638E-04
     +,   2.1164620E-04,   2.2127984E-04,   2.3182869E-04
     +,   2.4333881E-04,   2.5585192E-04,   2.6940607E-04
     +,   2.8403694E-04,   2.9978246E-04,   3.1668934E-04
     +,   3.3481943E-04,   3.5425634E-04,   3.7511875E-04
     +,   3.9756994E-04,   4.2182638E-04,   4.4816919E-04
     +,   4.7695401E-04,   5.0861359E-04,   5.4365525E-04
     +,   5.8265490E-04,   6.2624429E-04,   6.7508465E-04
     +,   7.2983111E-04,   7.9109205E-04,   8.5938897E-04
     +,   9.3510962E-04,   1.0184570E-03,   1.1094417E-03
     +,   1.2078622E-03,   1.3133058E-03,   1.4251701E-03
     +,   1.5426878E-03,   1.6649198E-03,   1.7907353E-03
     +,   1.9187877E-03,   2.0475348E-03,   2.1753304E-03
     +,   2.3006944E-03,   2.4228524E-03,   2.5425144E-03
     +,   2.6628149E-03,   2.7902185E-03,   2.9351059E-03
     +,   3.1116619E-03,   3.3367197E-03,   3.6273287E-03
     +,   3.9971005E-03,   4.4520516E-03,   4.9877809E-03
     +,   5.5907085E-03,   6.2449286E-03,   6.9423877E-03
     +,   7.6892930E-03,   8.5006040E-03,   9.3817208E-03
     +,   1.0310376E-02,   1.1239680E-02,   1.2130969E-02
     +,   1.2994677E-02,   1.3898207E-02,   1.4917859E-02
     +,   1.6061550E-02,   1.7227404E-02,   1.8243335E-02
     +,   1.8966466E-02,   1.9363416E-02,   1.9508410E-02
     +,   1.9504450E-02,   1.9390818E-02,   1.9103594E-02
     +,   1.8514823E-02,   1.7519841E-02,   1.6110243E-02
     +,   1.4384761E-02,   1.2500363E-02,   1.0608084E-02
     +,   8.8135693E-03,   7.1747238E-03,   5.7187648E-03
     +,   4.4594384E-03,   3.4036629E-03,   2.5493028E-03
     +,   1.8824241E-03,   1.3779943E-03,   1.0049874E-03
     +,   7.3226204E-04,   5.3305447E-04,   3.8671799E-04
     +,   2.7851120E-04,   1.9827117E-04,   1.3899253E-04
     +,   9.5649215E-05,   6.4462176E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz114 = Yx/0.116951219512195
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5229123E-06,   3.6958852E-06
     +,   3.8752901E-06,   4.0612713E-06,   4.2539705E-06
     +,   4.4535341E-06,   4.6601067E-06,   4.8738370E-06
     +,   5.0948679E-06,   5.3233553E-06,   5.5594483E-06
     +,   5.8032970E-06,   6.0550556E-06,   6.3148805E-06
     +,   6.5829281E-06,   6.8593586E-06,   7.1443328E-06
     +,   7.4380155E-06,   7.7405721E-06,   8.0521677E-06
     +,   8.3729756E-06,   8.7031658E-06,   9.0429066E-06
     +,   9.3923882E-06,   9.7517650E-06,   1.0121232E-05
     +,   1.0500959E-05,   1.0891122E-05,   1.1291896E-05
     +,   1.1703460E-05,   1.2125978E-05,   1.2559622E-05
     +,   1.3004559E-05,   1.3460942E-05,   1.3928924E-05
     +,   1.4408650E-05,   1.4900254E-05,   1.5403850E-05
     +,   1.5919579E-05,   1.6447502E-05,   1.6987728E-05
     +,   1.7540322E-05,   1.8105327E-05,   1.8682778E-05
     +,   1.9272686E-05,   1.9875042E-05,   2.0489817E-05
     +,   2.1116954E-05,   2.1756383E-05,   2.2408005E-05
     +,   2.3071705E-05,   2.3747345E-05,   2.4434758E-05
     +,   2.5133810E-05,   2.5844269E-05,   2.6565982E-05
     +,   2.7298751E-05,   2.8042376E-05,   2.8796685E-05
     +,   2.9561514E-05,   3.0336738E-05,   3.1122265E-05
     +,   3.1918029E-05,   3.2724067E-05,   3.3540513E-05
     +,   3.4367516E-05,   3.5205438E-05,   3.6054669E-05
     +,   3.6915855E-05,   3.7789712E-05,   3.8677263E-05
     +,   3.9579616E-05,   4.0498257E-05,   4.1434796E-05
     +,   4.2391232E-05,   4.3369851E-05,   4.4373213E-05
     +,   4.5404202E-05,   4.6466143E-05,   4.7562695E-05
     +,   4.8697817E-05,   4.9875980E-05,   5.1101844E-05
     +,   5.2380627E-05,   5.3717726E-05,   5.5118988E-05
     +,   5.6590419E-05,   5.8138427E-05,   5.9769423E-05
     +,   6.1490107E-05,   6.3307249E-05,   6.5227498E-05
     +,   6.7257388E-05,   6.9403330E-05,   7.1671493E-05
     +,   7.4067357E-05,   7.6596189E-05,   7.9262216E-05
     +,   8.2069237E-05,   8.5019739E-05,   8.8115536E-05
     +,   9.1356829E-05,   9.4742936E-05,   9.8271361E-05
     +,   1.0193833E-04,   1.0573856E-04,   1.0966480E-04
     +,   1.1370810E-04,   1.1785797E-04,   1.2210221E-04
     +,   1.2642650E-04,   1.3081529E-04,   1.3525099E-04
     +,   1.3971499E-04,   1.4418678E-04,   1.4864517E-04
     +,   1.5306743E-04,   1.5743055E-04,   1.6171047E-04
     +,   1.6588307E-04,   1.6992426E-04,   1.7380992E-04
     +,   1.7751634E-04,   1.8102099E-04,   1.8430222E-04
     +,   1.8733948E-04,   1.9011428E-04,   1.9260944E-04
     +,   1.9481027E-04,   1.9670415E-04,   1.9828085E-04
     +,   1.9953260E-04,   2.0045457E-04,   2.0104425E-04
     +,   2.0130213E-04,   2.0123123E-04,   2.0083718E-04
     +,   2.0012830E-04,   1.9911519E-04,   1.9781067E-04
     +,   1.9622977E-04,   1.9438930E-04,   1.9230774E-04
     +,   1.9000478E-04,   1.8750157E-04,   1.8481984E-04
     +,   1.8198202E-04,   1.7901105E-04,   1.7592999E-04
     +,   1.7276173E-04,   1.6952876E-04,   1.6625352E-04
     +,   1.6295770E-04,   1.5966214E-04,   1.5638692E-04
     +,   1.5315143E-04,   1.4997422E-04,   1.4687287E-04
     +,   1.4386408E-04,   1.4096405E-04,   1.3818826E-04
     +,   1.3555154E-04,   1.3306853E-04,   1.3075372E-04
     +,   1.2862132E-04,   1.2668564E-04,   1.2496139E-04
     +,   1.2346361E-04,   1.2220770E-04,   1.2120960E-04
     +,   1.2048605E-04,   1.2005416E-04,   1.1993165E-04
     +,   1.2013669E-04,   1.2068749E-04,   1.2160250E-04
     +,   1.2289963E-04,   1.2459619E-04,   1.2670828E-04
     +,   1.2925037E-04,   1.3223503E-04,   1.3567165E-04
     +,   1.3956639E-04,   1.4392174E-04,   1.4873566E-04
     +,   1.5400077E-04,   1.5970414E-04,   1.6582741E-04
     +,   1.7234588E-04,   1.7922811E-04,   1.8643680E-04
     +,   1.9392876E-04,   2.0165462E-04,   2.0955983E-04
     +,   2.1758633E-04,   2.2567279E-04,   2.3375546E-04
     +,   2.4177023E-04,   2.4965472E-04,   2.5734975E-04
     +,   2.6480039E-04,   2.7195853E-04,   2.7878556E-04
     +,   2.8525354E-04,   2.9134570E-04,   2.9706044E-04
     +,   3.0241074E-04,   3.0742559E-04,   3.1215037E-04
     +,   3.1664761E-04,   3.2099642E-04,   3.2529165E-04
     +,   3.2964398E-04,   3.3417856E-04,   3.3903474E-04
     +,   3.4436455E-04,   3.5033323E-04,   3.5711934E-04
     +,   3.6491622E-04,   3.7393256E-04,   3.8439705E-04
     +,   3.9656108E-04,   4.1070118E-04,   4.2712348E-04
     +,   4.4616743E-04,   4.6820496E-04,   4.9363635E-04
     +,   5.2288349E-04,   5.5637828E-04,   5.9454370E-04
     +,   6.3776597E-04,   6.8637019E-04,   7.4059551E-04
     +,   8.0057181E-04,   8.6630130E-04,   9.3767192E-04
     +,   1.0144759E-03,   1.0964466E-03,   1.1833175E-03
     +,   1.2748934E-03,   1.3711056E-03,   1.4720382E-03
     +,   1.5779387E-03,   1.6891734E-03,   1.8061229E-03
     +,   1.9290294E-03,   2.0578259E-03,   2.1919834E-03
     +,   2.3303938E-03,   2.4713699E-03,   2.6128613E-03
     +,   2.7528873E-03,   2.8902506E-03,   3.0255239E-03
     +,   3.1621289E-03,   3.3071993E-03,   3.4717601E-03
     +,   3.6698296E-03,   3.9162268E-03,   4.2234971E-03
     +,   4.5989291E-03,   5.0428580E-03,   5.5487650E-03
     +,   6.1051315E-03,   6.6991281E-03,   7.3233121E-03
     +,   7.9855025E-03,   8.7190643E-03,   9.5866602E-03
     +,   1.0669176E-02,   1.2037435E-02,   1.3713417E-02
     +,   1.5637888E-02,   1.7661681E-02,   1.9570809E-02
     +,   2.1139838E-02,   2.2193071E-02,   2.2641508E-02
     +,   2.2478564E-02,   2.1745779E-02,   2.0505004E-02
     +,   1.8837189E-02,   1.6851330E-02,   1.4677661E-02
     +,   1.2443539E-02,   1.0256722E-02,   8.2057789E-03
     +,   6.3674925E-03,   4.8038969E-03,   3.5483027E-03
     +,   2.5954398E-03,   1.9047991E-03,   1.4169291E-03
     +,   1.0718569E-03,   8.2164869E-04,   6.3392828E-04
     +,   4.8931642E-04,   3.7661873E-04,   2.8885214E-04
     +,   2.2089537E-04,   1.6857051E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz115 = Yx/0.111829268292683
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7623761E-05,   1.7993934E-05
     +,   1.8368812E-05,   1.8748538E-05,   1.9133275E-05
     +,   1.9523235E-05,   1.9918631E-05,   2.0319707E-05
     +,   2.0726755E-05,   2.1140095E-05,   2.1560083E-05
     +,   2.1987098E-05,   2.2421586E-05,   2.2864027E-05
     +,   2.3314935E-05,   2.3774895E-05,   2.4244517E-05
     +,   2.4724492E-05,   2.5215542E-05,   2.5718475E-05
     +,   2.6234133E-05,   2.6763440E-05,   2.7307358E-05
     +,   2.7866969E-05,   2.8443337E-05,   2.9037679E-05
     +,   2.9651235E-05,   3.0285326E-05,   3.0941326E-05
     +,   3.1620701E-05,   3.2324973E-05,   3.3055723E-05
     +,   3.3814584E-05,   3.4603279E-05,   3.5423567E-05
     +,   3.6277244E-05,   3.7166174E-05,   3.8092225E-05
     +,   3.9057351E-05,   4.0063453E-05,   4.1112511E-05
     +,   4.2206466E-05,   4.3347256E-05,   4.4536817E-05
     +,   4.5777018E-05,   4.7069690E-05,   4.8416605E-05
     +,   4.9819464E-05,   5.1279851E-05,   5.2799231E-05
     +,   5.4378965E-05,   5.6020246E-05,   5.7724068E-05
     +,   5.9491351E-05,   6.1322629E-05,   6.3218380E-05
     +,   6.5178770E-05,   6.7203706E-05,   6.9292793E-05
     +,   7.1445429E-05,   7.3660609E-05,   7.5937132E-05
     +,   7.8273275E-05,   8.0667160E-05,   8.3116603E-05
     +,   8.5618776E-05,   8.8170913E-05,   9.0769456E-05
     +,   9.3410927E-05,   9.6091135E-05,   9.8805867E-05
     +,   1.0155028E-04,   1.0431957E-04,   1.0710825E-04
     +,   1.0991091E-04,   1.1272179E-04,   1.1553487E-04
     +,   1.1834381E-04,   1.2114237E-04,   1.2392412E-04
     +,   1.2668240E-04,   1.2941071E-04,   1.3210229E-04
     +,   1.3475072E-04,   1.3734933E-04,   1.3989190E-04
     +,   1.4237198E-04,   1.4478371E-04,   1.4712116E-04
     +,   1.4937884E-04,   1.5155161E-04,   1.5363454E-04
     +,   1.5562304E-04,   1.5751318E-04,   1.5930124E-04
     +,   1.6098407E-04,   1.6255898E-04,   1.6402366E-04
     +,   1.6537652E-04,   1.6661624E-04,   1.6774227E-04
     +,   1.6875428E-04,   1.6965276E-04,   1.7043842E-04
     +,   1.7111252E-04,   1.7167695E-04,   1.7213380E-04
     +,   1.7248570E-04,   1.7273561E-04,   1.7288691E-04
     +,   1.7294318E-04,   1.7290835E-04,   1.7278655E-04
     +,   1.7258216E-04,   1.7229965E-04,   1.7194361E-04
     +,   1.7151880E-04,   1.7102985E-04,   1.7048145E-04
     +,   1.6987832E-04,   1.6922504E-04,   1.6852599E-04
     +,   1.6778555E-04,   1.6700781E-04,   1.6619670E-04
     +,   1.6535594E-04,   1.6448893E-04,   1.6359896E-04
     +,   1.6268888E-04,   1.6176142E-04,   1.6081883E-04
     +,   1.5986330E-04,   1.5889661E-04,   1.5792034E-04
     +,   1.5693573E-04,   1.5594385E-04,   1.5494556E-04
     +,   1.5394148E-04,   1.5293207E-04,   1.5191763E-04
     +,   1.5089834E-04,   1.4987441E-04,   1.4884581E-04
     +,   1.4781262E-04,   1.4677497E-04,   1.4573295E-04
     +,   1.4468675E-04,   1.4363686E-04,   1.4258378E-04
     +,   1.4152833E-04,   1.4047144E-04,   1.3941458E-04
     +,   1.3835941E-04,   1.3730783E-04,   1.3626236E-04
     +,   1.3522584E-04,   1.3420163E-04,   1.3319351E-04
     +,   1.3220568E-04,   1.3124311E-04,   1.3031105E-04
     +,   1.2941542E-04,   1.2856266E-04,   1.2775973E-04
     +,   1.2701425E-04,   1.2633410E-04,   1.2572794E-04
     +,   1.2520475E-04,   1.2477410E-04,   1.2444574E-04
     +,   1.2423008E-04,   1.2413776E-04,   1.2417963E-04
     +,   1.2436694E-04,   1.2471105E-04,   1.2522351E-04
     +,   1.2591611E-04,   1.2680053E-04,   1.2788859E-04
     +,   1.2919209E-04,   1.3072298E-04,   1.3249308E-04
     +,   1.3451415E-04,   1.3679812E-04,   1.3935698E-04
     +,   1.4220264E-04,   1.4534729E-04,   1.4880343E-04
     +,   1.5258402E-04,   1.5670210E-04,   1.6117188E-04
     +,   1.6600847E-04,   1.7122774E-04,   1.7684692E-04
     +,   1.8288537E-04,   1.8936445E-04,   1.9630759E-04
     +,   2.0374084E-04,   2.1169371E-04,   2.2019951E-04
     +,   2.2929428E-04,   2.3901819E-04,   2.4941555E-04
     +,   2.6053455E-04,   2.7242524E-04,   2.8514132E-04
     +,   2.9873761E-04,   3.1326839E-04,   3.2878536E-04
     +,   3.4533784E-04,   3.6296883E-04,   3.8171196E-04
     +,   4.0158964E-04,   4.2261349E-04,   4.4478086E-04
     +,   4.6807353E-04,   4.9245905E-04,   5.1789341E-04
     +,   5.4432399E-04,   5.7168986E-04,   5.9993169E-04
     +,   6.2899606E-04,   6.5883884E-04,   6.8943249E-04
     +,   7.2077190E-04,   7.5287541E-04,   7.8578282E-04
     +,   8.1955350E-04,   8.5426617E-04,   8.9000817E-04
     +,   9.2686713E-04,   9.6492935E-04,   1.0042771E-03
     +,   1.0449913E-03,   1.0871532E-03,   1.1308674E-03
     +,   1.1762735E-03,   1.2235621E-03,   1.2729942E-03
     +,   1.3249130E-03,   1.3797403E-03,   1.4379651E-03
     +,   1.5001211E-03,   1.5667786E-03,   1.6385111E-03
     +,   1.7158923E-03,   1.7994979E-03,   1.8899302E-03
     +,   1.9878221E-03,   2.0938269E-03,   2.2085935E-03
     +,   2.3326925E-03,   2.4665119E-03,   2.6102089E-03
     +,   2.7637847E-03,   2.9273380E-03,   3.1015493E-03
     +,   3.2883985E-03,   3.4919069E-03,   3.7186013E-03
     +,   3.9774245E-03,   4.2788247E-03,   4.6330821E-03
     +,   5.0481148E-03,   5.5277152E-03,   6.0715917E-03
     +,   6.6775414E-03,   7.3453360E-03,   8.0796191E-03
     +,   8.8886470E-03,   9.7775040E-03,   1.0739051E-02
     +,   1.1749307E-02,   1.2772352E-02,   1.3773060E-02
     +,   1.4728358E-02,   1.5626701E-02,   1.6452035E-02
     +,   1.7162586E-02,   1.7679850E-02,   1.7900527E-02
     +,   1.7727956E-02,   1.7108964E-02,   1.6057014E-02
     +,   1.4651934E-02,   1.3018193E-02,   1.1292370E-02
     +,   9.5941629E-03,   8.0091944E-03,   6.5853172E-03
     +,   5.3400290E-03,   4.2713052E-03,   3.3680643E-03
     +,   2.6162497E-03,   2.0015596E-03,   1.5093611E-03
     +,   1.1243189E-03,   8.3016709E-04,   6.1042508E-04
     +,   4.4934070E-04,   3.3291453E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz116 = Yx/0.105341463414634
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz1168(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6282682E-05,   1.6515101E-05
     +,   1.6750693E-05,   1.6989969E-05,   1.7233480E-05
     +,   1.7481816E-05,   1.7735625E-05,   1.7995582E-05
     +,   1.8262424E-05,   1.8536941E-05,   1.8819952E-05
     +,   1.9112329E-05,   1.9414987E-05,   1.9728885E-05
     +,   2.0055035E-05,   2.0394471E-05,   2.0748288E-05
     +,   2.1117592E-05,   2.1503540E-05,   2.1907315E-05
     +,   2.2330123E-05,   2.2773196E-05,   2.3237759E-05
     +,   2.3725102E-05,   2.4236451E-05,   2.4773095E-05
     +,   2.5336276E-05,   2.5927233E-05,   2.6547186E-05
     +,   2.7197333E-05,   2.7878821E-05,   2.8592765E-05
     +,   2.9340215E-05,   3.0122170E-05,   3.0939551E-05
     +,   3.1793203E-05,   3.2683885E-05,   3.3612250E-05
     +,   3.4578883E-05,   3.5584169E-05,   3.6628477E-05
     +,   3.7711980E-05,   3.8834718E-05,   3.9996612E-05
     +,   4.1197400E-05,   4.2436699E-05,   4.3713942E-05
     +,   4.5028395E-05,   4.6379166E-05,   4.7765181E-05
     +,   4.9185197E-05,   5.0637802E-05,   5.2121362E-05
     +,   5.3634205E-05,   5.5174292E-05,   5.6739591E-05
     +,   5.8327834E-05,   5.9936596E-05,   6.1563289E-05
     +,   6.3205240E-05,   6.4859611E-05,   6.6523462E-05
     +,   6.8193658E-05,   6.9867107E-05,   7.1540584E-05
     +,   7.3210707E-05,   7.4874217E-05,   7.6527576E-05
     +,   7.8167497E-05,   7.9790421E-05,   8.1393046E-05
     +,   8.2971856E-05,   8.4523621E-05,   8.6044951E-05
     +,   8.7532680E-05,   8.8983747E-05,   9.0395086E-05
     +,   9.1763795E-05,   9.3087183E-05,   9.4362695E-05
     +,   9.5587886E-05,   9.6760567E-05,   9.7878656E-05
     +,   9.8940407E-05,   9.9944133E-05,   1.0088854E-04
     +,   1.0177243E-04,   1.0259490E-04,   1.0335528E-04
     +,   1.0405314E-04,   1.0468832E-04,   1.0526090E-04
     +,   1.0577115E-04,   1.0621965E-04,   1.0660720E-04
     +,   1.0693482E-04,   1.0720378E-04,   1.0741552E-04
     +,   1.0757174E-04,   1.0767431E-04,   1.0772530E-04
     +,   1.0772693E-04,   1.0768160E-04,   1.0759182E-04
     +,   1.0746029E-04,   1.0728975E-04,   1.0708310E-04
     +,   1.0684325E-04,   1.0657321E-04,   1.0627601E-04
     +,   1.0595474E-04,   1.0561245E-04,   1.0525220E-04
     +,   1.0487695E-04,   1.0448975E-04,   1.0409341E-04
     +,   1.0369080E-04,   1.0328460E-04,   1.0287741E-04
     +,   1.0247169E-04,   1.0206972E-04,   1.0167366E-04
     +,   1.0128554E-04,   1.0090711E-04,   1.0054000E-04
     +,   1.0018564E-04,   9.9845267E-05,   9.9519864E-05
     +,   9.9210301E-05,   9.8917124E-05,   9.8640725E-05
     +,   9.8381373E-05,   9.8138968E-05,   9.7913362E-05
     +,   9.7704156E-05,   9.7510776E-05,   9.7332479E-05
     +,   9.7168369E-05,   9.7017386E-05,   9.6878350E-05
     +,   9.6750002E-05,   9.6630851E-05,   9.6519478E-05
     +,   9.6414260E-05,   9.6313583E-05,   9.6215779E-05
     +,   9.6119154E-05,   9.6022013E-05,   9.5922660E-05
     +,   9.5819458E-05,   9.5710777E-05,   9.5595067E-05
     +,   9.5470888E-05,   9.5336887E-05,   9.5191783E-05
     +,   9.5034506E-05,   9.4864059E-05,   9.4679715E-05
     +,   9.4480842E-05,   9.4267110E-05,   9.4038362E-05
     +,   9.3794704E-05,   9.3536575E-05,   9.3264658E-05
     +,   9.2980015E-05,   9.2684058E-05,   9.2378577E-05
     +,   9.2065835E-05,   9.1748523E-05,   9.1429858E-05
     +,   9.1113572E-05,   9.0804009E-05,   9.0506117E-05
     +,   9.0225461E-05,   8.9968380E-05,   8.9741887E-05
     +,   8.9553781E-05,   8.9412664E-05,   8.9327950E-05
     +,   8.9309935E-05,   8.9369772E-05,   8.9519504E-05
     +,   8.9772089E-05,   9.0141439E-05,   9.0642417E-05
     +,   9.1290931E-05,   9.2103794E-05,   9.3099050E-05
     +,   9.4295923E-05,   9.5714946E-05,   9.7378150E-05
     +,   9.9309385E-05,   1.0153445E-04,   1.0408150E-04
     +,   1.0698161E-04,   1.1026937E-04,   1.1398322E-04
     +,   1.1816621E-04,   1.2286722E-04,   1.2814159E-04
     +,   1.3405165E-04,   1.4066782E-04,   1.4806993E-04
     +,   1.5634757E-04,   1.6559972E-04,   1.7593637E-04
     +,   1.8747791E-04,   2.0035327E-04,   2.1469900E-04
     +,   2.3065858E-04,   2.4837817E-04,   2.6800213E-04
     +,   2.8966900E-04,   3.1350742E-04,   3.3962959E-04
     +,   3.6812236E-04,   3.9904180E-04,   4.3241004E-04
     +,   4.6820621E-04,   5.0635944E-04,   5.4675149E-04
     +,   5.8921246E-04,   6.3351856E-04,   6.7940075E-04
     +,   7.2655210E-04,   7.7463657E-04,   8.2330132E-04
     +,   8.7219395E-04,   9.2099042E-04,   9.6941309E-04
     +,   1.0172566E-03,   1.0644144E-03,   1.1109116E-03
     +,   1.1569228E-03,   1.2027844E-03,   1.2490123E-03
     +,   1.2962909E-03,   1.3454556E-03,   1.3974647E-03
     +,   1.4533654E-03,   1.5142509E-03,   1.5812112E-03
     +,   1.6553066E-03,   1.7375342E-03,   1.8287889E-03
     +,   1.9297787E-03,   2.0409420E-03,   2.1623129E-03
     +,   2.2933832E-03,   2.4330074E-03,   2.5794962E-03
     +,   2.7308816E-03,   2.8854061E-03,   3.0421512E-03
     +,   3.2015943E-03,   3.3658035E-03,   3.5380963E-03
     +,   3.7222039E-03,   3.9211879E-03,   4.1366075E-03
     +,   4.3683788E-03,   4.6156007E-03,   4.8780502E-03
     +,   5.1576225E-03,   5.4589137E-03,   5.7885172E-03
     +,   6.1527840E-03,   6.5549514E-03,   6.9932323E-03
     +,   7.4615679E-03,   7.9537900E-03,   8.4701171E-03
     +,   9.0226410E-03,   9.6362643E-03,   1.0343703E-02
     +,   1.1176072E-02,   1.2152120E-02,   1.3266322E-02
     +,   1.4477265E-02,   1.5698252E-02,   1.6798466E-02
     +,   1.7620118E-02,   1.8011626E-02,   1.7864941E-02
     +,   1.7143331E-02,   1.5890015E-02,   1.4216637E-02
     +,   1.2278453E-02,   1.0244244E-02,   8.2676364E-03
     +,   6.4670891E-03,   4.9158167E-03,   3.6432687E-03
     +,   2.6434883E-03,   1.8874158E-03,   1.3341354E-03
     +,   9.4005291E-04,   6.6466839E-04,   4.7392893E-04
     +,   3.4133700E-04,   2.4774531E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz1168 = Yx/0.101675
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2369351E-06,   3.3292463E-06
     +,   3.4245923E-06,   3.5231737E-06,   3.6252029E-06
     +,   3.7309142E-06,   3.8405587E-06,   3.9544097E-06
     +,   4.0727582E-06,   4.1959256E-06,   4.3242503E-06
     +,   4.4580984E-06,   4.5978636E-06,   4.7439685E-06
     +,   4.8968636E-06,   5.0570311E-06,   5.2249857E-06
     +,   5.4012767E-06,   5.5864871E-06,   5.7812390E-06
     +,   5.9861909E-06,   6.2020404E-06,   6.4295241E-06
     +,   6.6694361E-06,   6.9225835E-06,   7.1898535E-06
     +,   7.4721556E-06,   7.7704581E-06,   8.0857735E-06
     +,   8.4191697E-06,   8.7717663E-06,   9.1447328E-06
     +,   9.5393016E-06,   9.9567533E-06,   1.0398439E-05
     +,   1.0865764E-05,   1.1360200E-05,   1.1883275E-05
     +,   1.2436617E-05,   1.3021875E-05,   1.3640819E-05
     +,   1.4295262E-05,   1.4987122E-05,   1.5718377E-05
     +,   1.6491100E-05,   1.7307451E-05,   1.8169681E-05
     +,   1.9080133E-05,   2.0041241E-05,   2.1055534E-05
     +,   2.2125641E-05,   2.3254281E-05,   2.4444254E-05
     +,   2.5698520E-05,   2.7019993E-05,   2.8411800E-05
     +,   2.9877070E-05,   3.1418993E-05,   3.3040822E-05
     +,   3.4745837E-05,   3.6537313E-05,   3.8418559E-05
     +,   4.0392722E-05,   4.2463027E-05,   4.4632601E-05
     +,   4.6904228E-05,   4.9280799E-05,   5.1764695E-05
     +,   5.4358301E-05,   5.7063389E-05,   5.9881699E-05
     +,   6.2814150E-05,   6.5861575E-05,   6.9023874E-05
     +,   7.2300623E-05,   7.5690798E-05,   7.9192403E-05
     +,   8.2802668E-05,   8.6518288E-05,   9.0335103E-05
     +,   9.4247633E-05,   9.8250042E-05,   1.0233504E-04
     +,   1.0649487E-04,   1.1072036E-04,   1.1500185E-04
     +,   1.1932823E-04,   1.2368811E-04,   1.2806861E-04
     +,   1.3245658E-04,   1.3683805E-04,   1.4119821E-04
     +,   1.4552173E-04,   1.4979309E-04,   1.5399640E-04
     +,   1.5811533E-04,   1.6213395E-04,   1.6603587E-04
     +,   1.6980551E-04,   1.7342716E-04,   1.7688613E-04
     +,   1.8016793E-04,   1.8325941E-04,   1.8614795E-04
     +,   1.8882229E-04,   1.9127250E-04,   1.9348954E-04
     +,   1.9546624E-04,   1.9719676E-04,   1.9867685E-04
     +,   1.9990392E-04,   2.0087708E-04,   2.0159702E-04
     +,   2.0206609E-04,   2.0228837E-04,   2.0226944E-04
     +,   2.0201648E-04,   2.0153800E-04,   2.0084395E-04
     +,   1.9994554E-04,   1.9885490E-04,   1.9758534E-04
     +,   1.9615100E-04,   1.9456662E-04,   1.9284735E-04
     +,   1.9100905E-04,   1.8906740E-04,   1.8703855E-04
     +,   1.8493814E-04,   1.8278208E-04,   1.8058544E-04
     +,   1.7836316E-04,   1.7612951E-04,   1.7389808E-04
     +,   1.7168159E-04,   1.6949199E-04,   1.6734048E-04
     +,   1.6523736E-04,   1.6319181E-04,   1.6121213E-04
     +,   1.5930575E-04,   1.5747934E-04,   1.5573851E-04
     +,   1.5408809E-04,   1.5253230E-04,   1.5107464E-04
     +,   1.4971792E-04,   1.4846456E-04,   1.4731674E-04
     +,   1.4627603E-04,   1.4534393E-04,   1.4452191E-04
     +,   1.4381135E-04,   1.4321378E-04,   1.4273082E-04
     +,   1.4236434E-04,   1.4211677E-04,   1.4199062E-04
     +,   1.4198908E-04,   1.4211572E-04,   1.4237469E-04
     +,   1.4277070E-04,   1.4330889E-04,   1.4399507E-04
     +,   1.4483547E-04,   1.4583685E-04,   1.4700629E-04
     +,   1.4835120E-04,   1.4987927E-04,   1.5159845E-04
     +,   1.5351645E-04,   1.5564088E-04,   1.5797935E-04
     +,   1.6053891E-04,   1.6332595E-04,   1.6634633E-04
     +,   1.6960507E-04,   1.7310592E-04,   1.7685146E-04
     +,   1.8084327E-04,   1.8508144E-04,   1.8956434E-04
     +,   1.9428862E-04,   1.9924976E-04,   2.0444137E-04
     +,   2.0985532E-04,   2.1548192E-04,   2.2131007E-04
     +,   2.2732771E-04,   2.3352084E-04,   2.3987517E-04
     +,   2.4637574E-04,   2.5300676E-04,   2.5975227E-04
     +,   2.6659708E-04,   2.7352638E-04,   2.8052647E-04
     +,   2.8758435E-04,   2.9468985E-04,   3.0183455E-04
     +,   3.0901300E-04,   3.1622240E-04,   3.2346463E-04
     +,   3.3074556E-04,   3.3807551E-04,   3.4547067E-04
     +,   3.5295344E-04,   3.6055211E-04,   3.6830199E-04
     +,   3.7624614E-04,   3.8443526E-04,   3.9292753E-04
     +,   4.0178798E-04,   4.1108980E-04,   4.2091223E-04
     +,   4.3133908E-04,   4.4245771E-04,   4.5435745E-04
     +,   4.6712701E-04,   4.8085005E-04,   4.9560494E-04
     +,   5.1146070E-04,   5.2847358E-04,   5.4668606E-04
     +,   5.6612777E-04,   5.8681425E-04,   6.0874986E-04
     +,   6.3193240E-04,   6.5636082E-04,   6.8204466E-04
     +,   7.0900947E-04,   7.3731079E-04,   7.6704432E-04
     +,   7.9835416E-04,   8.3143410E-04,   8.6653925E-04
     +,   9.0398005E-04,   9.4411842E-04,   9.8736526E-04
     +,   1.0341792E-03,   1.0850622E-03,   1.1405601E-03
     +,   1.2012747E-03,   1.2678787E-03,   1.3411313E-03
     +,   1.4218915E-03,   1.5111392E-03,   1.6100042E-03
     +,   1.7197856E-03,   1.8419576E-03,   1.9781913E-03
     +,   2.1302928E-03,   2.3000434E-03,   2.4889617E-03
     +,   2.6979493E-03,   2.9269101E-03,   3.1744784E-03
     +,   3.4380665E-03,   3.7143214E-03,   3.9999830E-03
     +,   4.2929351E-03,   4.5931181E-03,   4.9028224E-03
     +,   5.2258405E-03,   5.5654892E-03,   5.9221718E-03
     +,   6.2913471E-03,   6.6634156E-03,   7.0266239E-03
     +,   7.3726294E-03,   7.7029299E-03,   8.0334190E-03
     +,   8.3938036E-03,   8.8209072E-03,   9.3468130E-03
     +,   9.9860122E-03,   1.0726573E-02,   1.1528104E-02
     +,   1.2326827E-02,   1.3044539E-02,   1.3599033E-02
     +,   1.3914059E-02,   1.3929753E-02,   1.3612618E-02
     +,   1.2963090E-02,   1.2017408E-02,   1.0841857E-02
     +,   9.5209731E-03,   8.1437416E-03,   6.7907814E-03
     +,   5.5263406E-03,   4.3941312E-03,   3.4177834E-03
     +,   2.6033551E-03,   1.9439405E-03,   1.4241170E-03
     +,   1.0242950E-03,   7.2373031E-04,   5.0269591E-04
     +,   3.4354365E-04,   2.3127103E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz118 = Yx/0.0895641025641026
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9997115E-05,   2.0770352E-05
     +,   2.1563246E-05,   2.2375663E-05,   2.3207420E-05
     +,   2.4058292E-05,   2.4928020E-05,   2.5816289E-05
     +,   2.6722730E-05,   2.7646978E-05,   2.8588573E-05
     +,   2.9547031E-05,   3.0521820E-05,   3.1512365E-05
     +,   3.2518055E-05,   3.3538228E-05,   3.4572196E-05
     +,   3.5619225E-05,   3.6678539E-05,   3.7749349E-05
     +,   3.8830818E-05,   3.9922092E-05,   4.1022271E-05
     +,   4.2130490E-05,   4.3245771E-05,   4.4367236E-05
     +,   4.5493922E-05,   4.6624878E-05,   4.7759164E-05
     +,   4.8895850E-05,   5.0034017E-05,   5.1172745E-05
     +,   5.2311178E-05,   5.3448442E-05,   5.4583747E-05
     +,   5.5716329E-05,   5.6845482E-05,   5.7970541E-05
     +,   5.9090980E-05,   6.0206236E-05,   6.1315957E-05
     +,   6.2419807E-05,   6.3517575E-05,   6.4609150E-05
     +,   6.5694614E-05,   6.6774090E-05,   6.7847905E-05
     +,   6.8916510E-05,   6.9980539E-05,   7.1040820E-05
     +,   7.2098308E-05,   7.3154210E-05,   7.4209885E-05
     +,   7.5267024E-05,   7.6327349E-05,   7.7393037E-05
     +,   7.8466313E-05,   7.9549784E-05,   8.0646256E-05
     +,   8.1758822E-05,   8.2890838E-05,   8.4045962E-05
     +,   8.5227977E-05,   8.6441200E-05,   8.7690030E-05
     +,   8.8979155E-05,   9.0313639E-05,   9.1698617E-05
     +,   9.3139643E-05,   9.4642295E-05,   9.6212614E-05
     +,   9.7856486E-05,   9.9580269E-05,   1.0139013E-04
     +,   1.0329253E-04,   1.0529392E-04,   1.0740064E-04
     +,   1.0961889E-04,   1.1195491E-04,   1.1441470E-04
     +,   1.1700384E-04,   1.1972777E-04,   1.2259121E-04
     +,   1.2559886E-04,   1.2875415E-04,   1.3206058E-04
     +,   1.3552024E-04,   1.3913486E-04,   1.4290484E-04
     +,   1.4682992E-04,   1.5090867E-04,   1.5513839E-04
     +,   1.5951500E-04,   1.6403357E-04,   1.6868779E-04
     +,   1.7346951E-04,   1.7836996E-04,   1.8337822E-04
     +,   1.8848277E-04,   1.9366998E-04,   1.9892567E-04
     +,   2.0423379E-04,   2.0957764E-04,   2.1493899E-04
     +,   2.2029899E-04,   2.2563808E-04,   2.3093555E-04
     +,   2.3617034E-04,   2.4132115E-04,   2.4636660E-04
     +,   2.5128483E-04,   2.5605474E-04,   2.6065504E-04
     +,   2.6506552E-04,   2.6926631E-04,   2.7323887E-04
     +,   2.7696532E-04,   2.8042958E-04,   2.8361645E-04
     +,   2.8651272E-04,   2.8910686E-04,   2.9138877E-04
     +,   2.9335043E-04,   2.9498574E-04,   2.9629059E-04
     +,   2.9726280E-04,   2.9790204E-04,   2.9820984E-04
     +,   2.9818987E-04,   2.9784749E-04,   2.9718934E-04
     +,   2.9622429E-04,   2.9496208E-04,   2.9341431E-04
     +,   2.9159337E-04,   2.8951286E-04,   2.8718729E-04
     +,   2.8463200E-04,   2.8186274E-04,   2.7889587E-04
     +,   2.7574811E-04,   2.7243636E-04,   2.6897783E-04
     +,   2.6538922E-04,   2.6168791E-04,   2.5789044E-04
     +,   2.5401363E-04,   2.5007385E-04,   2.4608755E-04
     +,   2.4207035E-04,   2.3803802E-04,   2.3400584E-04
     +,   2.2998935E-04,   2.2600315E-04,   2.2206204E-04
     +,   2.1818081E-04,   2.1437401E-04,   2.1065612E-04
     +,   2.0704167E-04,   2.0354528E-04,   2.0018157E-04
     +,   1.9696527E-04,   1.9391128E-04,   1.9103492E-04
     +,   1.8835133E-04,   1.8587580E-04,   1.8362423E-04
     +,   1.8161252E-04,   1.7985642E-04,   1.7837205E-04
     +,   1.7717568E-04,   1.7628362E-04,   1.7571183E-04
     +,   1.7547644E-04,   1.7559352E-04,   1.7607848E-04
     +,   1.7694685E-04,   1.7821330E-04,   1.7989209E-04
     +,   1.8199673E-04,   1.8454013E-04,   1.8753388E-04
     +,   1.9098852E-04,   1.9491320E-04,   1.9931594E-04
     +,   2.0420243E-04,   2.0957665E-04,   2.1544060E-04
     +,   2.2179371E-04,   2.2863221E-04,   2.3595006E-04
     +,   2.4373784E-04,   2.5198210E-04,   2.6066534E-04
     +,   2.6976681E-04,   2.7926103E-04,   2.8911760E-04
     +,   2.9930117E-04,   3.0977224E-04,   3.2048620E-04
     +,   3.3139324E-04,   3.4243887E-04,   3.5356506E-04
     +,   3.6471046E-04,   3.7581017E-04,   3.8679864E-04
     +,   3.9761089E-04,   4.0818323E-04,   4.1845633E-04
     +,   4.2837913E-04,   4.3791070E-04,   4.4702383E-04
     +,   4.5570845E-04,   4.6397754E-04,   4.7186957E-04
     +,   4.7945202E-04,   4.8682478E-04,   4.9412390E-04
     +,   5.0152262E-04,   5.0923007E-04,   5.1749218E-04
     +,   5.2658835E-04,   5.3682632E-04,   5.4853637E-04
     +,   5.6206528E-04,   5.7776814E-04,   5.9599744E-04
     +,   6.1709649E-04,   6.4139196E-04,   6.6918513E-04
     +,   7.0074439E-04,   7.3629949E-04,   7.7603984E-04
     +,   8.2010677E-04,   8.6858525E-04,   9.2150329E-04
     +,   9.7882340E-04,   1.0404278E-03,   1.1061104E-03
     +,   1.1755764E-03,   1.2484343E-03,   1.3241972E-03
     +,   1.4023142E-03,   1.4822285E-03,   1.5634418E-03
     +,   1.6456153E-03,   1.7286956E-03,   1.8130291E-03
     +,   1.8994473E-03,   1.9892766E-03,   2.0842883E-03
     +,   2.1865291E-03,   2.2980468E-03,   2.4205821E-03
     +,   2.5552844E-03,   2.7024674E-03,   2.8615671E-03
     +,   3.0313309E-03,   3.2102736E-03,   3.3973262E-03
     +,   3.5925563E-03,   3.7978448E-03,   4.0172320E-03
     +,   4.2567160E-03,   4.5234864E-03,   4.8246579E-03
     +,   5.1657022E-03,   5.5489354E-03,   5.9724310E-03
     +,   6.4296066E-03,   6.9095138E-03,   7.3976773E-03
     +,   7.8774430E-03,   8.3314935E-03,   8.7431846E-03
     +,   9.0975575E-03,   9.3819592E-03,   9.5860092E-03
     +,   9.7012939E-03,   9.7208973E-03,   9.6392930E-03
     +,   9.4528329E-03,   9.1606714E-03,   8.7661538E-03
     +,   8.2776807E-03,   7.7090161E-03,   7.0784683E-03
     +,   6.4072995E-03,   5.7177758E-03,   5.0310078E-03
     +,   4.3656114E-03,   3.7366021E-03,   3.1552303E-03
     +,   2.6289134E-03,   2.1617098E-03,   1.7546280E-03
     +,   1.4062542E-03,   1.1131703E-03,   8.7059755E-04
     +,   6.7287113E-04,   5.1400030E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz119 = Yx/0.0780769230769231
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1382649E-05,   3.1841941E-05
     +,   3.2303764E-05,   3.2768618E-05,   3.3237073E-05
     +,   3.3709723E-05,   3.4187240E-05,   3.4670324E-05
     +,   3.5159745E-05,   3.5656329E-05,   3.6160949E-05
     +,   3.6674548E-05,   3.7198115E-05,   3.7732691E-05
     +,   3.8279395E-05,   3.8839393E-05,   3.9413910E-05
     +,   4.0004241E-05,   4.0611707E-05,   4.1237723E-05
     +,   4.1883741E-05,   4.2551270E-05,   4.3241871E-05
     +,   4.3957214E-05,   4.4698914E-05,   4.5468725E-05
     +,   4.6268415E-05,   4.7099795E-05,   4.7964750E-05
     +,   4.8865175E-05,   4.9803009E-05,   5.0780229E-05
     +,   5.1798874E-05,   5.2860985E-05,   5.3968623E-05
     +,   5.5123903E-05,   5.6328958E-05,   5.7585883E-05
     +,   5.8896931E-05,   6.0264163E-05,   6.1689854E-05
     +,   6.3176158E-05,   6.4725282E-05,   6.6339446E-05
     +,   6.8020847E-05,   6.9771675E-05,   7.1594179E-05
     +,   7.3490519E-05,   7.5462900E-05,   7.7513498E-05
     +,   7.9644517E-05,   8.1858125E-05,   8.4156389E-05
     +,   8.6541586E-05,   8.9015673E-05,   9.1580820E-05
     +,   9.4239040E-05,   9.6992408E-05,   9.9842815E-05
     +,   1.0279219E-04,   1.0584242E-04,   1.0899527E-04
     +,   1.1225226E-04,   1.1561513E-04,   1.1908534E-04
     +,   1.2266403E-04,   1.2635258E-04,   1.3015165E-04
     +,   1.3406224E-04,   1.3808452E-04,   1.4221905E-04
     +,   1.4646543E-04,   1.5082346E-04,   1.5529216E-04
     +,   1.5987040E-04,   1.6455675E-04,   1.6934892E-04
     +,   1.7424427E-04,   1.7923983E-04,   1.8433206E-04
     +,   1.8951652E-04,   1.9478869E-04,   2.0014297E-04
     +,   2.0557371E-04,   2.1107402E-04,   2.1663716E-04
     +,   2.2225501E-04,   2.2791977E-04,   2.3362224E-04
     +,   2.3935347E-04,   2.4510399E-04,   2.5086344E-04
     +,   2.5662142E-04,   2.6236754E-04,   2.6809110E-04
     +,   2.7378093E-04,   2.7942663E-04,   2.8501693E-04
     +,   2.9054147E-04,   2.9598945E-04,   3.0135110E-04
     +,   3.0661642E-04,   3.1177621E-04,   3.1682153E-04
     +,   3.2174418E-04,   3.2653665E-04,   3.3119167E-04
     +,   3.3570276E-04,   3.4006423E-04,   3.4427099E-04
     +,   3.4831837E-04,   3.5220236E-04,   3.5591924E-04
     +,   3.5946615E-04,   3.6284002E-04,   3.6603870E-04
     +,   3.6905953E-04,   3.7190047E-04,   3.7455914E-04
     +,   3.7703311E-04,   3.7931971E-04,   3.8141606E-04
     +,   3.8331875E-04,   3.8502403E-04,   3.8652768E-04
     +,   3.8782478E-04,   3.8891006E-04,   3.8977744E-04
     +,   3.9042046E-04,   3.9083223E-04,   3.9100522E-04
     +,   3.9093199E-04,   3.9060428E-04,   3.9001447E-04
     +,   3.8915427E-04,   3.8801605E-04,   3.8659244E-04
     +,   3.8487680E-04,   3.8286281E-04,   3.8054521E-04
     +,   3.7792049E-04,   3.7498545E-04,   3.7173886E-04
     +,   3.6818083E-04,   3.6431357E-04,   3.6014049E-04
     +,   3.5566746E-04,   3.5090183E-04,   3.4585339E-04
     +,   3.4053347E-04,   3.3495546E-04,   3.2913487E-04
     +,   3.2308899E-04,   3.1683670E-04,   3.1039806E-04
     +,   3.0379553E-04,   2.9705217E-04,   2.9019234E-04
     +,   2.8324084E-04,   2.7622402E-04,   2.6916806E-04
     +,   2.6209923E-04,   2.5504475E-04,   2.4803125E-04
     +,   2.4108475E-04,   2.3423105E-04,   2.2749556E-04
     +,   2.2090295E-04,   2.1447639E-04,   2.0823852E-04
     +,   2.0221101E-04,   1.9641456E-04,   1.9086836E-04
     +,   1.8559047E-04,   1.8059842E-04,   1.7590825E-04
     +,   1.7153491E-04,   1.6749307E-04,   1.6379637E-04
     +,   1.6045770E-04,   1.5748947E-04,   1.5490409E-04
     +,   1.5271376E-04,   1.5093060E-04,   1.4956722E-04
     +,   1.4863673E-04,   1.4815293E-04,   1.4813062E-04
     +,   1.4858588E-04,   1.4953605E-04,   1.5100031E-04
     +,   1.5299965E-04,   1.5555711E-04,   1.5869763E-04
     +,   1.6244898E-04,   1.6684088E-04,   1.7190565E-04
     +,   1.7767763E-04,   1.8419368E-04,   1.9149300E-04
     +,   1.9961587E-04,   2.0860402E-04,   2.1850082E-04
     +,   2.2935029E-04,   2.4119574E-04,   2.5408104E-04
     +,   2.6804945E-04,   2.8314249E-04,   2.9939957E-04
     +,   3.1685969E-04,   3.3555980E-04,   3.5553370E-04
     +,   3.7681227E-04,   3.9942516E-04,   4.2339903E-04
     +,   4.4875496E-04,   4.7550883E-04,   5.0367136E-04
     +,   5.3324451E-04,   5.6421588E-04,   5.9656077E-04
     +,   6.3023658E-04,   6.6517713E-04,   7.0129044E-04
     +,   7.3846150E-04,   7.7654776E-04,   8.1537978E-04
     +,   8.5476827E-04,   8.9451525E-04,   9.3442411E-04
     +,   9.7431184E-04,   1.0140298E-03,   1.0534888E-03
     +,   1.0926748E-03,   1.1316668E-03,   1.1706552E-03
     +,   1.2099538E-03,   1.2499975E-03,   1.2913415E-03
     +,   1.3346587E-03,   1.3807255E-03,   1.4304111E-03
     +,   1.4846757E-03,   1.5445772E-03,   1.6112752E-03
     +,   1.6860326E-03,   1.7702142E-03,   1.8652563E-03
     +,   1.9726020E-03,   2.0935657E-03,   2.2291925E-03
     +,   2.3800638E-03,   2.5460946E-03,   2.7263961E-03
     +,   2.9192220E-03,   3.1220294E-03,   3.3316605E-03
     +,   3.5446845E-03,   3.7578717E-03,   3.9686621E-03
     +,   4.1756262E-03,   4.3788981E-03,   4.5803939E-03
     +,   4.7837808E-03,   4.9941726E-03,   5.2174986E-03
     +,   5.4595750E-03,   5.7249255E-03,   6.0156649E-03
     +,   6.3305539E-03,   6.6645001E-03,   7.0087076E-03
     +,   7.3514436E-03,   7.6794275E-03,   7.9793334E-03
     +,   8.2391296E-03,   8.4490478E-03,   8.6017540E-03
     +,   8.6920252E-03,   8.7159649E-03,   8.6701922E-03
     +,   8.5514411E-03,   8.3566308E-03,   8.0835894E-03
     +,   7.7320514E-03,   7.3049273E-03,   6.8090614E-03
     +,   6.2555820E-03,   5.6595732E-03,   5.0388798E-03
     +,   4.4127507E-03,   3.7999412E-03,   3.2173218E-03
     +,   2.6784604E-03,   2.1930360E-03,   1.7665104E-03
     +,   1.4005268E-03,   1.0934122E-03,   8.4108202E-04
     +,   6.3780975E-04,   4.7707613E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz120 = Yx/0.0796923076923077
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2208256E-05,   3.3695178E-05
     +,   3.5221583E-05,   3.6786190E-05,   3.8387523E-05
     +,   4.0023864E-05,   4.1693274E-05,   4.3393589E-05
     +,   4.5122390E-05,   4.6877110E-05,   4.8654882E-05
     +,   5.0452687E-05,   5.2267278E-05,   5.4095235E-05
     +,   5.5933029E-05,   5.7776968E-05,   5.9623282E-05
     +,   6.1468199E-05,   6.3307918E-05,   6.5138709E-05
     +,   6.6957007E-05,   6.8759458E-05,   7.0542977E-05
     +,   7.2305062E-05,   7.4043448E-05,   7.5756849E-05
     +,   7.7444616E-05,   7.9107107E-05,   8.0745871E-05
     +,   8.2363782E-05,   8.3965344E-05,   8.5556872E-05
     +,   8.7146778E-05,   8.8745903E-05,   9.0367794E-05
     +,   9.2029040E-05,   9.3749688E-05,   9.5553522E-05
     +,   9.7468728E-05,   9.9527875E-05,   1.0176872E-04
     +,   1.0423427E-04,   1.0697325E-04,   1.1004027E-04
     +,   1.1349589E-04,   1.1740671E-04,   1.2184493E-04
     +,   1.2688816E-04,   1.3261846E-04,   1.3912158E-04
     +,   1.4648563E-04,   1.5479961E-04,   1.6415169E-04
     +,   1.7462806E-04,   1.8630958E-04,   1.9927215E-04
     +,   2.1358367E-04,   2.2930374E-04,   2.4648308E-04
     +,   2.6516404E-04,   2.8538110E-04,   3.0716351E-04
     +,   3.3053517E-04,   3.5552093E-04,   3.8214689E-04
     +,   4.1043994E-04,   4.4043444E-04,   4.7216399E-04
     +,   5.0566701E-04,   5.4097379E-04,   5.7811115E-04
     +,   6.1708817E-04,   6.5790425E-04,   7.0054160E-04
     +,   7.4498454E-04,   7.9123629E-04,   8.3934714E-04
     +,   8.8946422E-04,   9.4189827E-04,   9.9720433E-04
     +,   1.0562838E-03,   1.1205350E-03,   1.1919982E-03
     +,   1.2735545E-03,   1.3690582E-03,   1.4834594E-03
     +,   1.6227326E-03,   1.7936665E-03,   2.0033421E-03
     +,   2.2584582E-03,   2.5644777E-03,   2.9247797E-03
     +,   3.3400247E-03,   3.8079049E-03,   4.3232748E-03
     +,   4.8786085E-03,   5.4650088E-03,   6.0731610E-03
     +,   6.6946102E-03,   7.3225312E-03,   7.9520363E-03
     +,   8.5789887E-03,   9.1977334E-03,   9.7980248E-03
     +,   1.0363399E-02,   1.0872367E-02,   1.1303321E-02
     +,   1.1641406E-02,   1.1883642E-02,   1.2038809E-02
     +,   1.2121498E-02,   1.2143338E-02,   1.2106496E-02
     +,   1.2003764E-02,   1.1825046E-02,   1.1566302E-02
     +,   1.1235641E-02,   1.0852616E-02,   1.0441892E-02
     +,   1.0025083E-02,   9.6151335E-03,   9.2161903E-03
     +,   8.8272821E-03,   8.4471116E-03,   8.0769258E-03
     +,   7.7202674E-03,   7.3805810E-03,   7.0588887E-03
     +,   6.7528961E-03,   6.4581227E-03,   6.1699874E-03
     +,   5.8858581E-03,   5.6059235E-03,   5.3329514E-03
     +,   5.0710584E-03,   4.8243618E-03,   4.5959628E-03
     +,   4.3873959E-03,   4.1985861E-03,   4.0281350E-03
     +,   3.8736986E-03,   3.7323232E-03,   3.6007259E-03
     +,   3.4756055E-03,   3.3538877E-03,   3.2329948E-03
     +,   3.1110605E-03,   2.9871042E-03,   2.8610493E-03
     +,   2.7336252E-03,   2.6061668E-03,   2.4803404E-03
     +,   2.3578345E-03,   2.2400832E-03,   2.1280942E-03
     +,   2.0223635E-03,   1.9228897E-03,   1.8292445E-03
     +,   1.7407265E-03,   1.6565159E-03,   1.5757894E-03
     +,   1.4978379E-03,   1.4221290E-03,   1.3483332E-03
     +,   1.2763058E-03,   1.2060684E-03,   1.1377700E-03
     +,   1.0716418E-03,   1.0079524E-03,   9.4697991E-04
     +,   8.8898931E-04,   8.3420775E-04,   7.8281708E-04
     +,   7.3494710E-04,   6.9068087E-04,   6.5004942E-04
     +,   6.1303971E-04,   5.7960366E-04,   5.4966158E-04
     +,   5.2310654E-04,   4.9981358E-04,   4.7964556E-04
     +,   4.6245652E-04,   4.4809314E-04,   4.3640094E-04
     +,   4.2722563E-04,   4.2041368E-04,   4.1581262E-04
     +,   4.1327268E-04,   4.1264613E-04,   4.1378694E-04
     +,   4.1655081E-04,   4.2079409E-04,   4.2637353E-04
     +,   4.3314634E-04,   4.4096945E-04,   4.4969950E-04
     +,   4.5919186E-04,   4.6930317E-04,   4.7988954E-04
     +,   4.9080758E-04,   5.0191511E-04,   5.1307282E-04
     +,   5.2414485E-04,   5.3499843E-04,   5.4550800E-04
     +,   5.5555440E-04,   5.6502607E-04,   5.7382154E-04
     +,   5.8185059E-04,   5.8903429E-04,   5.9530692E-04
     +,   6.0061569E-04,   6.0492341E-04,   6.0820591E-04
     +,   6.1045476E-04,   6.1167468E-04,   6.1188469E-04
     +,   6.1111694E-04,   6.0941448E-04,   6.0683128E-04
     +,   6.0343067E-04,   5.9928268E-04,   5.9446314E-04
     +,   5.8905088E-04,   5.8312790E-04,   5.7677506E-04
     +,   5.7007215E-04,   5.6309509E-04,   5.5591564E-04
     +,   5.4859906E-04,   5.4120464E-04,   5.3378235E-04
     +,   5.2637467E-04,   5.1901542E-04,   5.1172933E-04
     +,   5.0453248E-04,   4.9743289E-04,   4.9043074E-04
     +,   4.8351914E-04,   4.7668398E-04,   4.6990725E-04
     +,   4.6316549E-04,   4.5643223E-04,   4.4967796E-04
     +,   4.4287264E-04,   4.3598586E-04,   4.2898723E-04
     +,   4.2184824E-04,   4.1454274E-04,   4.0704719E-04
     +,   3.9934172E-04,   3.9141052E-04,   3.8324267E-04
     +,   3.7483111E-04,   3.6617342E-04,   3.5727286E-04
     +,   3.4813688E-04,   3.3877711E-04,   3.2920943E-04
     +,   3.1945400E-04,   3.0953466E-04,   2.9947743E-04
     +,   2.8931076E-04,   2.7906633E-04,   2.6877606E-04
     +,   2.5847260E-04,   2.4819007E-04,   2.3796206E-04
     +,   2.2782090E-04,   2.1779805E-04,   2.0792404E-04
     +,   1.9822754E-04,   1.8873456E-04,   1.7946874E-04
     +,   1.7045210E-04,   1.6170279E-04,   1.5323740E-04
     +,   1.4506861E-04,   1.3720743E-04,   1.2966117E-04
     +,   1.2243554E-04,   1.1553276E-04,   1.0895381E-04
     +,   1.0269648E-04,   9.6757598E-05,   9.1131529E-05
     +,   8.5811283E-05,   8.0788930E-05,   7.6054850E-05
     +,   7.1599090E-05,   6.7410379E-05,   6.3477499E-05
     +,   5.9788301E-05,   5.6330926E-05,   5.3092954E-05
     +,   5.0062437E-05,   4.7227189E-05,   4.4575598E-05
     +,   4.2096050E-05,   3.9777628E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz75 = Yx/0.127833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.5833022E-05,   2.6655045E-05
     +,   2.7517437E-05,   2.8422111E-05,   2.9370955E-05
     +,   3.0365816E-05,   3.1408486E-05,   3.2500669E-05
     +,   3.3643977E-05,   3.4839948E-05,   3.6089950E-05
     +,   3.7395232E-05,   3.8756851E-05,   4.0175699E-05
     +,   4.1652474E-05,   4.3187632E-05,   4.4781398E-05
     +,   4.6433765E-05,   4.8144437E-05,   4.9912847E-05
     +,   5.1738120E-05,   5.3619096E-05,   5.5554247E-05
     +,   5.7541896E-05,   5.9579776E-05,   6.1665574E-05
     +,   6.3796499E-05,   6.5969492E-05,   6.8181209E-05
     +,   7.0428003E-05,   7.2705996E-05,   7.5011041E-05
     +,   7.7338773E-05,   7.9684665E-05,   8.2044033E-05
     +,   8.4412117E-05,   8.6784079E-05,   8.9155059E-05
     +,   9.1520436E-05,   9.3875402E-05,   9.6215721E-05
     +,   9.8537312E-05,   1.0083650E-04,   1.0311013E-04
     +,   1.0535579E-04,   1.0757180E-04,   1.0975751E-04
     +,   1.1191337E-04,   1.1404116E-04,   1.1614422E-04
     +,   1.1822764E-04,   1.2029857E-04,   1.2236636E-04
     +,   1.2444302E-04,   1.2654312E-04,   1.2868458E-04
     +,   1.3088844E-04,   1.3317933E-04,   1.3558567E-04
     +,   1.3813980E-04,   1.4087812E-04,   1.4384114E-04
     +,   1.4707311E-04,   1.5062247E-04,   1.5454125E-04
     +,   1.5888418E-04,   1.6370924E-04,   1.6907540E-04
     +,   1.7504350E-04,   1.8167339E-04,   1.8902415E-04
     +,   1.9715143E-04,   2.0610758E-04,   2.1593801E-04
     +,   2.2668191E-04,   2.3837008E-04,   2.5102292E-04
     +,   2.6465068E-04,   2.7925402E-04,   2.9482431E-04
     +,   3.1134367E-04,   3.2879080E-04,   3.4714187E-04
     +,   3.6637927E-04,   3.8649535E-04,   4.0750511E-04
     +,   4.2945222E-04,   4.5242606E-04,   4.7656841E-04
     +,   5.0209265E-04,   5.2929425E-04,   5.5856007E-04
     +,   5.9037778E-04,   6.2534219E-04,   6.6415570E-04
     +,   7.0762134E-04,   7.5665145E-04,   8.1226602E-04
     +,   8.7562855E-04,   9.4808248E-04,   1.0312485E-03
     +,   1.1271108E-03,   1.2381563E-03,   1.3674322E-03
     +,   1.5185729E-03,   1.6956402E-03,   1.9027716E-03
     +,   2.1436349E-03,   2.4207383E-03,   2.7347044E-03
     +,   3.0837662E-03,   3.4640429E-03,   3.8707976E-03
     +,   4.3014800E-03,   4.7600437E-03,   5.2619050E-03
     +,   5.8365860E-03,   6.5249340E-03,   7.3673553E-03
     +,   8.3848471E-03,   9.5604192E-03,   1.0834792E-02
     +,   1.2125392E-02,   1.3360289E-02,   1.4502416E-02
     +,   1.5542810E-02,   1.6470512E-02,   1.7250862E-02
     +,   1.7841244E-02,   1.8234849E-02,   1.8492896E-02
     +,   1.8728690E-02,   1.9044617E-02,   1.9461131E-02
     +,   1.9885181E-02,   2.0142591E-02,   2.0058308E-02
     +,   1.9537997E-02,   1.8603813E-02,   1.7372366E-02
     +,   1.6002590E-02,   1.4647606E-02,   1.3423940E-02
     +,   1.2393775E-02,   1.1559764E-02,   1.0878272E-02
     +,   1.0288649E-02,   9.7428784E-03,   9.2198756E-03
     +,   8.7207258E-03,   8.2532773E-03,   7.8179585E-03
     +,   7.4024885E-03,   6.9862767E-03,   6.5497155E-03
     +,   6.0824999E-03,   5.5869659E-03,   5.0761220E-03
     +,   4.5686732E-03,   4.0835473E-03,   3.6356843E-03
     +,   3.2341750E-03,   2.8822962E-03,   2.5787265E-03
     +,   2.3192288E-03,   2.0982360E-03,   1.9099974E-03
     +,   1.7492063E-03,   1.6112892E-03,   1.4924735E-03
     +,   1.3897475E-03,   1.3007601E-03,   1.2237174E-03
     +,   1.1572873E-03,   1.1004988E-03,   1.0526254E-03
     +,   1.0130968E-03,   9.8142086E-04,   9.5712446E-04
     +,   9.3971216E-04,   9.2865428E-04,   9.2338718E-04
     +,   9.2331442E-04,   9.2782662E-04,   9.3630963E-04
     +,   9.4815769E-04,   9.6277858E-04,   9.7959908E-04
     +,   9.9806360E-04,   1.0176307E-03,   1.0377738E-03
     +,   1.0579738E-03,   1.0777225E-03,   1.0965168E-03
     +,   1.1138672E-03,   1.1292993E-03,   1.1423591E-03
     +,   1.1526254E-03,   1.1597179E-03,   1.1633059E-03
     +,   1.1631208E-03,   1.1589665E-03,   1.1507255E-03
     +,   1.1383641E-03,   1.1219385E-03,   1.1015935E-03
     +,   1.0775563E-03,   1.0501363E-03,   1.0197125E-03
     +,   9.8671974E-04,   9.5163641E-04,   9.1497065E-04
     +,   8.7724515E-04,   8.3897507E-04,   8.0065726E-04
     +,   7.6276046E-04,   7.2570913E-04,   6.8987295E-04
     +,   6.5556366E-04,   6.2303286E-04,   5.9246592E-04
     +,   5.6398544E-04,   5.3765706E-04,   5.1349285E-04
     +,   4.9145432E-04,   4.7146503E-04,   4.5341579E-04
     +,   4.3717318E-04,   4.2258570E-04,   4.0949188E-04
     +,   3.9772704E-04,   3.8712806E-04,   3.7753666E-04
     +,   3.6880421E-04,   3.6079402E-04,   3.5338217E-04
     +,   3.4645840E-04,   3.3992730E-04,   3.3370656E-04
     +,   3.2772688E-04,   3.2193030E-04,   3.1627002E-04
     +,   3.1070836E-04,   3.0521513E-04,   2.9976660E-04
     +,   2.9434485E-04,   2.8893622E-04,   2.8353030E-04
     +,   2.7811897E-04,   2.7269672E-04,   2.6725925E-04
     +,   2.6180272E-04,   2.5632509E-04,   2.5082455E-04
     +,   2.4529960E-04,   2.3974906E-04,   2.3417255E-04
     +,   2.2857013E-04,   2.2294198E-04,   2.1728879E-04
     +,   2.1161226E-04,   2.0591449E-04,   2.0019803E-04
     +,   1.9446615E-04,   1.8872313E-04,   1.8297366E-04
     +,   1.7722277E-04,   1.7147690E-04,   1.6574271E-04
     +,   1.6002727E-04,   1.5433792E-04,   1.4868294E-04
     +,   1.4307075E-04,   1.3750966E-04,   1.3200815E-04
     +,   1.2657518E-04,   1.2121898E-04,   1.1594817E-04
     +,   1.1077057E-04,   1.0569423E-04,   1.0072616E-04
     +,   9.5873533E-05,   9.1142319E-05,   8.6538523E-05
     +,   8.2066879E-05,   7.7732082E-05,   7.3537689E-05
     +,   6.9486552E-05,   6.5581269E-05,   6.1823193E-05
     +,   5.8213504E-05,   5.4752269E-05,   5.1439354E-05
     +,   4.8273650E-05,   4.5253859E-05,   4.2377804E-05
     +,   3.9643204E-05,   3.7047008E-05,   3.4586141E-05
     +,   3.2256845E-05,   3.0055429E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz80 = Yx/0.163227272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8277441E-05,   3.9353898E-05
     +,   4.0427080E-05,   4.1495030E-05,   4.2555774E-05
     +,   4.3607288E-05,   4.4647531E-05,   4.5674453E-05
     +,   4.6685978E-05,   4.7680085E-05,   4.8654711E-05
     +,   4.9607825E-05,   5.0537437E-05,   5.1441584E-05
     +,   5.2318363E-05,   5.3165917E-05,   5.3982461E-05
     +,   5.4766304E-05,   5.5515811E-05,   5.6229477E-05
     +,   5.6905861E-05,   5.7543712E-05,   5.8141817E-05
     +,   5.8699199E-05,   5.9214930E-05,   5.9688340E-05
     +,   6.0118869E-05,   6.0506147E-05,   6.0850027E-05
     +,   6.1150567E-05,   6.1408027E-05,   6.1622937E-05
     +,   6.1796120E-05,   6.1928593E-05,   6.2021812E-05
     +,   6.2077444E-05,   6.2097599E-05,   6.2084764E-05
     +,   6.2041887E-05,   6.1972387E-05,   6.1880186E-05
     +,   6.1769846E-05,   6.1646526E-05,   6.1516090E-05
     +,   6.1385195E-05,   6.1261315E-05,   6.1152816E-05
     +,   6.1069091E-05,   6.1020524E-05,   6.1018654E-05
     +,   6.1076200E-05,   6.1207094E-05,   6.1426566E-05
     +,   6.1751147E-05,   6.2198698E-05,   6.2788356E-05
     +,   6.3540545E-05,   6.4476859E-05,   6.5619963E-05
     +,   6.6993489E-05,   6.8621717E-05,   7.0529539E-05
     +,   7.2741830E-05,   7.5283584E-05,   7.8179233E-05
     +,   8.1452104E-05,   8.5124448E-05,   8.9216242E-05
     +,   9.3745606E-05,   9.8727221E-05,   1.0417307E-04
     +,   1.1009056E-04,   1.1648372E-04,   1.2335107E-04
     +,   1.3068703E-04,   1.3848107E-04,   1.4671724E-04
     +,   1.5537466E-04,   1.6442859E-04,   1.7385041E-04
     +,   1.8360736E-04,   1.9366584E-04,   2.0398981E-04
     +,   2.1454523E-04,   2.2529885E-04,   2.3622268E-04
     +,   2.4729397E-04,   2.5849967E-04,   2.6983663E-04
     +,   2.8131634E-04,   2.9296699E-04,   3.0483486E-04
     +,   3.1698780E-04,   3.2951843E-04,   3.4254434E-04
     +,   3.5620900E-04,   3.7068396E-04,   3.8616496E-04
     +,   4.0287286E-04,   4.2104683E-04,   4.4094207E-04
     +,   4.6281912E-04,   4.8693948E-04,   5.1355007E-04
     +,   5.4287800E-04,   5.7511625E-04,   6.1041163E-04
     +,   6.4885750E-04,   6.9049193E-04,   7.3529745E-04
     +,   7.8320911E-04,   8.3414995E-04,   8.8806363E-04
     +,   9.4499491E-04,   1.0051698E-03,   1.0691233E-03
     +,   1.1378084E-03,   1.2127323E-03,   1.2960125E-03
     +,   1.3903979E-03,   1.4991779E-03,   1.6259959E-03
     +,   1.7746380E-03,   1.9488401E-03,   2.1521614E-03
     +,   2.3878613E-03,   2.6587760E-03,   2.9667716E-03
     +,   3.3120464E-03,   3.6922961E-03,   4.1029197E-03
     +,   4.5388290E-03,   4.9986201E-03,   5.4895631E-03
     +,   6.0310229E-03,   6.6524479E-03,   7.3845130E-03
     +,   8.2466155E-03,   9.2384955E-03,   1.0343668E-02
     +,   1.1544477E-02,   1.2838259E-02,   1.4239824E-02
     +,   1.5765244E-02,   1.7409176E-02,   1.9137511E-02
     +,   2.0902002E-02,   2.2650840E-02,   2.4300111E-02
     +,   2.5683507E-02,   2.6563432E-02,   2.6750961E-02
     +,   2.6253788E-02,   2.5309257E-02,   2.4252722E-02
     +,   2.3314007E-02,   2.2491602E-02,   2.1591563E-02
     +,   2.0391239E-02,   1.8798368E-02,   1.6899381E-02
     +,   1.4893578E-02,   1.2987263E-02,   1.1318508E-02
     +,   9.9354042E-03,   8.8145677E-03,   7.8958338E-03
     +,   7.1143159E-03,   6.4202310E-03,   5.7849027E-03
     +,   5.1975925E-03,   4.6588574E-03,   4.1742884E-03
     +,   3.7499382E-03,   3.3895364E-03,   3.0932729E-03
     +,   2.8580262E-03,   2.6783720E-03,   2.5476583E-03
     +,   2.4588504E-03,   2.4049548E-03,   2.3791662E-03
     +,   2.3749282E-03,   2.3860363E-03,   2.4067899E-03
     +,   2.4321571E-03,   2.4578839E-03,   2.4805469E-03
     +,   2.4975259E-03,   2.5069288E-03,   2.5075071E-03
     +,   2.4985827E-03,   2.4799739E-03,   2.4519577E-03
     +,   2.4152028E-03,   2.3707242E-03,   2.3198139E-03
     +,   2.2639569E-03,   2.2047453E-03,   2.1437872E-03
     +,   2.0826219E-03,   2.0226429E-03,   1.9650317E-03
     +,   1.9107158E-03,   1.8603458E-03,   1.8142760E-03
     +,   1.7725732E-03,   1.7350409E-03,   1.7012482E-03
     +,   1.6705764E-03,   1.6422679E-03,   1.6154912E-03
     +,   1.5893885E-03,   1.5631345E-03,   1.5359813E-03
     +,   1.5072958E-03,   1.4765875E-03,   1.4435160E-03
     +,   1.4079001E-03,   1.3697095E-03,   1.3290427E-03
     +,   1.2861113E-03,   1.2412162E-03,   1.1947213E-03
     +,   1.1470277E-03,   1.0985488E-03,   1.0497038E-03
     +,   1.0008949E-03,   9.5249491E-04,   9.0484275E-04
     +,   8.5824379E-04,   8.1296312E-04,   7.6922285E-04
     +,   7.2720536E-04,   6.8706059E-04,   6.4889737E-04
     +,   6.1279134E-04,   5.7878782E-04,   5.4690230E-04
     +,   5.1712047E-04,   4.8940198E-04,   4.6368639E-04
     +,   4.3989232E-04,   4.1791968E-04,   3.9765541E-04
     +,   3.7897704E-04,   3.6175497E-04,   3.4585485E-04
     +,   3.3114213E-04,   3.1748554E-04,   3.0475768E-04
     +,   2.9283768E-04,   2.8161443E-04,   2.7098603E-04
     +,   2.6086072E-04,   2.5115773E-04,   2.4180810E-04
     +,   2.3275355E-04,   2.2394559E-04,   2.1534591E-04
     +,   2.0692537E-04,   1.9866323E-04,   1.9054534E-04
     +,   1.8256367E-04,   1.7471628E-04,   1.6700463E-04
     +,   1.5943359E-04,   1.5201111E-04,   1.4474663E-04
     +,   1.3765041E-04,   1.3073273E-04,   1.2400471E-04
     +,   1.1747647E-04,   1.1115708E-04,   1.0505425E-04
     +,   9.9175159E-05,   9.3524570E-05,   8.8106601E-05
     +,   8.2923019E-05,   7.7974837E-05,   7.3260941E-05
     +,   6.8779584E-05,   6.4527150E-05,   6.0499518E-05
     +,   5.6691108E-05,   5.3096021E-05,   4.9707349E-05
     +,   4.6517634E-05,   4.3519380E-05,   4.0704344E-05
     +,   3.8064518E-05,   3.5591442E-05,   3.3276978E-05
     +,   3.1112759E-05,   2.9090830E-05,   2.7203165E-05
     +,   2.5442179E-05,   2.3800338E-05,   2.2270598E-05
     +,   2.0845982E-05,   1.9520046E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz85 = Yx/0.183590909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1190601E-05,   1.1789768E-05
     +,   1.2416171E-05,   1.3070400E-05,   1.3752994E-05
     +,   1.4464436E-05,   1.5205143E-05,   1.5975462E-05
     +,   1.6775643E-05,   1.7605909E-05,   1.8466348E-05
     +,   1.9356956E-05,   2.0277643E-05,   2.1228212E-05
     +,   2.2208354E-05,   2.3217643E-05,   2.4255532E-05
     +,   2.5321364E-05,   2.6414347E-05,   2.7533553E-05
     +,   2.8677958E-05,   2.9846369E-05,   3.1037474E-05
     +,   3.2249893E-05,   3.3481992E-05,   3.4732151E-05
     +,   3.5998550E-05,   3.7279271E-05,   3.8572311E-05
     +,   3.9875529E-05,   4.1186733E-05,   4.2503631E-05
     +,   4.3823857E-05,   4.5145011E-05,   4.6464629E-05
     +,   4.7780250E-05,   4.9089347E-05,   5.0389488E-05
     +,   5.1678249E-05,   5.2953168E-05,   5.4211985E-05
     +,   5.5452489E-05,   5.6672547E-05,   5.7870260E-05
     +,   5.9043858E-05,   6.0191804E-05,   6.1312785E-05
     +,   6.2405779E-05,   6.3470070E-05,   6.4505250E-05
     +,   6.5511304E-05,   6.6488647E-05,   6.7438079E-05
     +,   6.8360961E-05,   6.9259055E-05,   7.0134767E-05
     +,   7.0991024E-05,   7.1831375E-05,   7.2660012E-05
     +,   7.3481795E-05,   7.4302312E-05,   7.5127798E-05
     +,   7.5965290E-05,   7.6822544E-05,   7.7708195E-05
     +,   7.8631463E-05,   7.9602563E-05,   8.0632293E-05
     +,   8.1732418E-05,   8.2915234E-05,   8.4193940E-05
     +,   8.5582265E-05,   8.7094741E-05,   8.8746281E-05
     +,   9.0552436E-05,   9.2529226E-05,   9.4692878E-05
     +,   9.7059819E-05,   9.9646808E-05,   1.0247056E-04
     +,   1.0554743E-04,   1.0889398E-04,   1.1252585E-04
     +,   1.1645878E-04,   1.2070721E-04,   1.2528556E-04
     +,   1.3020659E-04,   1.3548289E-04,   1.4112509E-04
     +,   1.4714325E-04,   1.5354629E-04,   1.6034121E-04
     +,   1.6753373E-04,   1.7512852E-04,   1.8312872E-04
     +,   1.9153531E-04,   2.0034862E-04,   2.0956635E-04
     +,   2.1918592E-04,   2.2920193E-04,   2.3960898E-04
     +,   2.5039923E-04,   2.6156555E-04,   2.7309940E-04
     +,   2.8499414E-04,   2.9724560E-04,   3.0985283E-04
     +,   3.2282120E-04,   3.3616612E-04,   3.4991652E-04
     +,   3.6411657E-04,   3.7883507E-04,   3.9416572E-04
     +,   4.1023677E-04,   4.2721181E-04,   4.4529838E-04
     +,   4.6474620E-04,   4.8585387E-04,   5.0896290E-04
     +,   5.3446140E-04,   5.6277844E-04,   5.9437990E-04
     +,   6.2976690E-04,   6.6947774E-04,   7.1408786E-04
     +,   7.6420733E-04,   8.2049263E-04,   8.8363001E-04
     +,   9.5433969E-04,   1.0333365E-03,   1.1213166E-03
     +,   1.2189021E-03,   1.3266293E-03,   1.4449166E-03
     +,   1.5741092E-03,   1.7145326E-03,   1.8665845E-03
     +,   2.0308730E-03,   2.2083372E-03,   2.4002946E-03
     +,   2.6083554E-03,   2.8342090E-03,   3.0792397E-03
     +,   3.3441153E-03,   3.6285780E-03,   3.9319741E-03
     +,   4.2546904E-03,   4.6006441E-03,   4.9801148E-03
     +,   5.4115169E-03,   5.9198723E-03,   6.5307380E-03
     +,   7.2604087E-03,   8.1064180E-03,   9.0442440E-03
     +,   1.0034437E-02,   1.1038670E-02,   1.2037283E-02
     +,   1.3038257E-02,   1.4071479E-02,   1.5167198E-02
     +,   1.6324408E-02,   1.7485501E-02,   1.8538410E-02
     +,   1.9356541E-02,   1.9856513E-02,   2.0032922E-02
     +,   1.9941585E-02,   1.9642888E-02,   1.9149572E-02
     +,   1.8421261E-02,   1.7413436E-02,   1.6143978E-02
     +,   1.4722928E-02,   1.3319823E-02,   1.2095497E-02
     +,   1.1149978E-02,   1.0513518E-02,   1.0168476E-02
     +,   1.0073333E-02,   1.0173568E-02,   1.0403297E-02
     +,   1.0688532E-02,   1.0956817E-02,   1.1150140E-02
     +,   1.1234918E-02,   1.1204325E-02,   1.1072088E-02
     +,   1.0861003E-02,   1.0591773E-02,   1.0276558E-02
     +,   9.9189095E-03,   9.5181996E-03,   9.0747513E-03
     +,   8.5935760E-03,   8.0852592E-03,   7.5647077E-03
     +,   7.0484797E-03,   6.5518916E-03,   6.0867774E-03
     +,   5.6603076E-03,   5.2748988E-03,   4.9291290E-03
     +,   4.6191905E-03,   4.3403488E-03,   4.0878723E-03
     +,   3.8574783E-03,   3.6452720E-03,   3.4475117E-03
     +,   3.2604921E-03,   3.0806896E-03,   2.9051392E-03
     +,   2.7318276E-03,   2.5599748E-03,   2.3901039E-03
     +,   2.2238558E-03,   2.0636069E-03,   1.9119723E-03
     +,   1.7713788E-03,   1.6437250E-03,   1.5301462E-03
     +,   1.4309675E-03,   1.3457811E-03,   1.2735805E-03
     +,   1.2129445E-03,   1.1622357E-03,   1.1197682E-03
     +,   1.0839250E-03,   1.0532420E-03,   1.0264541E-03
     +,   1.0025036E-03,   9.8053378E-04,   9.5986138E-04
     +,   9.3995646E-04,   9.2041475E-04,   9.0093218E-04
     +,   8.8128611E-04,   8.6132239E-04,   8.4094109E-04
     +,   8.2008459E-04,   7.9873443E-04,   7.7690301E-04
     +,   7.5462752E-04,   7.3196576E-04,   7.0899015E-04
     +,   6.8578764E-04,   6.6245301E-04,   6.3908531E-04
     +,   6.1578589E-04,   5.9265801E-04,   5.6980050E-04
     +,   5.4730801E-04,   5.2526977E-04,   5.0376775E-04
     +,   4.8287294E-04,   4.6264564E-04,   4.4313664E-04
     +,   4.2438449E-04,   4.0641462E-04,   3.8923998E-04
     +,   3.7286323E-04,   3.5727609E-04,   3.4245898E-04
     +,   3.2838390E-04,   3.1501689E-04,   3.0231674E-04
     +,   2.9023824E-04,   2.7873437E-04,   2.6775675E-04
     +,   2.5725673E-04,   2.4718692E-04,   2.3750322E-04
     +,   2.2816462E-04,   2.1913339E-04,   2.1037611E-04
     +,   2.0186460E-04,   1.9357409E-04,   1.8548549E-04
     +,   1.7758262E-04,   1.6985455E-04,   1.6229265E-04
     +,   1.5489256E-04,   1.4765158E-04,   1.4057031E-04
     +,   1.3365019E-04,   1.2689496E-04,   1.2030874E-04
     +,   1.1389631E-04,   1.0766341E-04,   1.0161504E-04
     +,   9.5756783E-05,   9.0093134E-05,   8.4628729E-05
     +,   7.9366902E-05,   7.4310854E-05,   6.9462352E-05
     +,   6.4822940E-05,   6.0392711E-05,   5.6171426E-05
     +,   5.2157517E-05,   4.8349106E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz90 = Yx/0.185022727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2782879E-05,   2.3479133E-05
     +,   2.4186051E-05,   2.4903120E-05,   2.5629803E-05
     +,   2.6365529E-05,   2.7109711E-05,   2.7861732E-05
     +,   2.8620943E-05,   2.9386720E-05,   3.0158390E-05
     +,   3.0935280E-05,   3.1716721E-05,   3.2502048E-05
     +,   3.3290595E-05,   3.4081713E-05,   3.4874778E-05
     +,   3.5669189E-05,   3.6464364E-05,   3.7259790E-05
     +,   3.8054968E-05,   3.8849470E-05,   3.9642884E-05
     +,   4.0434967E-05,   4.1225405E-05,   4.2014079E-05
     +,   4.2800897E-05,   4.3585867E-05,   4.4369091E-05
     +,   4.5150777E-05,   4.5931218E-05,   4.6710829E-05
     +,   4.7490121E-05,   4.8269743E-05,   4.9050417E-05
     +,   4.9832997E-05,   5.0618433E-05,   5.1407784E-05
     +,   5.2202256E-05,   5.3003056E-05,   5.3811582E-05
     +,   5.4629236E-05,   5.5457549E-05,   5.6298086E-05
     +,   5.7152502E-05,   5.8022411E-05,   5.8909540E-05
     +,   5.9815571E-05,   6.0742230E-05,   6.1691186E-05
     +,   6.2664054E-05,   6.3662475E-05,   6.4687920E-05
     +,   6.5741893E-05,   6.6825647E-05,   6.7940491E-05
     +,   6.9087466E-05,   7.0267539E-05,   7.1481511E-05
     +,   7.2730021E-05,   7.4013551E-05,   7.5332435E-05
     +,   7.6686738E-05,   7.8076489E-05,   7.9501537E-05
     +,   8.0961472E-05,   8.2455903E-05,   8.3984152E-05
     +,   8.5545616E-05,   8.7139444E-05,   8.8764893E-05
     +,   9.0421025E-05,   9.2107104E-05,   9.3822237E-05
     +,   9.5565782E-05,   9.7337150E-05,   9.9135897E-05
     +,   1.0096169E-04,   1.0281454E-04,   1.0469476E-04
     +,   1.0660273E-04,   1.0853947E-04,   1.1050604E-04
     +,   1.1250416E-04,   1.1453570E-04,   1.1660319E-04
     +,   1.1870936E-04,   1.2085767E-04,   1.2305175E-04
     +,   1.2529593E-04,   1.2759506E-04,   1.2995432E-04
     +,   1.3237941E-04,   1.3487677E-04,   1.3745345E-04
     +,   1.4011677E-04,   1.4287521E-04,   1.4573762E-04
     +,   1.4871403E-04,   1.5181498E-04,   1.5505272E-04
     +,   1.5844015E-04,   1.6199212E-04,   1.6572470E-04
     +,   1.6965618E-04,   1.7380701E-04,   1.7819999E-04
     +,   1.8286055E-04,   1.8781774E-04,   1.9310406E-04
     +,   1.9875534E-04,   2.0481249E-04,   2.1131990E-04
     +,   2.1832807E-04,   2.2589143E-04,   2.3407080E-04
     +,   2.4293117E-04,   2.5254433E-04,   2.6298629E-04
     +,   2.7433908E-04,   2.8669005E-04,   3.0013034E-04
     +,   3.1475574E-04,   3.3066684E-04,   3.4796819E-04
     +,   3.6676592E-04,   3.8717082E-04,   4.0929369E-04
     +,   4.3324879E-04,   4.5914782E-04,   4.8710444E-04
     +,   5.1722553E-04,   5.4961629E-04,   5.8436982E-04
     +,   6.2157208E-04,   6.6129712E-04,   7.0360088E-04
     +,   7.4852753E-04,   7.9611124E-04,   8.4638380E-04
     +,   8.9937920E-04,   9.5515035E-04,   1.0137908E-03
     +,   1.0754507E-03,   1.1403415E-03,   1.2087609E-03
     +,   1.2810838E-03,   1.3577410E-03,   1.4391877E-03
     +,   1.5258595E-03,   1.6181059E-03,   1.7161135E-03
     +,   1.8198496E-03,   1.9290185E-03,   2.0430286E-03
     +,   2.1609729E-03,   2.2816539E-03,   2.4035985E-03
     +,   2.5250574E-03,   2.6439813E-03,   2.7580170E-03
     +,   2.8644635E-03,   2.9602856E-03,   3.0422246E-03
     +,   3.1070516E-03,   3.1519916E-03,   3.1753106E-03
     +,   3.1770715E-03,   3.1598648E-03,   3.1294103E-03
     +,   3.0948829E-03,   3.0688457E-03,   3.0668657E-03
     +,   3.1069857E-03,   3.2092496E-03,   3.3953353E-03
     +,   3.6880842E-03,   4.1106725E-03,   4.6854699E-03
     +,   5.4328707E-03,   6.3698892E-03,   7.5076590E-03
     +,   8.8467021E-03,   1.0369008E-02,   1.2025579E-02
     +,   1.3723053E-02,   1.5327075E-02,   1.6709978E-02
     +,   1.7840836E-02,   1.8845011E-02,   1.9936452E-02
     +,   2.1236828E-02,   2.2644313E-02,   2.3890126E-02
     +,   2.4718048E-02,   2.5004320E-02,   2.4750266E-02
     +,   2.4035370E-02,   2.3006417E-02,   2.1866670E-02
     +,   2.0807687E-02,   1.9918095E-02,   1.9152477E-02
     +,   1.8382052E-02,   1.7476086E-02,   1.6359469E-02
     +,   1.5030163E-02,   1.3546060E-02,   1.1998705E-02
     +,   1.0488498E-02,   9.1054086E-03,   7.9144696E-03
     +,   6.9467663E-03,   6.1993734E-03,   5.6439089E-03
     +,   5.2388972E-03,   4.9410714E-03,   4.7128699E-03
     +,   4.5259194E-03,   4.3612593E-03,   4.2076441E-03
     +,   4.0591164E-03,   3.9126966E-03,   3.7666864E-03
     +,   3.6197007E-03,   3.4704083E-03,   3.3176846E-03
     +,   3.1609465E-03,   3.0004305E-03,   2.8373390E-03
     +,   2.6737240E-03,   2.5121814E-03,   2.3554370E-03
     +,   2.2059483E-03,   2.0656199E-03,   1.9356066E-03
     +,   1.8163096E-03,   1.7074867E-03,   1.6084022E-03
     +,   1.5180253E-03,   1.4352149E-03,   1.3588675E-03
     +,   1.2880086E-03,   1.2218389E-03,   1.1597525E-03
     +,   1.1013262E-03,   1.0462884E-03,   9.9447730E-04
     +,   9.4581099E-04,   9.0025878E-04,   8.5780467E-04
     +,   8.1843307E-04,   7.8211061E-04,   7.4877538E-04
     +,   7.1832439E-04,   6.9061539E-04,   6.6546572E-04
     +,   6.4265472E-04,   6.2192726E-04,   6.0300383E-04
     +,   5.8558933E-04,   5.6938385E-04,   5.5408926E-04
     +,   5.3942081E-04,   5.2511698E-04,   5.1094266E-04
     +,   4.9669651E-04,   4.8221470E-04,   4.6737326E-04
     +,   4.5208514E-04,   4.3630201E-04,   4.2001193E-04
     +,   4.0323497E-04,   3.8601842E-04,   3.6843293E-04
     +,   3.5056955E-04,   3.3253027E-04,   3.1442897E-04
     +,   2.9638072E-04,   2.7850355E-04,   2.6090915E-04
     +,   2.4370494E-04,   2.2698673E-04,   2.1084126E-04
     +,   1.9534054E-04,   1.8054509E-04,   1.6650045E-04
     +,   1.5323843E-04,   1.4077940E-04,   1.2912977E-04
     +,   1.1828662E-04,   1.0823591E-04,   9.8956509E-05
     +,   9.0419308E-05,   8.2590755E-05,   7.5432217E-05
     +,   6.8903166E-05,   6.2960498E-05,   5.7561341E-05
     +,   5.2662224E-05,   4.8221362E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ttz95 = Yx/0.184386363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7760400E-05,   1.7836195E-05
     +,   1.7910595E-05,   1.7983626E-05,   1.8055314E-05
     +,   1.8125673E-05,   1.8194727E-05,   1.8262492E-05
     +,   1.8328978E-05,   1.8394203E-05,   1.8458177E-05
     +,   1.8520905E-05,   1.8582392E-05,   1.8642644E-05
     +,   1.8701654E-05,   1.8759427E-05,   1.8815952E-05
     +,   1.8871227E-05,   1.8925239E-05,   1.8977975E-05
     +,   1.9029419E-05,   1.9079554E-05,   1.9128362E-05
     +,   1.9175819E-05,   1.9221896E-05,   1.9266574E-05
     +,   1.9309819E-05,   1.9351599E-05,   1.9391880E-05
     +,   1.9430629E-05,   1.9467807E-05,   1.9503372E-05
     +,   1.9537289E-05,   1.9569512E-05,   1.9599995E-05
     +,   1.9628691E-05,   1.9655559E-05,   1.9680545E-05
     +,   1.9703606E-05,   1.9724681E-05,   1.9743729E-05
     +,   1.9760690E-05,   1.9775514E-05,   1.9788151E-05
     +,   1.9798537E-05,   1.9806626E-05,   1.9812360E-05
     +,   1.9815685E-05,   1.9816543E-05,   1.9814879E-05
     +,   1.9810639E-05,   1.9803771E-05,   1.9794215E-05
     +,   1.9781921E-05,   1.9766834E-05,   1.9748899E-05
     +,   1.9728068E-05,   1.9704285E-05,   1.9677504E-05
     +,   1.9647672E-05,   1.9614747E-05,   1.9578674E-05
     +,   1.9539415E-05,   1.9496923E-05,   1.9451156E-05
     +,   1.9402078E-05,   1.9349642E-05,   1.9293819E-05
     +,   1.9234567E-05,   1.9171865E-05,   1.9105673E-05
     +,   1.9035970E-05,   1.8962724E-05,   1.8885923E-05
     +,   1.8805542E-05,   1.8721559E-05,   1.8633964E-05
     +,   1.8542749E-05,   1.8447905E-05,   1.8349423E-05
     +,   1.8247310E-05,   1.8141558E-05,   1.8032182E-05
     +,   1.7919185E-05,   1.7802580E-05,   1.7682387E-05
     +,   1.7558623E-05,   1.7431310E-05,   1.7300485E-05
     +,   1.7166172E-05,   1.7028406E-05,   1.6887225E-05
     +,   1.6742682E-05,   1.6594819E-05,   1.6443682E-05
     +,   1.6289334E-05,   1.6131831E-05,   1.5971240E-05
     +,   1.5807622E-05,   1.5641055E-05,   1.5471609E-05
     +,   1.5299369E-05,   1.5124408E-05,   1.4946825E-05
     +,   1.4766701E-05,   1.4584128E-05,   1.4399203E-05
     +,   1.4212035E-05,   1.4022720E-05,   1.3831360E-05
     +,   1.3638075E-05,   1.3442961E-05,   1.3246148E-05
     +,   1.3047739E-05,   1.2847865E-05,   1.2646632E-05
     +,   1.2444178E-05,   1.2240614E-05,   1.2036076E-05
     +,   1.1830683E-05,   1.1624560E-05,   1.1417838E-05
     +,   1.1210656E-05,   1.1003137E-05,   1.0795400E-05
     +,   1.0587591E-05,   1.0379823E-05,   1.0172241E-05
     +,   9.9649578E-06,   9.7581133E-06,   9.5518226E-06
     +,   9.3462204E-06,   9.1414195E-06,   8.9375517E-06
     +,   8.7347298E-06,   8.5330657E-06,   8.3326804E-06
     +,   8.1336921E-06,   7.9362053E-06,   7.7403174E-06
     +,   7.5461426E-06,   7.3537894E-06,   7.1633508E-06
     +,   6.9749203E-06,   6.7886094E-06,   6.6045204E-06
     +,   6.4227588E-06,   6.2434729E-06,   6.0668422E-06
     +,   5.8931059E-06,   5.7226089E-06,   5.5559058E-06
     +,   5.3938329E-06,   5.2376986E-06,   5.0895328E-06
     +,   4.9524856E-06,   4.8313691E-06,   4.7334343E-06
     +,   4.6694781E-06,   4.6553464E-06,   4.7139197E-06
     +,   4.8777583E-06,   5.1924308E-06,   5.7206671E-06
     +,   6.5474437E-06,   7.7859113E-06,   9.5839659E-06
     +,   1.2131443E-05,   1.5667674E-05,   2.0488418E-05
     +,   2.6951226E-05,   3.5479090E-05,   4.6561414E-05
     +,   6.0749924E-05,   7.8647157E-05,   1.0089308E-04
     +,   1.2814095E-04,   1.6102428E-04,   2.0012011E-04
     +,   2.4590894E-04,   2.9872611E-04,   3.5871088E-04
     +,   4.2576407E-04,   4.9951504E-04,   5.7929353E-04
     +,   6.6410995E-04,   7.5266627E-04,   8.4338890E-04
     +,   9.3446608E-04,   1.0239045E-03,   1.1096237E-03
     +,   1.1895393E-03,   1.2616514E-03,   1.3241463E-03
     +,   1.3754850E-03,   1.4144726E-03,   1.4403089E-03
     +,   1.4526254E-03,   1.4514935E-03,   1.4374050E-03
     +,   1.4112352E-03,   1.3741892E-03,   1.3277256E-03
     +,   1.2734785E-03,   1.2131813E-03,   1.1485765E-03
     +,   1.0813446E-03,   1.0130481E-03,   9.4507582E-04
     +,   8.7860442E-04,   8.1458234E-04,   7.5372861E-04
     +,   6.9653447E-04,   6.4327795E-04,   5.9405348E-04
     +,   5.4880575E-04,   5.0735846E-04,   4.6944595E-04
     +,   4.3474798E-04,   4.0292123E-04,   3.7361597E-04
     +,   3.4649918E-04,   3.2126950E-04,   2.9766379E-04
     +,   2.7546071E-04,   2.5448270E-04,   2.3459506E-04
     +,   2.1570025E-04,   1.9773093E-04,   1.8064557E-04
     +,   1.6442292E-04,   1.4905528E-04,   1.3454224E-04
     +,   1.2088756E-04,   1.0809709E-04,   9.6173229E-05
     +,   8.5114676E-05,   7.4915733E-05,   6.5564818E-05
     +,   5.7043551E-05,   4.9327606E-05,   4.2387441E-05
     +,   3.6188103E-05,   3.0689676E-05,   2.5848498E-05
     +,   2.1618333E-05,   1.7950833E-05,   1.4796317E-05
     +,   1.2105004E-05,   9.8280725E-06,   7.9179172E-06
     +,   6.3291573E-06,   5.0192552E-06,   3.9487977E-06
     +,   3.0817573E-06,   2.3857458E-06,   1.8320803E-06
     +,   1.3956463E-06,   1.0547296E-06,   7.9083480E-07
     +,   5.8841954E-07,   4.3456765E-07,   3.1867242E-07
     +,   2.3214264E-07,   1.6810701E-07,   1.2112224E-07
     +,   8.6933738E-08,   6.2255403E-08,   4.4575533E-08
     +,   3.1995299E-08,   2.3096419E-08,   1.6831319E-08
     +,   1.2433889E-08,   9.3496526E-09,   7.1818036E-09
     +,   5.6493117E-09,   4.5547868E-09,   3.7611780E-09
     +,   3.1739784E-09,   2.7286979E-09,   2.3815598E-09
     +,   2.1030917E-09,   1.8734836E-09,   1.6794807E-09
     +,   1.5121586E-09,   1.3655052E-09,   1.2353870E-09
     +,   1.1189170E-09,   1.0140306E-09,   9.1918279E-10
     +,   8.3319207E-10,   7.5510215E-10,   6.8413003E-10
     +,   6.1959698E-10,   5.6091864E-10,   5.0756843E-10
     +,   4.5907914E-10,   4.1502179E-10,   3.7501083E-10
     +,   3.3868935E-10,   3.0573497E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz100 = Yx/0.0107916666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4548663E-05,   1.4702648E-05
     +,   1.4842837E-05,   1.4968804E-05,   1.5080172E-05
     +,   1.5176593E-05,   1.5257776E-05,   1.5323469E-05
     +,   1.5373464E-05,   1.5407611E-05,   1.5425805E-05
     +,   1.5427984E-05,   1.5414147E-05,   1.5384332E-05
     +,   1.5338635E-05,   1.5277197E-05,   1.5200209E-05
     +,   1.5107905E-05,   1.5000573E-05,   1.4878542E-05
     +,   1.4742182E-05,   1.4591908E-05,   1.4428175E-05
     +,   1.4251462E-05,   1.4062303E-05,   1.3861249E-05
     +,   1.3648882E-05,   1.3425818E-05,   1.3192689E-05
     +,   1.2950150E-05,   1.2698871E-05,   1.2439540E-05
     +,   1.2172854E-05,   1.1899521E-05,   1.1620247E-05
     +,   1.1335747E-05,   1.1046733E-05,   1.0753916E-05
     +,   1.0457982E-05,   1.0159643E-05,   9.8595647E-06
     +,   9.5584155E-06,   9.2568444E-06,   8.9554806E-06
     +,   8.6549335E-06,   8.3557879E-06,   8.0586078E-06
     +,   7.7639288E-06,   7.4722598E-06,   7.1840814E-06
     +,   6.8998465E-06,   6.6199768E-06,   6.3448706E-06
     +,   6.0748735E-06,   5.8103374E-06,   5.5515461E-06
     +,   5.2987757E-06,   5.0522631E-06,   4.8122174E-06
     +,   4.5788197E-06,   4.3522173E-06,   4.1325320E-06
     +,   3.9198685E-06,   3.7142884E-06,   3.5158303E-06
     +,   3.3245276E-06,   3.1403636E-06,   2.9633277E-06
     +,   2.7933640E-06,   2.6304201E-06,   2.4744043E-06
     +,   2.3252305E-06,   2.1827773E-06,   2.0469279E-06
     +,   1.9175411E-06,   1.7944635E-06,   1.6775425E-06
     +,   1.5666152E-06,   1.4615036E-06,   1.3620265E-06
     +,   1.2680050E-06,   1.1792458E-06,   1.0955634E-06
     +,   1.0167605E-06,   9.4264828E-07,   8.7302874E-07
     +,   8.0771372E-07,   7.4650734E-07,   6.8922458E-07
     +,   6.3567671E-07,   5.8567889E-07,   5.3905336E-07
     +,   4.9562590E-07,   4.5522395E-07,   4.1768033E-07
     +,   3.8283616E-07,   3.5053344E-07,   3.2062417E-07
     +,   2.9296160E-07,   2.6740850E-07,   2.4383013E-07
     +,   2.2210062E-07,   2.0209687E-07,   1.8370446E-07
     +,   1.6681255E-07,   1.5131616E-07,   1.3711684E-07
     +,   1.2412137E-07,   1.1224093E-07,   1.0139190E-07
     +,   9.1496744E-08,   8.2481321E-08,   7.4277274E-08
     +,   6.6819560E-08,   6.0048450E-08,   5.3907261E-08
     +,   4.8344109E-08,   4.3309885E-08,   3.8759847E-08
     +,   3.4651922E-08,   3.0947291E-08,   2.7610353E-08
     +,   2.4608360E-08,   2.1911042E-08,   1.9490852E-08
     +,   1.7323137E-08,   1.5385652E-08,   1.3659398E-08
     +,   1.2128503E-08,   1.0781428E-08,   9.6117398E-09
     +,   8.6202983E-09,   7.8177056E-09,   7.2286150E-09
     +,   6.8974511E-09,   6.8968218E-09,   7.3392030E-09
     +,   8.3929033E-09,   1.0303869E-08,   1.3424737E-08
     +,   1.8252448E-08,   2.5476899E-08,   3.6043140E-08
     +,   5.1227872E-08,   7.2729968E-08,   1.0278349E-07
     +,   1.4428406E-07,   2.0092909E-07,   2.7737235E-07
     +,   3.7939137E-07,   5.1404606E-07,   6.8981166E-07
     +,   9.1669824E-07,   1.2063326E-06,   1.5719536E-06
     +,   2.0282916E-06,   2.5913712E-06,   3.2782082E-06
     +,   4.1063136E-06,   5.0929357E-06,   6.2544218E-06
     +,   7.6052120E-06,   9.1566690E-06,   1.0916000E-05
     +,   1.2885267E-05,   1.5060215E-05,   1.7429238E-05
     +,   1.9972851E-05,   2.2663666E-05,   2.5466570E-05
     +,   2.8339537E-05,   3.1235664E-05,   3.4106277E-05
     +,   3.6904883E-05,   3.9592567E-05,   4.2145697E-05
     +,   4.4564684E-05,   4.6884630E-05,   4.9187915E-05
     +,   5.1618066E-05,   5.4393960E-05,   5.7824123E-05
     +,   6.2320207E-05,   6.8409252E-05,   7.6744102E-05
     +,   8.8110821E-05,   1.0343565E-04,   1.2379119E-04
     +,   1.5039786E-04,   1.8461506E-04,   2.2792634E-04
     +,   2.8189318E-04,   3.4806808E-04,   4.2786429E-04
     +,   5.2237528E-04,   6.3213502E-04,   7.5684499E-04
     +,   8.9511991E-04,   1.0442982E-03,   1.2003478E-03
     +,   1.3579245E-03,   1.5106418E-03,   1.6515170E-03
     +,   1.7735433E-03,   1.8703353E-03,   1.9367927E-03
     +,   1.9696220E-03,   1.9676932E-03,   1.9321698E-03
     +,   1.8663778E-03,   1.7754488E-03,   1.6657951E-03
     +,   1.5444596E-03,   1.4184301E-03,   1.2940277E-03
     +,   1.1764164E-03,   1.0692710E-03,   9.7464269E-04
     +,   8.9303456E-04,   8.2363549E-04,   7.6464342E-04
     +,   7.1366865E-04,   6.6812988E-04,   6.2558713E-04
     +,   5.8400456E-04,   5.4191425E-04,   4.9848604E-04
     +,   4.5350433E-04,   4.0727787E-04,   3.6051151E-04
     +,   3.1415734E-04,   2.6925883E-04,   2.2681302E-04
     +,   1.8766856E-04,   1.5245898E-04,   1.2156220E-04
     +,   9.5105548E-05,   7.2993498E-05,   5.4949265E-05
     +,   4.0567131E-05,   2.9367417E-05,   2.0844791E-05
     +,   1.4505647E-05,   9.8956871E-06,   6.6173830E-06
     +,   4.3374434E-06,   2.7865419E-06,   1.7544754E-06
     +,   1.0825387E-06,   6.5454600E-07,   3.8779584E-07
     +,   2.2511149E-07,   1.2802793E-07,   7.1335847E-08
     +,   3.8938133E-08,   2.0819702E-08,   1.0904182E-08
     +,   5.5939786E-09,   2.8108029E-09,   1.3832346E-09
     +,   6.6667039E-10,   3.1468414E-10,   1.4546721E-10
     +,   6.5850735E-11,   2.9192794E-11,   1.2673371E-11
     +,   5.3875667E-12,   2.2427700E-12,   9.1427592E-13
     +,   3.6496931E-13,   1.4266169E-13,   5.4606279E-14
     +,   2.0468031E-14,   7.5127020E-15,   2.7001507E-15
     +,   9.5035117E-16,   3.2753332E-16,   1.1054428E-16
     +,   3.6534417E-17,   1.1824716E-17,   3.7479107E-18
     +,   1.1635149E-18,   3.5384367E-19,   1.0548912E-19
     +,   3.0877599E-20,   8.9140359E-21,   2.5681688E-21
     +,   7.6108215E-22,   2.4810478E-22,   9.8522934E-23
     +,   5.0589735E-23,   3.1819500E-23,   2.2242044E-23
     +,   1.6217160E-23,   1.1996149E-23,   8.9107661E-24
     +,   6.6233251E-24,   4.9205629E-24,   3.6524019E-24
     +,   2.7083853E-24,   2.0063259E-24
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz104 = Yx/0.01092
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4473574E-07,   1.6509873E-07
     +,   1.8799987E-07,   2.1370600E-07,   2.4250576E-07
     +,   2.7470887E-07,   3.1064832E-07,   3.5067993E-07
     +,   3.9518255E-07,   4.4456078E-07,   4.9924080E-07
     +,   5.5967354E-07,   6.2633274E-07,   6.9971492E-07
     +,   7.8033793E-07,   8.6874024E-07,   9.6547922E-07
     +,   1.0711282E-06,   1.1862761E-06,   1.3115223E-06
     +,   1.4474753E-06,   1.5947492E-06,   1.7539559E-06
     +,   1.9257141E-06,   2.1106162E-06,   2.3092616E-06
     +,   2.5222180E-06,   2.7500323E-06,   2.9932207E-06
     +,   3.2522594E-06,   3.5275834E-06,   3.8195753E-06
     +,   4.1285593E-06,   4.4547937E-06,   4.7984649E-06
     +,   5.1596803E-06,   5.5384589E-06,   5.9347190E-06
     +,   6.3483089E-06,   6.7789206E-06,   7.2261882E-06
     +,   7.6895976E-06,   8.1685257E-06,   8.6622222E-06
     +,   9.1698175E-06,   9.6903104E-06,   1.0222575E-05
     +,   1.0765361E-05,   1.1317294E-05,   1.1876876E-05
     +,   1.2442495E-05,   1.3012430E-05,   1.3584844E-05
     +,   1.4157848E-05,   1.4729392E-05,   1.5297428E-05
     +,   1.5859800E-05,   1.6414304E-05,   1.6958720E-05
     +,   1.7490782E-05,   1.8008232E-05,   1.8508823E-05
     +,   1.8990297E-05,   1.9450485E-05,   1.9887262E-05
     +,   2.0298550E-05,   2.0682402E-05,   2.1036927E-05
     +,   2.1360405E-05,   2.1651209E-05,   2.1907896E-05
     +,   2.2129148E-05,   2.2313847E-05,   2.2461036E-05
     +,   2.2569962E-05,   2.2640061E-05,   2.2670960E-05
     +,   2.2662505E-05,   2.2614742E-05,   2.2527915E-05
     +,   2.2402473E-05,   2.2239068E-05,   2.2038546E-05
     +,   2.1801923E-05,   2.1530423E-05,   2.1225391E-05
     +,   2.0888381E-05,   2.0521033E-05,   2.0125171E-05
     +,   1.9702698E-05,   1.9255600E-05,   1.8785990E-05
     +,   1.8296043E-05,   1.7787950E-05,   1.7263939E-05
     +,   1.6726302E-05,   1.6177270E-05,   1.5619124E-05
     +,   1.5054045E-05,   1.4484248E-05,   1.3911816E-05
     +,   1.3338835E-05,   1.2767239E-05,   1.2198951E-05
     +,   1.1635728E-05,   1.1079232E-05,   1.0531044E-05
     +,   9.9926210E-06,   9.4652751E-06,   8.9501818E-06
     +,   8.4484500E-06,   7.9609881E-06,   7.4886484E-06
     +,   7.0320939E-06,   6.5919271E-06,   6.1685760E-06
     +,   5.7624084E-06,   5.3736312E-06,   5.0023991E-06
     +,   4.6487312E-06,   4.3125615E-06,   3.9937572E-06
     +,   3.6921115E-06,   3.4073253E-06,   3.1390405E-06
     +,   2.8868692E-06,   2.6503408E-06,   2.4289759E-06
     +,   2.2222305E-06,   2.0295606E-06,   1.8503721E-06
     +,   1.6840821E-06,   1.5300718E-06,   1.3877374E-06
     +,   1.2564597E-06,   1.1356224E-06,   1.0246251E-06
     +,   9.2287547E-07,   8.2978767E-07,   7.4479203E-07
     +,   6.6734236E-07,   5.9691092E-07,   5.3298629E-07
     +,   4.7507990E-07,   4.2273135E-07,   3.7549825E-07
     +,   3.3296266E-07,   2.9473293E-07,   2.6044094E-07
     +,   2.2973940E-07,   2.0230453E-07,   1.7783675E-07
     +,   1.5605741E-07,   1.3670787E-07,   1.1954906E-07
     +,   1.0436248E-07,   9.0947388E-08,   7.9119204E-08
     +,   6.8709575E-08,   5.9566233E-08,   5.1550018E-08
     +,   4.4534989E-08,   3.8407837E-08,   3.3066492E-08
     +,   2.8418988E-08,   2.4383324E-08,   2.0887452E-08
     +,   1.7869557E-08,   1.5280431E-08,   1.3090236E-08
     +,   1.1303433E-08,   9.9901261E-09,   9.3498329E-09
     +,   9.8356630E-09,   1.2385530E-08,   1.8838062E-08
     +,   3.2652729E-08,   6.0107766E-08,   1.1222208E-07
     +,   2.0773140E-07,   3.7752156E-07,   6.7098472E-07
     +,   1.1648589E-06,   1.9751740E-06,   3.2728494E-06
     +,   5.3033909E-06,   8.4113071E-06,   1.3069629E-05
     +,   1.9913516E-05,   2.9775263E-05,   4.3719661E-05
     +,   6.3068655E-05,   8.9403286E-05,   1.2453026E-04
     +,   1.7039588E-04,   2.2892546E-04,   3.0177852E-04
     +,   3.9003798E-04,   4.9386389E-04,   6.1214826E-04
     +,   7.4225327E-04,   8.7993318E-04,   1.0194978E-03
     +,   1.1542226E-03,   1.2769926E-03,   1.3811381E-03
     +,   1.4612336E-03,   1.5137626E-03,   1.5375041E-03
     +,   1.5335381E-03,   1.5048797E-03,   1.4558504E-03
     +,   1.3913239E-03,   1.3160086E-03,   1.2339315E-03
     +,   1.1481901E-03,   1.0609571E-03,   9.7367272E-04
     +,   8.8734168E-04,   8.0280774E-04,   7.2091265E-04
     +,   6.4256071E-04,   5.6867447E-04,   5.0008518E-04
     +,   4.3741806E-04,   3.8102551E-04,   3.3097152E-04
     +,   2.8706019E-04,   2.4890053E-04,   2.1598590E-04
     +,   1.8776381E-04,   1.6367939E-04,   1.4320000E-04
     +,   1.2582631E-04,   1.1109366E-04,   9.8567660E-05
     +,   8.7847322E-05,   7.8570680E-05,   7.0421287E-05
     +,   6.3134874E-05,   5.6504294E-05,   5.0380138E-05
     +,   4.4665670E-05,   3.9308372E-05,   3.4289827E-05
     +,   2.9614561E-05,   2.5299028E-05,   2.1362326E-05
     +,   1.7819830E-05,   1.4679201E-05,   1.1937634E-05
     +,   9.5820806E-06,   7.5904568E-06,   5.9333997E-06
     +,   4.5765137E-06,   3.4828749E-06,   2.6151915E-06
     +,   1.9374377E-06,   1.4161236E-06,   1.0212112E-06
     +,   7.2656275E-07,   5.1000848E-07,   3.5320178E-07
     +,   2.4132592E-07,   1.6267869E-07,   1.0819262E-07
     +,   7.0990296E-08,   4.5955755E-08,   2.9351295E-08
     +,   1.8495022E-08,   1.1497813E-08,   7.0520594E-09
     +,   4.2673975E-09,   2.5477103E-09,   1.5006169E-09
     +,   8.7204260E-10,   4.9996218E-10,   2.8280314E-10
     +,   1.5782048E-10,   8.6894235E-11,   4.7200840E-11
     +,   2.5296274E-11,   1.3375036E-11,   6.9772187E-12
     +,   3.5908793E-12,   1.8233407E-12,   9.1342960E-13
     +,   4.5145227E-13,   2.2014073E-13,   1.0590508E-13
     +,   5.0267147E-14,   2.3538625E-14,   1.0874972E-14
     +,   4.9568381E-15,   2.2291137E-15,   9.8898233E-16
     +,   4.3290814E-16,   1.8695231E-16,   7.9656004E-17
     +,   3.3483745E-17,   1.3886753E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz106 = Yx/0.00795454545454546
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7198735E-21,   3.1024312E-21
     +,   5.5703183E-21,   9.9546663E-21,   1.7706959E-20
     +,   3.1349586E-20,   5.5244640E-20,   9.6898580E-20
     +,   1.6916487E-19,   2.9395342E-19,   5.0841281E-19
     +,   8.7523412E-19,   1.4996935E-18,   2.5577049E-18
     +,   4.3417925E-18,   7.3359654E-18,   1.2337207E-17
     +,   2.0651201E-17,   3.4406743E-17,   5.7057443E-17
     +,   9.4178463E-17,   1.5472503E-16,   2.5300948E-16
     +,   4.1180285E-16,   6.6712040E-16,   1.0757082E-15
     +,   1.7264488E-15,   2.7579367E-15,   4.3851425E-15
     +,   6.9398955E-15,   1.0931844E-14,   1.7139720E-14
     +,   2.6747528E-14,   4.1546471E-14,   6.4232562E-14
     +,   9.8842822E-14,   1.5139325E-13,   2.3079913E-13
     +,   3.5021709E-13,   5.2893969E-13,   7.9514639E-13
     +,   1.1897579E-12,   1.7719026E-12,   2.6265858E-12
     +,   3.8753653E-12,   5.6912049E-12,   8.3189011E-12
     +,   1.2103134E-11,   1.7526685E-11,   2.5262242E-11
     +,   3.6242166E-11,   5.1751922E-11,   7.3554038E-11
     +,   1.0405466E-10,   1.4651479E-10,   2.0534016E-10
     +,   2.8644237E-10,   3.9771317E-10,   5.4963301E-10
     +,   7.5604245E-10,   1.0351164E-09,   1.4106034E-09
     +,   1.9133137E-09,   2.5830778E-09,   3.4710721E-09
     +,   4.6425352E-09,   6.1804593E-09,   8.1894180E-09
     +,   1.0800881E-08,   1.4178534E-08,   1.8525816E-08
     +,   2.4092948E-08,   3.1187199E-08,   4.0181764E-08
     +,   5.1529032E-08,   6.5773143E-08,   8.3563258E-08
     +,   1.0566927E-07,   1.3300016E-07,   1.6662074E-07
     +,   2.0776520E-07,   2.5786343E-07,   3.1854734E-07
     +,   3.9167981E-07,   4.7935299E-07,   5.8391902E-07
     +,   7.0797410E-07,   8.5438705E-07,   1.0262653E-06
     +,   1.2269725E-06,   1.4600995E-06,   1.7294184E-06
     +,   2.0388511E-06,   2.3924410E-06,   2.7942751E-06
     +,   3.2483663E-06,   3.7586599E-06,   4.3288169E-06
     +,   4.9622372E-06,   5.6617923E-06,   6.4298715E-06
     +,   7.2680687E-06,   8.1772550E-06,   9.1572392E-06
     +,   1.0206849E-05,   1.1323757E-05,   1.2504295E-05
     +,   1.3743481E-05,   1.5035036E-05,   1.6371314E-05
     +,   1.7743183E-05,   1.9140387E-05,   2.0551284E-05
     +,   2.1963335E-05,   2.3362905E-05,   2.4735818E-05
     +,   2.6067242E-05,   2.7342277E-05,   2.8545901E-05
     +,   2.9663543E-05,   3.0681236E-05,   3.1585867E-05
     +,   3.2365504E-05,   3.3009746E-05,   3.3509838E-05
     +,   3.3858865E-05,   3.4052006E-05,   3.4086544E-05
     +,   3.3962016E-05,   3.3680153E-05,   3.3244865E-05
     +,   3.2662207E-05,   3.1940097E-05,   3.1088330E-05
     +,   3.0118179E-05,   2.9042209E-05,   2.7874086E-05
     +,   2.6628231E-05,   2.5319448E-05,   2.3962686E-05
     +,   2.2572871E-05,   2.1164547E-05,   1.9751562E-05
     +,   1.8346909E-05,   1.6962727E-05,   1.5609841E-05
     +,   1.4297836E-05,   1.3035031E-05,   1.1828382E-05
     +,   1.0683383E-05,   9.6041913E-06,   8.5937545E-06
     +,   7.6537926E-06,   6.7848559E-06,   5.9865006E-06
     +,   5.2574528E-06,   4.5956795E-06,   3.9984729E-06
     +,   3.4626364E-06,   2.9846376E-06,   2.5606289E-06
     +,   2.1866003E-06,   1.8584986E-06,   1.5722720E-06
     +,   1.3239245E-06,   1.1095999E-06,   9.2563448E-07
     +,   7.6857339E-07,   6.3518661E-07,   5.2249828E-07
     +,   4.2779754E-07,   3.4862995E-07,   2.8278819E-07
     +,   2.2831006E-07,   1.8346874E-07,   1.4674693E-07
     +,   1.1682688E-07,   9.2573529E-08,   7.3013666E-08
     +,   5.7318125E-08,   4.4786407E-08,   3.4831363E-08
     +,   2.6963050E-08,   2.0774934E-08,   1.5932887E-08
     +,   1.2165801E-08,   9.2628056E-09,   7.0952328E-09
     +,   5.7271037E-09,   5.8237970E-09,   9.9874296E-09
     +,   2.6707626E-08,   8.0955544E-08,   2.3984856E-07
     +,   6.6843342E-07,   1.7371010E-06,   4.2008514E-06
     +,   9.4482675E-06,   1.9760480E-05,   3.8426555E-05
     +,   6.9473004E-05,   1.1678234E-04,   1.8260021E-04
     +,   2.6588081E-04,   3.6145715E-04,   4.6128128E-04
     +,   5.5835175E-04,   6.5262691E-04,   7.5643515E-04
     +,   8.9567405E-04,   1.1034826E-03,   1.4056781E-03
     +,   1.8021498E-03,   2.2538987E-03,   2.6870391E-03
     +,   3.0180758E-03,   3.1898255E-03,   3.1954551E-03
     +,   3.0733705E-03,   2.8771977E-03,   2.6441170E-03
     +,   2.3838710E-03,   2.0911342E-03,   1.7654765E-03
     +,   1.4217114E-03,   1.0859640E-03,   7.8460819E-04
     +,   5.3531479E-04,   3.4425512E-04,   2.0811519E-04
     +,   1.1786848E-04,   6.2306615E-05,   3.0627889E-05
     +,   1.3954844E-05,   5.8775886E-06,   2.2833399E-06
     +,   8.1668617E-07,   2.6856475E-07,   8.1109533E-08
     +,   2.2475184E-08,   5.7094098E-09,   1.3288615E-09
     +,   2.8324612E-10,   5.5262867E-11,   9.8650766E-12
     +,   1.6108242E-12,   2.4053519E-13,   3.2836733E-14
     +,   4.0969590E-15,   4.6715614E-16,   4.8675771E-17
     +,   4.6375488E-18,   4.0639926E-19,   3.4159238E-20
     +,   3.5432900E-21,   8.2942688E-22,   3.7970372E-22
     +,   2.0248561E-22,   1.0963010E-22,   5.9200559E-23
     +,   3.1825782E-23,   1.7030087E-23,   9.0703850E-24
     +,   4.8083593E-24,   2.5371449E-24,   1.3324906E-24
     +,   6.9653879E-25,   3.6240731E-25,   1.8768337E-25
     +,   9.6744626E-26,   4.9634675E-26,   2.5346463E-26
     +,   1.2883337E-26,   6.5179085E-27,   3.2820893E-27
     +,   1.6450146E-27,   8.2064058E-28,   4.0748667E-28
     +,   2.0138837E-28,   9.9068566E-29,   4.8506273E-29
     +,   2.3639529E-29,   1.1466793E-29,   5.5363557E-30
     +,   2.6605099E-30,   1.2725884E-30,   6.0587062E-31
     +,   2.8709950E-31,   1.3541459E-31,   6.3570764E-32
     +,   2.9705136E-32,   1.3815384E-32,   6.3955048E-33
     +,   2.9467658E-33,   1.3514559E-33,   6.1689856E-34
     +,   2.8029011E-34,   1.2675373E-34,   5.7055287E-35
     +,   2.5561518E-35,   1.1398897E-35
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz108 = Yx/0.0102083333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   2.4749742E-38
     +,   2.0798608E-37,   1.6979171E-36,   1.3462609E-35
     +,   1.0367699E-34,   7.7551173E-34,   5.6338164E-33
     +,   3.9745442E-32,   2.7230743E-31,   1.8119149E-30
     +,   1.1707432E-29,   7.3463827E-29,   4.4763446E-28
     +,   2.6488150E-27,   1.5219655E-26,   8.4924235E-26
     +,   4.6012605E-25,   2.4209498E-24,   1.2368312E-23
     +,   6.1357734E-23,   2.9558575E-22,   1.3826969E-21
     +,   6.2802121E-21,   2.7697846E-20,   1.1862122E-19
     +,   4.9328342E-19,   1.9917184E-18,   7.8085800E-18
     +,   2.9726721E-17,   1.0987793E-16,   3.9434874E-16
     +,   1.3742638E-15,   4.6500580E-15,   1.5276583E-14
     +,   4.8728969E-14,   1.5092310E-13,   4.5384776E-13
     +,   1.3250541E-12,   3.7561178E-12,   1.0338028E-11
     +,   2.7625582E-11,   7.1671252E-11,   1.8053027E-10
     +,   4.4150586E-10,   1.0482817E-09,   2.4164926E-09
     +,   5.4084106E-09,   1.1752161E-08,   2.4792493E-08
     +,   5.0779562E-08,   1.0098007E-07,   1.9496375E-07
     +,   3.6545933E-07,   6.6513161E-07,   1.1753733E-06
     +,   2.0167217E-06,   3.3598903E-06,   5.4354941E-06
     +,   8.5391721E-06,   1.3027771E-05,   1.9303778E-05
     +,   2.7783002E-05,   3.8844188E-05,   5.2764430E-05
     +,   6.9647635E-05,   8.9354762E-05,   1.1145106E-04
     +,   1.3518863E-04,   1.5953419E-04,   1.8324179E-04
     +,   2.0496760E-04,   2.2341513E-04,   2.3748315E-04
     +,   2.4638802E-04,   2.4974372E-04,   2.4758620E-04
     +,   2.4033616E-04,   2.2871738E-04,   2.1364694E-04
     +,   1.9612088E-04,   1.7712265E-04,   1.5757538E-04
     +,   1.3835274E-04,   1.2036947E-04,   1.0476837E-04
     +,   9.3197741E-05,   8.8137916E-05,   9.3174858E-05
     +,   1.1301805E-04,   1.5296342E-04,   2.1757404E-04
     +,   3.0872086E-04,   4.2388763E-04,   5.5627665E-04
     +,   6.9767388E-04,   8.4291695E-04,   9.9278404E-04
     +,   1.1526375E-03,   1.3272973E-03,   1.5148353E-03
     +,   1.7012109E-03,   1.8576855E-03,   1.9457656E-03
     +,   1.9327044E-03,   1.8098421E-03,   1.5986759E-03
     +,   1.3394979E-03,   1.0738389E-03,   8.3370932E-04
     +,   6.3902384E-04,   4.9746892E-04,   4.0467567E-04
     +,   3.4704330E-04,   3.0786061E-04,   2.7362703E-04
     +,   2.3726714E-04,   1.9766725E-04,   1.5719702E-04
     +,   1.1915221E-04,   8.6133645E-05,   5.9447488E-05
     +,   3.9205126E-05,   2.4712805E-05,   1.4884397E-05
     +,   8.5586462E-06,   4.6929199E-06,   2.4508158E-06
     +,   1.2175590E-06,   5.7477916E-07,   2.5759607E-07
     +,   1.0952258E-07,   4.4154312E-08,   1.6871983E-08
     +,   6.1086745E-09,   2.0953894E-09,   6.8084871E-10
     +,   2.0953385E-10,   6.1075721E-11,   1.6861693E-11
     +,   4.4088522E-12,   1.0917358E-12,   2.5603209E-13
     +,   5.6868992E-14,   1.1962984E-14,   2.3832170E-15
     +,   4.4964426E-16,   8.0348884E-17,   1.3597957E-17
     +,   2.1793376E-18,   3.3081354E-19,   4.7558142E-20
     +,   6.4747106E-21,   8.3482658E-22,   1.0194924E-22
     +,   1.1791087E-23,   1.2914400E-24,   1.3396101E-25
     +,   1.3161117E-26,   1.2245948E-27,   1.0790446E-28
     +,   9.0054393E-30,   7.1172845E-31,   5.3277512E-32
     +,   3.7767285E-33,   2.5357778E-34,   1.6122986E-35
     +,   9.7096074E-37,   5.5373682E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz110 = Yx/0.007
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3221886E-11,   3.0113027E-11
     +,   3.8955558E-11,   5.0274146E-11,   6.4726106E-11
     +,   8.3133146E-11,   1.0651943E-10,   1.3615840E-10
     +,   1.7362781E-10,   2.2087999E-10,   2.8032118E-10
     +,   3.5490949E-10,   4.4827173E-10,   5.6484389E-10
     +,   7.1003275E-10,   8.9041446E-10,   1.1139628E-09
     +,   1.3903159E-09,   1.7310993E-09,   2.1502840E-09
     +,   2.6646243E-09,   3.2941472E-09,   4.0627137E-09
     +,   4.9987374E-09,   6.1357817E-09,   7.5136386E-09
     +,   9.1791215E-09,   1.1187219E-08,   1.3602375E-08
     +,   1.6499811E-08,   1.9967164E-08,   2.4106116E-08
     +,   2.9034378E-08,   3.4887734E-08,   4.1822457E-08
     +,   5.0017633E-08,   5.9678037E-08,   7.1036816E-08
     +,   8.4359620E-08,   9.9945758E-08,   1.1813452E-07
     +,   1.3930682E-07,   1.6388974E-07,   1.9236074E-07
     +,   2.2525133E-07,   2.6315149E-07,   3.0671325E-07
     +,   3.5665607E-07,   4.1376890E-07,   4.7891547E-07
     +,   5.5303633E-07,   6.3715333E-07,   7.3236924E-07
     +,   8.3987845E-07,   9.6095039E-07,   1.0969517E-06
     +,   1.2493299E-06,   1.4196185E-06,   1.6094309E-06
     +,   1.8204590E-06,   2.0544685E-06,   2.3132918E-06
     +,   2.5988015E-06,   2.9129369E-06,   3.2576747E-06
     +,   3.6349804E-06,   4.0468676E-06,   4.4952858E-06
     +,   4.9822143E-06,   5.5095124E-06,   6.0790344E-06
     +,   6.6924654E-06,   7.3514420E-06,   8.0573700E-06
     +,   8.8115466E-06,   9.6150670E-06,   1.0468751E-05
     +,   1.1373157E-05,   1.2328609E-05,   1.3335138E-05
     +,   1.4392338E-05,   1.5499589E-05,   1.6655742E-05
     +,   1.7859418E-05,   1.9108671E-05,   2.0401285E-05
     +,   2.1734471E-05,   2.3105165E-05,   2.4509702E-05
     +,   2.5944133E-05,   2.7404085E-05,   2.8884699E-05
     +,   3.0380728E-05,   3.1886677E-05,   3.3396715E-05
     +,   3.4904569E-05,   3.6403908E-05,   3.7888003E-05
     +,   3.9350143E-05,   4.0783318E-05,   4.2180629E-05
     +,   4.3534990E-05,   4.4839551E-05,   4.6087382E-05
     +,   4.7271849E-05,   4.8386530E-05,   4.9425205E-05
     +,   5.0382019E-05,   5.1251529E-05,   5.2028758E-05
     +,   5.2709122E-05,   5.3288659E-05,   5.3763906E-05
     +,   5.4132048E-05,   5.4390843E-05,   5.4538774E-05
     +,   5.4574906E-05,   5.4499040E-05,   5.4311618E-05
     +,   5.4013763E-05,   5.3607240E-05,   5.3094493E-05
     +,   5.2478565E-05,   5.1763091E-05,   5.0952214E-05
     +,   5.0050698E-05,   4.9063663E-05,   4.7996764E-05
     +,   4.6855901E-05,   4.5647430E-05,   4.4377826E-05
     +,   4.3053915E-05,   4.1682506E-05,   4.0270661E-05
     +,   3.8825361E-05,   3.7353526E-05,   3.5862115E-05
     +,   3.4357941E-05,   3.2847569E-05,   3.1337309E-05
     +,   2.9833349E-05,   2.8341565E-05,   2.6867448E-05
     +,   2.5416159E-05,   2.3992689E-05,   2.2601564E-05
     +,   2.1247053E-05,   1.9933277E-05,   1.8664188E-05
     +,   1.7443614E-05,   1.6275450E-05,   1.5163943E-05
     +,   1.4113790E-05,   1.3130377E-05,   1.2220151E-05
     +,   1.1391067E-05,   1.0652934E-05,   1.0017834E-05
     +,   9.5006762E-06,   9.1197335E-06,   8.8969891E-06
     +,   8.8586285E-06,   9.0352878E-06,   9.4621428E-06
     +,   1.0178831E-05,   1.1229081E-05,   1.2659910E-05
     +,   1.4520539E-05,   1.6861120E-05,   1.9730895E-05
     +,   2.3175891E-05,   2.7236718E-05,   3.1946511E-05
     +,   3.7328457E-05,   4.3393091E-05,   5.0137714E-05
     +,   5.7544821E-05,   6.5581189E-05,   7.4198651E-05
     +,   8.3336017E-05,   9.2920491E-05,   1.0286994E-04
     +,   1.1309673E-04,   1.2351236E-04,   1.3403122E-04
     +,   1.4457421E-04,   1.5507480E-04,   1.6548498E-04
     +,   1.7578063E-04,   1.8596745E-04,   1.9609062E-04
     +,   2.0624205E-04,   2.1656806E-04,   2.2727757E-04
     +,   2.3864770E-04,   2.5102391E-04,   2.6481328E-04
     +,   2.8047024E-04,   2.9847224E-04,   3.1928334E-04
     +,   3.4330593E-04,   3.7082861E-04,   4.0197207E-04
     +,   4.3663671E-04,   4.7445882E-04,   5.1479670E-04
     +,   5.5673224E-04,   5.9910084E-04,   6.4055569E-04
     +,   6.7965651E-04,   7.1496872E-04,   7.4516836E-04
     +,   7.6914689E-04,   7.8609306E-04,   7.9554447E-04
     +,   7.9740671E-04,   7.9193828E-04,   7.7970204E-04
     +,   7.6149130E-04,   7.3824514E-04,   7.1095675E-04
     +,   6.8059162E-04,   6.4802653E-04,   6.1400398E-04
     +,   5.7911046E-04,   5.4378185E-04,   5.0832547E-04
     +,   4.7295014E-04,   4.3780057E-04,   4.0299547E-04
     +,   3.6865927E-04,   3.3494004E-04,   3.0201691E-04
     +,   2.7010156E-04,   2.3943231E-04,   2.1025288E-04
     +,   1.8279804E-04,   1.5727775E-04,   1.3385985E-04
     +,   1.1265765E-04,   9.3725685E-05,   7.7059893E-05
     +,   6.2599531E-05,   5.0233728E-05,   3.9812650E-05
     +,   3.1159008E-05,   2.4078356E-05,   1.8369359E-05
     +,   1.3833514E-05,   1.0282676E-05,   7.5434559E-06
     +,   5.4611273E-06,   3.9013148E-06,   2.7499693E-06
     +,   1.9124789E-06,   1.3121465E-06,   8.8809867E-07
     +,   5.9294251E-07,   3.9048567E-07,   2.5363474E-07
     +,   1.6248241E-07,   1.0265563E-07,   6.3960464E-08
     +,   3.9297642E-08,   2.3809090E-08,   1.4223841E-08
     +,   8.3784739E-09,   4.8660680E-09,   2.7864466E-09
     +,   1.5731189E-09,   8.7556462E-10,   4.8042686E-10
     +,   2.5988200E-10,   1.3858441E-10,   7.2848803E-11
     +,   3.7749248E-11,   1.9281632E-11,   9.7081995E-12
     +,   4.8179702E-12,   2.3568491E-12,   1.1363513E-12
     +,   5.4003183E-13,   2.5294404E-13,   1.1677225E-13
     +,   5.3129891E-14,   2.3825156E-14,   1.0529675E-14
     +,   4.5862472E-15,   1.9687242E-15,   8.3285769E-16
     +,   3.4724698E-16,   1.4268237E-16,   5.7783754E-17
     +,   2.3064573E-17,   9.0755593E-18,   3.5209824E-18
     +,   1.3475156E-18,   5.0909818E-19,   1.9016688E-19
     +,   7.0416852E-20,   2.5976719E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz112 = Yx/0.00665
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3521132E-05,   1.3855456E-05
     +,   1.4194964E-05,   1.4539733E-05,   1.4889841E-05
     +,   1.5245363E-05,   1.5606374E-05,   1.5972946E-05
     +,   1.6345140E-05,   1.6723043E-05,   1.7106695E-05
     +,   1.7496162E-05,   1.7891489E-05,   1.8292705E-05
     +,   1.8699848E-05,   1.9112931E-05,   1.9531961E-05
     +,   1.9956928E-05,   2.0387808E-05,   2.0824567E-05
     +,   2.1267142E-05,   2.1715459E-05,   2.2169415E-05
     +,   2.2628921E-05,   2.3093806E-05,   2.3563925E-05
     +,   2.4039096E-05,   2.4519104E-05,   2.5003712E-05
     +,   2.5492662E-05,   2.5985659E-05,   2.6482394E-05
     +,   2.6982523E-05,   2.7485670E-05,   2.7991437E-05
     +,   2.8499397E-05,   2.9009092E-05,   2.9520046E-05
     +,   3.0031761E-05,   3.0543681E-05,   3.1055268E-05
     +,   3.1565931E-05,   3.2075077E-05,   3.2582069E-05
     +,   3.3086271E-05,   3.3587025E-05,   3.4083649E-05
     +,   3.4575456E-05,   3.5061752E-05,   3.5541823E-05
     +,   3.6014953E-05,   3.6480429E-05,   3.6937519E-05
     +,   3.7385536E-05,   3.7823727E-05,   3.8251423E-05
     +,   3.8667909E-05,   3.9072514E-05,   3.9464565E-05
     +,   3.9843431E-05,   4.0208481E-05,   4.0559127E-05
     +,   4.0894778E-05,   4.1214924E-05,   4.1519063E-05
     +,   4.1806710E-05,   4.2077460E-05,   4.2330899E-05
     +,   4.2566724E-05,   4.2784592E-05,   4.2984295E-05
     +,   4.3165608E-05,   4.3328393E-05,   4.3472541E-05
     +,   4.3598018E-05,   4.3704829E-05,   4.3793025E-05
     +,   4.3862732E-05,   4.3914119E-05,   4.3947399E-05
     +,   4.3962849E-05,   4.3960801E-05,   4.3941622E-05
     +,   4.3905751E-05,   4.3853648E-05,   4.3785851E-05
     +,   4.3702912E-05,   4.3605429E-05,   4.3494056E-05
     +,   4.3369462E-05,   4.3232358E-05,   4.3083477E-05
     +,   4.2923602E-05,   4.2753494E-05,   4.2573964E-05
     +,   4.2385826E-05,   4.2189902E-05,   4.1987030E-05
     +,   4.1778025E-05,   4.1563722E-05,   4.1344931E-05
     +,   4.1122465E-05,   4.0897103E-05,   4.0669613E-05
     +,   4.0440747E-05,   4.0211180E-05,   3.9981613E-05
     +,   3.9752682E-05,   3.9524977E-05,   3.9299044E-05
     +,   3.9075378E-05,   3.8854432E-05,   3.8636601E-05
     +,   3.8422208E-05,   3.8211543E-05,   3.8004804E-05
     +,   3.7802161E-05,   3.7603673E-05,   3.7409394E-05
     +,   3.7219259E-05,   3.7033151E-05,   3.6850921E-05
     +,   3.6672322E-05,   3.6497047E-05,   3.6324749E-05
     +,   3.6155005E-05,   3.5987337E-05,   3.5821238E-05
     +,   3.5656129E-05,   3.5491375E-05,   3.5326331E-05
     +,   3.5160308E-05,   3.4992565E-05,   3.4822362E-05
     +,   3.4648925E-05,   3.4471457E-05,   3.4289173E-05
     +,   3.4101267E-05,   3.3906952E-05,   3.3705430E-05
     +,   3.3495940E-05,   3.3277753E-05,   3.3050139E-05
     +,   3.2812426E-05,   3.2564014E-05,   3.2304328E-05
     +,   3.2032880E-05,   3.1749263E-05,   3.1453186E-05
     +,   3.1144449E-05,   3.0822990E-05,   3.0488929E-05
     +,   3.0142572E-05,   2.9784442E-05,   2.9415314E-05
     +,   2.9036297E-05,   2.8648887E-05,   2.8254954E-05
     +,   2.7856891E-05,   2.7457687E-05,   2.7060953E-05
     +,   2.6671054E-05,   2.6293192E-05,   2.5933519E-05
     +,   2.5599173E-05,   2.5298390E-05,   2.5040596E-05
     +,   2.4836427E-05,   2.4697769E-05,   2.4637759E-05
     +,   2.4670768E-05,   2.4812329E-05,   2.5079024E-05
     +,   2.5488365E-05,   2.6058575E-05,   2.6808420E-05
     +,   2.7757018E-05,   2.8923523E-05,   3.0326915E-05
     +,   3.1986023E-05,   3.3919379E-05,   3.6145128E-05
     +,   3.8681388E-05,   4.1546911E-05,   4.4761728E-05
     +,   4.8347985E-05,   5.2331583E-05,   5.6744371E-05
     +,   6.1626175E-05,   6.7027031E-05,   7.3011055E-05
     +,   7.9659389E-05,   8.7072971E-05,   9.5376090E-05
     +,   1.0471968E-04,   1.1528313E-04,   1.2727431E-04
     +,   1.4092952E-04,   1.5651197E-04,   1.7430670E-04
     +,   1.9461171E-04,   2.1772854E-04,   2.4395145E-04
     +,   2.7355037E-04,   3.0674989E-04,   3.4371504E-04
     +,   3.8452857E-04,   4.2916738E-04,   4.7748565E-04
     +,   5.2920188E-04,   5.8388483E-04,   6.4094277E-04
     +,   6.9962785E-04,   7.5904821E-04,   8.1818044E-04
     +,   8.7589171E-04,   9.3097519E-04,   9.8219351E-04
     +,   1.0283195E-03,   1.0681780E-03,   1.1007042E-03
     +,   1.1249827E-03,   1.1402869E-03,   1.1461169E-03
     +,   1.1422207E-03,   1.1286077E-03,   1.1055490E-03
     +,   1.0735699E-03,   1.0334224E-03,   9.8605582E-04
     +,   9.3257945E-04,   8.7421556E-04,   8.1224635E-04
     +,   7.4796751E-04,   6.8265013E-04,   6.1748561E-04
     +,   5.5355672E-04,   4.9181486E-04,   4.3305656E-04
     +,   3.7790931E-04,   3.2683418E-04,   2.8013409E-04
     +,   2.3796108E-04,   2.0033011E-04,   1.6714211E-04
     +,   1.3820677E-04,   1.1326141E-04,   9.1990732E-05
     +,   7.4048403E-05,   5.9075439E-05,   4.6710968E-05
     +,   3.6606023E-05,   2.8432605E-05,   2.1888747E-05
     +,   1.6702013E-05,   1.2631785E-05,   9.4694005E-06
     +,   7.0365354E-06,   5.1830521E-06,   3.7845828E-06
     +,   2.7395968E-06,   1.9662125E-06,   1.3992327E-06
     +,   9.8746239E-07,   6.9121478E-07,   4.8003329E-07
     +,   3.3085487E-07,   2.2642043E-07,   1.5395030E-07
     +,   1.0408549E-07,   7.0052920E-08,   4.7004868E-08
     +,   3.1506193E-08,   2.1148091E-08,   1.4260044E-08
     +,   9.6955945E-09,   6.6747172E-09,   4.6727062E-09
     +,   3.3393037E-09,   2.4431439E-09,   1.8323865E-09
     +,   1.4082682E-09,   1.1068203E-09,   8.8685470E-10
     +,   7.2184309E-10,   5.9470934E-10,   4.9436727E-10
     +,   4.1354692E-10,   3.4740008E-10,   2.9260125E-10
     +,   2.4681279E-10,   2.0832583E-10,   1.7585618E-10
     +,   1.4840008E-10,   1.2515904E-10,   1.0547730E-10
     +,   8.8813658E-11,   7.4711223E-11,   6.2786068E-11
     +,   5.2710114E-11,   4.4205611E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz113 = Yx/0.0091304347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1966546E-09,   4.9989208E-09
     +,   5.9439960E-09,   7.0551907E-09,   8.3592600E-09
     +,   9.8867883E-09,   1.1672693E-08,   1.3756738E-08
     +,   1.6184053E-08,   1.9005919E-08,   2.2280190E-08
     +,   2.6072179E-08,   3.0455396E-08,   3.5512389E-08
     +,   4.1335586E-08,   4.8028213E-08,   5.5705414E-08
     +,   6.4495168E-08,   7.4539308E-08,   8.5994749E-08
     +,   9.9034587E-08,   1.1384937E-07,   1.3064771E-07
     +,   1.4965917E-07,   1.7113209E-07,   1.9533913E-07
     +,   2.2257454E-07,   2.5315720E-07,   2.8743085E-07
     +,   3.2576551E-07,   3.6855744E-07,   4.1623048E-07
     +,   4.6923606E-07,   5.2805240E-07,   5.9318648E-07
     +,   6.6517219E-07,   7.4456972E-07,   8.3196369E-07
     +,   9.2796910E-07,   1.0332121E-06,   1.1483513E-06
     +,   1.2740563E-06,   1.4110134E-06,   1.5599188E-06
     +,   1.7214778E-06,   1.8963970E-06,   2.0853818E-06
     +,   2.2891304E-06,   2.5083257E-06,   2.7436326E-06
     +,   2.9956866E-06,   3.2650908E-06,   3.5524031E-06
     +,   3.8581470E-06,   4.1827575E-06,   4.5266374E-06
     +,   4.8900952E-06,   5.2733585E-06,   5.6765684E-06
     +,   6.0997627E-06,   6.5428721E-06,   7.0057235E-06
     +,   7.4879877E-06,   7.9892452E-06,   8.5089468E-06
     +,   9.0463518E-06,   9.6006479E-06,   1.0170804E-05
     +,   1.0755716E-05,   1.1354059E-05,   1.1964434E-05
     +,   1.2585224E-05,   1.3214752E-05,   1.3851120E-05
     +,   1.4492365E-05,   1.5136408E-05,   1.5781012E-05
     +,   1.6423844E-05,   1.7062526E-05,   1.7694605E-05
     +,   1.8317509E-05,   1.8928706E-05,   1.9525562E-05
     +,   2.0105508E-05,   2.0665919E-05,   2.1204265E-05
     +,   2.1718006E-05,   2.2204727E-05,   2.2662047E-05
     +,   2.3087741E-05,   2.3479695E-05,   2.3835921E-05
     +,   2.4154597E-05,   2.4434090E-05,   2.4672954E-05
     +,   2.4869931E-05,   2.5023994E-05,   2.5134314E-05
     +,   2.5200317E-05,   2.5221652E-05,   2.5198200E-05
     +,   2.5130092E-05,   2.5017684E-05,   2.4861576E-05
     +,   2.4662597E-05,   2.4421779E-05,   2.4140389E-05
     +,   2.3819901E-05,   2.3461953E-05,   2.3068356E-05
     +,   2.2641121E-05,   2.2182343E-05,   2.1694304E-05
     +,   2.1179330E-05,   2.0639898E-05,   2.0078489E-05
     +,   1.9497702E-05,   1.8900093E-05,   1.8288301E-05
     +,   1.7664908E-05,   1.7032458E-05,   1.6393504E-05
     +,   1.5750536E-05,   1.5105928E-05,   1.4461968E-05
     +,   1.3820904E-05,   1.3184799E-05,   1.2555663E-05
     +,   1.1935307E-05,   1.1325486E-05,   1.0727729E-05
     +,   1.0143505E-05,   9.5740570E-06,   9.0205558E-06
     +,   8.4839694E-06,   7.9651254E-06,   7.4647378E-06
     +,   6.9833841E-06,   6.5214758E-06,   6.0792963E-06
     +,   5.6570402E-06,   5.2547821E-06,   4.8724655E-06
     +,   4.5099346E-06,   4.1669791E-06,   3.8432704E-06
     +,   3.5384076E-06,   3.2519458E-06,   2.9833786E-06
     +,   2.7321350E-06,   2.4976011E-06,   2.2791476E-06
     +,   2.0761167E-06,   1.8878154E-06,   1.7135407E-06
     +,   1.5525936E-06,   1.4042721E-06,   1.2678652E-06
     +,   1.1426731E-06,   1.0280185E-06,   9.2322665E-07
     +,   8.2764251E-07,   7.4063763E-07,   6.6160493E-07
     +,   5.8995698E-07,   5.2513235E-07,   4.6660097E-07
     +,   4.1385940E-07,   3.6642791E-07,   3.2385540E-07
     +,   2.8572128E-07,   2.5163146E-07,   2.2121696E-07
     +,   1.9413504E-07,   1.7007288E-07,   1.4874136E-07
     +,   1.2988130E-07,   1.1326832E-07,   9.8722175E-08
     +,   8.6124722E-08,   7.5456271E-08,   6.6857915E-08
     +,   6.0733925E-08,   5.7920694E-08,   5.9954232E-08
     +,   6.9475611E-08,   9.0824614E-08,   1.3088098E-07
     +,   2.0020181E-07,   3.1447786E-07,   4.9633695E-07
     +,   7.7740265E-07,   1.2004357E-06,   1.8213552E-06
     +,   2.7108233E-06,   3.9548827E-06,   5.6541840E-06
     +,   7.9217298E-06,   1.0879216E-05,   1.4652111E-05
     +,   1.9364426E-05,   2.5135763E-05,   3.2082946E-05
     +,   4.0328112E-05,   5.0015769E-05,   6.1344275E-05
     +,   7.4607226E-05,   9.0244575E-05,   1.0889991E-04
     +,   1.3147471E-04,   1.5916354E-04,   1.9345534E-04
     +,   2.3608720E-04,   2.8893497E-04,   3.5382263E-04
     +,   4.3225073E-04,   5.2506820E-04,   6.3212047E-04
     +,   7.5190875E-04,   8.8132842E-04,   1.0156063E-03
     +,   1.1484239E-03,   1.2722976E-03,   1.3792209E-03
     +,   1.4614866E-03,   1.5125646E-03,   1.5279230E-03
     +,   1.5056545E-03,   1.4467671E-03,   1.3550951E-03
     +,   1.2368540E-03,   1.0998923E-03,   9.5276802E-04
     +,   8.0383464E-04,   6.6046033E-04,   5.2843173E-04
     +,   4.1168230E-04,   3.1228384E-04,   2.3064323E-04
     +,   1.6585246E-04,   1.1611303E-04,   7.9144018E-05
     +,   5.2521365E-05,   3.3933426E-05,   2.1344438E-05
     +,   1.3071067E-05,   7.7931309E-06,   4.5235292E-06
     +,   2.5561976E-06,   1.4062854E-06,   7.5318070E-07
     +,   3.9269304E-07,   1.9931213E-07,   9.8477805E-08
     +,   4.7363532E-08,   2.2173008E-08,   1.0103539E-08
     +,   4.4810959E-09,   1.9343123E-09,   8.1258400E-10
     +,   3.3220066E-10,   1.3216470E-10,   5.1165756E-11
     +,   1.9273447E-11,   7.0642736E-12,   2.5193138E-12
     +,   8.7417996E-13,   2.9518635E-13,   9.7041624E-14
     +,   3.1090307E-14,   9.7329261E-15,   2.9975569E-15
     +,   9.2366285E-16,   2.9600180E-16,   1.0615271E-16
     +,   4.6458113E-17,   2.5392221E-17,   1.6246297E-17
     +,   1.1241811E-17,   8.0240680E-18,   5.7864692E-18
     +,   4.1829419E-18,   3.0225953E-18,   2.1812594E-18
     +,   1.5715209E-18,   1.1302769E-18,   8.1149148E-19
     +,   5.8157983E-19,   4.1607087E-19,   2.9713188E-19
     +,   2.1181900E-19,   1.5073140E-19,   1.0707228E-19
     +,   7.5923012E-20,   5.3740629E-20,   3.7971406E-20
     +,   2.6781935E-20,   1.8856099E-20,   1.3252457E-20
     +,   9.2974519E-21,   6.5112507E-21
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz114 = Yx/0.0063
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6177479E-08,   1.8994402E-08
     +,   2.2263036E-08,   2.6048793E-08,   3.0425316E-08
     +,   3.5475448E-08,   4.1292083E-08,   4.7979082E-08
     +,   5.5652304E-08,   6.4441117E-08,   7.4488860E-08
     +,   8.5954476E-08,   9.9013675E-08,   1.1386033E-07
     +,   1.3070753E-07,   1.4978930E-07,   1.7136146E-07
     +,   1.9570376E-07,   2.2312044E-07,   2.5394206E-07
     +,   2.8852639E-07,   3.2726018E-07,   3.7055932E-07
     +,   4.1887324E-07,   4.7267784E-07,   5.3248738E-07
     +,   5.9884570E-07,   6.7233071E-07,   7.5355462E-07
     +,   8.4316230E-07,   9.4183179E-07,   1.0502739E-06
     +,   1.1692300E-06,   1.2994710E-06,   1.4417960E-06
     +,   1.5970294E-06,   1.7660174E-06,   1.9496240E-06
     +,   2.1487394E-06,   2.3642449E-06,   2.5970505E-06
     +,   2.8480531E-06,   3.1181526E-06,   3.4082341E-06
     +,   3.7191680E-06,   4.0518007E-06,   4.4069470E-06
     +,   4.7853819E-06,   5.1878333E-06,   5.6149743E-06
     +,   6.0674101E-06,   6.5456779E-06,   7.0502197E-06
     +,   7.5814246E-06,   8.1395183E-06,   8.7246826E-06
     +,   9.3369490E-06,   9.9762274E-06,   1.0642304E-05
     +,   1.1334822E-05,   1.2053284E-05,   1.2797048E-05
     +,   1.3565276E-05,   1.4357030E-05,   1.5171214E-05
     +,   1.6006488E-05,   1.6861462E-05,   1.7734466E-05
     +,   1.8623787E-05,   1.9527444E-05,   2.0443416E-05
     +,   2.1369411E-05,   2.2303135E-05,   2.3242023E-05
     +,   2.4183490E-05,   2.5124842E-05,   2.6063221E-05
     +,   2.6995689E-05,   2.7919292E-05,   2.8831028E-05
     +,   2.9727757E-05,   3.0606443E-05,   3.1463922E-05
     +,   3.2297154E-05,   3.3103024E-05,   3.3878576E-05
     +,   3.4620800E-05,   3.5326888E-05,   3.5994028E-05
     +,   3.6619607E-05,   3.7201131E-05,   3.7736230E-05
     +,   3.8222708E-05,   3.8658571E-05,   3.9042025E-05
     +,   3.9371454E-05,   3.9645489E-05,   3.9862956E-05
     +,   4.0022951E-05,   4.0124789E-05,   4.0168045E-05
     +,   4.0152521E-05,   4.0078288E-05,   3.9945673E-05
     +,   3.9755236E-05,   3.9507766E-05,   3.9204315E-05
     +,   3.8846178E-05,   3.8434842E-05,   3.7972000E-05
     +,   3.7459595E-05,   3.6899695E-05,   3.6294612E-05
     +,   3.5646746E-05,   3.4958714E-05,   3.4233180E-05
     +,   3.3473003E-05,   3.2681059E-05,   3.1860378E-05
     +,   3.1013969E-05,   3.0144893E-05,   2.9256276E-05
     +,   2.8351255E-05,   2.7432885E-05,   2.6504196E-05
     +,   2.5568253E-05,   2.4627947E-05,   2.3686202E-05
     +,   2.2745733E-05,   2.1809272E-05,   2.0879308E-05
     +,   1.9958336E-05,   1.9048584E-05,   1.8152263E-05
     +,   1.7271341E-05,   1.6407632E-05,   1.5562857E-05
     +,   1.4738564E-05,   1.3936086E-05,   1.3156600E-05
     +,   1.2401168E-05,   1.1670694E-05,   1.0965872E-05
     +,   1.0287254E-05,   9.6353024E-06,   9.0102794E-06
     +,   8.4123121E-06,   7.8414396E-06,   7.2975813E-06
     +,   6.7805036E-06,   6.2898753E-06,   5.8253027E-06
     +,   5.3863055E-06,   4.9722939E-06,   4.5826127E-06
     +,   4.2165780E-06,   3.8734502E-06,   3.5524301E-06
     +,   3.2526898E-06,   2.9734144E-06,   2.7137546E-06
     +,   2.4728770E-06,   2.2499962E-06,   2.0443856E-06
     +,   1.8554039E-06,   1.6825592E-06,   1.5255871E-06
     +,   1.3845319E-06,   1.2598555E-06,   1.1526118E-06
     +,   1.0646517E-06,   9.9886245E-07,   9.5946473E-07
     +,   9.5237266E-07,   9.8557643E-07,   1.0695569E-06
     +,   1.2176984E-06,   1.4466394E-06,   1.7765316E-06
     +,   2.2311669E-06,   2.8378399E-06,   3.6268591E-06
     +,   4.6307259E-06,   5.8829746E-06,   7.4164614E-06
     +,   9.2611735E-06,   1.1441887E-05,   1.3975865E-05
     +,   1.6870434E-05,   2.0120842E-05,   2.3709970E-05
     +,   2.7608750E-05,   3.1778480E-05,   3.6176232E-05
     +,   4.0763261E-05,   4.5516168E-05,   5.0441013E-05
     +,   5.5590965E-05,   6.1085782E-05,   6.7131034E-05
     +,   7.4035444E-05,   8.2224564E-05,   9.2247334E-05
     +,   1.0477228E-04,   1.2057016E-04,   1.4048826E-04
     +,   1.6541073E-04,   1.9621004E-04,   2.3369913E-04
     +,   2.7859092E-04,   3.3146347E-04,   3.9273468E-04
     +,   4.6265489E-04,   5.4130441E-04,   6.2857301E-04
     +,   7.2411186E-04,   8.2726183E-04,   9.3694584E-04
     +,   1.0515230E-03,   1.1686339E-03,   1.2851199E-03
     +,   1.3969899E-03,   1.4995160E-03,   1.5874857E-03
     +,   1.6556013E-03,   1.6989660E-03,   1.7136309E-03
     +,   1.6971090E-03,   1.6487660E-03,   1.5700090E-03
     +,   1.4642595E-03,   1.3366678E-03,   1.1936238E-03
     +,   1.0421431E-03,   8.8922662E-04,   7.4122462E-04
     +,   6.0337118E-04,   4.7949547E-04,   3.7190688E-04
     +,   2.8146512E-04,   2.0780531E-04,   1.4964101E-04
     +,   1.0508417E-04,   7.1952563E-05,   4.8030077E-05
     +,   3.1253010E-05,   1.9821804E-05,   1.2252402E-05
     +,   7.3804595E-06,   4.3322457E-06,   2.4778553E-06
     +,   1.3808276E-06,   7.4970461E-07,   3.9656854E-07
     +,   2.0436133E-07,   1.0259021E-07,   5.0169032E-08
     +,   2.3899343E-08,   1.1090084E-08,   5.0125704E-09
     +,   2.2068019E-09,   9.4633967E-10,   3.9526912E-10
     +,   1.6079946E-10,   6.3716289E-11,   2.4592177E-11
     +,   9.2461473E-12,   3.3875084E-12,   1.2102184E-12
     +,   4.2226170E-13,   1.4441852E-13,   4.8835969E-14
     +,   1.6649744E-14,   5.9575160E-15,   2.3898668E-15
     +,   1.1471844E-15,   6.6381681E-16,   4.3808089E-16
     +,   3.0952424E-16,   2.2511534E-16,   1.6543988E-16
     +,   1.2192712E-16,   8.9847147E-17,   6.6129411E-17
     +,   4.8595574E-17,   3.5650075E-17,   2.6107312E-17
     +,   1.9085006E-17,   1.3926980E-17,   1.0144850E-17
     +,   7.3768000E-18,   5.3544609E-18,   3.8796826E-18
     +,   2.8060872E-18,   2.0260048E-18,   1.4601723E-18
     +,   1.0505108E-18,   7.5443396E-19,   5.4084827E-19
     +,   3.8703833E-19,   2.7648142E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz115 = Yx/0.00852173913043478
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.2638842E-08,   4.8954814E-08
     +,   5.6120463E-08,   6.4236673E-08,   7.3414306E-08
     +,   8.3774900E-08,   9.5451654E-08,   1.0858967E-07
     +,   1.2334699E-07,   1.3989607E-07,   1.5842296E-07
     +,   1.7912939E-07,   2.0223263E-07,   2.2796672E-07
     +,   2.5658292E-07,   2.8834984E-07,   3.2355442E-07
     +,   3.6250276E-07,   4.0551870E-07,   4.5294576E-07
     +,   5.0514660E-07,   5.6250298E-07,   6.2541289E-07
     +,   6.9429916E-07,   7.6959202E-07,   8.5174810E-07
     +,   9.4123413E-07,   1.0385321E-06,   1.1441372E-06
     +,   1.2585548E-06,   1.3822992E-06,   1.5158903E-06
     +,   1.6598520E-06,   1.8147082E-06,   1.9809797E-06
     +,   2.1591820E-06,   2.3498185E-06,   2.5533741E-06
     +,   2.7703320E-06,   3.0011236E-06,   3.2461778E-06
     +,   3.5058765E-06,   3.7805657E-06,   4.0705472E-06
     +,   4.3760742E-06,   4.6973446E-06,   5.0344961E-06
     +,   5.3876015E-06,   5.7566635E-06,   6.1416063E-06
     +,   6.5422778E-06,   6.9584403E-06,   7.3897577E-06
     +,   7.8358325E-06,   8.2961242E-06,   8.7700391E-06
     +,   9.2568598E-06,   9.7557740E-06,   1.0265867E-05
     +,   1.0786123E-05,   1.1315428E-05,   1.1852577E-05
     +,   1.2396235E-05,   1.2945018E-05,   1.3497458E-05
     +,   1.4051950E-05,   1.4606885E-05,   1.5160515E-05
     +,   1.5711101E-05,   1.6256789E-05,   1.6795739E-05
     +,   1.7326027E-05,   1.7845759E-05,   1.8352977E-05
     +,   1.8845776E-05,   1.9322249E-05,   1.9780495E-05
     +,   2.0218649E-05,   2.0634932E-05,   2.1027618E-05
     +,   2.1395021E-05,   2.1735588E-05,   2.2047829E-05
     +,   2.2330385E-05,   2.2581995E-05,   2.2801552E-05
     +,   2.2988059E-05,   2.3140679E-05,   2.3258712E-05
     +,   2.3341625E-05,   2.3389042E-05,   2.3400742E-05
     +,   2.3376671E-05,   2.3316943E-05,   2.3221823E-05
     +,   2.3091758E-05,   2.2927326E-05,   2.2729286E-05
     +,   2.2498518E-05,   2.2236070E-05,   2.1943091E-05
     +,   2.1620897E-05,   2.1270867E-05,   2.0894540E-05
     +,   2.0493506E-05,   2.0069443E-05,   1.9624122E-05
     +,   1.9159372E-05,   1.8677047E-05,   1.8179029E-05
     +,   1.7667264E-05,   1.7143657E-05,   1.6610164E-05
     +,   1.6068660E-05,   1.5521078E-05,   1.4969227E-05
     +,   1.4414953E-05,   1.3859975E-05,   1.3306016E-05
     +,   1.2754679E-05,   1.2207488E-05,   1.1665918E-05
     +,   1.1131354E-05,   1.0605057E-05,   1.0088186E-05
     +,   9.5818596E-06,   9.0870235E-06,   8.6045875E-06
     +,   8.1353010E-06,   7.6798697E-06,   7.2388416E-06
     +,   6.8127283E-06,   6.4018873E-06,   6.0066441E-06
     +,   5.6271924E-06,   5.2636474E-06,   4.9160694E-06
     +,   4.5844458E-06,   4.2686711E-06,   3.9685806E-06
     +,   3.6839763E-06,   3.4146046E-06,   3.1601551E-06
     +,   2.9202815E-06,   2.6946354E-06,   2.4828250E-06
     +,   2.2844558E-06,   2.0991458E-06,   1.9265351E-06
     +,   1.7662840E-06,   1.6181093E-06,   1.4818165E-06
     +,   1.3573185E-06,   1.2446599E-06,   1.1440721E-06
     +,   1.0560251E-06,   9.8127578E-07,   9.2093183E-07
     +,   8.7653160E-07,   8.5012891E-07,   8.4437352E-07
     +,   8.6261338E-07,   9.0898567E-07,   9.8850853E-07
     +,   1.1071687E-06,   1.2719946E-06,   1.4910859E-06
     +,   1.7736252E-06,   2.1298695E-06,   2.5710578E-06
     +,   3.1092263E-06,   3.7569991E-06,   4.5273418E-06
     +,   5.4331481E-06,   6.4866776E-06,   7.6991892E-06
     +,   9.0802705E-06,   1.0637074E-05,   1.2373717E-05
     +,   1.4290723E-05,   1.6384316E-05,   1.8645713E-05
     +,   2.1060794E-05,   2.3609995E-05,   2.6268102E-05
     +,   2.9004183E-05,   3.1782176E-05,   3.4561741E-05
     +,   3.7299062E-05,   3.9947827E-05,   4.2461394E-05
     +,   4.4794378E-05,   4.6904854E-05,   4.8757185E-05
     +,   5.0325354E-05,   5.1596540E-05,   5.2575506E-05
     +,   5.3289936E-05,   5.3796608E-05,   5.4188335E-05
     +,   5.4601867E-05,   5.5226559E-05,   5.6313333E-05
     +,   5.8183930E-05,   6.1238890E-05,   6.5965287E-05
     +,   7.2941824E-05,   8.2840554E-05,   9.6424636E-05
     +,   1.1454194E-04,   1.3810913E-04,   1.6808430E-04
     +,   2.0542777E-04,   2.5104912E-04,   3.0573024E-04
     +,   3.7002430E-04,   4.4414270E-04,   5.2783301E-04
     +,   6.2024768E-04,   7.1982323E-04,   8.2422752E-04
     +,   9.3034218E-04,   1.0343317E-03,   1.1318208E-03
     +,   1.2181689E-03,   1.2888069E-03,   1.3396274E-03
     +,   1.3673847E-03,   1.3700371E-03,   1.3469787E-03
     +,   1.2991427E-03,   1.2289395E-03,   1.1400358E-03
     +,   1.0370120E-03,   9.2495442E-04,   8.0899289E-04
     +,   6.9390086E-04,   5.8377790E-04,   4.8182314E-04
     +,   3.9023417E-04,   3.1023027E-04,   2.4216279E-04
     +,   1.8567246E-04,   1.3987880E-04,   1.0357684E-04
     +,   7.5408214E-05,   5.3993386E-05,   3.8028949E-05
     +,   2.6350757E-05,   1.7964283E-05,   1.2048814E-05
     +,   7.9494384E-06,   5.1582474E-06,   3.2909888E-06
     +,   2.0637390E-06,   1.2714872E-06,   7.6934816E-07
     +,   4.5699002E-07,   2.6635868E-07,   1.5226843E-07
     +,   8.5342457E-08,   4.6878654E-08,   2.5227651E-08
     +,   1.3295995E-08,   6.8611836E-09,   3.4656900E-09
     +,   1.7131075E-09,   8.2852869E-10,   3.9200876E-10
     +,   1.8141696E-10,   8.2109215E-11,   3.6342093E-11
     +,   1.5729586E-11,   6.6571709E-12,   2.7549816E-12
     +,   1.1149529E-12,   4.4130769E-13,   1.7088949E-13
     +,   6.4767642E-14,   2.4046827E-14,   8.7583639E-15
     +,   3.1377978E-15,   1.1110130E-15,   3.9226366E-16
     +,   1.4032713E-16,   5.2271938E-17,   2.1089757E-17
     +,   9.6015205E-18,   5.0274222E-18,   2.9785818E-18
     +,   1.9253504E-18,   1.3121108E-18,   9.2130467E-19
     +,   6.5765739E-19,   4.7376909E-19,   3.4300016E-19
     +,   2.4896922E-19,   1.8091325E-19,   1.3148416E-19
     +,   9.5519056E-20,   6.9335546E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz116 = Yx/0.00665
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz1168(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   4.2207104E-38,   2.2918133E-37,   1.2210660E-36
     +,   6.3839352E-36,   3.2753193E-35,   1.6489401E-34
     +,   8.1456487E-34,   3.9485333E-33,   1.8782720E-32
     +,   8.7669615E-32,   4.0155856E-31,   1.8047551E-30
     +,   7.9597338E-30,   3.4446756E-29,   1.4628752E-28
     +,   6.0958952E-28,   2.4927402E-27,   1.0001940E-26
     +,   3.9380775E-26,   1.5215697E-25,   5.7688673E-25
     +,   2.1461513E-24,   7.8346502E-24,   2.8066380E-23
     +,   9.8656201E-23,   3.4030631E-22,   1.1518301E-21
     +,   3.8257313E-21,   1.2468476E-20,   3.9876610E-20
     +,   1.2513992E-19,   3.8537295E-19,   1.1644976E-18
     +,   3.4529246E-18,   1.0047083E-17,   2.8686928E-17
     +,   8.0371469E-17,   2.2095864E-16,   5.9610653E-16
     +,   1.5780704E-15,   4.0992689E-15,   1.0449042E-14
     +,   2.6136650E-14,   6.4150820E-14,   1.5450598E-13
     +,   3.6516731E-13,   8.4689780E-13,   1.9273062E-12
     +,   4.3039214E-12,   9.4315632E-12,   2.0281396E-11
     +,   4.2795587E-11,   8.8613464E-11,   1.8005784E-10
     +,   3.5902847E-10,   7.0249634E-10,   1.3488770E-09
     +,   2.5417213E-09,   4.7000173E-09,   8.5291099E-09
     +,   1.5190029E-08,   2.6550177E-08,   4.5544496E-08
     +,   7.6681168E-08,   1.2672207E-07,   2.0556176E-07
     +,   3.2732459E-07,   5.1168132E-07,   7.8532094E-07
     +,   1.1834678E-06,   1.7513363E-06,   2.5453403E-06
     +,   3.6337169E-06,   5.0961489E-06,   7.0226074E-06
     +,   9.5105370E-06,   1.2660312E-05,   1.6569338E-05
     +,   2.1324977E-05,   2.6995847E-05,   3.3622291E-05
     +,   4.1207510E-05,   4.9710030E-05,   5.9037193E-05
     +,   6.9041052E-05,   7.9519537E-05,   9.0222791E-05
     +,   1.0086405E-04,   1.1113664E-04,   1.2074091E-04
     +,   1.2941388E-04,   1.3696350E-04,   1.4330422E-04
     +,   1.4848677E-04,   1.5271436E-04,   1.5633927E-04
     +,   1.5983316E-04,   1.6372725E-04,   1.6852528E-04
     +,   1.7459854E-04,   1.8208120E-04,   1.9078772E-04
     +,   2.0017357E-04,   2.0935772E-04,   2.1721701E-04
     +,   2.2254145E-04,   2.2423823E-04,   2.2157111E-04
     +,   2.1443564E-04,   2.0371121E-04,   1.9176169E-04
     +,   1.8313025E-04,   1.8531545E-04,   2.0911371E-04
     +,   2.6739435E-04,   3.7087846E-04,   5.2065687E-04
     +,   7.0058327E-04,   8.7666104E-04,   1.0100539E-03
     +,   1.0814128E-03,   1.1127946E-03,   1.1700116E-03
     +,   1.3372026E-03,   1.6699490E-03,   2.1468007E-03
     +,   2.6492060E-03,   2.9961334E-03,   3.0299048E-03
     +,   2.7055983E-03,   2.1190115E-03,   1.4496072E-03
     +,   8.6350285E-04,   4.4659077E-04,   1.9988697E-04
     +,   7.7148296E-05,   2.5581043E-05,   7.2606899E-06
     +,   1.7579802E-06,   3.6200387E-07,   6.3243888E-08
     +,   9.3562011E-09,   1.1703261E-09,   1.2369146E-10
     +,   1.1065635E-11,   8.4787131E-13,   5.9038379E-14
     +,   4.7601464E-15,   6.7532206E-16,   1.5266273E-16
     +,   3.8672060E-17,   9.7359944E-18,   2.3876599E-18
     +,   5.6924099E-19,   1.3201198E-19,   2.9817308E-20
     +,   6.5701381E-21,   1.4151091E-21,   2.9867463E-22
     +,   6.1967025E-23,   1.2684297E-23,   2.5716816E-24
     +,   5.1849643E-25,   1.0434937E-25,   2.1020040E-26
     +,   4.2442250E-27,   8.5902321E-28,   1.7405367E-28
     +,   3.5220823E-29,   7.0976229E-30,   1.4204314E-30
     +,   2.8160676E-31,   5.5189748E-32,   1.0674548E-32
     +,   2.0355562E-33,   3.8236866E-34,   7.0731567E-35
     +,   1.2880294E-35,   2.3091036E-36,   4.0745248E-37
     +,   7.0763308E-38,   1.2109500E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz1168 = Yx/0.00795454545454546
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3029142E-07,   2.5613323E-07
     +,   2.8450813E-07,   3.1561967E-07,   3.4968269E-07
     +,   3.8692338E-07,   4.2757932E-07,   4.7189900E-07
     +,   5.2014150E-07,   5.7257932E-07,   6.2949289E-07
     +,   6.9117317E-07,   7.5792127E-07,   8.3004653E-07
     +,   9.0786631E-07,   9.9170541E-07,   1.0818943E-06
     +,   1.1787686E-06,   1.2826665E-06,   1.3939283E-06
     +,   1.5128966E-06,   1.6399089E-06,   1.7753001E-06
     +,   1.9194074E-06,   2.0725438E-06,   2.2350305E-06
     +,   2.4071649E-06,   2.5892336E-06,   2.7815045E-06
     +,   2.9842251E-06,   3.1976222E-06,   3.4218947E-06
     +,   3.6572137E-06,   3.9037195E-06,   4.1615176E-06
     +,   4.4306789E-06,   4.7112317E-06,   5.0031599E-06
     +,   5.3064227E-06,   5.6208974E-06,   5.9464487E-06
     +,   6.2828690E-06,   6.6299071E-06,   6.9872549E-06
     +,   7.3545530E-06,   7.7313871E-06,   8.1172857E-06
     +,   8.5117244E-06,   8.9141231E-06,   9.3238505E-06
     +,   9.7402171E-06,   1.0162491E-05,   1.0589878E-05
     +,   1.1021571E-05,   1.1456666E-05,   1.1894276E-05
     +,   1.2333445E-05,   1.2773196E-05,   1.3212529E-05
     +,   1.3650414E-05,   1.4085816E-05,   1.4517689E-05
     +,   1.4944964E-05,   1.5366602E-05,   1.5781579E-05
     +,   1.6188840E-05,   1.6587412E-05,   1.6976295E-05
     +,   1.7354581E-05,   1.7721351E-05,   1.8075776E-05
     +,   1.8417051E-05,   1.8744466E-05,   1.9057336E-05
     +,   1.9355082E-05,   1.9637202E-05,   1.9903242E-05
     +,   2.0152853E-05,   2.0385780E-05,   2.0601859E-05
     +,   2.0800990E-05,   2.0983196E-05,   2.1148579E-05
     +,   2.1297335E-05,   2.1429752E-05,   2.1546208E-05
     +,   2.1647162E-05,   2.1733165E-05,   2.1804835E-05
     +,   2.1862876E-05,   2.1908052E-05,   2.1941192E-05
     +,   2.1963173E-05,   2.1974929E-05,   2.1977434E-05
     +,   2.1971682E-05,   2.1958702E-05,   2.1939530E-05
     +,   2.1915208E-05,   2.1886784E-05,   2.1855276E-05
     +,   2.1821690E-05,   2.1787002E-05,   2.1752146E-05
     +,   2.1718010E-05,   2.1685415E-05,   2.1655136E-05
     +,   2.1627868E-05,   2.1604228E-05,   2.1584759E-05
     +,   2.1569906E-05,   2.1560028E-05,   2.1555392E-05
     +,   2.1556161E-05,   2.1562410E-05,   2.1574102E-05
     +,   2.1591108E-05,   2.1613198E-05,   2.1640046E-05
     +,   2.1671234E-05,   2.1706257E-05,   2.1744514E-05
     +,   2.1785332E-05,   2.1827966E-05,   2.1871600E-05
     +,   2.1915352E-05,   2.1958294E-05,   2.1999454E-05
     +,   2.2037828E-05,   2.2072376E-05,   2.2102042E-05
     +,   2.2125772E-05,   2.2142513E-05,   2.2151211E-05
     +,   2.2150847E-05,   2.2140441E-05,   2.2119040E-05
     +,   2.2085756E-05,   2.2039772E-05,   2.1980341E-05
     +,   2.1906810E-05,   2.1818638E-05,   2.1715397E-05
     +,   2.1596801E-05,   2.1462727E-05,   2.1313224E-05
     +,   2.1148546E-05,   2.0969183E-05,   2.0775902E-05
     +,   2.0569760E-05,   2.0352149E-05,   2.0124864E-05
     +,   1.9890131E-05,   1.9650663E-05,   1.9409685E-05
     +,   1.9171044E-05,   1.8939210E-05,   1.8719324E-05
     +,   1.8517227E-05,   1.8339508E-05,   1.8193470E-05
     +,   1.8087116E-05,   1.8029106E-05,   1.8028655E-05
     +,   1.8095412E-05,   1.8239301E-05,   1.8470302E-05
     +,   1.8798186E-05,   1.9232240E-05,   1.9780940E-05
     +,   2.0451524E-05,   2.1249620E-05,   2.2178918E-05
     +,   2.3240733E-05,   2.4433513E-05,   2.5752735E-05
     +,   2.7190523E-05,   2.8735387E-05,   3.0372181E-05
     +,   3.2082298E-05,   3.3843702E-05,   3.5631125E-05
     +,   3.7416630E-05,   3.9170307E-05,   4.0860956E-05
     +,   4.2456872E-05,   4.3927052E-05,   4.5242621E-05
     +,   4.6378238E-05,   4.7313908E-05,   4.8037549E-05
     +,   4.8547743E-05,   4.8857448E-05,   4.8998671E-05
     +,   4.9028265E-05,   4.9034963E-05,   4.9147744E-05
     +,   4.9545401E-05,   5.0467028E-05,   5.2222811E-05
     +,   5.5204269E-05,   5.9892944E-05,   6.6866676E-05
     +,   7.6801458E-05,   9.0465983E-05,   1.0871202E-04
     +,   1.3245361E-04,   1.6263410E-04,   2.0018405E-04
     +,   2.4596910E-04,   3.0072170E-04,   3.6495773E-04
     +,   4.3889190E-04,   5.2235293E-04,   6.1469286E-04
     +,   7.1470602E-04,   8.2058233E-04,   9.2989998E-04
     +,   1.0396481E-03,   1.1463002E-03,   1.2459771E-03
     +,   1.3346355E-03,   1.4083055E-03,   1.4633780E-03
     +,   1.4968895E-03,   1.5067777E-03,   1.4920916E-03
     +,   1.4531264E-03,   1.3914431E-03,   1.3097799E-03
     +,   1.2118609E-03,   1.1021022E-03,   9.8525302E-04
     +,   8.6603023E-04,   7.4878731E-04,   6.3720864E-04
     +,   5.3413276E-04,   4.4147411E-04,   3.6023208E-04
     +,   2.9058955E-04,   2.3208068E-04,   1.8378292E-04
     +,   1.4449931E-04,   1.1292271E-04,   8.7767658E-05
     +,   6.7857778E-05,   5.2170366E-05,   3.9850918E-05
     +,   3.0207020E-05,   2.2688260E-05,   1.6858829E-05
     +,   1.2373669E-05,   8.9573205E-06,   6.3870239E-06
     +,   4.4808676E-06,   3.0899669E-06,   2.0929010E-06
     +,   1.3915491E-06,   9.0785016E-07,   5.8099727E-07
     +,   3.6470433E-07,   2.2457512E-07,   1.3569937E-07
     +,   8.0516664E-08,   4.6971937E-08,   2.6998183E-08
     +,   1.5340859E-08,   8.6648493E-09,   4.9059348E-09
     +,   2.8182885E-09,   1.6686180E-09,   1.0356017E-09
     +,   6.8267081E-10,   4.7993343E-10,   3.5753880E-10
     +,   2.7858899E-10,   2.2382768E-10,   1.8326374E-10
     +,   1.5165899E-10,   1.2619190E-10,   1.0525029E-10
     +,   8.7840582E-11,   7.3287897E-11,   6.1097419E-11
     +,   5.0880574E-11,   4.2322108E-11,   3.5159192E-11
     +,   2.9171072E-11,   2.4171590E-11,   2.0002765E-11
     +,   1.6531448E-11,   1.3644607E-11,   1.1247263E-11
     +,   9.2589469E-12,   7.6122303E-12,   6.2501636E-12
     +,   5.1251434E-12,   4.1971053E-12,   3.4326444E-12
     +,   2.8037355E-12,   2.2870744E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz118 = Yx/0.00795454545454546
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.2341661E-06,   9.1656830E-06
     +,   9.0984431E-06,   9.0325757E-06,   8.9682053E-06
     +,   8.9054583E-06,   8.8444558E-06,   8.7853159E-06
     +,   8.7281560E-06,   8.6730824E-06,   8.6202108E-06
     +,   8.5696411E-06,   8.5214742E-06,   8.4758103E-06
     +,   8.4327394E-06,   8.3923496E-06,   8.3547247E-06
     +,   8.3199429E-06,   8.2880797E-06,   8.2592014E-06
     +,   8.2333736E-06,   8.2106544E-06,   8.1910957E-06
     +,   8.1747457E-06,   8.1616454E-06,   8.1518319E-06
     +,   8.1453363E-06,   8.1421813E-06,   8.1423859E-06
     +,   8.1459639E-06,   8.1529215E-06,   8.1632588E-06
     +,   8.1769722E-06,   8.1940480E-06,   8.2144707E-06
     +,   8.2382157E-06,   8.2652523E-06,   8.2955466E-06
     +,   8.3290579E-06,   8.3657360E-06,   8.4055282E-06
     +,   8.4483772E-06,   8.4942176E-06,   8.5429783E-06
     +,   8.5945831E-06,   8.6489508E-06,   8.7059952E-06
     +,   8.7656244E-06,   8.8277402E-06,   8.8922434E-06
     +,   8.9590249E-06,   9.0279736E-06,   9.0989752E-06
     +,   9.1719121E-06,   9.2466553E-06,   9.3230828E-06
     +,   9.4010611E-06,   9.4804564E-06,   9.5611294E-06
     +,   9.6429403E-06,   9.7257480E-06,   9.8094060E-06
     +,   9.8937608E-06,   9.9786675E-06,   1.0063979E-05
     +,   1.0149532E-05,   1.0235181E-05,   1.0320766E-05
     +,   1.0406132E-05,   1.0491121E-05,   1.0575581E-05
     +,   1.0659349E-05,   1.0742277E-05,   1.0824201E-05
     +,   1.0904972E-05,   1.0984439E-05,   1.1062447E-05
     +,   1.1138844E-05,   1.1213484E-05,   1.1286224E-05
     +,   1.1356916E-05,   1.1425424E-05,   1.1491606E-05
     +,   1.1555333E-05,   1.1616467E-05,   1.1674890E-05
     +,   1.1730471E-05,   1.1783095E-05,   1.1832644E-05
     +,   1.1879011E-05,   1.1922090E-05,   1.1961781E-05
     +,   1.1997985E-05,   1.2030612E-05,   1.2059580E-05
     +,   1.2084805E-05,   1.2106218E-05,   1.2123744E-05
     +,   1.2137327E-05,   1.2146906E-05,   1.2152431E-05
     +,   1.2153857E-05,   1.2151146E-05,   1.2144264E-05
     +,   1.2133185E-05,   1.2117888E-05,   1.2098361E-05
     +,   1.2074594E-05,   1.2046586E-05,   1.2014340E-05
     +,   1.1977866E-05,   1.1937179E-05,   1.1892304E-05
     +,   1.1843267E-05,   1.1790103E-05,   1.1732847E-05
     +,   1.1671550E-05,   1.1606257E-05,   1.1537028E-05
     +,   1.1463921E-05,   1.1386998E-05,   1.1306334E-05
     +,   1.1222005E-05,   1.1134088E-05,   1.1042666E-05
     +,   1.0947834E-05,   1.0849675E-05,   1.0748295E-05
     +,   1.0643788E-05,   1.0536262E-05,   1.0425823E-05
     +,   1.0312589E-05,   1.0196672E-05,   1.0078198E-05
     +,   9.9572962E-06,   9.8340943E-06,   9.7087386E-06
     +,   9.5813848E-06,   9.4521974E-06,   9.3213512E-06
     +,   9.1890442E-06,   9.0555141E-06,   8.9210080E-06
     +,   8.7858234E-06,   8.6503114E-06,   8.5148904E-06
     +,   8.3800469E-06,   8.2463866E-06,   8.1146381E-06
     +,   7.9856791E-06,   7.8605799E-06,   7.7406476E-06
     +,   7.6274709E-06,   7.5229736E-06,   7.4294644E-06
     +,   7.3497490E-06,   7.2871658E-06,   7.2456960E-06
     +,   7.2300613E-06,   7.2458283E-06,   7.2995067E-06
     +,   7.3986807E-06,   7.5521248E-06,   7.7699024E-06
     +,   8.0635136E-06,   8.4459944E-06,   8.9319965E-06
     +,   9.5378646E-06,   1.0281759E-05,   1.1183670E-05
     +,   1.2265368E-05,   1.3550420E-05,   1.5064196E-05
     +,   1.6833779E-05,   1.8887577E-05,   2.1255519E-05
     +,   2.3968711E-05,   2.7058957E-05,   3.0558647E-05
     +,   3.4500634E-05,   3.8917835E-05,   4.3842520E-05
     +,   4.9306200E-05,   5.5339711E-05,   6.1972656E-05
     +,   6.9232643E-05,   7.7145298E-05,   8.5734762E-05
     +,   9.5022937E-05,   1.0502843E-04,   1.1576813E-04
     +,   1.2725627E-04,   1.3950352E-04,   1.5251728E-04
     +,   1.6630228E-04,   1.8085969E-04,   1.9618534E-04
     +,   2.1227021E-04,   2.2910058E-04,   2.4665636E-04
     +,   2.6490880E-04,   2.8382050E-04,   3.0334532E-04
     +,   3.2342598E-04,   3.4399098E-04,   3.6495726E-04
     +,   3.8622718E-04,   4.0768646E-04,   4.2920501E-04
     +,   4.5063836E-04,   4.7182676E-04,   4.9259450E-04
     +,   5.1275321E-04,   5.3210504E-04,   5.5044406E-04
     +,   5.6755863E-04,   5.8323599E-04,   5.9726834E-04
     +,   6.0945511E-04,   6.1960734E-04,   6.2755455E-04
     +,   6.3314766E-04,   6.3626375E-04,   6.3680945E-04
     +,   6.3472526E-04,   6.2998623E-04,   6.2260509E-04
     +,   6.1263243E-04,   6.0015550E-04,   5.8529741E-04
     +,   5.6821550E-04,   5.4909836E-04,   5.2815967E-04
     +,   5.0563487E-04,   4.8177870E-04,   4.5685520E-04
     +,   4.3113419E-04,   4.0488769E-04,   3.7838303E-04
     +,   3.5187585E-04,   3.2560763E-04,   2.9980321E-04
     +,   2.7466629E-04,   2.5037472E-04,   2.2708108E-04
     +,   2.0491287E-04,   1.8397075E-04,   1.6432768E-04
     +,   1.4603134E-04,   1.2910750E-04,   1.1355846E-04
     +,   9.9367011E-05,   8.6500018E-05,   7.4909833E-05
     +,   6.4536274E-05,   5.5310200E-05,   4.7156522E-05
     +,   3.9995692E-05,   3.3745458E-05,   2.8323344E-05
     +,   2.3648470E-05,   1.9642388E-05,   1.6229988E-05
     +,   1.3340608E-05,   1.0908833E-05,   8.8742518E-06
     +,   7.1819827E-06,   5.7827510E-06,   4.6326054E-06
     +,   3.6926674E-06,   2.9289317E-06,   2.3119567E-06
     +,   1.8163950E-06,   1.4205916E-06,   1.1062248E-06
     +,   8.5793704E-07,   6.6289465E-07,   5.1050893E-07
     +,   3.9206475E-07,   3.0047434E-07,   2.2998937E-07
     +,   1.7599967E-07,   1.3481932E-07,   1.0353248E-07
     +,   7.9839701E-08,   6.1946366E-08,   4.8456421E-08
     +,   3.8293031E-08,   3.0631444E-08,   2.4842233E-08
     +,   2.0449614E-08,   1.7094923E-08,   1.4510236E-08
     +,   1.2495850E-08,   1.0904233E-08,   9.6265067E-09
     +,   8.5829894E-09,   7.7153288E-09,   6.9811037E-09
     +,   6.3493508E-09,   5.7976228E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz119 = Yx/0.00665
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4098431E-05,   1.4395142E-05
     +,   1.4710339E-05,   1.5044750E-05,   1.5399084E-05
     +,   1.5774038E-05,   1.6170288E-05,   1.6588492E-05
     +,   1.7029266E-05,   1.7493225E-05,   1.7980918E-05
     +,   1.8492874E-05,   1.9029572E-05,   1.9591445E-05
     +,   2.0178879E-05,   2.0792204E-05,   2.1431690E-05
     +,   2.2097545E-05,   2.2789916E-05,   2.3508874E-05
     +,   2.4254425E-05,   2.5026487E-05,   2.5824900E-05
     +,   2.6649464E-05,   2.7499809E-05,   2.8375563E-05
     +,   2.9276231E-05,   3.0201214E-05,   3.1149844E-05
     +,   3.2121359E-05,   3.3114899E-05,   3.4129502E-05
     +,   3.5164143E-05,   3.6217672E-05,   3.7288886E-05
     +,   3.8376464E-05,   3.9479022E-05,   4.0595060E-05
     +,   4.1723088E-05,   4.2861397E-05,   4.4008353E-05
     +,   4.5162175E-05,   4.6321024E-05,   4.7483045E-05
     +,   4.8646292E-05,   4.9808801E-05,   5.0968567E-05
     +,   5.2123542E-05,   5.3271680E-05,   5.4410888E-05
     +,   5.5539098E-05,   5.6654215E-05,   5.7754147E-05
     +,   5.8836864E-05,   5.9900274E-05,   6.0942406E-05
     +,   6.1961269E-05,   6.2954903E-05,   6.3921456E-05
     +,   6.4859079E-05,   6.5766013E-05,   6.6640561E-05
     +,   6.7481073E-05,   6.8286026E-05,   6.9053989E-05
     +,   6.9783549E-05,   7.0473463E-05,   7.1122508E-05
     +,   7.1729657E-05,   7.2293871E-05,   7.2814320E-05
     +,   7.3290190E-05,   7.3720847E-05,   7.4105701E-05
     +,   7.4444302E-05,   7.4736316E-05,   7.4981457E-05
     +,   7.5179589E-05,   7.5330667E-05,   7.5434735E-05
     +,   7.5491917E-05,   7.5502452E-05,   7.5466676E-05
     +,   7.5384960E-05,   7.5257791E-05,   7.5085729E-05
     +,   7.4869407E-05,   7.4609510E-05,   7.4306809E-05
     +,   7.3962110E-05,   7.3576259E-05,   7.3150208E-05
     +,   7.2684910E-05,   7.2181370E-05,   7.1640621E-05
     +,   7.1063754E-05,   7.0451868E-05,   6.9806098E-05
     +,   6.9127571E-05,   6.8417517E-05,   6.7677058E-05
     +,   6.6907465E-05,   6.6109897E-05,   6.5285640E-05
     +,   6.4435881E-05,   6.3561834E-05,   6.2664789E-05
     +,   6.1746003E-05,   6.0806691E-05,   5.9848076E-05
     +,   5.8871465E-05,   5.7878024E-05,   5.6869067E-05
     +,   5.5845765E-05,   5.4809403E-05,   5.3761149E-05
     +,   5.2702293E-05,   5.1633979E-05,   5.0557494E-05
     +,   4.9473991E-05,   4.8384652E-05,   4.7290680E-05
     +,   4.6193305E-05,   4.5093671E-05,   4.3992899E-05
     +,   4.2892236E-05,   4.1792755E-05,   4.0695682E-05
     +,   3.9602081E-05,   3.8513164E-05,   3.7430000E-05
     +,   3.6353795E-05,   3.5285611E-05,   3.4226669E-05
     +,   3.3178076E-05,   3.2140968E-05,   3.1116560E-05
     +,   3.0106101E-05,   2.9110799E-05,   2.8131910E-05
     +,   2.7170820E-05,   2.6228969E-05,   2.5307818E-05
     +,   2.4408944E-05,   2.3534109E-05,   2.2685135E-05
     +,   2.1864007E-05,   2.1072952E-05,   2.0314405E-05
     +,   1.9590987E-05,   1.8905610E-05,   1.8261533E-05
     +,   1.7662360E-05,   1.7112039E-05,   1.6614946E-05
     +,   1.6175969E-05,   1.5800493E-05,   1.5494436E-05
     +,   1.5264333E-05,   1.5117394E-05,   1.5061497E-05
     +,   1.5105281E-05,   1.5258160E-05,   1.5530386E-05
     +,   1.5933076E-05,   1.6478278E-05,   1.7178945E-05
     +,   1.8048959E-05,   1.9103249E-05,   2.0357744E-05
     +,   2.1829273E-05,   2.3535637E-05,   2.5495669E-05
     +,   2.7729124E-05,   3.0256415E-05,   3.3098910E-05
     +,   3.6278714E-05,   3.9818282E-05,   4.3740394E-05
     +,   4.8068374E-05,   5.2825577E-05,   5.8034871E-05
     +,   6.3718631E-05,   6.9898793E-05,   7.6596283E-05
     +,   8.3830200E-05,   9.1617665E-05,   9.9974059E-05
     +,   1.0891216E-04,   1.1844062E-04,   1.2856530E-04
     +,   1.3928796E-04,   1.5060502E-04,   1.6250757E-04
     +,   1.7498191E-04,   1.8800802E-04,   2.0155875E-04
     +,   2.1559982E-04,   2.3009056E-04,   2.4498289E-04
     +,   2.6022023E-04,   2.7573822E-04,   2.9146596E-04
     +,   3.0732510E-04,   3.2322918E-04,   3.3908617E-04
     +,   3.5479848E-04,   3.7026263E-04,   3.8537072E-04
     +,   4.0001282E-04,   4.1407751E-04,   4.2745157E-04
     +,   4.4002288E-04,   4.5168266E-04,   4.6232596E-04
     +,   4.7185240E-04,   4.8016917E-04,   4.8719201E-04
     +,   4.9284688E-04,   4.9707043E-04,   4.9981190E-04
     +,   5.0103397E-04,   5.0071313E-04,   4.9884093E-04
     +,   4.9542356E-04,   4.9048243E-04,   4.8405348E-04
     +,   4.7618806E-04,   4.6695021E-04,   4.5641660E-04
     +,   4.4467667E-04,   4.3182995E-04,   4.1798418E-04
     +,   4.0325441E-04,   3.8776259E-04,   3.7163307E-04
     +,   3.5499220E-04,   3.3796777E-04,   3.2068611E-04
     +,   3.0326960E-04,   2.8583594E-04,   2.6849826E-04
     +,   2.5136265E-04,   2.3452593E-04,   2.1807619E-04
     +,   2.0209319E-04,   1.8664663E-04,   1.7179509E-04
     +,   1.5758711E-04,   1.4406252E-04,   1.3124997E-04
     +,   1.1916889E-04,   1.0783067E-04,   9.7238510E-05
     +,   8.7387416E-05,   7.8265788E-05,   6.9856804E-05
     +,   6.2138446E-05,   5.5083976E-05,   4.8663307E-05
     +,   4.2844094E-05,   3.7591970E-05,   3.2870972E-05
     +,   2.8644499E-05,   2.4876270E-05,   2.1529944E-05
     +,   1.8570012E-05,   1.5962289E-05,   1.3673959E-05
     +,   1.1673675E-05,   9.9319104E-06,   8.4211670E-06
     +,   7.1158793E-06,   5.9923773E-06,   5.0289991E-06
     +,   4.2061097E-06,   3.5058317E-06,   2.9121782E-06
     +,   2.4107692E-06,   1.9888828E-06,   1.6352061E-06
     +,   1.3398333E-06,   1.0940514E-06,   8.9030419E-07
     +,   7.2201493E-07,   5.8353413E-07,   4.6999654E-07
     +,   3.7724831E-07,   3.0176534E-07,   2.4055430E-07
     +,   1.9110159E-07,   1.5129147E-07,   1.1936284E-07
     +,   9.3846964E-08,   7.3531425E-08,   5.7414123E-08
     +,   4.4674859E-08,   3.4641555E-08,   2.6768669E-08
     +,   2.0613056E-08,   1.5817930E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz120 = Yx/0.00733333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3103491E-07,   1.5242617E-07
     +,   1.7691089E-07,   2.0486706E-07,   2.3670754E-07
     +,   2.7288166E-07,   3.1387674E-07,   3.6021876E-07
     +,   4.1247264E-07,   4.7124533E-07,   5.3718213E-07
     +,   6.1096813E-07,   6.9332668E-07,   7.8501824E-07
     +,   8.8683760E-07,   9.9961039E-07,   1.1241900E-06
     +,   1.2614538E-06,   1.4122945E-06,   1.5776179E-06
     +,   1.7583312E-06,   1.9553390E-06,   2.1695275E-06
     +,   2.4017747E-06,   2.6528985E-06,   2.9236955E-06
     +,   3.2148926E-06,   3.5271462E-06,   3.8610333E-06
     +,   4.2170300E-06,   4.5955053E-06,   4.9967043E-06
     +,   5.4207389E-06,   5.8675714E-06,   6.3370080E-06
     +,   6.8286918E-06,   7.3420911E-06,   7.8764906E-06
     +,   8.4310341E-06,   9.0046306E-06,   9.5960877E-06
     +,   1.0204026E-05,   1.0826943E-05,   1.1463233E-05
     +,   1.2111223E-05,   1.2769212E-05,   1.3435533E-05
     +,   1.4108611E-05,   1.4787038E-05,   1.5469663E-05
     +,   1.6155685E-05,   1.6844766E-05,   1.7537128E-05
     +,   1.8233737E-05,   1.8936307E-05,   1.9647599E-05
     +,   2.0371410E-05,   2.1112774E-05,   2.1878079E-05
     +,   2.2675174E-05,   2.3513474E-05,   2.4404095E-05
     +,   2.5359843E-05,   2.6395446E-05,   2.7527563E-05
     +,   2.8774763E-05,   3.0157868E-05,   3.1699747E-05
     +,   3.3425815E-05,   3.5363799E-05,   3.7544374E-05
     +,   4.0000894E-05,   4.2770240E-05,   4.5892408E-05
     +,   4.9411388E-05,   5.3375141E-05,   5.7835416E-05
     +,   6.2847823E-05,   6.8471927E-05,   7.4770272E-05
     +,   8.1806626E-05,   8.9645655E-05,   9.8348770E-05
     +,   1.0797297E-04,   1.1856453E-04,   1.3015687E-04
     +,   1.4276228E-04,   1.5636902E-04,   1.7093228E-04
     +,   1.8637153E-04,   2.0256508E-04,   2.1934624E-04
     +,   2.3650423E-04,   2.5378860E-04,   2.7091531E-04
     +,   2.8757597E-04,   3.0345732E-04,   3.1825571E-04
     +,   3.3170308E-04,   3.4358614E-04,   3.5377231E-04
     +,   3.6222665E-04,   3.6902833E-04,   3.7437663E-04
     +,   3.7858917E-04,   3.8208844E-04,   3.8537692E-04
     +,   3.8900206E-04,   3.9351251E-04,   3.9940939E-04
     +,   4.0709649E-04,   4.1683874E-04,   4.2872853E-04
     +,   4.4267386E-04,   4.5840314E-04,   4.7549946E-04
     +,   4.9344852E-04,   5.1171303E-04,   5.2980427E-04
     +,   5.4736098E-04,   5.6420593E-04,   5.8037793E-04
     +,   5.9613021E-04,   6.1189116E-04,   6.2818895E-04
     +,   6.4555067E-04,   6.6439761E-04,   6.8494020E-04
     +,   7.0711091E-04,   7.3052739E-04,   7.5451582E-04
     +,   7.7817054E-04,   8.0046372E-04,   8.2036282E-04
     +,   8.3695987E-04,   8.4956893E-04,   8.5779064E-04
     +,   8.6152868E-04,   8.6096162E-04,   8.5647486E-04
     +,   8.4857451E-04,   8.3779643E-04,   8.2462933E-04
     +,   8.0946524E-04,   7.9258339E-04,   7.7415869E-04
     +,   7.5429701E-04,   7.3308015E-04,   7.1060931E-04
     +,   6.8703567E-04,   6.6257798E-04,   6.3752342E-04
     +,   6.1221083E-04,   5.8700069E-04,   5.6224770E-04
     +,   5.3827249E-04,   5.1533646E-04,   4.9362413E-04
     +,   4.7323658E-04,   4.5419502E-04,   4.3644267E-04
     +,   4.1985934E-04,   4.0427819E-04,   3.8950145E-04
     +,   3.7531753E-04,   3.6151853E-04,   3.4791636E-04
     +,   3.3435281E-04,   3.2070733E-04,   3.0690187E-04
     +,   2.9290238E-04,   2.7871484E-04,   2.6437934E-04
     +,   2.4996340E-04,   2.3555578E-04,   2.2125586E-04
     +,   2.0716742E-04,   1.9339361E-04,   1.8003066E-04
     +,   1.6716339E-04,   1.5486342E-04,   1.4318859E-04
     +,   1.3218135E-04,   1.2186842E-04,   1.1226227E-04
     +,   1.0336307E-04,   9.5159434E-05,   8.7629829E-05
     +,   8.0745122E-05,   7.4471049E-05,   6.8768801E-05
     +,   6.3597392E-05,   5.8915492E-05,   5.4682194E-05
     +,   5.0857856E-05,   4.7405054E-05,   4.4289332E-05
     +,   4.1479059E-05,   3.8945436E-05,   3.6662554E-05
     +,   3.4607347E-05,   3.2759152E-05,   3.1099276E-05
     +,   2.9610832E-05,   2.8278597E-05,   2.7088410E-05
     +,   2.6027126E-05,   2.5082487E-05,   2.4242889E-05
     +,   2.3497239E-05,   2.2834971E-05,   2.2246044E-05
     +,   2.1720891E-05,   2.1250407E-05,   2.0826003E-05
     +,   2.0439680E-05,   2.0084020E-05,   1.9752188E-05
     +,   1.9437985E-05,   1.9135883E-05,   1.8840979E-05
     +,   1.8549006E-05,   1.8256338E-05,   1.7959954E-05
     +,   1.7657372E-05,   1.7346651E-05,   1.7026345E-05
     +,   1.6695471E-05,   1.6353406E-05,   1.5999891E-05
     +,   1.5635002E-05,   1.5259073E-05,   1.4872645E-05
     +,   1.4476452E-05,   1.4071410E-05,   1.3658529E-05
     +,   1.3238908E-05,   1.2813736E-05,   1.2384256E-05
     +,   1.1951704E-05,   1.1517320E-05,   1.1082368E-05
     +,   1.0648091E-05,   1.0215668E-05,   9.7862376E-06
     +,   9.3609133E-06,   8.9407549E-06,   8.5267284E-06
     +,   8.1197340E-06,   7.7206423E-06,   7.3302085E-06
     +,   6.9491152E-06,   6.5779964E-06,   6.2174081E-06
     +,   5.8678083E-06,   5.5295814E-06,   5.2030655E-06
     +,   4.8885254E-06,   4.5861375E-06,   4.2960169E-06
     +,   4.0182358E-06,   3.7528093E-06,   3.4996779E-06
     +,   3.2587370E-06,   3.0298568E-06,   2.8128429E-06
     +,   2.6074640E-06,   2.4134697E-06,   2.2305758E-06
     +,   2.0584610E-06,   1.8967837E-06,   1.7451932E-06
     +,   1.6033231E-06,   1.4707844E-06,   1.3471825E-06
     +,   1.2321276E-06,   1.1252114E-06,   1.0260405E-06
     +,   9.3420942E-07,   8.4932867E-07,   7.7100384E-07
     +,   6.9885840E-07,   6.3251542E-07,   5.7161674E-07
     +,   5.1580787E-07,   4.6475384E-07,   4.1812737E-07
     +,   3.7561537E-07,   3.3692260E-07,   3.0176298E-07
     +,   2.6986962E-07,   2.4098551E-07,   2.1487206E-07
     +,   1.9130134E-07,   1.7006242E-07,   1.5095503E-07
     +,   1.3379470E-07,   1.1840752E-07,   1.0463377E-07
     +,   9.2323752E-08,   8.1340566E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz75 = Yx/0.01176
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1400616E-11,   3.1573348E-11
     +,   4.6346340E-11,   6.7688001E-11,   9.8358245E-11
     +,   1.4220482E-10,   2.0456116E-10,   2.9277830E-10
     +,   4.1692769E-10,   5.9073851E-10,   8.3280216E-10
     +,   1.1681600E-09,   1.6303416E-09,   2.2639812E-09
     +,   3.1281489E-09,   4.3005501E-09,   5.8828240E-09
     +,   8.0070954E-09,   1.0844124E-08,   1.4613255E-08
     +,   1.9594541E-08,   2.6143438E-08,   3.4708055E-08
     +,   4.5850857E-08,   6.0271233E-08,   7.8836486E-08
     +,   1.0261267E-07,   1.3290315E-07,   1.7129084E-07
     +,   2.1968570E-07,   2.8037701E-07,   3.5609037E-07
     +,   4.5004970E-07,   5.6604028E-07,   7.0847665E-07
     +,   8.8247032E-07,   1.0938960E-06,   1.3494495E-06
     +,   1.6567292E-06,   2.0242314E-06,   2.4614544E-06
     +,   2.9788614E-06,   3.5879020E-06,   4.3009868E-06
     +,   5.1314223E-06,   6.0933298E-06,   7.2015159E-06
     +,   8.4713001E-06,   9.9183226E-06,   1.1558268E-05
     +,   1.3406587E-05,   1.5478146E-05,   1.7786811E-05
     +,   2.0345227E-05,   2.3163921E-05,   2.6251444E-05
     +,   2.9613382E-05,   3.3252170E-05,   3.7166519E-05
     +,   4.1351039E-05,   4.5795874E-05,   5.0486447E-05
     +,   5.5402852E-05,   6.0520480E-05,   6.5809581E-05
     +,   7.1234892E-05,   7.6757075E-05,   8.2331760E-05
     +,   8.7911496E-05,   9.3444964E-05,   9.8879347E-05
     +,   1.0415971E-04,   1.0923158E-04,   1.1404062E-04
     +,   1.1853506E-04,   1.2266633E-04,   1.2638999E-04
     +,   1.2966731E-04,   1.3246643E-04,   1.3476312E-04
     +,   1.3654144E-04,   1.3779488E-04,   1.3852645E-04
     +,   1.3874924E-04,   1.3848640E-04,   1.3777103E-04
     +,   1.3664601E-04,   1.3516322E-04,   1.3338325E-04
     +,   1.3137404E-04,   1.2921014E-04,   1.2697148E-04
     +,   1.2474199E-04,   1.2260779E-04,   1.2065574E-04
     +,   1.1897178E-04,   1.1763845E-04,   1.1673327E-04
     +,   1.1632602E-04,   1.1647687E-04,   1.1723372E-04
     +,   1.1863007E-04,   1.2068293E-04,   1.2339088E-04
     +,   1.2673315E-04,   1.3066897E-04,   1.3513774E-04
     +,   1.4006085E-04,   1.4534514E-04,   1.5088725E-04
     +,   1.5657915E-04,   1.6231713E-04,   1.6800915E-04
     +,   1.7358552E-04,   1.7900705E-04,   1.8427493E-04
     +,   1.8943612E-04,   1.9458975E-04,   1.9988765E-04
     +,   2.0553512E-04,   2.1178734E-04,   2.1894379E-04
     +,   2.2734203E-04,   2.3734955E-04,   2.4935394E-04
     +,   2.6374825E-04,   2.8091826E-04,   3.0121772E-04
     +,   3.2494889E-04,   3.5232934E-04,   3.8347248E-04
     +,   4.1835953E-04,   4.5683849E-04,   4.9862347E-04
     +,   5.4332905E-04,   5.9051096E-04,   6.3971814E-04
     +,   6.9054688E-04,   7.4268167E-04,   7.9589605E-04
     +,   8.5001090E-04,   9.0481504E-04,   9.5994951E-04
     +,   1.0147719E-03,   1.0682322E-03,   1.1188189E-03
     +,   1.1645670E-03,   1.2031714E-03,   1.2321980E-03
     +,   1.2493673E-03,   1.2528538E-03,   1.2415585E-03
     +,   1.2152957E-03,   1.1748490E-03,   1.1218854E-03
     +,   1.0587536E-03,   9.8819169E-04,   9.1300573E-04
     +,   8.3579199E-04,   7.5874571E-04,   6.8354694E-04
     +,   6.1137317E-04,   5.4298394E-04,   4.7883877E-04
     +,   4.1921771E-04,   3.6432629E-04,   3.1435539E-04
     +,   2.6948977E-04,   2.2988497E-04,   1.9563265E-04
     +,   1.6672327E-04,   1.4301646E-04,   1.2423251E-04
     +,   1.0996730E-04,   9.9721226E-05,   9.2933777E-05
     +,   8.9024506E-05,   8.7427827E-05,   8.7619650E-05
     +,   8.9135036E-05,   9.1577072E-05,   9.4617346E-05
     +,   9.7991513E-05,   1.0149181E-04,   1.0495783E-04
     +,   1.0826723E-04,   1.1132774E-04,   1.1407056E-04
     +,   1.1644470E-04,   1.1841267E-04,   1.1994808E-04
     +,   1.2103309E-04,   1.2165713E-04,   1.2181588E-04
     +,   1.2151063E-04,   1.2074770E-04,   1.1953805E-04
     +,   1.1789709E-04,   1.1584405E-04,   1.1340177E-04
     +,   1.1059657E-04,   1.0745775E-04,   1.0401691E-04
     +,   1.0030782E-04,   9.6366239E-05,   9.2228780E-05
     +,   8.7932793E-05,   8.3516097E-05,   7.9016267E-05
     +,   7.4469841E-05,   6.9912130E-05,   6.5377062E-05
     +,   6.0896491E-05,   5.6499572E-05,   5.2212734E-05
     +,   4.8059752E-05,   4.4061253E-05,   4.0234368E-05
     +,   3.6593003E-05,   3.3148201E-05,   2.9907487E-05
     +,   2.6875452E-05,   2.4054099E-05,   2.1442836E-05
     +,   1.9038596E-05,   1.6836326E-05,   1.4829395E-05
     +,   1.3009717E-05,   1.1367942E-05,   9.8938817E-06
     +,   8.5768470E-06,   7.4057716E-06,   6.3693656E-06
     +,   5.4563998E-06,   4.6559489E-06,   3.9573360E-06
     +,   3.3503554E-06,   2.8253780E-06,   2.3733653E-06
     +,   1.9858858E-06,   1.6551767E-06,   1.3741627E-06
     +,   1.1364192E-06,   9.3614483E-07,   7.6815343E-07
     +,   6.2784881E-07,   5.1117058E-07,   4.1454823E-07
     +,   3.3487115E-07,   2.6944898E-07,   2.1595609E-07
     +,   1.7240006E-07,   1.3708558E-07,   1.0857436E-07
     +,   8.5651706E-08,   6.7299212E-08,   5.2668000E-08
     +,   4.1053063E-08,   3.1871068E-08,   2.4642880E-08
     +,   1.8976998E-08,   1.4554676E-08,   1.1117515E-08
     +,   8.4573246E-09,   6.4073853E-09,   4.8343818E-09
     +,   3.6324845E-09,   2.7181162E-09,   2.0255024E-09
     +,   1.5030991E-09,   1.1107687E-09,   8.1740886E-10
     +,   5.9901062E-10,   4.3712012E-10,   3.1763467E-10
     +,   2.2983739E-10,   1.6560193E-10,   1.1881410E-10
     +,   8.4881747E-11,   6.0382428E-11,   4.2770343E-11
     +,   3.0165998E-11,   2.1184721E-11,   1.4813718E-11
     +,   1.0314033E-11,   7.1502864E-12,   4.9356162E-12
     +,   3.3921444E-12,   2.3212990E-12,   1.5816060E-12
     +,   1.0729605E-12,   7.2472876E-13,   4.8739745E-13
     +,   3.2635705E-13,   2.1757776E-13,   1.4442275E-13
     +,   9.5447908E-14,   6.2804722E-14,   4.1145872E-14
     +,   2.6838168E-14,   1.7429512E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz80 = Yx/0.01092
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8801040E-05,   1.8972103E-05
     +,   1.9145005E-05,   1.9319996E-05,   1.9497307E-05
     +,   1.9677158E-05,   1.9859746E-05,   2.0045260E-05
     +,   2.0233847E-05,   2.0425661E-05,   2.0620804E-05
     +,   2.0819371E-05,   2.1021415E-05,   2.1226979E-05
     +,   2.1436055E-05,   2.1648619E-05,   2.1864613E-05
     +,   2.2083945E-05,   2.2306491E-05,   2.2532089E-05
     +,   2.2760552E-05,   2.2991653E-05,   2.3225128E-05
     +,   2.3460703E-05,   2.3698032E-05,   2.3936776E-05
     +,   2.4176534E-05,   2.4416900E-05,   2.4657415E-05
     +,   2.4897616E-05,   2.5136989E-05,   2.5375015E-05
     +,   2.5611151E-05,   2.5844820E-05,   2.6075442E-05
     +,   2.6302414E-05,   2.6525126E-05,   2.6742950E-05
     +,   2.6955266E-05,   2.7161437E-05,   2.7360846E-05
     +,   2.7552858E-05,   2.7736874E-05,   2.7912291E-05
     +,   2.8078535E-05,   2.8235063E-05,   2.8381357E-05
     +,   2.8516941E-05,   2.8641392E-05,   2.8754343E-05
     +,   2.8855466E-05,   2.8944532E-05,   2.9021390E-05
     +,   2.9085970E-05,   2.9138298E-05,   2.9178536E-05
     +,   2.9206940E-05,   2.9223929E-05,   2.9230059E-05
     +,   2.9226043E-05,   2.9212764E-05,   2.9191298E-05
     +,   2.9162920E-05,   2.9129098E-05,   2.9091527E-05
     +,   2.9052124E-05,   2.9013036E-05,   2.8976649E-05
     +,   2.8945584E-05,   2.8922699E-05,   2.8911089E-05
     +,   2.8914052E-05,   2.8935116E-05,   2.8977980E-05
     +,   2.9046514E-05,   2.9144721E-05,   2.9276709E-05
     +,   2.9446630E-05,   2.9658640E-05,   2.9916871E-05
     +,   3.0225314E-05,   3.0587813E-05,   3.1007930E-05
     +,   3.1488951E-05,   3.2033724E-05,   3.2644653E-05
     +,   3.3323526E-05,   3.4071578E-05,   3.4889224E-05
     +,   3.5776160E-05,   3.6731253E-05,   3.7752379E-05
     +,   3.8836461E-05,   3.9979470E-05,   4.1176394E-05
     +,   4.2421059E-05,   4.3706441E-05,   4.5024357E-05
     +,   4.6365858E-05,   4.7720940E-05,   4.9078975E-05
     +,   5.0428465E-05,   5.1757521E-05,   5.3053634E-05
     +,   5.4304128E-05,   5.5496192E-05,   5.6616969E-05
     +,   5.7653844E-05,   5.8594644E-05,   5.9427774E-05
     +,   6.0142320E-05,   6.0728358E-05,   6.1177037E-05
     +,   6.1480809E-05,   6.1633509E-05,   6.1630628E-05
     +,   6.1469458E-05,   6.1149352E-05,   6.0672108E-05
     +,   6.0042432E-05,   5.9268608E-05,   5.8363672E-05
     +,   5.7346824E-05,   5.6245455E-05,   5.5098080E-05
     +,   5.3958072E-05,   5.2898293E-05,   5.2017054E-05
     +,   5.1444713E-05,   5.1351293E-05,   5.1954132E-05
     +,   5.3525171E-05,   5.6397126E-05,   6.0966577E-05
     +,   6.7694367E-05,   7.7101038E-05,   8.9755704E-05
     +,   1.0625993E-04,   1.2722732E-04,   1.5325626E-04
     +,   1.8489789E-04,   2.2262512E-04,   2.6680523E-04
     +,   3.1767055E-04,   3.7528962E-04,   4.3956103E-04
     +,   5.1019812E-04,   5.8672059E-04,   6.6845788E-04
     +,   7.5456104E-04,   8.4400509E-04,   9.3559228E-04
     +,   1.0279695E-03,   1.1196501E-03,   1.2090263E-03
     +,   1.2943936E-03,   1.3739917E-03,   1.4460607E-03
     +,   1.5088930E-03,   1.5608968E-03,   1.6006794E-03
     +,   1.6271118E-03,   1.6393834E-03,   1.6370524E-03
     +,   1.6200653E-03,   1.5887545E-03,   1.5438210E-03
     +,   1.4862930E-03,   1.4174768E-03,   1.3389023E-03
     +,   1.2522766E-03,   1.1594311E-03,   1.0622675E-03
     +,   9.6271571E-04,   8.6269685E-04,   7.6405337E-04
     +,   6.6850451E-04,   5.7759683E-04,   4.9264397E-04
     +,   4.1467856E-04,   3.4442684E-04,   2.8230090E-04
     +,   2.2839905E-04,   1.8253030E-04,   1.4426159E-04
     +,   1.1297392E-04,   8.7918736E-05,   6.8276531E-05
     +,   5.3213491E-05,   4.1926956E-05,   3.3676068E-05
     +,   2.7805367E-05,   2.3755509E-05,   2.1064307E-05
     +,   1.9361438E-05,   1.8359024E-05,   1.7839437E-05
     +,   1.7642380E-05,   1.7652785E-05,   1.7790038E-05
     +,   1.7998918E-05,   1.8242354E-05,   1.8495923E-05
     +,   1.8743764E-05,   1.8975652E-05,   1.9185049E-05
     +,   1.9367741E-05,   1.9520992E-05,   1.9643005E-05
     +,   1.9732603E-05,   1.9789031E-05,   1.9811840E-05
     +,   1.9800826E-05,   1.9756009E-05,   1.9677595E-05
     +,   1.9565974E-05,   1.9421712E-05,   1.9245537E-05
     +,   1.9038329E-05,   1.8801140E-05,   1.8535140E-05
     +,   1.8241633E-05,   1.7922057E-05,   1.7577961E-05
     +,   1.7210976E-05,   1.6822807E-05,   1.6415255E-05
     +,   1.5990187E-05,   1.5549474E-05,   1.5095021E-05
     +,   1.4628775E-05,   1.4152686E-05,   1.3668664E-05
     +,   1.3178594E-05,   1.2684367E-05,   1.2187786E-05
     +,   1.1690589E-05,   1.1194493E-05,   1.0701118E-05
     +,   1.0211985E-05,   9.7285201E-06,   9.2520841E-06
     +,   8.7839389E-06,   8.3252125E-06,   7.8769272E-06
     +,   7.4400273E-06,   7.0153492E-06,   6.6035923E-06
     +,   6.2053559E-06,   5.8211695E-06,   5.4514235E-06
     +,   5.0964181E-06,   4.7563772E-06,   4.4314393E-06
     +,   4.1216358E-06,   3.8269213E-06,   3.5471996E-06
     +,   3.2823066E-06,   3.0319977E-06,   2.7959777E-06
     +,   2.5739180E-06,   2.3654468E-06,   2.1701410E-06
     +,   1.9875481E-06,   1.8172091E-06,   1.6586256E-06
     +,   1.5112862E-06,   1.3746793E-06,   1.2482842E-06
     +,   1.1315714E-06,   1.0240126E-06,   9.2509174E-07
     +,   8.3429939E-07,   7.5113059E-07,   6.7509296E-07
     +,   6.0571659E-07,   5.4253798E-07,   4.8511924E-07
     +,   4.3303351E-07,   3.8588007E-07,   3.4327164E-07
     +,   3.0484642E-07,   2.7025845E-07,   2.3918557E-07
     +,   2.1132242E-07,   1.8638620E-07,   1.6411131E-07
     +,   1.4425052E-07,   1.2657694E-07,   1.1087820E-07
     +,   9.6960683E-08,   8.4644682E-08,   7.3766934E-08
     +,   6.4176788E-08,   5.5738173E-08,   4.8326097E-08
     +,   4.1828134E-08,   3.6141799E-08,   3.1175215E-08
     +,   2.6844988E-08,   2.3076780E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz85 = Yx/0.01148
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5533101E-06,   1.7071642E-06
     +,   1.8731569E-06,   2.0519067E-06,   2.2440347E-06
     +,   2.4501546E-06,   2.6708740E-06,   2.9067874E-06
     +,   3.1584711E-06,   3.4264956E-06,   3.7113966E-06
     +,   4.0136879E-06,   4.3338546E-06,   4.6723499E-06
     +,   5.0295903E-06,   5.4059542E-06,   5.8017808E-06
     +,   6.2173635E-06,   6.6529551E-06,   7.1087547E-06
     +,   7.5849207E-06,   8.0815589E-06,   8.5987203E-06
     +,   9.1364400E-06,   9.6946424E-06,   1.0273268E-05
     +,   1.0872175E-05,   1.1491181E-05,   1.2130067E-05
     +,   1.2788565E-05,   1.3466365E-05,   1.4163126E-05
     +,   1.4878457E-05,   1.5611942E-05,   1.6363123E-05
     +,   1.7131504E-05,   1.7916565E-05,   1.8717727E-05
     +,   1.9534427E-05,   2.0365980E-05,   2.1211750E-05
     +,   2.2071004E-05,   2.2942972E-05,   2.3826846E-05
     +,   2.4721747E-05,   2.5626745E-05,   2.6540840E-05
     +,   2.7462955E-05,   2.8391943E-05,   2.9326564E-05
     +,   3.0265481E-05,   3.1207266E-05,   3.2150368E-05
     +,   3.3093191E-05,   3.4033896E-05,   3.4970661E-05
     +,   3.5901470E-05,   3.6824200E-05,   3.7736594E-05
     +,   3.8636306E-05,   3.9520855E-05,   4.0387669E-05
     +,   4.1234016E-05,   4.2057160E-05,   4.2854266E-05
     +,   4.3622364E-05,   4.4358552E-05,   4.5059773E-05
     +,   4.5723082E-05,   4.6345438E-05,   4.6923931E-05
     +,   4.7455622E-05,   4.7937734E-05,   4.8367518E-05
     +,   4.8742422E-05,   4.9060025E-05,   4.9318092E-05
     +,   4.9514587E-05,   4.9647704E-05,   4.9715909E-05
     +,   4.9717913E-05,   4.9652728E-05,   4.9519673E-05
     +,   4.9318391E-05,   4.9048856E-05,   4.8711383E-05
     +,   4.8306661E-05,   4.7835700E-05,   4.7299931E-05
     +,   4.6701112E-05,   4.6041387E-05,   4.5323271E-05
     +,   4.4549703E-05,   4.3723954E-05,   4.2849653E-05
     +,   4.1930914E-05,   4.0972143E-05,   3.9978248E-05
     +,   3.8954426E-05,   3.7906429E-05,   3.6840291E-05
     +,   3.5762638E-05,   3.4680401E-05,   3.3601122E-05
     +,   3.2532687E-05,   3.1483469E-05,   3.0462417E-05
     +,   2.9478915E-05,   2.8542776E-05,   2.7664270E-05
     +,   2.6854193E-05,   2.6123664E-05,   2.5484285E-05
     +,   2.4947949E-05,   2.4526968E-05,   2.4233877E-05
     +,   2.4081543E-05,   2.4083009E-05,   2.4251465E-05
     +,   2.4600164E-05,   2.5142315E-05,   2.5890829E-05
     +,   2.6858090E-05,   2.8055705E-05,   2.9494040E-05
     +,   3.1181560E-05,   3.3124565E-05,   3.5326138E-05
     +,   3.7786103E-05,   4.0499974E-05,   4.3459517E-05
     +,   4.6652374E-05,   5.0063936E-05,   5.3678512E-05
     +,   5.7483168E-05,   6.1471575E-05,   6.5648994E-05
     +,   7.0038106E-05,   7.4684795E-05,   7.9662117E-05
     +,   8.5071493E-05,   9.1040929E-05,   9.7718868E-05
     +,   1.0526292E-04,   1.1382524E-04,   1.2354026E-04
     +,   1.3451440E-04,   1.4682484E-04,   1.6053257E-04
     +,   1.7571099E-04,   1.9248472E-04,   2.1107229E-04
     +,   2.3182030E-04,   2.5520966E-04,   2.8181387E-04
     +,   3.1220171E-04,   3.4679996E-04,   3.8575593E-04
     +,   4.2886997E-04,   4.7569149E-04,   5.2588194E-04
     +,   5.7983951E-04,   6.3950918E-04,   7.0916687E-04
     +,   7.9585717E-04,   9.0914569E-04,   1.0599686E-03
     +,   1.2585613E-03,   1.5116807E-03,   1.8195093E-03
     +,   2.1728643E-03,   2.5515517E-03,   2.9247086E-03
     +,   3.2537316E-03,   3.4979829E-03,   3.6225070E-03
     +,   3.6057374E-03,   3.4449487E-03,   3.1574869E-03
     +,   2.7770349E-03,   2.3461778E-03,   1.9076215E-03
     +,   1.4966722E-03,   1.1368680E-03,   8.3930331E-04
     +,   6.0475915E-04,   4.2717555E-04,   2.9715989E-04
     +,   2.0467474E-04,   1.4061113E-04,   9.7415781E-05
     +,   6.9167276E-05,   5.1371808E-05,   4.0690313E-05
     +,   3.4692639E-05,   3.1655934E-05,   3.0397900E-05
     +,   3.0138046E-05,   3.0383091E-05,   3.0834966E-05
     +,   3.1321299E-05,   3.1746389E-05,   3.2059190E-05
     +,   3.2233540E-05,   3.2257070E-05,   3.2125205E-05
     +,   3.1838124E-05,   3.1399344E-05,   3.0815016E-05
     +,   3.0093417E-05,   2.9244698E-05,   2.8280647E-05
     +,   2.7214395E-05,   2.6060021E-05,   2.4832292E-05
     +,   2.3546447E-05,   2.2217813E-05,   2.0861424E-05
     +,   1.9491816E-05,   1.8122922E-05,   1.6767595E-05
     +,   1.5437568E-05,   1.4143387E-05,   1.2894244E-05
     +,   1.1697823E-05,   1.0560375E-05,   9.4868101E-06
     +,   8.4806525E-06,   7.5440562E-06,   6.6779853E-06
     +,   5.8823730E-06,   5.1561810E-06,   4.4974918E-06
     +,   3.9037068E-06,   3.3717295E-06,   2.8979766E-06
     +,   2.4785718E-06,   2.1094759E-06,   1.7865559E-06
     +,   1.5056542E-06,   1.2626940E-06,   1.0537497E-06
     +,   8.7507669E-07,   7.2313827E-07,   5.9464872E-07
     +,   4.8659331E-07,   3.9622435E-07,   3.2105754E-07
     +,   2.5887397E-07,   2.0771283E-07,   1.6584603E-07
     +,   1.3176805E-07,   1.0417937E-07,   8.1964039E-08
     +,   6.4169946E-08,   4.9992313E-08,   3.8756180E-08
     +,   2.9898484E-08,   2.2952170E-08,   1.7533210E-08
     +,   1.3328014E-08,   1.0081846E-08,   7.5889490E-09
     +,   5.6844072E-09,   4.2370143E-09,   3.1426874E-09
     +,   2.3195563E-09,   1.7036301E-09,   1.2451348E-09
     +,   9.0557495E-10,   6.5538125E-10,   4.7198723E-10
     +,   3.3825021E-10,   2.4121977E-10,   1.7117835E-10
     +,   1.2088053E-10,   8.4942595E-11,   5.9397237E-11
     +,   4.1330338E-11,   2.8618235E-11,   1.9718721E-11
     +,   1.3520294E-11,   9.2247538E-12,   6.2631870E-12
     +,   4.2315279E-12,   2.8449261E-12,   1.9033197E-12
     +,   1.2671059E-12,   8.3943453E-13,   5.5337804E-13
     +,   3.6301878E-13,   2.3697217E-13,   1.5393507E-13
     +,   9.9503474E-14,   6.4004669E-14,   4.0968141E-14
     +,   2.6094732E-14,   1.6539435E-14,   1.0431827E-14
     +,   6.5472741E-15,   4.0891617E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz90 = Yx/0.014
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2046349E-06,   2.3883931E-06
     +,   2.5840993E-06,   2.7922129E-06,   3.0131800E-06
     +,   3.2474336E-06,   3.4953891E-06,   3.7574428E-06
     +,   4.0339614E-06,   4.3253012E-06,   4.6317732E-06
     +,   4.9536575E-06,   5.2912019E-06,   5.6446115E-06
     +,   6.0140478E-06,   6.3996249E-06,   6.8014092E-06
     +,   7.2194152E-06,   7.6535962E-06,   8.1038543E-06
     +,   8.5700267E-06,   9.0518879E-06,   9.5491450E-06
     +,   1.0061463E-05,   1.0588389E-05,   1.1129458E-05
     +,   1.1684101E-05,   1.2251689E-05,   1.2831523E-05
     +,   1.3422840E-05,   1.4024804E-05,   1.4636518E-05
     +,   1.5257013E-05,   1.5885264E-05,   1.6520187E-05
     +,   1.7160633E-05,   1.7805411E-05,   1.8453262E-05
     +,   1.9102923E-05,   1.9753013E-05,   2.0402198E-05
     +,   2.1049058E-05,   2.1692160E-05,   2.2330052E-05
     +,   2.2961260E-05,   2.3584300E-05,   2.4197685E-05
     +,   2.4799925E-05,   2.5389540E-05,   2.5965051E-05
     +,   2.6525011E-05,   2.7067987E-05,   2.7592570E-05
     +,   2.8097415E-05,   2.8581164E-05,   2.9042561E-05
     +,   2.9480359E-05,   2.9893388E-05,   3.0280529E-05
     +,   3.0640731E-05,   3.0973006E-05,   3.1276446E-05
     +,   3.1550204E-05,   3.1793534E-05,   3.2005762E-05
     +,   3.2186294E-05,   3.2334625E-05,   3.2450349E-05
     +,   3.2533131E-05,   3.2582746E-05,   3.2599055E-05
     +,   3.2582007E-05,   3.2531658E-05,   3.2448144E-05
     +,   3.2331707E-05,   3.2182652E-05,   3.2001411E-05
     +,   3.1788495E-05,   3.1544489E-05,   3.1270058E-05
     +,   3.0965981E-05,   3.0633073E-05,   3.0272273E-05
     +,   2.9884546E-05,   2.9470961E-05,   2.9032621E-05
     +,   2.8570723E-05,   2.8086479E-05,   2.7581198E-05
     +,   2.7056196E-05,   2.6512818E-05,   2.5952491E-05
     +,   2.5376659E-05,   2.4786761E-05,   2.4184244E-05
     +,   2.3570643E-05,   2.2947395E-05,   2.2316031E-05
     +,   2.1677999E-05,   2.1034804E-05,   2.0387866E-05
     +,   1.9738656E-05,   1.9088538E-05,   1.8438925E-05
     +,   1.7791128E-05,   1.7146422E-05,   1.6506072E-05
     +,   1.5871292E-05,   1.5243210E-05,   1.4622888E-05
     +,   1.4011390E-05,   1.3409641E-05,   1.2818578E-05
     +,   1.2238997E-05,   1.1671696E-05,   1.1117338E-05
     +,   1.0576587E-05,   1.0049966E-05,   9.5380028E-06
     +,   9.0410995E-06,   8.5596066E-06,   8.0938362E-06
     +,   7.6440465E-06,   7.2104144E-06,   6.7930864E-06
     +,   6.3922230E-06,   6.0079365E-06,   5.6404288E-06
     +,   5.2899427E-06,   4.9569294E-06,   4.6420664E-06
     +,   4.3464870E-06,   4.0718974E-06,   3.8209214E-06
     +,   3.5973846E-06,   3.4067928E-06,   3.2568937E-06
     +,   3.1583356E-06,   3.1254340E-06,   3.1770735E-06
     +,   3.3376321E-06,   3.6378865E-06,   4.1158960E-06
     +,   4.8176526E-06,   5.7973120E-06,   7.1171899E-06
     +,   8.8470124E-06,   1.1062363E-05,   1.3842570E-05
     +,   1.7268105E-05,   2.1417209E-05,   2.6362053E-05
     +,   3.2165630E-05,   3.8879785E-05,   4.6543977E-05
     +,   5.5185730E-05,   6.4824642E-05,   7.5479336E-05
     +,   8.7176188E-05,   9.9959259E-05,   1.1390496E-04
     +,   1.2913367E-04,   1.4581915E-04,   1.6419691E-04
     +,   1.8456799E-04,   2.0729529E-04,   2.3279199E-04
     +,   2.6150711E-04,   2.9390553E-04,   3.3043895E-04
     +,   3.7151107E-04,   4.1744090E-04,   4.6842440E-04
     +,   5.2448484E-04,   5.8541744E-04,   6.5074966E-04
     +,   7.1969430E-04,   7.9111150E-04,   8.6350623E-04
     +,   9.3505532E-04,   1.0036661E-03,   1.0670746E-03
     +,   1.1229977E-03,   1.1693061E-03,   1.2042057E-03
     +,   1.2264084E-03,   1.2352719E-03,   1.2308803E-03
     +,   1.2140425E-03,   1.1862243E-03,   1.1493935E-03
     +,   1.1058176E-03,   1.0578384E-03,   1.0076425E-03
     +,   9.5706678E-04,   9.0747402E-04,   8.5969997E-04
     +,   8.1407232E-04,   7.7049603E-04,   7.2859024E-04
     +,   6.8784493E-04,   6.4776430E-04,   6.0798542E-04
     +,   5.6835677E-04,   5.2896899E-04,   4.9012975E-04
     +,   4.5231235E-04,   4.1608029E-04,   3.8200061E-04
     +,   3.5056481E-04,   3.2213153E-04,   2.9689271E-04
     +,   2.7486152E-04,   2.5588350E-04,   2.3966940E-04
     +,   2.2583737E-04,   2.1395576E-04,   2.0358538E-04
     +,   1.9431516E-04,   1.8578865E-04,   1.7771631E-04
     +,   1.6988204E-04,   1.6213993E-04,   1.5440557E-04
     +,   1.4664321E-04,   1.3885340E-04,   1.3106123E-04
     +,   1.2330512E-04,   1.1562824E-04,   1.0807304E-04
     +,   1.0067845E-04,   9.3477669E-05,   8.6497283E-05
     +,   7.9758480E-05,   7.3278519E-05,   6.7070621E-05
     +,   6.1145533E-05,   5.5512537E-05,   5.0179529E-05
     +,   4.5152690E-05,   4.0436869E-05,   3.6035548E-05
     +,   3.1950251E-05,   2.8179980E-05,   2.4721296E-05
     +,   2.1568423E-05,   1.8712948E-05,   1.6143807E-05
     +,   1.3847752E-05,   1.1809835E-05,   1.0013359E-05
     +,   8.4405665E-06,   7.0731326E-06,   5.8924529E-06
     +,   4.8799743E-06,   4.0176310E-06,   3.2881746E-06
     +,   2.6753071E-06,   2.1638286E-06,   1.7397970E-06
     +,   1.3906022E-06,   1.1049378E-06,   8.7276669E-07
     +,   6.8529550E-07,   5.3490947E-07,   4.1504771E-07
     +,   3.2012707E-07,   2.4544335E-07,   1.8706065E-07
     +,   1.4171144E-07,   1.0671050E-07,   7.9870290E-08
     +,   5.9420291E-08,   4.3938275E-08,   3.2292142E-08
     +,   2.3588234E-08,   1.7124631E-08,   1.2355878E-08
     +,   8.8600167E-09,   6.3139942E-09,   4.4716182E-09
     +,   3.1471468E-09,   2.2011133E-09,   1.5298318E-09
     +,   1.0565813E-09,   7.2514122E-10,   4.9452792E-10
     +,   3.3511668E-10,   2.2565368E-10,   1.5097758E-10
     +,   1.0037222E-10,   6.6302165E-11,   4.3517332E-11
     +,   2.8379235E-11,   1.8388735E-11,   1.1838565E-11
     +,   7.5726942E-12,   4.8127453E-12,   3.0390157E-12
     +,   1.9065906E-12,   1.1884356E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ttz95 = Yx/0.00991666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9942694E-05,   4.1531555E-05
     +,   4.3161388E-05,   4.4830493E-05,   4.6536876E-05
     +,   4.8278260E-05,   5.0052131E-05,   5.1855666E-05
     +,   5.3685791E-05,   5.5539200E-05,   5.7412333E-05
     +,   5.9301350E-05,   6.1202234E-05,   6.3110732E-05
     +,   6.5022439E-05,   6.6932786E-05,   6.8837049E-05
     +,   7.0730413E-05,   7.2608003E-05,   7.4464879E-05
     +,   7.6296121E-05,   7.8096782E-05,   7.9862031E-05
     +,   8.1587204E-05,   8.3267601E-05,   8.4898857E-05
     +,   8.6476794E-05,   8.7997461E-05,   8.9457215E-05
     +,   9.0852744E-05,   9.2181093E-05,   9.3439710E-05
     +,   9.4626492E-05,   9.5739699E-05,   9.6778123E-05
     +,   9.7741045E-05,   9.8628268E-05,   9.9439974E-05
     +,   1.0017703E-04,   1.0084065E-04,   1.0143269E-04
     +,   1.0195546E-04,   1.0241166E-04,   1.0280457E-04
     +,   1.0313785E-04,   1.0341552E-04,   1.0364207E-04
     +,   1.0382228E-04,   1.0396118E-04,   1.0406410E-04
     +,   1.0413653E-04,   1.0418419E-04,   1.0421282E-04
     +,   1.0422824E-04,   1.0423629E-04,   1.0424283E-04
     +,   1.0425349E-04,   1.0427384E-04,   1.0430934E-04
     +,   1.0436516E-04,   1.0444624E-04,   1.0455729E-04
     +,   1.0470262E-04,   1.0488646E-04,   1.0511246E-04
     +,   1.0538416E-04,   1.0570472E-04,   1.0607700E-04
     +,   1.0650368E-04,   1.0698706E-04,   1.0752939E-04
     +,   1.0813269E-04,   1.0879895E-04,   1.0953001E-04
     +,   1.1032782E-04,   1.1119440E-04,   1.1213181E-04
     +,   1.1314244E-04,   1.1422893E-04,   1.1539424E-04
     +,   1.1664163E-04,   1.1797496E-04,   1.1939841E-04
     +,   1.2091680E-04,   1.2253529E-04,   1.2425978E-04
     +,   1.2609651E-04,   1.2805233E-04,   1.3013439E-04
     +,   1.3235032E-04,   1.3470814E-04,   1.3721592E-04
     +,   1.3988164E-04,   1.4271356E-04,   1.4571975E-04
     +,   1.4890764E-04,   1.5228453E-04,   1.5585672E-04
     +,   1.5963009E-04,   1.6360925E-04,   1.6779816E-04
     +,   1.7219911E-04,   1.7681389E-04,   1.8164242E-04
     +,   1.8668376E-04,   1.9193612E-04,   1.9739618E-04
     +,   2.0306002E-04,   2.0892348E-04,   2.1498218E-04
     +,   2.2123165E-04,   2.2766851E-04,   2.3428987E-04
     +,   2.4109529E-04,   2.4808536E-04,   2.5526463E-04
     +,   2.6263928E-04,   2.7022013E-04,   2.7802060E-04
     +,   2.8605881E-04,   2.9435643E-04,   3.0293837E-04
     +,   3.1183235E-04,   3.2106927E-04,   3.3068124E-04
     +,   3.4070012E-04,   3.5115756E-04,   3.6208113E-04
     +,   3.7349548E-04,   3.8541789E-04,   3.9785841E-04
     +,   4.1081602E-04,   4.2427948E-04,   4.3822330E-04
     +,   4.5260930E-04,   4.6738450E-04,   4.8248086E-04
     +,   4.9781537E-04,   5.1329366E-04,   5.2880973E-04
     +,   5.4424733E-04,   5.5948412E-04,   5.7439611E-04
     +,   5.8885984E-04,   6.0275535E-04,   6.1597332E-04
     +,   6.2841724E-04,   6.4000650E-04,   6.5068091E-04
     +,   6.6040433E-04,   6.6916581E-04,   6.7698036E-04
     +,   6.8389106E-04,   6.8996812E-04,   6.9530885E-04
     +,   7.0003251E-04,   7.0428097E-04,   7.0821331E-04
     +,   7.1200158E-04,   7.1582664E-04,   7.1987353E-04
     +,   7.2432525E-04,   7.2935887E-04,   7.3514157E-04
     +,   7.4182753E-04,   7.4955792E-04,   7.5846276E-04
     +,   7.6866697E-04,   7.8030291E-04,   7.9352653E-04
     +,   8.0854032E-04,   8.2562194E-04,   8.4515824E-04
     +,   8.6768408E-04,   8.9391257E-04,   9.2477817E-04
     +,   9.6146559E-04,   1.0054376E-03,   1.0584679E-03
     +,   1.1226768E-03,   1.2005804E-03,   1.2951373E-03
     +,   1.4098256E-03,   1.5487251E-03,   1.7166059E-03
     +,   1.9189995E-03,   2.1623073E-03,   2.4539020E-03
     +,   2.8021319E-03,   3.2160466E-03,   3.7047318E-03
     +,   4.2758356E-03,   4.9334108E-03,   5.6756693E-03
     +,   6.4937356E-03,   7.3727765E-03,   8.2966918E-03
     +,   9.2565259E-03,   1.0259636E-02,   1.1332803E-02
     +,   1.2512005E-02,   1.3819691E-02,   1.5247053E-02
     +,   1.6766652E-02,   1.8376712E-02,   2.0132368E-02
     +,   2.2108417E-02,   2.4306124E-02,   2.6603058E-02
     +,   2.8821290E-02,   3.0846665E-02,   3.2649916E-02
     +,   3.4194950E-02,   3.5392188E-02,   3.6187630E-02
     +,   3.6660686E-02,   3.6960118E-02,   3.7124101E-02
     +,   3.7047211E-02,   3.6696639E-02,   3.6267772E-02
     +,   3.6003057E-02,   3.5884906E-02,   3.5580613E-02
     +,   3.4699801E-02,   3.3122092E-02,   3.1109221E-02
     +,   2.9081572E-02,   2.7268056E-02,   2.5594659E-02
     +,   2.3877909E-02,   2.2041028E-02,   2.0136606E-02
     +,   1.8250121E-02,   1.6439762E-02,   1.4741750E-02
     +,   1.3187068E-02,   1.1799145E-02,   1.0583711E-02
     +,   9.5266756E-03,   8.6019281E-03,   7.7827633E-03
     +,   7.0503075E-03,   6.3956385E-03,   5.8165146E-03
     +,   5.3122500E-03,   4.8801331E-03,   4.5146118E-03
     +,   4.2082937E-03,   3.9533223E-03,   3.7421673E-03
     +,   3.5679464E-03,   3.4243697E-03,   3.3055265E-03
     +,   3.2057518E-03,   3.1195441E-03,   3.0416376E-03
     +,   2.9670896E-03,   2.8914940E-03,   2.8111755E-03
     +,   2.7233867E-03,   2.6264121E-03,   2.5195810E-03
     +,   2.4032188E-03,   2.2785023E-03,   2.1472422E-03
     +,   2.0116570E-03,   1.8741551E-03,   1.7371167E-03
     +,   1.6027127E-03,   1.4727991E-03,   1.3488536E-03
     +,   1.2319473E-03,   1.1227510E-03,   1.0215899E-03
     +,   9.2850887E-04,   8.4331504E-04,   7.6566404E-04
     +,   6.9509260E-04,   6.3108583E-04,   5.7309354E-04
     +,   5.2057236E-04,   4.7299138E-04,   4.2985540E-04
     +,   3.9070167E-04,   3.5511362E-04,   3.2271360E-04
     +,   2.9316684E-04,   2.6618195E-04,   2.4150121E-04
     +,   2.1890501E-04,   1.9820100E-04,   1.7922594E-04
     +,   1.6183637E-04,   1.4590954E-04,   1.3133536E-04
     +,   1.1801737E-04,   1.0586643E-04,   9.4801930E-05
     +,   8.4747051E-05,   7.5630735E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz100 = Yx/0.3058125
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3851462E-05,   2.4564266E-05
     +,   2.5300491E-05,   2.6060685E-05,   2.6845384E-05
     +,   2.7655049E-05,   2.8490118E-05,   2.9350967E-05
     +,   3.0237909E-05,   3.1151245E-05,   3.2091142E-05
     +,   3.3057724E-05,   3.4051016E-05,   3.5071003E-05
     +,   3.6117515E-05,   3.7190344E-05,   3.8289159E-05
     +,   3.9413528E-05,   4.0562918E-05,   4.1736701E-05
     +,   4.2934145E-05,   4.4154385E-05,   4.5396468E-05
     +,   4.6659399E-05,   4.7941961E-05,   4.9242957E-05
     +,   5.0561081E-05,   5.1894902E-05,   5.3242977E-05
     +,   5.4603814E-05,   5.5975815E-05,   5.7357433E-05
     +,   5.8747093E-05,   6.0143208E-05,   6.1544226E-05
     +,   6.2948719E-05,   6.4355219E-05,   6.5762477E-05
     +,   6.7169341E-05,   6.8574751E-05,   6.9977963E-05
     +,   7.1378367E-05,   7.2775620E-05,   7.4169649E-05
     +,   7.5560754E-05,   7.6949465E-05,   7.8336809E-05
     +,   7.9724094E-05,   8.1113125E-05,   8.2506092E-05
     +,   8.3905674E-05,   8.5314983E-05,   8.6737637E-05
     +,   8.8177760E-05,   8.9639812E-05,   9.1128917E-05
     +,   9.2650444E-05,   9.4210285E-05,   9.5814663E-05
     +,   9.7470169E-05,   9.9183606E-05,   1.0096210E-04
     +,   1.0281267E-04,   1.0474267E-04,   1.0675933E-04
     +,   1.0886952E-04,   1.1108020E-04,   1.1339765E-04
     +,   1.1582790E-04,   1.1837617E-04,   1.2104709E-04
     +,   1.2384423E-04,   1.2677051E-04,   1.2982724E-04
     +,   1.3301484E-04,   1.3633246E-04,   1.3977758E-04
     +,   1.4334607E-04,   1.4703255E-04,   1.5082996E-04
     +,   1.5472925E-04,   1.5872016E-04,   1.6279043E-04
     +,   1.6692652E-04,   1.7111305E-04,   1.7533367E-04
     +,   1.7957011E-04,   1.8380377E-04,   1.8801428E-04
     +,   1.9218099E-04,   1.9628290E-04,   2.0029800E-04
     +,   2.0420460E-04,   2.0798136E-04,   2.1160729E-04
     +,   2.1506177E-04,   2.1832585E-04,   2.2138102E-04
     +,   2.2421098E-04,   2.2680043E-04,   2.2913661E-04
     +,   2.3120845E-04,   2.3300743E-04,   2.3452695E-04
     +,   2.3576344E-04,   2.3671545E-04,   2.3738439E-04
     +,   2.3777386E-04,   2.3789032E-04,   2.3774240E-04
     +,   2.3734148E-04,   2.3670067E-04,   2.3583537E-04
     +,   2.3476291E-04,   2.3350219E-04,   2.3207377E-04
     +,   2.3049937E-04,   2.2880174E-04,   2.2700465E-04
     +,   2.2513229E-04,   2.2320944E-04,   2.2126103E-04
     +,   2.1931222E-04,   2.1738795E-04,   2.1551273E-04
     +,   2.1371101E-04,   2.1200658E-04,   2.1042279E-04
     +,   2.0898212E-04,   2.0770656E-04,   2.0661733E-04
     +,   2.0573492E-04,   2.0507888E-04,   2.0466821E-04
     +,   2.0452111E-04,   2.0465482E-04,   2.0508606E-04
     +,   2.0583066E-04,   2.0690379E-04,   2.0831966E-04
     +,   2.1009188E-04,   2.1223306E-04,   2.1475491E-04
     +,   2.1766844E-04,   2.2098314E-04,   2.2470765E-04
     +,   2.2884946E-04,   2.3341419E-04,   2.3840601E-04
     +,   2.4382774E-04,   2.4968031E-04,   2.5596240E-04
     +,   2.6267034E-04,   2.6979920E-04,   2.7734140E-04
     +,   2.8528736E-04,   2.9362482E-04,   3.0234086E-04
     +,   3.1142074E-04,   3.2084846E-04,   3.3060828E-04
     +,   3.4068519E-04,   3.5106554E-04,   3.6173867E-04
     +,   3.7269891E-04,   3.8394736E-04,   3.9549291E-04
     +,   4.0735450E-04,   4.1956551E-04,   4.3217494E-04
     +,   4.4524964E-04,   4.5887707E-04,   4.7316993E-04
     +,   4.8826772E-04,   5.0433743E-04,   5.2157807E-04
     +,   5.4022216E-04,   5.6053372E-04,   5.8280921E-04
     +,   6.0737744E-04,   6.3459371E-04,   6.6483155E-04
     +,   6.9847499E-04,   7.3590834E-04,   7.7750022E-04
     +,   8.2358188E-04,   8.7443355E-04,   9.3027146E-04
     +,   9.9123653E-04,   1.0573857E-03,   1.1287176E-03
     +,   1.2052011E-03,   1.2868232E-03,   1.3736784E-03
     +,   1.4660794E-03,   1.5646850E-03,   1.6706340E-03
     +,   1.7856885E-03,   1.9123324E-03,   2.0537795E-03
     +,   2.2138532E-03,   2.3967340E-03,   2.6065763E-03
     +,   2.8470864E-03,   3.1211663E-03,   3.4309584E-03
     +,   3.7782101E-03,   4.1648690E-03,   4.5936620E-03
     +,   5.0681569E-03,   5.5922884E-03,   6.1701229E-03
     +,   6.8073152E-03,   7.5148158E-03,   8.3137844E-03
     +,   9.2384554E-03,   1.0333798E-02,   1.1646869E-02
     +,   1.3214095E-02,   1.5049099E-02,   1.7135262E-02
     +,   1.9422557E-02,   2.1828301E-02,   2.4250396E-02
     +,   2.6605876E-02,   2.8879356E-02,   3.1121496E-02
     +,   3.3359453E-02,   3.5502180E-02,   3.7386362E-02
     +,   3.8956963E-02,   4.0355776E-02,   4.1733950E-02
     +,   4.2949066E-02,   4.3558650E-02,   4.3227091E-02
     +,   4.2084217E-02,   4.0580075E-02,   3.9033942E-02
     +,   3.7435103E-02,   3.5633031E-02,   3.3559956E-02
     +,   3.1256329E-02,   2.8825931E-02,   2.6414612E-02
     +,   2.4148546E-02,   2.2060199E-02,   2.0098126E-02
     +,   1.8204387E-02,   1.6371248E-02,   1.4644230E-02
     +,   1.3094183E-02,   1.1782370E-02,   1.0732678E-02
     +,   9.9208029E-03,   9.2844125E-03,   8.7473365E-03
     +,   8.2445890E-03,   7.7370461E-03,   7.2125560E-03
     +,   6.6780248E-03,   6.1488650E-03,   5.6406185E-03
     +,   5.1644258E-03,   4.7257696E-03,   4.3252208E-03
     +,   3.9601722E-03,   3.6266572E-03,   3.3206397E-03
     +,   3.0387896E-03,   2.7787066E-03,   2.5388459E-03
     +,   2.3181909E-03,   2.1159390E-03,   1.9312664E-03
     +,   1.7632146E-03,   1.6106036E-03,   1.4721130E-03
     +,   1.3463113E-03,   1.2317713E-03,   1.1271156E-03
     +,   1.0310991E-03,   9.4262196E-04,   8.6076761E-04
     +,   7.8478456E-04,   7.1409461E-04,   6.4825744E-04
     +,   5.8695214E-04,   5.2995572E-04,   4.7710026E-04
     +,   4.2826348E-04,   3.8333217E-04,   3.4219847E-04
     +,   3.0473588E-04,   2.7080296E-04,   2.4023093E-04
     +,   2.1283299E-04,   1.8839988E-04,   1.6671205E-04
     +,   1.4753832E-04,   1.3064803E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz104 = Yx/0.304872340425532
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.1466784E-05,   5.3464071E-05
     +,   5.5527864E-05,   5.7658028E-05,   5.9854134E-05
     +,   6.2115374E-05,   6.4440552E-05,   6.6828055E-05
     +,   6.9275848E-05,   7.1781520E-05,   7.4342141E-05
     +,   7.6954333E-05,   7.9614219E-05,   8.2317507E-05
     +,   8.5059386E-05,   8.7834604E-05,   9.0637470E-05
     +,   9.3461822E-05,   9.6301184E-05,   9.9148579E-05
     +,   1.0199677E-04,   1.0483813E-04,   1.0766481E-04
     +,   1.1046886E-04,   1.1324188E-04,   1.1597566E-04
     +,   1.1866174E-04,   1.2129175E-04,   1.2385732E-04
     +,   1.2635032E-04,   1.2876271E-04,   1.3108680E-04
     +,   1.3331522E-04,   1.3544098E-04,   1.3745749E-04
     +,   1.3935885E-04,   1.4113952E-04,   1.4279474E-04
     +,   1.4432042E-04,   1.4571300E-04,   1.4696991E-04
     +,   1.4808920E-04,   1.4906976E-04,   1.4991131E-04
     +,   1.5061436E-04,   1.5118025E-04,   1.5161105E-04
     +,   1.5190987E-04,   1.5208026E-04,   1.5212677E-04
     +,   1.5205450E-04,   1.5186933E-04,   1.5157768E-04
     +,   1.5118654E-04,   1.5070349E-04,   1.5013642E-04
     +,   1.4949367E-04,   1.4878396E-04,   1.4801614E-04
     +,   1.4719933E-04,   1.4634275E-04,   1.4545552E-04
     +,   1.4454700E-04,   1.4362620E-04,   1.4270206E-04
     +,   1.4178346E-04,   1.4087869E-04,   1.3999609E-04
     +,   1.3914330E-04,   1.3832774E-04,   1.3755634E-04
     +,   1.3683549E-04,   1.3617110E-04,   1.3556860E-04
     +,   1.3503272E-04,   1.3456780E-04,   1.3417748E-04
     +,   1.3386483E-04,   1.3363243E-04,   1.3348219E-04
     +,   1.3341557E-04,   1.3343335E-04,   1.3353587E-04
     +,   1.3372301E-04,   1.3399398E-04,   1.3434776E-04
     +,   1.3478266E-04,   1.3529681E-04,   1.3588787E-04
     +,   1.3655305E-04,   1.3728943E-04,   1.3809369E-04
     +,   1.3896225E-04,   1.3989140E-04,   1.4087716E-04
     +,   1.4191543E-04,   1.4300199E-04,   1.4413246E-04
     +,   1.4530242E-04,   1.4650746E-04,   1.4774305E-04
     +,   1.4900470E-04,   1.5028808E-04,   1.5158860E-04
     +,   1.5290205E-04,   1.5422427E-04,   1.5555101E-04
     +,   1.5687838E-04,   1.5820246E-04,   1.5951971E-04
     +,   1.6082672E-04,   1.6212009E-04,   1.6339697E-04
     +,   1.6465454E-04,   1.6589041E-04,   1.6710239E-04
     +,   1.6828858E-04,   1.6944770E-04,   1.7057842E-04
     +,   1.7168021E-04,   1.7275276E-04,   1.7379624E-04
     +,   1.7481131E-04,   1.7579921E-04,   1.7676184E-04
     +,   1.7770143E-04,   1.7862095E-04,   1.7952401E-04
     +,   1.8041498E-04,   1.8129878E-04,   1.8218110E-04
     +,   1.8306842E-04,   1.8396795E-04,   1.8488763E-04
     +,   1.8583606E-04,   1.8682278E-04,   1.8785789E-04
     +,   1.8895224E-04,   1.9011724E-04,   1.9136509E-04
     +,   1.9270832E-04,   1.9415989E-04,   1.9573336E-04
     +,   1.9744235E-04,   1.9930076E-04,   2.0132260E-04
     +,   2.0352175E-04,   2.0591197E-04,   2.0850674E-04
     +,   2.1131929E-04,   2.1436266E-04,   2.1764904E-04
     +,   2.2119033E-04,   2.2499810E-04,   2.2908354E-04
     +,   2.3345767E-04,   2.3813083E-04,   2.4311437E-04
     +,   2.4841982E-04,   2.5405909E-04,   2.6004596E-04
     +,   2.6639589E-04,   2.7312650E-04,   2.8025833E-04
     +,   2.8781602E-04,   2.9582862E-04,   3.0432997E-04
     +,   3.1335955E-04,   3.2296398E-04,   3.3319715E-04
     +,   3.4411979E-04,   3.5580047E-04,   3.6831686E-04
     +,   3.8175483E-04,   3.9620668E-04,   4.1177426E-04
     +,   4.2856560E-04,   4.4669444E-04,   4.6627963E-04
     +,   4.8744431E-04,   5.1031663E-04,   5.3502468E-04
     +,   5.6169997E-04,   5.9047714E-04,   6.2149734E-04
     +,   6.5490796E-04,   6.9086940E-04,   7.2956440E-04
     +,   7.7120680E-04,   8.1604678E-04,   8.6438924E-04
     +,   9.1660093E-04,   9.7311323E-04,   1.0344227E-03
     +,   1.1010881E-03,   1.1737056E-03,   1.2528709E-03
     +,   1.3391443E-03,   1.4330107E-03,   1.5348458E-03
     +,   1.6448868E-03,   1.7632584E-03,   1.8900344E-03
     +,   2.0253281E-03,   2.1693925E-03,   2.3227648E-03
     +,   2.4863305E-03,   2.6613027E-03,   2.8491181E-03
     +,   3.0512116E-03,   3.2686922E-03,   3.5019917E-03
     +,   3.7506509E-03,   4.0133903E-03,   4.2886254E-03
     +,   4.5757685E-03,   4.8775729E-03,   5.2034156E-03
     +,   5.5727693E-03,   6.0169823E-03,   6.5770387E-03
     +,   7.2950013E-03,   8.2006073E-03,   9.2985835E-03
     +,   1.0564672E-02,   1.1954825E-02,   1.3422935E-02
     +,   1.4936347E-02,   1.6480295E-02,   1.8057495E-02
     +,   1.9699790E-02,   2.1495299E-02,   2.3589952E-02
     +,   2.6106276E-02,   2.9004056E-02,   3.2034893E-02
     +,   3.4891620E-02,   3.7397988E-02,   3.9500851E-02
     +,   4.1121487E-02,   4.2148873E-02,   4.2621691E-02
     +,   4.2836379E-02,   4.3162622E-02,   4.3666594E-02
     +,   4.3917961E-02,   4.3259636E-02,   4.1327432E-02
     +,   3.8302701E-02,   3.4714945E-02,   3.1095881E-02
     +,   2.7789982E-02,   2.4946168E-02,   2.2587614E-02
     +,   2.0673433E-02,   1.9116506E-02,   1.7786814E-02
     +,   1.6545950E-02,   1.5300211E-02,   1.4024004E-02
     +,   1.2740417E-02,   1.1487578E-02,   1.0298986E-02
     +,   9.1997832E-03,   8.2069319E-03,   7.3268595E-03
     +,   6.5540168E-03,   5.8734212E-03,   5.2664257E-03
     +,   4.7166776E-03,   4.2133546E-03,   3.7512493E-03
     +,   3.3288549E-03,   2.9460739E-03,   2.6026063E-03
     +,   2.2971903E-03,   2.0274422E-03,   1.7902646E-03
     +,   1.5821735E-03,   1.3997375E-03,   1.2397423E-03
     +,   1.0993542E-03,   9.7609067E-04,   8.6782244E-04
     +,   7.7268353E-04,   6.8904890E-04,   6.1546743E-04
     +,   5.5064796E-04,   4.9344584E-04,   4.4284135E-04
     +,   3.9794610E-04,   3.5798360E-04,   3.2229230E-04
     +,   2.9030442E-04,   2.6154440E-04,   2.3560847E-04
     +,   2.1216126E-04,   1.9091865E-04,   1.7164472E-04
     +,   1.5413806E-04,   1.3823055E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz106 = Yx/0.299808510638298
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2136678E-05,   5.4125878E-05
     +,   5.6152916E-05,   5.8216538E-05,   6.0315404E-05
     +,   6.2448045E-05,   6.4612876E-05,   6.6808185E-05
     +,   6.9032169E-05,   7.1282971E-05,   7.3558505E-05
     +,   7.5856638E-05,   7.8175151E-05,   8.0511665E-05
     +,   8.2863771E-05,   8.5228952E-05,   8.7604552E-05
     +,   8.9987901E-05,   9.2376256E-05,   9.4766765E-05
     +,   9.7156539E-05,   9.9542638E-05,   1.0192209E-04
     +,   1.0429197E-04,   1.0664906E-04,   1.0899045E-04
     +,   1.1131311E-04,   1.1361390E-04,   1.1588984E-04
     +,   1.1813788E-04,   1.2035508E-04,   1.2253845E-04
     +,   1.2468506E-04,   1.2679210E-04,   1.2885679E-04
     +,   1.3087633E-04,   1.3284813E-04,   1.3476952E-04
     +,   1.3663813E-04,   1.3845142E-04,   1.4020709E-04
     +,   1.4190300E-04,   1.4353686E-04,   1.4510668E-04
     +,   1.4661044E-04,   1.4804641E-04,   1.4941272E-04
     +,   1.5070775E-04,   1.5192995E-04,   1.5307785E-04
     +,   1.5415011E-04,   1.5514543E-04,   1.5606274E-04
     +,   1.5690099E-04,   1.5765919E-04,   1.5833662E-04
     +,   1.5893258E-04,   1.5944641E-04,   1.5987779E-04
     +,   1.6022635E-04,   1.6049191E-04,   1.6067445E-04
     +,   1.6077407E-04,   1.6079110E-04,   1.6072595E-04
     +,   1.6057925E-04,   1.6035174E-04,   1.6004451E-04
     +,   1.5965867E-04,   1.5919562E-04,   1.5865699E-04
     +,   1.5804447E-04,   1.5736019E-04,   1.5660645E-04
     +,   1.5578564E-04,   1.5490048E-04,   1.5395389E-04
     +,   1.5294917E-04,   1.5188959E-04,   1.5077878E-04
     +,   1.4962071E-04,   1.4841929E-04,   1.4717889E-04
     +,   1.4590383E-04,   1.4459892E-04,   1.4326874E-04
     +,   1.4191843E-04,   1.4055299E-04,   1.3917763E-04
     +,   1.3779773E-04,   1.3641856E-04,   1.3504564E-04
     +,   1.3368452E-04,   1.3234065E-04,   1.3101957E-04
     +,   1.2972677E-04,   1.2846776E-04,   1.2724787E-04
     +,   1.2607248E-04,   1.2494685E-04,   1.2387603E-04
     +,   1.2286507E-04,   1.2191876E-04,   1.2104188E-04
     +,   1.2023890E-04,   1.1951412E-04,   1.1887174E-04
     +,   1.1831576E-04,   1.1784986E-04,   1.1747763E-04
     +,   1.1720241E-04,   1.1702730E-04,   1.1695527E-04
     +,   1.1698891E-04,   1.1713077E-04,   1.1738307E-04
     +,   1.1774787E-04,   1.1822701E-04,   1.1882206E-04
     +,   1.1953436E-04,   1.2036519E-04,   1.2131545E-04
     +,   1.2238584E-04,   1.2357689E-04,   1.2488893E-04
     +,   1.2632192E-04,   1.2787573E-04,   1.2954982E-04
     +,   1.3134364E-04,   1.3325608E-04,   1.3528597E-04
     +,   1.3743171E-04,   1.3969162E-04,   1.4206336E-04
     +,   1.4454457E-04,   1.4713260E-04,   1.4982422E-04
     +,   1.5261582E-04,   1.5550377E-04,   1.5848399E-04
     +,   1.6155186E-04,   1.6470253E-04,   1.6793086E-04
     +,   1.7123160E-04,   1.7459874E-04,   1.7802644E-04
     +,   1.8150867E-04,   1.8503888E-04,   1.8861066E-04
     +,   1.9221766E-04,   1.9585353E-04,   1.9951191E-04
     +,   2.0318675E-04,   2.0687227E-04,   2.1056365E-04
     +,   2.1425587E-04,   2.1794517E-04,   2.2162848E-04
     +,   2.2530407E-04,   2.2897078E-04,   2.3262929E-04
     +,   2.3628183E-04,   2.3993195E-04,   2.4358479E-04
     +,   2.4724827E-04,   2.5093177E-04,   2.5464725E-04
     +,   2.5840866E-04,   2.6223273E-04,   2.6613928E-04
     +,   2.7015025E-04,   2.7429062E-04,   2.7858929E-04
     +,   2.8307797E-04,   2.8779253E-04,   2.9277321E-04
     +,   2.9806528E-04,   3.0371963E-04,   3.0979369E-04
     +,   3.1635369E-04,   3.2347545E-04,   3.3124638E-04
     +,   3.3976760E-04,   3.4915761E-04,   3.5955542E-04
     +,   3.7112230E-04,   3.8404617E-04,   3.9854660E-04
     +,   4.1487650E-04,   4.3332411E-04,   4.5421688E-04
     +,   4.7792061E-04,   5.0483632E-04,   5.3539604E-04
     +,   5.7005853E-04,   6.0929667E-04,   6.5358152E-04
     +,   7.0336909E-04,   7.5908529E-04,   8.2110678E-04
     +,   8.8974054E-04,   9.6521812E-04,   1.0476909E-03
     +,   1.1372297E-03,   1.2338257E-03,   1.3374189E-03
     +,   1.4479109E-03,   1.5651776E-03,   1.6890811E-03
     +,   1.8194853E-03,   1.9562268E-03,   2.0990812E-03
     +,   2.2477242E-03,   2.4017207E-03,   2.5605196E-03
     +,   2.7235372E-03,   2.8903680E-03,   3.0611814E-03
     +,   3.2372025E-03,   3.4213637E-03,   3.6189293E-03
     +,   3.8379007E-03,   4.0889834E-03,   4.3849591E-03
     +,   4.7395364E-03,   5.1660626E-03,   5.6767296E-03
     +,   6.2830010E-03,   6.9968482E-03,   7.8313099E-03
     +,   8.7990444E-03,   9.9097025E-03,   1.1170028E-02
     +,   1.2589053E-02,   1.4183825E-02,   1.5974313E-02
     +,   1.7963387E-02,   2.0121628E-02,   2.2400469E-02
     +,   2.4763001E-02,   2.7191026E-02,   2.9658642E-02
     +,   3.2104969E-02,   3.4410439E-02,   3.6369372E-02
     +,   3.7758730E-02,   3.8585596E-02,   3.9277963E-02
     +,   4.0430963E-02,   4.2231396E-02,   4.4243462E-02
     +,   4.5803923E-02,   4.6459362E-02,   4.6022806E-02
     +,   4.4491585E-02,   4.2070467E-02,   3.9161112E-02
     +,   3.6173694E-02,   3.3307612E-02,   3.0533731E-02
     +,   2.7764255E-02,   2.5003919E-02,   2.2361448E-02
     +,   1.9967264E-02,   1.7895622E-02,   1.6144529E-02
     +,   1.4661320E-02,   1.3375001E-02,   1.2216790E-02
     +,   1.1132600E-02,   1.0090929E-02,   9.0829683E-03
     +,   8.1151333E-03,   7.1990862E-03,   6.3447044E-03
     +,   5.5576288E-03,   4.8394124E-03,   4.1891043E-03
     +,   3.6042174E-03,   3.0817077E-03,   2.6182698E-03
     +,   2.2106722E-03,   1.8555998E-03,   1.5496003E-03
     +,   1.2888181E-03,   1.0690020E-03,   8.8550366E-04
     +,   7.3349464E-04,   6.0821796E-04,   5.0519430E-04
     +,   4.2044031E-04,   3.5054091E-04,   2.9269265E-04
     +,   2.4464208E-04,   2.0461937E-04,   1.7122961E-04
     +,   1.4337340E-04,   1.2016031E-04,   1.0085876E-04
     +,   8.4849496E-05,   7.1604081E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz108 = Yx/0.306395833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8238282E-05,   6.9761278E-05
     +,   7.1281902E-05,   7.2799259E-05,   7.4312527E-05
     +,   7.5820935E-05,   7.7323799E-05,   7.8820442E-05
     +,   8.0310325E-05,   8.1792969E-05,   8.3267936E-05
     +,   8.4734864E-05,   8.6193446E-05,   8.7643457E-05
     +,   8.9084759E-05,   9.0517227E-05,   9.1940805E-05
     +,   9.3355484E-05,   9.4761308E-05,   9.6158350E-05
     +,   9.7546712E-05,   9.8926561E-05,   1.0029795E-04
     +,   1.0166115E-04,   1.0301620E-04,   1.0436330E-04
     +,   1.0570260E-04,   1.0703412E-04,   1.0835793E-04
     +,   1.0967417E-04,   1.1098265E-04,   1.1228336E-04
     +,   1.1357618E-04,   1.1486087E-04,   1.1613714E-04
     +,   1.1740463E-04,   1.1866292E-04,   1.1991146E-04
     +,   1.2114979E-04,   1.2237704E-04,   1.2359265E-04
     +,   1.2479574E-04,   1.2598552E-04,   1.2716097E-04
     +,   1.2832116E-04,   1.2946516E-04,   1.3059190E-04
     +,   1.3170039E-04,   1.3278965E-04,   1.3385862E-04
     +,   1.3490641E-04,   1.3593212E-04,   1.3693490E-04
     +,   1.3791415E-04,   1.3886916E-04,   1.3979954E-04
     +,   1.4070494E-04,   1.4158520E-04,   1.4244042E-04
     +,   1.4327078E-04,   1.4407674E-04,   1.4485905E-04
     +,   1.4561851E-04,   1.4635635E-04,   1.4707397E-04
     +,   1.4777300E-04,   1.4845531E-04,   1.4912307E-04
     +,   1.4977861E-04,   1.5042450E-04,   1.5106353E-04
     +,   1.5169865E-04,   1.5233297E-04,   1.5296970E-04
     +,   1.5361219E-04,   1.5426383E-04,   1.5492810E-04
     +,   1.5560827E-04,   1.5630785E-04,   1.5703004E-04
     +,   1.5777793E-04,   1.5855455E-04,   1.5936251E-04
     +,   1.6020436E-04,   1.6108218E-04,   1.6199781E-04
     +,   1.6295259E-04,   1.6394768E-04,   1.6498346E-04
     +,   1.6606013E-04,   1.6717735E-04,   1.6833424E-04
     +,   1.6952932E-04,   1.7076083E-04,   1.7202641E-04
     +,   1.7332319E-04,   1.7464806E-04,   1.7599711E-04
     +,   1.7736638E-04,   1.7875135E-04,   1.8014747E-04
     +,   1.8154962E-04,   1.8295269E-04,   1.8435137E-04
     +,   1.8574037E-04,   1.8711426E-04,   1.8846792E-04
     +,   1.8979596E-04,   1.9109366E-04,   1.9235630E-04
     +,   1.9357944E-04,   1.9475931E-04,   1.9589247E-04
     +,   1.9697570E-04,   1.9800672E-04,   1.9898366E-04
     +,   1.9990519E-04,   2.0077078E-04,   2.0158045E-04
     +,   2.0233484E-04,   2.0303542E-04,   2.0368422E-04
     +,   2.0428385E-04,   2.0483772E-04,   2.0534990E-04
     +,   2.0582476E-04,   2.0626733E-04,   2.0668347E-04
     +,   2.0707921E-04,   2.0746108E-04,   2.0783622E-04
     +,   2.0821190E-04,   2.0859590E-04,   2.0899638E-04
     +,   2.0942152E-04,   2.0988012E-04,   2.1038089E-04
     +,   2.1093275E-04,   2.1154499E-04,   2.1222708E-04
     +,   2.1298838E-04,   2.1383828E-04,   2.1478666E-04
     +,   2.1584331E-04,   2.1701770E-04,   2.1831956E-04
     +,   2.1975885E-04,   2.2134502E-04,   2.2308751E-04
     +,   2.2499566E-04,   2.2707864E-04,   2.2934513E-04
     +,   2.3180345E-04,   2.3446175E-04,   2.3732767E-04
     +,   2.4040793E-04,   2.4370874E-04,   2.4723582E-04
     +,   2.5099399E-04,   2.5498727E-04,   2.5921859E-04
     +,   2.6369066E-04,   2.6840446E-04,   2.7336061E-04
     +,   2.7855879E-04,   2.8399818E-04,   2.8967709E-04
     +,   2.9559305E-04,   3.0174377E-04,   3.0812691E-04
     +,   3.1473945E-04,   3.2157925E-04,   3.2864494E-04
     +,   3.3593600E-04,   3.4345285E-04,   3.5119796E-04
     +,   3.5917596E-04,   3.6739351E-04,   3.7585982E-04
     +,   3.8458777E-04,   3.9359339E-04,   4.0289623E-04
     +,   4.1251973E-04,   4.2249059E-04,   4.3284087E-04
     +,   4.4360460E-04,   4.5481900E-04,   4.6652483E-04
     +,   4.7876508E-04,   4.9158162E-04,   5.0501822E-04
     +,   5.1911653E-04,   5.3391483E-04,   5.4944743E-04
     +,   5.6574470E-04,   5.8283075E-04,   6.0072250E-04
     +,   6.1943056E-04,   6.3896202E-04,   6.5931899E-04
     +,   6.8050344E-04,   7.0251658E-04,   7.2536897E-04
     +,   7.4908184E-04,   7.7368837E-04,   7.9924788E-04
     +,   8.2584505E-04,   8.5359765E-04,   8.8266411E-04
     +,   9.1325201E-04,   9.4563124E-04,   9.8013668E-04
     +,   1.0171935E-03,   1.0573375E-03,   1.1012467E-03
     +,   1.1497763E-03,   1.2040199E-03,   1.2653819E-03
     +,   1.3356559E-03,   1.4171051E-03,   1.5125552E-03
     +,   1.6254336E-03,   1.7597622E-03,   1.9200741E-03
     +,   2.1112529E-03,   2.3382574E-03,   2.6057684E-03
     +,   2.9177882E-03,   3.2772764E-03,   3.6857431E-03
     +,   4.1428814E-03,   4.6463506E-03,   5.1916591E-03
     +,   5.7722959E-03,   6.3803545E-03,   7.0082201E-03
     +,   7.6509388E-03,   8.3092935E-03,   8.9925425E-03
     +,   9.7202677E-03,   1.0523190E-02,   1.1444573E-02
     +,   1.2543698E-02,   1.3899614E-02,   1.5606754E-02
     +,   1.7753161E-02,   2.0380957E-02,   2.3446625E-02
     +,   2.6804065E-02,   3.0221630E-02,   3.3427622E-02
     +,   3.6181856E-02,   3.8374271E-02,   4.0104117E-02
     +,   4.1647937E-02,   4.3299846E-02,   4.5187768E-02
     +,   4.7167573E-02,   4.8849437E-02,   4.9774464E-02
     +,   4.9590502E-02,   4.8106823E-02,   4.5385119E-02
     +,   4.1877821E-02,   3.8271070E-02,   3.5036523E-02
     +,   3.2198906E-02,   2.9529927E-02,   2.6861284E-02
     +,   2.4206491E-02,   2.1677662E-02,   1.9350711E-02
     +,   1.7210582E-02,   1.5195983E-02,   1.3272682E-02
     +,   1.1464260E-02,   9.8282313E-03,   8.4125968E-03
     +,   7.2275950E-03,   6.2465467E-03,   5.4239011E-03
     +,   4.7152275E-03,   4.0879608E-03,   3.5233123E-03
     +,   3.0126891E-03,   2.5533275E-03,   2.1445763E-03
     +,   1.7857651E-03,   1.4752143E-03,   1.2099590E-03
     +,   9.8607002E-04,   7.9902075E-04,   6.4416224E-04
     +,   5.1698909E-04,   4.1336293E-04,   3.2955568E-04
     +,   2.6228806E-04,   2.0868728E-04,   1.6627478E-04
     +,   1.3292197E-04,   1.0683138E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz110 = Yx/0.30275
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5977594E-05,   7.8401354E-05
     +,   8.0863618E-05,   8.3363040E-05,   8.5898144E-05
     +,   8.8467554E-05,   9.1069589E-05,   9.3702707E-05
     +,   9.6365155E-05,   9.9055360E-05,   1.0177158E-04
     +,   1.0451205E-04,   1.0727510E-04,   1.1005887E-04
     +,   1.1286174E-04,   1.1568198E-04,   1.1851795E-04
     +,   1.2136805E-04,   1.2423073E-04,   1.2710455E-04
     +,   1.2998802E-04,   1.3287997E-04,   1.3577897E-04
     +,   1.3868421E-04,   1.4159434E-04,   1.4450875E-04
     +,   1.4742654E-04,   1.5034704E-04,   1.5326968E-04
     +,   1.5619399E-04,   1.5911966E-04,   1.6204652E-04
     +,   1.6497435E-04,   1.6790313E-04,   1.7083285E-04
     +,   1.7376375E-04,   1.7669590E-04,   1.7962948E-04
     +,   1.8256494E-04,   1.8550221E-04,   1.8844180E-04
     +,   1.9138391E-04,   1.9432869E-04,   1.9727641E-04
     +,   2.0022705E-04,   2.0318065E-04,   2.0613718E-04
     +,   2.0909634E-04,   2.1205777E-04,   2.1502098E-04
     +,   2.1798527E-04,   2.2094976E-04,   2.2391326E-04
     +,   2.2687476E-04,   2.2983232E-04,   2.3278443E-04
     +,   2.3572898E-04,   2.3866352E-04,   2.4158569E-04
     +,   2.4449252E-04,   2.4738070E-04,   2.5024702E-04
     +,   2.5308752E-04,   2.5589817E-04,   2.5867479E-04
     +,   2.6141244E-04,   2.6410649E-04,   2.6675145E-04
     +,   2.6934198E-04,   2.7187209E-04,   2.7433605E-04
     +,   2.7672734E-04,   2.7903970E-04,   2.8126643E-04
     +,   2.8340056E-04,   2.8543541E-04,   2.8736395E-04
     +,   2.8917889E-04,   2.9087334E-04,   2.9244027E-04
     +,   2.9387258E-04,   2.9516366E-04,   2.9630680E-04
     +,   2.9729560E-04,   2.9812410E-04,   2.9878662E-04
     +,   2.9927780E-04,   2.9959303E-04,   2.9972792E-04
     +,   2.9967906E-04,   2.9944358E-04,   2.9901904E-04
     +,   2.9840428E-04,   2.9759851E-04,   2.9660203E-04
     +,   2.9541604E-04,   2.9404252E-04,   2.9248459E-04
     +,   2.9074622E-04,   2.8883206E-04,   2.8674811E-04
     +,   2.8450121E-04,   2.8209883E-04,   2.7954968E-04
     +,   2.7686302E-04,   2.7404877E-04,   2.7111798E-04
     +,   2.6808211E-04,   2.6495309E-04,   2.6174317E-04
     +,   2.5846556E-04,   2.5513314E-04,   2.5175948E-04
     +,   2.4835792E-04,   2.4494194E-04,   2.4152473E-04
     +,   2.3811978E-04,   2.3473978E-04,   2.3139725E-04
     +,   2.2810447E-04,   2.2487255E-04,   2.2171254E-04
     +,   2.1863489E-04,   2.1564895E-04,   2.1276326E-04
     +,   2.0998612E-04,   2.0732428E-04,   2.0478417E-04
     +,   2.0237087E-04,   2.0008914E-04,   1.9794227E-04
     +,   1.9593330E-04,   1.9406392E-04,   1.9233547E-04
     +,   1.9074835E-04,   1.8930205E-04,   1.8799574E-04
     +,   1.8682799E-04,   1.8579660E-04,   1.8489898E-04
     +,   1.8413219E-04,   1.8349290E-04,   1.8297756E-04
     +,   1.8258221E-04,   1.8230295E-04,   1.8213557E-04
     +,   1.8207594E-04,   1.8211985E-04,   1.8226329E-04
     +,   1.8250220E-04,   1.8283259E-04,   1.8325083E-04
     +,   1.8375338E-04,   1.8433706E-04,   1.8499872E-04
     +,   1.8573573E-04,   1.8654543E-04,   1.8742590E-04
     +,   1.8837508E-04,   1.8939142E-04,   1.9047380E-04
     +,   1.9162125E-04,   1.9283302E-04,   1.9410870E-04
     +,   1.9544833E-04,   1.9685221E-04,   1.9832060E-04
     +,   1.9985434E-04,   2.0145443E-04,   2.0312236E-04
     +,   2.0485961E-04,   2.0666826E-04,   2.0855064E-04
     +,   2.1050972E-04,   2.1254890E-04,   2.1467227E-04
     +,   2.1688470E-04,   2.1919221E-04,   2.2160176E-04
     +,   2.2412202E-04,   2.2676341E-04,   2.2953801E-04
     +,   2.3246082E-04,   2.3554954E-04,   2.3882517E-04
     +,   2.4231280E-04,   2.4604143E-04,   2.5004553E-04
     +,   2.5436547E-04,   2.5904682E-04,   2.6414290E-04
     +,   2.6971457E-04,   2.7583036E-04,   2.8256772E-04
     +,   2.9001356E-04,   2.9826455E-04,   3.0742722E-04
     +,   3.1761825E-04,   3.2896546E-04,   3.4160767E-04
     +,   3.5569258E-04,   3.7137885E-04,   3.8883532E-04
     +,   4.0824153E-04,   4.2978363E-04,   4.5365957E-04
     +,   4.8007772E-04,   5.0925562E-04,   5.4142281E-04
     +,   5.7682651E-04,   6.1573420E-04,   6.5843499E-04
     +,   7.0524961E-04,   7.5654016E-04,   8.1271824E-04
     +,   8.7424921E-04,   9.4166672E-04,   1.0155815E-03
     +,   1.0966872E-03,   1.1857488E-03,   1.2836118E-03
     +,   1.3911767E-03,   1.5093572E-03,   1.6390488E-03
     +,   1.7810797E-03,   1.9361556E-03,   2.1048093E-03
     +,   2.2873918E-03,   2.4841228E-03,   2.6951798E-03
     +,   2.9208192E-03,   3.1615919E-03,   3.4185050E-03
     +,   3.6931201E-03,   3.9874353E-03,   4.3036663E-03
     +,   4.6438025E-03,   5.0090915E-03,   5.3997906E-03
     +,   5.8152145E-03,   6.2542604E-03,   6.7160018E-03
     +,   7.2001540E-03,   7.7070128E-03,   8.2370834E-03
     +,   8.7922486E-03,   9.3807876E-03,   1.0027315E-02
     +,   1.0783373E-02,   1.1728308E-02,   1.2949333E-02
     +,   1.4499882E-02,   1.6357504E-02,   1.8416146E-02
     +,   2.0534033E-02,   2.2615885E-02,   2.4673099E-02
     +,   2.6815642E-02,   2.9189037E-02,   3.1907730E-02
     +,   3.5017971E-02,   3.8481526E-02,   4.2167716E-02
     +,   4.5827247E-02,   4.9042232E-02,   5.1263943E-02
     +,   5.2080534E-02,   5.1554587E-02,   5.0224349E-02
     +,   4.8669275E-02,   4.7059242E-02,   4.5121063E-02
     +,   4.2483751E-02,   3.9025225E-02,   3.4949489E-02
     +,   3.0636640E-02,   2.6459167E-02,   2.2677414E-02
     +,   1.9405141E-02,   1.6623415E-02,   1.4231330E-02
     +,   1.2119251E-02,   1.0221564E-02,   8.5254284E-03
     +,   7.0436457E-03,   5.7845549E-03,   4.7374647E-03
     +,   3.8756696E-03,   3.1662309E-03,   2.5782620E-03
     +,   2.0873384E-03,   1.6759515E-03,   1.3322469E-03
     +,   1.0478392E-03,   8.1602781E-04,   6.3046574E-04
     +,   4.8468474E-04,   3.7207201E-04,   2.8622962E-04
     +,   2.2131635E-04,   1.7234078E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz112 = Yx/0.3023125
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.1750259E-05,   5.3109598E-05
     +,   5.4489756E-05,   5.5891491E-05,   5.7315799E-05
     +,   5.8763777E-05,   6.0236700E-05,   6.1736013E-05
     +,   6.3263316E-05,   6.4820473E-05,   6.6409484E-05
     +,   6.8032539E-05,   6.9692040E-05,   7.1390634E-05
     +,   7.3131079E-05,   7.4916432E-05,   7.6749864E-05
     +,   7.8634832E-05,   8.0574922E-05,   8.2573839E-05
     +,   8.4635518E-05,   8.6764005E-05,   8.8963483E-05
     +,   9.1238333E-05,   9.3592746E-05,   9.6031283E-05
     +,   9.8558296E-05,   1.0117825E-04,   1.0389549E-04
     +,   1.0671440E-04,   1.0963906E-04,   1.1267360E-04
     +,   1.1582174E-04,   1.1908710E-04,   1.2247295E-04
     +,   1.2598230E-04,   1.2961768E-04,   1.3338115E-04
     +,   1.3727459E-04,   1.4129895E-04,   1.4545501E-04
     +,   1.4974273E-04,   1.5416146E-04,   1.5870988E-04
     +,   1.6338611E-04,   1.6818735E-04,   1.7311002E-04
     +,   1.7814999E-04,   1.8330214E-04,   1.8856053E-04
     +,   1.9391844E-04,   1.9936853E-04,   2.0490217E-04
     +,   2.1051046E-04,   2.1618325E-04,   2.2190997E-04
     +,   2.2767912E-04,   2.3347838E-04,   2.3929504E-04
     +,   2.4511543E-04,   2.5092563E-04,   2.5671098E-04
     +,   2.6245622E-04,   2.6814599E-04,   2.7376460E-04
     +,   2.7929575E-04,   2.8472344E-04,   2.9003099E-04
     +,   2.9520245E-04,   3.0022100E-04,   3.0507124E-04
     +,   3.0973661E-04,   3.1420225E-04,   3.1845274E-04
     +,   3.2247373E-04,   3.2625149E-04,   3.2977291E-04
     +,   3.3302547E-04,   3.3599811E-04,   3.3868017E-04
     +,   3.4106243E-04,   3.4313684E-04,   3.4489622E-04
     +,   3.4633485E-04,   3.4744816E-04,   3.4823333E-04
     +,   3.4868845E-04,   3.4881313E-04,   3.4860839E-04
     +,   3.4807689E-04,   3.4722232E-04,   3.4605010E-04
     +,   3.4456659E-04,   3.4278000E-04,   3.4069942E-04
     +,   3.3833511E-04,   3.3569874E-04,   3.3280300E-04
     +,   3.2966127E-04,   3.2628817E-04,   3.2269891E-04
     +,   3.1890970E-04,   3.1493668E-04,   3.1079748E-04
     +,   3.0650891E-04,   3.0208883E-04,   2.9755521E-04
     +,   2.9292595E-04,   2.8821858E-04,   2.8345070E-04
     +,   2.7863990E-04,   2.7380270E-04,   2.6895595E-04
     +,   2.6411525E-04,   2.5929618E-04,   2.5451300E-04
     +,   2.4977990E-04,   2.4510958E-04,   2.4051448E-04
     +,   2.3600589E-04,   2.3159391E-04,   2.2728828E-04
     +,   2.2309771E-04,   2.1902967E-04,   2.1509088E-04
     +,   2.1128733E-04,   2.0762392E-04,   2.0410506E-04
     +,   2.0073383E-04,   1.9751335E-04,   1.9444525E-04
     +,   1.9153117E-04,   1.8877175E-04,   1.8616747E-04
     +,   1.8371816E-04,   1.8142333E-04,   1.7928220E-04
     +,   1.7729394E-04,   1.7545738E-04,   1.7377119E-04
     +,   1.7223427E-04,   1.7084551E-04,   1.6960397E-04
     +,   1.6850872E-04,   1.6755938E-04,   1.6675558E-04
     +,   1.6609758E-04,   1.6558592E-04,   1.6522178E-04
     +,   1.6500671E-04,   1.6494276E-04,   1.6503285E-04
     +,   1.6528026E-04,   1.6568898E-04,   1.6626377E-04
     +,   1.6700981E-04,   1.6793303E-04,   1.6904005E-04
     +,   1.7033807E-04,   1.7183489E-04,   1.7353853E-04
     +,   1.7545804E-04,   1.7760250E-04,   1.7998133E-04
     +,   1.8260417E-04,   1.8548129E-04,   1.8862236E-04
     +,   1.9203725E-04,   1.9573572E-04,   1.9972739E-04
     +,   2.0402099E-04,   2.0862490E-04,   2.1354695E-04
     +,   2.1879449E-04,   2.2437309E-04,   2.3028839E-04
     +,   2.3654455E-04,   2.4314501E-04,   2.5009166E-04
     +,   2.5738630E-04,   2.6502993E-04,   2.7302274E-04
     +,   2.8136437E-04,   2.9005547E-04,   2.9909681E-04
     +,   3.0848998E-04,   3.1823778E-04,   3.2834624E-04
     +,   3.3882377E-04,   3.4968197E-04,   3.6093695E-04
     +,   3.7261043E-04,   3.8472968E-04,   3.9732712E-04
     +,   4.1044448E-04,   4.2413067E-04,   4.3844193E-04
     +,   4.5344359E-04,   4.6921027E-04,   4.8582599E-04
     +,   5.0338241E-04,   5.2198005E-04,   5.4172846E-04
     +,   5.6274468E-04,   5.8515032E-04,   6.0907501E-04
     +,   6.3465134E-04,   6.6201511E-04,   6.9130230E-04
     +,   7.2265154E-04,   7.5620308E-04,   7.9209550E-04
     +,   8.3047058E-04,   8.7148126E-04,   9.1529585E-04
     +,   9.6210657E-04,   1.0121473E-03,   1.0657159E-03
     +,   1.1231974E-03,   1.1850811E-03,   1.2519998E-03
     +,   1.3247423E-03,   1.4042694E-03,   1.4917051E-03
     +,   1.5883329E-03,   1.6955431E-03,   1.8147673E-03
     +,   1.9473957E-03,   2.0946914E-03,   2.2576770E-03
     +,   2.4370095E-03,   2.6328797E-03,   2.8449295E-03
     +,   3.0721894E-03,   3.3130273E-03,   3.5653287E-03
     +,   3.8266876E-03,   4.0948326E-03,   4.3681408E-03
     +,   4.6462137E-03,   4.9301507E-03,   5.2224710E-03
     +,   5.5266190E-03,   5.8461586E-03,   6.1841626E-03
     +,   6.5434175E-03,   6.9281259E-03,   7.3467917E-03
     +,   7.8152400E-03,   8.3573265E-03,   9.0018474E-03
     +,   9.7750211E-03,   1.0691782E-02,   1.1750665E-02
     +,   1.2936839E-02,   1.4234213E-02,   1.5644988E-02
     +,   1.7210063E-02,   1.9017415E-02,   2.1186091E-02
     +,   2.3827381E-02,   2.7000351E-02,   3.0674476E-02
     +,   3.4698360E-02,   3.8784876E-02,   4.2547286E-02
     +,   4.5615312E-02,   4.7801293E-02,   4.9198933E-02
     +,   5.0094150E-02,   5.0717797E-02,   5.1045224E-02
     +,   5.0830450E-02,   4.9831104E-02,   4.7983229E-02
     +,   4.5364983E-02,   4.2072885E-02,   3.8222589E-02
     +,   3.4034103E-02,   2.9813737E-02,   2.5815587E-02
     +,   2.2149459E-02,   1.8815205E-02,   1.5790654E-02
     +,   1.3076607E-02,   1.0689888E-02,   8.6381780E-03
     +,   6.9074589E-03,   5.4655862E-03,   4.2731045E-03
     +,   3.2935268E-03,   2.4971566E-03,   1.8603608E-03
     +,   1.3623261E-03,   9.8284509E-04,   7.0147432E-04
     +,   4.9825932E-04,   3.5479225E-04,   2.5524793E-04
     +,   1.8685113E-04,   1.3990735E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz113 = Yx/0.302042553191489
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0044258E-05,   8.3415885E-05
     +,   8.6817214E-05,   9.0240152E-05,   9.3676281E-05
     +,   9.7116768E-05,   1.0055257E-04,   1.0397445E-04
     +,   1.0737291E-04,   1.1073848E-04,   1.1406153E-04
     +,   1.1733254E-04,   1.2054195E-04,   1.2368053E-04
     +,   1.2673906E-04,   1.2970883E-04,   1.3258129E-04
     +,   1.3534845E-04,   1.3800272E-04,   1.4053709E-04
     +,   1.4294515E-04,   1.4522109E-04,   1.4735996E-04
     +,   1.4935738E-04,   1.5120980E-04,   1.5291458E-04
     +,   1.5446986E-04,   1.5587464E-04,   1.5712886E-04
     +,   1.5823316E-04,   1.5918934E-04,   1.5999986E-04
     +,   1.6066821E-04,   1.6119854E-04,   1.6159595E-04
     +,   1.6186635E-04,   1.6201624E-04,   1.6205294E-04
     +,   1.6198441E-04,   1.6181922E-04,   1.6156636E-04
     +,   1.6123558E-04,   1.6083667E-04,   1.6038012E-04
     +,   1.5987658E-04,   1.5933682E-04,   1.5877202E-04
     +,   1.5819326E-04,   1.5761171E-04,   1.5703855E-04
     +,   1.5648484E-04,   1.5596152E-04,   1.5547930E-04
     +,   1.5504866E-04,   1.5467982E-04,   1.5438261E-04
     +,   1.5416635E-04,   1.5404026E-04,   1.5401286E-04
     +,   1.5409214E-04,   1.5428575E-04,   1.5460062E-04
     +,   1.5504326E-04,   1.5561945E-04,   1.5633450E-04
     +,   1.5719296E-04,   1.5819882E-04,   1.5935535E-04
     +,   1.6066521E-04,   1.6213032E-04,   1.6375197E-04
     +,   1.6553057E-04,   1.6746607E-04,   1.6955730E-04
     +,   1.7180260E-04,   1.7419964E-04,   1.7674504E-04
     +,   1.7943462E-04,   1.8226347E-04,   1.8522593E-04
     +,   1.8831535E-04,   1.9152425E-04,   1.9484425E-04
     +,   1.9826627E-04,   2.0178003E-04,   2.0537483E-04
     +,   2.0903850E-04,   2.1275865E-04,   2.1652153E-04
     +,   2.2031298E-04,   2.2411786E-04,   2.2792046E-04
     +,   2.3170405E-04,   2.3545172E-04,   2.3914596E-04
     +,   2.4276855E-04,   2.4630121E-04,   2.4972536E-04
     +,   2.5302215E-04,   2.5617282E-04,   2.5915887E-04
     +,   2.6196180E-04,   2.6456377E-04,   2.6694717E-04
     +,   2.6909538E-04,   2.7099272E-04,   2.7262405E-04
     +,   2.7397560E-04,   2.7503492E-04,   2.7579113E-04
     +,   2.7623444E-04,   2.7635685E-04,   2.7615231E-04
     +,   2.7561642E-04,   2.7474668E-04,   2.7354245E-04
     +,   2.7200519E-04,   2.7013829E-04,   2.6794715E-04
     +,   2.6543910E-04,   2.6262336E-04,   2.5951097E-04
     +,   2.5611513E-04,   2.5245023E-04,   2.4853231E-04
     +,   2.4437933E-04,   2.4000990E-04,   2.3544434E-04
     +,   2.3070358E-04,   2.2580993E-04,   2.2078556E-04
     +,   2.1565425E-04,   2.1043900E-04,   2.0516397E-04
     +,   1.9985282E-04,   1.9452894E-04,   1.8921604E-04
     +,   1.8393726E-04,   1.7871500E-04,   1.7357118E-04
     +,   1.6852719E-04,   1.6360388E-04,   1.5882081E-04
     +,   1.5419703E-04,   1.4975095E-04,   1.4549996E-04
     +,   1.4146065E-04,   1.3764913E-04,   1.3408088E-04
     +,   1.3077061E-04,   1.2773262E-04,   1.2498097E-04
     +,   1.2252953E-04,   1.2039180E-04,   1.1858143E-04
     +,   1.1711223E-04,   1.1599825E-04,   1.1525382E-04
     +,   1.1489374E-04,   1.1493338E-04,   1.1538858E-04
     +,   1.1627591E-04,   1.1761235E-04,   1.1941554E-04
     +,   1.2170355E-04,   1.2449475E-04,   1.2780767E-04
     +,   1.3166043E-04,   1.3607118E-04,   1.4105729E-04
     +,   1.4663467E-04,   1.5281781E-04,   1.5961933E-04
     +,   1.6704954E-04,   1.7511522E-04,   1.8381987E-04
     +,   1.9316348E-04,   2.0314087E-04,   2.1374183E-04
     +,   2.2495142E-04,   2.3674968E-04,   2.4910987E-04
     +,   2.6199943E-04,   2.7538164E-04,   2.8921408E-04
     +,   3.0344928E-04,   3.1803554E-04,   3.3291930E-04
     +,   3.4804593E-04,   3.6335835E-04,   3.7880387E-04
     +,   3.9433269E-04,   4.0990079E-04,   4.2547271E-04
     +,   4.4102516E-04,   4.5654995E-04,   4.7205490E-04
     +,   4.8756879E-04,   5.0314429E-04,   5.1886117E-04
     +,   5.3482683E-04,   5.5117812E-04,   5.6808582E-04
     +,   5.8575114E-04,   6.0440518E-04,   6.2430772E-04
     +,   6.4574188E-04,   6.6900760E-04,   6.9441332E-04
     +,   7.2226964E-04,   7.5287546E-04,   7.8650622E-04
     +,   8.2340016E-04,   8.6374971E-04,   9.0768764E-04
     +,   9.5527718E-04,   1.0065025E-03,   1.0612766E-03
     +,   1.1194341E-03,   1.1807330E-03,   1.2448765E-03
     +,   1.3115240E-03,   1.3803013E-03,   1.4508258E-03
     +,   1.5227398E-03,   1.5957210E-03,   1.6695145E-03
     +,   1.7439666E-03,   1.8190773E-03,   1.8950469E-03
     +,   1.9723552E-03,   2.0518638E-03,   2.1349362E-03
     +,   2.2235622E-03,   2.3204491E-03,   2.4290939E-03
     +,   2.5537391E-03,   2.6992094E-03,   2.8706167E-03
     +,   3.0729547E-03,   3.3106152E-03,   3.5868683E-03
     +,   3.9034626E-03,   4.2603738E-03,   4.6556974E-03
     +,   5.0857919E-03,   5.5457526E-03,   6.0304357E-03
     +,   6.5359338E-03,   7.0617022E-03,   7.6132840E-03
     +,   8.2046557E-03,   8.8594556E-03,   9.6096769E-03
     +,   1.0490480E-02,   1.1530722E-02,   1.2740470E-02
     +,   1.4100158E-02,   1.5559766E-02,   1.7056730E-02
     +,   1.8554093E-02,   2.0082375E-02,   2.1757234E-02
     +,   2.3751801E-02,   2.6224105E-02,   2.9221360E-02
     +,   3.2611299E-02,   3.6118925E-02,   3.9492063E-02
     +,   4.2652313E-02,   4.5630634E-02,   4.8354924E-02
     +,   5.0604153E-02,   5.2201428E-02,   5.3124357E-02
     +,   5.3339239E-02,   5.2644473E-02,   5.0828841E-02
     +,   4.7959227E-02,   4.4388205E-02,   4.0464684E-02
     +,   3.6322076E-02,   3.1952638E-02,   2.7400449E-02
     +,   2.2834776E-02,   1.8486906E-02,   1.4560988E-02
     +,   1.1191372E-02,   8.4357122E-03,   6.2791151E-03
     +,   4.6489835E-03,   3.4409664E-03,   2.5495323E-03
     +,   1.8882293E-03,   1.3954088E-03,   1.0290464E-03
     +,   7.5921166E-04,   5.6256657E-04,   4.2014857E-04
     +,   3.1680943E-04,   2.4112737E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz114 = Yx/0.300553191489362
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0475574E-05,   5.2674703E-05
     +,   5.4961096E-05,   5.7337667E-05,   5.9807415E-05
     +,   6.2373350E-05,   6.5038439E-05,   6.7805675E-05
     +,   7.0677932E-05,   7.3658135E-05,   7.6749071E-05
     +,   7.9953294E-05,   8.3273335E-05,   8.6711487E-05
     +,   9.0269888E-05,   9.3950264E-05,   9.7754128E-05
     +,   1.0168278E-04,   1.0573694E-04,   1.0991703E-04
     +,   1.1422302E-04,   1.1865440E-04,   1.2320997E-04
     +,   1.2788846E-04,   1.3268727E-04,   1.3760396E-04
     +,   1.4263485E-04,   1.4777602E-04,   1.5302260E-04
     +,   1.5836925E-04,   1.6380992E-04,   1.6933783E-04
     +,   1.7494551E-04,   1.8062499E-04,   1.8636764E-04
     +,   1.9216430E-04,   1.9800503E-04,   2.0387970E-04
     +,   2.0977781E-04,   2.1568782E-04,   2.2159881E-04
     +,   2.2749895E-04,   2.3337646E-04,   2.3921939E-04
     +,   2.4501581E-04,   2.5075368E-04,   2.5642139E-04
     +,   2.6200715E-04,   2.6749974E-04,   2.7288805E-04
     +,   2.7816149E-04,   2.8330993E-04,   2.8832353E-04
     +,   2.9319347E-04,   2.9791097E-04,   3.0246831E-04
     +,   3.0685827E-04,   3.1107420E-04,   3.1511011E-04
     +,   3.1896110E-04,   3.2262242E-04,   3.2609029E-04
     +,   3.2936153E-04,   3.3243335E-04,   3.3530415E-04
     +,   3.3797193E-04,   3.4043627E-04,   3.4269644E-04
     +,   3.4475239E-04,   3.4660465E-04,   3.4825393E-04
     +,   3.4970095E-04,   3.5094735E-04,   3.5199441E-04
     +,   3.5284393E-04,   3.5349786E-04,   3.5395814E-04
     +,   3.5422709E-04,   3.5430683E-04,   3.5419976E-04
     +,   3.5390840E-04,   3.5343520E-04,   3.5278284E-04
     +,   3.5195419E-04,   3.5095186E-04,   3.4977894E-04
     +,   3.4843854E-04,   3.4693370E-04,   3.4526808E-04
     +,   3.4344516E-04,   3.4146843E-04,   3.3934216E-04
     +,   3.3707055E-04,   3.3465790E-04,   3.3210873E-04
     +,   3.2942809E-04,   3.2662114E-04,   3.2369338E-04
     +,   3.2065020E-04,   3.1749779E-04,   3.1424224E-04
     +,   3.1088965E-04,   3.0744690E-04,   3.0392085E-04
     +,   3.0031841E-04,   2.9664653E-04,   2.9291259E-04
     +,   2.8912420E-04,   2.8528899E-04,   2.8141413E-04
     +,   2.7750773E-04,   2.7357705E-04,   2.6963025E-04
     +,   2.6567487E-04,   2.6171858E-04,   2.5776887E-04
     +,   2.5383354E-04,   2.4991977E-04,   2.4603531E-04
     +,   2.4218704E-04,   2.3838207E-04,   2.3462743E-04
     +,   2.3092999E-04,   2.2729629E-04,   2.2373239E-04
     +,   2.2024481E-04,   2.1683946E-04,   2.1352209E-04
     +,   2.1029823E-04,   2.0717322E-04,   2.0415202E-04
     +,   2.0123963E-04,   1.9844039E-04,   1.9575896E-04
     +,   1.9319932E-04,   1.9076520E-04,   1.8846031E-04
     +,   1.8628803E-04,   1.8425153E-04,   1.8235369E-04
     +,   1.8059685E-04,   1.7898394E-04,   1.7751683E-04
     +,   1.7619746E-04,   1.7502760E-04,   1.7400888E-04
     +,   1.7314235E-04,   1.7242931E-04,   1.7187047E-04
     +,   1.7146666E-04,   1.7121821E-04,   1.7112537E-04
     +,   1.7118838E-04,   1.7140697E-04,   1.7178078E-04
     +,   1.7230948E-04,   1.7299225E-04,   1.7382835E-04
     +,   1.7481683E-04,   1.7595658E-04,   1.7724620E-04
     +,   1.7868463E-04,   1.8027017E-04,   1.8200149E-04
     +,   1.8387726E-04,   1.8589593E-04,   1.8805638E-04
     +,   1.9035712E-04,   1.9279748E-04,   1.9537691E-04
     +,   1.9809496E-04,   2.0095214E-04,   2.0394909E-04
     +,   2.0708781E-04,   2.1037058E-04,   2.1380110E-04
     +,   2.1738429E-04,   2.2112632E-04,   2.2503492E-04
     +,   2.2911972E-04,   2.3339297E-04,   2.3786820E-04
     +,   2.4256206E-04,   2.4749397E-04,   2.5268659E-04
     +,   2.5816544E-04,   2.6395958E-04,   2.7010191E-04
     +,   2.7662973E-04,   2.8358321E-04,   2.9100725E-04
     +,   2.9895062E-04,   3.0746585E-04,   3.1660835E-04
     +,   3.2643770E-04,   3.3701645E-04,   3.4840844E-04
     +,   3.6067894E-04,   3.7389534E-04,   3.8812420E-04
     +,   4.0343156E-04,   4.1988143E-04,   4.3753660E-04
     +,   4.5645787E-04,   4.7670220E-04,   4.9832556E-04
     +,   5.2138377E-04,   5.4593117E-04,   5.7202583E-04
     +,   5.9973408E-04,   6.2913407E-04,   6.6031958E-04
     +,   6.9340877E-04,   7.2855502E-04,   7.6595478E-04
     +,   8.0585328E-04,   8.4855681E-04,   8.9444156E-04
     +,   9.4395742E-04,   9.9761947E-04,   1.0560139E-03
     +,   1.1197762E-03,   1.1895652E-03,   1.2660365E-03
     +,   1.3498096E-03,   1.4414241E-03,   1.5413000E-03
     +,   1.6497114E-03,   1.7667778E-03,   1.8924685E-03
     +,   2.0266178E-03,   2.1689686E-03,   2.3192477E-03
     +,   2.4772079E-03,   2.6426727E-03,   2.8155963E-03
     +,   2.9960687E-03,   3.1843113E-03,   3.3806926E-03
     +,   3.5857621E-03,   3.8003090E-03,   4.0254323E-03
     +,   4.2626318E-03,   4.5138975E-03,   4.7816583E-03
     +,   5.0685960E-03,   5.3774482E-03,   5.7108505E-03
     +,   6.0712937E-03,   6.4612529E-03,   6.8834857E-03
     +,   7.3408475E-03,   7.8355027E-03,   8.3674537E-03
     +,   8.9330208E-03,   9.5244180E-03,   1.0131974E-02
     +,   1.0750168E-02,   1.1386738E-02,   1.2071790E-02
     +,   1.2860923E-02,   1.3826549E-02,   1.5036616E-02
     +,   1.6530277E-02,   1.8305846E-02,   2.0330567E-02
     +,   2.2561099E-02,   2.4952168E-02,   2.7446266E-02
     +,   2.9971879E-02,   3.2492515E-02,   3.5100307E-02
     +,   3.8053334E-02,   4.1630283E-02,   4.5826871E-02
     +,   5.0151814E-02,   5.3784668E-02,   5.6019440E-02
     +,   5.6595780E-02,   5.5629730E-02,   5.3313967E-02
     +,   4.9756587E-02,   4.5073394E-02,   3.9536025E-02
     +,   3.3575606E-02,   2.7661292E-02,   2.2173975E-02
     +,   1.7351974E-02,   1.3295049E-02,   9.9959020E-03
     +,   7.3831454E-03,   5.3587770E-03,   3.8237837E-03
     +,   2.6873657E-03,   1.8686004E-03,   1.2955863E-03
     +,   9.0604578E-04,   6.4799224E-04,   4.8012438E-04
     +,   3.7121266E-04,   2.9896098E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz115 = Yx/0.292063829787234
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.9917667E-05,   7.1849849E-05
     +,   7.3825322E-05,   7.5846081E-05,   7.7914221E-05
     +,   8.0031983E-05,   8.2201717E-05,   8.4425992E-05
     +,   8.6707325E-05,   8.9048597E-05,   9.1452457E-05
     +,   9.3921852E-05,   9.6459647E-05,   9.9068740E-05
     +,   1.0175208E-04,   1.0451250E-04,   1.0735278E-04
     +,   1.1027559E-04,   1.1328335E-04,   1.1637847E-04
     +,   1.1956294E-04,   1.2283857E-04,   1.2620669E-04
     +,   1.2966858E-04,   1.3322469E-04,   1.3687534E-04
     +,   1.4062013E-04,   1.4445827E-04,   1.4838830E-04
     +,   1.5240813E-04,   1.5651519E-04,   1.6070607E-04
     +,   1.6497682E-04,   1.6932267E-04,   1.7373830E-04
     +,   1.7821766E-04,   1.8275404E-04,   1.8734005E-04
     +,   1.9196788E-04,   1.9662885E-04,   2.0131399E-04
     +,   2.0601384E-04,   2.1071851E-04,   2.1541781E-04
     +,   2.2010131E-04,   2.2475854E-04,   2.2937880E-04
     +,   2.3395171E-04,   2.3846685E-04,   2.4291415E-04
     +,   2.4728398E-04,   2.5156722E-04,   2.5575544E-04
     +,   2.5984072E-04,   2.6381612E-04,   2.6767567E-04
     +,   2.7141429E-04,   2.7502820E-04,   2.7851461E-04
     +,   2.8187217E-04,   2.8510057E-04,   2.8820112E-04
     +,   2.9117599E-04,   2.9402907E-04,   2.9676562E-04
     +,   2.9939180E-04,   3.0191525E-04,   3.0434487E-04
     +,   3.0669026E-04,   3.0896199E-04,   3.1117190E-04
     +,   3.1333207E-04,   3.1545540E-04,   3.1755486E-04
     +,   3.1964382E-04,   3.2173577E-04,   3.2384403E-04
     +,   3.2598083E-04,   3.2815911E-04,   3.3039018E-04
     +,   3.3268469E-04,   3.3505206E-04,   3.3750045E-04
     +,   3.4003682E-04,   3.4266629E-04,   3.4539256E-04
     +,   3.4821709E-04,   3.5113993E-04,   3.5415892E-04
     +,   3.5726978E-04,   3.6046666E-04,   3.6374133E-04
     +,   3.6708373E-04,   3.7048204E-04,   3.7392240E-04
     +,   3.7738937E-04,   3.8086605E-04,   3.8433404E-04
     +,   3.8777399E-04,   3.9116500E-04,   3.9448589E-04
     +,   3.9771426E-04,   4.0082843E-04,   4.0380526E-04
     +,   4.0662262E-04,   4.0925870E-04,   4.1169202E-04
     +,   4.1390184E-04,   4.1586862E-04,   4.1757422E-04
     +,   4.1900182E-04,   4.2013594E-04,   4.2096319E-04
     +,   4.2147250E-04,   4.2165373E-04,   4.2149986E-04
     +,   4.2100562E-04,   4.2016813E-04,   4.1898657E-04
     +,   4.1746252E-04,   4.1559979E-04,   4.1340393E-04
     +,   4.1088366E-04,   4.0804807E-04,   4.0490972E-04
     +,   4.0148196E-04,   3.9777963E-04,   3.9382000E-04
     +,   3.8962055E-04,   3.8520043E-04,   3.8057950E-04
     +,   3.7577885E-04,   3.7081935E-04,   3.6572313E-04
     +,   3.6051185E-04,   3.5520759E-04,   3.4983191E-04
     +,   3.4440719E-04,   3.3895404E-04,   3.3349317E-04
     +,   3.2804470E-04,   3.2262850E-04,   3.1726254E-04
     +,   3.1196425E-04,   3.0675074E-04,   3.0163728E-04
     +,   2.9663849E-04,   2.9176800E-04,   2.8703859E-04
     +,   2.8246143E-04,   2.7804702E-04,   2.7380497E-04
     +,   2.6974408E-04,   2.6587199E-04,   2.6219574E-04
     +,   2.5872185E-04,   2.5545628E-04,   2.5240413E-04
     +,   2.4957024E-04,   2.4695962E-04,   2.4457637E-04
     +,   2.4242482E-04,   2.4050957E-04,   2.3883511E-04
     +,   2.3740607E-04,   2.3622732E-04,   2.3530435E-04
     +,   2.3464284E-04,   2.3424884E-04,   2.3412958E-04
     +,   2.3429187E-04,   2.3474374E-04,   2.3549367E-04
     +,   2.3655080E-04,   2.3792451E-04,   2.3962471E-04
     +,   2.4166254E-04,   2.4404853E-04,   2.4679385E-04
     +,   2.4991031E-04,   2.5340982E-04,   2.5730400E-04
     +,   2.6160479E-04,   2.6632444E-04,   2.7147483E-04
     +,   2.7706780E-04,   2.8311473E-04,   2.8962761E-04
     +,   2.9661792E-04,   3.0409690E-04,   3.1207607E-04
     +,   3.2056723E-04,   3.2958176E-04,   3.3913093E-04
     +,   3.4922760E-04,   3.5988449E-04,   3.7111447E-04
     +,   3.8293097E-04,   3.9534879E-04,   4.0838312E-04
     +,   4.2204937E-04,   4.3636299E-04,   4.5134081E-04
     +,   4.6700050E-04,   4.8335808E-04,   5.0043123E-04
     +,   5.1823817E-04,   5.3679646E-04,   5.5612467E-04
     +,   5.7624414E-04,   5.9717841E-04,   6.1895530E-04
     +,   6.4160721E-04,   6.6517852E-04,   6.8972434E-04
     +,   7.1531470E-04,   7.4203970E-04,   7.7001547E-04
     +,   7.9938909E-04,   8.3034066E-04,   8.6309563E-04
     +,   8.9792674E-04,   9.3516288E-04,   9.7519549E-04
     +,   1.0184938E-03,   1.0656134E-03,   1.1172133E-03
     +,   1.1740780E-03,   1.2371504E-03,   1.3075604E-03
     +,   1.3866574E-03,   1.4760379E-03,   1.5775685E-03
     +,   1.6933650E-03,   1.8257147E-03,   1.9769920E-03
     +,   2.1494874E-03,   2.3452011E-03,   2.5656843E-03
     +,   2.8119418E-03,   3.0844542E-03,   3.3833024E-03
     +,   3.7084813E-03,   4.0601622E-03,   4.4387900E-03
     +,   4.8448164E-03,   5.2780872E-03,   5.7369736E-03
     +,   6.2175589E-03,   6.7133894E-03,   7.2165173E-03
     +,   7.7196783E-03,   8.2194898E-03,   8.7196445E-03
     +,   9.2327539E-03,   9.7793983E-03,   1.0383964E-02
     +,   1.1068223E-02,   1.1844779E-02,   1.2713170E-02
     +,   1.3660208E-02,   1.4664996E-02,   1.5706370E-02
     +,   1.6770573E-02,   1.7857293E-02,   1.8984104E-02
     +,   2.0187687E-02,   2.1518553E-02,   2.3025285E-02
     +,   2.4731368E-02,   2.6621189E-02,   2.8653586E-02
     +,   3.0796625E-02,   3.3053126E-02,   3.5457887E-02
     +,   3.8060930E-02,   4.0905707E-02,   4.3974303E-02
     +,   4.7096767E-02,   4.9900208E-02,   5.1890098E-02
     +,   5.2626252E-02,   5.1858909E-02,   4.9545042E-02
     +,   4.5799218E-02,   4.0870290E-02,   3.5141964E-02
     +,   2.9098893E-02,   2.3232600E-02,   1.7931158E-02
     +,   1.3419900E-02,   9.7656678E-03,   6.9239312E-03
     +,   4.7901492E-03,   3.2392330E-03,   2.1475004E-03
     +,   1.4037084E-03,   9.1292604E-04,   5.9808075E-04
     +,   3.9976218E-04,   2.7506761E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz116 = Yx/0.291468085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz1168(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0634850E-04,   1.1088345E-04
     +,   1.1550813E-04,   1.2021674E-04,   1.2500277E-04
     +,   1.2985943E-04,   1.3477923E-04,   1.3975447E-04
     +,   1.4477673E-04,   1.4983771E-04,   1.5492832E-04
     +,   1.6003936E-04,   1.6516133E-04,   1.7028461E-04
     +,   1.7539937E-04,   1.8049566E-04,   1.8556356E-04
     +,   1.9059313E-04,   1.9557435E-04,   2.0049764E-04
     +,   2.0535328E-04,   2.1013201E-04,   2.1482463E-04
     +,   2.1942264E-04,   2.2391730E-04,   2.2830088E-04
     +,   2.3256594E-04,   2.3670528E-04,   2.4071250E-04
     +,   2.4458175E-04,   2.4830757E-04,   2.5188513E-04
     +,   2.5531041E-04,   2.5857979E-04,   2.6169026E-04
     +,   2.6463944E-04,   2.6742578E-04,   2.7004792E-04
     +,   2.7250542E-04,   2.7479822E-04,   2.7692688E-04
     +,   2.7889237E-04,   2.8069617E-04,   2.8234030E-04
     +,   2.8382722E-04,   2.8515968E-04,   2.8634089E-04
     +,   2.8737419E-04,   2.8826355E-04,   2.8901282E-04
     +,   2.8962645E-04,   2.9010879E-04,   2.9046455E-04
     +,   2.9069846E-04,   2.9081554E-04,   2.9082072E-04
     +,   2.9071901E-04,   2.9051569E-04,   2.9021586E-04
     +,   2.8982470E-04,   2.8934726E-04,   2.8878884E-04
     +,   2.8815449E-04,   2.8744937E-04,   2.8667843E-04
     +,   2.8584682E-04,   2.8495927E-04,   2.8402096E-04
     +,   2.8303638E-04,   2.8201059E-04,   2.8094806E-04
     +,   2.7985347E-04,   2.7873123E-04,   2.7758605E-04
     +,   2.7642222E-04,   2.7524389E-04,   2.7405555E-04
     +,   2.7286127E-04,   2.7166511E-04,   2.7047127E-04
     +,   2.6928372E-04,   2.6810609E-04,   2.6694266E-04
     +,   2.6579705E-04,   2.6467300E-04,   2.6357415E-04
     +,   2.6250439E-04,   2.6146715E-04,   2.6046604E-04
     +,   2.5950468E-04,   2.5858640E-04,   2.5771486E-04
     +,   2.5689346E-04,   2.5612552E-04,   2.5541446E-04
     +,   2.5476364E-04,   2.5417624E-04,   2.5365560E-04
     +,   2.5320487E-04,   2.5282725E-04,   2.5252564E-04
     +,   2.5230332E-04,   2.5216298E-04,   2.5210742E-04
     +,   2.5213929E-04,   2.5226109E-04,   2.5247529E-04
     +,   2.5278382E-04,   2.5318874E-04,   2.5369192E-04
     +,   2.5429428E-04,   2.5499731E-04,   2.5580169E-04
     +,   2.5670778E-04,   2.5771561E-04,   2.5882476E-04
     +,   2.6003443E-04,   2.6134311E-04,   2.6274909E-04
     +,   2.6424989E-04,   2.6584259E-04,   2.6752375E-04
     +,   2.6928898E-04,   2.7113382E-04,   2.7305295E-04
     +,   2.7504034E-04,   2.7708945E-04,   2.7919337E-04
     +,   2.8134426E-04,   2.8353379E-04,   2.8575363E-04
     +,   2.8799419E-04,   2.9024595E-04,   2.9249903E-04
     +,   2.9474311E-04,   2.9696763E-04,   2.9916171E-04
     +,   3.0131472E-04,   3.0341593E-04,   3.0545448E-04
     +,   3.0742018E-04,   3.0930233E-04,   3.1109148E-04
     +,   3.1277825E-04,   3.1435411E-04,   3.1581079E-04
     +,   3.1714159E-04,   3.1834011E-04,   3.1940127E-04
     +,   3.2032109E-04,   3.2109700E-04,   3.2172765E-04
     +,   3.2221316E-04,   3.2255484E-04,   3.2275586E-04
     +,   3.2282114E-04,   3.2275679E-04,   3.2257079E-04
     +,   3.2227280E-04,   3.2187413E-04,   3.2138766E-04
     +,   3.2082762E-04,   3.2021027E-04,   3.1955284E-04
     +,   3.1887426E-04,   3.1819401E-04,   3.1753333E-04
     +,   3.1691429E-04,   3.1635939E-04,   3.1589193E-04
     +,   3.1553561E-04,   3.1531436E-04,   3.1525220E-04
     +,   3.1537266E-04,   3.1569909E-04,   3.1625430E-04
     +,   3.1706007E-04,   3.1813781E-04,   3.1950721E-04
     +,   3.2118699E-04,   3.2319504E-04,   3.2554750E-04
     +,   3.2825914E-04,   3.3134385E-04,   3.3481489E-04
     +,   3.3868363E-04,   3.4296181E-04,   3.4766077E-04
     +,   3.5279297E-04,   3.5837083E-04,   3.6440926E-04
     +,   3.7092675E-04,   3.7794438E-04,   3.8548899E-04
     +,   3.9359383E-04,   4.0230068E-04,   4.1165951E-04
     +,   4.2173301E-04,   4.3259567E-04,   4.4433807E-04
     +,   4.5706559E-04,   4.7090091E-04,   4.8598528E-04
     +,   5.0247938E-04,   5.2055926E-04,   5.4041960E-04
     +,   5.6226918E-04,   5.8632629E-04,   6.1281567E-04
     +,   6.4196426E-04,   6.7399530E-04,   7.0911786E-04
     +,   7.4752438E-04,   7.8938500E-04,   8.3484309E-04
     +,   8.8400836E-04,   9.3695824E-04,   9.9374435E-04
     +,   1.0543893E-03,   1.1188932E-03,   1.1872489E-03
     +,   1.2594502E-03,   1.3354954E-03,   1.4154076E-03
     +,   1.4992491E-03,   1.5871405E-03,   1.6792619E-03
     +,   1.7758847E-03,   1.8774046E-03,   1.9843637E-03
     +,   2.0974809E-03,   2.2176972E-03,   2.3462155E-03
     +,   2.4845242E-03,   2.6343688E-03,   2.7977431E-03
     +,   2.9767598E-03,   3.1734880E-03,   3.3897168E-03
     +,   3.6267093E-03,   3.8849262E-03,   4.1637928E-03
     +,   4.4616186E-03,   4.7756759E-03,   5.1024109E-03
     +,   5.4378072E-03,   5.7778647E-03,   6.1190948E-03
     +,   6.4589949E-03,   6.7963973E-03,   7.1319928E-03
     +,   7.4687148E-03,   7.8118849E-03,   8.1689693E-03
     +,   8.5483845E-03,   8.9573711E-03,   9.3996944E-03
     +,   9.8746028E-03,   1.0379162E-02,   1.0913872E-02
     +,   1.1490045E-02,   1.2134056E-02,   1.2884155E-02
     +,   1.3778893E-02,   1.4842215E-02,   1.6074676E-02
     +,   1.7456105E-02,   1.8958816E-02,   2.0560646E-02
     +,   2.2246432E-02,   2.3995318E-02,   2.5768669E-02
     +,   2.7522175E-02,   2.9246498E-02,   3.1008290E-02
     +,   3.2941703E-02,   3.5173252E-02,   3.7720025E-02
     +,   4.0442590E-02,   4.3087460E-02,   4.5377094E-02
     +,   4.7056831E-02,   4.7872204E-02,   4.7541272E-02
     +,   4.5811020E-02,   4.2590275E-02,   3.8059458E-02
     +,   3.2659847E-02,   2.6961837E-02,   2.1493962E-02
     +,   1.6625972E-02,   1.2536786E-02,   9.2519233E-03
     +,   6.7033367E-03,   4.7827968E-03,   3.3732192E-03
     +,   2.3641004E-03,   1.6570681E-03,   1.1690087E-03
     +,   8.3345739E-04,   6.0081226E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz1168 = Yx/0.280148936170213
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.6179229E-05,   8.8821915E-05
     +,   9.1510585E-05,   9.4244686E-05,   9.7023505E-05
     +,   9.9846431E-05,   1.0271267E-04,   1.0562150E-04
     +,   1.0857213E-04,   1.1156378E-04,   1.1459563E-04
     +,   1.1766684E-04,   1.2077649E-04,   1.2392386E-04
     +,   1.2710789E-04,   1.3032790E-04,   1.3358291E-04
     +,   1.3687216E-04,   1.4019478E-04,   1.4355002E-04
     +,   1.4693703E-04,   1.5035518E-04,   1.5380369E-04
     +,   1.5728192E-04,   1.6078928E-04,   1.6432519E-04
     +,   1.6788920E-04,   1.7148076E-04,   1.7509956E-04
     +,   1.7874522E-04,   1.8241743E-04,   1.8611591E-04
     +,   1.8984060E-04,   1.9359133E-04,   1.9736798E-04
     +,   2.0117049E-04,   2.0499878E-04,   2.0885302E-04
     +,   2.1273326E-04,   2.1663930E-04,   2.2057138E-04
     +,   2.2452952E-04,   2.2851373E-04,   2.3252401E-04
     +,   2.3656027E-04,   2.4062235E-04,   2.4471010E-04
     +,   2.4882326E-04,   2.5296156E-04,   2.5712440E-04
     +,   2.6131130E-04,   2.6552155E-04,   2.6975427E-04
     +,   2.7400878E-04,   2.7828358E-04,   2.8257776E-04
     +,   2.8688964E-04,   2.9121788E-04,   2.9556069E-04
     +,   2.9991637E-04,   3.0428273E-04,   3.0865779E-04
     +,   3.1303905E-04,   3.1742430E-04,   3.2181109E-04
     +,   3.2619666E-04,   3.3057833E-04,   3.3495302E-04
     +,   3.3931807E-04,   3.4367022E-04,   3.4800655E-04
     +,   3.5232352E-04,   3.5661846E-04,   3.6088724E-04
     +,   3.6512685E-04,   3.6933398E-04,   3.7350447E-04
     +,   3.7763492E-04,   3.8172107E-04,   3.8575954E-04
     +,   3.8974566E-04,   3.9367555E-04,   3.9754430E-04
     +,   4.0134793E-04,   4.0508085E-04,   4.0873865E-04
     +,   4.1231557E-04,   4.1580631E-04,   4.1920491E-04
     +,   4.2250569E-04,   4.2570243E-04,   4.2878836E-04
     +,   4.3175690E-04,   4.3460145E-04,   4.3731483E-04
     +,   4.3988990E-04,   4.4231990E-04,   4.4459727E-04
     +,   4.4671484E-04,   4.4866602E-04,   4.5044362E-04
     +,   4.5204113E-04,   4.5345261E-04,   4.5467186E-04
     +,   4.5569387E-04,   4.5651424E-04,   4.5712839E-04
     +,   4.5753358E-04,   4.5772703E-04,   4.5770768E-04
     +,   4.5747485E-04,   4.5702938E-04,   4.5637231E-04
     +,   4.5550702E-04,   4.5443745E-04,   4.5316861E-04
     +,   4.5170690E-04,   4.5005928E-04,   4.4823508E-04
     +,   4.4624353E-04,   4.4409561E-04,   4.4180304E-04
     +,   4.3937843E-04,   4.3683496E-04,   4.3418774E-04
     +,   4.3145064E-04,   4.2863959E-04,   4.2577059E-04
     +,   4.2285954E-04,   4.1992281E-04,   4.1697707E-04
     +,   4.1403872E-04,   4.1112394E-04,   4.0824918E-04
     +,   4.0543018E-04,   4.0268217E-04,   4.0002065E-04
     +,   3.9745998E-04,   3.9501392E-04,   3.9269598E-04
     +,   3.9051895E-04,   3.8849498E-04,   3.8663513E-04
     +,   3.8495057E-04,   3.8345129E-04,   3.8214680E-04
     +,   3.8104609E-04,   3.8015700E-04,   3.7948790E-04
     +,   3.7904599E-04,   3.7883761E-04,   3.7886968E-04
     +,   3.7914811E-04,   3.7967876E-04,   3.8046704E-04
     +,   3.8151784E-04,   3.8283700E-04,   3.8442886E-04
     +,   3.8629869E-04,   3.8845130E-04,   3.9089163E-04
     +,   3.9362480E-04,   3.9665625E-04,   3.9999140E-04
     +,   4.0363614E-04,   4.0759699E-04,   4.1188096E-04
     +,   4.1649511E-04,   4.2144800E-04,   4.2674909E-04
     +,   4.3240783E-04,   4.3843527E-04,   4.4484355E-04
     +,   4.5164535E-04,   4.5885475E-04,   4.6648693E-04
     +,   4.7455839E-04,   4.8308505E-04,   4.9208442E-04
     +,   5.0157408E-04,   5.1157310E-04,   5.2209891E-04
     +,   5.3316925E-04,   5.4480141E-04,   5.5701262E-04
     +,   5.6981866E-04,   5.8323424E-04,   5.9727323E-04
     +,   6.1194965E-04,   6.2727591E-04,   6.4326532E-04
     +,   6.5993168E-04,   6.7728868E-04,   6.9535279E-04
     +,   7.1414362E-04,   7.3368556E-04,   7.5400586E-04
     +,   7.7513634E-04,   7.9711765E-04,   8.1999757E-04
     +,   8.4382930E-04,   8.6867309E-04,   8.9459872E-04
     +,   9.2168403E-04,   9.5001003E-04,   9.7966753E-04
     +,   1.0107516E-03,   1.0433602E-03,   1.0775939E-03
     +,   1.1135575E-03,   1.1513560E-03,   1.1910914E-03
     +,   1.2328626E-03,   1.2767696E-03,   1.3229072E-03
     +,   1.3713629E-03,   1.4222170E-03,   1.4755484E-03
     +,   1.5314285E-03,   1.5899162E-03,   1.6510746E-03
     +,   1.7149629E-03,   1.7816478E-03,   1.8512112E-03
     +,   1.9237831E-03,   1.9995493E-03,   2.0787930E-03
     +,   2.1619226E-03,   2.2495158E-03,   2.3423440E-03
     +,   2.4413704E-03,   2.5477612E-03,   2.6628566E-03
     +,   2.7881076E-03,   2.9250081E-03,   3.0750732E-03
     +,   3.2398056E-03,   3.4207341E-03,   3.6195272E-03
     +,   3.8381694E-03,   4.0791286E-03,   4.3454249E-03
     +,   4.6406016E-03,   4.9684136E-03,   5.3322124E-03
     +,   5.7341070E-03,   6.1739651E-03,   6.6486481E-03
     +,   7.1515269E-03,   7.6728570E-03,   8.2011968E-03
     +,   8.7259514E-03,   9.2407344E-03,   9.7472342E-03
     +,   1.0258117E-02,   1.0797498E-02,   1.1397441E-02
     +,   1.2090057E-02,   1.2897180E-02,   1.3821516E-02
     +,   1.4843947E-02,   1.5929306E-02,   1.7037941E-02
     +,   1.8137150E-02,   1.9206939E-02,   2.0241717E-02
     +,   2.1250615E-02,   2.2261389E-02,   2.3322657E-02
     +,   2.4495717E-02,   2.5830336E-02,   2.7334057E-02
     +,   2.8956790E-02,   3.0610228E-02,   3.2216229E-02
     +,   3.3751469E-02,   3.5251204E-02,   3.6761016E-02
     +,   3.8266841E-02,   3.9648406E-02,   4.0686440E-02
     +,   4.1122176E-02,   4.0735293E-02,   3.9403908E-02
     +,   3.7123114E-02,   3.3989921E-02,   3.0179350E-02
     +,   2.5926752E-02,   2.1511057E-02,   1.7222505E-02
     +,   1.3317904E-02,   9.9759782E-03,   7.2765532E-03
     +,   5.2064778E-03,   3.6876719E-03,   2.6103347E-03
     +,   1.8618043E-03,   1.3443038E-03,   9.8276359E-04
     +,   7.2464155E-04,   5.3581980E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz118 = Yx/0.283574468085106
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1847928E-04,   1.2212493E-04
     +,   1.2586583E-04,   1.2970528E-04,   1.3364655E-04
     +,   1.3769315E-04,   1.4184856E-04,   1.4611636E-04
     +,   1.5050023E-04,   1.5500392E-04,   1.5963113E-04
     +,   1.6438533E-04,   1.6927016E-04,   1.7428893E-04
     +,   1.7944470E-04,   1.8474046E-04,   1.9017857E-04
     +,   1.9576131E-04,   2.0149010E-04,   2.0736613E-04
     +,   2.1338978E-04,   2.1956077E-04,   2.2587799E-04
     +,   2.3233957E-04,   2.3894240E-04,   2.4568281E-04
     +,   2.5255571E-04,   2.5955500E-04,   2.6667328E-04
     +,   2.7390217E-04,   2.8123194E-04,   2.8865141E-04
     +,   2.9614844E-04,   3.0370933E-04,   3.1131957E-04
     +,   3.1896288E-04,   3.2662245E-04,   3.3427999E-04
     +,   3.4191684E-04,   3.4951267E-04,   3.5704719E-04
     +,   3.6449905E-04,   3.7184669E-04,   3.7906846E-04
     +,   3.8614240E-04,   3.9304662E-04,   3.9975959E-04
     +,   4.0626028E-04,   4.1252861E-04,   4.1854530E-04
     +,   4.2429171E-04,   4.2975083E-04,   4.3490727E-04
     +,   4.3974697E-04,   4.4425781E-04,   4.4842961E-04
     +,   4.5225411E-04,   4.5572515E-04,   4.5883880E-04
     +,   4.6159347E-04,   4.6398988E-04,   4.6603096E-04
     +,   4.6772181E-04,   4.6907019E-04,   4.7008513E-04
     +,   4.7077885E-04,   4.7116482E-04,   4.7125827E-04
     +,   4.7107638E-04,   4.7063784E-04,   4.6996231E-04
     +,   4.6907074E-04,   4.6798502E-04,   4.6672751E-04
     +,   4.6532153E-04,   4.6378968E-04,   4.6215547E-04
     +,   4.6044178E-04,   4.5867090E-04,   4.5686492E-04
     +,   4.5504488E-04,   4.5323043E-04,   4.5144072E-04
     +,   4.4969333E-04,   4.4800423E-04,   4.4638780E-04
     +,   4.4485685E-04,   4.4342261E-04,   4.4209458E-04
     +,   4.4087970E-04,   4.3978373E-04,   4.3881062E-04
     +,   4.3796224E-04,   4.3723872E-04,   4.3663845E-04
     +,   4.3615836E-04,   4.3579357E-04,   4.3553801E-04
     +,   4.3538419E-04,   4.3532325E-04,   4.3534552E-04
     +,   4.3544007E-04,   4.3559540E-04,   4.3579965E-04
     +,   4.3604008E-04,   4.3630388E-04,   4.3657771E-04
     +,   4.3684893E-04,   4.3710432E-04,   4.3733133E-04
     +,   4.3751783E-04,   4.3765205E-04,   4.3772336E-04
     +,   4.3772146E-04,   4.3763677E-04,   4.3746116E-04
     +,   4.3718700E-04,   4.3680827E-04,   4.3631965E-04
     +,   4.3571676E-04,   4.3499735E-04,   4.3415878E-04
     +,   4.3320059E-04,   4.3212302E-04,   4.3092750E-04
     +,   4.2961587E-04,   4.2819176E-04,   4.2665857E-04
     +,   4.2502116E-04,   4.2328483E-04,   4.2145528E-04
     +,   4.1953899E-04,   4.1754203E-04,   4.1547182E-04
     +,   4.1333504E-04,   4.1113910E-04,   4.0889098E-04
     +,   4.0659829E-04,   4.0426801E-04,   4.0190693E-04
     +,   3.9952240E-04,   3.9712118E-04,   3.9471008E-04
     +,   3.9229533E-04,   3.8988402E-04,   3.8748246E-04
     +,   3.8509723E-04,   3.8273475E-04,   3.8040252E-04
     +,   3.7810698E-04,   3.7585580E-04,   3.7365698E-04
     +,   3.7151872E-04,   3.6944973E-04,   3.6746019E-04
     +,   3.6556020E-04,   3.6376074E-04,   3.6207409E-04
     +,   3.6051334E-04,   3.5909237E-04,   3.5782621E-04
     +,   3.5673092E-04,   3.5582326E-04,   3.5512121E-04
     +,   3.5464371E-04,   3.5441003E-04,   3.5444120E-04
     +,   3.5475782E-04,   3.5538190E-04,   3.5633607E-04
     +,   3.5764286E-04,   3.5932526E-04,   3.6140720E-04
     +,   3.6391188E-04,   3.6686333E-04,   3.7028574E-04
     +,   3.7420358E-04,   3.7864110E-04,   3.8362329E-04
     +,   3.8917520E-04,   3.9532332E-04,   4.0209413E-04
     +,   4.0951514E-04,   4.1761546E-04,   4.2642604E-04
     +,   4.3597873E-04,   4.4630823E-04,   4.5745188E-04
     +,   4.6944959E-04,   4.8234404E-04,   4.9618247E-04
     +,   5.1101664E-04,   5.2690163E-04,   5.4389797E-04
     +,   5.6207302E-04,   5.8150018E-04,   6.0225953E-04
     +,   6.2443840E-04,   6.4813346E-04,   6.7345018E-04
     +,   7.0050103E-04,   7.2940666E-04,   7.6029543E-04
     +,   7.9330278E-04,   8.2856277E-04,   8.6621294E-04
     +,   9.0638670E-04,   9.4920734E-04,   9.9478499E-04
     +,   1.0432134E-03,   1.0945703E-03,   1.1489054E-03
     +,   1.2062476E-03,   1.2666135E-03,   1.3300079E-03
     +,   1.3964341E-03,   1.4659107E-03,   1.5384940E-03
     +,   1.6142982E-03,   1.6935037E-03,   1.7764018E-03
     +,   1.8633954E-03,   1.9550130E-03,   2.0519083E-03
     +,   2.1548583E-03,   2.2647330E-03,   2.3824335E-03
     +,   2.5088487E-03,   2.6447906E-03,   2.7909225E-03
     +,   2.9477105E-03,   3.1154186E-03,   3.2941655E-03
     +,   3.4840286E-03,   3.6851659E-03,   3.8980092E-03
     +,   4.1233660E-03,   4.3624290E-03,   4.6166256E-03
     +,   4.8873839E-03,   5.1757400E-03,   5.4820217E-03
     +,   5.8057876E-03,   6.1461353E-03,   6.5023503E-03
     +,   6.8747816E-03,   7.2655478E-03,   7.6787365E-03
     +,   8.1194630E-03,   8.5921120E-03,   9.0980837E-03
     +,   9.6339257E-03,   1.0191017E-02,   1.0757220E-02
     +,   1.1320538E-02,   1.1873341E-02,   1.2415677E-02
     +,   1.2956093E-02,   1.3509368E-02,   1.4091574E-02
     +,   1.4714294E-02,   1.5380701E-02,   1.6085558E-02
     +,   1.6819367E-02,   1.7575139E-02,   1.8353432E-02
     +,   1.9162294E-02,   2.0012319E-02,   2.0911071E-02
     +,   2.1861533E-02,   2.2865925E-02,   2.3929989E-02
     +,   2.5061788E-02,   2.6261833E-02,   2.7510226E-02
     +,   2.8758246E-02,   2.9931145E-02,   3.0939098E-02
     +,   3.1690057E-02,   3.2098196E-02,   3.2087870E-02
     +,   3.1597201E-02,   3.0585792E-02,   2.9046567E-02
     +,   2.7016345E-02,   2.4579782E-02,   2.1860879E-02
     +,   1.9005191E-02,   1.6157994E-02,   1.3444632E-02
     +,   1.0959912E-02,   8.7639028E-03,   6.8849581E-03
     +,   5.3243418E-03,   4.0630791E-03,   3.0681777E-03
     +,   2.2994664E-03,   1.7150987E-03,   1.2760944E-03
     +,   9.4879267E-04,   7.0588314E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz119 = Yx/0.256914893617021
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0231905E-04,   1.0644255E-04
     +,   1.1070960E-04,   1.1512254E-04,   1.1968375E-04
     +,   1.2439523E-04,   1.2925884E-04,   1.3427620E-04
     +,   1.3944862E-04,   1.4477750E-04,   1.5026373E-04
     +,   1.5590803E-04,   1.6171084E-04,   1.6767249E-04
     +,   1.7379303E-04,   1.8007212E-04,   1.8650947E-04
     +,   1.9310426E-04,   1.9985568E-04,   2.0676269E-04
     +,   2.1382370E-04,   2.2103744E-04,   2.2840172E-04
     +,   2.3591494E-04,   2.4357432E-04,   2.5137782E-04
     +,   2.5932235E-04,   2.6740468E-04,   2.7562160E-04
     +,   2.8396930E-04,   2.9244355E-04,   3.0103966E-04
     +,   3.0975297E-04,   3.1857775E-04,   3.2750799E-04
     +,   3.3653705E-04,   3.4565790E-04,   3.5486213E-04
     +,   3.6414154E-04,   3.7348634E-04,   3.8288621E-04
     +,   3.9233046E-04,   4.0180649E-04,   4.1130162E-04
     +,   4.2080157E-04,   4.3029204E-04,   4.3975702E-04
     +,   4.4917932E-04,   4.5854208E-04,   4.6782661E-04
     +,   4.7701370E-04,   4.8608391E-04,   4.9501652E-04
     +,   5.0379167E-04,   5.1238766E-04,   5.2078412E-04
     +,   5.2896008E-04,   5.3689489E-04,   5.4456887E-04
     +,   5.5196241E-04,   5.5905734E-04,   5.6583679E-04
     +,   5.7228509E-04,   5.7838764E-04,   5.8413355E-04
     +,   5.8951176E-04,   5.9451524E-04,   5.9913826E-04
     +,   6.0337811E-04,   6.0723512E-04,   6.1071134E-04
     +,   6.1381306E-04,   6.1654847E-04,   6.1892858E-04
     +,   6.2096782E-04,   6.2268169E-04,   6.2409113E-04
     +,   6.2521530E-04,   6.2607927E-04,   6.2670768E-04
     +,   6.2712730E-04,   6.2736688E-04,   6.2745356E-04
     +,   6.2741805E-04,   6.2728912E-04,   6.2709575E-04
     +,   6.2686647E-04,   6.2662823E-04,   6.2640751E-04
     +,   6.2622764E-04,   6.2611047E-04,   6.2607537E-04
     +,   6.2613905E-04,   6.2631490E-04,   6.2661298E-04
     +,   6.2704069E-04,   6.2760076E-04,   6.2829419E-04
     +,   6.2911655E-04,   6.3006044E-04,   6.3111621E-04
     +,   6.3226954E-04,   6.3350389E-04,   6.3480000E-04
     +,   6.3613470E-04,   6.3748460E-04,   6.3882337E-04
     +,   6.4012274E-04,   6.4135494E-04,   6.4248958E-04
     +,   6.4349780E-04,   6.4434967E-04,   6.4501591E-04
     +,   6.4546935E-04,   6.4568251E-04,   6.4563117E-04
     +,   6.4529269E-04,   6.4464589E-04,   6.4367370E-04
     +,   6.4236019E-04,   6.4069440E-04,   6.3866709E-04
     +,   6.3627330E-04,   6.3351094E-04,   6.3038070E-04
     +,   6.2688772E-04,   6.2303961E-04,   6.1884773E-04
     +,   6.1432546E-04,   6.0949067E-04,   6.0436170E-04
     +,   5.9896125E-04,   5.9331255E-04,   5.8744237E-04
     +,   5.8137788E-04,   5.7514751E-04,   5.6878210E-04
     +,   5.6231202E-04,   5.5576843E-04,   5.4918305E-04
     +,   5.4258743E-04,   5.3601369E-04,   5.2949268E-04
     +,   5.2305491E-04,   5.1673112E-04,   5.1055005E-04
     +,   5.0454034E-04,   4.9872918E-04,   4.9314409E-04
     +,   4.8780977E-04,   4.8275106E-04,   4.7799191E-04
     +,   4.7355506E-04,   4.6946254E-04,   4.6573585E-04
     +,   4.6239546E-04,   4.5946226E-04,   4.5695587E-04
     +,   4.5489642E-04,   4.5330345E-04,   4.5219733E-04
     +,   4.5159820E-04,   4.5152640E-04,   4.5200280E-04
     +,   4.5304882E-04,   4.5468719E-04,   4.5693998E-04
     +,   4.5983074E-04,   4.6338272E-04,   4.6762050E-04
     +,   4.7256789E-04,   4.7824881E-04,   4.8468760E-04
     +,   4.9190730E-04,   4.9992942E-04,   5.0877541E-04
     +,   5.1846431E-04,   5.2901241E-04,   5.4043415E-04
     +,   5.5274036E-04,   5.6593906E-04,   5.8003393E-04
     +,   5.9502502E-04,   6.1090803E-04,   6.2767544E-04
     +,   6.4531516E-04,   6.6380814E-04,   6.8313617E-04
     +,   7.0327480E-04,   7.2419504E-04,   7.4586790E-04
     +,   7.6826086E-04,   7.9133833E-04,   8.1506465E-04
     +,   8.3940371E-04,   8.6432043E-04,   8.8978093E-04
     +,   9.1575237E-04,   9.4220939E-04,   9.6913229E-04
     +,   9.9650724E-04,   1.0243303E-03,   1.0526112E-03
     +,   1.0813745E-03,   1.1106575E-03,   1.1405186E-03
     +,   1.1710337E-03,   1.2022966E-03,   1.2344200E-03
     +,   1.2675340E-03,   1.3017836E-03,   1.3373235E-03
     +,   1.3743124E-03,   1.4129173E-03,   1.4532976E-03
     +,   1.4956082E-03,   1.5399938E-03,   1.5865929E-03
     +,   1.6355411E-03,   1.6869738E-03,   1.7410537E-03
     +,   1.7979814E-03,   1.8580336E-03,   1.9215917E-03
     +,   1.9892037E-03,   2.0616152E-03,   2.1398114E-03
     +,   2.2250491E-03,   2.3188642E-03,   2.4230310E-03
     +,   2.5394845E-03,   2.6701798E-03,   2.8169211E-03
     +,   2.9811433E-03,   3.1636490E-03,   3.3644394E-03
     +,   3.5825346E-03,   3.8159210E-03,   4.0616402E-03
     +,   4.3160408E-03,   4.5751748E-03,   4.8353183E-03
     +,   5.0936779E-03,   5.3491793E-03,   5.6032347E-03
     +,   5.8604581E-03,   6.1291587E-03,   6.4214948E-03
     +,   6.7529306E-03,   7.1409596E-03,   7.6029934E-03
     +,   8.1534777E-03,   8.8005541E-03,   9.5430333E-03
     +,   1.0368627E-02,   1.1254099E-02,   1.2168061E-02
     +,   1.3076400E-02,   1.3949119E-02,   1.4766742E-02
     +,   1.5524519E-02,   1.6233262E-02,   1.6916035E-02
     +,   1.7601788E-02,   1.8317183E-02,   1.9079087E-02
     +,   1.9890560E-02,   2.0741217E-02,   2.1613579E-02
     +,   2.2491315E-02,   2.3364358E-02,   2.4228482E-02
     +,   2.5078552E-02,   2.5901003E-02,   2.6671609E-02
     +,   2.7359929E-02,   2.7937673E-02,   2.8382896E-02
     +,   2.8676355E-02,   2.8791873E-02,   2.8688325E-02
     +,   2.8309878E-02,   2.7597103E-02,   2.6504977E-02
     +,   2.5019504E-02,   2.3167303E-02,   2.1014318E-02
     +,   1.8655960E-02,   1.6202914E-02,   1.3765544E-02
     +,   1.1442208E-02,   9.3101151E-03,   7.4214884E-03
     +,   5.8024772E-03,   4.4562570E-03,   3.3675556E-03
     +,   2.5090112E-03,   1.8468760E-03,   1.3461391E-03
     +,   9.7379525E-04,   7.0093025E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz120 = Yx/0.253521739130435
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.8647507E-05,   5.0083356E-05
     +,   5.1560513E-05,   5.3081112E-05,   5.4647444E-05
     +,   5.6261928E-05,   5.7927209E-05,   5.9646089E-05
     +,   6.1421546E-05,   6.3256848E-05,   6.5155451E-05
     +,   6.7121095E-05,   6.9157722E-05,   7.1269737E-05
     +,   7.3461757E-05,   7.5738899E-05,   7.8106663E-05
     +,   8.0571081E-05,   8.3138759E-05,   8.5816944E-05
     +,   8.8613597E-05,   9.1537571E-05,   9.4598523E-05
     +,   9.7807446E-05,   1.0117605E-04,   1.0471778E-04
     +,   1.0844730E-04,   1.1238085E-04,   1.1653644E-04
     +,   1.2093381E-04,   1.2559482E-04,   1.3054321E-04
     +,   1.3580495E-04,   1.4140800E-04,   1.4738282E-04
     +,   1.5376190E-04,   1.6057977E-04,   1.6787302E-04
     +,   1.7568067E-04,   1.8404258E-04,   1.9300134E-04
     +,   2.0260063E-04,   2.1288579E-04,   2.2390412E-04
     +,   2.3570485E-04,   2.4833999E-04,   2.6186483E-04
     +,   2.7633950E-04,   2.9183002E-04,   3.0841108E-04
     +,   3.2616753E-04,   3.4519756E-04,   3.6561518E-04
     +,   3.8755513E-04,   4.1117164E-04,   4.3664640E-04
     +,   4.6418750E-04,   4.9403193E-04,   5.2644731E-04
     +,   5.6173257E-04,   6.0021743E-04,   6.4226368E-04
     +,   6.8826211E-04,   7.3863915E-04,   7.9385558E-04
     +,   8.5440744E-04,   9.2084141E-04,   9.9374878E-04
     +,   1.0737935E-03,   1.1617022E-03,   1.2583010E-03
     +,   1.3645142E-03,   1.4814137E-03,   1.6102483E-03
     +,   1.7525333E-03,   1.9101424E-03,   2.0854003E-03
     +,   2.2811773E-03,   2.5009459E-03,   2.7486992E-03
     +,   3.0287416E-03,   3.3454802E-03,   3.7030582E-03
     +,   4.1053034E-03,   4.5557269E-03,   5.0580385E-03
     +,   5.6166197E-03,   6.2371870E-03,   6.9269519E-03
     +,   7.6949089E-03,   8.5523138E-03,   9.5141381E-03
     +,   1.0601649E-02,   1.1844226E-02,   1.3277554E-02
     +,   1.4935364E-02,   1.6834855E-02,   1.8957729E-02
     +,   2.1236282E-02,   2.3553843E-02,   2.5772184E-02
     +,   2.7783148E-02,   2.9561585E-02,   3.1172391E-02
     +,   3.2705463E-02,   3.4167849E-02,   3.5419971E-02
     +,   3.6224555E-02,   3.6387518E-02,   3.5880253E-02
     +,   3.4845375E-02,   3.3487331E-02,   3.1951945E-02
     +,   3.0289067E-02,   2.8503556E-02,   2.6621830E-02
     +,   2.4714300E-02,   2.2868171E-02,   2.1148635E-02
     +,   1.9577844E-02,   1.8140877E-02,   1.6807126E-02
     +,   1.5551648E-02,   1.4365016E-02,   1.3250330E-02
     +,   1.2213244E-02,   1.1253292E-02,   1.0361721E-02
     +,   9.5254108E-03,   8.7332791E-03,   7.9808366E-03
     +,   7.2712866E-03,   6.6127512E-03,   6.0141189E-03
     +,   5.4810331E-03,   5.0138836E-03,   4.6079750E-03
     +,   4.2551518E-03,   3.9460249E-03,   3.6718727E-03
     +,   3.4257795E-03,   3.2028693E-03,   2.9999972E-03
     +,   2.8151975E-03,   2.6471440E-03,   2.4947184E-03
     +,   2.3568147E-03,   2.2323015E-03,   2.1200401E-03
     +,   2.0189488E-03,   1.9280597E-03,   1.8465394E-03
     +,   1.7736757E-03,   1.7088309E-03,   1.6514119E-03
     +,   1.6008376E-03,   1.5565048E-03,   1.5177787E-03
     +,   1.4839934E-03,   1.4544699E-03,   1.4285168E-03
     +,   1.4054604E-03,   1.3846611E-03,   1.3655263E-03
     +,   1.3475220E-03,   1.3301894E-03,   1.3131448E-03
     +,   1.2960907E-03,   1.2788071E-03,   1.2611540E-03
     +,   1.2430693E-03,   1.2245566E-03,   1.2056771E-03
     +,   1.1865402E-03,   1.1672936E-03,   1.1481068E-03
     +,   1.1291630E-03,   1.1106456E-03,   1.0927316E-03
     +,   1.0755772E-03,   1.0593119E-03,   1.0440379E-03
     +,   1.0298208E-03,   1.0166904E-03,   1.0046402E-03
     +,   9.9363353E-04,   9.8360260E-04,   9.7445422E-04
     +,   9.6607523E-04,   9.5834315E-04,   9.5112377E-04
     +,   9.4428461E-04,   9.3769742E-04,   9.3124318E-04
     +,   9.2481816E-04,   9.1833295E-04,   9.1171940E-04
     +,   9.0493145E-04,   8.9794159E-04,   8.9074526E-04
     +,   8.8335649E-04,   8.7580737E-04,   8.6814456E-04
     +,   8.6042762E-04,   8.5272483E-04,   8.4510964E-04
     +,   8.3765795E-04,   8.3044666E-04,   8.2354731E-04
     +,   8.1702560E-04,   8.1093871E-04,   8.0533361E-04
     +,   8.0024631E-04,   7.9569995E-04,   7.9170510E-04
     +,   7.8826112E-04,   7.8535394E-04,   7.8296062E-04
     +,   7.8104855E-04,   7.7957707E-04,   7.7849941E-04
     +,   7.7776570E-04,   7.7732326E-04,   7.7711995E-04
     +,   7.7710423E-04,   7.7722850E-04,   7.7744853E-04
     +,   7.7772618E-04,   7.7802874E-04,   7.7833043E-04
     +,   7.7861047E-04,   7.7885640E-04,   7.7905989E-04
     +,   7.7921757E-04,   7.7932928E-04,   7.7939837E-04
     +,   7.7942916E-04,   7.7942491E-04,   7.7938952E-04
     +,   7.7932113E-04,   7.7921635E-04,   7.7906542E-04
     +,   7.7885465E-04,   7.7856210E-04,   7.7816029E-04
     +,   7.7761494E-04,   7.7688618E-04,   7.7592657E-04
     +,   7.7468465E-04,   7.7310554E-04,   7.7112997E-04
     +,   7.6869800E-04,   7.6574797E-04,   7.6222111E-04
     +,   7.5805956E-04,   7.5320905E-04,   7.4762187E-04
     +,   7.4125623E-04,   7.3407631E-04,   7.2605570E-04
     +,   7.1717601E-04,   7.0742919E-04,   6.9681549E-04
     +,   6.8534445E-04,   6.7303627E-04,   6.5991865E-04
     +,   6.4602785E-04,   6.3140824E-04,   6.1611191E-04
     +,   6.0019520E-04,   5.8371964E-04,   5.6675175E-04
     +,   5.4936158E-04,   5.3161959E-04,   5.1359780E-04
     +,   4.9536937E-04,   4.7700535E-04,   4.5857672E-04
     +,   4.4015099E-04,   4.2179425E-04,   4.0356760E-04
     +,   3.8553076E-04,   3.6773676E-04,   3.5023704E-04
     +,   3.3307611E-04,   3.1629612E-04,   2.9993331E-04
     +,   2.8401910E-04,   2.6858196E-04,   2.5364413E-04
     +,   2.3922567E-04,   2.2534032E-04,   2.1200019E-04
     +,   1.9921178E-04,   1.8697999E-04,   1.7530491E-04
     +,   1.6418517E-04,   1.5361540E-04,   1.4358919E-04
     +,   1.3409648E-04,   1.2512672E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz75 = Yx/0.274489361702128
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.0019425E-05,   6.0893461E-05
     +,   6.1743020E-05,   6.2570041E-05,   6.3376989E-05
     +,   6.4166765E-05,   6.4942840E-05,   6.5709173E-05
     +,   6.6470224E-05,   6.7231063E-05,   6.7997265E-05
     +,   6.8774934E-05,   6.9570691E-05,   7.0391710E-05
     +,   7.1245624E-05,   7.2140603E-05,   7.3085153E-05
     +,   7.4088282E-05,   7.5159347E-05,   7.6307959E-05
     +,   7.7544028E-05,   7.8877667E-05,   8.0319085E-05
     +,   8.1878556E-05,   8.3566294E-05,   8.5392436E-05
     +,   8.7366898E-05,   8.9499285E-05,   9.1798844E-05
     +,   9.4274379E-05,   9.6934062E-05,   9.9785539E-05
     +,   1.0283566E-04,   1.0609061E-04,   1.0955568E-04
     +,   1.1323542E-04,   1.1713352E-04,   1.2125274E-04
     +,   1.2559535E-04,   1.3016243E-04,   1.3495493E-04
     +,   1.3997294E-04,   1.4521630E-04,   1.5068472E-04
     +,   1.5637782E-04,   1.6229558E-04,   1.6843842E-04
     +,   1.7480750E-04,   1.8140515E-04,   1.8823483E-04
     +,   1.9530163E-04,   2.0261246E-04,   2.1017602E-04
     +,   2.1800358E-04,   2.2610782E-04,   2.3450446E-04
     +,   2.4321071E-04,   2.5224590E-04,   2.6163104E-04
     +,   2.7138836E-04,   2.8154094E-04,   2.9211238E-04
     +,   3.0312481E-04,   3.1460103E-04,   3.2656186E-04
     +,   3.3902479E-04,   3.5200678E-04,   3.6551998E-04
     +,   3.7957579E-04,   3.9418167E-04,   4.0934491E-04
     +,   4.2507175E-04,   4.4137231E-04,   4.5826021E-04
     +,   4.7576008E-04,   4.9391162E-04,   5.1277434E-04
     +,   5.3243671E-04,   5.5302505E-04,   5.7471363E-04
     +,   5.9773057E-04,   6.2237273E-04,   6.4900913E-04
     +,   6.7809026E-04,   7.1014627E-04,   7.4578641E-04
     +,   7.8568200E-04,   8.3055551E-04,   8.8114321E-04
     +,   9.3817251E-04,   1.0023284E-03,   1.0742234E-03
     +,   1.1543948E-03,   1.2433341E-03,   1.3415500E-03
     +,   1.4496741E-03,   1.5686533E-03,   1.6999457E-03
     +,   1.8458358E-03,   2.0097152E-03,   2.1964966E-03
     +,   2.4129192E-03,   2.6678250E-03,   2.9720152E-03
     +,   3.3376440E-03,   3.7768548E-03,   4.2999075E-03
     +,   4.9134642E-03,   5.6200740E-03,   6.4195455E-03
     +,   7.3125204E-03,   8.3052740E-03,   9.4127934E-03
     +,   1.0658255E-02,   1.2066569E-02,   1.3654440E-02
     +,   1.5418762E-02,   1.7328525E-02,   1.9321300E-02
     +,   2.1309095E-02,   2.3193344E-02,   2.4891203E-02
     +,   2.6368236E-02,   2.7662473E-02,   2.8874414E-02
     +,   3.0107407E-02,   3.1386796E-02,   3.2618031E-02
     +,   3.3627532E-02,   3.4256723E-02,   3.4430388E-02
     +,   3.4148511E-02,   3.3434432E-02,   3.2314520E-02
     +,   3.0847721E-02,   2.9144736E-02,   2.7325327E-02
     +,   2.5454411E-02,   2.3540232E-02,   2.1595739E-02
     +,   1.9684536E-02,   1.7899690E-02,   1.6309634E-02
     +,   1.4931674E-02,   1.3745938E-02,   1.2720680E-02
     +,   1.1824961E-02,   1.1028993E-02,   1.0303651E-02
     +,   9.6240761E-03,   8.9744907E-03,   8.3494904E-03
     +,   7.7510858E-03,   7.1839299E-03,   6.6517419E-03
     +,   6.1560208E-03,   5.6966334E-03,   5.2728397E-03
     +,   4.8841676E-03,   4.5305509E-03,   4.2120172E-03
     +,   3.9282758E-03,   3.6784017E-03,   3.4606021E-03
     +,   3.2721828E-03,   3.1097489E-03,   2.9694708E-03
     +,   2.8474240E-03,   2.7399114E-03,   2.6437440E-03
     +,   2.5563959E-03,   2.4760582E-03,   2.4015659E-03
     +,   2.3322925E-03,   2.2679903E-03,   2.2086238E-03
     +,   2.1542276E-03,   2.1048042E-03,   2.0602434E-03
     +,   2.0202878E-03,   1.9845148E-03,   1.9523557E-03
     +,   1.9231141E-03,   1.8959948E-03,   1.8701496E-03
     +,   1.8447143E-03,   1.8188440E-03,   1.7917614E-03
     +,   1.7627842E-03,   1.7313670E-03,   1.6971134E-03
     +,   1.6598041E-03,   1.6194001E-03,   1.5760423E-03
     +,   1.5300295E-03,   1.4818117E-03,   1.4319574E-03
     +,   1.3811184E-03,   1.3299990E-03,   1.2793164E-03
     +,   1.2297744E-03,   1.1820321E-03,   1.1366775E-03
     +,   1.0942117E-03,   1.0550431E-03,   1.0194728E-03
     +,   9.8769984E-04,   9.5982826E-04,   9.3587022E-04
     +,   9.1575691E-04,   8.9935231E-04,   8.8646397E-04
     +,   8.7685237E-04,   8.7024417E-04,   8.6633844E-04
     +,   8.6481898E-04,   8.6535618E-04,   8.6761487E-04
     +,   8.7126001E-04,   8.7595871E-04,   8.8138587E-04
     +,   8.8722457E-04,   8.9317275E-04,   8.9894439E-04
     +,   9.0427266E-04,   9.0891530E-04,   9.1265433E-04
     +,   9.1530039E-04,   9.1669656E-04,   9.1671798E-04
     +,   9.1527338E-04,   9.1230671E-04,   9.0779539E-04
     +,   9.0174883E-04,   8.9420774E-04,   8.8524038E-04
     +,   8.7493891E-04,   8.6341484E-04,   8.5079775E-04
     +,   8.3722564E-04,   8.2284253E-04,   8.0779736E-04
     +,   7.9223578E-04,   7.7629596E-04,   7.6010876E-04
     +,   7.4379228E-04,   7.2745309E-04,   7.1118120E-04
     +,   6.9505058E-04,   6.7912246E-04,   6.6344114E-04
     +,   6.4803642E-04,   6.3292787E-04,   6.1812159E-04
     +,   6.0361490E-04,   5.8939651E-04,   5.7545048E-04
     +,   5.6175567E-04,   5.4828794E-04,   5.3502055E-04
     +,   5.2192848E-04,   5.0898630E-04,   4.9616920E-04
     +,   4.8345482E-04,   4.7082437E-04,   4.5825992E-04
     +,   4.4574725E-04,   4.3327553E-04,   4.2083653E-04
     +,   4.0842491E-04,   3.9603745E-04,   3.8367472E-04
     +,   3.7133961E-04,   3.5903664E-04,   3.4677243E-04
     +,   3.3455715E-04,   3.2240071E-04,   3.1031657E-04
     +,   2.9831805E-04,   2.8642127E-04,   2.7464196E-04
     +,   2.6299799E-04,   2.5150663E-04,   2.4018694E-04
     +,   2.2905644E-04,   2.1813448E-04,   2.0743857E-04
     +,   1.9698593E-04,   1.8679396E-04,   1.7687779E-04
     +,   1.6725252E-04,   1.5793082E-04,   1.4892493E-04
     +,   1.4024442E-04,   1.3189821E-04,   1.2389236E-04
     +,   1.1623218E-04,   1.0892010E-04,   1.0195775E-04
     +,   9.5344105E-05,   8.9077199E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz80 = Yx/0.269276595744681
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0691986E-05,   5.3450651E-05
     +,   5.6329711E-05,   5.9327998E-05,   6.2443556E-05
     +,   6.5673572E-05,   6.9014321E-05,   7.2461182E-05
     +,   7.6008546E-05,   7.9649966E-05,   8.3377920E-05
     +,   8.7183871E-05,   9.1058479E-05,   9.4991352E-05
     +,   9.8971250E-05,   1.0298612E-04,   1.0702304E-04
     +,   1.1106850E-04,   1.1510832E-04,   1.1912778E-04
     +,   1.2311173E-04,   1.2704478E-04,   1.3091130E-04
     +,   1.3469582E-04,   1.3838259E-04,   1.4195660E-04
     +,   1.4540285E-04,   1.4870708E-04,   1.5185577E-04
     +,   1.5483615E-04,   1.5763652E-04,   1.6024632E-04
     +,   1.6265626E-04,   1.6485844E-04,   1.6684651E-04
     +,   1.6861581E-04,   1.7016318E-04,   1.7148739E-04
     +,   1.7258908E-04,   1.7347056E-04,   1.7413621E-04
     +,   1.7459222E-04,   1.7484659E-04,   1.7490935E-04
     +,   1.7479209E-04,   1.7450820E-04,   1.7407267E-04
     +,   1.7350211E-04,   1.7281443E-04,   1.7202884E-04
     +,   1.7116567E-04,   1.7024631E-04,   1.6929279E-04
     +,   1.6832794E-04,   1.6737510E-04,   1.6645780E-04
     +,   1.6559979E-04,   1.6482479E-04,   1.6415612E-04
     +,   1.6361706E-04,   1.6323020E-04,   1.6301744E-04
     +,   1.6300006E-04,   1.6319829E-04,   1.6363162E-04
     +,   1.6431832E-04,   1.6527581E-04,   1.6652042E-04
     +,   1.6806755E-04,   1.6993177E-04,   1.7212685E-04
     +,   1.7466606E-04,   1.7756243E-04,   1.8082878E-04
     +,   1.8447851E-04,   1.8852569E-04,   1.9298562E-04
     +,   1.9787473E-04,   2.0321232E-04,   2.0902028E-04
     +,   2.1532329E-04,   2.2215067E-04,   2.2953541E-04
     +,   2.3751639E-04,   2.4613715E-04,   2.5544874E-04
     +,   2.6550802E-04,   2.7638051E-04,   2.8813927E-04
     +,   3.0086853E-04,   3.1466354E-04,   3.2963211E-04
     +,   3.4589774E-04,   3.6360367E-04,   3.8291581E-04
     +,   4.0402560E-04,   4.2715768E-04,   4.5257056E-04
     +,   4.8056638E-04,   5.1148835E-04,   5.4572901E-04
     +,   5.8372226E-04,   6.2594772E-04,   6.7291420E-04
     +,   7.2515709E-04,   7.8322145E-04,   8.4764120E-04
     +,   9.1892749E-04,   9.9756615E-04,   1.0840158E-03
     +,   1.1787240E-03,   1.2821972E-03,   1.3950649E-03
     +,   1.5182258E-03,   1.6529688E-03,   1.8011651E-03
     +,   1.9653367E-03,   2.1487470E-03,   2.3552298E-03
     +,   2.5889478E-03,   2.8539193E-03,   3.1534610E-03
     +,   3.4897646E-03,   3.8637922E-03,   4.2756479E-03
     +,   4.7253766E-03,   5.2140392E-03,   5.7441713E-03
     +,   6.3194446E-03,   6.9429688E-03,   7.6153544E-03
     +,   8.3332267E-03,   9.0904003E-03,   9.8819993E-03
     +,   1.0712258E-02,   1.1602694E-02,   1.2595313E-02
     +,   1.3744127E-02,   1.5092380E-02,   1.6643837E-02
     +,   1.8346192E-02,   2.0102860E-02,   2.1812815E-02
     +,   2.3417542E-02,   2.4925508E-02,   2.6398728E-02
     +,   2.7907267E-02,   2.9470550E-02,   3.1006485E-02
     +,   3.2314878E-02,   3.3129167E-02,   3.3237718E-02
     +,   3.2610349E-02,   3.1432517E-02,   3.0005863E-02
     +,   2.8579501E-02,   2.7233768E-02,   2.5890414E-02
     +,   2.4417726E-02,   2.2738127E-02,   2.0877244E-02
     +,   1.8952645E-02,   1.7124237E-02,   1.5529722E-02
     +,   1.4230540E-02,   1.3195245E-02,   1.2328596E-02
     +,   1.1524969E-02,   1.0713631E-02,   9.8743923E-03
     +,   9.0262257E-03,   8.2042832E-03,   7.4405856E-03
     +,   6.7550708E-03,   6.1555626E-03,   5.6415796E-03
     +,   5.2085426E-03,   4.8502949E-03,   4.5599928E-03
     +,   4.3303072E-03,   4.1536102E-03,   4.0222802E-03
     +,   3.9290194E-03,   3.8671556E-03,   3.8307242E-03
     +,   3.8144577E-03,   3.8136556E-03,   3.8240715E-03
     +,   3.8418050E-03,   3.8632024E-03,   3.8848186E-03
     +,   3.9033750E-03,   3.9157867E-03,   3.9192303E-03
     +,   3.9112517E-03,   3.8898904E-03,   3.8538235E-03
     +,   3.8024508E-03,   3.7359504E-03,   3.6552716E-03
     +,   3.5620641E-03,   3.4585495E-03,   3.3473654E-03
     +,   3.2313631E-03,   3.1134400E-03,   2.9963346E-03
     +,   2.8824902E-03,   2.7739420E-03,   2.6722266E-03
     +,   2.5783493E-03,   2.4927785E-03,   2.4154973E-03
     +,   2.3460581E-03,   2.2836560E-03,   2.2272272E-03
     +,   2.1755602E-03,   2.1273722E-03,   2.0813986E-03
     +,   2.0364665E-03,   1.9915560E-03,   1.9458316E-03
     +,   1.8986702E-03,   1.8496719E-03,   1.7986570E-03
     +,   1.7456410E-03,   1.6908123E-03,   1.6345099E-03
     +,   1.5771796E-03,   1.5193350E-03,   1.4615272E-03
     +,   1.4043150E-03,   1.3482342E-03,   1.2937681E-03
     +,   1.2413351E-03,   1.1912802E-03,   1.1438624E-03
     +,   1.0992551E-03,   1.0575521E-03,   1.0187732E-03
     +,   9.8286616E-04,   9.4972679E-04,   9.1920712E-04
     +,   8.9112663E-04,   8.6528237E-04,   8.4146060E-04
     +,   8.1944681E-04,   7.9903234E-04,   7.8001764E-04
     +,   7.6221948E-04,   7.4547296E-04,   7.2963064E-04
     +,   7.1456440E-04,   7.0016464E-04,   6.8633823E-04
     +,   6.7300524E-04,   6.6009827E-04,   6.4756029E-04
     +,   6.3534291E-04,   6.2340149E-04,   6.1169692E-04
     +,   6.0019299E-04,   5.8885559E-04,   5.7765137E-04
     +,   5.6654750E-04,   5.5551314E-04,   5.4451666E-04
     +,   5.3352816E-04,   5.2251917E-04,   5.1146315E-04
     +,   5.0033524E-04,   4.8911280E-04,   4.7777744E-04
     +,   4.6631403E-04,   4.5471053E-04,   4.4295931E-04
     +,   4.3105768E-04,   4.1900616E-04,   4.0681093E-04
     +,   3.9448094E-04,   3.8203088E-04,   3.6947741E-04
     +,   3.5684233E-04,   3.4414892E-04,   3.3142464E-04
     +,   3.1869748E-04,   3.0599904E-04,   2.9336006E-04
     +,   2.8081256E-04,   2.6838959E-04,   2.5612221E-04
     +,   2.4404247E-04,   2.3217910E-04,   2.2056133E-04
     +,   2.0921437E-04,   1.9816305E-04,   1.8742810E-04
     +,   1.7702911E-04,   1.6698158E-04,   1.5729926E-04
     +,   1.4799209E-04,   1.3906842E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz85 = Yx/0.268234042553191
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1650696E-05,   3.2597516E-05
     +,   3.3562894E-05,   3.4546418E-05,   3.5547691E-05
     +,   3.6566275E-05,   3.7601632E-05,   3.8653288E-05
     +,   3.9720646E-05,   4.0803192E-05,   4.1900337E-05
     +,   4.3011521E-05,   4.4136170E-05,   4.5273770E-05
     +,   4.6423818E-05,   4.7585905E-05,   4.8759659E-05
     +,   4.9944807E-05,   5.1141244E-05,   5.2348954E-05
     +,   5.3568096E-05,   5.4799031E-05,   5.6042336E-05
     +,   5.7298883E-05,   5.8569702E-05,   5.9856287E-05
     +,   6.1160368E-05,   6.2484098E-05,   6.3829961E-05
     +,   6.5200984E-05,   6.6600536E-05,   6.8032488E-05
     +,   6.9501250E-05,   7.1011702E-05,   7.2569193E-05
     +,   7.4179690E-05,   7.5849588E-05,   7.7585733E-05
     +,   7.9395621E-05,   8.1286904E-05,   8.3267885E-05
     +,   8.5347041E-05,   8.7533175E-05,   8.9835223E-05
     +,   9.2262220E-05,   9.4823277E-05,   9.7527154E-05
     +,   1.0038257E-04,   1.0339774E-04,   1.0658035E-04
     +,   1.0993743E-04,   1.1347510E-04,   1.1719846E-04
     +,   1.2111173E-04,   1.2521734E-04,   1.2951675E-04
     +,   1.3400952E-04,   1.3869372E-04,   1.4356551E-04
     +,   1.4861925E-04,   1.5384736E-04,   1.5924043E-04
     +,   1.6478682E-04,   1.7047336E-04,   1.7628515E-04
     +,   1.8220507E-04,   1.8821524E-04,   1.9429559E-04
     +,   2.0042573E-04,   2.0658389E-04,   2.1274807E-04
     +,   2.1889569E-04,   2.2500483E-04,   2.3105345E-04
     +,   2.3702066E-04,   2.4288699E-04,   2.4863423E-04
     +,   2.5424585E-04,   2.5970821E-04,   2.6501014E-04
     +,   2.7014289E-04,   2.7510131E-04,   2.7988307E-04
     +,   2.8448954E-04,   2.8892531E-04,   2.9319857E-04
     +,   2.9732045E-04,   3.0130587E-04,   3.0517203E-04
     +,   3.0893917E-04,   3.1263017E-04,   3.1626920E-04
     +,   3.1988250E-04,   3.2349714E-04,   3.2714164E-04
     +,   3.3084382E-04,   3.3463261E-04,   3.3853593E-04
     +,   3.4258192E-04,   3.4679801E-04,   3.5121155E-04
     +,   3.5584989E-04,   3.6074116E-04,   3.6591402E-04
     +,   3.7140003E-04,   3.7723340E-04,   3.8345254E-04
     +,   3.9010085E-04,   3.9722901E-04,   4.0489552E-04
     +,   4.1316752E-04,   4.2212417E-04,   4.3185576E-04
     +,   4.4246946E-04,   4.5408745E-04,   4.6685582E-04
     +,   4.8094490E-04,   4.9655989E-04,   5.1394448E-04
     +,   5.3339370E-04,   5.5526179E-04,   5.7997147E-04
     +,   6.0802180E-04,   6.3999736E-04,   6.7657046E-04
     +,   7.1849435E-04,   7.6660665E-04,   8.2180882E-04
     +,   8.8506116E-04,   9.5735246E-04,   1.0396987E-03
     +,   1.1331091E-03,   1.2386189E-03,   1.3572994E-03
     +,   1.4903722E-03,   1.6393547E-03,   1.8062599E-03
     +,   1.9938208E-03,   2.2056454E-03,   2.4461276E-03
     +,   2.7200202E-03,   3.0316329E-03,   3.3837478E-03
     +,   3.7766339E-03,   4.2076493E-03,   4.6722582E-03
     +,   5.1664612E-03,   5.6902887E-03,   6.2509826E-03
     +,   6.8638055E-03,   7.5489869E-03,   8.3252825E-03
     +,   9.2032272E-03,   1.0181868E-02,   1.1250628E-02
     +,   1.2394262E-02,   1.3596567E-02,   1.4841846E-02
     +,   1.6116807E-02,   1.7415011E-02,   1.8739479E-02
     +,   2.0097269E-02,   2.1490026E-02,   2.2909425E-02
     +,   2.4330916E-02,   2.5689708E-02,   2.6849907E-02
     +,   2.7617332E-02,   2.7826307E-02,   2.7444690E-02
     +,   2.6595155E-02,   2.5464289E-02,   2.4191961E-02
     +,   2.2853531E-02,   2.1534598E-02,   2.0389471E-02
     +,   1.9598737E-02,   1.9258047E-02,   1.9304922E-02
     +,   1.9546984E-02,   1.9761575E-02,   1.9788012E-02
     +,   1.9562112E-02,   1.9096769E-02,   1.8442420E-02
     +,   1.7655877E-02,   1.6787330E-02,   1.5880041E-02
     +,   1.4973374E-02,   1.4102855E-02,   1.3295634E-02
     +,   1.2565853E-02,   1.1913139E-02,   1.1325994E-02
     +,   1.0788740E-02,   1.0288161E-02,   9.8168403E-03
     +,   9.3717696E-03,   8.9505566E-03,   8.5478639E-03
     +,   8.1546735E-03,   7.7606738E-03,   7.3582572E-03
     +,   6.9459956E-03,   6.5295584E-03,   6.1197835E-03
     +,   5.7290592E-03,   5.3677312E-03,   5.0417585E-03
     +,   4.7523705E-03,   4.4971956E-03,   4.2721308E-03
     +,   4.0729688E-03,   3.8964166E-03,   3.7403363E-03
     +,   3.6034526E-03,   3.4847374E-03,   3.3828637E-03
     +,   3.2958661E-03,   3.2210783E-03,   3.1552650E-03
     +,   3.0949523E-03,   3.0367891E-03,   2.9778909E-03
     +,   2.9160839E-03,   2.8500592E-03,   2.7793928E-03
     +,   2.7044769E-03,   2.6263350E-03,   2.5464399E-03
     +,   2.4664844E-03,   2.3881663E-03,   2.3130099E-03
     +,   2.2422413E-03,   2.1767132E-03,   2.1168690E-03
     +,   2.0627538E-03,   2.0140682E-03,   1.9702318E-03
     +,   1.9304494E-03,   1.8938028E-03,   1.8593199E-03
     +,   1.8260448E-03,   1.7930836E-03,   1.7596541E-03
     +,   1.7251138E-03,   1.6889770E-03,   1.6509180E-03
     +,   1.6107718E-03,   1.5685249E-03,   1.5242919E-03
     +,   1.4782973E-03,   1.4308577E-03,   1.3823473E-03
     +,   1.3331729E-03,   1.2837555E-03,   1.2345093E-03
     +,   1.1858206E-03,   1.1380324E-03,   1.0914387E-03
     +,   1.0462772E-03,   1.0027271E-03,   9.6090662E-04
     +,   9.2087779E-04,   8.8265724E-04,   8.4621314E-04
     +,   8.1147952E-04,   7.7836250E-04,   7.4674893E-04
     +,   7.1651005E-04,   6.8751036E-04,   6.5961527E-04
     +,   6.3269562E-04,   6.0662744E-04,   5.8129895E-04
     +,   5.5661483E-04,   5.3249195E-04,   5.0886656E-04
     +,   4.8568775E-04,   4.6292465E-04,   4.4055778E-04
     +,   4.1858488E-04,   3.9701306E-04,   3.7586270E-04
     +,   3.5515957E-04,   3.3493908E-04,   3.1523811E-04
     +,   2.9609661E-04,   2.7755625E-04,   2.5965515E-04
     +,   2.4243107E-04,   2.2591512E-04,   2.1013588E-04
     +,   1.9511368E-04,   1.8086490E-04,   1.6739735E-04
     +,   1.5471422E-04,   1.4281066E-04,   1.3167744E-04
     +,   1.2129838E-04,   1.1165370E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz90 = Yx/0.271212765957447
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5137135E-05,   3.6066987E-05
     +,   3.7019901E-05,   3.7996040E-05,   3.8995535E-05
     +,   4.0018425E-05,   4.1064715E-05,   4.2134321E-05
     +,   4.3227083E-05,   4.4342807E-05,   4.5481222E-05
     +,   4.6641919E-05,   4.7824476E-05,   4.9028396E-05
     +,   5.0253082E-05,   5.1497889E-05,   5.2762105E-05
     +,   5.4044940E-05,   5.5345568E-05,   5.6663084E-05
     +,   5.7996538E-05,   5.9344977E-05,   6.0707349E-05
     +,   6.2082683E-05,   6.3469823E-05,   6.4867789E-05
     +,   6.6275512E-05,   6.7691915E-05,   6.9116009E-05
     +,   7.0546812E-05,   7.1983428E-05,   7.3424984E-05
     +,   7.4870688E-05,   7.6319906E-05,   7.7772056E-05
     +,   7.9226702E-05,   8.0683545E-05,   8.2142440E-05
     +,   8.3603503E-05,   8.5066844E-05,   8.6533022E-05
     +,   8.8002686E-05,   8.9476736E-05,   9.0956339E-05
     +,   9.2442955E-05,   9.3938303E-05,   9.5444469E-05
     +,   9.6963762E-05,   9.8498938E-05,   1.0005298E-04
     +,   1.0162927E-04,   1.0323152E-04,   1.0486381E-04
     +,   1.0653066E-04,   1.0823675E-04,   1.0998722E-04
     +,   1.1178758E-04,   1.1364357E-04,   1.1556113E-04
     +,   1.1754665E-04,   1.1960655E-04,   1.2174753E-04
     +,   1.2397622E-04,   1.2629952E-04,   1.2872426E-04
     +,   1.3125698E-04,   1.3390435E-04,   1.3667237E-04
     +,   1.3956713E-04,   1.4259378E-04,   1.4575741E-04
     +,   1.4906185E-04,   1.5251065E-04,   1.5610609E-04
     +,   1.5984972E-04,   1.6374201E-04,   1.6778205E-04
     +,   1.7196762E-04,   1.7629549E-04,   1.8076102E-04
     +,   1.8535783E-04,   1.9007870E-04,   1.9491457E-04
     +,   1.9985548E-04,   2.0488970E-04,   2.1000518E-04
     +,   2.1518799E-04,   2.2042426E-04,   2.2569874E-04
     +,   2.3099630E-04,   2.3630194E-04,   2.4160020E-04
     +,   2.4687636E-04,   2.5211679E-04,   2.5730906E-04
     +,   2.6244190E-04,   2.6750664E-04,   2.7249596E-04
     +,   2.7740665E-04,   2.8223719E-04,   2.8699075E-04
     +,   2.9167332E-04,   2.9629603E-04,   3.0087380E-04
     +,   3.0542692E-04,   3.0998085E-04,   3.1456616E-04
     +,   3.1921908E-04,   3.2398230E-04,   3.2890413E-04
     +,   3.3403901E-04,   3.3944813E-04,   3.4519783E-04
     +,   3.5136184E-04,   3.5801870E-04,   3.6525290E-04
     +,   3.7315287E-04,   3.8181213E-04,   3.9132615E-04
     +,   4.0179209E-04,   4.1330818E-04,   4.2596916E-04
     +,   4.3986615E-04,   4.5508408E-04,   4.7169894E-04
     +,   4.8977276E-04,   5.0935481E-04,   5.3047331E-04
     +,   5.5313791E-04,   5.7733228E-04,   6.0301588E-04
     +,   6.3011912E-04,   6.5854681E-04,   6.8817375E-04
     +,   7.1885274E-04,   7.5041596E-04,   7.8268070E-04
     +,   8.1545871E-04,   8.4856956E-04,   8.8185660E-04
     +,   9.1519818E-04,   9.4853080E-04,   9.8187511E-04
     +,   1.0153515E-03,   1.0492002E-03,   1.0838055E-03
     +,   1.1196987E-03,   1.1575657E-03,   1.1982275E-03
     +,   1.2426251E-03,   1.2917671E-03,   1.3466699E-03
     +,   1.4082837E-03,   1.4774168E-03,   1.5546512E-03
     +,   1.6402742E-03,   1.7342506E-03,   1.8362398E-03
     +,   1.9456524E-03,   2.0617584E-03,   2.1838667E-03
     +,   2.3114991E-03,   2.4445534E-03,   2.5834371E-03
     +,   2.7291623E-03,   2.8833214E-03,   3.0480011E-03
     +,   3.2256308E-03,   3.4187685E-03,   3.6298241E-03
     +,   3.8607977E-03,   4.1132104E-03,   4.3884544E-03
     +,   4.6887817E-03,   5.0190422E-03,   5.3891535E-03
     +,   5.8164052E-03,   6.3268533E-03,   6.9548269E-03
     +,   7.7399169E-03,   8.7206755E-03,   9.9248663E-03
     +,   1.1358665E-02,   1.3000629E-02,   1.4806181E-02
     +,   1.6720969E-02,   1.8696081E-02,   2.0705057E-02
     +,   2.2768740E-02,   2.4968050E-02,   2.7395872E-02
     +,   3.0037859E-02,   3.2675803E-02,   3.4939051E-02
     +,   3.6497433E-02,   3.7226621E-02,   3.7199888E-02
     +,   3.6554765E-02,   3.5416603E-02,   3.3944316E-02
     +,   3.2363851E-02,   3.0862942E-02,   2.9448427E-02
     +,   2.7970562E-02,   2.6315346E-02,   2.4538729E-02
     +,   2.2806223E-02,   2.1247389E-02,   1.9889800E-02
     +,   1.8688509E-02,   1.7576359E-02,   1.6496507E-02
     +,   1.5423202E-02,   1.4369367E-02,   1.3373021E-02
     +,   1.2468926E-02,   1.1666405E-02,   1.0946951E-02
     +,   1.0278348E-02,   9.6321180E-03,   8.9938510E-03
     +,   8.3645666E-03,   7.7559487E-03,   7.1836254E-03
     +,   6.6613876E-03,   6.1976835E-03,   5.7944786E-03
     +,   5.4480056E-03,   5.1507023E-03,   4.8934752E-03
     +,   4.6675350E-03,   4.4654454E-03,   4.2814640E-03
     +,   4.1113594E-03,   3.9520324E-03,   3.8011090E-03
     +,   3.6566965E-03,   3.5172715E-03,   3.3816413E-03
     +,   3.2489472E-03,   3.1186643E-03,   2.9905790E-03
     +,   2.8646975E-03,   2.7411641E-03,   2.6201797E-03
     +,   2.5019385E-03,   2.3865963E-03,   2.2742464E-03
     +,   2.1649445E-03,   2.0587472E-03,   1.9557232E-03
     +,   1.8559820E-03,   1.7596984E-03,   1.6670984E-03
     +,   1.5784369E-03,   1.4939894E-03,   1.4140190E-03
     +,   1.3387559E-03,   1.2683569E-03,   1.2029010E-03
     +,   1.1423840E-03,   1.0867076E-03,   1.0356797E-03
     +,   9.8903326E-04,   9.4643864E-04,   9.0751407E-04
     +,   8.7184797E-04,   8.3901524E-04,   8.0859300E-04
     +,   7.8016875E-04,   7.5335696E-04,   7.2780583E-04
     +,   7.0320349E-04,   6.7927648E-04,   6.5579690E-04
     +,   6.3258217E-04,   6.0948794E-04,   5.8641337E-04
     +,   5.6329137E-04,   5.4009026E-04,   5.1680504E-04
     +,   4.9345853E-04,   4.7009127E-04,   4.4676338E-04
     +,   4.2354522E-04,   4.0051813E-04,   3.7776676E-04
     +,   3.5537774E-04,   3.3343839E-04,   3.1203026E-04
     +,   2.9123182E-04,   2.7111167E-04,   2.5173259E-04
     +,   2.3314543E-04,   2.1539374E-04,   1.9850876E-04
     +,   1.8251392E-04,   1.6742102E-04,   1.5323477E-04
     +,   1.3994960E-04,   1.2755406E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ttz95 = Yx/0.280446808510638
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.6427592E-07,   6.1710750E-07
     +,   6.7415363E-07,   7.3567662E-07,   8.0194854E-07
     +,   8.7325071E-07,   9.4987303E-07,   1.0321144E-06
     +,   1.1202790E-06,   1.2146844E-06,   1.3156490E-06
     +,   1.4234997E-06,   1.5385682E-06,   1.6611897E-06
     +,   1.7917033E-06,   1.9304496E-06,   2.0777702E-06
     +,   2.2340053E-06,   2.3994944E-06,   2.5745726E-06
     +,   2.7595706E-06,   2.9548107E-06,   3.1606046E-06
     +,   3.3772669E-06,   3.6050756E-06,   3.8443186E-06
     +,   4.0952536E-06,   4.3581226E-06,   4.6331475E-06
     +,   4.9205278E-06,   5.2204382E-06,   5.5330270E-06
     +,   5.8584110E-06,   6.1966798E-06,   6.5478866E-06
     +,   6.9120520E-06,   7.2891603E-06,   7.6791521E-06
     +,   8.0819500E-06,   8.4973963E-06,   8.9253344E-06
     +,   9.3655417E-06,   9.8177561E-06,   1.0281677E-05
     +,   1.0756958E-05,   1.1243211E-05,   1.1740010E-05
     +,   1.2246885E-05,   1.2763334E-05,   1.3288812E-05
     +,   1.3822743E-05,   1.4364527E-05,   1.4913525E-05
     +,   1.5469106E-05,   1.6030570E-05,   1.6597256E-05
     +,   1.7168466E-05,   1.7743509E-05,   1.8321698E-05
     +,   1.8902365E-05,   1.9484849E-05,   2.0068543E-05
     +,   2.0652822E-05,   2.1237156E-05,   2.1821075E-05
     +,   2.2404116E-05,   2.2985952E-05,   2.3566263E-05
     +,   2.4144898E-05,   2.4721732E-05,   2.5296818E-05
     +,   2.5870253E-05,   2.6442336E-05,   2.7013426E-05
     +,   2.7584076E-05,   2.8154996E-05,   2.8727001E-05
     +,   2.9301073E-05,   2.9878400E-05,   3.0460325E-05
     +,   3.1048308E-05,   3.1644056E-05,   3.2249351E-05
     +,   3.2866217E-05,   3.3496752E-05,   3.4143268E-05
     +,   3.4808134E-05,   3.5493893E-05,   3.6203131E-05
     +,   3.6938542E-05,   3.7702899E-05,   3.8498943E-05
     +,   3.9329432E-05,   4.0197127E-05,   4.1104759E-05
     +,   4.2054904E-05,   4.3050142E-05,   4.4092842E-05
     +,   4.5185374E-05,   4.6329809E-05,   4.7528301E-05
     +,   4.8782742E-05,   5.0095117E-05,   5.1467294E-05
     +,   5.2901349E-05,   5.4399654E-05,   5.5964847E-05
     +,   5.7600202E-05,   5.9309961E-05,   6.1099570E-05
     +,   6.2975858E-05,   6.4947904E-05,   6.7027075E-05
     +,   6.9228074E-05,   7.1569113E-05,   7.4073163E-05
     +,   7.6768032E-05,   7.9688019E-05,   8.2873747E-05
     +,   8.6373773E-05,   9.0244932E-05,   9.4552692E-05
     +,   9.9371551E-05,   1.0478561E-04,   1.1088797E-04
     +,   1.1777932E-04,   1.2556823E-04,   1.3436738E-04
     +,   1.4429347E-04,   1.5546176E-04,   1.6798559E-04
     +,   1.8196959E-04,   1.9750989E-04,   2.1468675E-04
     +,   2.3356621E-04,   2.5419769E-04,   2.7661372E-04
     +,   3.0083477E-04,   3.2687787E-04,   3.5476591E-04
     +,   3.8454018E-04,   4.1628044E-04,   4.5013041E-04
     +,   4.8632268E-04,   5.2520540E-04,   5.6728383E-04
     +,   6.1325246E-04,   6.6403073E-04,   7.2080368E-04
     +,   7.8506023E-04,   8.5861835E-04,   9.4362570E-04
     +,   1.0425297E-03,   1.1579846E-03,   1.2926433E-03
     +,   1.4488031E-03,   1.6279315E-03,   1.8300776E-03
     +,   2.0532927E-03,   2.2932391E-03,   2.5433542E-03
     +,   2.7957060E-03,   3.0427203E-03,   3.2796785E-03
     +,   3.5073650E-03,   3.7339202E-03,   3.9748321E-03
     +,   4.2503411E-03,   4.5804507E-03,   4.9790079E-03
     +,   5.4495852E-03,   5.9860721E-03,   6.5791332E-03
     +,   7.2253328E-03,   7.9311719E-03,   8.7052807E-03
     +,   9.5432503E-03,   1.0427843E-02,   1.1364604E-02
     +,   1.2431568E-02,   1.3788097E-02,   1.5652429E-02
     +,   1.8335665E-02,   2.2240669E-02,   2.7552430E-02
     +,   3.3923317E-02,   4.0729687E-02,   4.7537480E-02
     +,   5.4670770E-02,   6.2514909E-02,   7.0930682E-02
     +,   7.9620086E-02,   8.5641570E-02,   8.7626792E-02
     +,   8.9109913E-02,   9.0098783E-02,   8.9386463E-02
     +,   8.6202599E-02,   8.0196753E-02,   7.3488861E-02
     +,   6.6028580E-02,   6.0176451E-02,   5.4451443E-02
     +,   4.7778420E-02,   4.1210398E-02,   3.4989484E-02
     +,   2.9616484E-02,   2.5560932E-02,   2.2628790E-02
     +,   2.0283462E-02,   1.8124815E-02,   1.6055159E-02
     +,   1.4136587E-02,   1.2432126E-02,   1.0968818E-02
     +,   9.7479327E-03,   8.7477788E-03,   7.9232231E-03
     +,   7.2128922E-03,   6.5562446E-03,   5.9124366E-03
     +,   5.2690729E-03,   4.6364078E-03,   4.0333774E-03
     +,   3.4753066E-03,   2.9689248E-03,   2.5138606E-03
     +,   2.1066430E-03,   1.7439548E-03,   1.4238723E-03
     +,   1.1454789E-03,   9.0782670E-04,   7.0912577E-04
     +,   5.4646935E-04,   4.1600002E-04,   3.1327846E-04
     +,   2.3373938E-04,   1.7304713E-04,   1.2731698E-04
     +,   9.3223374E-05,   6.8025191E-05,   4.9529415E-05
     +,   3.6021942E-05,   2.6189708E-05,   1.9044932E-05
     +,   1.3855190E-05,   1.0083103E-05,   7.3376141E-06
     +,   5.3360759E-06,   3.8748790E-06,   2.8071217E-06
     +,   2.0267603E-06,   1.4569856E-06,   1.0418437E-06
     +,   7.4034710E-07,   5.2236163E-07,   3.6564990E-07
     +,   2.5374976E-07,   1.7446202E-07,   1.1876563E-07
     +,   8.0012349E-08,   5.3322402E-08,   3.5137919E-08
     +,   2.2887908E-08,   1.4733008E-08,   9.3697015E-09
     +,   5.8859819E-09,   3.6518284E-09,   2.2374473E-09
     +,   1.3536190E-09,   8.0853768E-10,   4.7681187E-10
     +,   2.7760441E-10,   1.5955844E-10,   9.0534580E-11
     +,   5.0714134E-11,   2.8045233E-11,   1.5312449E-11
     +,   8.2548482E-12,   4.3947641E-12,   2.3110814E-12
     +,   1.2009802E-12,   6.1709812E-13,   3.1385569E-13
     +,   1.5825233E-13,   7.9316335E-14,   3.9676443E-14
     +,   1.9933057E-14,   1.0150296E-14,   5.3035227E-15
     +,   2.8845963E-15,   1.6549997E-15,   1.0094009E-15
     +,   6.5375782E-16,   4.4564955E-16,   3.1567849E-16
     +,   2.2950540E-16,   1.6957197E-16,   1.2645860E-16
     +,   9.4763426E-17,   7.1164148E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt100 = Yx/0.4368
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0565382E-06,   1.1847044E-06
     +,   1.3256142E-06,   1.4801534E-06,   1.6492221E-06
     +,   1.8337265E-06,   2.0345733E-06,   2.2526606E-06
     +,   2.4888677E-06,   2.7440572E-06,   3.0190449E-06
     +,   3.3146048E-06,   3.6314498E-06,   3.9702286E-06
     +,   4.3315040E-06,   4.7157464E-06,   5.1233214E-06
     +,   5.5544792E-06,   6.0093366E-06,   6.4878727E-06
     +,   6.9899179E-06,   7.5151411E-06,   8.0630325E-06
     +,   8.6329464E-06,   9.2239907E-06,   9.8351557E-06
     +,   1.0465203E-05,   1.1112723E-05,   1.1776119E-05
     +,   1.2453610E-05,   1.3143255E-05,   1.3842936E-05
     +,   1.4550386E-05,   1.5263207E-05,   1.5978876E-05
     +,   1.6694759E-05,   1.7408158E-05,   1.8116287E-05
     +,   1.8816385E-05,   1.9505600E-05,   2.0181174E-05
     +,   2.0840360E-05,   2.1480497E-05,   2.2099033E-05
     +,   2.2693548E-05,   2.3261795E-05,   2.3801720E-05
     +,   2.4311483E-05,   2.4789495E-05,   2.5234434E-05
     +,   2.5645277E-05,   2.6021296E-05,   2.6362095E-05
     +,   2.6667618E-05,   2.6938138E-05,   2.7174292E-05
     +,   2.7377053E-05,   2.7547761E-05,   2.7688075E-05
     +,   2.7800006E-05,   2.7885852E-05,   2.7948236E-05
     +,   2.7990040E-05,   2.8014414E-05,   2.8024708E-05
     +,   2.8024488E-05,   2.8017475E-05,   2.8007522E-05
     +,   2.7998563E-05,   2.7994605E-05,   2.7999669E-05
     +,   2.8017776E-05,   2.8052909E-05,   2.8108949E-05
     +,   2.8189714E-05,   2.8298891E-05,   2.8440030E-05
     +,   2.8616530E-05,   2.8831639E-05,   2.9088480E-05
     +,   2.9390034E-05,   2.9739189E-05,   3.0138741E-05
     +,   3.0591520E-05,   3.1100350E-05,   3.1668220E-05
     +,   3.2298296E-05,   3.2994114E-05,   3.3759541E-05
     +,   3.4599092E-05,   3.5517947E-05,   3.6522062E-05
     +,   3.7618342E-05,   3.8814836E-05,   4.0120827E-05
     +,   4.1546780E-05,   4.3104748E-05,   4.4808025E-05
     +,   4.6671572E-05,   4.8711510E-05,   5.0945546E-05
     +,   5.3392210E-05,   5.6071243E-05,   5.9002621E-05
     +,   6.2206731E-05,   6.5703687E-05,   6.9512549E-05
     +,   7.3650808E-05,   7.8134064E-05,   8.2975130E-05
     +,   8.8182693E-05,   9.3761861E-05,   9.9711993E-05
     +,   1.0602763E-04,   1.1269645E-04,   1.1970053E-04
     +,   1.2701443E-04,   1.3460701E-04,   1.4243988E-04
     +,   1.5046955E-04,   1.5864783E-04,   1.6692202E-04
     +,   1.7523728E-04,   1.8353903E-04,   1.9177444E-04
     +,   1.9989452E-04,   2.0785854E-04,   2.1563561E-04
     +,   2.2320940E-04,   2.3058058E-04,   2.3777150E-04
     +,   2.4482782E-04,   2.5182354E-04,   2.5886032E-04
     +,   2.6607074E-04,   2.7361672E-04,   2.8168713E-04
     +,   2.9049270E-04,   3.0026108E-04,   3.1122618E-04
     +,   3.2361632E-04,   3.3764140E-04,   3.5347929E-04
     +,   3.7126063E-04,   3.9105260E-04,   4.1285122E-04
     +,   4.3657128E-04,   4.6204252E-04,   4.8901216E-04
     +,   5.1715790E-04,   5.4610154E-04,   5.7542964E-04
     +,   6.0472323E-04,   6.3359336E-04,   6.6171290E-04
     +,   6.8885414E-04,   7.1493001E-04,   7.4003474E-04
     +,   7.6448504E-04,   7.8886078E-04,   8.1405055E-04
     +,   8.4128522E-04,   8.7215722E-04,   9.0861111E-04
     +,   9.5289090E-04,   1.0074163E-03,   1.0745820E-03
     +,   1.1565016E-03,   1.2547442E-03,   1.3701685E-03
     +,   1.5030330E-03,   1.6536403E-03,   1.8236926E-03
     +,   2.0183374E-03,   2.2484523E-03,   2.5321532E-03
     +,   2.8937678E-03,   3.3587662E-03,   3.9446913E-03
     +,   4.6512424E-03,   5.4554483E-03,   6.3174316E-03
     +,   7.1961526E-03,   8.0653494E-03,   8.9182677E-03
     +,   9.7653065E-03,   1.0654237E-02,   1.1730552E-02
     +,   1.3258862E-02,   1.5460077E-02,   1.8264048E-02
     +,   2.1448432E-02,   2.5189387E-02,   3.0094286E-02
     +,   3.6416002E-02,   4.3493968E-02,   5.0409090E-02
     +,   5.6973320E-02,   6.3613899E-02,   7.2727531E-02
     +,   8.4002510E-02,   9.3124174E-02,   9.7537264E-02
     +,   9.3456753E-02,   8.8371672E-02,   8.4902011E-02
     +,   8.0866583E-02,   7.5517833E-02,   6.8021841E-02
     +,   5.8292180E-02,   4.9095400E-02,   4.2203028E-02
     +,   3.7066124E-02,   3.2625131E-02,   2.8170880E-02
     +,   2.3686750E-02,   1.9593609E-02,   1.6287806E-02
     +,   1.3837813E-02,   1.2048427E-02,   1.0737523E-02
     +,   9.8071788E-03,   9.1392295E-03,   8.5582575E-03
     +,   7.8958450E-03,   7.0604817E-03,   6.0584475E-03
     +,   4.9687922E-03,   3.8975254E-03,   2.9359644E-03
     +,   2.1378710E-03,   1.5169407E-03,   1.0576667E-03
     +,   7.3013414E-04,   5.0193549E-04,   3.4484494E-04
     +,   2.3713069E-04,   1.6321683E-04,   1.1235358E-04
     +,   7.7240671E-05,   5.2941541E-05,   3.6108690E-05
     +,   2.4457901E-05,   1.6418724E-05,   1.0903021E-05
     +,   7.1503309E-06,   4.6247133E-06,   2.9467681E-06
     +,   1.8481988E-06,   1.1403690E-06,   6.9188934E-07
     +,   4.1263135E-07,   2.4182276E-07,   1.3922609E-07
     +,   7.8720802E-08,   4.3696851E-08,   2.3804228E-08
     +,   1.2721705E-08,   6.6672250E-09,   3.4251197E-09
     +,   1.7241779E-09,   8.5019419E-10,   4.1051787E-10
     +,   1.9403727E-10,   8.9761289E-11,   4.0630197E-11
     +,   1.7992892E-11,   7.7957424E-12,   3.3054011E-12
     +,   1.3723427E-12,   5.5871383E-13,   2.2376225E-13
     +,   8.8746834E-14,   3.5331493E-14,   1.4486567E-14
     +,   6.3780412E-15,   3.1660201E-15,   1.8204978E-15
     +,   1.1923672E-15,   8.5168141E-16,   6.3740897E-16
     +,   4.8756228E-16,   3.7633661E-16,   2.9141827E-16
     +,   2.2580588E-16,   1.7489374E-16,   1.3534332E-16
     +,   1.0462654E-16,   8.0790750E-17,   6.2312038E-17
     +,   4.8003534E-17,   3.6936251E-17,   2.8386453E-17
     +,   2.1789013E-17,   1.6704656E-17,   1.2790802E-17
     +,   9.7819269E-18,   7.4714775E-18,   5.6996566E-18
     +,   4.3425328E-18,   3.3044054E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt104 = Yx/0.408
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.8022922E-07,   7.4179383E-07
     +,   8.0817961E-07,   8.7970216E-07,   9.5669327E-07
     +,   1.0395022E-06,   1.1284950E-06,   1.2240573E-06
     +,   1.3265911E-06,   1.4365232E-06,   1.5542957E-06
     +,   1.6803730E-06,   1.8152391E-06,   1.9594008E-06
     +,   2.1133858E-06,   2.2777429E-06,   2.4530427E-06
     +,   2.6398773E-06,   2.8388599E-06,   3.0506224E-06
     +,   3.2758189E-06,   3.5151186E-06,   3.7692059E-06
     +,   4.0387963E-06,   4.3245886E-06,   4.6273240E-06
     +,   4.9477330E-06,   5.2865566E-06,   5.6445374E-06
     +,   6.0224161E-06,   6.4209271E-06,   6.8407962E-06
     +,   7.2827297E-06,   7.7474187E-06,   8.2355236E-06
     +,   8.7476801E-06,   9.2844793E-06,   9.8464689E-06
     +,   1.0434177E-05,   1.1048016E-05,   1.1688405E-05
     +,   1.2355658E-05,   1.3050030E-05,   1.3771696E-05
     +,   1.4520758E-05,   1.5297224E-05,   1.6101023E-05
     +,   1.6932001E-05,   1.7789895E-05,   1.8674365E-05
     +,   1.9584984E-05,   2.0521216E-05,   2.1482447E-05
     +,   2.2468026E-05,   2.3477129E-05,   2.4508963E-05
     +,   2.5562613E-05,   2.6637132E-05,   2.7731532E-05
     +,   2.8844799E-05,   2.9975903E-05,   3.1123847E-05
     +,   3.2287571E-05,   3.3466164E-05,   3.4658766E-05
     +,   3.5864505E-05,   3.7082773E-05,   3.8312941E-05
     +,   3.9554710E-05,   4.0807819E-05,   4.2072395E-05
     +,   4.3348653E-05,   4.4637272E-05,   4.5939076E-05
     +,   4.7255355E-05,   4.8587768E-05,   4.9938284E-05
     +,   5.1309282E-05,   5.2703643E-05,   5.4124670E-05
     +,   5.5575929E-05,   5.7061625E-05,   5.8586105E-05
     +,   6.0154234E-05,   6.1771025E-05,   6.3441839E-05
     +,   6.5172033E-05,   6.6967186E-05,   6.8832604E-05
     +,   7.0773625E-05,   7.2795279E-05,   7.4902040E-05
     +,   7.7097859E-05,   7.9386162E-05,   8.1769605E-05
     +,   8.4249812E-05,   8.6827735E-05,   8.9503097E-05
     +,   9.2275026E-05,   9.5141346E-05,   9.8099510E-05
     +,   1.0114585E-04,   1.0427664E-04,   1.0748753E-04
     +,   1.1077436E-04,   1.1413346E-04,   1.1756137E-04
     +,   1.2105568E-04,   1.2461530E-04,   1.2824073E-04
     +,   1.3193367E-04,   1.3569811E-04,   1.3953928E-04
     +,   1.4346464E-04,   1.4748251E-04,   1.5160287E-04
     +,   1.5583570E-04,   1.6019164E-04,   1.6468015E-04
     +,   1.6930970E-04,   1.7408702E-04,   1.7901586E-04
     +,   1.8409698E-04,   1.8932838E-04,   1.9470489E-04
     +,   2.0021810E-04,   2.0585829E-04,   2.1161420E-04
     +,   2.1747591E-04,   2.2343491E-04,   2.2948826E-04
     +,   2.3563810E-04,   2.4189586E-04,   2.4828225E-04
     +,   2.5482918E-04,   2.6158008E-04,   2.6858845E-04
     +,   2.7591738E-04,   2.8363627E-04,   2.9181791E-04
     +,   3.0053288E-04,   3.0984546E-04,   3.1980986E-04
     +,   3.3046558E-04,   3.4183494E-04,   3.5392473E-04
     +,   3.6672942E-04,   3.8023660E-04,   3.9443941E-04
     +,   4.0935111E-04,   4.2502090E-04,   4.4154999E-04
     +,   4.5910754E-04,   4.7794165E-04,   4.9838051E-04
     +,   5.2082253E-04,   5.4571603E-04,   5.7352596E-04
     +,   6.0469029E-04,   6.3956546E-04,   6.7838497E-04
     +,   7.2121865E-04,   7.6795061E-04,   8.1829174E-04
     +,   8.7182014E-04,   9.2805305E-04,   9.8653568E-04
     +,   1.0469564E-03,   1.1092591E-03,   1.1737399E-03
     +,   1.2411218E-03,   1.3126148E-03,   1.3899738E-03
     +,   1.4755484E-03,   1.5723382E-03,   1.6840686E-03
     +,   1.8151929E-03,   1.9707633E-03,   2.1561517E-03
     +,   2.3767303E-03,   2.6377984E-03,   2.9453025E-03
     +,   3.3075584E-03,   3.7372976E-03,   4.2520110E-03
     +,   4.8705461E-03,   5.6061633E-03,   6.4597358E-03
     +,   7.4184565E-03,   8.4627541E-03,   9.5798951E-03
     +,   1.0784015E-02,   1.2150777E-02,   1.3861318E-02
     +,   1.6197558E-02,   1.9449938E-02,   2.3819093E-02
     +,   2.9322920E-02,   3.5668269E-02,   4.2303387E-02
     +,   4.8961595E-02,   5.5779196E-02,   6.2718287E-02
     +,   7.1089685E-02,   8.0872953E-02,   8.9313880E-02
     +,   9.5778242E-02,   0.1001582    ,   0.1026404    
     +,   0.1016201    ,   9.2533857E-02,   8.1870422E-02
     +,   7.3634028E-02,   6.3130550E-02,   5.1550169E-02
     +,   4.2973813E-02,   3.6131814E-02,   2.9938322E-02
     +,   2.5092702E-02,   2.1851346E-02,   1.9608840E-02
     +,   1.7599555E-02,   1.5489554E-02,   1.3338142E-02
     +,   1.1284422E-02,   9.4078761E-03,   7.7372524E-03
     +,   6.2754462E-03,   5.0121341E-03,   3.9328956E-03
     +,   3.0249723E-03,   2.2777184E-03,   1.6796051E-03
     +,   1.2153721E-03,   8.6564408E-04,   6.0889032E-04
     +,   4.2429555E-04,   2.9379851E-04,   2.0285248E-04
     +,   1.4027666E-04,   9.7715834E-05,   6.9041169E-05
     +,   4.9835544E-05,   3.6982954E-05,   2.8338407E-05
     +,   2.2458085E-05,   1.8386647E-05,   1.5498432E-05
     +,   1.3385401E-05,   1.1781342E-05,   1.0512082E-05
     +,   9.4641582E-06,   8.5644460E-06,   7.7666546E-06
     +,   7.0422557E-06,   6.3743455E-06,   5.7534194E-06
     +,   5.1744232E-06,   4.6348027E-06,   4.1333142E-06
     +,   3.6692823E-06,   3.2421306E-06,   2.8511147E-06
     +,   2.4952494E-06,   2.1733135E-06,   1.8837883E-06
     +,   1.6249433E-06,   1.3948928E-06,   1.1916303E-06
     +,   1.0130658E-06,   8.5709013E-07,   7.2162317E-07
     +,   6.0463299E-07,   5.0415969E-07,   4.1834718E-07
     +,   3.4546426E-07,   2.8389749E-07,   2.3217623E-07
     +,   1.8895832E-07,   1.5304249E-07,   1.2335315E-07
     +,   9.8943190E-08,   7.8979411E-08,   6.2739275E-08
     +,   4.9597180E-08,   3.9018715E-08,   3.0548065E-08
     +,   2.3800478E-08,   1.8453832E-08,   1.4238955E-08
     +,   1.0933744E-08,   8.3550793E-09,   6.3537620E-09
     +,   4.8084212E-09,   3.6213650E-09,   2.7141487E-09
     +,   2.0243887E-09,   1.5026033E-09,   1.1099272E-09
     +,   8.1589691E-10,   5.9686400E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt106 = Yx/0.40978
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2186051E-06,   1.3130982E-06
     +,   1.4130226E-06,   1.5185204E-06,   1.6297236E-06
     +,   1.7467528E-06,   1.8697159E-06,   1.9987081E-06
     +,   2.1338069E-06,   2.2750833E-06,   2.4225847E-06
     +,   2.5763450E-06,   2.7363822E-06,   2.9026967E-06
     +,   3.0752731E-06,   3.2540809E-06,   3.4390719E-06
     +,   3.6301847E-06,   3.8273433E-06,   4.0304608E-06
     +,   4.2394377E-06,   4.4541653E-06,   4.6745272E-06
     +,   4.9004143E-06,   5.1316915E-06,   5.3682511E-06
     +,   5.6099734E-06,   5.8567512E-06,   6.1084893E-06
     +,   6.3651041E-06,   6.6265343E-06,   6.8927393E-06
     +,   7.1636996E-06,   7.4394343E-06,   7.7199911E-06
     +,   8.0054506E-06,   8.2959377E-06,   8.5916117E-06
     +,   8.8926981E-06,   9.1994298E-06,   9.5121295E-06
     +,   9.8311411E-06,   1.0156866E-05,   1.0489748E-05
     +,   1.0830282E-05,   1.1179007E-05,   1.1536499E-05
     +,   1.1903373E-05,   1.2280275E-05,   1.2667877E-05
     +,   1.3066870E-05,   1.3477960E-05,   1.3901849E-05
     +,   1.4339254E-05,   1.4790844E-05,   1.5257303E-05
     +,   1.5739251E-05,   1.6237282E-05,   1.6751919E-05
     +,   1.7283644E-05,   1.7832836E-05,   1.8399827E-05
     +,   1.8984805E-05,   1.9587920E-05,   2.0209205E-05
     +,   2.0848549E-05,   2.1505799E-05,   2.2180622E-05
     +,   2.2872679E-05,   2.3581435E-05,   2.4306381E-05
     +,   2.5046837E-05,   2.5802176E-05,   2.6571644E-05
     +,   2.7354572E-05,   2.8150314E-05,   2.8958251E-05
     +,   2.9777868E-05,   3.0608844E-05,   3.1451062E-05
     +,   3.2304575E-05,   3.3169850E-05,   3.4047567E-05
     +,   3.4938945E-05,   3.5845547E-05,   3.6769547E-05
     +,   3.7713562E-05,   3.8680912E-05,   3.9675422E-05
     +,   4.0701663E-05,   4.1764877E-05,   4.2870877E-05
     +,   4.4026132E-05,   4.5237797E-05,   4.6513600E-05
     +,   4.7861646E-05,   4.9290615E-05,   5.0809394E-05
     +,   5.2427225E-05,   5.4153268E-05,   5.5996898E-05
     +,   5.7967118E-05,   6.0072893E-05,   6.2322608E-05
     +,   6.4724394E-05,   6.7285910E-05,   7.0014168E-05
     +,   7.2915682E-05,   7.5996802E-05,   7.9263642E-05
     +,   8.2721985E-05,   8.6378292E-05,   9.0239220E-05
     +,   9.4312745E-05,   9.8607714E-05,   1.0313529E-04
     +,   1.0790829E-04,   1.1294258E-04,   1.1825626E-04
     +,   1.2387089E-04,   1.2981116E-04,   1.3610430E-04
     +,   1.4278000E-04,   1.4987061E-04,   1.5740957E-04
     +,   1.6542988E-04,   1.7396464E-04,   1.8304340E-04
     +,   1.9269298E-04,   2.0293340E-04,   2.1377890E-04
     +,   2.2523364E-04,   2.3729335E-04,   2.4994102E-04
     +,   2.6314901E-04,   2.7687775E-04,   2.9107492E-04
     +,   3.0567677E-04,   3.2061109E-04,   3.3579761E-04
     +,   3.5114994E-04,   3.6658015E-04,   3.8200279E-04
     +,   3.9733938E-04,   4.1252104E-04,   4.2749644E-04
     +,   4.4223692E-04,   4.5673904E-04,   4.7103147E-04
     +,   4.8517875E-04,   4.9928337E-04,   5.1348412E-04
     +,   5.2795664E-04,   5.4290850E-04,   5.5857189E-04
     +,   5.7519402E-04,   5.9302599E-04,   6.1231689E-04
     +,   6.3330348E-04,   6.5620570E-04,   6.8123738E-04
     +,   7.0861675E-04,   7.3858839E-04,   7.7145518E-04
     +,   8.0760941E-04,   8.4755500E-04,   8.9190784E-04
     +,   9.4136666E-04,   9.9664787E-04,   1.0583696E-03
     +,   1.1269051E-03,   1.2022315E-03,   1.2838173E-03
     +,   1.3705649E-03,   1.4608596E-03,   1.5527809E-03
     +,   1.6444074E-03,   1.7342231E-03,   1.8215497E-03
     +,   1.9069486E-03,   1.9924815E-03,   2.0818638E-03
     +,   2.1805645E-03,   2.2959830E-03,   2.4377683E-03
     +,   2.6182453E-03,   2.8526357E-03,   3.1586438E-03
     +,   3.5552317E-03,   4.0608724E-03,   4.6919421E-03
     +,   5.4610129E-03,   6.3751754E-03,   7.4368836E-03
     +,   8.6524636E-03,   1.0052668E-02,   1.1719135E-02
     +,   1.3777465E-02,   1.6289653E-02,   1.9100714E-02
     +,   2.1956518E-02,   2.4984313E-02,   2.8941948E-02
     +,   3.4842312E-02,   4.3127630E-02,   5.2913398E-02
     +,   6.2615164E-02,   7.1603812E-02,   8.0488563E-02
     +,   8.7731875E-02,   9.3309097E-02,   9.8617420E-02
     +,   0.1026152    ,   0.1012194    ,   9.7576760E-02
     +,   9.2165917E-02,   7.9263784E-02,   6.4279072E-02
     +,   5.3438015E-02,   4.5512822E-02,   3.8552295E-02
     +,   3.1527232E-02,   2.4803065E-02,   1.9426972E-02
     +,   1.5730502E-02,   1.3189341E-02,   1.1087599E-02
     +,   9.0214638E-03,   6.9698994E-03,   5.0974330E-03
     +,   3.5494207E-03,   2.3723973E-03,   1.5337120E-03
     +,   9.6617534E-04,   5.9842551E-04,   3.6847068E-04
     +,   2.2821447E-04,   1.4351591E-04,   9.1999769E-05
     +,   5.9981907E-05,   3.9513037E-05,   2.6088555E-05
     +,   1.7135557E-05,   1.1128026E-05,   7.1109689E-06
     +,   4.4547037E-06,   2.7278220E-06,   1.6289005E-06
     +,   9.4676051E-07,   5.3486406E-07,   2.9337744E-07
     +,   1.5611374E-07,   8.0549341E-08,   4.0286150E-08
     +,   1.9527594E-08,   9.1737782E-09,   4.1782684E-09
     +,   1.8464157E-09,   7.9294094E-10,   3.3205991E-10
     +,   1.3660018E-10,   5.6051889E-11,   2.3634341E-11
     +,   1.0754861E-11,   5.5882751E-12,   3.4039978E-12
     +,   2.3681426E-12,   1.7880750E-12,   1.4059322E-12
     +,   1.1246286E-12,   9.0524235E-13,   7.2981953E-13
     +,   5.8824327E-13,   4.7366944E-13,   3.8093668E-13
     +,   3.0595310E-13,   2.4539260E-13,   1.9655017E-13
     +,   1.5721094E-13,   1.2557268E-13,   1.0016238E-13
     +,   7.9784195E-14,   6.3463761E-14,   5.0412281E-14
     +,   3.9989259E-14,   3.1677619E-14,   2.5058856E-14
     +,   1.9795406E-14,   1.5616011E-14,   1.2301865E-14
     +,   9.6777444E-15,   7.6027755E-15,   5.9644642E-15
     +,   4.6726733E-15,   3.6556223E-15,   2.8559507E-15
     +,   2.2281371E-15,   1.7359138E-15,   1.3505638E-15
     +,   1.0492910E-15,   8.1409930E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt108 = Yx/0.395428571428571
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.6171598E-06,   5.8355145E-06
     +,   6.0537573E-06,   6.2712888E-06,   6.4875017E-06
     +,   6.7017727E-06,   6.9134881E-06,   7.1220320E-06
     +,   7.3267965E-06,   7.5271937E-06,   7.7226550E-06
     +,   7.9126312E-06,   8.0966147E-06,   8.2741290E-06
     +,   8.4447493E-06,   8.6080981E-06,   8.7638573E-06
     +,   8.9117730E-06,   9.0516642E-06,   9.1834254E-06
     +,   9.3070339E-06,   9.4225543E-06,   9.5301457E-06
     +,   9.6300719E-06,   9.7226884E-06,   9.8084729E-06
     +,   9.8879982E-06,   9.9619638E-06,   1.0031181E-05
     +,   1.0096575E-05,   1.0159194E-05,   1.0220200E-05
     +,   1.0280874E-05,   1.0342611E-05,   1.0406918E-05
     +,   1.0475404E-05,   1.0549786E-05,   1.0631870E-05
     +,   1.0723555E-05,   1.0826811E-05,   1.0943681E-05
     +,   1.1076258E-05,   1.1226686E-05,   1.1397131E-05
     +,   1.1589777E-05,   1.1806803E-05,   1.2050368E-05
     +,   1.2322603E-05,   1.2625565E-05,   1.2961250E-05
     +,   1.3331551E-05,   1.3738239E-05,   1.4182954E-05
     +,   1.4667193E-05,   1.5192223E-05,   1.5759180E-05
     +,   1.6368940E-05,   1.7022156E-05,   1.7719231E-05
     +,   1.8460300E-05,   1.9245217E-05,   2.0073570E-05
     +,   2.0944595E-05,   2.1857286E-05,   2.2810342E-05
     +,   2.3802069E-05,   2.4830591E-05,   2.5893629E-05
     +,   2.6988735E-05,   2.8113080E-05,   2.9263703E-05
     +,   3.0437302E-05,   3.1630494E-05,   3.2839591E-05
     +,   3.4060853E-05,   3.5290461E-05,   3.6524412E-05
     +,   3.7758677E-05,   3.8989307E-05,   4.0212373E-05
     +,   4.1423922E-05,   4.2620264E-05,   4.3797703E-05
     +,   4.4952892E-05,   4.6082554E-05,   4.7183792E-05
     +,   4.8253889E-05,   4.9290535E-05,   5.0291645E-05
     +,   5.1255556E-05,   5.2180992E-05,   5.3066942E-05
     +,   5.3912812E-05,   5.4718399E-05,   5.5483877E-05
     +,   5.6209690E-05,   5.6896733E-05,   5.7546098E-05
     +,   5.8159294E-05,   5.8737995E-05,   5.9284237E-05
     +,   5.9800182E-05,   6.0288297E-05,   6.0751136E-05
     +,   6.1191538E-05,   6.1612445E-05,   6.2017003E-05
     +,   6.2408530E-05,   6.2790554E-05,   6.3166910E-05
     +,   6.3541687E-05,   6.3919390E-05,   6.4304993E-05
     +,   6.4704058E-05,   6.5122826E-05,   6.5568478E-05
     +,   6.6049106E-05,   6.6574037E-05,   6.7153938E-05
     +,   6.7801018E-05,   6.8529240E-05,   6.9354355E-05
     +,   7.0294183E-05,   7.1368755E-05,   7.2600385E-05
     +,   7.4013624E-05,   7.5635558E-05,   7.7495555E-05
     +,   7.9625439E-05,   8.2059247E-05,   8.4833373E-05
     +,   8.7986169E-05,   9.1558264E-05,   9.5591815E-05
     +,   1.0013123E-04,   1.0522272E-04,   1.1091417E-04
     +,   1.1725511E-04,   1.2429769E-04,   1.3209613E-04
     +,   1.4070648E-04,   1.5018742E-04,   1.6060058E-04
     +,   1.7201019E-04,   1.8448180E-04,   1.9808399E-04
     +,   2.1288657E-04,   2.2895855E-04,   2.4636785E-04
     +,   2.6518080E-04,   2.8545989E-04,   3.0726040E-04
     +,   3.3063069E-04,   3.5561252E-04,   3.8223912E-04
     +,   4.1053319E-04,   4.4050673E-04,   4.7216355E-04
     +,   5.0549250E-04,   5.4046052E-04,   5.7700888E-04
     +,   6.1503932E-04,   6.5439491E-04,   6.9484563E-04
     +,   7.3607243E-04,   7.7765482E-04,   8.1906351E-04
     +,   8.5967762E-04,   8.9882471E-04,   9.3584205E-04
     +,   9.7017485E-04,   1.0015137E-03,   1.0299654E-03
     +,   1.0562529E-03,   1.0819272E-03,   1.1095802E-03
     +,   1.1429986E-03,   1.1872065E-03,   1.2482976E-03
     +,   1.3329656E-03,   1.4476331E-03,   1.5971840E-03
     +,   1.7834725E-03,   2.0040167E-03,   2.2513983E-03
     +,   2.5140720E-03,   2.7790351E-03,   3.0362492E-03
     +,   3.2838918E-03,   3.5326642E-03,   3.8070467E-03
     +,   4.1412213E-03,   4.5690304E-03,   5.1096617E-03
     +,   5.7537542E-03,   6.4567602E-03,   7.1472004E-03
     +,   7.7544856E-03,   8.2512423E-03,   8.6902902E-03
     +,   9.2116557E-03,   1.0026963E-02,   1.1436950E-02
     +,   1.3879371E-02,   1.7799828E-02,   2.3242047E-02
     +,   2.9868538E-02,   3.7410516E-02,   4.4230293E-02
     +,   4.8481774E-02,   5.3260330E-02,   6.2343664E-02
     +,   7.9708926E-02,   9.8778561E-02,   0.1057756    
     +,   0.1112238    ,   0.1176023    ,   0.1089070    
     +,   9.5860079E-02,   8.8390641E-02,   7.5756550E-02
     +,   6.2222134E-02,   5.3587683E-02,   4.4781264E-02
     +,   3.4856033E-02,   2.6739525E-02,   2.0960592E-02
     +,   1.6417410E-02,   1.2501625E-02,   9.1418112E-03
     +,   6.3925255E-03,   4.2736172E-03,   2.7426716E-03
     +,   1.7016073E-03,   1.0264233E-03,   6.0297427E-04
     +,   3.4496174E-04,   1.9290939E-04,   1.0676046E-04
     +,   5.9803155E-05,   3.4846256E-05,   2.1518514E-05
     +,   1.4055525E-05,   9.5188952E-06,   6.5208992E-06
     +,   4.4316989E-06,   2.9523176E-06,   1.9156182E-06
     +,   1.2069110E-06,   7.3738204E-07,   4.3663599E-07
     +,   2.5053328E-07,   1.3929099E-07,   7.5044944E-08
     +,   3.9183838E-08,   1.9832340E-08,   9.7347925E-09
     +,   4.6382027E-09,   2.1486080E-09,   9.7087283E-10
     +,   4.3071252E-10,   1.8997640E-10,   8.5246372E-11
     +,   4.0373090E-11,   2.1102545E-11,   1.2539217E-11
     +,   8.4113810E-12,   6.1501759E-12,   4.7226775E-12
     +,   3.7134384E-12,   2.9490670E-12,   2.3499739E-12
     +,   1.8734628E-12,   1.4924222E-12,   1.1873600E-12
     +,   9.4327194E-13,   7.4819708E-13,   5.9253389E-13
     +,   4.6850962E-13,   3.6985790E-13,   2.9151058E-13
     +,   2.2939522E-13,   1.8022504E-13,   1.4136953E-13
     +,   1.1071215E-13,   8.6565256E-14,   6.7576194E-14
     +,   5.2667577E-14,   4.0982527E-14,   3.1838390E-14
     +,   2.4695052E-14,   1.9123398E-14,   1.4785099E-14
     +,   1.1412490E-14,   8.7950828E-15,   6.7669708E-15
     +,   5.1981988E-15,   3.9866271E-15,   3.0525339E-15
     +,   2.3335103E-15,   1.7809861E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt110 = Yx/0.386857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7644962E-06,   2.9640360E-06
     +,   3.1737673E-06,   3.3938677E-06,   3.6244905E-06
     +,   3.8657654E-06,   4.1177955E-06,   4.3806581E-06
     +,   4.6543951E-06,   4.9390364E-06,   5.2345640E-06
     +,   5.5409364E-06,   5.8580790E-06,   6.1858855E-06
     +,   6.5242175E-06,   6.8729041E-06,   7.2317421E-06
     +,   7.6004981E-06,   7.9789070E-06,   8.3666710E-06
     +,   8.7634626E-06,   9.1689290E-06,   9.5826799E-06
     +,   1.0004329E-05,   1.0433409E-05,   1.0869488E-05
     +,   1.1312076E-05,   1.1760671E-05,   1.2214755E-05
     +,   1.2673788E-05,   1.3137217E-05,   1.3604473E-05
     +,   1.4074975E-05,   1.4548130E-05,   1.5023335E-05
     +,   1.5499974E-05,   1.5977439E-05,   1.6455087E-05
     +,   1.6932319E-05,   1.7408473E-05,   1.7882934E-05
     +,   1.8355056E-05,   1.8824210E-05,   1.9289761E-05
     +,   1.9751067E-05,   2.0207504E-05,   2.0658454E-05
     +,   2.1103284E-05,   2.1541380E-05,   2.1972139E-05
     +,   2.2394963E-05,   2.2809258E-05,   2.3214432E-05
     +,   2.3609955E-05,   2.3995244E-05,   2.4369772E-05
     +,   2.4733035E-05,   2.5084522E-05,   2.5423769E-05
     +,   2.5750322E-05,   2.6063770E-05,   2.6363725E-05
     +,   2.6649819E-05,   2.6921751E-05,   2.7179252E-05
     +,   2.7422077E-05,   2.7650063E-05,   2.7863069E-05
     +,   2.8061040E-05,   2.8243961E-05,   2.8411909E-05
     +,   2.8565002E-05,   2.8703469E-05,   2.8827593E-05
     +,   2.8937780E-05,   2.9034505E-05,   2.9118359E-05
     +,   2.9190029E-05,   2.9250339E-05,   2.9300212E-05
     +,   2.9340728E-05,   2.9373083E-05,   2.9398620E-05
     +,   2.9418852E-05,   2.9435421E-05,   2.9450151E-05
     +,   2.9465040E-05,   2.9482242E-05,   2.9504099E-05
     +,   2.9533125E-05,   2.9572031E-05,   2.9623679E-05
     +,   2.9691126E-05,   2.9777584E-05,   2.9886436E-05
     +,   3.0021201E-05,   3.0185542E-05,   3.0383209E-05
     +,   3.0618092E-05,   3.0894102E-05,   3.1215237E-05
     +,   3.1585467E-05,   3.2008775E-05,   3.2489072E-05
     +,   3.3030188E-05,   3.3635864E-05,   3.4309651E-05
     +,   3.5054891E-05,   3.5874764E-05,   3.6772231E-05
     +,   3.7749902E-05,   3.8810227E-05,   3.9955274E-05
     +,   4.1186948E-05,   4.2506774E-05,   4.3916185E-05
     +,   4.5416236E-05,   4.7008045E-05,   4.8692396E-05
     +,   5.0470255E-05,   5.2342635E-05,   5.4310593E-05
     +,   5.6375520E-05,   5.8539317E-05,   6.0804468E-05
     +,   6.3174040E-05,   6.5652290E-05,   6.8244379E-05
     +,   7.0957220E-05,   7.3799114E-05,   7.6780867E-05
     +,   7.9915393E-05,   8.3219129E-05,   8.6711734E-05
     +,   9.0417707E-05,   9.4366980E-05,   9.8595810E-05
     +,   1.0314836E-04,   1.0807852E-04,   1.1345156E-04
     +,   1.1934548E-04,   1.2585348E-04,   1.3308598E-04
     +,   1.4117215E-04,   1.5025954E-04,   1.6051589E-04
     +,   1.7212681E-04,   1.8529186E-04,   2.0021945E-04
     +,   2.1712029E-04,   2.3619652E-04,   2.5762725E-04
     +,   2.8155523E-04,   3.0807281E-04,   3.3720437E-04
     +,   3.6889070E-04,   4.0297836E-04,   4.3921568E-04
     +,   4.7725107E-04,   5.1663647E-04,   5.5685180E-04
     +,   5.9732655E-04,   6.3747080E-04,   6.7671941E-04
     +,   7.1457878E-04,   7.5066893E-04,   7.8476238E-04
     +,   8.1681815E-04,   8.4700302E-04,   8.7568420E-04
     +,   9.0340880E-04,   9.3085779E-04,   9.5877971E-04
     +,   9.8790776E-04,   1.0188638E-03,   1.0520803E-03
     +,   1.0877334E-03,   1.1257145E-03,   1.1656564E-03
     +,   1.2070262E-03,   1.2492745E-03,   1.2920324E-03
     +,   1.3353406E-03,   1.3798543E-03,   1.4269828E-03
     +,   1.4789122E-03,   1.5385160E-03,   1.6091419E-03
     +,   1.6943718E-03,   1.7978424E-03,   1.9233673E-03
     +,   2.0754938E-03,   2.2605900E-03,   2.4883084E-03
     +,   2.7727953E-03,   3.1325726E-03,   3.5879433E-03
     +,   4.1553862E-03,   4.8393309E-03,   5.6238296E-03
     +,   6.4693103E-03,   7.3218201E-03,   8.1380382E-03
     +,   8.9192772E-03,   9.7371927E-03,   1.0736740E-02
     +,   1.2130668E-02,   1.4202841E-02,   1.7207583E-02
     +,   2.1099046E-02,   2.5569381E-02,   3.0523745E-02
     +,   3.6009047E-02,   4.2570855E-02,   5.2385006E-02
     +,   6.5815620E-02,   8.0078185E-02,   9.5519237E-02
     +,   0.1032477    ,   0.1071443    ,   0.1161609    
     +,   0.1200621    ,   0.1181099    ,   0.1079351    
     +,   9.1824390E-02,   7.2394088E-02,   5.3536311E-02
     +,   3.8745575E-02,   2.7305178E-02,   1.8510129E-02
     +,   1.1981571E-02,   7.2678258E-03,   4.0109497E-03
     +,   1.9784332E-03,   8.7318616E-04,   3.5169555E-04
     +,   1.3732718E-04,   6.0243736E-05,   3.5537429E-05
     +,   2.7793551E-05,   2.4626734E-05,   2.2416731E-05
     +,   2.0305455E-05,   1.8162602E-05,   1.6017020E-05
     +,   1.3922038E-05,   1.1926805E-05,   1.0070267E-05
     +,   8.3801251E-06,   6.8731806E-06,   5.5559758E-06
     +,   4.4264420E-06,   3.4757152E-06,   2.6898749E-06
     +,   2.0517061E-06,   1.5423739E-06,   1.1427701E-06
     +,   8.3450260E-07,   6.0060910E-07,   4.2603634E-07
     +,   2.9784911E-07,   2.0523288E-07,   1.3937763E-07
     +,   9.3288811E-08,   6.1541471E-08,   4.0013159E-08
     +,   2.5640622E-08,   1.6193905E-08,   1.0080453E-08
     +,   6.1845555E-09,   3.7396597E-09,   2.2287479E-09
     +,   1.3092045E-09,   7.5800066E-10,   4.3256471E-10
     +,   2.4332214E-10,   1.3491777E-10,   7.3750624E-11
     +,   3.9747549E-11,   2.1125586E-11,   1.1076026E-11
     +,   5.7316482E-12,   2.9298109E-12,   1.4814017E-12
     +,   7.4252285E-13,   3.7025499E-13,   1.8468925E-13
     +,   9.2932240E-14,   4.7736669E-14,   2.5407841E-14
     +,   1.4231200E-14,   8.4821227E-15,   5.3921520E-15
     +,   3.6293312E-15,   2.5528590E-15,   1.8507664E-15
     +,   1.3673406E-15,   1.0211697E-15,   7.6695657E-16
     +,   5.7745359E-16,   4.3505756E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt112 = Yx/0.378285714285714
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3774912E-13,   4.5069103E-13
     +,   5.9997076E-13,   7.9679888E-13,   1.0556885E-12
     +,   1.3953712E-12,   1.8399770E-12,   2.4204902E-12
     +,   3.1765890E-12,   4.1590121E-12,   5.4323612E-12
     +,   7.0787508E-12,   9.2022813E-12,   1.1934506E-11
     +,   1.5441331E-11,   1.9931348E-11,   2.5666138E-11
     +,   3.2972895E-11,   4.2259755E-11,   5.4034398E-11
     +,   6.8926823E-11,   8.7716438E-11,   1.1136477E-10
     +,   1.4105701E-10,   1.7824416E-10,   2.2470663E-10
     +,   2.8261538E-10,   3.5461334E-10,   4.4391130E-10
     +,   5.5439520E-10,   6.9075901E-10,   8.5865476E-10
     +,   1.0648717E-09,   1.3175406E-09,   1.6263761E-09
     +,   2.0029478E-09,   2.4610078E-09,   3.0168297E-09
     +,   3.6896977E-09,   4.5022492E-09,   5.4811857E-09
     +,   6.6577539E-09,   8.0684943E-09,   9.7560289E-09
     +,   1.1769919E-08,   1.4167685E-08,   1.7015875E-08
     +,   2.0391308E-08,   2.4382475E-08,   2.9091021E-08
     +,   3.4633430E-08,   4.1143025E-08,   4.8771682E-08
     +,   5.7693050E-08,   6.8103361E-08,   8.0226471E-08
     +,   9.4315126E-08,   1.1065526E-07,   1.2956986E-07
     +,   1.5142284E-07,   1.7662400E-07,   2.0563496E-07
     +,   2.3897215E-07,   2.7721802E-07,   3.2102662E-07
     +,   3.7112667E-07,   4.2834165E-07,   4.9358658E-07
     +,   5.6789452E-07,   6.5241284E-07,   7.4843621E-07
     +,   8.5740101E-07,   9.8092823E-07,   1.1208124E-06
     +,   1.2790725E-06,   1.4579624E-06,   1.6599840E-06
     +,   1.8879198E-06,   2.1448777E-06,   2.4343080E-06
     +,   2.7599981E-06,   3.1261734E-06,   3.5374333E-06
     +,   3.9988745E-06,   4.5160041E-06,   5.0948775E-06
     +,   5.7419702E-06,   6.4643323E-06,   7.2694152E-06
     +,   8.1651997E-06,   9.1601214E-06,   1.0262932E-05
     +,   1.1482691E-05,   1.2828767E-05,   1.4310672E-05
     +,   1.5937767E-05,   1.7719474E-05,   1.9664672E-05
     +,   2.1781980E-05,   2.4079040E-05,   2.6562846E-05
     +,   2.9238905E-05,   3.2111660E-05,   3.5183530E-05
     +,   3.8455313E-05,   4.1925727E-05,   4.5590918E-05
     +,   4.9444512E-05,   5.3477706E-05,   5.7678961E-05
     +,   6.2033490E-05,   6.6524204E-05,   7.1130686E-05
     +,   7.5830438E-05,   8.0597863E-05,   8.5405751E-05
     +,   9.0224377E-05,   9.5023068E-05,   9.9769430E-05
     +,   1.0443091E-04,   1.0897485E-04,   1.1336867E-04
     +,   1.1758097E-04,   1.2158208E-04,   1.2534467E-04
     +,   1.2884360E-04,   1.3205764E-04,   1.3496885E-04
     +,   1.3756394E-04,   1.3983392E-04,   1.4177508E-04
     +,   1.4338859E-04,   1.4468133E-04,   1.4566550E-04
     +,   1.4635893E-04,   1.4678499E-04,   1.4697239E-04
     +,   1.4695519E-04,   1.4677258E-04,   1.4646862E-04
     +,   1.4609228E-04,   1.4569718E-04,   1.4534166E-04
     +,   1.4508869E-04,   1.4500628E-04,   1.4516752E-04
     +,   1.4565109E-04,   1.4654151E-04,   1.4792923E-04
     +,   1.4991093E-04,   1.5258892E-04,   1.5607005E-04
     +,   1.6046388E-04,   1.6588082E-04,   1.7242857E-04
     +,   1.8020842E-04,   1.8931173E-04,   1.9981890E-04
     +,   2.1179882E-04,   2.2531141E-04,   2.4041891E-04
     +,   2.5719992E-04,   2.7576988E-04,   2.9630901E-04
     +,   3.1909288E-04,   3.4451863E-04,   3.7312106E-04
     +,   4.0557125E-04,   4.4265346E-04,   4.8520081E-04
     +,   5.3399854E-04,   5.8966188E-04,   6.5250508E-04
     +,   7.2241912E-04,   7.9879176E-04,   8.8053528E-04
     +,   9.6621498E-04,   1.0543083E-03,   1.1436014E-03
     +,   1.2336539E-03,   1.3252194E-03,   1.4204944E-03
     +,   1.5230434E-03,   1.6372654E-03,   1.7673631E-03
     +,   1.9159589E-03,   2.0827232E-03,   2.2635076E-03
     +,   2.4504380E-03,   2.6332808E-03,   2.8020046E-03
     +,   2.9497987E-03,   3.0756032E-03,   3.1851726E-03
     +,   3.2900360E-03,   3.4046781E-03,   3.5431983E-03
     +,   3.7173873E-03,   3.9376775E-03,   4.2162291E-03
     +,   4.5687291E-03,   5.0120116E-03,   5.5614859E-03
     +,   6.2385625E-03,   7.0872288E-03,   8.1714094E-03
     +,   9.5268786E-03,   1.1113449E-02,   1.2862621E-02
     +,   1.4796566E-02,   1.7038552E-02,   1.9637603E-02
     +,   2.2602489E-02,   2.6767427E-02,   3.3773266E-02
     +,   4.2709418E-02,   5.0476145E-02,   5.7574224E-02
     +,   6.6452503E-02,   8.2255870E-02,   0.1011008    
     +,   0.1160563    ,   0.1245200    ,   0.1285772    
     +,   0.1212838    ,   0.1056084    ,   8.4675916E-02
     +,   6.2368911E-02,   4.3139968E-02,   2.8455036E-02
     +,   1.7127421E-02,   9.2044929E-03,   4.4820909E-03
     +,   1.9538396E-03,   7.5435173E-04,   2.7182273E-04
     +,   1.0610137E-04,   5.2513977E-05,   3.2467742E-05
     +,   2.2623570E-05,   1.7071934E-05,   1.3996252E-05
     +,   1.2404216E-05,   1.1616382E-05,   1.1208388E-05
     +,   1.0951941E-05,   1.0740902E-05,   1.0532501E-05
     +,   1.0312088E-05,   1.0075914E-05,   9.8239225E-06
     +,   9.5572250E-06,   9.2772898E-06,   8.9857067E-06
     +,   8.6840882E-06,   8.3740615E-06,   8.0572763E-06
     +,   7.7353652E-06,   7.4099153E-06,   7.0824690E-06
     +,   6.7545375E-06,   6.4275655E-06,   6.1029054E-06
     +,   5.7818297E-06,   5.4655497E-06,   5.1551510E-06
     +,   4.8516245E-06,   4.5558754E-06,   4.2687061E-06
     +,   3.9907968E-06,   3.7227246E-06,   3.4649822E-06
     +,   3.2179616E-06,   2.9819448E-06,   2.7571220E-06
     +,   2.5436207E-06,   2.3414573E-06,   2.1506025E-06
     +,   1.9709314E-06,   1.8022824E-06,   1.6444158E-06
     +,   1.4970649E-06,   1.3598996E-06,   1.2325742E-06
     +,   1.1146968E-06,   1.0058669E-06,   9.0565561E-07
     +,   8.1362231E-07,   7.2932812E-07,   6.5231899E-07
     +,   5.8215346E-07,   5.1838452E-07,   4.6058204E-07
     +,   4.0831833E-07,   3.6118621E-07,   3.1878690E-07
     +,   2.8074379E-07,   2.4669302E-07,   2.1629383E-07
     +,   1.8922044E-07,   1.6517060E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt113 = Yx/0.356285714285714
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2113163E-07,   1.3514651E-07
     +,   1.5057252E-07,   1.6752513E-07,   1.8612654E-07
     +,   2.0650501E-07,   2.2879551E-07,   2.5313889E-07
     +,   2.7968196E-07,   3.0857893E-07,   3.3998828E-07
     +,   3.7407429E-07,   4.1100617E-07,   4.5095811E-07
     +,   4.9410778E-07,   5.4063673E-07,   5.9072909E-07
     +,   6.4457112E-07,   7.0235041E-07,   7.6425454E-07
     +,   8.3047127E-07,   9.0118539E-07,   9.7657892E-07
     +,   1.0568347E-06,   1.1421208E-06,   1.2326093E-06
     +,   1.3284591E-06,   1.4298209E-06,   1.5368366E-06
     +,   1.6496346E-06,   1.7683329E-06,   1.8930350E-06
     +,   2.0238281E-06,   2.1607846E-06,   2.3039590E-06
     +,   2.4533883E-06,   2.6090893E-06,   2.7710585E-06
     +,   2.9392818E-06,   3.1137051E-06,   3.2942744E-06
     +,   3.4809043E-06,   3.6734912E-06,   3.8719108E-06
     +,   4.0760251E-06,   4.2856709E-06,   4.5006750E-06
     +,   4.7208505E-06,   4.9459923E-06,   5.1758916E-06
     +,   5.4103293E-06,   5.6490849E-06,   5.8919336E-06
     +,   6.1386681E-06,   6.3890670E-06,   6.6429466E-06
     +,   6.9001289E-06,   7.1604691E-06,   7.4238487E-06
     +,   7.6901952E-06,   7.9594856E-06,   8.2317592E-06
     +,   8.5071060E-06,   8.7857225E-06,   9.0678968E-06
     +,   9.3539920E-06,   9.6445428E-06,   9.9401750E-06
     +,   1.0241713E-05,   1.0550123E-05,   1.0866598E-05
     +,   1.1192522E-05,   1.1529559E-05,   1.1879592E-05
     +,   1.2244836E-05,   1.2627830E-05,   1.3031416E-05
     +,   1.3458819E-05,   1.3913683E-05,   1.4400055E-05
     +,   1.4922378E-05,   1.5485602E-05,   1.6095071E-05
     +,   1.6756649E-05,   1.7476583E-05,   1.8261670E-05
     +,   1.9119008E-05,   2.0056224E-05,   2.1081185E-05
     +,   2.2202174E-05,   2.3427750E-05,   2.4766612E-05
     +,   2.6227592E-05,   2.7819677E-05,   2.9551909E-05
     +,   3.1433112E-05,   3.3472170E-05,   3.5677615E-05
     +,   3.8057984E-05,   4.0621260E-05,   4.3375447E-05
     +,   4.6327918E-05,   4.9486047E-05,   5.2856489E-05
     +,   5.6445861E-05,   6.0260434E-05,   6.4305903E-05
     +,   6.8587462E-05,   7.3110154E-05,   7.7878518E-05
     +,   8.2895858E-05,   8.8165412E-05,   9.3688766E-05
     +,   9.9466924E-05,   1.0549880E-04,   1.1178250E-04
     +,   1.1831330E-04,   1.2508527E-04,   1.3208941E-04
     +,   1.3931477E-04,   1.4674821E-04,   1.5437337E-04
     +,   1.6217172E-04,   1.7012293E-04,   1.7820488E-04
     +,   1.8639311E-04,   1.9466304E-04,   2.0298841E-04
     +,   2.1134372E-04,   2.1970272E-04,   2.2804081E-04
     +,   2.3633290E-04,   2.4455640E-04,   2.5268839E-04
     +,   2.6070769E-04,   2.6859410E-04,   2.7632684E-04
     +,   2.8388546E-04,   2.9124907E-04,   2.9839578E-04
     +,   3.0530151E-04,   3.1194021E-04,   3.1828365E-04
     +,   3.2430107E-04,   3.2995868E-04,   3.3522074E-04
     +,   3.4005014E-04,   3.4440789E-04,   3.4825594E-04
     +,   3.5155850E-04,   3.5428372E-04,   3.5640635E-04
     +,   3.5791236E-04,   3.5880244E-04,   3.5909805E-04
     +,   3.5884866E-04,   3.5814018E-04,   3.5710543E-04
     +,   3.5593685E-04,   3.5490078E-04,   3.5435252E-04
     +,   3.5475430E-04,   3.5668921E-04,   3.6087466E-04
     +,   3.6816701E-04,   3.7955615E-04,   3.9614100E-04
     +,   4.1908349E-04,   4.4953736E-04,   4.8854551E-04
     +,   5.3690874E-04,   5.9504580E-04,   6.6285644E-04
     +,   7.3960930E-04,   8.2388037E-04,   9.1360492E-04
     +,   1.0062144E-03,   1.0988901E-03,   1.1889311E-03
     +,   1.2741766E-03,   1.3534166E-03,   1.4267277E-03
     +,   1.4956623E-03,   1.5632169E-03,   1.6335509E-03
     +,   1.7114428E-03,   1.8015896E-03,   1.9078250E-03
     +,   2.0324283E-03,   2.1757092E-03,   2.3360699E-03
     +,   2.5105448E-03,   2.6957910E-03,   2.8892853E-03
     +,   3.0903881E-03,   3.3008629E-03,   3.5246378E-03
     +,   3.7668233E-03,   4.0323567E-03,   4.3249782E-03
     +,   4.6474654E-03,   5.0034504E-03,   5.4002232E-03
     +,   5.8510574E-03,   6.3759307E-03,   7.0007225E-03
     +,   7.7565941E-03,   8.6828172E-03,   9.8316073E-03
     +,   1.1264273E-02,   1.3027454E-02,   1.5108907E-02
     +,   1.7390324E-02,   1.9675126E-02,   2.1986749E-02
     +,   2.5275754E-02,   3.1568222E-02,   4.1929070E-02
     +,   5.4386798E-02,   6.6405490E-02,   7.7876449E-02
     +,   8.8771872E-02,   0.1026968    ,   0.1159096    
     +,   0.1261793    ,   0.1315513    ,   0.1218736    
     +,   0.1025980    ,   7.9368658E-02,   5.6421656E-02
     +,   3.4908582E-02,   1.7431661E-02,   6.8887784E-03
     +,   2.1816196E-03,   5.8913656E-04,   1.8135496E-04
     +,   1.0076987E-04,   8.3131679E-05,   7.2494418E-05
     +,   6.1744548E-05,   5.1236992E-05,   4.1757146E-05
     +,   3.3719607E-05,   2.7181175E-05,   2.1970751E-05
     +,   1.7824206E-05,   1.4481654E-05,   1.1736898E-05
     +,   9.4481156E-06,   7.5263588E-06,   5.9165091E-06
     +,   4.5812008E-06,   3.4901004E-06,   2.6143655E-06
     +,   1.9249169E-06,   1.3928260E-06,   9.9035231E-07
     +,   6.9196034E-07,   4.7507265E-07,   3.2049300E-07
     +,   2.1245235E-07,   1.3838743E-07,   8.8576648E-08
     +,   5.5708902E-08,   3.4429359E-08,   2.0908848E-08
     +,   1.2477463E-08,   7.3170048E-09,   4.2166843E-09
     +,   2.3880820E-09,   1.3291879E-09,   7.2715678E-10
     +,   3.9105844E-10,   2.0677869E-10,   1.0753410E-10
     +,   5.5028353E-11,   2.7728762E-11,   1.3775194E-11
     +,   6.7585226E-12,   3.2842101E-12,   1.5873946E-12
     +,   7.6811420E-13,   3.7548239E-13,   1.8765099E-13
     +,   9.7168022E-14,   5.2765280E-14,   3.0249478E-14
     +,   1.8286081E-14,   1.1562974E-14,   7.5613530E-15
     +,   5.0568807E-15,   3.4278932E-15,   2.3404526E-15
     +,   1.6028942E-15,   1.0983716E-15,   7.5191872E-16
     +,   5.1381500E-16,   3.5029810E-16,   2.3821224E-16
     +,   1.6155438E-16,   1.0926579E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt114 = Yx/0.354857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8146702E-06,   3.9990941E-06
     +,   4.1874309E-06,   4.3794407E-06,   4.5748666E-06
     +,   4.7734366E-06,   4.9748646E-06,   5.1788547E-06
     +,   5.3850972E-06,   5.5932856E-06,   5.8031023E-06
     +,   6.0142265E-06,   6.2263462E-06,   6.4391506E-06
     +,   6.6523380E-06,   6.8656227E-06,   7.0787328E-06
     +,   7.2914195E-06,   7.5034545E-06,   7.7146451E-06
     +,   7.9248266E-06,   8.1338712E-06,   8.3416935E-06
     +,   8.5482661E-06,   8.7535846E-06,   8.9577270E-06
     +,   9.1608108E-06,   9.3630169E-06,   9.5645955E-06
     +,   9.7658531E-06,   9.9671806E-06,   1.0169020E-05
     +,   1.0371906E-05,   1.0576429E-05,   1.0783261E-05
     +,   1.0993150E-05,   1.1206910E-05,   1.1425424E-05
     +,   1.1649662E-05,   1.1880629E-05,   1.2119416E-05
     +,   1.2367163E-05,   1.2625057E-05,   1.2894339E-05
     +,   1.3176279E-05,   1.3472189E-05,   1.3783393E-05
     +,   1.4111233E-05,   1.4457057E-05,   1.4822204E-05
     +,   1.5207998E-05,   1.5615735E-05,   1.6046653E-05
     +,   1.6501990E-05,   1.6982849E-05,   1.7490318E-05
     +,   1.8025363E-05,   1.8588875E-05,   1.9181613E-05
     +,   1.9804242E-05,   2.0457270E-05,   2.1141099E-05
     +,   2.1855927E-05,   2.2601862E-05,   2.3378851E-05
     +,   2.4186606E-05,   2.5024772E-05,   2.5892705E-05
     +,   2.6789739E-05,   2.7714881E-05,   2.8667126E-05
     +,   2.9645176E-05,   3.0647698E-05,   3.1673098E-05
     +,   3.2719730E-05,   3.3785840E-05,   3.4869481E-05
     +,   3.5968606E-05,   3.7081158E-05,   3.8205002E-05
     +,   3.9337843E-05,   4.0477491E-05,   4.1621577E-05
     +,   4.2767904E-05,   4.3914093E-05,   4.5057961E-05
     +,   4.6197201E-05,   4.7329737E-05,   4.8453352E-05
     +,   4.9566090E-05,   5.0666025E-05,   5.1751296E-05
     +,   5.2820127E-05,   5.3870939E-05,   5.4902270E-05
     +,   5.5912700E-05,   5.6901081E-05,   5.7866255E-05
     +,   5.8807378E-05,   5.9723629E-05,   6.0614482E-05
     +,   6.1479492E-05,   6.2318541E-05,   6.3131592E-05
     +,   6.3919026E-05,   6.4681422E-05,   6.5419707E-05
     +,   6.6135188E-05,   6.6829620E-05,   6.7505338E-05
     +,   6.8165173E-05,   6.8812675E-05,   6.9452202E-05
     +,   7.0089001E-05,   7.0729257E-05,   7.1380404E-05
     +,   7.2051043E-05,   7.2751274E-05,   7.3492585E-05
     +,   7.4288262E-05,   7.5153264E-05,   7.6104385E-05
     +,   7.7160345E-05,   7.8341836E-05,   7.9671488E-05
     +,   8.1173705E-05,   8.2874823E-05,   8.4802581E-05
     +,   8.6986271E-05,   8.9456065E-05,   9.2243070E-05
     +,   9.5378353E-05,   9.8893142E-05,   1.0281747E-04
     +,   1.0718039E-04,   1.1200923E-04,   1.1732849E-04
     +,   1.2315957E-04,   1.2952094E-04,   1.3642710E-04
     +,   1.4388814E-04,   1.5190977E-04,   1.6049400E-04
     +,   1.6963876E-04,   1.7933753E-04,   1.8958151E-04
     +,   2.0035949E-04,   2.1165806E-04,   2.2346310E-04
     +,   2.3576157E-04,   2.4854174E-04,   2.6179332E-04
     +,   2.7550870E-04,   2.8968448E-04,   3.0432115E-04
     +,   3.1942123E-04,   3.3499117E-04,   3.5104138E-04
     +,   3.6758633E-04,   3.8464498E-04,   4.0224724E-04
     +,   4.2044144E-04,   4.3930532E-04,   4.5896755E-04
     +,   4.7963695E-04,   5.0163828E-04,   5.2545348E-04
     +,   5.5176870E-04,   5.8151386E-04,   6.1588141E-04
     +,   6.5630535E-04,   7.0439378E-04,   7.6179340E-04
     +,   8.2997774E-04,   9.0996857E-04,   1.0020445E-03
     +,   1.1054567E-03,   1.2182222E-03,   1.3370962E-03
     +,   1.4577560E-03,   1.5752047E-03,   1.6843879E-03
     +,   1.7809583E-03,   1.8620507E-03,   1.9269069E-03
     +,   1.9772302E-03,   2.0171730E-03,   2.0529071E-03
     +,   2.0918173E-03,   2.1414531E-03,   2.2084941E-03
     +,   2.2979416E-03,   2.4128226E-03,   2.5545522E-03
     +,   2.7238580E-03,   2.9218630E-03,   3.1506766E-03
     +,   3.4129156E-03,   3.7098164E-03,   4.0384852E-03
     +,   4.3899622E-03,   4.7508520E-03,   5.1107472E-03
     +,   5.4752403E-03,   5.8798534E-03,   6.3960324E-03
     +,   7.1197371E-03,   8.1397025E-03,   9.4933864E-03
     +,   1.1128473E-02,   1.2890300E-02,   1.4550778E-02
     +,   1.5885169E-02,   1.6799040E-02,   1.7487567E-02
     +,   1.8535504E-02,   2.0823535E-02,   2.5055060E-02
     +,   3.0973600E-02,   3.7881594E-02,   4.6360645E-02
     +,   5.7334822E-02,   7.1692109E-02,   8.9139342E-02
     +,   0.1068659    ,   0.1217454    ,   0.1382937    
     +,   0.1535809    ,   0.1445266    ,   0.1125774    
     +,   7.1273200E-02,   3.3344392E-02,   1.0709442E-02
     +,   2.2689744E-03,   3.1242098E-04,   2.9202542E-05
     +,   2.0936811E-06,   1.3132234E-07,   1.7869830E-08
     +,   1.1735480E-08,   1.0084917E-08,   8.7322150E-09
     +,   7.5526945E-09,   6.5243451E-09,   5.6288978E-09
     +,   4.8502096E-09,   4.1739421E-09,   3.5873740E-09
     +,   3.0792600E-09,   2.6397142E-09,   2.2599767E-09
     +,   1.9323376E-09,   1.6500382E-09,   1.4071385E-09
     +,   1.1984145E-09,   1.0192984E-09,   8.6580260E-10
     +,   7.3444900E-10,   6.2219235E-10,   5.2638538E-10
     +,   4.4473453E-10,   3.7524611E-10,   3.1618899E-10
     +,   2.6606509E-10,   2.2358557E-10,   1.8763369E-10
     +,   1.5724809E-10,   1.3160381E-10,   1.0999226E-10
     +,   9.1804252E-11,   7.6518604E-11,   6.3690733E-11
     +,   5.2941023E-11,   4.3945361E-11,   3.6427805E-11
     +,   3.0154924E-11,   2.4927723E-11,   2.0578331E-11
     +,   1.6964288E-11,   1.3965727E-11,   1.1481227E-11
     +,   9.4257206E-12,   7.7274584E-12,   6.3264342E-12
     +,   5.1722116E-12,   4.2227302E-12,   3.4427597E-12
     +,   2.8029471E-12,   2.2788770E-12,   1.8502045E-12
     +,   1.5000918E-12,   1.2145277E-12,   9.8196158E-13
     +,   7.9281839E-13,   6.3922045E-13,   5.1465782E-13
     +,   4.1379216E-13,   3.3222928E-13,   2.6637273E-13
     +,   2.1327094E-13,   1.7051799E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt115 = Yx/0.353
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8824792E-10,   2.2984782E-10
     +,   2.8015484E-10,   3.4088130E-10,   4.1405299E-10
     +,   5.0206034E-10,   6.0772037E-10,   7.3434314E-10
     +,   8.8580959E-10,   1.0666700E-09,   1.2822362E-09
     +,   1.5386981E-09,   1.8432588E-09,   2.2042799E-09
     +,   2.6314506E-09,   3.1359619E-09,   3.7307344E-09
     +,   4.4306274E-09,   5.2527183E-09,   6.2165686E-09
     +,   7.3445454E-09,   8.6621732E-09,   1.0198477E-08
     +,   1.1986539E-08,   1.4063647E-08,   1.6472175E-08
     +,   1.9259804E-08,   2.2480213E-08,   2.6193701E-08
     +,   3.0467806E-08,   3.5378008E-08,   4.1008455E-08
     +,   4.7452758E-08,   5.4814709E-08,   6.3209292E-08
     +,   7.2763349E-08,   8.3616534E-08,   9.5922125E-08
     +,   1.0984882E-07,   1.2557926E-07,   1.4331428E-07
     +,   1.6327098E-07,   1.8568494E-07,   2.1081058E-07
     +,   2.3892204E-07,   2.7031371E-07,   3.0530086E-07
     +,   3.4422004E-07,   3.8742945E-07,   4.3530864E-07
     +,   4.8825893E-07,   5.4670301E-07,   6.1108324E-07
     +,   6.8186637E-07,   7.5953045E-07,   8.4457935E-07
     +,   9.3752885E-07,   1.0389095E-06,   1.1492643E-06
     +,   1.2691453E-06,   1.3991116E-06,   1.5397272E-06
     +,   1.6915473E-06,   1.8551331E-06,   2.0310395E-06
     +,   2.2197903E-06,   2.4219164E-06,   2.6378991E-06
     +,   2.8682200E-06,   3.1132984E-06,   3.3735450E-06
     +,   3.6492968E-06,   3.9408751E-06,   4.2485121E-06
     +,   4.5724132E-06,   4.9127216E-06,   5.2694986E-06
     +,   5.6427393E-06,   6.0323941E-06,   6.4383498E-06
     +,   6.8603963E-06,   7.2983166E-06,   7.7517843E-06
     +,   8.2204915E-06,   8.7040435E-06,   9.2020900E-06
     +,   9.7142274E-06,   1.0240145E-05,   1.0779534E-05
     +,   1.1332225E-05,   1.1898190E-05,   1.2477559E-05
     +,   1.3070694E-05,   1.3678309E-05,   1.4301492E-05
     +,   1.4941738E-05,   1.5601172E-05,   1.6282471E-05
     +,   1.6989161E-05,   1.7725537E-05,   1.8496963E-05
     +,   1.9309804E-05,   2.0171727E-05,   2.1091635E-05
     +,   2.2079919E-05,   2.3148517E-05,   2.4310870E-05
     +,   2.5582063E-05,   2.6978913E-05,   2.8519878E-05
     +,   3.0224879E-05,   3.2115513E-05,   3.4214463E-05
     +,   3.6545851E-05,   3.9134378E-05,   4.2005642E-05
     +,   4.5185177E-05,   4.8698763E-05,   5.2571155E-05
     +,   5.6826495E-05,   6.1487488E-05,   6.6574590E-05
     +,   7.2105780E-05,   7.8096433E-05,   8.4558669E-05
     +,   9.1500129E-05,   9.8925098E-05,   1.0683241E-04
     +,   1.1521692E-04,   1.2406742E-04,   1.3336839E-04
     +,   1.4309784E-04,   1.5322954E-04,   1.6373070E-04
     +,   1.7456450E-04,   1.8568931E-04,   1.9705862E-04
     +,   2.0862221E-04,   2.2032757E-04,   2.3212016E-04
     +,   2.4394348E-04,   2.5574066E-04,   2.6745666E-04
     +,   2.7903894E-04,   2.9043705E-04,   3.0160739E-04
     +,   3.1251344E-04,   3.2312772E-04,   3.3343569E-04
     +,   3.4343963E-04,   3.5316267E-04,   3.6265302E-04
     +,   3.7199067E-04,   3.8129365E-04,   3.9072329E-04
     +,   4.0048902E-04,   4.1085202E-04,   4.2212603E-04
     +,   4.3467447E-04,   4.4889990E-04,   4.6523457E-04
     +,   4.8412054E-04,   5.0598499E-04,   5.3121510E-04
     +,   5.6013343E-04,   5.9297099E-04,   6.2984694E-04
     +,   6.7075877E-04,   7.1558764E-04,   7.6411263E-04
     +,   8.1603538E-04,   8.7102753E-04,   9.2878338E-04
     +,   9.8907144E-04,   1.0517780E-03,   1.1169580E-03
     +,   1.1848479E-03,   1.2558645E-03,   1.3305852E-03
     +,   1.4097183E-03,   1.4940554E-03,   1.5844210E-03
     +,   1.6816380E-03,   1.7864960E-03,   1.8996958E-03
     +,   2.0217518E-03,   2.1528723E-03,   2.2927718E-03
     +,   2.4404484E-03,   2.5939737E-03,   2.7504496E-03
     +,   2.9061371E-03,   3.0568882E-03,   3.1989098E-03
     +,   3.3297744E-03,   3.4495108E-03,   3.5616481E-03
     +,   3.6742170E-03,   3.8007880E-03,   3.9617163E-03
     +,   4.1851723E-03,   4.5063668E-03,   4.9622641E-03
     +,   5.5799219E-03,   6.3616917E-03,   7.2773220E-03
     +,   8.2718814E-03,   9.2848716E-03,   1.0261730E-02
     +,   1.1150963E-02,   1.1918324E-02,   1.2613143E-02
     +,   1.3444304E-02,   1.4746479E-02,   1.6777208E-02
     +,   1.9454380E-02,   2.2290803E-02,   2.4792690E-02
     +,   2.7219664E-02,   3.0874895E-02,   3.6943562E-02
     +,   4.5397904E-02,   5.5365231E-02,   6.5326661E-02
     +,   7.6852903E-02,   9.0544961E-02,   0.1066422    
     +,   0.1308454    ,   0.1536661    ,   0.1588243    
     +,   0.1256863    ,   6.4606816E-02,   1.8798145E-02
     +,   2.7744703E-03,   2.6269394E-04,   9.5159514E-05
     +,   8.4975349E-05,   7.0412840E-05,   5.1270774E-05
     +,   3.2779866E-05,   1.8401463E-05,   9.0700787E-06
     +,   3.9255151E-06,   1.4917670E-06,   4.9774923E-07
     +,   1.4583088E-07,   3.7521097E-08,   8.4806215E-09
     +,   1.6864552E-09,   2.9744435E-10,   4.8536983E-11
     +,   8.9839438E-12,   3.0421609E-12,   1.9019159E-12
     +,   1.4382085E-12,   1.1202742E-12,   8.7506125E-13
     +,   6.8308304E-13,   5.3263795E-13,   4.1482299E-13
     +,   3.2265274E-13,   2.5062664E-13,   1.9440607E-13
     +,   1.5057721E-13,   1.1645657E-13,   8.9930084E-14
     +,   6.9336796E-14,   5.3374463E-14,   4.1020935E-14
     +,   3.1475304E-14,   2.4110901E-14,   1.8438913E-14
     +,   1.4077743E-14,   1.0729977E-14,   8.1644040E-15
     +,   6.2017639E-15,   4.7028438E-15,   3.5601282E-15
     +,   2.6904303E-15,   2.0297118E-15,   1.5286034E-15
     +,   1.1492377E-15,   8.6252423E-16,   6.4622738E-16
     +,   4.8333050E-16,   3.6087407E-16,   2.6897640E-16
     +,   2.0013215E-16,   1.4865193E-16,   1.1022171E-16
     +,   8.1585916E-17,   6.0284526E-17,   4.4467893E-17
     +,   3.2743882E-17,   2.4069397E-17,   1.7662042E-17
     +,   1.2938068E-17,   9.4610263E-18,   6.9064953E-18
     +,   5.0329250E-18,   3.6612788E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt116 = Yx/0.345333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt1168(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3447900E-06,   7.4423328E-06
     +,   7.5354251E-06,   7.6239648E-06,   7.7078676E-06
     +,   7.7870682E-06,   7.8615276E-06,   7.9312176E-06
     +,   7.9961401E-06,   8.0563186E-06,   8.1117960E-06
     +,   8.1626404E-06,   8.2089427E-06,   8.2508141E-06
     +,   8.2883944E-06,   8.3218411E-06,   8.3513378E-06
     +,   8.3770856E-06,   8.3993127E-06,   8.4182693E-06
     +,   8.4342191E-06,   8.4474486E-06,   8.4582680E-06
     +,   8.4670000E-06,   8.4739850E-06,   8.4795811E-06
     +,   8.4841568E-06,   8.4881021E-06,   8.4918101E-06
     +,   8.4956928E-06,   8.5001629E-06,   8.5056508E-06
     +,   8.5125885E-06,   8.5214151E-06,   8.5325719E-06
     +,   8.5465044E-06,   8.5636593E-06,   8.5844867E-06
     +,   8.6094287E-06,   8.6389291E-06,   8.6734317E-06
     +,   8.7133676E-06,   8.7591698E-06,   8.8112574E-06
     +,   8.8700463E-06,   8.9359437E-06,   9.0093445E-06
     +,   9.0906378E-06,   9.1801967E-06,   9.2783876E-06
     +,   9.3855606E-06,   9.5020587E-06,   9.6282047E-06
     +,   9.7643224E-06,   9.9107056E-06,   1.0067649E-05
     +,   1.0235429E-05,   1.0414311E-05,   1.0604545E-05
     +,   1.0806374E-05,   1.1020027E-05,   1.1245728E-05
     +,   1.1483677E-05,   1.1734074E-05,   1.1997126E-05
     +,   1.2273002E-05,   1.2561889E-05,   1.2863952E-05
     +,   1.3179373E-05,   1.3508304E-05,   1.3850924E-05
     +,   1.4207380E-05,   1.4577865E-05,   1.4962522E-05
     +,   1.5361540E-05,   1.5775115E-05,   1.6203418E-05
     +,   1.6646636E-05,   1.7104998E-05,   1.7578734E-05
     +,   1.8068056E-05,   1.8573246E-05,   1.9094545E-05
     +,   1.9632271E-05,   2.0186708E-05,   2.0758218E-05
     +,   2.1347121E-05,   2.1953851E-05,   2.2578772E-05
     +,   2.3222356E-05,   2.3885108E-05,   2.4567542E-05
     +,   2.5270203E-05,   2.5993762E-05,   2.6738946E-05
     +,   2.7506507E-05,   2.8297407E-05,   2.9112645E-05
     +,   2.9953475E-05,   3.0821280E-05,   3.1717820E-05
     +,   3.2645043E-05,   3.3605458E-05,   3.4601941E-05
     +,   3.5638088E-05,   3.6718247E-05,   3.7847600E-05
     +,   3.9032391E-05,   4.0280243E-05,   4.1600266E-05
     +,   4.3003165E-05,   4.4501830E-05,   4.6111178E-05
     +,   4.7848927E-05,   4.9735314E-05,   5.1793926E-05
     +,   5.4051397E-05,   5.6538182E-05,   5.9288108E-05
     +,   6.2339066E-05,   6.5732806E-05,   6.9514688E-05
     +,   7.3733594E-05,   7.8442099E-05,   8.3695777E-05
     +,   8.9552137E-05,   9.6071235E-05,   1.0331335E-04
     +,   1.1133982E-04,   1.2021009E-04,   1.2998274E-04
     +,   1.4071193E-04,   1.5244875E-04,   1.6523690E-04
     +,   1.7911414E-04,   1.9410967E-04,   2.1024152E-04
     +,   2.2751611E-04,   2.4592801E-04,   2.6545761E-04
     +,   2.8606851E-04,   3.0770808E-04,   3.3030790E-04
     +,   3.5378398E-04,   3.7803387E-04,   4.0294445E-04
     +,   4.2839209E-04,   4.5424697E-04,   4.8037927E-04
     +,   5.0666969E-04,   5.3301547E-04,   5.5933860E-04
     +,   5.8559666E-04,   6.1179191E-04,   6.3797709E-04
     +,   6.6425680E-04,   6.9078774E-04,   7.1777537E-04
     +,   7.4546243E-04,   7.7410851E-04,   8.0397783E-04
     +,   8.3531410E-04,   8.6831616E-04,   9.0312399E-04
     +,   9.3980995E-04,   9.7837695E-04,   1.0187720E-03
     +,   1.0609188E-03,   1.1047684E-03,   1.1503597E-03
     +,   1.1978939E-03,   1.2478149E-03,   1.3008935E-03
     +,   1.3582852E-03,   1.4215558E-03,   1.4926705E-03
     +,   1.5738964E-03,   1.6676243E-03,   1.7760800E-03
     +,   1.9009787E-03,   2.0430894E-03,   2.2018205E-03
     +,   2.3749052E-03,   2.5583224E-03,   2.7464775E-03
     +,   2.9327394E-03,   3.1103152E-03,   3.2733388E-03
     +,   3.4179601E-03,   3.5432342E-03,   3.6517349E-03
     +,   3.7497275E-03,   3.8470598E-03,   3.9569042E-03
     +,   4.0953299E-03,   4.2803353E-03,   4.5296531E-03
     +,   4.8568286E-03,   5.2660620E-03,   5.7478193E-03
     +,   6.2783412E-03,   6.8252767E-03,   7.3582889E-03
     +,   7.8601800E-03,   8.3329789E-03,   8.7972628E-03
     +,   9.2867482E-03,   9.8410184E-03,   1.0493755E-02
     +,   1.1253526E-02,   1.2091713E-02,   1.2969239E-02
     +,   1.3905715E-02,   1.5027177E-02,   1.6530223E-02
     +,   1.8588368E-02,   2.1256654E-02,   2.4415419E-02
     +,   2.7840272E-02,   3.1422485E-02,   3.5235792E-02
     +,   3.9372452E-02,   4.4180546E-02,   5.0184954E-02
     +,   5.8778148E-02,   7.2062075E-02,   8.8782743E-02
     +,   0.1044833    ,   0.1191639    ,   0.1289419    
     +,   0.1128951    ,   6.9744252E-02,   2.7738104E-02
     +,   6.5789637E-03,   8.7849359E-04,   6.3661209E-05
     +,   2.4585693E-06,   5.8853640E-08,   8.8884979E-09
     +,   7.3180009E-09,   6.3860144E-09,   5.5711018E-09
     +,   4.8569544E-09,   4.2315058E-09,   3.6840895E-09
     +,   3.2053167E-09,   2.7868801E-09,   2.4214120E-09
     +,   2.1024222E-09,   1.8242122E-09,   1.5817280E-09
     +,   1.3705230E-09,   1.1867012E-09,   1.0268293E-09
     +,   8.8787949E-10,   7.6719620E-10,   6.6245642E-10
     +,   5.7162081E-10,   4.9289667E-10,   4.2471662E-10
     +,   3.6571188E-10,   3.1468572E-10,   2.7058925E-10
     +,   2.3250772E-10,   1.9964604E-10,   1.7130791E-10
     +,   1.4688759E-10,   1.2585943E-10,   1.0776547E-10
     +,   9.2207006E-11,   7.8837999E-11,   6.7359000E-11
     +,   5.7510215E-11,   4.9065984E-11,   4.1831049E-11
     +,   3.5637129E-11,   3.0337927E-11,   2.5807868E-11
     +,   2.1937877E-11,   1.8634464E-11,   1.5816595E-11
     +,   1.3414813E-11,   1.1369104E-11,   9.6280935E-12
     +,   8.1474272E-12,   6.8892175E-12,   5.8208095E-12
     +,   4.9142517E-12,   4.1456691E-12,   3.4945280E-12
     +,   2.9433461E-12,   2.4771138E-12,   2.0830820E-12
     +,   1.7503118E-12,   1.4695210E-12,   1.2327657E-12
     +,   1.0333142E-12,   8.6541543E-13,   7.2420390E-13
     +,   6.0552811E-13,   5.0587952E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt1168 = Yx/0.3154375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.2870387E-06,   3.4487725E-06
     +,   3.6168576E-06,   3.7915015E-06,   3.9729184E-06
     +,   4.1613289E-06,   4.3569594E-06,   4.5600445E-06
     +,   4.7708199E-06,   4.9895361E-06,   5.2164401E-06
     +,   5.4517836E-06,   5.6958224E-06,   5.9488143E-06
     +,   6.2110144E-06,   6.4826791E-06,   6.7640599E-06
     +,   7.0554042E-06,   7.3569486E-06,   7.6689248E-06
     +,   7.9915471E-06,   8.3250179E-06,   8.6695136E-06
     +,   9.0252142E-06,   9.3922326E-06,   9.7706961E-06
     +,   1.0160678E-05,   1.0562221E-05,   1.0975333E-05
     +,   1.1399975E-05,   1.1836065E-05,   1.2283475E-05
     +,   1.2742024E-05,   1.3211473E-05,   1.3691530E-05
     +,   1.4181838E-05,   1.4681983E-05,   1.5191474E-05
     +,   1.5709791E-05,   1.6236281E-05,   1.6770293E-05
     +,   1.7311069E-05,   1.7857794E-05,   1.8409590E-05
     +,   1.8965513E-05,   1.9524558E-05,   2.0085672E-05
     +,   2.0647743E-05,   2.1209609E-05,   2.1770076E-05
     +,   2.2327911E-05,   2.2881861E-05,   2.3430634E-05
     +,   2.3972978E-05,   2.4507572E-05,   2.5033176E-05
     +,   2.5548539E-05,   2.6052452E-05,   2.6543757E-05
     +,   2.7021362E-05,   2.7484244E-05,   2.7931494E-05
     +,   2.8362261E-05,   2.8775876E-05,   2.9171784E-05
     +,   2.9549563E-05,   2.9908995E-05,   3.0250010E-05
     +,   3.0572777E-05,   3.0877636E-05,   3.1165211E-05
     +,   3.1436317E-05,   3.1692067E-05,   3.1933821E-05
     +,   3.2163240E-05,   3.2382275E-05,   3.2593180E-05
     +,   3.2798507E-05,   3.3001164E-05,   3.3204353E-05
     +,   3.3411623E-05,   3.3626835E-05,   3.3854190E-05
     +,   3.4098219E-05,   3.4363729E-05,   3.4655888E-05
     +,   3.4980094E-05,   3.5342066E-05,   3.5747726E-05
     +,   3.6203248E-05,   3.6714991E-05,   3.7289436E-05
     +,   3.7933180E-05,   3.8652899E-05,   3.9455292E-05
     +,   4.0346938E-05,   4.1334388E-05,   4.2423937E-05
     +,   4.3621731E-05,   4.4933440E-05,   4.6364530E-05
     +,   4.7919792E-05,   4.9603648E-05,   5.1419698E-05
     +,   5.3370994E-05,   5.5459805E-05,   5.7687525E-05
     +,   6.0054539E-05,   6.2560575E-05,   6.5204360E-05
     +,   6.7983528E-05,   7.0895119E-05,   7.3934963E-05
     +,   7.7098623E-05,   8.0380574E-05,   8.3775405E-05
     +,   8.7277025E-05,   9.0879970E-05,   9.4578871E-05
     +,   9.8369565E-05,   1.0224943E-04,   1.0621759E-04
     +,   1.1027594E-04,   1.1443013E-04,   1.1869007E-04
     +,   1.2307055E-04,   1.2759304E-04,   1.3228566E-04
     +,   1.3718517E-04,   1.4233675E-04,   1.4779615E-04
     +,   1.5362888E-04,   1.5991194E-04,   1.6673242E-04
     +,   1.7418851E-04,   1.8238770E-04,   1.9144482E-04
     +,   2.0147994E-04,   2.1261603E-04,   2.2497469E-04
     +,   2.3867057E-04,   2.5380717E-04,   2.7047293E-04
     +,   2.8873439E-04,   3.0863099E-04,   3.3017434E-04
     +,   3.5334547E-04,   3.7809333E-04,   4.0434083E-04
     +,   4.3199386E-04,   4.6095162E-04,   4.9111963E-04
     +,   5.2243238E-04,   5.5487675E-04,   5.8851473E-04
     +,   6.2350283E-04,   6.6011195E-04,   6.9873926E-04
     +,   7.3990267E-04,   7.8421424E-04,   8.3234633E-04
     +,   8.8496343E-04,   9.4263291E-04,   1.0057269E-03
     +,   1.0743187E-03,   1.1480883E-03,   1.2262465E-03
     +,   1.3075246E-03,   1.3902254E-03,   1.4723489E-03
     +,   1.5517909E-03,   1.6266301E-03,   1.6954518E-03
     +,   1.7576725E-03,   1.8138193E-03,   1.8657303E-03
     +,   1.9165878E-03,   1.9707500E-03,   2.0333647E-03
     +,   2.1097646E-03,   2.2046901E-03,   2.3214382E-03
     +,   2.4611279E-03,   2.6222498E-03,   2.8006586E-03
     +,   2.9901047E-03,   3.1833372E-03,   3.3736061E-03
     +,   3.5562559E-03,   3.7300654E-03,   3.8980078E-03
     +,   4.0670526E-03,   4.2470596E-03,   4.4492339E-03
     +,   4.6850285E-03,   4.9663316E-03,   5.3072404E-03
     +,   5.7261316E-03,   6.2453500E-03,   6.8852399E-03
     +,   7.6521421E-03,   8.5247513E-03,   9.4485106E-03
     +,   1.0347149E-02,   1.1152004E-02,   1.1836005E-02
     +,   1.2431378E-02,   1.3019506E-02,   1.3698106E-02
     +,   1.4541592E-02,   1.5574259E-02,   1.6779548E-02
     +,   1.8149784E-02,   1.9728608E-02,   2.1567550E-02
     +,   2.3600539E-02,   2.5595590E-02,   2.7339013E-02
     +,   2.9028691E-02,   3.1431593E-02,   3.5238784E-02
     +,   4.0601753E-02,   4.7472712E-02,   5.4925356E-02
     +,   6.1795045E-02,   6.9067389E-02,   7.6833285E-02
     +,   8.4625505E-02,   9.1317192E-02,   9.0227425E-02
     +,   7.4379161E-02,   4.7230929E-02,   2.1809071E-02
     +,   7.0222407E-03,   1.5291455E-03,   2.2449769E-04
     +,   2.7942571E-05,   9.3912986E-06,   8.3504601E-06
     +,   8.3581899E-06,   8.3960640E-06,   8.4257335E-06
     +,   8.4462199E-06,   8.4574431E-06,   8.4593639E-06
     +,   8.4519706E-06,   8.4352887E-06,   8.4093681E-06
     +,   8.3742943E-06,   8.3301802E-06,   8.2771721E-06
     +,   8.2154356E-06,   8.1451753E-06,   8.0666177E-06
     +,   7.9800147E-06,   7.8856365E-06,   7.7837849E-06
     +,   7.6747829E-06,   7.5589651E-06,   7.4366840E-06
     +,   7.3083147E-06,   7.1742465E-06,   7.0348733E-06
     +,   6.8905979E-06,   6.7418437E-06,   6.5890285E-06
     +,   6.4325714E-06,   6.2729041E-06,   6.1104606E-06
     +,   5.9456606E-06,   5.7789189E-06,   5.6106619E-06
     +,   5.4413003E-06,   5.2712335E-06,   5.1008446E-06
     +,   4.9305258E-06,   4.7606336E-06,   4.5915313E-06
     +,   4.4235480E-06,   4.2570155E-06,   4.0922291E-06
     +,   3.9294887E-06,   3.7690543E-06,   3.6111883E-06
     +,   3.4561142E-06,   3.3040565E-06,   3.1552056E-06
     +,   3.0097331E-06,   2.8678064E-06,   2.7295546E-06
     +,   2.5951069E-06,   2.4645565E-06,   2.3379964E-06
     +,   2.2154859E-06,   2.0970833E-06,   1.9828158E-06
     +,   1.8727110E-06,   1.7667662E-06,   1.6649799E-06
     +,   1.5673244E-06,   1.4737727E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt118 = Yx/0.29668085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5159619E-07,   8.0881807E-07
     +,   8.6966486E-07,   9.3430435E-07,   1.0029066E-06
     +,   1.0756454E-06,   1.1526948E-06,   1.2342324E-06
     +,   1.3204337E-06,   1.4114811E-06,   1.5075515E-06
     +,   1.6088237E-06,   1.7154748E-06,   1.8276808E-06
     +,   1.9456154E-06,   2.0694492E-06,   2.1993485E-06
     +,   2.3354762E-06,   2.4779888E-06,   2.6270372E-06
     +,   2.7827659E-06,   2.9453108E-06,   3.1147965E-06
     +,   3.2913483E-06,   3.4750633E-06,   3.6660463E-06
     +,   3.8643761E-06,   4.0701261E-06,   4.2833503E-06
     +,   4.5040906E-06,   4.7323729E-06,   4.9682048E-06
     +,   5.2115788E-06,   5.4624670E-06,   5.7208240E-06
     +,   5.9865847E-06,   6.2596619E-06,   6.5399454E-06
     +,   6.8273202E-06,   7.1216186E-06,   7.4226846E-06
     +,   7.7303175E-06,   8.0443069E-06,   8.3644118E-06
     +,   8.6903765E-06,   9.0219219E-06,   9.3587505E-06
     +,   9.7005432E-06,   1.0046964E-05,   1.0397665E-05
     +,   1.0752279E-05,   1.1110430E-05,   1.1471730E-05
     +,   1.1835799E-05,   1.2202226E-05,   1.2570634E-05
     +,   1.2940642E-05,   1.3311875E-05,   1.3683987E-05
     +,   1.4056654E-05,   1.4429594E-05,   1.4802565E-05
     +,   1.5175365E-05,   1.5547877E-05,   1.5920077E-05
     +,   1.6291979E-05,   1.6663764E-05,   1.7035665E-05
     +,   1.7408112E-05,   1.7781647E-05,   1.8157018E-05
     +,   1.8535102E-05,   1.8917062E-05,   1.9304203E-05
     +,   1.9698145E-05,   2.0100741E-05,   2.0514117E-05
     +,   2.0940690E-05,   2.1383230E-05,   2.1844808E-05
     +,   2.2328824E-05,   2.2839067E-05,   2.3379635E-05
     +,   2.3955041E-05,   2.4570118E-05,   2.5230118E-05
     +,   2.5940595E-05,   2.6707547E-05,   2.7537229E-05
     +,   2.8436327E-05,   2.9411865E-05,   3.0471161E-05
     +,   3.1621817E-05,   3.2871878E-05,   3.4229670E-05
     +,   3.5703728E-05,   3.7303085E-05,   3.9036902E-05
     +,   4.0914852E-05,   4.2946729E-05,   4.5142915E-05
     +,   4.7513771E-05,   5.0070317E-05,   5.2823470E-05
     +,   5.5784600E-05,   5.8965248E-05,   6.2376734E-05
     +,   6.6030167E-05,   6.9936592E-05,   7.4106421E-05
     +,   7.8548757E-05,   8.3271967E-05,   8.8282170E-05
     +,   9.3583920E-05,   9.9178455E-05,   1.0506460E-04
     +,   1.1123662E-04,   1.1768541E-04,   1.2439623E-04
     +,   1.3134991E-04,   1.3852165E-04,   1.4588049E-04
     +,   1.5338967E-04,   1.6100710E-04,   1.6868528E-04
     +,   1.7637089E-04,   1.8400738E-04,   1.9153403E-04
     +,   1.9888868E-04,   2.0600767E-04,   2.1282909E-04
     +,   2.1929275E-04,   2.2534409E-04,   2.3093467E-04
     +,   2.3602572E-04,   2.4059028E-04,   2.4461542E-04
     +,   2.4810582E-04,   2.5108663E-04,   2.5360665E-04
     +,   2.5574167E-04,   2.5759792E-04,   2.5931589E-04
     +,   2.6107329E-04,   2.6308763E-04,   2.6561838E-04
     +,   2.6896721E-04,   2.7347685E-04,   2.7952658E-04
     +,   2.8752652E-04,   2.9790690E-04,   3.1110313E-04
     +,   3.2753870E-04,   3.4760468E-04,   3.7163607E-04
     +,   3.9988404E-04,   4.3249363E-04,   4.6948294E-04
     +,   5.1072642E-04,   5.5594003E-04,   6.0469355E-04
     +,   6.5641984E-04,   7.1044313E-04,   7.6603104E-04
     +,   8.2246680E-04,   8.7913690E-04,   9.3564263E-04
     +,   9.9193980E-04,   1.0484901E-03,   1.1064068E-03
     +,   1.1675621E-03,   1.2346298E-03,   1.3109936E-03
     +,   1.4004740E-03,   1.5068323E-03,   1.6331199E-03
     +,   1.7809025E-03,   1.9495416E-03,   2.1357816E-03
     +,   2.3338494E-03,   2.5361858E-03,   2.7348467E-03
     +,   2.9233892E-03,   3.0988439E-03,   3.2631790E-03
     +,   3.4237625E-03,   3.5924218E-03,   3.7830570E-03
     +,   4.0082433E-03,   4.2757667E-03,   4.5864312E-03
     +,   4.9341177E-03,   5.3083599E-03,   5.6987246E-03
     +,   6.0992292E-03,   6.5112626E-03,   6.9444445E-03
     +,   7.4152891E-03,   7.9421056E-03,   8.5342936E-03
     +,   9.1783348E-03,   9.8308995E-03,   1.0431342E-02
     +,   1.0932941E-02,   1.1331659E-02,   1.1669562E-02
     +,   1.2017570E-02,   1.2463050E-02,   1.3099444E-02
     +,   1.3993291E-02,   1.5171066E-02,   1.6698688E-02
     +,   1.8734302E-02,   2.1328483E-02,   2.4155270E-02
     +,   2.6657365E-02,   2.8531162E-02,   2.9985741E-02
     +,   3.1578440E-02,   3.3713575E-02,   3.6022983E-02
     +,   3.7738752E-02,   3.9314322E-02,   4.2399999E-02
     +,   4.7697853E-02,   5.4237034E-02,   6.1153255E-02
     +,   6.8813287E-02,   7.4865997E-02,   7.1927726E-02
     +,   5.6444835E-02,   3.4844253E-02,   1.6485646E-02
     +,   5.8128629E-03,   1.5284702E-03,   3.4792832E-04
     +,   1.1069570E-04,   5.6900713E-05,   3.0684143E-05
     +,   1.4334984E-05,   5.6271701E-06,   1.8506695E-06
     +,   5.1051273E-07,   1.1884146E-07,   2.4079544E-08
     +,   4.9567959E-09,   1.6431123E-09,   1.0644298E-09
     +,   8.8892155E-10,   7.7383649E-10,   6.7636963E-10
     +,   5.9092370E-10,   5.1583060E-10,   4.4988097E-10
     +,   3.9201173E-10,   3.4127898E-10,   2.9684544E-10
     +,   2.5796629E-10,   2.2397777E-10,   1.9429143E-10
     +,   1.6838814E-10,   1.4580752E-10,   1.2614106E-10
     +,   1.0902847E-10,   9.4152720E-11,   8.1233263E-11
     +,   7.0022897E-11,   6.0305094E-11,   5.1889298E-11
     +,   4.4607585E-11,   3.8312863E-11,   3.2876674E-11
     +,   2.8186429E-11,   2.4143456E-11,   2.0661556E-11
     +,   1.7665905E-11,   1.5090819E-11,   1.2879492E-11
     +,   1.0982174E-11,   9.3559327E-12,   7.9632386E-12
     +,   6.7717442E-12,   5.7532811E-12,   4.8835801E-12
     +,   4.1415708E-12,   3.5091374E-12,   2.9705782E-12
     +,   2.5123757E-12,   2.1229342E-12,   1.7922240E-12
     +,   1.5116618E-12,   1.2738578E-12,   1.0724939E-12
     +,   9.0213465E-13,   7.5815005E-13,   6.3656410E-13
     +,   5.3399407E-13,   4.4754131E-13,   3.7474676E-13
     +,   3.1350470E-13,   2.6203432E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt119 = Yx/0.267787234042553
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9591341E-06,   2.0688087E-06
     +,   2.1831574E-06,   2.3022947E-06,   2.4263320E-06
     +,   2.5553816E-06,   2.6895548E-06,   2.8289639E-06
     +,   2.9737159E-06,   3.1239272E-06,   3.2797079E-06
     +,   3.4411696E-06,   3.6084261E-06,   3.7815937E-06
     +,   3.9607912E-06,   4.1461399E-06,   4.3377681E-06
     +,   4.5358065E-06,   4.7403937E-06,   4.9516766E-06
     +,   5.1698089E-06,   5.3949584E-06,   5.6272970E-06
     +,   5.8670294E-06,   6.1143464E-06,   6.3694820E-06
     +,   6.6326770E-06,   6.9041953E-06,   7.1843247E-06
     +,   7.4733766E-06,   7.7716923E-06,   8.0796408E-06
     +,   8.3976247E-06,   8.7260796E-06,   9.0654712E-06
     +,   9.4163142E-06,   9.7791517E-06,   1.0154565E-05
     +,   1.0543202E-05,   1.0945708E-05,   1.1362816E-05
     +,   1.1795279E-05,   1.2243896E-05,   1.2709505E-05
     +,   1.3192987E-05,   1.3695263E-05,   1.4217284E-05
     +,   1.4760032E-05,   1.5324520E-05,   1.5911777E-05
     +,   1.6522852E-05,   1.7158798E-05,   1.7820652E-05
     +,   1.8509498E-05,   1.9226318E-05,   1.9972136E-05
     +,   2.0747906E-05,   2.1554519E-05,   2.2392824E-05
     +,   2.3263563E-05,   2.4167426E-05,   2.5104970E-05
     +,   2.6076592E-05,   2.7082639E-05,   2.8123301E-05
     +,   2.9198512E-05,   3.0308185E-05,   3.1451887E-05
     +,   3.2629163E-05,   3.3839206E-05,   3.5081168E-05
     +,   3.6353838E-05,   3.7655973E-05,   3.8985967E-05
     +,   4.0342162E-05,   4.1722713E-05,   4.3125576E-05
     +,   4.4548538E-05,   4.5989400E-05,   4.7445908E-05
     +,   4.8915648E-05,   5.0396433E-05,   5.1885963E-05
     +,   5.3382337E-05,   5.4883632E-05,   5.6388533E-05
     +,   5.7895846E-05,   5.9405149E-05,   6.0916460E-05
     +,   6.2430649E-05,   6.3949534E-05,   6.5475724E-05
     +,   6.7013047E-05,   6.8566689E-05,   7.0143178E-05
     +,   7.1750437E-05,   7.3398231E-05,   7.5097836E-05
     +,   7.6862474E-05,   7.8707017E-05,   8.0648388E-05
     +,   8.2705068E-05,   8.4897438E-05,   8.7247208E-05
     +,   8.9777619E-05,   9.2512964E-05,   9.5478157E-05
     +,   9.8698343E-05,   1.0219870E-04,   1.0600375E-04
     +,   1.1013633E-04,   1.1461790E-04,   1.1946673E-04
     +,   1.2469853E-04,   1.3032436E-04,   1.3635169E-04
     +,   1.4278205E-04,   1.4961245E-04,   1.5683316E-04
     +,   1.6442922E-04,   1.7237973E-04,   1.8065755E-04
     +,   1.8922993E-04,   1.9805990E-04,   2.0710636E-04
     +,   2.1632425E-04,   2.2566765E-04,   2.3508846E-04
     +,   2.4454069E-04,   2.5397912E-04,   2.6336338E-04
     +,   2.7265688E-04,   2.8183093E-04,   2.9086348E-04
     +,   2.9974242E-04,   3.0846542E-04,   3.1704069E-04
     +,   3.2548717E-04,   3.3383598E-04,   3.4212865E-04
     +,   3.5041710E-04,   3.5876216E-04,   3.6723330E-04
     +,   3.7590676E-04,   3.8486265E-04,   3.9418513E-04
     +,   4.0396018E-04,   4.1427405E-04,   4.2521293E-04
     +,   4.3686497E-04,   4.4932036E-04,   4.6267442E-04
     +,   4.7703180E-04,   4.9251318E-04,   5.0926150E-04
     +,   5.2744750E-04,   5.4727861E-04,   5.6900777E-04
     +,   5.9293903E-04,   6.1942916E-04,   6.4889691E-04
     +,   6.8182230E-04,   7.1874773E-04,   7.6028035E-04
     +,   8.0709654E-04,   8.5994811E-04,   9.1965840E-04
     +,   9.8712684E-04,   1.0633152E-03,   1.1492131E-03
     +,   1.2457620E-03,   1.3537578E-03,   1.4737203E-03
     +,   1.6057473E-03,   1.7493749E-03,   1.9035458E-03
     +,   2.0666472E-03,   2.2366592E-03,   2.4114253E-03
     +,   2.5889571E-03,   2.7676271E-03,   2.9462108E-03
     +,   3.1237358E-03,   3.2991895E-03,   3.4712143E-03
     +,   3.6380305E-03,   3.7978019E-03,   3.9494019E-03
     +,   4.0934058E-03,   4.2328397E-03,   4.3733618E-03
     +,   4.5224894E-03,   4.6880594E-03,   4.8766104E-03
     +,   5.0924858E-03,   5.3383950E-03,   5.6176963E-03
     +,   5.9375986E-03,   6.3113612E-03,   6.7569693E-03
     +,   7.2910851E-03,   7.9207467E-03,   8.6388439E-03
     +,   9.4296969E-03,   1.0283901E-02,   1.1210265E-02
     +,   1.2224625E-02,   1.3311791E-02,   1.4396347E-02
     +,   1.5380542E-02,   1.6254073E-02,   1.7183553E-02
     +,   1.8465143E-02,   2.0327605E-02,   2.2722654E-02
     +,   2.5299210E-02,   2.7617410E-02,   2.9411199E-02
     +,   3.0673208E-02,   3.1678282E-02,   3.3070523E-02
     +,   3.5535961E-02,   3.9113421E-02,   4.3090403E-02
     +,   4.6848305E-02,   5.0615668E-02,   5.4828778E-02
     +,   5.8610953E-02,   5.9178974E-02,   5.3853445E-02
     +,   4.2648382E-02,   2.8505258E-02,   1.5573181E-02
     +,   6.7427158E-03,   2.2568633E-03,   5.7876040E-04
     +,   1.2052171E-04,   2.9748680E-05,   1.6865803E-05
     +,   1.5684593E-05,   1.5718228E-05,   1.5793583E-05
     +,   1.5816371E-05,   1.5781019E-05,   1.5687667E-05
     +,   1.5537345E-05,   1.5331712E-05,   1.5072998E-05
     +,   1.4763988E-05,   1.4407982E-05,   1.4008702E-05
     +,   1.3570235E-05,   1.3097001E-05,   1.2593662E-05
     +,   1.2065001E-05,   1.1515885E-05,   1.0951210E-05
     +,   1.0375833E-05,   9.7944239E-06,   9.2114751E-06
     +,   8.6312630E-06,   8.0577847E-06,   7.4946647E-06
     +,   6.9451667E-06,   6.4122351E-06,   5.8983610E-06
     +,   5.4056400E-06,   4.9358041E-06,   4.4901944E-06
     +,   4.0697478E-06,   3.6750532E-06,   3.3063952E-06
     +,   2.9637561E-06,   2.6468258E-06,   2.3550585E-06
     +,   2.0877326E-06,   1.8439169E-06,   1.6225750E-06
     +,   1.4225295E-06,   1.2425530E-06,   1.0813387E-06
     +,   9.3757404E-07,   8.0992083E-07,   6.9707039E-07
     +,   5.9772816E-07,   5.1065552E-07,   4.3465784E-07
     +,   3.6860385E-07,   3.1143654E-07,   2.6216335E-07
     +,   2.1987300E-07,   1.8372339E-07,   1.5295186E-07
     +,   1.2686371E-07,   1.0483779E-07,   8.6315879E-08
     +,   7.0804603E-08,   5.7866107E-08,   4.7117847E-08
     +,   3.8224190E-08,   3.0895102E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt120 = Yx/0.246521739130435
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7615970E-05,   2.8715722E-05
     +,   2.9836094E-05,   3.0976003E-05,   3.2134314E-05
     +,   3.3309898E-05,   3.4501601E-05,   3.5708235E-05
     +,   3.6928650E-05,   3.8161779E-05,   3.9406554E-05
     +,   4.0661991E-05,   4.1927226E-05,   4.3201486E-05
     +,   4.4484168E-05,   4.5774861E-05,   4.7073321E-05
     +,   4.8379541E-05,   4.9693805E-05,   5.1016679E-05
     +,   5.2349038E-05,   5.3692140E-05,   5.5047614E-05
     +,   5.6417608E-05,   5.7804642E-05,   5.9211805E-05
     +,   6.0642764E-05,   6.2101732E-05,   6.3593579E-05
     +,   6.5123859E-05,   6.6698871E-05,   6.8325586E-05
     +,   7.0011920E-05,   7.1766459E-05,   7.3598749E-05
     +,   7.5519223E-05,   7.7539175E-05,   7.9670848E-05
     +,   8.1927479E-05,   8.4323037E-05,   8.6872635E-05
     +,   8.9592097E-05,   9.2498150E-05,   9.5608302E-05
     +,   9.8940684E-05,   1.0251412E-04,   1.0634793E-04
     +,   1.1046179E-04,   1.1487560E-04,   1.1960934E-04
     +,   1.2468293E-04,   1.3011586E-04,   1.3592720E-04
     +,   1.4213551E-04,   1.4875778E-04,   1.5581051E-04
     +,   1.6330840E-04,   1.7126431E-04,   1.7968948E-04
     +,   1.8859282E-04,   1.9798073E-04,   2.0785721E-04
     +,   2.1822267E-04,   2.2907525E-04,   2.4040992E-04
     +,   2.5221720E-04,   2.6448554E-04,   2.7719827E-04
     +,   2.9033699E-04,   3.0387801E-04,   3.1779610E-04
     +,   3.3206146E-04,   3.4664330E-04,   3.6150683E-04
     +,   3.7661722E-04,   3.9193858E-04,   4.0743474E-04
     +,   4.2306972E-04,   4.3881161E-04,   4.5463102E-04
     +,   4.7050224E-04,   4.8640763E-04,   5.0233502E-04
     +,   5.1828410E-04,   5.3426309E-04,   5.5029662E-04
     +,   5.6642242E-04,   5.8269943E-04,   5.9920741E-04
     +,   6.1605457E-04,   6.3338102E-04,   6.5136584E-04
     +,   6.7023427E-04,   6.9026987E-04,   7.1182463E-04
     +,   7.3532882E-04,   7.6131371E-04,   7.9041935E-04
     +,   8.2342117E-04,   8.6123537E-04,   9.0494059E-04
     +,   9.5576886E-04,   1.0151058E-03,   1.0844532E-03
     +,   1.1653940E-03,   1.2595346E-03,   1.3684301E-03
     +,   1.4935338E-03,   1.6361625E-03,   1.7974873E-03
     +,   1.9785443E-03,   2.1803661E-03,   2.4040972E-03
     +,   2.6513033E-03,   2.9242767E-03,   3.2265775E-03
     +,   3.5634588E-03,   3.9423858E-03,   4.3731402E-03
     +,   4.8677893E-03,   5.4401825E-03,   6.1049708E-03
     +,   6.8758293E-03,   7.7618668E-03,   8.7610204E-03
     +,   9.8511614E-03,   1.0983543E-02,   1.2086138E-02
     +,   1.3086197E-02,   1.3950676E-02,   1.4729375E-02
     +,   1.5568723E-02,   1.6669193E-02,   1.8188523E-02
     +,   2.0140700E-02,   2.2366988E-02,   2.4623632E-02
     +,   2.6732547E-02,   2.8661888E-02,   3.0465085E-02
     +,   3.2170918E-02,   3.3772808E-02,   3.5344623E-02
     +,   3.7155155E-02,   3.9607711E-02,   4.2993233E-02
     +,   4.7149565E-02,   5.1147483E-02,   5.3629551E-02
     +,   5.4084238E-02,   5.3610247E-02,   5.3896185E-02
     +,   5.5426147E-02,   5.7023764E-02,   5.7259120E-02
     +,   5.5598125E-02,   5.2326690E-02,   4.8318371E-02
     +,   4.4435855E-02,   4.0784393E-02,   3.6985192E-02
     +,   3.2957241E-02,   2.9078519E-02,   2.5760997E-02
     +,   2.3104759E-02,   2.0947449E-02,   1.9083088E-02
     +,   1.7373856E-02,   1.5745606E-02,   1.4170006E-02
     +,   1.2661899E-02,   1.1270317E-02,   1.0054532E-02
     +,   9.0579754E-03,   8.2928790E-03,   7.7396194E-03
     +,   7.3572611E-03,   7.0973639E-03,   6.9149612E-03
     +,   6.7738011E-03,   6.6469074E-03,   6.5147933E-03
     +,   6.3635213E-03,   6.1836946E-03,   5.9702303E-03
     +,   5.7224287E-03,   5.4437299E-03,   5.1409081E-03
     +,   4.8229657E-03,   4.4998336E-03,   4.1811182E-03
     +,   3.8752276E-03,   3.5888737E-03,   3.3268814E-03
     +,   3.0922187E-03,   2.8862236E-03,   2.7088795E-03
     +,   2.5590297E-03,   2.4346155E-03,   2.3329027E-03
     +,   2.2506770E-03,   2.1844241E-03,   2.1304986E-03
     +,   2.0853013E-03,   2.0454302E-03,   2.0078071E-03
     +,   1.9697868E-03,   1.9292376E-03,   1.8845854E-03
     +,   1.8348085E-03,   1.7794224E-03,   1.7184246E-03
     +,   1.6522143E-03,   1.5814926E-03,   1.5071706E-03
     +,   1.4302777E-03,   1.3518734E-03,   1.2729713E-03
     +,   1.1944905E-03,   1.1172327E-03,   1.0418462E-03
     +,   9.6883450E-04,   8.9856790E-04,   8.3129579E-04
     +,   7.6716364E-04,   7.0623745E-04,   6.4853043E-04
     +,   5.9401605E-04,   5.4263946E-04,   4.9433205E-04
     +,   4.4902266E-04,   4.0663744E-04,   3.6709954E-04
     +,   3.3033185E-04,   2.9625944E-04,   2.6480094E-04
     +,   2.3586951E-04,   2.0937428E-04,   1.8521625E-04
     +,   1.6328710E-04,   1.4347103E-04,   1.2564700E-04
     +,   1.0968835E-04,   9.5463591E-05,   8.2839790E-05
     +,   7.1685085E-05,   6.1869352E-05,   5.3265700E-05
     +,   4.5752433E-05,   3.9215083E-05,   3.3545602E-05
     +,   2.8643935E-05,   2.4418468E-05,   2.0785741E-05
     +,   1.7670152E-05,   1.5003966E-05,   1.2727046E-05
     +,   1.0786142E-05,   9.1342790E-06,   7.7303639E-06
     +,   6.5386780E-06,   5.5282230E-06,   4.6721466E-06
     +,   3.9473471E-06,   3.3340602E-06,   2.8153183E-06
     +,   2.3766486E-06,   2.0057619E-06,   1.6922166E-06
     +,   1.4271398E-06,   1.2030254E-06,   1.0135426E-06
     +,   8.5334301E-07,   7.1790032E-07,   6.0339818E-07
     +,   5.0662590E-07,   4.2486064E-07,   3.5581351E-07
     +,   2.9754034E-07,   2.4840384E-07,   2.0701027E-07
     +,   1.7218375E-07,   1.4292085E-07,   1.1837309E-07
     +,   9.7815381E-08,   8.0633505E-08,   6.6302547E-08
     +,   5.4376020E-08,   4.4474863E-08,   3.6275367E-08
     +,   2.9503470E-08,   2.3925697E-08,   1.9344910E-08
     +,   1.5593759E-08,   1.2531473E-08,   1.0039150E-08
     +,   8.0172491E-09,   6.3821530E-09,   5.0642632E-09
     +,   4.0054835E-09,   3.1577694E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt75 = Yx/0.4165
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0321526E-05,   1.0749223E-05
     +,   1.1189915E-05,   1.1643646E-05,   1.2110434E-05
     +,   1.2590279E-05,   1.3083139E-05,   1.3588959E-05
     +,   1.4107641E-05,   1.4639089E-05,   1.5183154E-05
     +,   1.5739657E-05,   1.6308413E-05,   1.6889197E-05
     +,   1.7481761E-05,   1.8085853E-05,   1.8701172E-05
     +,   1.9327419E-05,   1.9964280E-05,   2.0611418E-05
     +,   2.1268501E-05,   2.1935182E-05,   2.2611101E-05
     +,   2.3295963E-05,   2.3989383E-05,   2.4691095E-05
     +,   2.5400786E-05,   2.6118199E-05,   2.6843118E-05
     +,   2.7575352E-05,   2.8314795E-05,   2.9061381E-05
     +,   2.9815150E-05,   3.0576211E-05,   3.1344796E-05
     +,   3.2121254E-05,   3.2906075E-05,   3.3699904E-05
     +,   3.4503610E-05,   3.5318189E-05,   3.6144964E-05
     +,   3.6985475E-05,   3.7841532E-05,   3.8715287E-05
     +,   3.9609302E-05,   4.0526458E-05,   4.1470106E-05
     +,   4.2444077E-05,   4.3452696E-05,   4.4500848E-05
     +,   4.5594028E-05,   4.6738314E-05,   4.7940448E-05
     +,   4.9207971E-05,   5.0548977E-05,   5.1972474E-05
     +,   5.3488144E-05,   5.5106491E-05,   5.6838842E-05
     +,   5.8697315E-05,   6.0694896E-05,   6.2845400E-05
     +,   6.5163404E-05,   6.7664507E-05,   7.0365240E-05
     +,   7.3282841E-05,   7.6435870E-05,   7.9843681E-05
     +,   8.3527164E-05,   8.7508226E-05,   9.1810703E-05
     +,   9.6459778E-05,   1.0148327E-04,   1.0691075E-04
     +,   1.1277504E-04,   1.1911222E-04,   1.2596171E-04
     +,   1.3336701E-04,   1.4137670E-04,   1.5004474E-04
     +,   1.5942985E-04,   1.6959796E-04,   1.8062031E-04
     +,   1.9257584E-04,   2.0554881E-04,   2.1963099E-04
     +,   2.3491829E-04,   2.5151303E-04,   2.6951867E-04
     +,   2.8904193E-04,   3.1018912E-04,   3.3306159E-04
     +,   3.5775499E-04,   3.8435782E-04,   4.1294718E-04
     +,   4.4358303E-04,   4.7631413E-04,   5.1116827E-04
     +,   5.4816040E-04,   5.8728614E-04,   6.2853243E-04
     +,   6.7187339E-04,   7.1728474E-04,   7.6473953E-04
     +,   8.1422745E-04,   8.6575752E-04,   9.1936486E-04
     +,   9.7512448E-04,   1.0331654E-03,   1.0936792E-03
     +,   1.1569237E-03,   1.2232477E-03,   1.2930725E-03
     +,   1.3669096E-03,   1.4453151E-03,   1.5288736E-03
     +,   1.6181159E-03,   1.7134666E-03,   1.8151494E-03
     +,   1.9231560E-03,   2.0372521E-03,   2.1570695E-03
     +,   2.2823515E-03,   2.4133055E-03,   2.5510269E-03
     +,   2.6979554E-03,   2.8582623E-03,   3.0380266E-03
     +,   3.2452738E-03,   3.4896797E-03,   3.7823259E-03
     +,   4.1355658E-03,   4.5640911E-03,   5.0875861E-03
     +,   5.7352390E-03,   6.5492080E-03,   7.5826622E-03
     +,   8.8903522E-03,   1.0516004E-02,   1.2481485E-02
     +,   1.4770105E-02,   1.7293701E-02,   1.9879891E-02
     +,   2.2359740E-02,   2.4735441E-02,   2.7218608E-02
     +,   3.0034613E-02,   3.3261094E-02,   3.6893420E-02
     +,   4.0887978E-02,   4.5028504E-02,   4.8885290E-02
     +,   5.2170470E-02,   5.5310786E-02,   5.9046745E-02
     +,   6.2641367E-02,   6.4654559E-02,   6.6377826E-02
     +,   6.9527186E-02,   7.2245285E-02,   7.2440125E-02
     +,   7.0491329E-02,   6.6807777E-02,   6.1546814E-02
     +,   5.5481832E-02,   4.9214855E-02,   4.3342296E-02
     +,   3.8506906E-02,   3.4650557E-02,   3.1197440E-02
     +,   2.7851325E-02,   2.4692314E-02,   2.1860680E-02
     +,   1.9439794E-02,   1.7460253E-02,   1.5880639E-02
     +,   1.4596345E-02,   1.3500804E-02,   1.2537556E-02
     +,   1.1699512E-02,   1.0993587E-02,   1.0408678E-02
     +,   9.9070473E-03,   9.4367703E-03,   8.9514256E-03
     +,   8.4253754E-03,   7.8585623E-03,   7.2716190E-03
     +,   6.6957292E-03,   6.1622644E-03,   5.6951870E-03
     +,   5.3075552E-03,   5.0012828E-03,   4.7690016E-03
     +,   4.5970776E-03,   4.4689849E-03,   4.3682219E-03
     +,   4.2804172E-03,   4.1944124E-03,   4.1024876E-03
     +,   4.0000025E-03,   3.8847434E-03,   3.7562926E-03
     +,   3.6154862E-03,   3.4640380E-03,   3.3042196E-03
     +,   3.1386346E-03,   2.9700114E-03,   2.8009885E-03
     +,   2.6339188E-03,   2.4707415E-03,   2.3129168E-03
     +,   2.1613904E-03,   2.0166272E-03,   1.8787005E-03
     +,   1.7474070E-03,   1.6223630E-03,   1.5030982E-03
     +,   1.3891427E-03,   1.2801010E-03,   1.1756698E-03
     +,   1.0756622E-03,   9.8002399E-04,   8.8880915E-04
     +,   8.0215110E-04,   7.2024215E-04,   6.4330408E-04
     +,   5.7154871E-04,   5.0514436E-04,   4.4419768E-04
     +,   3.8874199E-04,   3.3872324E-04,   2.9399848E-04
     +,   2.5434612E-04,   2.1948108E-04,   1.8906157E-04
     +,   1.6271080E-04,   1.4003411E-04,   1.2063172E-04
     +,   1.0411094E-04,   9.0097907E-05,   7.8245866E-05
     +,   6.8238645E-05,   5.9792910E-05,   5.2659612E-05
     +,   4.6623478E-05,   4.1500323E-05,   3.7134203E-05
     +,   3.3394845E-05,   3.0174617E-05,   2.7384755E-05
     +,   2.4952780E-05,   2.2819897E-05,   2.0938469E-05
     +,   1.9269797E-05,   1.7782546E-05,   1.6451379E-05
     +,   1.5255579E-05,   1.4178057E-05,   1.3204653E-05
     +,   1.2323560E-05,   1.1524768E-05,   1.0799637E-05
     +,   1.0140668E-05,   9.5413516E-06,   8.9958403E-06
     +,   8.4989115E-06,   8.0458894E-06,   7.6325332E-06
     +,   7.2549551E-06,   6.9096136E-06,   6.5932932E-06
     +,   6.3030561E-06,   6.0361972E-06,   5.7902571E-06
     +,   5.5630139E-06,   5.3524277E-06,   5.1566717E-06
     +,   4.9740770E-06,   4.8031616E-06,   4.6425789E-06
     +,   4.4911435E-06,   4.3477826E-06,   4.2115635E-06
     +,   4.0816458E-06,   3.9573065E-06,   3.8379026E-06
     +,   3.7228756E-06,   3.6117503E-06,   3.5041055E-06
     +,   3.3995916E-06,   3.2979017E-06,   3.1987852E-06
     +,   3.1020240E-06,   3.0074452E-06,   2.9148978E-06
     +,   2.8242689E-06,   2.7354577E-06,   2.6483958E-06
     +,   2.5630195E-06,   2.4792917E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt80 = Yx/0.44156
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4263342E-05,   1.4738745E-05
     +,   1.5220238E-05,   1.5707355E-05,   1.6199607E-05
     +,   1.6696522E-05,   1.7197633E-05,   1.7702485E-05
     +,   1.8210654E-05,   1.8721767E-05,   1.9235466E-05
     +,   1.9751473E-05,   2.0269557E-05,   2.0789588E-05
     +,   2.1311515E-05,   2.1835385E-05,   2.2361386E-05
     +,   2.2889828E-05,   2.3421173E-05,   2.3956052E-05
     +,   2.4495299E-05,   2.5039923E-05,   2.5591182E-05
     +,   2.6150597E-05,   2.6719896E-05,   2.7301161E-05
     +,   2.7896753E-05,   2.8509368E-05,   2.9142062E-05
     +,   2.9798248E-05,   3.0481762E-05,   3.1196836E-05
     +,   3.1948133E-05,   3.2740754E-05,   3.3580276E-05
     +,   3.4472694E-05,   3.5424480E-05,   3.6442543E-05
     +,   3.7534272E-05,   3.8707338E-05,   3.9969913E-05
     +,   4.1330444E-05,   4.2797634E-05,   4.4380395E-05
     +,   4.6087720E-05,   4.7928705E-05,   4.9912247E-05
     +,   5.2047108E-05,   5.4341639E-05,   5.6803743E-05
     +,   5.9440623E-05,   6.2258681E-05,   6.5263259E-05
     +,   6.8458787E-05,   7.1847906E-05,   7.5432217E-05
     +,   7.9211393E-05,   8.3183353E-05,   8.7344160E-05
     +,   9.1687703E-05,   9.6205884E-05,   1.0088847E-04
     +,   1.0572277E-04,   1.1069432E-04,   1.1578664E-04
     +,   1.2098072E-04,   1.2625655E-04,   1.3159169E-04
     +,   1.3696324E-04,   1.4234650E-04,   1.4771683E-04
     +,   1.5304858E-04,   1.5831717E-04,   1.6349780E-04
     +,   1.6856763E-04,   1.7350560E-04,   1.7829295E-04
     +,   1.8291397E-04,   1.8735763E-04,   1.9161748E-04
     +,   1.9569266E-04,   1.9958950E-04,   2.0332170E-04
     +,   2.0691262E-04,   2.1039514E-04,   2.1381403E-04
     +,   2.1722638E-04,   2.2070338E-04,   2.2433088E-04
     +,   2.2821067E-04,   2.3246123E-04,   2.3721711E-04
     +,   2.4262963E-04,   2.4886549E-04,   2.5610559E-04
     +,   2.6454151E-04,   2.7437357E-04,   2.8580523E-04
     +,   2.9903930E-04,   3.1427096E-04,   3.3168340E-04
     +,   3.5143879E-04,   3.7367610E-04,   3.9850100E-04
     +,   4.2598622E-04,   4.5616698E-04,   4.8903766E-04
     +,   5.2455347E-04,   5.6263601E-04,   6.0317549E-04
     +,   6.4603199E-04,   6.9105241E-04,   7.3806569E-04
     +,   7.8690454E-04,   8.3740434E-04,   8.8942371E-04
     +,   9.4284705E-04,   9.9761586E-04,   1.0537310E-03
     +,   1.1112925E-03,   1.1705193E-03,   1.2317772E-03
     +,   1.2956084E-03,   1.3627575E-03,   1.4341805E-03
     +,   1.5110204E-03,   1.5945809E-03,   1.6862230E-03
     +,   1.7872513E-03,   1.8987041E-03,   2.0211560E-03
     +,   2.1544390E-03,   2.2974680E-03,   2.4481113E-03
     +,   2.6033630E-03,   2.7598434E-03,   2.9147726E-03
     +,   3.0674618E-03,   3.2210711E-03,   3.3841180E-03
     +,   3.5709802E-03,   3.8005218E-03,   4.0924069E-03
     +,   4.4616419E-03,   4.9137310E-03,   5.4449537E-03
     +,   6.0529276E-03,   6.7604245E-03,   7.6457066E-03
     +,   8.8560563E-03,   1.0574393E-02,   1.2935314E-02
     +,   1.5940757E-02,   1.9469580E-02,   2.3459040E-02
     +,   2.8127052E-02,   3.3856418E-02,   4.0734988E-02
     +,   4.8189200E-02,   5.4866992E-02,   5.9543036E-02
     +,   6.3247077E-02,   6.8586551E-02,   7.5900532E-02
     +,   8.2566179E-02,   8.6709931E-02,   8.8172778E-02
     +,   8.5965328E-02,   8.1293732E-02,   7.6001056E-02
     +,   7.0512407E-02,   6.5839484E-02,   6.1149381E-02
     +,   5.4795101E-02,   4.7178142E-02,   4.0079955E-02
     +,   3.4833275E-02,   3.1466141E-02,   2.9029513E-02
     +,   2.6575228E-02,   2.3839865E-02,   2.1136189E-02
     +,   1.8840557E-02,   1.7066969E-02,   1.5694693E-02
     +,   1.4548609E-02,   1.3514639E-02,   1.2548517E-02
     +,   1.1642992E-02,   1.0806346E-02,   1.0054983E-02
     +,   9.4061559E-03,   8.8665104E-03,   8.4235230E-03
     +,   8.0467351E-03,   7.6977713E-03,   7.3428997E-03
     +,   6.9617992E-03,   6.5500471E-03,   6.1162710E-03
     +,   5.6766234E-03,   5.2489606E-03,   4.8483843E-03
     +,   4.4847857E-03,   4.1623167E-03,   3.8801627E-03
     +,   3.6341702E-03,   3.4184975E-03,   3.2269014E-03
     +,   3.0534896E-03,   2.8931082E-03,   2.7414146E-03
     +,   2.5948626E-03,   2.4506855E-03,   2.3069053E-03
     +,   2.1623485E-03,   2.0166195E-03,   1.8700223E-03
     +,   1.7234549E-03,   1.5782705E-03,   1.4360698E-03
     +,   1.2985358E-03,   1.1672677E-03,   1.0436411E-03
     +,   9.2870020E-04,   8.2311878E-04,   7.2720298E-04
     +,   6.4091012E-04,   5.6390394E-04,   4.9563049E-04
     +,   4.3539578E-04,   3.8242881E-04,   3.3593556E-04
     +,   2.9514809E-04,   2.5935590E-04,   2.2791524E-04
     +,   2.0026055E-04,   1.7590442E-04,   1.5442957E-04
     +,   1.3547961E-04,   1.1875145E-04,   1.0398683E-04
     +,   9.0963265E-05,   7.9486141E-05,   6.9384565E-05
     +,   6.0507555E-05,   5.2719988E-05,   4.5899891E-05
     +,   3.9937360E-05,   3.4733697E-05,   3.0199317E-05
     +,   2.6253623E-05,   2.2824481E-05,   1.9847334E-05
     +,   1.7264443E-05,   1.5024621E-05,   1.3082788E-05
     +,   1.1399255E-05,   9.9391473E-06,   8.6720538E-06
     +,   7.5716298E-06,   6.6150405E-06,   5.7825064E-06
     +,   5.0570156E-06,   4.4240205E-06,   3.8709845E-06
     +,   3.3871779E-06,   2.9634498E-06,   2.5919619E-06
     +,   2.2659769E-06,   1.9797164E-06,   1.7282330E-06
     +,   1.5072565E-06,   1.3130804E-06,   1.1424913E-06
     +,   9.9270312E-07,   8.6126312E-07,   7.4603440E-07
     +,   6.4512136E-07,   5.5686326E-07,   4.7977841E-07
     +,   4.1256271E-07,   3.5404855E-07,   3.0320547E-07
     +,   2.5911024E-07,   2.2094662E-07,   1.8798498E-07
     +,   1.5957723E-07,   1.3515053E-07,   1.1419404E-07
     +,   9.6258120E-08,   8.0943273E-08,   6.7899379E-08
     +,   5.6816557E-08,   4.7424326E-08,   3.9484725E-08
     +,   3.2790886E-08,   2.7161791E-08,   2.2440949E-08
     +,   1.8492159E-08,   1.5198292E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt85 = Yx/0.45598
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5592683E-06,   4.8607017E-06
     +,   5.1813822E-06,   5.5224082E-06,   5.8849087E-06
     +,   6.2700447E-06,   6.6790030E-06,   7.1129925E-06
     +,   7.5732310E-06,   8.0609680E-06,   8.5774327E-06
     +,   9.1238599E-06,   9.7014681E-06,   1.0311453E-05
     +,   1.0954981E-05,   1.1633175E-05,   1.2347099E-05
     +,   1.3097760E-05,   1.3886081E-05,   1.4712896E-05
     +,   1.5578948E-05,   1.6484850E-05,   1.7431084E-05
     +,   1.8418064E-05,   1.9445937E-05,   2.0514810E-05
     +,   2.1624555E-05,   2.2774897E-05,   2.3965376E-05
     +,   2.5195353E-05,   2.6464008E-05,   2.7770340E-05
     +,   2.9113167E-05,   3.0491135E-05,   3.1902746E-05
     +,   3.3346325E-05,   3.4820088E-05,   3.6322112E-05
     +,   3.7850499E-05,   3.9403072E-05,   4.0977870E-05
     +,   4.2572774E-05,   4.4185781E-05,   4.5814952E-05
     +,   4.7458481E-05,   4.9114744E-05,   5.0782339E-05
     +,   5.2460109E-05,   5.4147247E-05,   5.5843298E-05
     +,   5.7548219E-05,   5.9262398E-05,   6.0986713E-05
     +,   6.2722655E-05,   6.4472086E-05,   6.6237619E-05
     +,   6.8022331E-05,   6.9829955E-05,   7.1664756E-05
     +,   7.3531563E-05,   7.5435790E-05,   7.7383316E-05
     +,   7.9380407E-05,   8.1433842E-05,   8.3550782E-05
     +,   8.5738422E-05,   8.8004497E-05,   9.0356545E-05
     +,   9.2802526E-05,   9.5350137E-05,   9.8007324E-05
     +,   1.0078177E-04,   1.0368146E-04,   1.0671403E-04
     +,   1.0988750E-04,   1.1321014E-04,   1.1669032E-04
     +,   1.2033692E-04,   1.2415984E-04,   1.2817000E-04
     +,   1.3237927E-04,   1.3680164E-04,   1.4145268E-04
     +,   1.4635066E-04,   1.5151608E-04,   1.5697298E-04
     +,   1.6274807E-04,   1.6887220E-04,   1.7537906E-04
     +,   1.8230670E-04,   1.8969683E-04,   1.9759424E-04
     +,   2.0604691E-04,   2.1510613E-04,   2.2482588E-04
     +,   2.3526083E-04,   2.4646812E-04,   2.5850383E-04
     +,   2.7142497E-04,   2.8528523E-04,   3.0013744E-04
     +,   3.1602848E-04,   3.3300187E-04,   3.5109188E-04
     +,   3.7032511E-04,   3.9071738E-04,   4.1226920E-04
     +,   4.3496399E-04,   4.5876749E-04,   4.8362251E-04
     +,   5.0944340E-04,   5.3611898E-04,   5.6350435E-04
     +,   5.9142581E-04,   6.1967527E-04,   6.4802007E-04
     +,   6.7619950E-04,   7.0394360E-04,   7.3097477E-04
     +,   7.5703295E-04,   7.8189053E-04,   8.0537691E-04
     +,   8.2740578E-04,   8.4800704E-04,   8.6735509E-04
     +,   8.8579376E-04,   9.0386387E-04,   9.2231319E-04
     +,   9.4210339E-04,   9.6439006E-04,   9.9049718E-04
     +,   1.0218576E-03,   1.0599514E-03,   1.1062131E-03
     +,   1.1619526E-03,   1.2282711E-03,   1.3060078E-03
     +,   1.3957297E-03,   1.4978098E-03,   1.6125783E-03
     +,   1.7405767E-03,   1.8829183E-03,   2.0417173E-03
     +,   2.2204653E-03,   2.4242254E-03,   2.6595166E-03
     +,   2.9336016E-03,   3.2531694E-03,   3.6225333E-03
     +,   4.0418161E-03,   4.5057265E-03,   5.0037107E-03
     +,   5.5220397E-03,   6.0475804E-03,   6.5730577E-03
     +,   7.1039018E-03,   7.6672737E-03,   8.3208969E-03
     +,   9.1550164E-03,   1.0281271E-02,   1.1815418E-02
     +,   1.3875105E-02,   1.6612219E-02,   2.0266201E-02
     +,   2.5163060E-02,   3.1590626E-02,   3.9536964E-02
     +,   4.8218474E-02,   5.6221567E-02,   6.3239679E-02
     +,   7.0296235E-02,   7.8050196E-02,   8.5457854E-02
     +,   9.0250365E-02,   9.4163276E-02,   9.6780196E-02
     +,   9.4751216E-02,   9.1029085E-02,   8.4784813E-02
     +,   7.4943870E-02,   6.4943492E-02,   5.6126848E-02
     +,   4.9000561E-02,   4.4152234E-02,   4.0722296E-02
     +,   3.7454773E-02,   3.3831496E-02,   2.9964181E-02
     +,   2.6204737E-02,   2.2835037E-02,   1.9929281E-02
     +,   1.7434092E-02,   1.5301449E-02,   1.3526807E-02
     +,   1.2115660E-02,   1.1052251E-02,   1.0288347E-02
     +,   9.7453287E-03,   9.3308594E-03,   8.9644473E-03
     +,   8.5956268E-03,   8.2054082E-03,   7.7953362E-03
     +,   7.3751519E-03,   6.9554644E-03,   6.5455427E-03
     +,   6.1532184E-03,   5.7841442E-03,   5.4404484E-03
     +,   5.1199561E-03,   4.8169964E-03,   4.5245402E-03
     +,   4.2365654E-03,   3.9497018E-03,   3.6636463E-03
     +,   3.3804863E-03,   3.1034746E-03,   2.8358558E-03
     +,   2.5801486E-03,   2.3379375E-03,   2.1099411E-03
     +,   1.8963256E-03,   1.6970071E-03,   1.5118332E-03
     +,   1.3406413E-03,   1.1832694E-03,   1.0395121E-03
     +,   9.0905151E-04,   7.9141802E-04,   6.8600016E-04
     +,   5.9207465E-04,   5.0883455E-04,   4.3543207E-04
     +,   3.7101842E-04,   3.1477510E-04,   2.6591439E-04
     +,   2.2369267E-04,   1.8741182E-04,   1.5641403E-04
     +,   1.3007957E-04,   1.0782963E-04,   8.9128742E-05
     +,   7.3485455E-05,   6.0453644E-05,   4.9635277E-05
     +,   4.0680672E-05,   3.3286087E-05,   2.7190592E-05
     +,   2.2173084E-05,   1.8048187E-05,   1.4660831E-05
     +,   1.1882341E-05,   9.6064450E-06,   7.7452742E-06
     +,   6.2261306E-06,   4.9889290E-06,   3.9840152E-06
     +,   3.1702004E-06,   2.5132595E-06,   1.9847973E-06
     +,   1.5612875E-06,   1.2232225E-06,   9.5444693E-07
     +,   7.4164166E-07,   5.7387666E-07,   4.4218353E-07
     +,   3.3925284E-07,   2.5915858E-07,   1.9711152E-07
     +,   1.4925742E-07,   1.1251444E-07,   8.4431662E-08
     +,   6.3066864E-08,   4.6887788E-08,   3.4693059E-08
     +,   2.5545960E-08,   1.8717735E-08,   1.3646035E-08
     +,   9.8977218E-09,   7.1418516E-09,   5.1260924E-09
     +,   3.6596131E-09,   2.5984388E-09,   1.8348219E-09
     +,   1.2883601E-09,   8.9954399E-10,   6.2447758E-10
     +,   4.3101123E-10,   2.9574979E-10,   2.0174015E-10
     +,   1.3679936E-10,   9.2208664E-11,   6.1780733E-11
     +,   4.1144040E-11,   2.7235620E-11,   1.7919628E-11
     +,   1.1719124E-11,   7.6178491E-12,   4.9222883E-12
     +,   3.1616352E-12,   2.0189126E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt90 = Yx/0.46116
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.3482303E-07,   9.0151474E-07
     +,   9.7323209E-07,   1.0503674E-06,   1.1333461E-06
     +,   1.2226328E-06,   1.3187313E-06,   1.4221893E-06
     +,   1.5336004E-06,   1.6536131E-06,   1.7829258E-06
     +,   1.9222937E-06,   2.0725342E-06,   2.2345275E-06
     +,   2.4092199E-06,   2.5976265E-06,   2.8008335E-06
     +,   3.0200008E-06,   3.2563612E-06,   3.5112216E-06
     +,   3.7859636E-06,   4.0820405E-06,   4.4009726E-06
     +,   4.7443668E-06,   5.1138545E-06,   5.5111650E-06
     +,   5.9380504E-06,   6.3963121E-06,   6.8877803E-06
     +,   7.4143045E-06,   7.9777374E-06,   8.5799211E-06
     +,   9.2226728E-06,   9.9077597E-06,   1.0636886E-05
     +,   1.1411668E-05,   1.2233619E-05,   1.3104095E-05
     +,   1.4024358E-05,   1.4995389E-05,   1.6018061E-05
     +,   1.7092967E-05,   1.8220448E-05,   1.9400573E-05
     +,   2.0633108E-05,   2.1917494E-05,   2.3252842E-05
     +,   2.4637899E-05,   2.6071051E-05,   2.7550295E-05
     +,   2.9073266E-05,   3.0637188E-05,   3.2238895E-05
     +,   3.3874963E-05,   3.5541390E-05,   3.7234051E-05
     +,   3.8948390E-05,   4.0679573E-05,   4.2422547E-05
     +,   4.4172029E-05,   4.5922578E-05,   4.7668662E-05
     +,   4.9404614E-05,   5.1124891E-05,   5.2824034E-05
     +,   5.4496591E-05,   5.6137542E-05,   5.7741981E-05
     +,   5.9305556E-05,   6.0824295E-05,   6.2294923E-05
     +,   6.3714666E-05,   6.5081753E-05,   6.6395034E-05
     +,   6.7654561E-05,   6.8861365E-05,   7.0017639E-05
     +,   7.1126844E-05,   7.2193878E-05,   7.3225121E-05
     +,   7.4228403E-05,   7.5213356E-05,   7.6191121E-05
     +,   7.7174722E-05,   7.8178811E-05,   7.9219957E-05
     +,   8.0316306E-05,   8.1487800E-05,   8.2755760E-05
     +,   8.4143074E-05,   8.5673739E-05,   8.7372675E-05
     +,   8.9265370E-05,   9.1377748E-05,   9.3735580E-05
     +,   9.6363903E-05,   9.9287005E-05,   1.0252735E-04
     +,   1.0610580E-04,   1.1004030E-04,   1.1434651E-04
     +,   1.1903637E-04,   1.2411892E-04,   1.2959927E-04
     +,   1.3547938E-04,   1.4175828E-04,   1.4843185E-04
     +,   1.5549411E-04,   1.6293829E-04,   1.7075798E-04
     +,   1.7894754E-04,   1.8750541E-04,   1.9643400E-04
     +,   2.0574318E-04,   2.1545046E-04,   2.2558487E-04
     +,   2.3618595E-04,   2.4730872E-04,   2.5902168E-04
     +,   2.7141121E-04,   2.8458182E-04,   2.9865641E-04
     +,   3.1377876E-04,   3.3011599E-04,   3.4785998E-04
     +,   3.6722550E-04,   3.8845744E-04,   4.1182432E-04
     +,   4.3762280E-04,   4.6616668E-04,   4.9778703E-04
     +,   5.3281413E-04,   5.7157269E-04,   6.1436062E-04
     +,   6.6144823E-04,   7.1307464E-04,   7.6945726E-04
     +,   8.3083019E-04,   8.9750387E-04,   9.6993591E-04
     +,   1.0488135E-03,   1.1351304E-03,   1.2302268E-03
     +,   1.3357489E-03,   1.4534993E-03,   1.5851993E-03
     +,   1.7321161E-03,   1.8946279E-03,   2.0718263E-03
     +,   2.2612708E-03,   2.4589812E-03,   2.6598165E-03
     +,   2.8583070E-03,   3.0498786E-03,   3.2322595E-03
     +,   3.4067472E-03,   3.5789202E-03,   3.7582922E-03
     +,   3.9567668E-03,   4.1863951E-03,   4.4579245E-03
     +,   4.7819489E-03,   5.1736897E-03,   5.6598266E-03
     +,   6.2824772E-03,   7.0939078E-03,   8.1391148E-03
     +,   9.4323931E-03,   1.0949737E-02,   1.2669234E-02
     +,   1.4654907E-02,   1.7083103E-02,   2.0105977E-02
     +,   2.3675689E-02,   2.7632391E-02,   3.2053079E-02
     +,   3.7461061E-02,   4.4689614E-02,   5.4423243E-02
     +,   6.5754637E-02,   7.5707614E-02,   8.2900442E-02
     +,   8.7722413E-02,   9.1426641E-02,   9.5729351E-02
     +,   9.7693793E-02,   9.5382646E-02,   8.9979306E-02
     +,   8.1165902E-02,   7.1262278E-02,   6.1672717E-02
     +,   5.3061351E-02,   4.6544388E-02,   4.2432517E-02
     +,   3.8870785E-02,   3.4340415E-02,   2.9223211E-02
     +,   2.4743771E-02,   2.1605244E-02,   1.9657291E-02
     +,   1.8401360E-02,   1.7360719E-02,   1.6205817E-02
     +,   1.4852775E-02,   1.3428685E-02,   1.2104005E-02
     +,   1.0969873E-02,   1.0031320E-02,   9.2523079E-03
     +,   8.5890116E-03,   8.0008432E-03,   7.4524712E-03
     +,   6.9162995E-03,   6.3759955E-03,   5.8284109E-03
     +,   5.2818540E-03,   4.7509214E-03,   4.2503336E-03
     +,   3.7903476E-03,   3.3749409E-03,   3.0025074E-03
     +,   2.6680916E-03,   2.3658061E-03,   2.0905407E-03
     +,   1.8387487E-03,   1.6084645E-03,   1.3988514E-03
     +,   1.2095787E-03,   1.0403125E-03,   8.9042546E-04
     +,   7.5890234E-04,   6.4437196E-04,   5.4522540E-04
     +,   4.5976869E-04,   3.8635323E-04,   3.2344286E-04
     +,   2.6966847E-04,   2.2383951E-04,   1.8492586E-04
     +,   1.5203198E-04,   1.2437410E-04,   1.0125913E-04
     +,   8.2065482E-05,   6.6232227E-05,   5.3255295E-05
     +,   4.2685275E-05,   3.4124598E-05,   2.7225742E-05
     +,   2.1689686E-05,   1.7263053E-05,   1.3732964E-05
     +,   1.0923212E-05,   8.6895980E-06,   6.9150037E-06
     +,   5.5049982E-06,   4.3840669E-06,   3.4921902E-06
     +,   2.7817871E-06,   2.2152249E-06,   1.7628410E-06
     +,   1.4012860E-06,   1.1121455E-06,   8.8085892E-07
     +,   6.9590294E-07,   5.4814080E-07,   4.3026765E-07
     +,   3.3643673E-07,   2.6195320E-07,   2.0302632E-07
     +,   1.5658568E-07,   1.2014370E-07,   9.1685337E-08
     +,   6.9576792E-08,   5.2494496E-08,   3.9371340E-08
     +,   2.9350554E-08,   2.1745452E-08,   1.6010571E-08
     +,   1.1713599E-08,   8.5153378E-09,   6.1505046E-09
     +,   4.4137525E-09,   3.1468006E-09,   2.2289126E-09
     +,   1.5684115E-09,   1.0964063E-09,   7.6140894E-10
     +,   5.2527749E-10,   3.5999045E-10,   2.4508220E-10
     +,   1.6575250E-10,   1.1135857E-10,   7.4321639E-11
     +,   4.9274702E-11,   3.2453602E-11,   2.1233647E-11
     +,   1.3801489E-11,   8.9116969E-12,   5.7167695E-12
     +,   3.6433157E-12,   2.3068975E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_htt95 = Yx/0.45038
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2442375E-07,   1.4511005E-07
     +,   1.6885528E-07,   1.9604443E-07,   2.2710023E-07
     +,   2.6248463E-07,   3.0270078E-07,   3.4829483E-07
     +,   3.9985588E-07,   4.5802048E-07,   5.2346849E-07
     +,   5.9692638E-07,   6.7916557E-07,   7.7100157E-07
     +,   8.7329306E-07,   9.8693806E-07,   1.1128718E-06
     +,   1.2520628E-06,   1.4055062E-06,   1.5742201E-06
     +,   1.7592361E-06,   1.9615948E-06,   2.1823287E-06
     +,   2.4224742E-06,   2.6830176E-06,   2.9649386E-06
     +,   3.2691523E-06,   3.5965149E-06,   3.9478095E-06
     +,   4.3237269E-06,   4.7248518E-06,   5.1516481E-06
     +,   5.6044437E-06,   6.0834109E-06,   6.5885597E-06
     +,   7.1197151E-06,   7.6765082E-06,   8.2583520E-06
     +,   8.8644865E-06,   9.4938468E-06,   1.0145212E-05
     +,   1.0817081E-05,   1.1507716E-05,   1.2215150E-05
     +,   1.2937163E-05,   1.3671315E-05,   1.4414939E-05
     +,   1.5165157E-05,   1.5918897E-05,   1.6672908E-05
     +,   1.7423785E-05,   1.8167990E-05,   1.8901866E-05
     +,   1.9621737E-05,   2.0323794E-05,   2.1004294E-05
     +,   2.1659484E-05,   2.2285667E-05,   2.2879256E-05
     +,   2.3436791E-05,   2.3954981E-05,   2.4430747E-05
     +,   2.4861214E-05,   2.5243817E-05,   2.5576292E-05
     +,   2.5856654E-05,   2.6083329E-05,   2.6255062E-05
     +,   2.6371023E-05,   2.6430753E-05,   2.6434234E-05
     +,   2.6381831E-05,   2.6274327E-05,   2.6112941E-05
     +,   2.5899246E-05,   2.5635221E-05,   2.5323217E-05
     +,   2.4965935E-05,   2.4566381E-05,   2.4127843E-05
     +,   2.3653918E-05,   2.3148372E-05,   2.2615232E-05
     +,   2.2058613E-05,   2.1482827E-05,   2.0892203E-05
     +,   2.0291183E-05,   1.9684161E-05,   1.9075582E-05
     +,   1.8469780E-05,   1.7871012E-05,   1.7283461E-05
     +,   1.6711179E-05,   1.6158025E-05,   1.5627693E-05
     +,   1.5123740E-05,   1.4649474E-05,   1.4208063E-05
     +,   1.3802432E-05,   1.3435372E-05,   1.3109448E-05
     +,   1.2827121E-05,   1.2590681E-05,   1.2402345E-05
     +,   1.2264259E-05,   1.2178540E-05,   1.2147366E-05
     +,   1.2172984E-05,   1.2257824E-05,   1.2404549E-05
     +,   1.2616141E-05,   1.2896016E-05,   1.3248095E-05
     +,   1.3676959E-05,   1.4187893E-05,   1.4787133E-05
     +,   1.5481850E-05,   1.6280457E-05,   1.7192586E-05
     +,   1.8229404E-05,   1.9403749E-05,   2.0730207E-05
     +,   2.2225380E-05,   2.3908211E-05,   2.5800169E-05
     +,   2.7925305E-05,   3.0311056E-05,   3.2987962E-05
     +,   3.5990703E-05,   3.9357812E-05,   4.3132830E-05
     +,   4.7363832E-05,   5.2104813E-05,   5.7414843E-05
     +,   6.3359337E-05,   7.0009664E-05,   7.7442535E-05
     +,   8.5739819E-05,   9.4988158E-05,   1.0527740E-04
     +,   1.1669758E-04,   1.2933680E-04,   1.4327820E-04
     +,   1.5859447E-04,   1.7534007E-04,   1.9354688E-04
     +,   2.1321444E-04,   2.3429938E-04,   2.5670746E-04
     +,   2.8028671E-04,   3.0482028E-04,   3.3002193E-04
     +,   3.5554057E-04,   3.8097173E-04,   4.0587297E-04
     +,   4.2978927E-04,   4.5228924E-04,   4.7301003E-04
     +,   4.9170462E-04,   5.0829165E-04,   5.2291050E-04
     +,   5.3596235E-04,   5.4813881E-04,   5.6042906E-04
     +,   5.7409343E-04,   5.9059513E-04,   6.1148789E-04
     +,   6.3826895E-04,   6.7222054E-04,   7.1427302E-04
     +,   7.6494121E-04,   8.2438922E-04,   8.9265144E-04
     +,   9.6998102E-04,   1.0572680E-03,   1.1564813E-03
     +,   1.2710756E-03,   1.4065217E-03,   1.5713680E-03
     +,   1.7794203E-03,   2.0533828E-03,   2.4285340E-03
     +,   2.9507792E-03,   3.6607108E-03,   4.5655016E-03
     +,   5.6256037E-03,   6.7884428E-03,   8.0426233E-03
     +,   9.4150826E-03,   1.0977359E-02,   1.3072760E-02
     +,   1.6627500E-02,   2.2622490E-02,   2.9665563E-02
     +,   3.4066930E-02,   3.6257923E-02,   4.0690549E-02
     +,   4.6396662E-02,   4.7688797E-02,   4.3170478E-02
     +,   3.6444660E-02,   2.9946798E-02,   2.4287499E-02
     +,   2.0072127E-02,   1.7166877E-02,   1.4912856E-02
     +,   1.2908712E-02,   1.1218389E-02,   9.9731190E-03
     +,   8.9940559E-03,   7.9975268E-03,   6.9051362E-03
     +,   5.8193654E-03,   4.8605129E-03,   4.0880456E-03
     +,   3.5012066E-03,   3.0623735E-03,   2.7221842E-03
     +,   2.4387315E-03,   2.1856497E-03,   1.9507767E-03
     +,   1.7311742E-03,   1.5284051E-03,   1.3451872E-03
     +,   1.1833316E-03,   1.0428024E-03,   9.2169648E-04
     +,   8.1685191E-04,   7.2471064E-04,   6.4207782E-04
     +,   5.6656095E-04,   4.9667055E-04,   4.3168711E-04
     +,   3.7142870E-04,   3.1601317E-04,   2.6564993E-04
     +,   2.2051469E-04,   1.8067879E-04,   1.4607614E-04
     +,   1.1650233E-04,   9.1636430E-05,   7.1070528E-05
     +,   5.4339042E-05,   4.0948831E-05,   3.0407589E-05
     +,   2.2245566E-05,   1.6030093E-05,   1.1375252E-05
     +,   7.9473266E-06,   5.4656061E-06,   3.6993492E-06
     +,   2.4637745E-06,   1.6143739E-06,   1.0405981E-06
     +,   6.5975541E-07,   4.1139342E-07,   2.5227922E-07
     +,   1.5213865E-07,   9.0221299E-08,   5.2610467E-08
     +,   3.0166976E-08,   1.7009681E-08,   9.4310444E-09
     +,   5.1418501E-09,   2.7567613E-09,   1.4534401E-09
     +,   7.5355039E-10,   3.8420267E-10,   1.9264544E-10
     +,   9.4996254E-11,   4.6068285E-11,   2.1971957E-11
     +,   1.0307162E-11,   4.7559747E-12,   2.1588597E-12
     +,   9.6434959E-13,   4.2409303E-13,   1.8378772E-13
     +,   7.8610722E-14,   3.3285488E-14,   1.4024487E-14
     +,   5.9340617E-15,   2.5591737E-15,   1.1498514E-15
     +,   5.5245956E-16,   2.8995433E-16,   1.6706530E-16
     +,   1.0422318E-16,   6.8774714E-17,   4.6958693E-17
     +,   3.2659542E-17,   2.2915421E-17,   1.6134308E-17
     +,   1.1366796E-17,   8.0015646E-18,   5.6239236E-18
     +,   3.9454058E-18,   2.7621662E-18,   1.9297013E-18
     +,   1.3452007E-18,   9.3571322E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz100 = Yx/0.153511627906977
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7956937E-07,   4.2410264E-07
     +,   4.7301759E-07,   5.2663609E-07,   5.8529037E-07
     +,   6.4932254E-07,   7.1908187E-07,   7.9492429E-07
     +,   8.7720849E-07,   9.6629958E-07,   1.0625575E-06
     +,   1.1663426E-06,   1.2780087E-06,   1.3979004E-06
     +,   1.5263524E-06,   1.6636830E-06,   1.8101930E-06
     +,   1.9661620E-06,   2.1318424E-06,   2.3074583E-06
     +,   2.4932019E-06,   2.6892274E-06,   2.8956470E-06
     +,   3.1125421E-06,   3.3399244E-06,   3.5777809E-06
     +,   3.8260318E-06,   4.0845457E-06,   4.3531354E-06
     +,   4.6315563E-06,   4.9195050E-06,   5.2166156E-06
     +,   5.5224682E-06,   5.8365772E-06,   6.1584064E-06
     +,   6.4873584E-06,   6.8227837E-06,   7.1639784E-06
     +,   7.5102125E-06,   7.8606754E-06,   8.2145552E-06
     +,   8.5709908E-06,   8.9290925E-06,   9.2879573E-06
     +,   9.6466601E-06,   1.0004279E-05,   1.0359882E-05
     +,   1.0712550E-05,   1.1061375E-05,   1.1405467E-05
     +,   1.1743973E-05,   1.2076062E-05,   1.2400948E-05
     +,   1.2717909E-05,   1.3026234E-05,   1.3325314E-05
     +,   1.3614573E-05,   1.3893506E-05,   1.4161677E-05
     +,   1.4418715E-05,   1.4664333E-05,   1.4898313E-05
     +,   1.5120499E-05,   1.5330832E-05,   1.5529331E-05
     +,   1.5716072E-05,   1.5891243E-05,   1.6055088E-05
     +,   1.6207978E-05,   1.6350343E-05,   1.6482749E-05
     +,   1.6605858E-05,   1.6720480E-05,   1.6827566E-05
     +,   1.6928236E-05,   1.7023825E-05,   1.7115881E-05
     +,   1.7206225E-05,   1.7296990E-05,   1.7390668E-05
     +,   1.7490142E-05,   1.7598779E-05,   1.7720451E-05
     +,   1.7859624E-05,   1.8021408E-05,   1.8211615E-05
     +,   1.8436822E-05,   1.8704441E-05,   1.9022702E-05
     +,   1.9400775E-05,   1.9848745E-05,   2.0377585E-05
     +,   2.0999169E-05,   2.1726257E-05,   2.2572431E-05
     +,   2.3551895E-05,   2.4679564E-05,   2.5970669E-05
     +,   2.7440852E-05,   2.9105660E-05,   3.0980675E-05
     +,   3.3080847E-05,   3.5420675E-05,   3.8013404E-05
     +,   4.0871219E-05,   4.4004715E-05,   4.7422356E-05
     +,   5.1130351E-05,   5.5132463E-05,   5.9429658E-05
     +,   6.4019237E-05,   6.8895519E-05,   7.4048468E-05
     +,   7.9464611E-05,   8.5125568E-05,   9.1009264E-05
     +,   9.7088276E-05,   1.0333141E-04,   1.0970207E-04
     +,   1.1615983E-04,   1.2265994E-04,   1.2915328E-04
     +,   1.3558727E-04,   1.4190668E-04,   1.4805414E-04
     +,   1.5397015E-04,   1.5959567E-04,   1.6487157E-04
     +,   1.6974143E-04,   1.7415138E-04,   1.7805313E-04
     +,   1.8140396E-04,   1.8416962E-04,   1.8632483E-04
     +,   1.8785566E-04,   1.8876060E-04,   1.8905182E-04
     +,   1.8875676E-04,   1.8791888E-04,   1.8659858E-04
     +,   1.8487341E-04,   1.8283838E-04,   1.8060513E-04
     +,   1.7830088E-04,   1.7606700E-04,   1.7405605E-04
     +,   1.7242866E-04,   1.7134950E-04,   1.7098243E-04
     +,   1.7148460E-04,   1.7300145E-04,   1.7566026E-04
     +,   1.7956521E-04,   1.8479333E-04,   1.9139276E-04
     +,   1.9938171E-04,   2.0875310E-04,   2.1948223E-04
     +,   2.3153824E-04,   2.4489840E-04,   2.5956999E-04
     +,   2.7561051E-04,   2.9314807E-04,   3.1240043E-04
     +,   3.3368650E-04,   3.5742443E-04,   3.8411081E-04
     +,   4.1428214E-04,   4.4845513E-04,   4.8704323E-04
     +,   5.3025706E-04,   5.7801092E-04,   6.2984886E-04
     +,   6.8490452E-04,   7.4192527E-04,   7.9939485E-04
     +,   8.5573882E-04,   9.0962066E-04,   9.6031051E-04
     +,   1.0080672E-03,   1.0544549E-03,   1.1025255E-03
     +,   1.1567889E-03,   1.2229389E-03,   1.3073963E-03
     +,   1.4169444E-03,   1.5590221E-03,   1.7433511E-03
     +,   1.9850330E-03,   2.3076672E-03,   2.7428027E-03
     +,   3.3205848E-03,   4.0503009E-03,   4.9018613E-03
     +,   5.8175065E-03,   6.7831096E-03,   7.9299929E-03
     +,   9.5466729E-03,   1.1897087E-02,   1.4990992E-02
     +,   1.8779181E-02,   2.3577120E-02,   2.9197611E-02
     +,   3.3978943E-02,   3.6928125E-02,   3.8839504E-02
     +,   4.0114038E-02,   3.9778292E-02,   3.6897056E-02
     +,   3.2436844E-02,   2.7766393E-02,   2.3085557E-02
     +,   1.8548332E-02,   1.4749950E-02,   1.2064398E-02
     +,   1.0376895E-02,   9.2141377E-03,   8.1052398E-03
     +,   6.8901633E-03,   5.6946543E-03,   4.6947724E-03
     +,   3.9564241E-03,   3.4403109E-03,   3.0726157E-03
     +,   2.7892804E-03,   2.5449840E-03,   2.3102823E-03
     +,   2.0691906E-03,   1.8173875E-03,   1.5593504E-03
     +,   1.3045407E-03,   1.0636270E-03,   8.4565638E-04
     +,   6.5652461E-04,   4.9861637E-04,   3.7122826E-04
     +,   2.7149823E-04,   1.9540281E-04,   1.3858732E-04
     +,   9.6937787E-05,   6.6891051E-05,   4.5532586E-05
     +,   3.0566218E-05,   2.0229321E-05,   1.3195511E-05
     +,   8.4824987E-06,   5.3736326E-06,   3.3547424E-06
     +,   2.0638752E-06,   1.2511226E-06,   7.4709578E-07
     +,   4.3923600E-07,   2.5409000E-07,   1.4451338E-07
     +,   8.0735951E-08,   4.4264688E-08,   2.3795657E-08
     +,   1.2532392E-08,   6.4615273E-09,   3.2592504E-09
     +,   1.6075780E-09,   7.7509088E-10,   3.6523168E-10
     +,   1.6819909E-10,   7.5735543E-11,   3.3371767E-11
     +,   1.4416005E-11,   6.1265997E-12,   2.5780096E-12
     +,   1.0862085E-12,   4.6678248E-13,   2.1010033E-13
     +,   1.0203852E-13,   5.4556250E-14,   3.2065123E-14
     +,   2.0293524E-14,   1.3469683E-14,   9.1782601E-15
     +,   6.3327520E-15,   4.3904809E-15,   3.0462936E-15
     +,   2.1111784E-15,   1.4600133E-15,   1.0071371E-15
     +,   6.9283012E-16,   4.7527421E-16,   3.2510231E-16
     +,   2.2173857E-16,   1.5080531E-16,   1.0226642E-16
     +,   6.9151340E-17,   4.6623833E-17,   3.1344878E-17
     +,   2.1011862E-17,   1.4044724E-17,   9.3605255E-18
     +,   6.2206811E-18,   4.1220635E-18,   2.7235925E-18
     +,   1.7943572E-18,   1.1787615E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz104 = Yx/0.142
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5271733E-08,   5.3008147E-08
     +,   6.1942210E-08,   7.2237128E-08,   8.4074500E-08
     +,   9.7655992E-08,   1.1320488E-07,   1.3096762E-07
     +,   1.5121508E-07,   1.7424539E-07,   2.0038389E-07
     +,   2.2998537E-07,   2.6343585E-07,   3.0115331E-07
     +,   3.4358922E-07,   3.9122972E-07,   4.4459640E-07
     +,   5.0424643E-07,   5.7077375E-07,   6.4480889E-07
     +,   7.2701795E-07,   8.1810322E-07,   9.1879923E-07
     +,   1.0298812E-06,   1.1521423E-06,   1.2864175E-06
     +,   1.4335603E-06,   1.5944477E-06,   1.7699755E-06
     +,   1.9610527E-06,   2.1685976E-06,   2.3935306E-06
     +,   2.6367698E-06,   2.8992238E-06,   3.1817842E-06
     +,   3.4853174E-06,   3.8106614E-06,   4.1586054E-06
     +,   4.5299180E-06,   4.9252658E-06,   5.3452986E-06
     +,   5.7905686E-06,   6.2615527E-06,   6.7586443E-06
     +,   7.2821376E-06,   7.8322300E-06,   8.4090125E-06
     +,   9.0124613E-06,   9.6424383E-06,   1.0298688E-05
     +,   1.0980826E-05,   1.1688348E-05,   1.2420614E-05
     +,   1.3176907E-05,   1.3956296E-05,   1.4757825E-05
     +,   1.5580361E-05,   1.6422675E-05,   1.7283432E-05
     +,   1.8161187E-05,   1.9054396E-05,   1.9961451E-05
     +,   2.0880596E-05,   2.1810067E-05,   2.2748043E-05
     +,   2.3692541E-05,   2.4641649E-05,   2.5593292E-05
     +,   2.6545471E-05,   2.7496028E-05,   2.8442910E-05
     +,   2.9383902E-05,   3.0316911E-05,   3.1239702E-05
     +,   3.2150121E-05,   3.3045999E-05,   3.3925116E-05
     +,   3.4785255E-05,   3.5624245E-05,   3.6439935E-05
     +,   3.7230089E-05,   3.7992606E-05,   3.8725284E-05
     +,   3.9426053E-05,   4.0092767E-05,   4.0723437E-05
     +,   4.1315987E-05,   4.1868512E-05,   4.2379084E-05
     +,   4.2845910E-05,   4.3267279E-05,   4.3641561E-05
     +,   4.3967251E-05,   4.4242996E-05,   4.4467593E-05
     +,   4.4639997E-05,   4.4759377E-05,   4.4825061E-05
     +,   4.4836637E-05,   4.4793916E-05,   4.4696935E-05
     +,   4.4546035E-05,   4.4341774E-05,   4.4085042E-05
     +,   4.3776960E-05,   4.3418950E-05,   4.3012740E-05
     +,   4.2560336E-05,   4.2063999E-05,   4.1526269E-05
     +,   4.0950021E-05,   4.0338287E-05,   3.9694489E-05
     +,   3.9022205E-05,   3.8325423E-05,   3.7608319E-05
     +,   3.6875503E-05,   3.6131907E-05,   3.5382996E-05
     +,   3.4634733E-05,   3.3893735E-05,   3.3167511E-05
     +,   3.2464533E-05,   3.1794432E-05,   3.1168242E-05
     +,   3.0598731E-05,   3.0100478E-05,   2.9690320E-05
     +,   2.9387411E-05,   2.9213572E-05,   2.9193356E-05
     +,   2.9354189E-05,   2.9726389E-05,   3.0343052E-05
     +,   3.1239953E-05,   3.2455344E-05,   3.4029519E-05
     +,   3.6004574E-05,   3.8424248E-05,   4.1333686E-05
     +,   4.4779186E-05,   4.8808353E-05,   5.3470925E-05
     +,   5.8819060E-05,   6.4907515E-05,   7.1795570E-05
     +,   7.9547150E-05,   8.8230598E-05,   9.7918499E-05
     +,   1.0868669E-04,   1.2061094E-04,   1.3376102E-04
     +,   1.4819462E-04,   1.6394984E-04,   1.8103411E-04
     +,   1.9941149E-04,   2.1899272E-04,   2.3962633E-04
     +,   2.6108971E-04,   2.8308411E-04,   3.0524065E-04
     +,   3.2712816E-04,   3.4826776E-04,   3.6815990E-04
     +,   3.8631717E-04,   4.0230062E-04,   4.1575861E-04
     +,   4.2646920E-04,   4.3437642E-04,   4.3961580E-04
     +,   4.4252814E-04,   4.4365734E-04,   4.4372643E-04
     +,   4.4359587E-04,   4.4420449E-04,   4.4650090E-04
     +,   4.5137480E-04,   4.5960132E-04,   4.7180735E-04
     +,   4.8848090E-04,   5.1001844E-04,   5.3682306E-04
     +,   5.6945090E-04,   6.0880801E-04,   6.5638666E-04
     +,   7.1452104E-04,   7.8662776E-04,   8.7734876E-04
     +,   9.9254609E-04,   1.1392103E-03,   1.3255453E-03
     +,   1.5612814E-03,   1.8576814E-03,   2.2259075E-03
     +,   2.6731582E-03,   3.2007012E-03,   3.8145669E-03
     +,   4.5554088E-03,   5.5292519E-03,   6.8967408E-03
     +,   8.7987771E-03,   1.1270706E-02,   1.4210932E-02
     +,   1.7289506E-02,   1.9860530E-02,   2.1690475E-02
     +,   2.3987669E-02,   2.8019203E-02,   3.2689150E-02
     +,   3.6073744E-02,   3.7744395E-02,   3.8196992E-02
     +,   3.7750181E-02,   3.5615247E-02,   3.1108223E-02
     +,   2.5064074E-02,   1.9388622E-02,   1.5585998E-02
     +,   1.3623351E-02,   1.2448051E-02,   1.1146922E-02
     +,   9.4858613E-03,   7.7155395E-03,   6.1379564E-03
     +,   4.8909527E-03,   3.9581121E-03,   3.2510054E-03
     +,   2.6782202E-03,   2.1796646E-03,   1.7310657E-03
     +,   1.3319493E-03,   9.9018274E-04,   7.1130862E-04
     +,   4.9460598E-04,   3.3379989E-04,   2.1949141E-04
     +,   1.4151281E-04,   9.0435140E-05,   5.8306854E-05
     +,   3.8890106E-05,   2.7594406E-05,   2.1238875E-05
     +,   1.7744056E-05,   1.5825673E-05,   1.4732675E-05
     +,   1.4047681E-05,   1.3549646E-05,   1.3126923E-05
     +,   1.2725984E-05,   1.2322946E-05,   1.1908387E-05
     +,   1.1479774E-05,   1.1037726E-05,   1.0584250E-05
     +,   1.0121869E-05,   9.6532958E-06,   9.1812817E-06
     +,   8.7085100E-06,   8.2375191E-06,   7.7706936E-06
     +,   7.3102965E-06,   6.8583972E-06,   6.4168530E-06
     +,   5.9873173E-06,   5.5712831E-06,   5.1699913E-06
     +,   4.7844824E-06,   4.4156222E-06,   4.0640734E-06
     +,   3.7302932E-06,   3.4145608E-06,   3.1170105E-06
     +,   2.8376230E-06,   2.5762197E-06,   2.3324981E-06
     +,   2.1060705E-06,   1.8964203E-06,   1.7029797E-06
     +,   1.5250866E-06,   1.3620491E-06,   1.2131125E-06
     +,   1.0775137E-06,   9.5445262E-07,   8.4313922E-07
     +,   7.4276983E-07,   6.5256319E-07,   5.7174549E-07
     +,   4.9956554E-07,   4.3530733E-07,   3.7827630E-07
     +,   3.2782035E-07,   2.8331678E-07,   2.4418699E-07
     +,   2.0988546E-07,   1.7991016E-07,   1.5379378E-07
     +,   1.3110994E-07,   1.1146586E-07,   9.4506611E-08
     +,   7.9908276E-08,   6.7380697E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz106 = Yx/0.1385
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.0504020E-07,   4.5097227E-07
     +,   5.0125828E-07,   5.5620455E-07,   6.1612701E-07
     +,   6.8135029E-07,   7.5220566E-07,   8.2903171E-07
     +,   9.1216907E-07,   1.0019666E-06,   1.0987696E-06
     +,   1.2029252E-06,   1.3147779E-06,   1.4346696E-06
     +,   1.5629336E-06,   1.6998982E-06,   1.8458815E-06
     +,   2.0011898E-06,   2.1661174E-06,   2.3409432E-06
     +,   2.5259333E-06,   2.7213343E-06,   2.9273747E-06
     +,   3.1442801E-06,   3.3722313E-06,   3.6114204E-06
     +,   3.8620087E-06,   4.1241451E-06,   4.3979694E-06
     +,   4.6836076E-06,   4.9811797E-06,   5.2908031E-06
     +,   5.6125914E-06,   5.9466656E-06,   6.2931472E-06
     +,   6.6521766E-06,   7.0239071E-06,   7.4085037E-06
     +,   7.8061848E-06,   8.2171509E-06,   8.6416776E-06
     +,   9.0800540E-06,   9.5326050E-06,   9.9996960E-06
     +,   1.0481733E-05,   1.0979145E-05,   1.1492410E-05
     +,   1.2022016E-05,   1.2568486E-05,   1.3132350E-05
     +,   1.3714143E-05,   1.4314394E-05,   1.4933594E-05
     +,   1.5572246E-05,   1.6230724E-05,   1.6909406E-05
     +,   1.7608534E-05,   1.8328261E-05,   1.9068599E-05
     +,   1.9829418E-05,   2.0610420E-05,   2.1411117E-05
     +,   2.2230779E-05,   2.3068515E-05,   2.3923183E-05
     +,   2.4793337E-05,   2.5677362E-05,   2.6573283E-05
     +,   2.7478969E-05,   2.8391931E-05,   2.9309542E-05
     +,   3.0228819E-05,   3.1146701E-05,   3.2059794E-05
     +,   3.2964646E-05,   3.3857672E-05,   3.4735145E-05
     +,   3.5593283E-05,   3.6428362E-05,   3.7236692E-05
     +,   3.8014627E-05,   3.8758742E-05,   3.9465729E-05
     +,   4.0132625E-05,   4.0756691E-05,   4.1335628E-05
     +,   4.1867464E-05,   4.2350726E-05,   4.2784395E-05
     +,   4.3168006E-05,   4.3501652E-05,   4.3785982E-05
     +,   4.4022265E-05,   4.4212393E-05,   4.4358902E-05
     +,   4.4464963E-05,   4.4534394E-05,   4.4571672E-05
     +,   4.4581961E-05,   4.4571047E-05,   4.4545421E-05
     +,   4.4512279E-05,   4.4479468E-05,   4.4455603E-05
     +,   4.4450026E-05,   4.4472868E-05,   4.4535056E-05
     +,   4.4648401E-05,   4.4825552E-05,   4.5080113E-05
     +,   4.5426586E-05,   4.5880410E-05,   4.6457932E-05
     +,   4.7176367E-05,   4.8053622E-05,   4.9108268E-05
     +,   5.0359195E-05,   5.1825537E-05,   5.3526008E-05
     +,   5.5478897E-05,   5.7701374E-05,   6.0208913E-05
     +,   6.3014646E-05,   6.6129105E-05,   6.9559326E-05
     +,   7.3307987E-05,   7.7373443E-05,   8.1748469E-05
     +,   8.6420681E-05,   9.1371243E-05,   9.6576077E-05
     +,   1.0200449E-04,   1.0762101E-04,   1.1338444E-04
     +,   1.1924993E-04,   1.2516943E-04,   1.3109253E-04
     +,   1.3696821E-04,   1.4274659E-04,   1.4838019E-04
     +,   1.5382511E-04,   1.5904277E-04,   1.6400163E-04
     +,   1.6867791E-04,   1.7305608E-04,   1.7713037E-04
     +,   1.8090443E-04,   1.8439132E-04,   1.8761329E-04
     +,   1.9060147E-04,   1.9339516E-04,   1.9604032E-04
     +,   1.9858971E-04,   2.0110169E-04,   2.0364023E-04
     +,   2.0627439E-04,   2.0907915E-04,   2.1213679E-04
     +,   2.1553879E-04,   2.1938790E-04,   2.2380288E-04
     +,   2.2892210E-04,   2.3490783E-04,   2.4195094E-04
     +,   2.5027423E-04,   2.6013379E-04,   2.7181476E-04
     +,   2.8562450E-04,   3.0187867E-04,   3.2087890E-04
     +,   3.4288157E-04,   3.6806235E-04,   3.9647947E-04
     +,   4.2803350E-04,   4.6243344E-04,   4.9918558E-04
     +,   5.3759495E-04,   5.7679060E-04,   6.1578443E-04
     +,   6.5355288E-04,   6.8913202E-04,   7.2171423E-04
     +,   7.5074600E-04,   7.7599712E-04,   7.9760130E-04
     +,   8.1607007E-04,   8.3230401E-04,   8.4763020E-04
     +,   8.6390594E-04,   8.8372192E-04,   9.1070030E-04
     +,   9.4982522E-04,   1.0077199E-03,   1.0928287E-03
     +,   1.2155654E-03,   1.3885553E-03,   1.6269897E-03
     +,   1.9487996E-03,   2.3737655E-03,   2.9205654E-03
     +,   3.6023366E-03,   4.4245268E-03,   5.3909216E-03
     +,   6.5212664E-03,   7.8728097E-03,   9.5453076E-03
     +,   1.1680690E-02,   1.4537059E-02,   1.8524997E-02
     +,   2.3679903E-02,   2.8938673E-02,   3.2771531E-02
     +,   3.5164528E-02,   3.8460549E-02,   4.2670231E-02
     +,   4.4575393E-02,   4.3268397E-02,   3.8529161E-02
     +,   3.1015042E-02,   2.3419147E-02,   1.7442625E-02
     +,   1.3231958E-02,   1.0559470E-02,   8.7896669E-03
     +,   7.2723357E-03,   5.8264299E-03,   4.5360541E-03
     +,   3.4656404E-03,   2.6131619E-03,   1.9510358E-03
     +,   1.4471607E-03,   1.0692583E-03,   7.8786223E-04
     +,   5.7859957E-04,   4.2262606E-04,   3.0600902E-04
     +,   2.1880552E-04,   1.5397050E-04,   1.0635145E-04
     +,   7.1979841E-05,   4.7679820E-05,   3.0884014E-05
     +,   1.9544470E-05,   1.2070980E-05,   7.2669991E-06
     +,   4.2589477E-06,   2.4268065E-06,   1.3428934E-06
     +,   7.2092462E-07,   3.7520610E-07,   1.8920802E-07
     +,   9.2414098E-08,   4.3711331E-08,   2.0021151E-08
     +,   8.8801944E-09,   3.8143919E-09,   1.5870387E-09
     +,   6.3982775E-10,   2.5009828E-10,   9.4901871E-11
     +,   3.5057384E-11,   1.2685323E-11,   4.5564646E-12
     +,   1.6699450E-12,   6.5594367E-13,   2.9414746E-13
     +,   1.5644326E-13,   9.6622444E-14,   6.5554150E-14
     +,   4.6600815E-14,   3.3799620E-14,   2.4710738E-14
     +,   1.8120234E-14,   1.3302228E-14,   9.7695128E-15
     +,   7.1766823E-15,   5.2727826E-15,   3.8745371E-15
     +,   2.8474114E-15,   2.0928130E-15,   1.5382984E-15
     +,   1.1307633E-15,   8.3117628E-16,   6.1092887E-16
     +,   4.4898077E-16,   3.2989985E-16,   2.4233636E-16
     +,   1.7795039E-16,   1.3061632E-16,   9.5823256E-17
     +,   7.0257724E-17,   5.1478222E-17,   3.7690696E-17
     +,   2.7573075E-17,   2.0153693E-17,   1.4716453E-17
     +,   1.0735224E-17,   7.8224725E-18,   5.6935685E-18
     +,   4.1390501E-18,   3.0052404E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz108 = Yx/0.1365
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.6847654E-07,   5.1584288E-07
     +,   5.6724986E-07,   6.2295948E-07,   6.8324204E-07
     +,   7.4837595E-07,   8.1864692E-07,   8.9434695E-07
     +,   9.7577242E-07,   1.0632286E-06,   1.1570201E-06
     +,   1.2574558E-06,   1.3648449E-06,   1.4794970E-06
     +,   1.6017201E-06,   1.7318185E-06,   1.8700919E-06
     +,   2.0168338E-06,   2.1723285E-06,   2.3368520E-06
     +,   2.5106665E-06,   2.6940215E-06,   2.8871482E-06
     +,   3.0902718E-06,   3.3035781E-06,   3.5272533E-06
     +,   3.7614495E-06,   4.0062973E-06,   4.2619026E-06
     +,   4.5283459E-06,   4.8056781E-06,   5.0939252E-06
     +,   5.3930844E-06,   5.7031211E-06,   6.0239759E-06
     +,   6.3555567E-06,   6.6977482E-06,   7.0503988E-06
     +,   7.4133586E-06,   7.7864097E-06,   8.1693561E-06
     +,   8.5619595E-06,   8.9639752E-06,   9.3751396E-06
     +,   9.7951879E-06,   1.0223855E-05,   1.0660873E-05
     +,   1.1105990E-05,   1.1558967E-05,   1.2019591E-05
     +,   1.2487685E-05,   1.2963113E-05,   1.3445788E-05
     +,   1.3935724E-05,   1.4432959E-05,   1.4937687E-05
     +,   1.5450183E-05,   1.5970863E-05,   1.6500300E-05
     +,   1.7039243E-05,   1.7588645E-05,   1.8149693E-05
     +,   1.8723798E-05,   1.9312703E-05,   1.9918474E-05
     +,   2.0543455E-05,   2.1190464E-05,   2.1862632E-05
     +,   2.2563627E-05,   2.3297478E-05,   2.4068795E-05
     +,   2.4882567E-05,   2.5744406E-05,   2.6660282E-05
     +,   2.7636723E-05,   2.8680704E-05,   2.9799519E-05
     +,   3.1000753E-05,   3.2292297E-05,   3.3682165E-05
     +,   3.5178222E-05,   3.6788315E-05,   3.8519767E-05
     +,   4.0379564E-05,   4.2373693E-05,   4.4507400E-05
     +,   4.6784466E-05,   4.9207487E-05,   5.1777064E-05
     +,   5.4492124E-05,   5.7349513E-05,   6.0343576E-05
     +,   6.3466243E-05,   6.6707093E-05,   7.0053124E-05
     +,   7.3488474E-05,   7.6995151E-05,   8.0552491E-05
     +,   8.4138024E-05,   8.7726919E-05,   9.1293427E-05
     +,   9.4810057E-05,   9.8249177E-05,   1.0158253E-04
     +,   1.0478255E-04,   1.0782263E-04,   1.1067740E-04
     +,   1.1332363E-04,   1.1574090E-04,   1.1791182E-04
     +,   1.1982246E-04,   1.2146313E-04,   1.2282823E-04
     +,   1.2391704E-04,   1.2473340E-04,   1.2528629E-04
     +,   1.2558945E-04,   1.2566164E-04,   1.2552628E-04
     +,   1.2521137E-04,   1.2474907E-04,   1.2417554E-04
     +,   1.2353035E-04,   1.2285598E-04,   1.2219737E-04
     +,   1.2160122E-04,   1.2111521E-04,   1.2078747E-04
     +,   1.2066542E-04,   1.2079502E-04,   1.2121980E-04
     +,   1.2197957E-04,   1.2310960E-04,   1.2463907E-04
     +,   1.2659034E-04,   1.2897754E-04,   1.3180546E-04
     +,   1.3506868E-04,   1.3875110E-04,   1.4282516E-04
     +,   1.4725162E-04,   1.5197956E-04,   1.5694773E-04
     +,   1.6208505E-04,   1.6731159E-04,   1.7254158E-04
     +,   1.7768510E-04,   1.8265088E-04,   1.8734930E-04
     +,   1.9169624E-04,   1.9561625E-04,   1.9904539E-04
     +,   2.0193546E-04,   2.0425694E-04,   2.0600187E-04
     +,   2.0718588E-04,   2.0785071E-04,   2.0806515E-04
     +,   2.0792580E-04,   2.0755670E-04,   2.0710845E-04
     +,   2.0675581E-04,   2.0669478E-04,   2.0713785E-04
     +,   2.0830856E-04,   2.1043434E-04,   2.1373831E-04
     +,   2.1842975E-04,   2.2469441E-04,   2.3268411E-04
     +,   2.4250595E-04,   2.5421343E-04,   2.6780021E-04
     +,   2.8319572E-04,   3.0026189E-04,   3.1880059E-04
     +,   3.3855991E-04,   3.5924534E-04,   3.8053718E-04
     +,   4.0211200E-04,   4.2366085E-04,   4.4490941E-04
     +,   4.6563742E-04,   4.8569537E-04,   5.0501502E-04
     +,   5.2361429E-04,   5.4160174E-04,   5.5917632E-04
     +,   5.7662092E-04,   5.9428893E-04,   6.1259279E-04
     +,   6.3198060E-04,   6.5291557E-04,   6.7586818E-04
     +,   7.0134056E-04,   7.2994450E-04,   7.6258095E-04
     +,   8.0081553E-04,   8.4762316E-04,   9.0873538E-04
     +,   9.9468301E-04,   1.1231879E-03,   1.3214827E-03
     +,   1.6294472E-03,   2.1053818E-03,   2.8307424E-03
     +,   3.8986481E-03,   5.3786212E-03,   7.2910837E-03
     +,   9.6327756E-03,   1.2412765E-02,   1.5647866E-02
     +,   1.9378051E-02,   2.3643708E-02,   2.8213091E-02
     +,   3.2423187E-02,   3.5645578E-02,   3.7730161E-02
     +,   3.8905054E-02,   3.9075818E-02,   3.7588708E-02
     +,   3.4192950E-02,   2.9381434E-02,   2.3921000E-02
     +,   1.8616108E-02,   1.3984163E-02,   1.0234753E-02
     +,   7.4737840E-03,   5.5736252E-03,   4.2003538E-03
     +,   3.0950517E-03,   2.1817628E-03,   1.4699444E-03
     +,   9.5807662E-04,   6.1464001E-04,   3.9639571E-04
     +,   2.6416901E-04,   1.8782991E-04,   1.4586595E-04
     +,   1.2372599E-04,   1.1214727E-04,   1.0563495E-04
     +,   1.0117570E-04,   9.7258038E-05,   9.3206625E-05
     +,   8.8776695E-05,   8.3929677E-05,   7.8718542E-05
     +,   7.3233467E-05,   6.7577137E-05,   6.1851926E-05
     +,   5.6154291E-05,   5.0571762E-05,   4.5180434E-05
     +,   4.0043287E-05,   3.5210087E-05,   3.0717667E-05
     +,   2.6590151E-05,   2.2839649E-05,   1.9467941E-05
     +,   1.6468111E-05,   1.3825910E-05,   1.1521240E-05
     +,   9.5299338E-06,   7.8253679E-06,   6.3793395E-06
     +,   5.1633874E-06,   4.1497347E-06,   3.3118597E-06
     +,   2.6249602E-06,   2.0663576E-06,   1.6156960E-06
     +,   1.2549440E-06,   9.6834765E-07,   7.4235282E-07
     +,   5.6545986E-07,   4.2798575E-07,   3.2190687E-07
     +,   2.4061583E-07,   1.7874942E-07,   1.3197931E-07
     +,   9.6858436E-08,   7.0655794E-08,   5.1234302E-08
     +,   3.6930029E-08,   2.6461963E-08,   1.8849088E-08
     +,   1.3346964E-08,   9.3952606E-09,   6.5744237E-09
     +,   4.5733506E-09,   3.1624379E-09,   2.1738131E-09
     +,   1.4852952E-09,   1.0087734E-09,   6.8098754E-10
     +,   4.5692536E-10,   3.0470948E-10,   2.0195511E-10
     +,   1.3302226E-10,   8.7073904E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz110 = Yx/0.126833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0366103E-06,   1.1364834E-06
     +,   1.2441473E-06,   1.3600136E-06,   1.4844944E-06
     +,   1.6180016E-06,   1.7609448E-06,   1.9137281E-06
     +,   2.0767450E-06,   2.2503878E-06,   2.4350252E-06
     +,   2.6310122E-06,   2.8386853E-06,   3.0583565E-06
     +,   3.2903115E-06,   3.5348064E-06,   3.7920624E-06
     +,   4.0622676E-06,   4.3455657E-06,   4.6420591E-06
     +,   4.9518062E-06,   5.2748096E-06,   5.6110216E-06
     +,   5.9603567E-06,   6.3226353E-06,   6.6976581E-06
     +,   7.0851420E-06,   7.4847453E-06,   7.8960675E-06
     +,   8.3186405E-06,   8.7519347E-06,   9.1953516E-06
     +,   9.6482399E-06,   1.0109877E-05,   1.0579485E-05
     +,   1.1056227E-05,   1.1539211E-05,   1.2027489E-05
     +,   1.2520091E-05,   1.3015952E-05,   1.3514026E-05
     +,   1.4013192E-05,   1.4512319E-05,   1.5010242E-05
     +,   1.5505795E-05,   1.5997786E-05,   1.6485033E-05
     +,   1.6966347E-05,   1.7440560E-05,   1.7906512E-05
     +,   1.8363076E-05,   1.8809160E-05,   1.9243693E-05
     +,   1.9665697E-05,   2.0074187E-05,   2.0468291E-05
     +,   2.0847188E-05,   2.1210135E-05,   2.1556474E-05
     +,   2.1885637E-05,   2.2197157E-05,   2.2490685E-05
     +,   2.2765955E-05,   2.3022858E-05,   2.3261407E-05
     +,   2.3481734E-05,   2.3684139E-05,   2.3869068E-05
     +,   2.4037145E-05,   2.4189154E-05,   2.4326093E-05
     +,   2.4449140E-05,   2.4559704E-05,   2.4659415E-05
     +,   2.4750152E-05,   2.4834048E-05,   2.4913517E-05
     +,   2.4991248E-05,   2.5070258E-05,   2.5153853E-05
     +,   2.5245685E-05,   2.5349742E-05,   2.5470345E-05
     +,   2.5612168E-05,   2.5780228E-05,   2.5979867E-05
     +,   2.6216743E-05,   2.6496817E-05,   2.6826292E-05
     +,   2.7211590E-05,   2.7659318E-05,   2.8176149E-05
     +,   2.8768767E-05,   2.9443821E-05,   3.0207810E-05
     +,   3.1066887E-05,   3.2026917E-05,   3.3093133E-05
     +,   3.4270259E-05,   3.5562094E-05,   3.6971680E-05
     +,   3.8500857E-05,   4.0150484E-05,   4.1919920E-05
     +,   4.3807318E-05,   4.5809382E-05,   4.7921141E-05
     +,   5.0136096E-05,   5.2446263E-05,   5.4842130E-05
     +,   5.7312482E-05,   5.9844970E-05,   6.2425628E-05
     +,   6.5039720E-05,   6.7671150E-05,   7.0303453E-05
     +,   7.2919298E-05,   7.5501455E-05,   7.8032390E-05
     +,   8.0495120E-05,   8.2873266E-05,   8.5151201E-05
     +,   8.7314445E-05,   8.9350193E-05,   9.1247268E-05
     +,   9.2996270E-05,   9.4590170E-05,   9.6024029E-05
     +,   9.7295560E-05,   9.8404875E-05,   9.9354802E-05
     +,   1.0015081E-04,   1.0080110E-04,   1.0131652E-04
     +,   1.0171062E-04,   1.0199959E-04,   1.0220216E-04
     +,   1.0233970E-04,   1.0243600E-04,   1.0251734E-04
     +,   1.0261247E-04,   1.0275256E-04,   1.0297115E-04
     +,   1.0330418E-04,   1.0378992E-04,   1.0446893E-04
     +,   1.0538405E-04,   1.0658006E-04,   1.0810362E-04
     +,   1.1000291E-04,   1.1232724E-04,   1.1512629E-04
     +,   1.1844932E-04,   1.2234449E-04,   1.2685775E-04
     +,   1.3203091E-04,   1.3790051E-04,   1.4449649E-04
     +,   1.5184011E-04,   1.5994154E-04,   1.6879945E-04
     +,   1.7839871E-04,   1.8870889E-04,   1.9968365E-04
     +,   2.1126153E-04,   2.2336615E-04,   2.3590645E-04
     +,   2.4878021E-04,   2.6187810E-04,   2.7508731E-04
     +,   2.8829571E-04,   3.0139854E-04,   3.1430522E-04
     +,   3.2694501E-04,   3.3927156E-04,   3.5127142E-04
     +,   3.6296845E-04,   3.7442811E-04,   3.8576336E-04
     +,   3.9714127E-04,   4.0878690E-04,   4.2098845E-04
     +,   4.3410243E-04,   4.4855621E-04,   4.6484452E-04
     +,   4.8351684E-04,   5.0515553E-04,   5.3034088E-04
     +,   5.5959896E-04,   5.9333525E-04,   6.3176791E-04
     +,   6.7485502E-04,   7.2223326E-04,   7.7318260E-04
     +,   8.2662673E-04,   8.8116870E-04,   9.3517906E-04
     +,   9.8697317E-04,   1.0351195E-03,   1.0789740E-03
     +,   1.1195715E-03,   1.1609901E-03,   1.2120812E-03
     +,   1.2880015E-03,   1.4103323E-03,   1.6042712E-03
     +,   1.8924477E-03,   2.2881452E-03,   2.7942394E-03
     +,   3.4116874E-03,   4.1490798E-03,   5.0191297E-03
     +,   6.0463287E-03,   7.3466399E-03,   9.2033567E-03
     +,   1.1945456E-02,   1.5755864E-02,   2.0588478E-02
     +,   2.6162889E-02,   3.2491270E-02,   3.9743807E-02
     +,   4.6203982E-02,   4.9487606E-02,   4.7743354E-02
     +,   4.0184047E-02,   3.0465869E-02,   2.2800235E-02
     +,   1.7592831E-02,   1.3365699E-02,   9.4773760E-03
     +,   6.1320118E-03,   3.5713448E-03,   1.8600997E-03
     +,   8.8147767E-04,   4.0384883E-04,   2.0198489E-04
     +,   1.2612437E-04,   9.9742283E-05,   9.0519694E-05
     +,   8.6439286E-05,   8.3411214E-05,   8.0218007E-05
     +,   7.6638920E-05,   7.2767914E-05,   6.8773341E-05
     +,   6.4817548E-05,   6.1030361E-05,   5.7501271E-05
     +,   5.4280004E-05,   5.1381674E-05,   4.8793481E-05
     +,   4.6483536E-05,   4.4409211E-05,   4.2524076E-05
     +,   4.0783252E-05,   3.9147162E-05,   3.7583632E-05
     +,   3.6068333E-05,   3.4584322E-05,   3.3121167E-05
     +,   3.1673764E-05,   3.0240932E-05,   2.8824086E-05
     +,   2.7426391E-05,   2.6052037E-05,   2.4705414E-05
     +,   2.3390829E-05,   2.2112321E-05,   2.0873407E-05
     +,   1.9676943E-05,   1.8525156E-05,   1.7419748E-05
     +,   1.6361837E-05,   1.5351949E-05,   1.4390125E-05
     +,   1.3476105E-05,   1.2609141E-05,   1.1788300E-05
     +,   1.1012305E-05,   1.0279789E-05,   9.5891346E-06
     +,   8.9387240E-06,   8.3267751E-06,   7.7515570E-06
     +,   7.2112562E-06,   6.7041374E-06,   6.2284471E-06
     +,   5.7824814E-06,   5.3646354E-06,   4.9733108E-06
     +,   4.6070327E-06,   4.2643433E-06,   3.9439078E-06
     +,   3.6444196E-06,   3.3646829E-06,   3.1035315E-06
     +,   2.8598997E-06,   2.6327507E-06,   2.4211379E-06
     +,   2.2241384E-06,   2.0409075E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz112 = Yx/0.12019512195122
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0347552E-06,   1.9411912E-06
     +,   1.8543733E-06,   1.7743566E-06,   1.7011887E-06
     +,   1.6349127E-06,   1.5755693E-06,   1.5231971E-06
     +,   1.4778345E-06,   1.4395191E-06,   1.4082914E-06
     +,   1.3841949E-06,   1.3672762E-06,   1.3575880E-06
     +,   1.3551878E-06,   1.3601410E-06,   1.3725200E-06
     +,   1.3924061E-06,   1.4198897E-06,   1.4550708E-06
     +,   1.4980617E-06,   1.5489837E-06,   1.6079707E-06
     +,   1.6751724E-06,   1.7507441E-06,   1.8348618E-06
     +,   1.9277109E-06,   2.0294929E-06,   2.1404214E-06
     +,   2.2607271E-06,   2.3906539E-06,   2.5304614E-06
     +,   2.6804230E-06,   2.8408290E-06,   3.0119832E-06
     +,   3.1942050E-06,   3.3878282E-06,   3.5931973E-06
     +,   3.8106841E-06,   4.0406503E-06,   4.2834918E-06
     +,   4.5396064E-06,   4.8094016E-06,   5.0932958E-06
     +,   5.3917151E-06,   5.7050906E-06,   6.0338584E-06
     +,   6.3784541E-06,   6.7393166E-06,   7.1168784E-06
     +,   7.5115668E-06,   7.9237998E-06,   8.3539771E-06
     +,   8.8025081E-06,   9.2697337E-06,   9.7560260E-06
     +,   1.0261693E-05,   1.0787026E-05,   1.1332276E-05
     +,   1.1897658E-05,   1.2483344E-05,   1.3089471E-05
     +,   1.3716083E-05,   1.4363222E-05,   1.5030880E-05
     +,   1.5718924E-05,   1.6427255E-05,   1.7155622E-05
     +,   1.7903807E-05,   1.8671439E-05,   1.9458190E-05
     +,   2.0263580E-05,   2.1087177E-05,   2.1928403E-05
     +,   2.2786717E-05,   2.3661552E-05,   2.4552255E-05
     +,   2.5458161E-05,   2.6378642E-05,   2.7313095E-05
     +,   2.8260820E-05,   2.9221274E-05,   3.0193816E-05
     +,   3.1177995E-05,   3.2173262E-05,   3.3179294E-05
     +,   3.4195687E-05,   3.5222271E-05,   3.6258825E-05
     +,   3.7305337E-05,   3.8361886E-05,   3.9428585E-05
     +,   4.0505656E-05,   4.1593481E-05,   4.2692533E-05
     +,   4.3803266E-05,   4.4926339E-05,   4.6062320E-05
     +,   4.7211961E-05,   4.8375878E-05,   4.9554834E-05
     +,   5.0749393E-05,   5.1960189E-05,   5.3187643E-05
     +,   5.4432141E-05,   5.5693898E-05,   5.6972880E-05
     +,   5.8268779E-05,   5.9581162E-05,   6.0909268E-05
     +,   6.2251900E-05,   6.3607687E-05,   6.4974724E-05
     +,   6.6350913E-05,   6.7733534E-05,   6.9119720E-05
     +,   7.0506016E-05,   7.1888688E-05,   7.3263553E-05
     +,   7.4626143E-05,   7.5971708E-05,   7.7295124E-05
     +,   7.8591052E-05,   7.9854050E-05,   8.1078586E-05
     +,   8.2258979E-05,   8.3389685E-05,   8.4465217E-05
     +,   8.5480402E-05,   8.6430264E-05,   8.7310327E-05
     +,   8.8116547E-05,   8.8845598E-05,   8.9494759E-05
     +,   9.0062218E-05,   9.0547073E-05,   9.0949419E-05
     +,   9.1270485E-05,   9.1512702E-05,   9.1679838E-05
     +,   9.1776972E-05,   9.1810580E-05,   9.1788716E-05
     +,   9.1720824E-05,   9.1617963E-05,   9.1492693E-05
     +,   9.1359048E-05,   9.1232621E-05,   9.1130387E-05
     +,   9.1070659E-05,   9.1072965E-05,   9.1157999E-05
     +,   9.1347414E-05,   9.1663562E-05,   9.2129500E-05
     +,   9.2768576E-05,   9.3604278E-05,   9.4660034E-05
     +,   9.5959011E-05,   9.7523691E-05,   9.9376048E-05
     +,   1.0153734E-04,   1.0402808E-04,   1.0686828E-04
     +,   1.1007825E-04,   1.1367924E-04,   1.1769452E-04
     +,   1.2215110E-04,   1.2708276E-04,   1.3253254E-04
     +,   1.3855634E-04,   1.4522743E-04,   1.5264211E-04
     +,   1.6092474E-04,   1.7023202E-04,   1.8075957E-04
     +,   1.9274429E-04,   2.0646515E-04,   2.2224089E-04
     +,   2.4042599E-04,   2.6139908E-04,   2.8554699E-04
     +,   3.1324808E-04,   3.4485591E-04,   3.8068320E-04
     +,   4.2099043E-04,   4.6599051E-04,   5.1586778E-04
     +,   5.7080353E-04,   6.3099881E-04,   6.9670641E-04
     +,   7.6822139E-04,   8.4582681E-04,   9.2971162E-04
     +,   1.0198591E-03,   1.1159419E-03,   1.2172883E-03
     +,   1.3229797E-03,   1.4320926E-03,   1.5440142E-03
     +,   1.6587438E-03,   1.7770866E-03,   1.9006501E-03
     +,   2.0316804E-03,   2.1728622E-03,   2.3272743E-03
     +,   2.4984949E-03,   2.6907600E-03,   2.9088357E-03
     +,   3.1581558E-03,   3.4494398E-03,   3.8157832E-03
     +,   4.3396796E-03,   5.1539405E-03,   6.3653863E-03
     +,   7.9393648E-03,   9.7309100E-03,   1.1750706E-02
     +,   1.4418828E-02,   1.8623391E-02,   2.5432948E-02
     +,   3.4721833E-02,   4.3615967E-02,   4.8235446E-02
     +,   4.7664672E-02,   4.3821990E-02,   3.8027789E-02
     +,   3.0603020E-02,   2.2395112E-02,   1.4759028E-02
     +,   8.7406011E-03,   4.6799360E-03,   2.3094858E-03
     +,   1.0897334E-03,   5.2337145E-04,   2.7975760E-04
     +,   1.7850818E-04,   1.3583175E-04,   1.1717020E-04
     +,   1.0828420E-04,   1.0281270E-04,   9.7988239E-05
     +,   9.2889743E-05,   8.7452958E-05,   8.1913582E-05
     +,   7.6544457E-05,   7.1554117E-05,   6.7059933E-05
     +,   6.3094070E-05,   5.9623217E-05,   5.6571720E-05
     +,   5.3844891E-05,   5.1347426E-05,   4.8995538E-05
     +,   4.6723304E-05,   4.4484583E-05,   4.2251686E-05
     +,   4.0011964E-05,   3.7763966E-05,   3.5513913E-05
     +,   3.3272874E-05,   3.1054278E-05,   2.8872124E-05
     +,   2.6740016E-05,   2.4670675E-05,   2.2675098E-05
     +,   2.0762580E-05,   1.8940738E-05,   1.7215385E-05
     +,   1.5590498E-05,   1.4068449E-05,   1.2650228E-05
     +,   1.1335476E-05,   1.0122583E-05,   9.0089379E-06
     +,   7.9912088E-06,   7.0652395E-06,   6.2264785E-06
     +,   5.4698821E-06,   4.7902513E-06,   4.1821654E-06
     +,   3.6402453E-06,   3.1590939E-06,   2.7335022E-06
     +,   2.3583877E-06,   2.0289458E-06,   1.7405979E-06
     +,   1.4890559E-06,   1.2703549E-06,   1.0808049E-06
     +,   9.1704686E-07,   7.7599896E-07,   6.5488820E-07
     +,   5.5120051E-07,   4.6269665E-07,   3.8736829E-07
     +,   3.2344306E-07,   2.6934632E-07,   2.2370018E-07
     +,   1.8529104E-07,   1.5306493E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz113 = Yx/0.117292682926829
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3893592E-09,   1.7783571E-09
     +,   2.2697035E-09,   2.8884188E-09,   3.6650996E-09
     +,   4.6370476E-09,   5.8495484E-09,   7.3573903E-09
     +,   9.2265742E-09,   1.1536432E-08,   1.4381743E-08
     +,   1.7875482E-08,   2.2151699E-08,   2.7368833E-08
     +,   3.3713430E-08,   4.1404242E-08,   5.0696666E-08
     +,   6.1887746E-08,   7.5321509E-08,   9.1394568E-08
     +,   1.1056238E-07,   1.3334559E-07,   1.6033620E-07
     +,   1.9220680E-07,   2.2971226E-07,   2.7370371E-07
     +,   3.2512941E-07,   3.8504382E-07,   4.5461314E-07
     +,   5.3512014E-07,   6.2796801E-07,   7.3468414E-07
     +,   8.5692079E-07,   9.9645411E-07,   1.1551828E-06
     +,   1.3351226E-06,   1.5383989E-06,   1.7672313E-06
     +,   2.0239418E-06,   2.3108921E-06,   2.6305215E-06
     +,   2.9852763E-06,   3.3776041E-06,   3.8099167E-06
     +,   4.2845591E-06,   4.8037678E-06,   5.3696344E-06
     +,   5.9840595E-06,   6.6487123E-06,   7.3649790E-06
     +,   8.1339267E-06,   8.9562463E-06,   9.8322071E-06
     +,   1.0761674E-05,   1.1743922E-05,   1.2777805E-05
     +,   1.3861563E-05,   1.4992873E-05,   1.6168826E-05
     +,   1.7385926E-05,   1.8640083E-05,   1.9926652E-05
     +,   2.1240354E-05,   2.2575497E-05,   2.3925921E-05
     +,   2.5284911E-05,   2.6645574E-05,   2.8000555E-05
     +,   2.9342475E-05,   3.0663643E-05,   3.1956537E-05
     +,   3.3213521E-05,   3.4427278E-05,   3.5590609E-05
     +,   3.6696765E-05,   3.7739446E-05,   3.8712813E-05
     +,   3.9611627E-05,   4.0431398E-05,   4.1168340E-05
     +,   4.1819407E-05,   4.2382413E-05,   4.2855958E-05
     +,   4.3239535E-05,   4.3533437E-05,   4.3738772E-05
     +,   4.3857432E-05,   4.3892065E-05,   4.3845965E-05
     +,   4.3723077E-05,   4.3527856E-05,   4.3265234E-05
     +,   4.2940541E-05,   4.2559353E-05,   4.2127464E-05
     +,   4.1650808E-05,   4.1135299E-05,   4.0586870E-05
     +,   4.0011248E-05,   3.9414037E-05,   3.8800532E-05
     +,   3.8175775E-05,   3.7544436E-05,   3.6910820E-05
     +,   3.6278849E-05,   3.5651999E-05,   3.5033394E-05
     +,   3.4425775E-05,   3.3831457E-05,   3.3252421E-05
     +,   3.2690390E-05,   3.2146741E-05,   3.1622709E-05
     +,   3.1119289E-05,   3.0637442E-05,   3.0178018E-05
     +,   2.9741943E-05,   2.9330180E-05,   2.8943894E-05
     +,   2.8584451E-05,   2.8253522E-05,   2.7953147E-05
     +,   2.7685828E-05,   2.7454533E-05,   2.7262815E-05
     +,   2.7114864E-05,   2.7015538E-05,   2.6970409E-05
     +,   2.6985803E-05,   2.7068814E-05,   2.7227303E-05
     +,   2.7469860E-05,   2.7805796E-05,   2.8245024E-05
     +,   2.8798004E-05,   2.9475601E-05,   3.0288891E-05
     +,   3.1248928E-05,   3.2366621E-05,   3.3652439E-05
     +,   3.5115969E-05,   3.6765687E-05,   3.8608749E-05
     +,   4.0650517E-05,   4.2894091E-05,   4.5340294E-05
     +,   4.7987280E-05,   5.0830095E-05,   5.3860662E-05
     +,   5.7067944E-05,   6.0437837E-05,   6.3953041E-05
     +,   6.7593675E-05,   7.1337869E-05,   7.5162301E-05
     +,   7.9042649E-05,   8.2954786E-05,   8.6876156E-05
     +,   9.0786889E-05,   9.4670533E-05,   9.8516532E-05
     +,   1.0232131E-04,   1.0608957E-04,   1.0983610E-04
     +,   1.1358765E-04,   1.1738400E-04,   1.2127890E-04
     +,   1.2534132E-04,   1.2965593E-04,   1.3432282E-04
     +,   1.3945629E-04,   1.4518258E-04,   1.5163748E-04
     +,   1.5896086E-04,   1.6728981E-04,   1.7675231E-04
     +,   1.8745764E-04,   1.9948617E-04,   2.1288004E-04
     +,   2.2763608E-04,   2.4369868E-04,   2.6095632E-04
     +,   2.7924520E-04,   2.9835905E-04,   3.1806348E-04
     +,   3.3811730E-04,   3.5830287E-04,   3.7846321E-04
     +,   3.9854136E-04,   4.1862400E-04,   4.3899473E-04
     +,   4.6018511E-04,   4.8302670E-04,   5.0870137E-04
     +,   5.3877535E-04,   5.7519390E-04,   6.2021305E-04
     +,   6.7623187E-04,   7.4550457E-04,   8.2970085E-04
     +,   9.2935882E-04,   1.0433445E-03,   1.1685194E-03
     +,   1.2998523E-03,   1.4312366E-03,   1.5571686E-03
     +,   1.6750754E-03,   1.7878896E-03,   1.9062110E-03
     +,   2.0494391E-03,   2.2459498E-03,   2.5330104E-03
     +,   2.9556660E-03,   3.5616057E-03,   4.3957569E-03
     +,   5.5115409E-03,   6.9847042E-03,   8.8435942E-03
     +,   1.0959213E-02,   1.3305534E-02,   1.6602013E-02
     +,   2.1812312E-02,   2.8025839E-02,   3.3741370E-02
     +,   4.1617632E-02,   5.1492844E-02,   5.5289786E-02
     +,   4.9962156E-02,   3.9511044E-02,   2.8460018E-02
     +,   1.8786265E-02,   1.1020405E-02,   5.6424844E-03
     +,   2.6225063E-03,   1.2628731E-03,   7.1596593E-04
     +,   4.6025499E-04,   3.0638155E-04,   2.0862921E-04
     +,   1.5083438E-04,   1.1884244E-04,   1.0116320E-04
     +,   9.0492795E-05,   8.2898077E-05,   7.6504970E-05
     +,   7.0551134E-05,   6.4820058E-05,   5.9321785E-05
     +,   5.4127464E-05,   4.9297025E-05,   4.4856119E-05
     +,   4.0798110E-05,   3.7094091E-05,   3.3703589E-05
     +,   3.0583622E-05,   2.7695296E-05,   2.5007470E-05
     +,   2.2497583E-05,   2.0150905E-05,   1.7959119E-05
     +,   1.5918486E-05,   1.4027755E-05,   1.2286433E-05
     +,   1.0693739E-05,   9.2479677E-06,   7.9457795E-06
     +,   6.7822430E-06,   5.7510138E-06,   4.8444390E-06
     +,   4.0538152E-06,   3.3697766E-06,   2.7826427E-06
     +,   2.2826337E-06,   1.8600997E-06,   1.5057609E-06
     +,   1.2108862E-06,   9.6732913E-07,   7.6767429E-07
     +,   6.0521126E-07,   4.7399504E-07,   3.6878393E-07
     +,   2.8504360E-07,   2.1887027E-07,   1.6695837E-07
     +,   1.2652323E-07,   9.5254030E-08,   7.1243619E-08
     +,   5.2936635E-08,   3.9077374E-08,   2.8658061E-08
     +,   2.0880082E-08,   1.5113837E-08,   1.0868932E-08
     +,   7.7653537E-09,   5.5120077E-09,   3.8871018E-09
     +,   2.7234635E-09,   1.8957869E-09,   1.3111203E-09
     +,   9.0089236E-10,   6.1502531E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz114 = Yx/0.116951219512195
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7568195E-06,   4.1475710E-06
     +,   4.5696324E-06,   5.0243802E-06,   5.5131241E-06
     +,   6.0370880E-06,   6.5973886E-06,   7.1950217E-06
     +,   7.8308303E-06,   8.5055317E-06,   9.2196260E-06
     +,   9.9734389E-06,   1.0767077E-05,   1.1600422E-05
     +,   1.2473115E-05,   1.3384549E-05,   1.4333851E-05
     +,   1.5319878E-05,   1.6341230E-05,   1.7396213E-05
     +,   1.8482880E-05,   1.9599011E-05,   2.0742129E-05
     +,   2.1909578E-05,   2.3098357E-05,   2.4305396E-05
     +,   2.5527384E-05,   2.6760870E-05,   2.8002298E-05
     +,   2.9248038E-05,   3.0494417E-05,   3.1737760E-05
     +,   3.2974447E-05,   3.4200937E-05,   3.5413806E-05
     +,   3.6609807E-05,   3.7785907E-05,   3.8939306E-05
     +,   4.0067553E-05,   4.1168409E-05,   4.2240092E-05
     +,   4.3281139E-05,   4.4290493E-05,   4.5267490E-05
     +,   4.6211910E-05,   4.7123940E-05,   4.8004164E-05
     +,   4.8853581E-05,   4.9673559E-05,   5.0465820E-05
     +,   5.1232419E-05,   5.1975669E-05,   5.2698128E-05
     +,   5.3402557E-05,   5.4091812E-05,   5.4768880E-05
     +,   5.5436714E-05,   5.6098244E-05,   5.6756297E-05
     +,   5.7413548E-05,   5.8072423E-05,   5.8735091E-05
     +,   5.9403363E-05,   6.0078724E-05,   6.0762235E-05
     +,   6.1454448E-05,   6.2155545E-05,   6.2865103E-05
     +,   6.3582302E-05,   6.4305743E-05,   6.5033601E-05
     +,   6.5763488E-05,   6.6492692E-05,   6.7217923E-05
     +,   6.7935667E-05,   6.8642003E-05,   6.9332760E-05
     +,   7.0003502E-05,   7.0649723E-05,   7.1266804E-05
     +,   7.1850096E-05,   7.2395036E-05,   7.2897150E-05
     +,   7.3352225E-05,   7.3756259E-05,   7.4105621E-05
     +,   7.4397045E-05,   7.4627758E-05,   7.4795447E-05
     +,   7.4898388E-05,   7.4935422E-05,   7.4906027E-05
     +,   7.4810348E-05,   7.4649215E-05,   7.4424126E-05
     +,   7.4137330E-05,   7.3791751E-05,   7.3391078E-05
     +,   7.2939678E-05,   7.2442672E-05,   7.1905815E-05
     +,   7.1335628E-05,   7.0739225E-05,   7.0124443E-05
     +,   6.9499663E-05,   6.8873873E-05,   6.8256639E-05
     +,   6.7658053E-05,   6.7088637E-05,   6.6559325E-05
     +,   6.6081433E-05,   6.5666543E-05,   6.5326436E-05
     +,   6.5073007E-05,   6.4918175E-05,   6.4873748E-05
     +,   6.4951324E-05,   6.5162101E-05,   6.5516819E-05
     +,   6.6025554E-05,   6.6697598E-05,   6.7541252E-05
     +,   6.8563648E-05,   6.9770715E-05,   7.1167007E-05
     +,   7.2755305E-05,   7.4537034E-05,   7.6511569E-05
     +,   7.8676734E-05,   8.1028302E-05,   8.3560466E-05
     +,   8.6265383E-05,   8.9133951E-05,   9.2155096E-05
     +,   9.5316827E-05,   9.8606091E-05,   1.0200879E-04
     +,   1.0551041E-04,   1.0909652E-04,   1.1275284E-04
     +,   1.1646552E-04,   1.2022151E-04,   1.2400936E-04
     +,   1.2781906E-04,   1.3164199E-04,   1.3547184E-04
     +,   1.3930433E-04,   1.4313696E-04,   1.4696928E-04
     +,   1.5080279E-04,   1.5464073E-04,   1.5848738E-04
     +,   1.6234795E-04,   1.6622851E-04,   1.7013522E-04
     +,   1.7407384E-04,   1.7804962E-04,   1.8206701E-04
     +,   1.8612968E-04,   1.9023972E-04,   1.9439860E-04
     +,   1.9860723E-04,   2.0286588E-04,   2.0717502E-04
     +,   2.1153664E-04,   2.1595448E-04,   2.2043471E-04
     +,   2.2498721E-04,   2.2962641E-04,   2.3437206E-04
     +,   2.3924922E-04,   2.4428853E-04,   2.4952684E-04
     +,   2.5500596E-04,   2.6077149E-04,   2.6687261E-04
     +,   2.7336043E-04,   2.8028546E-04,   2.8769765E-04
     +,   2.9564544E-04,   3.0417624E-04,   3.1333661E-04
     +,   3.2317682E-04,   3.3375577E-04,   3.4514797E-04
     +,   3.5745130E-04,   3.7079747E-04,   3.8536190E-04
     +,   4.0137148E-04,   4.1910747E-04,   4.3890742E-04
     +,   4.6115846E-04,   4.8628199E-04,   5.1471818E-04
     +,   5.4691115E-04,   5.8329850E-04,   6.2431482E-04
     +,   6.7043031E-04,   7.2222238E-04,   7.8048586E-04
     +,   8.4637891E-04,   9.2161860E-04,   1.0087154E-03
     +,   1.1112069E-03,   1.2338001E-03,   1.3822139E-03
     +,   1.5623175E-03,   1.7782698E-03,   2.0298474E-03
     +,   2.3101098E-03,   2.6058725E-03,   2.9045274E-03
     +,   3.2093604E-03,   3.5580450E-03,   4.0265885E-03
     +,   4.6989089E-03,   5.6127994E-03,   6.7425976E-03
     +,   8.0716219E-03,   9.6975276E-03,   1.1838901E-02
     +,   1.4769122E-02,   1.8862378E-02,   2.4615455E-02
     +,   3.2175623E-02,   4.0537104E-02,   4.7395088E-02
     +,   5.0078660E-02,   4.6981256E-02,   3.8614299E-02
     +,   2.7483152E-02,   1.6785745E-02,   8.8115595E-03
     +,   4.1137212E-03,   1.9019444E-03,   1.0359675E-03
     +,   7.0751156E-04,   5.4067944E-04,   4.1462475E-04
     +,   3.0568967E-04,   2.1564469E-04,   1.4782914E-04
     +,   1.0105474E-04,   7.0518159E-05,   5.0721468E-05
     +,   3.7449452E-05,   2.8169565E-05,   2.1557886E-05
     +,   1.6909278E-05,   1.3760209E-05,   1.1731348E-05
     +,   1.0495043E-05,   9.7829216E-06,   9.3932113E-06
     +,   9.1871698E-06,   9.0771482E-06,   9.0119775E-06
     +,   8.9639307E-06,   8.9190453E-06,   8.8707720E-06
     +,   8.8162942E-06,   8.7545459E-06,   8.6852160E-06
     +,   8.6083137E-06,   8.5239990E-06,   8.4324829E-06
     +,   8.3340028E-06,   8.2288252E-06,   8.1172420E-06
     +,   7.9995443E-06,   7.8760377E-06,   7.7470513E-06
     +,   7.6129199E-06,   7.4739851E-06,   7.3305896E-06
     +,   7.1830996E-06,   7.0318661E-06,   6.8772624E-06
     +,   6.7196443E-06,   6.5593867E-06,   6.3968459E-06
     +,   6.2323943E-06,   6.0663788E-06,   5.8991632E-06
     +,   5.7310867E-06,   5.5624992E-06,   5.3937256E-06
     +,   5.2250839E-06,   5.0568979E-06,   4.8894562E-06
     +,   4.7230596E-06,   4.5579732E-06,   4.3944706E-06
     +,   4.2327906E-06,   4.0731807E-06,   3.9158476E-06
     +,   3.7610107E-06,   3.6088484E-06,   3.4595482E-06
     +,   3.3132594E-06,   3.1701372E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz115 = Yx/0.111829268292683
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8610486E-08,   3.3172501E-08
     +,   3.8398912E-08,   4.4375952E-08,   5.1199351E-08
     +,   5.8975303E-08,   6.7821034E-08,   7.7866019E-08
     +,   8.9252481E-08,   1.0213707E-07,   1.1669098E-07
     +,   1.3310121E-07,   1.5157178E-07,   1.7232441E-07
     +,   1.9559984E-07,   2.2165813E-07,   2.5078032E-07
     +,   2.8326855E-07,   3.1944774E-07,   3.5966548E-07
     +,   4.0429302E-07,   4.5372599E-07,   5.0838338E-07
     +,   5.6871329E-07,   6.3518183E-07,   7.0828781E-07
     +,   7.8855027E-07,   8.7651409E-07,   9.7274881E-07
     +,   1.0778467E-06,   1.1924237E-06,   1.3171159E-06
     +,   1.4525807E-06,   1.5994948E-06,   1.7585505E-06
     +,   1.9304571E-06,   2.1159353E-06,   2.3157172E-06
     +,   2.5305549E-06,   2.7611845E-06,   3.0083720E-06
     +,   3.2728710E-06,   3.5554383E-06,   3.8568323E-06
     +,   4.1778026E-06,   4.5190959E-06,   4.8814527E-06
     +,   5.2656028E-06,   5.6722647E-06,   6.1021524E-06
     +,   6.5559611E-06,   7.0343808E-06,   7.5380799E-06
     +,   8.0677555E-06,   8.6240316E-06,   9.2075907E-06
     +,   9.8190758E-06,   1.0459135E-05,   1.1128430E-05
     +,   1.1827613E-05,   1.2557362E-05,   1.3318376E-05
     +,   1.4111319E-05,   1.4936964E-05,   1.5796093E-05
     +,   1.6689459E-05,   1.7617960E-05,   1.8582436E-05
     +,   1.9583893E-05,   2.0623280E-05,   2.1701737E-05
     +,   2.2820341E-05,   2.3980381E-05,   2.5183102E-05
     +,   2.6429921E-05,   2.7722386E-05,   2.9062025E-05
     +,   3.0450494E-05,   3.1889624E-05,   3.3381388E-05
     +,   3.4927703E-05,   3.6530833E-05,   3.8192946E-05
     +,   3.9916547E-05,   4.1704079E-05,   4.3558328E-05
     +,   4.5481982E-05,   4.7478123E-05,   4.9549715E-05
     +,   5.1700041E-05,   5.3932523E-05,   5.6250607E-05
     +,   5.8657788E-05,   6.1157829E-05,   6.3754625E-05
     +,   6.6451859E-05,   6.9253605E-05,   7.2163581E-05
     +,   7.5185832E-05,   7.8323988E-05,   8.1581922E-05
     +,   8.4962885E-05,   8.8470326E-05,   9.2106930E-05
     +,   9.5875199E-05,   9.9777171E-05,   1.0381395E-04
     +,   1.0798577E-04,   1.1229229E-04,   1.1673196E-04
     +,   1.2130153E-04,   1.2599693E-04,   1.3081175E-04
     +,   1.3573837E-04,   1.4076650E-04,   1.4588430E-04
     +,   1.5107689E-04,   1.5632743E-04,   1.6161594E-04
     +,   1.6692023E-04,   1.7221531E-04,   1.7747343E-04
     +,   1.8266439E-04,   1.8775598E-04,   1.9271430E-04
     +,   1.9750334E-04,   2.0208691E-04,   2.0642797E-04
     +,   2.1049043E-04,   2.1423880E-04,   2.1764044E-04
     +,   2.2066492E-04,   2.2328648E-04,   2.2548361E-04
     +,   2.2724101E-04,   2.2854956E-04,   2.2940761E-04
     +,   2.2982116E-04,   2.2980459E-04,   2.2938054E-04
     +,   2.2858016E-04,   2.2744259E-04,   2.2601486E-04
     +,   2.2435056E-04,   2.2250933E-04,   2.2055565E-04
     +,   2.1855692E-04,   2.1658275E-04,   2.1470252E-04
     +,   2.1298423E-04,   2.1149240E-04,   2.1028683E-04
     +,   2.0942102E-04,   2.0894066E-04,   2.0888299E-04
     +,   2.0927616E-04,   2.1013852E-04,   2.1147920E-04
     +,   2.1329868E-04,   2.1558921E-04,   2.1833682E-04
     +,   2.2152263E-04,   2.2512487E-04,   2.2912092E-04
     +,   2.3348987E-04,   2.3821460E-04,   2.4328312E-04
     +,   2.4869095E-04,   2.5444228E-04,   2.6055053E-04
     +,   2.6703789E-04,   2.7393550E-04,   2.8128197E-04
     +,   2.8912237E-04,   2.9750509E-04,   3.0648176E-04
     +,   3.1610610E-04,   3.2643316E-04,   3.3752274E-04
     +,   3.4944408E-04,   3.6228396E-04,   3.7615577E-04
     +,   3.9121351E-04,   4.0766670E-04,   4.2579250E-04
     +,   4.4594210E-04,   4.6854024E-04,   4.9407239E-04
     +,   5.2305270E-04,   5.5597100E-04,   5.9323461E-04
     +,   6.3509285E-04,   6.8156881E-04,   7.3242147E-04
     +,   7.8715465E-04,   8.4508408E-04,   9.0547040E-04
     +,   9.6770952E-04,   1.0315405E-03,   1.0972000E-03
     +,   1.1654856E-03,   1.2377057E-03,   1.3155504E-03
     +,   1.4009499E-03,   1.4960137E-03,   1.6030810E-03
     +,   1.7246823E-03,   1.8631569E-03,   2.0198037E-03
     +,   2.1939045E-03,   2.3827257E-03,   2.5840683E-03
     +,   2.8020565E-03,   3.0542456E-03,   3.3757130E-03
     +,   3.8170833E-03,   4.4373763E-03,   5.2912184E-03
     +,   6.4016613E-03,   7.7194995E-03,   9.1297487E-03
     +,   1.0612648E-02,   1.2502966E-02,   1.5487065E-02
     +,   2.0192968E-02,   2.6877876E-02,   3.5206195E-02
     +,   4.3397855E-02,   4.8129834E-02,   4.6702866E-02
     +,   3.8885053E-02,   2.6975783E-02,   1.5082224E-02
     +,   6.7405300E-03,   2.5703984E-03,   1.0287747E-03
     +,   5.5198011E-04,   3.8486347E-04,   3.0239162E-04
     +,   2.5561158E-04,   2.2932659E-04,   2.1288595E-04
     +,   1.9881950E-04,   1.8338516E-04,   1.6571871E-04
     +,   1.4648763E-04,   1.2682265E-04,   1.0774162E-04
     +,   8.9957161E-05,   7.3884221E-05,   5.9711456E-05
     +,   4.7479323E-05,   3.7134811E-05,   2.8562537E-05
     +,   2.1603553E-05,   1.6070482E-05,   1.1761394E-05
     +,   8.4726535E-06,   6.0107150E-06,   4.2012684E-06
     +,   2.8943846E-06,   1.9659410E-06,   1.3166341E-06
     +,   8.6939093E-07,   5.6591949E-07,   3.6303786E-07
     +,   2.2942443E-07,   1.4277171E-07,   8.7453074E-08
     +,   5.2703978E-08,   3.1236308E-08,   1.8199740E-08
     +,   1.0421278E-08,   5.8626166E-09,   3.2393539E-09
     +,   1.7577131E-09,   9.3641672E-10,   4.8975896E-10
     +,   2.5143601E-10,   1.2670599E-10,   6.2670209E-11
     +,   3.0426512E-11,   1.4500800E-11,   6.7856575E-12
     +,   3.1188736E-12,   1.4090660E-12,   6.2648530E-13
     +,   2.7470159E-13,   1.1924481E-13,   5.1575382E-14
     +,   2.2468367E-14,   1.0023657E-14,   4.6832202E-15
     +,   2.3461068E-15,   1.2795316E-15,   7.5864712E-16
     +,   4.8113488E-16,   3.1941279E-16,   2.1788300E-16
     +,   1.5076097E-16,   1.0500022E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz116 = Yx/0.105341463414634
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz1168(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4468711E-07,   1.6038840E-07
     +,   1.7757223E-07,   1.9635254E-07,   2.1684924E-07
     +,   2.3918813E-07,   2.6350074E-07,   2.8992463E-07
     +,   3.1860276E-07,   3.4968505E-07,   3.8332527E-07
     +,   4.1968323E-07,   4.5892361E-07,   5.0121582E-07
     +,   5.4673347E-07,   5.9565491E-07,   6.4816106E-07
     +,   7.0443616E-07,   7.6466785E-07,   8.2904489E-07
     +,   8.9775818E-07,   9.7099974E-07,   1.0489605E-06
     +,   1.1318363E-06,   1.2198143E-06,   1.3130884E-06
     +,   1.4118473E-06,   1.5162778E-06,   1.6265652E-06
     +,   1.7428931E-06,   1.8654408E-06,   1.9943873E-06
     +,   2.1299090E-06,   2.2721795E-06,   2.4213734E-06
     +,   2.5776637E-06,   2.7412234E-06,   2.9122275E-06
     +,   3.0908654E-06,   3.2773110E-06,   3.4717677E-06
     +,   3.6744386E-06,   3.8855433E-06,   4.1053149E-06
     +,   4.3340124E-06,   4.5719162E-06,   4.8193319E-06
     +,   5.0766039E-06,   5.3441090E-06,   5.6222680E-06
     +,   5.9115464E-06,   6.2124641E-06,   6.5255908E-06
     +,   6.8515756E-06,   7.1910972E-06,   7.5449475E-06
     +,   7.9139600E-06,   8.2990609E-06,   8.7012522E-06
     +,   9.1216161E-06,   9.5613314E-06,   1.0021657E-05
     +,   1.0503919E-05,   1.1009565E-05,   1.1540135E-05
     +,   1.2097207E-05,   1.2682513E-05,   1.3297803E-05
     +,   1.3944993E-05,   1.4626001E-05,   1.5342928E-05
     +,   1.6097873E-05,   1.6893131E-05,   1.7731001E-05
     +,   1.8613979E-05,   1.9544692E-05,   2.0525842E-05
     +,   2.1560307E-05,   2.2651186E-05,   2.3801804E-05
     +,   2.5015604E-05,   2.6296437E-05,   2.7648275E-05
     +,   2.9075574E-05,   3.0582938E-05,   3.2175507E-05
     +,   3.3858578E-05,   3.5638022E-05,   3.7519829E-05
     +,   3.9510451E-05,   4.1616633E-05,   4.3845197E-05
     +,   4.6202989E-05,   4.8697031E-05,   5.1334155E-05
     +,   5.4120581E-05,   5.7062312E-05,   6.0164224E-05
     +,   6.3430474E-05,   6.6863497E-05,   7.0464550E-05
     +,   7.4232521E-05,   7.8164565E-05,   8.2254788E-05
     +,   8.6494969E-05,   9.0873895E-05,   9.5376839E-05
     +,   9.9985788E-05,   1.0467956E-04,   1.0943361E-04
     +,   1.1421960E-04,   1.1900663E-04,   1.2376030E-04
     +,   1.2844423E-04,   1.3301933E-04,   1.3744562E-04
     +,   1.4168132E-04,   1.4568509E-04,   1.4941531E-04
     +,   1.5283209E-04,   1.5589716E-04,   1.5857500E-04
     +,   1.6083343E-04,   1.6264463E-04,   1.6398559E-04
     +,   1.6483855E-04,   1.6519176E-04,   1.6503966E-04
     +,   1.6438318E-04,   1.6322994E-04,   1.6159411E-04
     +,   1.5949662E-04,   1.5696418E-04,   1.5402997E-04
     +,   1.5073217E-04,   1.4711381E-04,   1.4322242E-04
     +,   1.3910898E-04,   1.3482713E-04,   1.3043253E-04
     +,   1.2598230E-04,   1.2153430E-04,   1.1714600E-04
     +,   1.1287416E-04,   1.0877483E-04,   1.0490201E-04
     +,   1.0130781E-04,   9.8042430E-05,   9.5153926E-05
     +,   9.2688024E-05,   9.0688613E-05,   8.9198162E-05
     +,   8.8257824E-05,   8.7908069E-05,   8.8189074E-05
     +,   8.9141395E-05,   9.0806047E-05,   9.3224837E-05
     +,   9.6440468E-05,   1.0049542E-04,   1.0543191E-04
     +,   1.1129020E-04,   1.1810625E-04,   1.2590949E-04
     +,   1.3472038E-04,   1.4454685E-04,   1.5537997E-04
     +,   1.6719085E-04,   1.7992879E-04,   1.9351803E-04
     +,   2.0785593E-04,   2.2281437E-04,   2.3824291E-04
     +,   2.5397327E-04,   2.6982449E-04,   2.8561542E-04
     +,   3.0117531E-04,   3.1635439E-04,   3.3103989E-04
     +,   3.4516939E-04,   3.5874097E-04,   3.7182120E-04
     +,   3.8455040E-04,   3.9714159E-04,   4.0987230E-04
     +,   4.2306964E-04,   4.3709090E-04,   4.5230027E-04
     +,   4.6904059E-04,   4.8760968E-04,   5.0824758E-04
     +,   5.3113501E-04,   5.5641221E-04,   5.8422692E-04
     +,   6.1481033E-04,   6.4857572E-04,   6.8623858E-04
     +,   7.2895992E-04,   7.7850727E-04,   8.3742285E-04
     +,   9.0919476E-04,   9.9840958E-04,   1.1108380E-03
     +,   1.2533393E-03,   1.4334423E-03,   1.6584193E-03
     +,   1.9335547E-03,   2.2596063E-03,   2.6301323E-03
     +,   3.0301989E-03,   3.4383335E-03,   3.8325426E-03
     +,   4.1986466E-03,   4.5374138E-03,   4.8701395E-03
     +,   5.2481093E-03,   5.7640332E-03,   6.5336428E-03
     +,   7.6127755E-03,   8.9156926E-03,   1.0294713E-02
     +,   1.1753414E-02,   1.3476455E-02,   1.5606952E-02
     +,   1.8268876E-02,   2.1889558E-02,   2.6929315E-02
     +,   3.3153426E-02,   3.9359465E-02,   4.2904925E-02
     +,   4.0176548E-02,   3.0381406E-02,   1.7920272E-02
     +,   8.3008595E-03,   3.3054699E-03,   1.4499861E-03
     +,   8.8427070E-04,   6.6985772E-04,   5.3139013E-04
     +,   4.2392485E-04,   3.4379834E-04,   2.8591097E-04
     +,   2.4268894E-04,   2.0794806E-04,   1.7830783E-04
     +,   1.5255225E-04,   1.3043644E-04,   1.1182972E-04
     +,   9.6381802E-05,   8.3544757E-05,   7.2723116E-05
     +,   6.3409971E-05,   5.5246186E-05,   4.8012360E-05
     +,   4.1587540E-05,   3.5904348E-05,   3.0915089E-05
     +,   2.6571968E-05,   2.2819791E-05,   1.9596620E-05
     +,   1.6837512E-05,   1.4478371E-05,   1.2459254E-05
     +,   1.0726731E-05,   9.2349974E-06,   7.9455713E-06
     +,   6.8269437E-06,   5.8537025E-06,   5.0054009E-06
     +,   4.2655033E-06,   3.6205411E-06,   3.0593912E-06
     +,   2.5726088E-06,   2.1519652E-06,   1.7901602E-06
     +,   1.4806384E-06,   1.2173666E-06,   9.9483782E-07
     +,   8.0795593E-07,   6.5207320E-07,   5.2293137E-07
     +,   4.1669486E-07,   3.2990977E-07,   2.5951996E-07
     +,   2.0282907E-07,   1.5749789E-07,   1.2150586E-07
     +,   9.3130225E-08,   7.0918666E-08,   5.3653540E-08
     +,   4.0328388E-08,   3.0115437E-08,   2.2342995E-08
     +,   1.6468681E-08,   1.2060074E-08,   8.7741698E-09
     +,   6.3421339E-09,   4.5543822E-09,   3.2493555E-09
     +,   2.3031843E-09,   1.6219397E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz1168 = Yx/0.101675
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1383852E-07,   2.4291720E-07
     +,   2.7550271E-07,   3.1195273E-07,   3.5265248E-07
     +,   3.9801569E-07,   4.4848539E-07,   5.0453565E-07
     +,   5.6666943E-07,   6.3542456E-07,   7.1136748E-07
     +,   7.9509692E-07,   8.8724283E-07,   9.8846579E-07
     +,   1.0994561E-06,   1.2209332E-06,   1.3536434E-06
     +,   1.4983582E-06,   1.6558718E-06,   1.8269982E-06
     +,   2.0125694E-06,   2.2134313E-06,   2.4304341E-06
     +,   2.6644491E-06,   2.9163207E-06,   3.1869181E-06
     +,   3.4770812E-06,   3.7876398E-06,   4.1193998E-06
     +,   4.4731410E-06,   4.8496054E-06,   5.2494925E-06
     +,   5.6734557E-06,   6.1220885E-06,   6.5959230E-06
     +,   7.0954225E-06,   7.6209749E-06,   8.1728731E-06
     +,   8.7513645E-06,   9.3565304E-06,   9.9884282E-06
     +,   1.0646972E-05,   1.1331974E-05,   1.2043152E-05
     +,   1.2780107E-05,   1.3542328E-05,   1.4329206E-05
     +,   1.5140009E-05,   1.5973917E-05,   1.6830003E-05
     +,   1.7707245E-05,   1.8604540E-05,   1.9520679E-05
     +,   2.0454450E-05,   2.1404472E-05,   2.2369422E-05
     +,   2.3347866E-05,   2.4338377E-05,   2.5339503E-05
     +,   2.6349791E-05,   2.7367820E-05,   2.8392195E-05
     +,   2.9421502E-05,   3.0454479E-05,   3.1489930E-05
     +,   3.2526656E-05,   3.3563661E-05,   3.4599962E-05
     +,   3.5634817E-05,   3.6667479E-05,   3.7697479E-05
     +,   3.8724374E-05,   3.9747996E-05,   4.0768198E-05
     +,   4.1785115E-05,   4.2799027E-05,   4.3810316E-05
     +,   4.4819513E-05,   4.5827386E-05,   4.6834826E-05
     +,   4.7842779E-05,   4.8852431E-05,   4.9864993E-05
     +,   5.0881856E-05,   5.1904386E-05,   5.2934185E-05
     +,   5.3972697E-05,   5.5021621E-05,   5.6082470E-05
     +,   5.7156867E-05,   5.8246427E-05,   5.9352620E-05
     +,   6.0476836E-05,   6.1620471E-05,   6.2784784E-05
     +,   6.3970772E-05,   6.5179469E-05,   6.6411507E-05
     +,   6.7667519E-05,   6.8947753E-05,   7.0252398E-05
     +,   7.1581198E-05,   7.2933843E-05,   7.4309552E-05
     +,   7.5707438E-05,   7.7126308E-05,   7.8564619E-05
     +,   8.0020567E-05,   8.1492173E-05,   8.2977182E-05
     +,   8.4473017E-05,   8.5977052E-05,   8.7486267E-05
     +,   8.8997716E-05,   9.0508103E-05,   9.2014219E-05
     +,   9.3512637E-05,   9.5000090E-05,   9.6473115E-05
     +,   9.7928489E-05,   9.9363009E-05,   1.0077359E-04
     +,   1.0215724E-04,   1.0351127E-04,   1.0483323E-04
     +,   1.0612079E-04,   1.0737197E-04,   1.0858502E-04
     +,   1.0975853E-04,   1.1089133E-04,   1.1198260E-04
     +,   1.1303190E-04,   1.1403910E-04,   1.1500438E-04
     +,   1.1592859E-04,   1.1681295E-04,   1.1765925E-04
     +,   1.1847011E-04,   1.1924908E-04,   1.2000079E-04
     +,   1.2073127E-04,   1.2144827E-04,   1.2216164E-04
     +,   1.2288374E-04,   1.2362990E-04,   1.2441890E-04
     +,   1.2527380E-04,   1.2622212E-04,   1.2729665E-04
     +,   1.2853609E-04,   1.2998543E-04,   1.3169640E-04
     +,   1.3372775E-04,   1.3614564E-04,   1.3902353E-04
     +,   1.4244173E-04,   1.4648690E-04,   1.5125150E-04
     +,   1.5683239E-04,   1.6332843E-04,   1.7083943E-04
     +,   1.7946296E-04,   1.8929076E-04,   2.0040513E-04
     +,   2.1287591E-04,   2.2675573E-04,   2.4207434E-04
     +,   2.5883503E-04,   2.7701195E-04,   2.9654618E-04
     +,   3.1734200E-04,   3.3926719E-04,   3.6215541E-04
     +,   3.8580783E-04,   4.0999547E-04,   4.3447051E-04
     +,   4.5897285E-04,   4.8323948E-04,   5.0701870E-04
     +,   5.3008494E-04,   5.5225298E-04,   5.7339075E-04
     +,   5.9343688E-04,   6.1241555E-04,   6.3044520E-04
     +,   6.4774539E-04,   6.6463795E-04,   6.8154192E-04
     +,   6.9895899E-04,   7.1745296E-04,   7.3763245E-04
     +,   7.6012971E-04,   7.8559353E-04,   8.1469346E-04
     +,   8.4814674E-04,   8.8676059E-04,   9.3148858E-04
     +,   9.8351436E-04,   1.0443656E-03,   1.1160616E-03
     +,   1.2013023E-03,   1.3036691E-03,   1.4277415E-03
     +,   1.5789453E-03,   1.7629415E-03,   1.9845201E-03
     +,   2.2460322E-03,   2.5458296E-03,   2.8775921E-03
     +,   3.2314179E-03,   3.5968896E-03,   3.9669625E-03
     +,   4.3405807E-03,   4.7234138E-03,   5.1288516E-03
     +,   5.5806213E-03,   6.1133271E-03,   6.7673004E-03
     +,   7.5801010E-03,   8.5728746E-03,   9.7200871E-03
     +,   1.0914819E-02,   1.2007505E-02,   1.3010547E-02
     +,   1.4381845E-02,   1.6999340E-02,   2.1509385E-02
     +,   2.7370738E-02,   3.2442141E-02,   3.3860993E-02
     +,   3.0085647E-02,   2.2392571E-02,   1.3976883E-02
     +,   7.4923839E-03,   3.6671504E-03,   1.8356709E-03
     +,   1.0652784E-03,   7.3709892E-04,   5.6712941E-04
     +,   4.5468152E-04,   3.6973142E-04,   3.0316593E-04
     +,   2.5061565E-04,   2.0862970E-04,   1.7438497E-04
     +,   1.4591200E-04,   1.2201826E-04,   1.0196941E-04
     +,   8.5193074E-05,   7.1140646E-05,   5.9283560E-05
     +,   4.9167651E-05,   4.0452043E-05,   3.2910229E-05
     +,   2.6403535E-05,   2.0845688E-05,   1.6171245E-05
     +,   1.2314305E-05,   9.1988322E-06,   6.7380856E-06
     +,   4.8386669E-06,   3.4060372E-06,   2.3500215E-06
     +,   1.5891752E-06,   1.0533004E-06,   6.8423259E-07
     +,   4.3563037E-07,   2.7183202E-07,   1.6624863E-07
     +,   9.9651508E-08,   5.8542394E-08,   3.3707408E-08
     +,   1.9022053E-08,   1.0521076E-08,   5.7032885E-09
     +,   3.0302101E-09,   1.5779318E-09,   8.0537066E-10
     +,   4.0288950E-10,   1.9755779E-10,   9.4957396E-11
     +,   4.4746380E-11,   2.0675035E-11,   9.3706466E-12
     +,   4.1685422E-12,   1.8223340E-12,   7.8458729E-13
     +,   3.3402510E-13,   1.4167708E-13,   6.0658313E-14
     +,   2.6783268E-14,   1.2562167E-14,   6.4516979E-15
     +,   3.6850118E-15,   2.3198261E-15,   1.5682568E-15
     +,   1.1076774E-15,   8.0112111E-16,   5.8616856E-16
     +,   4.3107420E-16,   3.1760093E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz118 = Yx/0.0895641025641026
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz119(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9596653E-06,   4.0684918E-06
     +,   4.1778358E-06,   4.2875840E-06,   4.3976138E-06
     +,   4.5078027E-06,   4.6180244E-06,   4.7281519E-06
     +,   4.8380480E-06,   4.9475889E-06,   5.0566350E-06
     +,   5.1650550E-06,   5.2727128E-06,   5.3794756E-06
     +,   5.4852135E-06,   5.5897995E-06,   5.6931108E-06
     +,   5.7950310E-06,   5.8954543E-06,   5.9942836E-06
     +,   6.0914367E-06,   6.1868504E-06,   6.2804802E-06
     +,   6.3723110E-06,   6.4623509E-06,   6.5506611E-06
     +,   6.6373359E-06,   6.7225287E-06,   6.8064601E-06
     +,   6.8894228E-06,   6.9718039E-06,   7.0540964E-06
     +,   7.1369172E-06,   7.2210246E-06,   7.3073429E-06
     +,   7.3969909E-06,   7.4912978E-06,   7.5918433E-06
     +,   7.7004897E-06,   7.8194034E-06,   7.9511065E-06
     +,   8.0985055E-06,   8.2649312E-06,   8.4541807E-06
     +,   8.6705486E-06,   8.9188807E-06,   9.2045830E-06
     +,   9.5336827E-06,   9.9128283E-06,   1.0349325E-05
     +,   1.0851135E-05,   1.1426885E-05,   1.2085839E-05
     +,   1.2837922E-05,   1.3693558E-05,   1.4663781E-05
     +,   1.5759997E-05,   1.6993978E-05,   1.8377703E-05
     +,   1.9923216E-05,   2.1642476E-05,   2.3547191E-05
     +,   2.5648438E-05,   2.7956776E-05,   3.0481806E-05
     +,   3.3231703E-05,   3.6213529E-05,   3.9432278E-05
     +,   4.2891385E-05,   4.6591671E-05,   5.0532017E-05
     +,   5.4708176E-05,   5.9113678E-05,   6.3738633E-05
     +,   6.8570582E-05,   7.3594121E-05,   7.8790566E-05
     +,   8.4138352E-05,   8.9613561E-05,   9.5189782E-05
     +,   1.0083787E-04,   1.0652756E-04,   1.1222631E-04
     +,   1.1790140E-04,   1.2351877E-04,   1.2904506E-04
     +,   1.3444673E-04,   1.3969201E-04,   1.4475005E-04
     +,   1.4959261E-04,   1.5419406E-04,   1.5853153E-04
     +,   1.6258559E-04,   1.6634104E-04,   1.6978649E-04
     +,   1.7291457E-04,   1.7572255E-04,   1.7821173E-04
     +,   1.8038800E-04,   1.8226099E-04,   1.8384431E-04
     +,   1.8515511E-04,   1.8621358E-04,   1.8704269E-04
     +,   1.8766757E-04,   1.8811530E-04,   1.8841392E-04
     +,   1.8859241E-04,   1.8868007E-04,   1.8870579E-04
     +,   1.8869805E-04,   1.8868427E-04,   1.8869061E-04
     +,   1.8874160E-04,   1.8886005E-04,   1.8906688E-04
     +,   1.8938094E-04,   1.8981913E-04,   1.9039627E-04
     +,   1.9112520E-04,   1.9201679E-04,   1.9308024E-04
     +,   1.9432274E-04,   1.9575017E-04,   1.9736656E-04
     +,   1.9917451E-04,   2.0117527E-04,   2.0336838E-04
     +,   2.0575209E-04,   2.0832290E-04,   2.1107607E-04
     +,   2.1400451E-04,   2.1710018E-04,   2.2035230E-04
     +,   2.2374892E-04,   2.2727590E-04,   2.3091704E-04
     +,   2.3465455E-04,   2.3846884E-04,   2.4233959E-04
     +,   2.4624480E-04,   2.5016197E-04,   2.5406919E-04
     +,   2.5794521E-04,   2.6176946E-04,   2.6552420E-04
     +,   2.6919445E-04,   2.7276872E-04,   2.7623985E-04
     +,   2.7960623E-04,   2.8287148E-04,   2.8604546E-04
     +,   2.8914408E-04,   2.9218974E-04,   2.9521124E-04
     +,   2.9824284E-04,   3.0132412E-04,   3.0449918E-04
     +,   3.0781573E-04,   3.1132344E-04,   3.1507312E-04
     +,   3.1911617E-04,   3.2350142E-04,   3.2827546E-04
     +,   3.3348106E-04,   3.3915631E-04,   3.4533301E-04
     +,   3.5203673E-04,   3.5928711E-04,   3.6709689E-04
     +,   3.7547221E-04,   3.8441367E-04,   3.9391755E-04
     +,   4.0397674E-04,   4.1458142E-04,   4.2572260E-04
     +,   4.3739291E-04,   4.4958800E-04,   4.6230780E-04
     +,   4.7555927E-04,   4.8935547E-04,   5.0371350E-04
     +,   5.1865302E-04,   5.3419475E-04,   5.5035582E-04
     +,   5.6714524E-04,   5.8456371E-04,   6.0260727E-04
     +,   6.2127621E-04,   6.4059038E-04,   6.6062604E-04
     +,   6.8156049E-04,   7.0373493E-04,   7.2773441E-04
     +,   7.5447647E-04,   7.8529463E-04,   8.2199991E-04
     +,   8.6690532E-04,   9.2278881E-04,   9.9276379E-04
     +,   1.0800359E-03,   1.1875486E-03,   1.3175445E-03
     +,   1.4711401E-03,   1.6481330E-03,   1.8474072E-03
     +,   2.0680518E-03,   2.3110458E-03,   2.5806453E-03
     +,   2.8840278E-03,   3.2279682E-03,   3.6132408E-03
     +,   4.0303827E-03,   4.4619902E-03,   4.8938030E-03
     +,   5.3293086E-03,   5.7963165E-03,   6.3381935E-03
     +,   6.9982354E-03,   7.8152474E-03,   8.8341683E-03
     +,   1.0108947E-02,   1.1677109E-02,   1.3523644E-02
     +,   1.5569424E-02,   1.7677352E-02,   1.9628815E-02
     +,   2.1072647E-02,   2.1543074E-02,   2.0633325E-02
     +,   1.8254425E-02,   1.4773930E-02,   1.0892370E-02
     +,   7.3326454E-03,   4.5586913E-03,   2.6829643E-03
     +,   1.5598369E-03,   9.4684027E-04,   6.2660425E-04
     +,   4.5427360E-04,   3.5160375E-04,   2.8253937E-04
     +,   2.3187976E-04,   1.9291606E-04,   1.6202140E-04
     +,   1.3682587E-04,   1.1572793E-04,   9.7719720E-05
     +,   8.2218467E-05,   6.8887792E-05,   5.7493005E-05
     +,   4.7823090E-05,   3.9664283E-05,   3.2802269E-05
     +,   2.7034897E-05,   2.2183769E-05,   1.8099587E-05
     +,   1.4661432E-05,   1.1772906E-05,   9.3571252E-06
     +,   7.3514248E-06,   5.7025686E-06,   4.3633372E-06
     +,   3.2906396E-06,   2.4445972E-06,   1.7881571E-06
     +,   1.2874573E-06,   9.1221307E-07,   6.3596781E-07
     +,   4.3621534E-07,   2.9434656E-07,   1.9538749E-07
     +,   1.2758770E-07,   8.1956550E-08,   5.1785751E-08
     +,   3.2188485E-08,   1.9680680E-08,   1.1837063E-08
     +,   7.0032491E-09,   4.0759156E-09,   2.3335212E-09
     +,   1.3142726E-09,   7.2819539E-10,   3.9695786E-10
     +,   2.1291773E-10,   1.1239789E-10,   5.8416855E-11
     +,   2.9911244E-11,   1.5107669E-11,   7.5435179E-12
     +,   3.7389081E-12,   1.8528458E-12,   9.2960947E-13
     +,   4.8161952E-13,   2.6467156E-13,   1.5851266E-13
     +,   1.0495913E-13,   7.6292176E-14,   5.9503665E-14
     +,   4.8552023E-14,   4.0646963E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz119 = Yx/0.0780769230769231
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.6127750E-06,   6.8266836E-06
     +,   7.0494666E-06,   7.2816956E-06,   7.5239750E-06
     +,   7.7769337E-06,   8.0412365E-06,   8.3175755E-06
     +,   8.6066639E-06,   8.9092655E-06,   9.2261507E-06
     +,   9.5581318E-06,   9.9060353E-06,   1.0270722E-05
     +,   1.0653075E-05,   1.1053996E-05,   1.1474410E-05
     +,   1.1915260E-05,   1.2377503E-05,   1.2862117E-05
     +,   1.3370082E-05,   1.3902395E-05,   1.4460040E-05
     +,   1.5044048E-05,   1.5655385E-05,   1.6295073E-05
     +,   1.6964081E-05,   1.7663389E-05,   1.8393954E-05
     +,   1.9156703E-05,   1.9952542E-05,   2.0782352E-05
     +,   2.1646958E-05,   2.2547159E-05,   2.3483684E-05
     +,   2.4457220E-05,   2.5468389E-05,   2.6517717E-05
     +,   2.7605727E-05,   2.8732731E-05,   2.9899071E-05
     +,   3.1104912E-05,   3.2350341E-05,   3.3635311E-05
     +,   3.4959656E-05,   3.6323090E-05,   3.7725145E-05
     +,   3.9165257E-05,   4.0642681E-05,   4.2156502E-05
     +,   4.3705655E-05,   4.5288896E-05,   4.6904799E-05
     +,   4.8551829E-05,   5.0228122E-05,   5.1931838E-05
     +,   5.3660799E-05,   5.5412773E-05,   5.7185287E-05
     +,   5.8975773E-05,   6.0781524E-05,   6.2599720E-05
     +,   6.4427331E-05,   6.6261397E-05,   6.8098903E-05
     +,   6.9936621E-05,   7.1771559E-05,   7.3600539E-05
     +,   7.5420663E-05,   7.7228891E-05,   7.9022597E-05
     +,   8.0799087E-05,   8.2556086E-05,   8.4291416E-05
     +,   8.6003303E-05,   8.7690365E-05,   8.9351466E-05
     +,   9.0985879E-05,   9.2593422E-05,   9.4174415E-05
     +,   9.5729425E-05,   9.7259806E-05,   9.8767166E-05
     +,   1.0025379E-04,   1.0172230E-04,   1.0317589E-04
     +,   1.0461808E-04,   1.0605287E-04,   1.0748443E-04
     +,   1.0891733E-04,   1.1035628E-04,   1.1180597E-04
     +,   1.1327116E-04,   1.1475649E-04,   1.1626638E-04
     +,   1.1780480E-04,   1.1937547E-04,   1.2098126E-04
     +,   1.2262458E-04,   1.2430687E-04,   1.2602884E-04
     +,   1.2778997E-04,   1.2958903E-04,   1.3142332E-04
     +,   1.3328927E-04,   1.3518214E-04,   1.3709595E-04
     +,   1.3902370E-04,   1.4095753E-04,   1.4288870E-04
     +,   1.4480767E-04,   1.4670451E-04,   1.4856886E-04
     +,   1.5039057E-04,   1.5215947E-04,   1.5386623E-04
     +,   1.5550217E-04,   1.5706010E-04,   1.5853433E-04
     +,   1.5992124E-04,   1.6121971E-04,   1.6243124E-04
     +,   1.6356062E-04,   1.6461607E-04,   1.6560973E-04
     +,   1.6655782E-04,   1.6748070E-04,   1.6840351E-04
     +,   1.6935583E-04,   1.7037184E-04,   1.7149032E-04
     +,   1.7275446E-04,   1.7421143E-04,   1.7591204E-04
     +,   1.7791036E-04,   1.8026288E-04,   1.8302767E-04
     +,   1.8626322E-04,   1.9002779E-04,   1.9437776E-04
     +,   1.9936616E-04,   2.0504088E-04,   2.1144372E-04
     +,   2.1860827E-04,   2.2655736E-04,   2.3530280E-04
     +,   2.4484293E-04,   2.5516070E-04,   2.6622292E-04
     +,   2.7798035E-04,   2.9036641E-04,   3.0329725E-04
     +,   3.1667232E-04,   3.3037801E-04,   3.4428845E-04
     +,   3.5826783E-04,   3.7217539E-04,   3.8587049E-04
     +,   3.9921724E-04,   4.1208792E-04,   4.2437197E-04
     +,   4.3597925E-04,   4.4684554E-04,   4.5693701E-04
     +,   4.6625521E-04,   4.7483819E-04,   4.8276217E-04
     +,   4.9014093E-04,   4.9712649E-04,   5.0390314E-04
     +,   5.1068503E-04,   5.1770872E-04,   5.2522850E-04
     +,   5.3350674E-04,   5.4280541E-04,   5.5337866E-04
     +,   5.6546374E-04,   5.7927193E-04,   5.9498375E-04
     +,   6.1274739E-04,   6.3267950E-04,   6.5487111E-04
     +,   6.7940413E-04,   7.0637331E-04,   7.3591393E-04
     +,   7.6822873E-04,   8.0361613E-04,   8.4248779E-04
     +,   8.8535377E-04,   9.3277736E-04,   9.8529295E-04
     +,   1.0432733E-03,   1.1067642E-03,   1.1753222E-03
     +,   1.2478916E-03,   1.3227654E-03,   1.3976771E-03
     +,   1.4700682E-03,   1.5375012E-03,   1.5981633E-03
     +,   1.6513731E-03,   1.6980026E-03,   1.7407261E-03
     +,   1.7840859E-03,   1.8344555E-03,   1.9000910E-03
     +,   1.9913479E-03,   2.1210741E-03,   2.3048248E-03
     +,   2.5603678E-03,   2.9060545E-03,   3.3582607E-03
     +,   3.9285072E-03,   4.6203677E-03,   5.4250471E-03
     +,   6.3161002E-03,   7.2486782E-03,   8.1721283E-03
     +,   9.0582427E-03,   9.9304160E-03,   1.0866340E-02
     +,   1.1957250E-02,   1.3242114E-02,   1.4662370E-02
     +,   1.6071668E-02,   1.7287359E-02,   1.8133905E-02
     +,   1.8445831E-02,   1.8057466E-02,   1.6838010E-02
     +,   1.4784549E-02,   1.2102149E-02,   9.1810878E-03
     +,   6.4601717E-03,   4.2619510E-03,   2.7037426E-03
     +,   1.7208590E-03,   1.1556350E-03,   8.4443379E-04
     +,   6.6496560E-04,   5.4466713E-04,   4.4887004E-04
     +,   3.6512708E-04,   2.9122739E-04,   2.2812809E-04
     +,   1.7663836E-04,   1.3639100E-04,   1.0597399E-04
     +,   8.3458443E-05,   6.6891931E-05,   5.4595948E-05
     +,   4.5279623E-05,   3.8025657E-05,   3.2218184E-05
     +,   2.7460184E-05,   2.3502285E-05,   2.0188569E-05
     +,   1.7418110E-05,   1.5119847E-05,   1.3237367E-05
     +,   1.1720425E-05,   1.0520837E-05,   9.5914620E-06
     +,   8.8868965E-06,   8.3647337E-06,   7.9866177E-06
     +,   7.7191617E-06,   7.5343419E-06,   7.4093909E-06
     +,   7.3264005E-06,   7.2717162E-06,   7.2352295E-06
     +,   7.2096595E-06,   7.1899049E-06,   7.1724830E-06
     +,   7.1550835E-06,   7.1362133E-06,   7.1149393E-06
     +,   7.0906972E-06,   7.0631636E-06,   7.0321676E-06
     +,   6.9976381E-06,   6.9595558E-06,   6.9179473E-06
     +,   6.8728532E-06,   6.8243398E-06,   6.7724754E-06
     +,   6.7173387E-06,   6.6590155E-06,   6.5975946E-06
     +,   6.5331737E-06,   6.4658479E-06,   6.3957259E-06
     +,   6.3229090E-06,   6.2475096E-06,   6.1696378E-06
     +,   6.0894140E-06,   6.0069501E-06,   5.9223703E-06
     +,   5.8357909E-06,   5.7473417E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz120 = Yx/0.0796923076923077
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.2816410E-06,   7.4757445E-06
     +,   7.6714114E-06,   7.8685589E-06,   8.0671098E-06
     +,   8.2669876E-06,   8.4681160E-06,   8.6704231E-06
     +,   8.8738352E-06,   9.0782924E-06,   9.2837263E-06
     +,   9.4900715E-06,   9.6972717E-06,   9.9052668E-06
     +,   1.0114004E-05,   1.0323432E-05,   1.0533498E-05
     +,   1.0744154E-05,   1.0955353E-05,   1.1167050E-05
     +,   1.1379198E-05,   1.1591755E-05,   1.1804671E-05
     +,   1.2017908E-05,   1.2231410E-05,   1.2445135E-05
     +,   1.2659028E-05,   1.2873038E-05,   1.3087101E-05
     +,   1.3301159E-05,   1.3515142E-05,   1.3728975E-05
     +,   1.3942582E-05,   1.4155878E-05,   1.4368771E-05
     +,   1.4581165E-05,   1.4792954E-05,   1.5004034E-05
     +,   1.5214298E-05,   1.5423622E-05,   1.5631904E-05
     +,   1.5839036E-05,   1.6044914E-05,   1.6249453E-05
     +,   1.6452583E-05,   1.6654267E-05,   1.6854501E-05
     +,   1.7053329E-05,   1.7250855E-05,   1.7447266E-05
     +,   1.7642840E-05,   1.7837972E-05,   1.8033203E-05
     +,   1.8229255E-05,   1.8427045E-05,   1.8627759E-05
     +,   1.8832881E-05,   1.9044261E-05,   1.9264195E-05
     +,   1.9495514E-05,   1.9741698E-05,   2.0007026E-05
     +,   2.0296711E-05,   2.0617168E-05,   2.0976218E-05
     +,   2.1383403E-05,   2.1850359E-05,   2.2391176E-05
     +,   2.3022989E-05,   2.3766330E-05,   2.4645931E-05
     +,   2.5691081E-05,   2.6936554E-05,   2.8422939E-05
     +,   3.0197516E-05,   3.2314736E-05,   3.4836525E-05
     +,   3.7832713E-05,   4.1381554E-05,   4.5569665E-05
     +,   5.0491668E-05,   5.6251036E-05,   6.2958687E-05
     +,   7.0734292E-05,   7.9704121E-05,   9.0002650E-05
     +,   1.0176941E-04,   1.1515039E-04,   1.3029319E-04
     +,   1.4734716E-04,   1.6645895E-04,   1.8776662E-04
     +,   2.1139585E-04,   2.3745703E-04,   2.6604021E-04
     +,   2.9721172E-04,   3.3102365E-04,   3.6751808E-04
     +,   4.0675927E-04,   4.4886643E-04,   4.9409142E-04
     +,   5.4290757E-04,   5.9615419E-04,   6.5518112E-04
     +,   7.2201405E-04,   7.9944503E-04,   8.9099049E-04
     +,   1.0006408E-03,   1.1323672E-03,   1.2894425E-03
     +,   1.4738201E-03,   1.6860473E-03,   1.9259864E-03
     +,   2.1945899E-03,   2.4960064E-03,   2.8391567E-03
     +,   3.2374703E-03,   3.7070762E-03,   4.2644795E-03
     +,   4.9257935E-03,   5.7070390E-03,   6.6221473E-03
     +,   7.6748668E-03,   8.8463146E-03,   1.0087632E-02
     +,   1.1326490E-02,   1.2484847E-02,   1.3495374E-02
     +,   1.4314539E-02,   1.4932739E-02,   1.5371399E-02
     +,   1.5653243E-02,   1.5767394E-02,   1.5672121E-02
     +,   1.5341391E-02,   1.4805527E-02,   1.4140676E-02
     +,   1.3423544E-02,   1.2706980E-02,   1.2036481E-02
     +,   1.1466424E-02,   1.1038432E-02,   1.0743708E-02
     +,   1.0517204E-02,   1.0276058E-02,   9.9704405E-03
     +,   9.6102599E-03,   9.2541045E-03,   8.9717805E-03
     +,   8.8047925E-03,   8.7450929E-03,   8.7367008E-03
     +,   8.6940704E-03,   8.5300179E-03,   8.1856092E-03
     +,   7.6511716E-03,   6.9680703E-03,   6.2100985E-03
     +,   5.4552886E-03,   4.7629797E-03,   4.1648960E-03
     +,   3.6695229E-03,   3.2720093E-03,   2.9625203E-03
     +,   2.7301998E-03,   2.5637664E-03,   2.4509402E-03
     +,   2.3783098E-03,   2.3320529E-03,   2.2990745E-03
     +,   2.2680725E-03,   2.2302603E-03,   2.1796781E-03
     +,   2.1131856E-03,   2.0302304E-03,   1.9324115E-03
     +,   1.8229451E-03,   1.7060582E-03,   1.5863673E-03
     +,   1.4683164E-03,   1.3557622E-03,   1.2517107E-03
     +,   1.1581982E-03,   1.0763087E-03,   1.0063046E-03
     +,   9.4780361E-04,   8.9996494E-04,   8.6166599E-04
     +,   8.3165342E-04,   8.0865482E-04,   7.9144200E-04
     +,   7.7887450E-04,   7.6991139E-04,   7.6361239E-04
     +,   7.5912802E-04,   7.5569260E-04,   7.5261935E-04
     +,   7.4929546E-04,   7.4518629E-04,   7.3983643E-04
     +,   7.3287607E-04,   7.2402367E-04,   7.1308628E-04
     +,   6.9995853E-04,   6.8461965E-04,   6.6712248E-04
     +,   6.4758572E-04,   6.2618341E-04,   6.0313265E-04
     +,   5.7868060E-04,   5.5309327E-04,   5.2664889E-04
     +,   4.9962709E-04,   4.7229958E-04,   4.4492664E-04
     +,   4.1775344E-04,   3.9100533E-04,   3.6488305E-04
     +,   3.3956245E-04,   3.1519585E-04,   2.9190644E-04
     +,   2.6979033E-04,   2.4891898E-04,   2.2933773E-04
     +,   2.1106641E-04,   1.9410290E-04,   1.7842613E-04
     +,   1.6399757E-04,   1.5076318E-04,   1.3865775E-04
     +,   1.2760848E-04,   1.1753688E-04,   1.0836117E-04
     +,   9.9999321E-05,   9.2371956E-05,   8.5402535E-05
     +,   7.9019388E-05,   7.3157164E-05,   6.7756882E-05
     +,   6.2765837E-05,   5.8138008E-05,   5.3834065E-05
     +,   4.9820559E-05,   4.6069159E-05,   4.2556341E-05
     +,   3.9262894E-05,   3.6173016E-05,   3.3273544E-05
     +,   3.0553540E-05,   2.8004091E-05,   2.5617253E-05
     +,   2.3386046E-05,   2.1304220E-05,   1.9365869E-05
     +,   1.7565146E-05,   1.5896294E-05,   1.4353629E-05
     +,   1.2931393E-05,   1.1623655E-05,   1.0424421E-05
     +,   9.3277249E-06,   8.3275636E-06,   7.4178897E-06
     +,   6.5927261E-06,   5.8462724E-06,   5.1727848E-06
     +,   4.5667034E-06,   4.0227119E-06,   3.5357132E-06
     +,   3.1008201E-06,   2.7134188E-06,   2.3691887E-06
     +,   2.0640782E-06,   1.7942907E-06,   1.5563069E-06
     +,   1.3468971E-06,   1.1630602E-06,   1.0020708E-06
     +,   8.6141722E-07,   7.3883314E-07,   6.3224650E-07
     +,   5.3979852E-07,   4.5980221E-07,   3.9075258E-07
     +,   3.3129351E-07,   2.8022126E-07,   2.3645964E-07
     +,   1.9905418E-07,   1.6716344E-07,   1.4004114E-07
     +,   1.1703396E-07,   9.7566044E-08,   8.1136236E-08
     +,   6.7305258E-08,   5.5692940E-08,   4.5968235E-08
     +,   3.7846181E-08,   3.1080113E-08,   2.5458904E-08
     +,   2.0800991E-08,   1.6951846E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz75 = Yx/0.127833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.4708665E-09,   7.5630924E-09
     +,   8.8250873E-09,   1.0280667E-08,   1.1956559E-08
     +,   1.3882707E-08,   1.6092548E-08,   1.8623378E-08
     +,   2.1516598E-08,   2.4818323E-08,   2.8579482E-08
     +,   3.2856317E-08,   3.7710855E-08,   4.3211227E-08
     +,   4.9432174E-08,   5.6455406E-08,   6.4370113E-08
     +,   7.3273362E-08,   8.3270436E-08,   9.4475325E-08
     +,   1.0701123E-07,   1.2101056E-07,   1.3661548E-07
     +,   1.5397906E-07,   1.7326280E-07,   1.9464086E-07
     +,   2.1829652E-07,   2.4442423E-07,   2.7322909E-07
     +,   3.0492663E-07,   3.3974285E-07,   3.7791375E-07
     +,   4.1968516E-07,   4.6531224E-07,   5.1505884E-07
     +,   5.6919731E-07,   6.2800768E-07,   6.9177503E-07
     +,   7.6079675E-07,   8.3536690E-07,   9.1579352E-07
     +,   1.0023851E-06,   1.0954554E-06,   1.1953236E-06
     +,   1.3023151E-06,   1.4167599E-06,   1.5389966E-06
     +,   1.6693745E-06,   1.8082528E-06,   1.9560091E-06
     +,   2.1130400E-06,   2.2797678E-06,   2.4566434E-06
     +,   2.6441687E-06,   2.8428701E-06,   3.0533561E-06
     +,   3.2762853E-06,   3.5124012E-06,   3.7625380E-06
     +,   4.0276368E-06,   4.3087643E-06,   4.6071395E-06
     +,   4.9241294E-06,   5.2613354E-06,   5.6206113E-06
     +,   6.0040861E-06,   6.4143364E-06,   6.8543900E-06
     +,   7.3279966E-06,   7.8397125E-06,   8.3953018E-06
     +,   9.0019612E-06,   9.6689128E-06,   1.0407826E-05
     +,   1.1233641E-05,   1.2165370E-05,   1.3226963E-05
     +,   1.4448432E-05,   1.5867070E-05,   1.7528599E-05
     +,   1.9488089E-05,   2.1811313E-05,   2.4574911E-05
     +,   2.7867225E-05,   3.1787211E-05,   3.6444129E-05
     +,   4.1954456E-05,   4.8439986E-05,   5.6022200E-05
     +,   6.4818312E-05,   7.4934673E-05,   8.6459098E-05
     +,   9.9454046E-05,   1.1395072E-04,   1.2994236E-04
     +,   1.4737800E-04,   1.6616390E-04,   1.8615989E-04
     +,   2.0718836E-04,   2.2903709E-04,   2.5147613E-04
     +,   2.7426713E-04,   2.9718605E-04,   3.2003509E-04
     +,   3.4266480E-04,   3.6498642E-04,   3.8697952E-04
     +,   4.0869665E-04,   4.3026166E-04,   4.5185571E-04
     +,   4.7369776E-04,   4.9602613E-04,   5.1906757E-04
     +,   5.4301857E-04,   5.6802074E-04,   5.9415866E-04
     +,   6.2146323E-04,   6.4996030E-04,   6.7974697E-04
     +,   7.1115303E-04,   7.4499048E-04,   7.8293076E-04
     +,   8.2804100E-04,   8.8547316E-04,   9.6329744E-04
     +,   1.0734688E-03,   1.2329561E-03,   1.4646144E-03
     +,   1.7968044E-03,   2.2596186E-03,   2.8770082E-03
     +,   3.6574446E-03,   4.5909435E-03,   5.6573381E-03
     +,   6.8428023E-03,   8.1514185E-03,   9.6003478E-03
     +,   1.1196764E-02,   1.2911220E-02,   1.4682552E-02
     +,   1.6478816E-02,   1.8339654E-02,   2.0254262E-02
     +,   2.1980952E-02,   2.3199517E-02,   2.3936983E-02
     +,   2.4587860E-02,   2.5442271E-02,   2.6405888E-02
     +,   2.7033463E-02,   2.6797727E-02,   2.5628913E-02
     +,   2.4025479E-02,   2.2468770E-02,   2.0948589E-02
     +,   1.9287374E-02,   1.7811993E-02,   1.7109968E-02
     +,   1.7100969E-02,   1.6991850E-02,   1.6137458E-02
     +,   1.4538388E-02,   1.2605529E-02,   1.0730871E-02
     +,   9.0866378E-03,   7.6822732E-03,   6.4999568E-03
     +,   5.5498979E-03,   4.8388299E-03,   4.3349704E-03
     +,   3.9757267E-03,   3.6991490E-03,   3.4658425E-03
     +,   3.2606183E-03,   3.0823017E-03,   2.9324973E-03
     +,   2.8089993E-03,   2.7043947E-03,   2.6080590E-03
     +,   2.5094203E-03,   2.4008164E-03,   2.2790327E-03
     +,   2.1453486E-03,   2.0043834E-03,   1.8623560E-03
     +,   1.7253417E-03,   1.5979612E-03,   1.4827296E-03
     +,   1.3800743E-03,   1.2888102E-03,   1.2067993E-03
     +,   1.1316381E-03,   1.0611772E-03,   9.9382235E-04
     +,   9.2862576E-04,   8.6523657E-04,   8.0376532E-04
     +,   7.4460683E-04,   6.8828108E-04,   6.3531176E-04
     +,   5.8614515E-04,   5.4109935E-04,   5.0034217E-04
     +,   4.6389701E-04,   4.3165887E-04,   4.0340939E-04
     +,   3.7884398E-04,   3.5759842E-04,   3.3926958E-04
     +,   3.2343608E-04,   3.0967811E-04,   2.9759289E-04
     +,   2.8680495E-04,   2.7697426E-04,   2.6780128E-04
     +,   2.5903070E-04,   2.5045071E-04,   2.4189131E-04
     +,   2.3322302E-04,   2.2435424E-04,   2.1522683E-04
     +,   2.0581299E-04,   1.9611258E-04,   1.8614846E-04
     +,   1.7596249E-04,   1.6561203E-04,   1.5516698E-04
     +,   1.4470539E-04,   1.3430911E-04,   1.2406107E-04
     +,   1.1404277E-04,   1.0433084E-04,   9.4994037E-05
     +,   8.6092063E-05,   7.7675133E-05,   6.9781316E-05
     +,   6.2437211E-05,   5.5658526E-05,   4.9450013E-05
     +,   4.3806096E-05,   3.8712431E-05,   3.4147586E-05
     +,   3.0083957E-05,   2.6489077E-05,   2.3327309E-05
     +,   2.0561347E-05,   1.8153134E-05,   1.6064732E-05
     +,   1.4259420E-05,   1.2702480E-05,   1.1361341E-05
     +,   1.0206138E-05,   9.2099444E-06,   8.3487521E-06
     +,   7.6013885E-06,   6.9494868E-06,   6.3773336E-06
     +,   5.8716037E-06,   5.4211005E-06,   5.0165431E-06
     +,   4.6503442E-06,   4.3163400E-06,   4.0095515E-06
     +,   3.7260081E-06,   3.4625903E-06,   3.2168207E-06
     +,   2.9867570E-06,   2.7708929E-06,   2.5680433E-06
     +,   2.3772591E-06,   2.1977767E-06,   2.0289790E-06
     +,   1.8703488E-06,   1.7214207E-06,   1.5817795E-06
     +,   1.4510518E-06,   1.3288656E-06,   1.2148735E-06
     +,   1.1087192E-06,   1.0100629E-06,   9.1855225E-07
     +,   8.3384691E-07,   7.5559734E-07,   6.8346532E-07
     +,   6.1710620E-07,   5.5618887E-07,   5.0038170E-07
     +,   4.4936056E-07,   4.0281489E-07,   3.6043699E-07
     +,   3.2193606E-07,   2.8702712E-07,   2.5544188E-07
     +,   2.2692058E-07,   2.0122023E-07,   1.7810736E-07
     +,   1.5736485E-07,   1.3878608E-07,   1.2218001E-07
     +,   1.0736596E-07,   9.4177828E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz80 = Yx/0.163227272727273
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2131236E-06,   5.5107812E-06
     +,   5.8186629E-06,   6.1366591E-06,   6.4646306E-06
     +,   6.8024142E-06,   7.1498166E-06,   7.5066250E-06
     +,   7.8725961E-06,   8.2474844E-06,   8.6310120E-06
     +,   9.0228941E-06,   9.4228380E-06,   9.8305500E-06
     +,   1.0245732E-05,   1.0668104E-05,   1.1097385E-05
     +,   1.1533325E-05,   1.1975695E-05,   1.2424295E-05
     +,   1.2878971E-05,   1.3339611E-05,   1.3806144E-05
     +,   1.4278598E-05,   1.4756999E-05,   1.5241510E-05
     +,   1.5732330E-05,   1.6229746E-05,   1.6734139E-05
     +,   1.7245951E-05,   1.7765737E-05,   1.8294126E-05
     +,   1.8831834E-05,   1.9379660E-05,   1.9938485E-05
     +,   2.0509264E-05,   2.1093016E-05,   2.1690810E-05
     +,   2.2303810E-05,   2.2933140E-05,   2.3580027E-05
     +,   2.4245679E-05,   2.4931314E-05,   2.5638130E-05
     +,   2.6367323E-05,   2.7120035E-05,   2.7897371E-05
     +,   2.8700382E-05,   2.9530052E-05,   3.0387293E-05
     +,   3.1272943E-05,   3.2187752E-05,   3.3132379E-05
     +,   3.4107470E-05,   3.5113495E-05,   3.6150945E-05
     +,   3.7220212E-05,   3.8321654E-05,   3.9455579E-05
     +,   4.0622297E-05,   4.1822084E-05,   4.3055268E-05
     +,   4.4322082E-05,   4.5622892E-05,   4.6958106E-05
     +,   4.8328027E-05,   4.9733168E-05,   5.1173854E-05
     +,   5.2650648E-05,   5.4163887E-05,   5.5714092E-05
     +,   5.7301469E-05,   5.8926416E-05,   6.0588936E-05
     +,   6.2289029E-05,   6.4026499E-05,   6.5800734E-05
     +,   6.7610883E-05,   6.9455855E-05,   7.1334136E-05
     +,   7.3243682E-05,   7.5182266E-05,   7.7146957E-05
     +,   7.9134639E-05,   8.1141552E-05,   8.3163759E-05
     +,   8.5196720E-05,   8.7235843E-05,   8.9276014E-05
     +,   9.1312162E-05,   9.3339215E-05,   9.5351847E-05
     +,   9.7345044E-05,   9.9314129E-05,   1.0125485E-04
     +,   1.0316345E-04,   1.0503711E-04,   1.0687381E-04
     +,   1.0867289E-04,   1.1043500E-04,   1.1216269E-04
     +,   1.1386027E-04,   1.1553465E-04,   1.1719534E-04
     +,   1.1885503E-04,   1.2053004E-04,   1.2224089E-04
     +,   1.2401272E-04,   1.2587626E-04,   1.2786876E-04
     +,   1.3003465E-04,   1.3242770E-04,   1.3511215E-04
     +,   1.3816588E-04,   1.4168289E-04,   1.4577789E-04
     +,   1.5059019E-04,   1.5628985E-04,   1.6308230E-04
     +,   1.7121474E-04,   1.8098048E-04,   1.9272053E-04
     +,   2.0682393E-04,   2.2372458E-04,   2.4389267E-04
     +,   2.6781927E-04,   2.9600458E-04,   3.2893146E-04
     +,   3.6704991E-04,   4.1074303E-04,   4.6030970E-04
     +,   5.1592628E-04,   5.7763763E-04,   6.4534927E-04
     +,   7.1890582E-04,   7.9826516E-04,   8.8383659E-04
     +,   9.7702164E-04,   1.0809096E-03,   1.2009797E-03
     +,   1.3455944E-03,   1.5260172E-03,   1.7558932E-03
     +,   2.0508640E-03,   2.4302986E-03,   2.9235326E-03
     +,   3.5790403E-03,   4.4674599E-03,   5.6665083E-03
     +,   7.2304797E-03,   9.1728959E-03,   1.1477758E-02
     +,   1.4081012E-02,   1.6787216E-02,   1.9307466E-02
     +,   2.1611791E-02,   2.4230579E-02,   2.7786873E-02
     +,   3.2099716E-02,   3.6313411E-02,   3.9774798E-02
     +,   4.1609094E-02,   4.0795904E-02,   3.8263608E-02
     +,   3.5237096E-02,   3.1755298E-02,   2.8700026E-02
     +,   2.6741432E-02,   2.5025764E-02,   2.2556569E-02
     +,   1.9443143E-02,   1.6414279E-02,   1.3916172E-02
     +,   1.2048659E-02,   1.0766151E-02,   9.8823775E-03
     +,   9.1364877E-03,   8.3642993E-03,   7.5609065E-03
     +,   6.7982133E-03,   6.1303391E-03,   5.5653462E-03
     +,   5.0834850E-03,   4.6611838E-03,   4.2828149E-03
     +,   3.9416882E-03,   3.6360850E-03,   3.3646717E-03
     +,   3.1235996E-03,   2.9061155E-03,   2.7042227E-03
     +,   2.5111823E-03,   2.3233523E-03,   2.1406119E-03
     +,   1.9654869E-03,   1.8016206E-03,   1.6522866E-03
     +,   1.5194053E-03,   1.4032385E-03,   1.3026366E-03
     +,   1.2155580E-03,   1.1396017E-03,   1.0724176E-03
     +,   1.0119410E-03,   9.5648068E-04,   9.0468006E-04
     +,   8.5547147E-04,   8.0802309E-04,   7.6170149E-04
     +,   7.1605301E-04,   6.7080167E-04,   6.2584464E-04
     +,   5.8123359E-04,   5.3714664E-04,   4.9385644E-04
     +,   4.5169424E-04,   4.1100918E-04,   3.7213066E-04
     +,   3.3534627E-04,   3.0088672E-04,   2.6890959E-04
     +,   2.3950211E-04,   2.1268634E-04,   1.8842515E-04
     +,   1.6663104E-04,   1.4717899E-04,   1.2991819E-04
     +,   1.1468017E-04,   1.0128628E-04,   8.9555964E-05
     +,   7.9312711E-05,   7.0387192E-05,   6.2619773E-05
     +,   5.5863260E-05,   4.9984446E-05,   4.4863355E-05
     +,   4.0393807E-05,   3.6483205E-05,   3.3051274E-05
     +,   3.0028896E-05,   2.7357206E-05,   2.4986557E-05
     +,   2.2875069E-05,   2.0987403E-05,   1.9293877E-05
     +,   1.7769624E-05,   1.6393635E-05,   1.5148004E-05
     +,   1.4017457E-05,   1.2988978E-05,   1.2051213E-05
     +,   1.1194282E-05,   1.0409597E-05,   9.6895965E-06
     +,   9.0275680E-06,   8.4175781E-06,   7.8544072E-06
     +,   7.3334249E-06,   6.8504969E-06,   6.4019573E-06
     +,   5.9845906E-06,   5.5955479E-06,   5.2322825E-06
     +,   4.8925458E-06,   4.5743814E-06,   4.2760294E-06
     +,   3.9959336E-06,   3.7327341E-06,   3.4852251E-06
     +,   3.2523187E-06,   3.0330473E-06,   2.8265601E-06
     +,   2.6320940E-06,   2.4489475E-06,   2.2764864E-06
     +,   2.1141498E-06,   1.9614022E-06,   1.8177686E-06
     +,   1.6827908E-06,   1.5560556E-06,   1.4371594E-06
     +,   1.3257352E-06,   1.2214185E-06,   1.1238743E-06
     +,   1.0327681E-06,   9.4778943E-07,   8.6862866E-07
     +,   7.9498761E-07,   7.2658349E-07,   6.6313214E-07
     +,   6.0436730E-07,   5.5002215E-07,   4.9984538E-07
     +,   4.5358712E-07,   4.1101185E-07,   3.7188667E-07
     +,   3.3599250E-07,   3.0311398E-07,   2.7304893E-07
     +,   2.4560009E-07,   2.2058263E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz85 = Yx/0.183590909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7733842E-08,   3.2153615E-08
     +,   3.7209492E-08,   4.2981529E-08,   4.9558015E-08
     +,   5.7036164E-08,   6.5522535E-08,   7.5133741E-08
     +,   8.5996831E-08,   9.8250624E-08,   1.1204491E-07
     +,   1.2754191E-07,   1.4491651E-07,   1.6435652E-07
     +,   1.8606308E-07,   2.1025072E-07,   2.3714766E-07
     +,   2.6699567E-07,   3.0005009E-07,   3.3657940E-07
     +,   3.7686456E-07,   4.2119885E-07,   4.6988595E-07
     +,   5.2324287E-07,   5.8158986E-07,   6.4526063E-07
     +,   7.1459129E-07,   7.8992230E-07,   8.7159606E-07
     +,   9.5995358E-07,   1.0553325E-06,   1.1580646E-06
     +,   1.2684709E-06,   1.3868599E-06,   1.5135228E-06
     +,   1.6487311E-06,   1.7927312E-06,   1.9457393E-06
     +,   2.1079493E-06,   2.2794995E-06,   2.4605074E-06
     +,   2.6510349E-06,   2.8510976E-06,   3.0606611E-06
     +,   3.2796336E-06,   3.5078672E-06,   3.7451532E-06
     +,   3.9912225E-06,   4.2457386E-06,   4.5083052E-06
     +,   4.7784638E-06,   5.0556914E-06,   5.3394051E-06
     +,   5.6289855E-06,   5.9237291E-06,   6.2229296E-06
     +,   6.5258205E-06,   6.8316253E-06,   7.1395548E-06
     +,   7.4488221E-06,   7.7586692E-06,   8.0683803E-06
     +,   8.3772838E-06,   8.6848222E-06,   8.9905561E-06
     +,   9.2941591E-06,   9.5955265E-06,   9.8947266E-06
     +,   1.0192119E-05,   1.0488312E-05,   1.0784291E-05
     +,   1.1081376E-05,   1.1381338E-05,   1.1686378E-05
     +,   1.1999219E-05,   1.2323131E-05,   1.2661938E-05
     +,   1.3020072E-05,   1.3402614E-05,   1.3815307E-05
     +,   1.4264503E-05,   1.4757270E-05,   1.5301253E-05
     +,   1.5904776E-05,   1.6576656E-05,   1.7326305E-05
     +,   1.8163475E-05,   1.9098356E-05,   2.0141259E-05
     +,   2.1302672E-05,   2.2593071E-05,   2.4022633E-05
     +,   2.5601143E-05,   2.7337932E-05,   2.9241563E-05
     +,   3.1319480E-05,   3.3578202E-05,   3.6022604E-05
     +,   3.8656290E-05,   4.1480769E-05,   4.4495959E-05
     +,   4.7699286E-05,   5.1086343E-05,   5.4649910E-05
     +,   5.8380654E-05,   6.2266801E-05,   6.6293840E-05
     +,   7.0444847E-05,   7.4700940E-05,   7.9041230E-05
     +,   8.3442741E-05,   8.7881861E-05,   9.2333728E-05
     +,   9.6774304E-05,   1.0117988E-04,   1.0552956E-04
     +,   1.0980535E-04,   1.1399471E-04,   1.1809120E-04
     +,   1.2209726E-04,   1.2602590E-04,   1.2990243E-04
     +,   1.3376724E-04,   1.3767809E-04,   1.4171221E-04
     +,   1.4596828E-04,   1.5056938E-04,   1.5566379E-04
     +,   1.6142830E-04,   1.6806911E-04,   1.7582587E-04
     +,   1.8497494E-04,   1.9583915E-04,   2.0879925E-04
     +,   2.2431716E-04,   2.4296627E-04,   2.6546750E-04
     +,   2.9273174E-04,   3.2589244E-04,   3.6630922E-04
     +,   4.1551903E-04,   4.7512341E-04,   5.4660364E-04
     +,   6.3107064E-04,   7.2899490E-04,   8.4002950E-04
     +,   9.6296804E-04,   1.0959429E-03,   1.2369059E-03
     +,   1.3843218E-03,   1.5378695E-03,   1.6988821E-03
     +,   1.8702765E-03,   2.0558606E-03,   2.2593478E-03
     +,   2.4840930E-03,   2.7351175E-03,   3.0249557E-03
     +,   3.3840663E-03,   3.8767925E-03,   4.6243146E-03
     +,   5.8208602E-03,   7.6833596E-03,   1.0269815E-02
     +,   1.3268705E-02,   1.6062008E-02,   1.8253934E-02
     +,   2.0263124E-02,   2.2922656E-02,   2.6435111E-02
     +,   3.0626778E-02,   3.5595503E-02,   4.1120373E-02
     +,   4.4857554E-02,   4.4341240E-02,   4.2969935E-02
     +,   4.2936146E-02,   4.0887710E-02,   3.6246747E-02
     +,   3.1103851E-02,   2.6142871E-02,   2.1639040E-02
     +,   1.7919989E-02,   1.5232988E-02,   1.3454109E-02
     +,   1.2103584E-02,   1.0843869E-02,   9.6053388E-03
     +,   8.4184352E-03,   7.3220115E-03,   6.3514253E-03
     +,   5.5301450E-03,   4.8601674E-03,   4.3200483E-03
     +,   3.8748654E-03,   3.4935900E-03,   3.1605603E-03
     +,   2.8736885E-03,   2.6351737E-03,   2.4436850E-03
     +,   2.2921215E-03,   2.1696193E-03,   2.0648798E-03
     +,   1.9686799E-03,   1.8749330E-03,   1.7806001E-03
     +,   1.6850430E-03,   1.5892135E-03,   1.4948637E-03
     +,   1.4038780E-03,   1.3177855E-03,   1.2374559E-03
     +,   1.1630005E-03,   1.0938541E-03,   1.0289957E-03
     +,   9.6722390E-04,   9.0740662E-04,   8.4866828E-04
     +,   7.9049746E-04,   7.3277002E-04,   6.7568640E-04
     +,   6.1968440E-04,   5.6532992E-04,   5.1320752E-04
     +,   4.6383182E-04,   4.1759311E-04,   3.7473423E-04
     +,   3.3534688E-04,   2.9938851E-04,   2.6671635E-04
     +,   2.3712470E-04,   2.1037375E-04,   1.8621510E-04
     +,   1.6441198E-04,   1.4475174E-04,   1.2704532E-04
     +,   1.1112896E-04,   9.6861222E-05,   8.4116749E-05
     +,   7.2780706E-05,   6.2745683E-05,   5.3909163E-05
     +,   4.6170986E-05,   3.9432238E-05,   3.3596021E-05
     +,   2.8568380E-05,   2.4258812E-05,   2.0581043E-05
     +,   1.7454398E-05,   1.4804739E-05,   1.2564430E-05
     +,   1.0672916E-05,   9.0768317E-06,   7.7296445E-06
     +,   6.5911936E-06,   5.6273225E-06,   4.8093189E-06
     +,   4.1132025E-06,   3.5190567E-06,   3.0104809E-06
     +,   2.5740410E-06,   2.1987100E-06,   1.8754134E-06
     +,   1.5966705E-06,   1.3563032E-06,   1.1491164E-06
     +,   9.7072711E-07,   8.1740609E-07,   6.8593840E-07
     +,   5.7351900E-07,   4.7769294E-07,   3.9630436E-07
     +,   3.2744555E-07,   2.6942328E-07,   2.2073949E-07
     +,   1.8007439E-07,   1.4625917E-07,   1.1827198E-07
     +,   9.5215682E-08,   7.6312929E-08,   6.0888617E-08
     +,   4.8364036E-08,   3.8242444E-08,   3.0102871E-08
     +,   2.3588500E-08,   1.8400392E-08,   1.4288386E-08
     +,   1.1044945E-08,   8.4991409E-09,   6.5104171E-09
     +,   4.9644653E-09,   3.7684065E-09,   2.8475560E-09
     +,   2.1419431E-09,   1.6038819E-09,   1.1955226E-09
     +,   8.8709862E-10,   6.5524958E-10,   4.8180371E-10
     +,   3.5265812E-10,   2.5696115E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz90 = Yx/0.185022727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3944426E-05,   1.4171323E-05
     +,   1.4389853E-05,   1.4599797E-05,   1.4800975E-05
     +,   1.4993234E-05,   1.5176454E-05,   1.5350557E-05
     +,   1.5515488E-05,   1.5671234E-05,   1.5817806E-05
     +,   1.5955249E-05,   1.6083644E-05,   1.6203096E-05
     +,   1.6313748E-05,   1.6415765E-05,   1.6509353E-05
     +,   1.6594740E-05,   1.6672189E-05,   1.6741997E-05
     +,   1.6804486E-05,   1.6860020E-05,   1.6908991E-05
     +,   1.6951833E-05,   1.6989015E-05,   1.7021046E-05
     +,   1.7048478E-05,   1.7071914E-05,   1.7091988E-05
     +,   1.7109409E-05,   1.7124921E-05,   1.7139331E-05
     +,   1.7153507E-05,   1.7168375E-05,   1.7184935E-05
     +,   1.7204249E-05,   1.7227447E-05,   1.7255745E-05
     +,   1.7290407E-05,   1.7332797E-05,   1.7384340E-05
     +,   1.7446526E-05,   1.7520928E-05,   1.7609174E-05
     +,   1.7712960E-05,   1.7834029E-05,   1.7974175E-05
     +,   1.8135217E-05,   1.8319015E-05,   1.8527422E-05
     +,   1.8762301E-05,   1.9025481E-05,   1.9318753E-05
     +,   1.9643863E-05,   2.0002441E-05,   2.0396041E-05
     +,   2.0826070E-05,   2.1293785E-05,   2.1800257E-05
     +,   2.2346348E-05,   2.2932685E-05,   2.3559658E-05
     +,   2.4227313E-05,   2.4935453E-05,   2.5683574E-05
     +,   2.6470720E-05,   2.7295720E-05,   2.8156910E-05
     +,   2.9052369E-05,   2.9979692E-05,   3.0936222E-05
     +,   3.1918822E-05,   3.2924141E-05,   3.3948378E-05
     +,   3.4987541E-05,   3.6037352E-05,   3.7093279E-05
     +,   3.8150574E-05,   3.9204446E-05,   4.0250012E-05
     +,   4.1282266E-05,   4.2296375E-05,   4.3287440E-05
     +,   4.4250861E-05,   4.5182118E-05,   4.6077086E-05
     +,   4.6931847E-05,   4.7742960E-05,   4.8507332E-05
     +,   4.9222388E-05,   4.9886083E-05,   5.0496859E-05
     +,   5.1053728E-05,   5.1556348E-05,   5.2004925E-05
     +,   5.2400283E-05,   5.2743839E-05,   5.3037620E-05
     +,   5.3284239E-05,   5.3486845E-05,   5.3649161E-05
     +,   5.3775431E-05,   5.3870415E-05,   5.3939340E-05
     +,   5.3987933E-05,   5.4022352E-05,   5.4049255E-05
     +,   5.4075732E-05,   5.4109350E-05,   5.4158201E-05
     +,   5.4230903E-05,   5.4336673E-05,   5.4485365E-05
     +,   5.4687611E-05,   5.4954802E-05,   5.5299311E-05
     +,   5.5734497E-05,   5.6274897E-05,   5.6936264E-05
     +,   5.7735742E-05,   5.8691978E-05,   5.9825121E-05
     +,   6.1156854E-05,   6.2710584E-05,   6.4511354E-05
     +,   6.6585497E-05,   6.8960988E-05,   7.1666633E-05
     +,   7.4732394E-05,   7.8188270E-05,   8.2064536E-05
     +,   8.6390224E-05,   9.1193397E-05,   9.6499010E-05
     +,   1.0232921E-04,   1.0870169E-04,   1.1562852E-04
     +,   1.2311575E-04,   1.3116386E-04,   1.3976821E-04
     +,   1.4892052E-04,   1.5861398E-04,   1.6885111E-04
     +,   1.7965442E-04,   1.9108091E-04,   2.0324544E-04
     +,   2.1634690E-04,   2.3069949E-04,   2.4676946E-04
     +,   2.6521328E-04,   2.8690812E-04,   3.1296801E-04
     +,   3.4473673E-04,   3.8374201E-04,   4.3159316E-04
     +,   4.8981415E-04,   5.5962865E-04,   6.4172951E-04
     +,   7.3610299E-04,   8.4202801E-04,   9.5844310E-04
     +,   1.0847559E-03,   1.2221846E-03,   1.3756092E-03
     +,   1.5557512E-03,   1.7812388E-03,   2.0794366E-03
     +,   2.4837027E-03,   3.0240358E-03,   3.7101530E-03
     +,   4.5125638E-03,   5.3554424E-03,   6.1381962E-03
     +,   6.7957756E-03,   7.3890737E-03,   8.1861075E-03
     +,   9.6608670E-03,   1.2344420E-02,   1.6633326E-02
     +,   2.2671852E-02,   2.9666333E-02,   3.5167284E-02
     +,   3.7632067E-02,   3.9205510E-02,   4.1904256E-02
     +,   4.4992398E-02,   4.7806025E-02,   4.8710484E-02
     +,   4.4833392E-02,   3.7400492E-02,   3.0726129E-02
     +,   2.6248677E-02,   2.2609422E-02,   1.8968087E-02
     +,   1.5716068E-02,   1.3407554E-02,   1.2059330E-02
     +,   1.1240428E-02,   1.0463217E-02,   9.4785374E-03
     +,   8.3231432E-03,   7.1729212E-03,   6.1708554E-03
     +,   5.3566722E-03,   4.6989871E-03,   4.1532908E-03
     +,   3.6908675E-03,   3.2975331E-03,   2.9640053E-03
     +,   2.6808623E-03,   2.4385704E-03,   2.2291294E-03
     +,   2.0471560E-03,   1.8898530E-03,   1.7561135E-03
     +,   1.6452550E-03,   1.5558875E-03,   1.4852794E-03
     +,   1.4293022E-03,   1.3828187E-03,   1.3403170E-03
     +,   1.2966034E-03,   1.2473953E-03,   1.1897294E-03
     +,   1.1221502E-03,   1.0446997E-03,   9.5873058E-04
     +,   8.6658780E-04,   7.7121198E-04,   6.7574339E-04
     +,   5.8316952E-04,   4.9603544E-04,   4.1625887E-04
     +,   3.4506197E-04,   2.8299686E-04,   2.3002068E-04
     +,   1.8563612E-04,   1.4903987E-04,   1.1925837E-04
     +,   9.5264026E-05,   7.6065437E-05,   6.0764927E-05
     +,   4.8586153E-05,   3.8882037E-05,   3.1129824E-05
     +,   2.4916655E-05,   1.9920784E-05,   1.5893029E-05
     +,   1.2640884E-05,   1.0014912E-05,   7.8973426E-06
     +,   6.1943661E-06,   4.8302672E-06,   3.7430718E-06
     +,   2.8815457E-06,   2.2032000E-06,   1.6727776E-06
     +,   1.2610246E-06,   9.4375866E-07,   7.0115010E-07
     +,   5.1706877E-07,   3.7848707E-07,   2.7497242E-07
     +,   1.9825848E-07,   1.4186021E-07,   1.0072586E-07
     +,   7.0963573E-08,   4.9603791E-08,   3.4399200E-08
     +,   2.3664279E-08,   1.6147524E-08,   1.0928308E-08
     +,   7.3350148E-09,   4.8821094E-09,   3.2220258E-09
     +,   2.1083471E-09,   1.3677310E-09,   8.7959950E-10
     +,   5.6072841E-10,   3.5431322E-10,   2.2189739E-10
     +,   1.3773205E-10,   8.4723069E-11,   5.1647065E-11
     +,   3.1198696E-11,   1.8675495E-11,   1.1077254E-11
     +,   6.5102541E-12,   3.7911926E-12,   2.1874729E-12
     +,   1.2505752E-12,   7.0837211E-13,   3.9757360E-13
     +,   2.2108998E-13,   1.2182925E-13,   6.6523677E-14
     +,   3.6000218E-14,   1.9310447E-14,   1.0269839E-14
     +,   5.4171027E-15,   2.8357704E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ttz95 = Yx/0.184386363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3751054E-06,   2.6166133E-06
     +,   2.8775519E-06,   3.1588982E-06,   3.4616155E-06
     +,   3.7866487E-06,   4.1349135E-06,   4.5072893E-06
     +,   4.9046075E-06,   5.3276649E-06,   5.7771767E-06
     +,   6.2537979E-06,   6.7581054E-06,   7.2905877E-06
     +,   7.8516441E-06,   8.4415715E-06,   9.0605608E-06
     +,   9.7086913E-06,   1.0385931E-05,   1.1092115E-05
     +,   1.1826967E-05,   1.2590086E-05,   1.3380930E-05
     +,   1.4198893E-05,   1.5043156E-05,   1.5912872E-05
     +,   1.6807056E-05,   1.7724615E-05,   1.8664372E-05
     +,   1.9625082E-05,   2.0605425E-05,   2.1604032E-05
     +,   2.2619502E-05,   2.3650420E-05,   2.4695351E-05
     +,   2.5752888E-05,   2.6821672E-05,   2.7900353E-05
     +,   2.8987748E-05,   3.0082634E-05,   3.1184012E-05
     +,   3.2290958E-05,   3.3402703E-05,   3.4518609E-05
     +,   3.5638241E-05,   3.6761339E-05,   3.7887814E-05
     +,   3.9017796E-05,   4.0151590E-05,   4.1289706E-05
     +,   4.2432857E-05,   4.3581931E-05,   4.4738001E-05
     +,   4.5902354E-05,   4.7076319E-05,   4.8261492E-05
     +,   4.9459493E-05,   5.0672079E-05,   5.1901057E-05
     +,   5.3148309E-05,   5.4415672E-05,   5.5705084E-05
     +,   5.7018289E-05,   5.8357120E-05,   5.9723323E-05
     +,   6.1118408E-05,   6.2543899E-05,   6.4001055E-05
     +,   6.5491156E-05,   6.7015113E-05,   6.8573878E-05
     +,   7.0168084E-05,   7.1798364E-05,   7.3465009E-05
     +,   7.5168427E-05,   7.6908807E-05,   7.8686295E-05
     +,   8.0500860E-05,   8.2352701E-05,   8.4241998E-05
     +,   8.6168773E-05,   8.8133478E-05,   9.0136338E-05
     +,   9.2178067E-05,   9.4259311E-05,   9.6381045E-05
     +,   9.8544275E-05,   1.0075044E-04,   1.0300087E-04
     +,   1.0529723E-04,   1.0764130E-04,   1.1003480E-04
     +,   1.1247944E-04,   1.1497703E-04,   1.1752930E-04
     +,   1.2013751E-04,   1.2280312E-04,   1.2552689E-04
     +,   1.2830966E-04,   1.3115157E-04,   1.3405277E-04
     +,   1.3701282E-04,   1.4003142E-04,   1.4310765E-04
     +,   1.4624096E-04,   1.4943097E-04,   1.5267728E-04
     +,   1.5598013E-04,   1.5934074E-04,   1.6276112E-04
     +,   1.6624437E-04,   1.6979522E-04,   1.7341952E-04
     +,   1.7712520E-04,   1.8092146E-04,   1.8481948E-04
     +,   1.8883140E-04,   1.9297136E-04,   1.9725367E-04
     +,   2.0169384E-04,   2.0630754E-04,   2.1110999E-04
     +,   2.1611605E-04,   2.2134000E-04,   2.2679570E-04
     +,   2.3249621E-04,   2.3845567E-04,   2.4468938E-04
     +,   2.5121693E-04,   2.5806300E-04,   2.6526235E-04
     +,   2.7286116E-04,   2.8092286E-04,   2.8952997E-04
     +,   2.9878912E-04,   3.0883274E-04,   3.1981885E-04
     +,   3.3193061E-04,   3.4537198E-04,   3.6035993E-04
     +,   3.7711122E-04,   3.9582761E-04,   4.1667887E-04
     +,   4.3978068E-04,   4.6516996E-04,   4.9278926E-04
     +,   5.2246614E-04,   5.5390102E-04,   5.8666378E-04
     +,   6.2020525E-04,   6.5387157E-04,   6.8693340E-04
     +,   7.1863009E-04,   7.4822211E-04,   7.7504502E-04
     +,   7.9856900E-04,   8.1845600E-04,   8.3461142E-04
     +,   8.4722060E-04,   8.5676590E-04,   8.6403557E-04
     +,   8.7009737E-04,   8.7625498E-04,   8.8398135E-04
     +,   8.9482893E-04,   9.1032631E-04,   9.3185739E-04
     +,   9.6054905E-04,   9.9716766E-04,   1.0420431E-03
     +,   1.0950346E-03,   1.1555679E-03,   1.2227533E-03
     +,   1.2955754E-03,   1.3731599E-03,   1.4550963E-03
     +,   1.5417257E-03,   1.6343278E-03,   1.7351108E-03
     +,   1.8469294E-03,   1.9726818E-03,   2.1144557E-03
     +,   2.2726550E-03,   2.4453774E-03,   2.6283392E-03
     +,   2.8155802E-03,   3.0009311E-03,   3.1799283E-03
     +,   3.3516339E-03,   3.5200662E-03,   3.6951930E-03
     +,   3.8939395E-03,   4.1420995E-03,   4.4783582E-03
     +,   4.9605188E-03,   5.6699258E-03,   6.7052143E-03
     +,   8.1578633E-03,   1.0071135E-02,   1.2429348E-02
     +,   1.5438472E-02,   2.0291200E-02,   2.8884368E-02
     +,   4.1330196E-02,   5.5823576E-02,   7.4228846E-02
     +,   0.1080036    ,   0.1509273    ,   0.1913311    
     +,   0.2175400    ,   0.2153429    ,   0.1879164    
     +,   0.1678520    ,   0.1349953    ,   9.8996341E-02
     +,   7.3536962E-02,   5.4887090E-02,   3.8987342E-02
     +,   2.7209323E-02,   1.9748423E-02,   1.4939511E-02
     +,   1.1662409E-02,   9.3283011E-03,   7.5139143E-03
     +,   5.9892009E-03,   4.6807979E-03,   3.5804962E-03
     +,   2.6912841E-03,   2.0041240E-03,   1.4930909E-03
     +,   1.1222509E-03,   8.5545401E-04,   6.6263706E-04
     +,   5.2147178E-04,   4.1631141E-04,   3.3644712E-04
     +,   2.7464380E-04,   2.2604238E-04,   1.8735584E-04
     +,   1.5630270E-04,   1.3123322E-04,   1.1089879E-04
     +,   9.4318093E-05,   8.0705424E-05,   6.9431764E-05
     +,   5.9998645E-05,   5.2016501E-05,   4.5185625E-05
     +,   3.9279657E-05,   3.4130211E-05,   2.9611962E-05
     +,   2.5631694E-05,   2.2119269E-05,   1.9020206E-05
     +,   1.6290382E-05,   1.3892703E-05,   1.1794848E-05
     +,   9.9675717E-06,   8.3837576E-06,   7.0180904E-06
     +,   5.8469423E-06,   4.8481738E-06,   4.0011105E-06
     +,   3.2866642E-06,   2.6874181E-06,   2.1874978E-06
     +,   1.7726423E-06,   1.4301805E-06,   1.1489238E-06
     +,   9.1907054E-07,   7.3212851E-07,   5.8080883E-07
     +,   4.5889118E-07,   3.6110060E-07,   2.8300596E-07
     +,   2.2091454E-07,   1.7175419E-07,   1.3299892E-07
     +,   1.0257231E-07,   7.8785760E-08,   6.0266586E-08
     +,   4.5909736E-08,   3.4825856E-08,   2.6305724E-08
     +,   1.9784078E-08,   1.4814227E-08,   1.1043509E-08
     +,   8.1953440E-09,   6.0539573E-09,   4.4512949E-09
     +,   3.2575436E-09,   2.3725482E-09,   1.7196666E-09
     +,   1.2403529E-09,   8.9023194E-10,   6.3575317E-10
     +,   4.5174170E-10,   3.1935946E-10,   2.2462061E-10
     +,   1.5717182E-10,   1.0940812E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_hatt100 = Yx/0.497960784313725
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3225006E-06,   1.4283315E-06
     +,   1.5427953E-06,   1.6666219E-06,   1.8005995E-06
     +,   1.9455788E-06,   2.1024762E-06,   2.2722759E-06
     +,   2.4560322E-06,   2.6548819E-06,   2.8700331E-06
     +,   3.1027737E-06,   3.3544773E-06,   3.6266008E-06
     +,   3.9206857E-06,   4.2383599E-06,   4.5813408E-06
     +,   4.9514301E-06,   5.3505159E-06,   5.7805682E-06
     +,   6.2436411E-06,   6.7418637E-06,   7.2774346E-06
     +,   7.8526482E-06,   8.4698031E-06,   9.1313223E-06
     +,   9.8396285E-06,   1.0597199E-05,   1.1406539E-05
     +,   1.2270175E-05,   1.3190638E-05,   1.4170458E-05
     +,   1.5212140E-05,   1.6318176E-05,   1.7491006E-05
     +,   1.8733022E-05,   2.0046549E-05,   2.1433811E-05
     +,   2.2897031E-05,   2.4438164E-05,   2.6059239E-05
     +,   2.7762049E-05,   2.9548290E-05,   3.1419524E-05
     +,   3.3377190E-05,   3.5422534E-05,   3.7556729E-05
     +,   3.9780723E-05,   4.2095427E-05,   4.4501478E-05
     +,   4.6999474E-05,   4.9589868E-05,   5.2272924E-05
     +,   5.5048968E-05,   5.7917936E-05,   6.0879938E-05
     +,   6.3934844E-05,   6.7082445E-05,   7.0322552E-05
     +,   7.3654766E-05,   7.7078723E-05,   8.0593964E-05
     +,   8.4199848E-05,   8.7895831E-05,   9.1681337E-05
     +,   9.5555341E-05,   9.9517209E-05,   1.0356567E-04
     +,   1.0769979E-04,   1.1191810E-04,   1.1621933E-04
     +,   1.2060157E-04,   1.2506329E-04,   1.2960225E-04
     +,   1.3421630E-04,   1.3890321E-04,   1.4366031E-04
     +,   1.4848467E-04,   1.5337377E-04,   1.5832491E-04
     +,   1.6333513E-04,   1.6840213E-04,   1.7352343E-04
     +,   1.7869740E-04,   1.8392249E-04,   1.8919868E-04
     +,   1.9452586E-04,   1.9990603E-04,   2.0534160E-04
     +,   2.1083702E-04,   2.1639850E-04,   2.2203344E-04
     +,   2.2775111E-04,   2.3356335E-04,   2.3948344E-04
     +,   2.4552617E-04,   2.5170864E-04,   2.5804865E-04
     +,   2.6456596E-04,   2.7128006E-04,   2.7821175E-04
     +,   2.8538029E-04,   2.9280537E-04,   3.0050398E-04
     +,   3.0849184E-04,   3.1678201E-04,   3.2538382E-04
     +,   3.3430313E-04,   3.4354258E-04,   3.5310094E-04
     +,   3.6297319E-04,   3.7315232E-04,   3.8362830E-04
     +,   3.9439189E-04,   4.0543341E-04,   4.1674753E-04
     +,   4.2833289E-04,   4.4019663E-04,   4.5235443E-04
     +,   4.6483582E-04,   4.7768388E-04,   4.9095682E-04
     +,   5.0473027E-04,   5.1909650E-04,   5.3416408E-04
     +,   5.5005343E-04,   5.6689599E-04,   5.8482721E-04
     +,   6.0398289E-04,   6.2448852E-04,   6.4645597E-04
     +,   6.6997041E-04,   6.9508777E-04,   7.2182226E-04
     +,   7.5014622E-04,   7.7998446E-04,   8.1121095E-04
     +,   8.4365229E-04,   8.7709533E-04,   9.1129279E-04
     +,   9.4597216E-04,   9.8084845E-04,   1.0156430E-03
     +,   1.0500962E-03,   1.0839757E-03,   1.1170986E-03
     +,   1.1493393E-03,   1.1806353E-03,   1.2109963E-03
     +,   1.2405079E-03,   1.2693343E-03,   1.2977100E-03
     +,   1.3259441E-03,   1.3544202E-03,   1.3835826E-03
     +,   1.4139394E-03,   1.4460494E-03,   1.4805171E-03
     +,   1.5179719E-03,   1.5590414E-03,   1.6043280E-03
     +,   1.6543601E-03,   1.7095354E-03,   1.7700725E-03
     +,   1.8359531E-03,   1.9068703E-03,   1.9821946E-03
     +,   2.0609773E-03,   2.1419905E-03,   2.2238176E-03
     +,   2.3049787E-03,   2.3841201E-03,   2.4602397E-03
     +,   2.5328768E-03,   2.6023115E-03,   2.6696750E-03
     +,   2.7369440E-03,   2.8068251E-03,   2.8824622E-03
     +,   2.9670559E-03,   3.0633851E-03,   3.1733024E-03
     +,   3.2973718E-03,   3.4346604E-03,   3.5827567E-03
     +,   3.7380778E-03,   3.8963940E-03,   4.0535214E-03
     +,   4.2059654E-03,   4.3514483E-03,   4.4891941E-03
     +,   4.6198578E-03,   4.7451989E-03,   4.8675621E-03
     +,   4.9893707E-03,   5.1127062E-03,   5.2391635E-03
     +,   5.3700260E-03,   5.5065849E-03,   5.6505245E-03
     +,   5.8041089E-03,   5.9700157E-03,   6.1507416E-03
     +,   6.3476660E-03,   6.5601040E-03,   6.7849178E-03
     +,   7.0169871E-03,   7.2508375E-03,   7.4830838E-03
     +,   7.7148816E-03,   7.9530850E-03,   8.2090590E-03
     +,   8.4951669E-03,   8.8206446E-03,   9.1914330E-03
     +,   9.6182656E-03,   1.0129400E-02,   1.0777262E-02
     +,   1.1651197E-02,   1.2959164E-02,   1.5193913E-02
     +,   1.9111412E-02,   2.5150986E-02,   3.2984965E-02
     +,   4.2867702E-02,   5.8374722E-02,   8.7770194E-02
     +,   0.1397109    ,   0.2072634    ,   0.2598913    
     +,   0.2570231    ,   0.1921162    ,   0.1114399    
     +,   5.3290229E-02,   2.1801461E-02,   8.1166392E-03
     +,   2.9530800E-03,   1.1077401E-03,   4.8897445E-04
     +,   2.8082205E-04,   1.9515482E-04,   1.4808077E-04
     +,   1.1734531E-04,   9.5915813E-05,   8.0457066E-05
     +,   6.9058144E-05,   6.0655715E-05,   5.4598950E-05
     +,   5.0341321E-05,   4.7347941E-05,   4.5135912E-05
     +,   4.3331151E-05,   4.1685806E-05,   4.0059796E-05
     +,   3.8388182E-05,   3.6650894E-05,   3.4851390E-05
     +,   3.3003758E-05,   3.1125888E-05,   2.9236422E-05
     +,   2.7353426E-05,   2.5493586E-05,   2.3671777E-05
     +,   2.1900982E-05,   2.0192409E-05,   1.8555094E-05
     +,   1.6996135E-05,   1.5520860E-05,   1.4132827E-05
     +,   1.2833887E-05,   1.1624460E-05,   1.0503782E-05
     +,   9.4699972E-06,   8.5202973E-06,   7.6511697E-06
     +,   6.8586528E-06,   6.1382948E-06,   5.4855063E-06
     +,   4.8954894E-06,   4.3635209E-06,   3.8848784E-06
     +,   3.4550542E-06,   3.0696760E-06,   2.7246640E-06
     +,   2.4161525E-06,   2.1405933E-06,   1.8946878E-06
     +,   1.6754192E-06,   1.4800612E-06,   1.3061168E-06
     +,   1.1513541E-06,   1.0137434E-06,   8.9147954E-07
     +,   7.8292800E-07,   6.8663849E-07,   6.0130020E-07
     +,   5.2575035E-07,   4.5893833E-07,   3.9993134E-07
     +,   3.4788559E-07,   3.0205078E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_hatt105 = Yx/0.44086
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4831948E-05,   2.5861586E-05
     +,   2.6933536E-05,   2.8048516E-05,   2.9207165E-05
     +,   3.0410039E-05,   3.1657648E-05,   3.2950404E-05
     +,   3.4288645E-05,   3.5672721E-05,   3.7102887E-05
     +,   3.8579379E-05,   4.0102444E-05,   4.1672309E-05
     +,   4.3289288E-05,   4.4953726E-05,   4.6666097E-05
     +,   4.8427017E-05,   5.0237286E-05,   5.2097912E-05
     +,   5.4010223E-05,   5.5975874E-05,   5.7996844E-05
     +,   6.0075792E-05,   6.2215579E-05,   6.4419954E-05
     +,   6.6693181E-05,   6.9040318E-05,   7.1467206E-05
     +,   7.3980635E-05,   7.6588338E-05,   7.9299149E-05
     +,   8.2122999E-05,   8.5071108E-05,   8.8155983E-05
     +,   9.1391601E-05,   9.4793460E-05,   9.8378710E-05
     +,   1.0216659E-04,   1.0617799E-04,   1.1043667E-04
     +,   1.1496885E-04,   1.1980427E-04,   1.2497668E-04
     +,   1.3052470E-04,   1.3649334E-04,   1.4293524E-04
     +,   1.4991274E-04,   1.5750008E-04,   1.6578587E-04
     +,   1.7487627E-04,   1.8489751E-04,   1.9599889E-04
     +,   2.0835584E-04,   2.2216924E-04,   2.3766865E-04
     +,   2.5510744E-04,   2.7476050E-04,   2.9691614E-04
     +,   3.2186630E-04,   3.4989367E-04,   3.8125631E-04
     +,   4.1616830E-04,   4.5478751E-04,   4.9719686E-04
     +,   5.4338929E-04,   5.9327006E-04,   6.4664654E-04
     +,   7.0325244E-04,   7.6275528E-04,   8.2480593E-04
     +,   8.8907144E-04,   9.5531449E-04,   1.0234560E-03
     +,   1.0936907E-03,   1.1665993E-03,   1.2432846E-03
     +,   1.3255404E-03,   1.4160451E-03,   1.5185694E-03
     +,   1.6381689E-03,   1.7813761E-03,   1.9562615E-03
     +,   2.1724710E-03,   2.4411555E-03,   2.7751483E-03
     +,   3.1894925E-03,   3.7036687E-03,   4.3475479E-03
     +,   5.1742932E-03,   6.2777256E-03,   7.8006573E-03
     +,   9.9152671E-03,   1.2778356E-02,   1.6496353E-02
     +,   2.1105161E-02,   2.6503431E-02,   3.2403491E-02
     +,   3.8589567E-02,   4.5277949E-02,   5.2702431E-02
     +,   6.0565263E-02,   6.8992883E-02,   7.8431331E-02
     +,   8.8156216E-02,   9.7112395E-02,   0.1032097    
     +,   0.1042285    ,   0.1004720    ,   9.2776284E-02
     +,   8.2129143E-02,   7.0904247E-02,   6.1443068E-02
     +,   5.4813124E-02,   5.0016493E-02,   4.5101006E-02
     +,   3.9749458E-02,   3.4931727E-02,   3.1271715E-02
     +,   2.8588474E-02,   2.6293525E-02,   2.3962200E-02
     +,   2.1544334E-02,   1.9151092E-02,   1.6864056E-02
     +,   1.4758696E-02,   1.2941721E-02,   1.1496205E-02
     +,   1.0424234E-02,   9.6557820E-03,   9.0931300E-03
     +,   8.6468924E-03,   8.2502048E-03,   7.8602042E-03
     +,   7.4544591E-03,   7.0266081E-03,   6.5814494E-03
     +,   6.1298818E-03,   5.6844917E-03,   5.2566021E-03
     +,   4.8549683E-03,   4.4858041E-03,   4.1533923E-03
     +,   3.8608350E-03,   3.6103958E-03,   3.4033225E-03
     +,   3.2394961E-03,   3.1169951E-03,   3.0318275E-03
     +,   2.9780024E-03,   2.9479170E-03,   2.9330247E-03
     +,   2.9246025E-03,   2.9145430E-03,   2.8960321E-03
     +,   2.8640262E-03,   2.8154950E-03,   2.7494214E-03
     +,   2.6665772E-03,   2.5691490E-03,   2.4602553E-03
     +,   2.3434635E-03,   2.2223641E-03,   2.1002272E-03
     +,   1.9797808E-03,   1.8631322E-03,   1.7517742E-03
     +,   1.6466635E-03,   1.5483262E-03,   1.4569833E-03
     +,   1.3726651E-03,   1.2952784E-03,   1.2246529E-03
     +,   1.1605653E-03,   1.1027509E-03,   1.0508866E-03
     +,   1.0045901E-03,   9.6342253E-04,   9.2688832E-04
     +,   8.9444680E-04,   8.6553232E-04,   8.3957490E-04
     +,   8.1602170E-04,   7.9435261E-04,   7.7409734E-04
     +,   7.5484702E-04,   7.3625933E-04,   7.1805739E-04
     +,   7.0002751E-04,   6.8201777E-04,   6.6392520E-04
     +,   6.4569054E-04,   6.2729116E-04,   6.0873071E-04
     +,   5.9003424E-04,   5.7123962E-04,   5.5239612E-04
     +,   5.3355866E-04,   5.1478390E-04,   4.9612817E-04
     +,   4.7764904E-04,   4.5940100E-04,   4.4143459E-04
     +,   4.2379671E-04,   4.0653229E-04,   3.8967986E-04
     +,   3.7327397E-04,   3.5734571E-04,   3.4192146E-04
     +,   3.2702190E-04,   3.1266303E-04,   2.9885699E-04
     +,   2.8561160E-04,   2.7292880E-04,   2.6080650E-04
     +,   2.4923950E-04,   2.3821832E-04,   2.2772976E-04
     +,   2.1775704E-04,   2.0828232E-04,   1.9928422E-04
     +,   1.9073983E-04,   1.8262547E-04,   1.7491651E-04
     +,   1.6758751E-04,   1.6061285E-04,   1.5396792E-04
     +,   1.4762837E-04,   1.4157061E-04,   1.3577197E-04
     +,   1.3021153E-04,   1.2486974E-04,   1.1972826E-04
     +,   1.1477025E-04,   1.0998106E-04,   1.0534708E-04
     +,   1.0085639E-04,   9.6498843E-05,   9.2265778E-05
     +,   8.8149645E-05,   8.4144216E-05,   8.0244768E-05
     +,   7.6447664E-05,   7.2749986E-05,   6.9149712E-05
     +,   6.5645887E-05,   6.2238083E-05,   5.8926289E-05
     +,   5.5710909E-05,   5.2592924E-05,   4.9573264E-05
     +,   4.6653000E-05,   4.3833414E-05,   4.1115756E-05
     +,   3.8500952E-05,   3.5989811E-05,   3.3583059E-05
     +,   3.1281135E-05,   2.9084058E-05,   2.6991509E-05
     +,   2.5002984E-05,   2.3117609E-05,   2.1334050E-05
     +,   1.9650646E-05,   1.8065572E-05,   1.6576530E-05
     +,   1.5180949E-05,   1.3876100E-05,   1.2659008E-05
     +,   1.1526424E-05,   1.0474940E-05,   9.5010855E-06
     +,   8.6012869E-06,   7.7718332E-06,   7.0089873E-06
     +,   6.3090774E-06,   5.6683498E-06,   5.0831868E-06
     +,   4.5499492E-06,   4.0651589E-06,   3.6253716E-06
     +,   3.2273199E-06,   2.8678114E-06,   2.5438389E-06
     +,   2.2524985E-06,   1.9910767E-06,   1.7569847E-06
     +,   1.5477920E-06,   1.3612446E-06,   1.1952147E-06
     +,   1.0477486E-06,   9.1701742E-07,   8.0135231E-07
     +,   6.9920355E-07,   6.0916460E-07,   5.2993926E-07
     +,   4.6035780E-07,   3.9934923E-07,   3.4595237E-07
     +,   2.9929274E-07,   2.5858972E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_hatt75 = Yx/0.4606
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6586456E-05,   2.7519698E-05
     +,   2.8460654E-05,   2.9408580E-05,   3.0362793E-05
     +,   3.1322681E-05,   3.2287713E-05,   3.3257427E-05
     +,   3.4231467E-05,   3.5209603E-05,   3.6191690E-05
     +,   3.7177699E-05,   3.8167716E-05,   3.9161987E-05
     +,   4.0160856E-05,   4.1164796E-05,   4.2174412E-05
     +,   4.3190448E-05,   4.4213753E-05,   4.5245306E-05
     +,   4.6286201E-05,   4.7337595E-05,   4.8400758E-05
     +,   4.9477090E-05,   5.0567942E-05,   5.1674811E-05
     +,   5.2799172E-05,   5.3942513E-05,   5.5106306E-05
     +,   5.6292003E-05,   5.7500994E-05,   5.8734557E-05
     +,   5.9993912E-05,   6.1280080E-05,   6.2594008E-05
     +,   6.3936379E-05,   6.5307730E-05,   6.6708330E-05
     +,   6.8138266E-05,   6.9597292E-05,   7.1084942E-05
     +,   7.2600436E-05,   7.4142750E-05,   7.5710552E-05
     +,   7.7302277E-05,   7.8916113E-05,   8.0550060E-05
     +,   8.2202023E-05,   8.3869818E-05,   8.5551314E-05
     +,   8.7244589E-05,   8.8948080E-05,   9.0660869E-05
     +,   9.2382856E-05,   9.4115108E-05,   9.5860472E-05
     +,   9.7623779E-05,   9.9412631E-05,   1.0123802E-04
     +,   1.0311515E-04,   1.0506425E-04,   1.0711168E-04
     +,   1.0929075E-04,   1.1164314E-04,   1.1421999E-04
     +,   1.1708241E-04,   1.2030345E-04,   1.2396810E-04
     +,   1.2817462E-04,   1.3303416E-04,   1.3867169E-04
     +,   1.4522420E-04,   1.5284150E-04,   1.6168260E-04
     +,   1.7191519E-04,   1.8371262E-04,   1.9724926E-04
     +,   2.1269712E-04,   2.3022242E-04,   2.4997999E-04
     +,   2.7210583E-04,   2.9671713E-04,   3.2390168E-04
     +,   3.5372286E-04,   3.8621150E-04,   4.2138115E-04
     +,   4.5923199E-04,   4.9978722E-04,   5.4312445E-04
     +,   5.8945065E-04,   6.3918543E-04,   6.9307239E-04
     +,   7.5230986E-04,   8.1868516E-04,   8.9467037E-04
     +,   9.8344567E-04,   1.0888437E-03,   1.2151331E-03
     +,   1.3667651E-03,   1.5480756E-03,   1.7632282E-03
     +,   2.0164570E-03,   2.3128965E-03,   2.6597357E-03
     +,   3.0676587E-03,   3.5519190E-03,   4.1329022E-03
     +,   4.8365863E-03,   5.6952322E-03,   6.7463000E-03
     +,   8.0248881E-03,   9.5500946E-03,   1.1319420E-02
     +,   1.3333754E-02,   1.5654689E-02,   1.8486908E-02
     +,   2.2223935E-02,   2.7280370E-02,   3.3801839E-02
     +,   4.1787442E-02,   5.1279627E-02,   6.2148977E-02
     +,   7.4458875E-02,   8.8595681E-02,   0.1032748    
     +,   0.1143766    ,   0.1218958    ,   0.1264968    
     +,   0.1241702    ,   0.1191606    ,   0.1113449    
     +,   9.9209800E-02,   8.6260684E-02,   7.5157404E-02
     +,   6.8160802E-02,   6.1690103E-02,   5.3080663E-02
     +,   4.4231161E-02,   3.7510660E-02,   3.3271573E-02
     +,   3.0453505E-02,   2.7862582E-02,   2.4984634E-02
     +,   2.1977872E-02,   1.9171519E-02,   1.6733591E-02
     +,   1.4676326E-02,   1.2958475E-02,   1.1529834E-02
     +,   1.0340016E-02,   9.3453219E-03,   8.5096881E-03
     +,   7.7994107E-03,   7.1820188E-03,   6.6320067E-03
     +,   6.1364067E-03,   5.6942841E-03,   5.3107175E-03
     +,   4.9895067E-03,   4.7282367E-03,   4.5170761E-03
     +,   4.3406901E-03,   4.1816239E-03,   4.0237857E-03
     +,   3.8550671E-03,   3.6687765E-03,   3.4638906E-03
     +,   3.2442242E-03,   3.0169387E-03,   2.7907733E-03
     +,   2.5743409E-03,   2.3747629E-03,   2.1968405E-03
     +,   2.0428170E-03,   1.9126275E-03,   1.8044084E-03
     +,   1.7151837E-03,   1.6415190E-03,   1.5800118E-03
     +,   1.5276334E-03,   1.4819001E-03,   1.4409105E-03
     +,   1.4032857E-03,   1.3680749E-03,   1.3346456E-03
     +,   1.3025838E-03,   1.2716122E-03,   1.2415214E-03
     +,   1.2121428E-03,   1.1833170E-03,   1.1548897E-03
     +,   1.1267078E-03,   1.0986320E-03,   1.0705434E-03
     +,   1.0423489E-03,   1.0139954E-03,   9.8547409E-04
     +,   9.5682021E-04,   9.2810963E-04,   8.9945388E-04
     +,   8.7099220E-04,   8.4287749E-04,   8.1526133E-04
     +,   7.8828307E-04,   7.6206040E-04,   7.3667476E-04
     +,   7.1216840E-04,   6.8854203E-04,   6.6575524E-04
     +,   6.4372912E-04,   6.2235363E-04,   6.0149824E-04
     +,   5.8102113E-04,   5.6077651E-04,   5.4062688E-04
     +,   5.2045239E-04,   5.0015567E-04,   4.7966617E-04
     +,   4.5894366E-04,   4.3798107E-04,   4.1679962E-04
     +,   3.9544742E-04,   3.7399831E-04,   3.5254433E-04
     +,   3.3119062E-04,   3.1005000E-04,   2.8924062E-04
     +,   2.6887926E-04,   2.4907553E-04,   2.2993059E-04
     +,   2.1153486E-04,   1.9396524E-04,   1.7728253E-04
     +,   1.6153223E-04,   1.4674618E-04,   1.3293982E-04
     +,   1.2011508E-04,   1.0826219E-04,   9.7360469E-05
     +,   8.7379121E-05,   7.8279911E-05,   7.0019320E-05
     +,   6.2549341E-05,   5.5818604E-05,   4.9774255E-05
     +,   4.4363445E-05,   3.9533894E-05,   3.5234258E-05
     +,   3.1415344E-05,   2.8030761E-05,   2.5036579E-05
     +,   2.2391923E-05,   2.0059249E-05,   1.8004064E-05
     +,   1.6194852E-05,   1.4603085E-05,   1.3203173E-05
     +,   1.1972138E-05,   1.0889386E-05,   9.9365989E-06
     +,   9.0975846E-06,   8.3580044E-06,   7.7051554E-06
     +,   7.1278600E-06,   6.6163457E-06,   6.1619867E-06
     +,   5.7572352E-06,   5.3955223E-06,   5.0711060E-06
     +,   4.7789722E-06,   4.5147617E-06,   4.2747106E-06
     +,   4.0555615E-06,   3.8544854E-06,   3.6690483E-06
     +,   3.4971770E-06,   3.3370743E-06,   3.1872262E-06
     +,   3.0463257E-06,   2.9132805E-06,   2.7871515E-06
     +,   2.6671646E-06,   2.5526535E-06,   2.4430776E-06
     +,   2.3379710E-06,   2.2369611E-06,   2.1397291E-06
     +,   2.0460127E-06,   1.9556044E-06,   1.8683210E-06
     +,   1.7840231E-06,   1.7025848E-06,   1.6239106E-06
     +,   1.5479114E-06,   1.4745209E-06,   1.4036707E-06
     +,   1.3353110E-06,   1.2693873E-06,   1.2058574E-06
     +,   1.1446731E-06,   1.0857958E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_hatt80 = Yx/0.529803921568627
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.9374279E-06,   6.3875755E-06
     +,   6.8654804E-06,   7.3721881E-06,   7.9087104E-06
     +,   8.4760177E-06,   9.0750391E-06,   9.7066368E-06
     +,   1.0371594E-05,   1.1070657E-05,   1.1804437E-05
     +,   1.2573463E-05,   1.3378147E-05,   1.4218782E-05
     +,   1.5095523E-05,   1.6008380E-05,   1.6957210E-05
     +,   1.7941704E-05,   1.8961373E-05,   2.0015552E-05
     +,   2.1103393E-05,   2.2223843E-05,   2.3375629E-05
     +,   2.4557372E-05,   2.5767349E-05,   2.7003794E-05
     +,   2.8264662E-05,   2.9547764E-05,   3.0850755E-05
     +,   3.2171163E-05,   3.3506400E-05,   3.4853820E-05
     +,   3.6210746E-05,   3.7574540E-05,   3.8942646E-05
     +,   4.0312676E-05,   4.1682510E-05,   4.3050328E-05
     +,   4.4414912E-05,   4.5775436E-05,   4.7132038E-05
     +,   4.8485610E-05,   4.9838181E-05,   5.1193041E-05
     +,   5.2554959E-05,   5.3930373E-05,   5.5327659E-05
     +,   5.6757293E-05,   5.8232104E-05,   5.9767463E-05
     +,   6.1381492E-05,   6.3095205E-05,   6.4932639E-05
     +,   6.6921042E-05,   6.9090536E-05,   7.1474627E-05
     +,   7.4109565E-05,   7.7034405E-05,   8.0290542E-05
     +,   8.3921361E-05,   8.7971595E-05,   9.2486785E-05
     +,   9.7512064E-05,   1.0309183E-04,   1.0926846E-04
     +,   1.1608042E-04,   1.2356245E-04,   1.3174248E-04
     +,   1.4064212E-04,   1.5027322E-04,   1.6063869E-04
     +,   1.7172877E-04,   1.8352257E-04,   1.9598396E-04
     +,   2.0906374E-04,   2.2269785E-04,   2.3680630E-04
     +,   2.5129443E-04,   2.6605435E-04,   2.8096544E-04
     +,   2.9589466E-04,   3.1070196E-04,   3.2523938E-04
     +,   3.3935855E-04,   3.5290993E-04,   3.6575153E-04
     +,   3.7774944E-04,   3.8878695E-04,   3.9876564E-04
     +,   4.0761413E-04,   4.1529184E-04,   4.2179495E-04
     +,   4.2716169E-04,   4.3147904E-04,   4.3488649E-04
     +,   4.3758223E-04,   4.3982710E-04,   4.4194813E-04
     +,   4.4434078E-04,   4.4746898E-04,   4.5186077E-04
     +,   4.5810174E-04,   4.6682148E-04,   4.7867370E-04
     +,   4.9431057E-04,   5.1434949E-04,   5.3933373E-04
     +,   5.6969206E-04,   6.0570665E-04,   6.4748828E-04
     +,   6.9497479E-04,   7.4798061E-04,   8.0627704E-04
     +,   8.6976617E-04,   9.3868608E-04,   1.0139154E-03
     +,   1.0972645E-03,   1.1917859E-03,   1.3019483E-03
     +,   1.4336567E-03,   1.5939724E-03,   1.7904659E-03
     +,   2.0302185E-03,   2.3185620E-03,   2.6577625E-03
     +,   3.0460882E-03,   3.4781294E-03,   3.9469674E-03
     +,   4.4498360E-03,   4.9981438E-03,   5.6338804E-03
     +,   6.4520980E-03,   7.6234904E-03,   9.3924664E-03
     +,   1.2018966E-02,   1.5664395E-02,   2.0285279E-02
     +,   2.5681006E-02,   3.1839248E-02,   3.9077230E-02
     +,   4.7344357E-02,   5.6323737E-02,   6.6741541E-02
     +,   7.9901278E-02,   9.7000413E-02,   0.1166305    
     +,   0.1326683    ,   0.1406836    ,   0.1402802    
     +,   0.1366462    ,   0.1305656    ,   0.1191169    
     +,   0.1062519    ,   9.7672567E-02,   8.4735364E-02
     +,   6.8127476E-02,   5.6244787E-02,   4.7899418E-02
     +,   4.0781561E-02,   3.5312645E-02,   3.1471163E-02
     +,   2.8345454E-02,   2.5217801E-02,   2.2068581E-02
     +,   1.9213876E-02,   1.6812487E-02,   1.4826898E-02
     +,   1.3199615E-02,   1.1902339E-02,   1.0885551E-02
     +,   1.0065106E-02,   9.3595497E-03,   8.7218788E-03
     +,   8.1389816E-03,   7.6114722E-03,   7.1349484E-03
     +,   6.6938242E-03,   6.2668193E-03,   5.8371727E-03
     +,   5.4003065E-03,   4.9652033E-03,   4.5499247E-03
     +,   4.1743694E-03,   3.8537029E-03,   3.5946195E-03
     +,   3.3948056E-03,   3.2448075E-03,   3.1310343E-03
     +,   3.0388385E-03,   2.9549021E-03,   2.8687415E-03
     +,   2.7734116E-03,   2.6655367E-03,   2.5449081E-03
     +,   2.4137329E-03,   2.2757561E-03,   2.1353606E-03
     +,   1.9967500E-03,   1.8633404E-03,   1.7374438E-03
     +,   1.6202023E-03,   1.5117330E-03,   1.4114027E-03
     +,   1.3181714E-03,   1.2309056E-03,   1.1485941E-03
     +,   1.0704885E-03,   9.9615357E-04,   9.2543365E-04
     +,   8.5837790E-04,   7.9515635E-04,   7.3598191E-04
     +,   6.8103627E-04,   6.3042337E-04,   5.8415160E-04
     +,   5.4213282E-04,   5.0418935E-04,   4.7006941E-04
     +,   4.3947250E-04,   4.1207171E-04,   3.8752626E-04
     +,   3.6549967E-04,   3.4567114E-04,   3.2773998E-04
     +,   3.1143028E-04,   2.9649248E-04,   2.8270527E-04
     +,   2.6987409E-04,   2.5782848E-04,   2.4642225E-04
     +,   2.3553232E-04,   2.2505668E-04,   2.1491165E-04
     +,   2.0503176E-04,   1.9536844E-04,   1.8588685E-04
     +,   1.7656473E-04,   1.6739190E-04,   1.5836688E-04
     +,   1.4949568E-04,   1.4078997E-04,   1.3226639E-04
     +,   1.2394440E-04,   1.1584441E-04,   1.0798728E-04
     +,   1.0039371E-04,   9.3082970E-05,   8.6071712E-05
     +,   7.9374098E-05,   7.3001975E-05,   6.6963483E-05
     +,   6.1263607E-05,   5.5904587E-05,   5.0885632E-05
     +,   4.6202804E-05,   4.1849638E-05,   3.7817692E-05
     +,   3.4096527E-05,   3.0673829E-05,   2.7535983E-05
     +,   2.4668601E-05,   2.2056534E-05,   1.9684041E-05
     +,   1.7535223E-05,   1.5594424E-05,   1.3846011E-05
     +,   1.2274758E-05,   1.0866080E-05,   9.6060012E-06
     +,   8.4811636E-06,   7.4789909E-06,   6.5877839E-06
     +,   5.7966377E-06,   5.0954118E-06,   4.4747876E-06
     +,   3.9262864E-06,   3.4421041E-06,   3.0152221E-06
     +,   2.6392333E-06,   2.3084172E-06,   2.0175885E-06
     +,   1.7621423E-06,   1.5379325E-06,   1.3412932E-06
     +,   1.1689408E-06,   1.0179831E-06,   8.8584284E-07
     +,   7.7024248E-07,   6.6918011E-07,   5.8087716E-07
     +,   5.0377685E-07,   4.3649814E-07,   3.7783451E-07
     +,   3.2671682E-07,   2.8221169E-07,   2.4349328E-07
     +,   2.0984061E-07,   1.8061627E-07,   1.5526416E-07
     +,   1.3329287E-07,   1.1427379E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_hatt85 = Yx/0.557117647058823
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6138072E-05,   1.6565622E-05
     +,   1.7000211E-05,   1.7442037E-05,   1.7891289E-05
     +,   1.8348155E-05,   1.8812818E-05,   1.9285442E-05
     +,   1.9766179E-05,   2.0255186E-05,   2.0752575E-05
     +,   2.1258453E-05,   2.1772894E-05,   2.2295948E-05
     +,   2.2827640E-05,   2.3367958E-05,   2.3916857E-05
     +,   2.4474257E-05,   2.5040030E-05,   2.5614027E-05
     +,   2.6196023E-05,   2.6785785E-05,   2.7382997E-05
     +,   2.7987338E-05,   2.8598377E-05,   2.9215696E-05
     +,   2.9838782E-05,   3.0467099E-05,   3.1100033E-05
     +,   3.1736930E-05,   3.2377095E-05,   3.3019758E-05
     +,   3.3664117E-05,   3.4309316E-05,   3.4954457E-05
     +,   3.5598561E-05,   3.6240668E-05,   3.6879712E-05
     +,   3.7514656E-05,   3.8144346E-05,   3.8767655E-05
     +,   3.9383442E-05,   3.9990489E-05,   4.0587613E-05
     +,   4.1173585E-05,   4.1747218E-05,   4.2307314E-05
     +,   4.2852698E-05,   4.3382261E-05,   4.3894928E-05
     +,   4.4389722E-05,   4.4865792E-05,   4.5322362E-05
     +,   4.5758934E-05,   4.6175126E-05,   4.6570924E-05
     +,   4.6946618E-05,   4.7302892E-05,   4.7640966E-05
     +,   4.7962592E-05,   4.8270318E-05,   4.8567403E-05
     +,   4.8858114E-05,   4.9147828E-05,   4.9443199E-05
     +,   4.9752216E-05,   5.0084524E-05,   5.0451494E-05
     +,   5.0866402E-05,   5.1344563E-05,   5.1903480E-05
     +,   5.2562878E-05,   5.3344847E-05,   5.4273674E-05
     +,   5.5375891E-05,   5.6680168E-05,   5.8216920E-05
     +,   6.0017985E-05,   6.2116414E-05,   6.4545849E-05
     +,   6.7339606E-05,   7.0530572E-05,   7.4149691E-05
     +,   7.8225989E-05,   8.2784689E-05,   8.7847446E-05
     +,   9.3430332E-05,   9.9544246E-05,   1.0619286E-04
     +,   1.1337341E-04,   1.2107561E-04,   1.2928108E-04
     +,   1.3796343E-04,   1.4708951E-04,   1.5661880E-04
     +,   1.6650358E-04,   1.7669157E-04,   1.8712442E-04
     +,   1.9774174E-04,   2.0847924E-04,   2.1927294E-04
     +,   2.3005750E-04,   2.4077043E-04,   2.5134996E-04
     +,   2.6173863E-04,   2.7188275E-04,   2.8173235E-04
     +,   2.9124226E-04,   3.0037295E-04,   3.0908969E-04
     +,   3.1736257E-04,   3.2516825E-04,   3.3248917E-04
     +,   3.3931682E-04,   3.4565252E-04,   3.5151275E-04
     +,   3.5693307E-04,   3.6197668E-04,   3.6674191E-04
     +,   3.7137512E-04,   3.7608147E-04,   3.8114024E-04
     +,   3.8691703E-04,   3.9387771E-04,   4.0259663E-04
     +,   4.1375970E-04,   4.2816350E-04,   4.4669936E-04
     +,   4.7033449E-04,   5.0007302E-04,   5.3692056E-04
     +,   5.8182661E-04,   6.3564378E-04,   6.9907075E-04
     +,   7.7263289E-04,   8.5666473E-04,   9.5133245E-04
     +,   1.0567068E-03,   1.1729189E-03,   1.3003986E-03
     +,   1.4402426E-03,   1.5947312E-03,   1.7679440E-03
     +,   1.9663488E-03,   2.1991560E-03,   2.4783120E-03
     +,   2.8178487E-03,   3.2325983E-03,   3.7366997E-03
     +,   4.3428079E-03,   5.0634514E-03,   5.9152734E-03
     +,   6.9229356E-03,   8.1163477E-03,   9.5236115E-03
     +,   1.1194882E-02,   1.3307526E-02,   1.6281061E-02
     +,   2.0649543E-02,   2.6753645E-02,   3.4878407E-02
     +,   4.5318678E-02,   5.7161950E-02,   6.9636427E-02
     +,   8.7036394E-02,   0.1126142    ,   0.1328259    
     +,   0.1404326    ,   0.1465241    ,   0.1524465    
     +,   0.1548311    ,   0.1462832    ,   0.1296984    
     +,   0.1121075    ,   9.9589497E-02,   8.7340213E-02
     +,   7.1058244E-02,   5.6794837E-02,   4.6312783E-02
     +,   3.6658537E-02,   2.8584233E-02,   2.3182824E-02
     +,   1.9755378E-02,   1.7263159E-02,   1.5265013E-02
     +,   1.3757193E-02,   1.2725678E-02,   1.1991105E-02
     +,   1.1318692E-02,   1.0549966E-02,   9.6457144E-03
     +,   8.6574452E-03,   7.6747565E-03,   6.7801694E-03
     +,   6.0234671E-03,   5.4159835E-03,   4.9395515E-03
     +,   4.5617656E-03,   4.2497311E-03,   3.9779004E-03
     +,   3.7299213E-03,   3.4969216E-03,   3.2746703E-03
     +,   3.0611726E-03,   2.8552134E-03,   2.6557252E-03
     +,   2.4618311E-03,   2.2731381E-03,   2.0899845E-03
     +,   1.9134431E-03,   1.7451284E-03,   1.5868328E-03
     +,   1.4401085E-03,   1.3059611E-03,   1.1847056E-03
     +,   1.0759890E-03,   9.7891281E-04,   8.9222018E-04
     +,   8.1450702E-04,   7.4439746E-04,   6.8064703E-04
     +,   6.2221708E-04,   5.6829967E-04,   5.1829848E-04
     +,   4.7179693E-04,   4.2851956E-04,   3.8829332E-04
     +,   3.5100669E-04,   3.1657581E-04,   2.8492347E-04
     +,   2.5596455E-04,   2.2959455E-04,   2.0568435E-04
     +,   1.8408350E-04,   1.6462681E-04,   1.4713584E-04
     +,   1.3142850E-04,   1.1732653E-04,   1.0465985E-04
     +,   9.3270195E-05,   8.3014871E-05,   7.3768701E-05
     +,   6.5423104E-05,   5.7884681E-05,   5.1074261E-05
     +,   4.4925138E-05,   3.9380408E-05,   3.4390567E-05
     +,   2.9912077E-05,   2.5906165E-05,   2.2336715E-05
     +,   1.9169864E-05,   1.6373571E-05,   1.3916972E-05
     +,   1.1770108E-05,   9.9041263E-06,   8.2914203E-06
     +,   6.9056091E-06,   5.7216071E-06,   4.7158869E-06
     +,   3.8666290E-06,   3.1537165E-06,   2.5587447E-06
     +,   2.0650959E-06,   1.6579321E-06,   1.3240450E-06
     +,   1.0518283E-06,   8.3118221E-07,   6.5337224E-07
     +,   5.1089910E-07,   3.9738967E-07,   3.0747418E-07
     +,   2.3665487E-07,   1.8118975E-07,   1.3799365E-07
     +,   1.0454415E-07,   7.8785668E-08,   5.9062160E-08
     +,   4.4043031E-08,   3.2670719E-08,   2.4107083E-08
     +,   1.7694688E-08,   1.2919436E-08,   9.3832915E-09
     +,   6.7790245E-09,   4.8717848E-09,   3.4826724E-09
     +,   2.4764775E-09,   1.7517109E-09,   1.2324984E-09
     +,   8.6261015E-10,   6.0053273E-10,   4.1587428E-10
     +,   2.8647049E-10,   1.9629050E-10,   1.3378583E-10
     +,   9.0703008E-11,   6.1167883E-11,   4.1032320E-11
     +,   2.7379012E-11,   1.8172318E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_hatt90 = Yx/0.552176470588235
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.8166111E-08,   1.0268502E-07
     +,   1.1946409E-07,   1.3882996E-07,   1.6115153E-07
     +,   1.8684428E-07,   2.1637520E-07,   2.5026819E-07
     +,   2.8910790E-07,   3.3354894E-07,   3.8431685E-07
     +,   4.4221665E-07,   5.0813799E-07,   5.8306176E-07
     +,   6.6806399E-07,   7.6432246E-07,   8.7312077E-07
     +,   9.9585236E-07,   1.1340250E-06,   1.2892609E-06
     +,   1.4632999E-06,   1.6579969E-06,   1.8753175E-06
     +,   2.1173512E-06,   2.3862638E-06,   2.6843413E-06
     +,   3.0139379E-06,   3.3774766E-06,   3.7774289E-06
     +,   4.2162969E-06,   4.6965820E-06,   5.2207638E-06
     +,   5.7912634E-06,   6.4104111E-06,   7.0804108E-06
     +,   7.8032963E-06,   8.5808888E-06,   9.4147426E-06
     +,   1.0306167E-05,   1.1256028E-05,   1.2264905E-05
     +,   1.3332887E-05,   1.4459604E-05,   1.5644182E-05
     +,   1.6885211E-05,   1.8180717E-05,   1.9528150E-05
     +,   2.0924381E-05,   2.2365693E-05,   2.3847802E-05
     +,   2.5365884E-05,   2.6914600E-05,   2.8488139E-05
     +,   3.0080399E-05,   3.1684773E-05,   3.3294611E-05
     +,   3.4903027E-05,   3.6503130E-05,   3.8088150E-05
     +,   3.9651502E-05,   4.1186984E-05,   4.2688884E-05
     +,   4.4152010E-05,   4.5572040E-05,   4.6945515E-05
     +,   4.8269823E-05,   4.9543596E-05,   5.0766499E-05
     +,   5.1939580E-05,   5.3065018E-05,   5.4146487E-05
     +,   5.5188808E-05,   5.6198271E-05,   5.7182257E-05
     +,   5.8149450E-05,   5.9109589E-05,   6.0073307E-05
     +,   6.1052044E-05,   6.2057916E-05,   6.3103478E-05
     +,   6.4201420E-05,   6.5364577E-05,   6.6605389E-05
     +,   6.7936031E-05,   6.9367787E-05,   7.0911272E-05
     +,   7.2575705E-05,   7.4369258E-05,   7.6298355E-05
     +,   7.8367942E-05,   8.0581216E-05,   8.2939441E-05
     +,   8.5441905E-05,   8.8086228E-05,   9.0868198E-05
     +,   9.3781637E-05,   9.6819123E-05,   9.9971541E-05
     +,   1.0322915E-04,   1.0658099E-04,   1.1001632E-04
     +,   1.1352405E-04,   1.1709436E-04,   1.2071813E-04
     +,   1.2438875E-04,   1.2810215E-04,   1.3185748E-04
     +,   1.3565800E-04,   1.3951205E-04,   1.4343350E-04
     +,   1.4744184E-04,   1.5156344E-04,   1.5583076E-04
     +,   1.6028326E-04,   1.6496591E-04,   1.6992916E-04
     +,   1.7522711E-04,   1.8091645E-04,   1.8705339E-04
     +,   1.9369223E-04,   2.0088219E-04,   2.0866431E-04
     +,   2.1706897E-04,   2.2611482E-04,   2.3580680E-04
     +,   2.4613537E-04,   2.5708057E-04,   2.6861305E-04
     +,   2.8070269E-04,   2.9332418E-04,   3.0647009E-04
     +,   3.2015951E-04,   3.3445266E-04,   3.4945886E-04
     +,   3.6534740E-04,   3.8234913E-04,   4.0075282E-04
     +,   4.2089281E-04,   4.4313094E-04,   4.6782458E-04
     +,   4.9528916E-04,   5.2575796E-04,   5.5934372E-04
     +,   5.9600372E-04,   6.3551584E-04,   6.7748630E-04
     +,   7.2137185E-04,   7.6653715E-04,   8.1235101E-04
     +,   8.5831218E-04,   9.0419676E-04,   9.5020531E-04
     +,   9.9709828E-04,   1.0462714E-03,   1.0997321E-03
     +,   1.1599474E-03,   1.2295663E-03,   1.3110472E-03
     +,   1.4062566E-03,   1.5161544E-03,   1.6407310E-03
     +,   1.7792202E-03,   1.9306396E-03,   2.0945417E-03
     +,   2.2717707E-03,   2.4648891E-03,   2.6779205E-03
     +,   2.9152213E-03,   3.1795066E-03,   3.4699005E-03
     +,   3.7821871E-03,   4.1143340E-03,   4.4795037E-03
     +,   4.9249614E-03,   5.5516935E-03,   6.5324861E-03
     +,   8.1293257E-03,   1.0680786E-02,   1.4453857E-02
     +,   1.9309845E-02,   2.4718961E-02,   3.1002782E-02
     +,   3.9982583E-02,   5.2728467E-02,   7.0785902E-02
     +,   9.5147826E-02,   0.1204151    ,   0.1453831    
     +,   0.1724076    ,   0.1835787    ,   0.1767039    
     +,   0.1629770    ,   0.1418481    ,   0.1178191    
     +,   9.5505357E-02,   7.3080324E-02,   5.7329394E-02
     +,   5.0062276E-02,   4.3840062E-02,   3.6412925E-02
     +,   2.9327396E-02,   2.3529829E-02,   1.9120244E-02
     +,   1.6001593E-02,   1.4043513E-02,   1.2953860E-02
     +,   1.2262841E-02,   1.1554966E-02,   1.0618901E-02
     +,   9.4304346E-03,   8.0838343E-03,   6.7237318E-03
     +,   5.4826643E-03,   4.4407444E-03,   3.6193659E-03
     +,   2.9986326E-03,   2.5396820E-03,   2.2006899E-03
     +,   1.9451069E-03,   1.7445724E-03,   1.5789995E-03
     +,   1.4353957E-03,   1.3061571E-03,   1.1873224E-03
     +,   1.0771032E-03,   9.7481016E-04,   8.8017370E-04
     +,   7.9297478E-04,   7.1290397E-04,   6.3956011E-04
     +,   5.7249737E-04,   5.1126769E-04,   4.5545134E-04
     +,   4.0467485E-04,   3.5861292E-04,   3.1696845E-04
     +,   2.7946467E-04,   2.4583621E-04,   2.1581788E-04
     +,   1.8913977E-04,   1.6552967E-04,   1.4471676E-04
     +,   1.2643315E-04,   1.1041777E-04,   9.6421536E-05
     +,   8.4211606E-05,   7.3572635E-05,   6.4307707E-05
     +,   5.6239816E-05,   4.9212227E-05,   4.3086122E-05
     +,   3.7740218E-05,   3.3069635E-05,   2.8983673E-05
     +,   2.5404092E-05,   2.2263772E-05,   1.9505425E-05
     +,   1.7079954E-05,   1.4945134E-05,   1.3064765E-05
     +,   1.1407842E-05,   9.9476083E-06,   8.6608206E-06
     +,   7.5273151E-06,   6.5296017E-06,   5.6522640E-06
     +,   4.8817492E-06,   4.2061288E-06,   3.6148140E-06
     +,   3.0983344E-06,   2.6482389E-06,   2.2569873E-06
     +,   1.9178094E-06,   1.6246025E-06,   1.3718885E-06
     +,   1.1547721E-06,   9.6883264E-07,   8.1013695E-07
     +,   6.7514947E-07,   5.6073924E-07,   4.6410963E-07
     +,   3.8279862E-07,   3.1462471E-07,   2.5768139E-07
     +,   2.1029336E-07,   1.7100862E-07,   1.3856400E-07
     +,   1.1186973E-07,   8.9992227E-08,   7.2130057E-08
     +,   5.7603394E-08,   4.5834170E-08,   3.6336520E-08
     +,   2.8701178E-08,   2.2587207E-08,   1.7710130E-08
     +,   1.3835085E-08,   1.0767970E-08,   8.3499323E-09
     +,   6.4508923E-09,   4.9653543E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_hatt95 = Yx/0.523352941176471
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5116296E-05,   3.5976180E-05
     +,   3.6846621E-05,   3.7727503E-05,   3.8618713E-05
     +,   3.9520186E-05,   4.0431842E-05,   4.1353665E-05
     +,   4.2285628E-05,   4.3227843E-05,   4.4180353E-05
     +,   4.5143341E-05,   4.6116977E-05,   4.7101508E-05
     +,   4.8097307E-05,   4.9104725E-05,   5.0124250E-05
     +,   5.1156414E-05,   5.2201871E-05,   5.3261341E-05
     +,   5.4335622E-05,   5.5425644E-05,   5.6532368E-05
     +,   5.7656976E-05,   5.8800582E-05,   5.9964565E-05
     +,   6.1150306E-05,   6.2359315E-05,   6.3593201E-05
     +,   6.4853622E-05,   6.6142406E-05,   6.7461362E-05
     +,   6.8812420E-05,   7.0197595E-05,   7.1618888E-05
     +,   7.3078343E-05,   7.4578114E-05,   7.6120210E-05
     +,   7.7706827E-05,   7.9339887E-05,   8.1021506E-05
     +,   8.2753555E-05,   8.4537911E-05,   8.6376363E-05
     +,   8.8270455E-05,   9.0221780E-05,   9.2231574E-05
     +,   9.4301053E-05,   9.6431111E-05,   9.8622571E-05
     +,   1.0087596E-04,   1.0319168E-04,   1.0556971E-04
     +,   1.0801019E-04,   1.1051263E-04,   1.1307666E-04
     +,   1.1570161E-04,   1.1838667E-04,   1.2113091E-04
     +,   1.2393329E-04,   1.2679269E-04,   1.2970816E-04
     +,   1.3267838E-04,   1.3570256E-04,   1.3877988E-04
     +,   1.4190956E-04,   1.4509133E-04,   1.4832497E-04
     +,   1.5161085E-04,   1.5494959E-04,   1.5834242E-04
     +,   1.6179080E-04,   1.6529718E-04,   1.6886422E-04
     +,   1.7249532E-04,   1.7619466E-04,   1.7996678E-04
     +,   1.8381678E-04,   1.8775061E-04,   1.9177487E-04
     +,   1.9589611E-04,   2.0012187E-04,   2.0445960E-04
     +,   2.0891750E-04,   2.1350340E-04,   2.1822572E-04
     +,   2.2309220E-04,   2.2811112E-04,   2.3328955E-04
     +,   2.3863484E-04,   2.4415337E-04,   2.4985065E-04
     +,   2.5573131E-04,   2.6179920E-04,   2.6805678E-04
     +,   2.7450509E-04,   2.8114393E-04,   2.8797128E-04
     +,   2.9498391E-04,   3.0217619E-04,   3.0954176E-04
     +,   3.1707116E-04,   3.2475410E-04,   3.3257750E-04
     +,   3.4052707E-04,   3.4858659E-04,   3.5673750E-04
     +,   3.6495936E-04,   3.7323037E-04,   3.8152735E-04
     +,   3.8982442E-04,   3.9809576E-04,   4.0631261E-04
     +,   4.1444640E-04,   4.2246652E-04,   4.3034283E-04
     +,   4.3804309E-04,   4.4553613E-04,   4.5278986E-04
     +,   4.5977262E-04,   4.6645349E-04,   4.7280188E-04
     +,   4.7878793E-04,   4.8438367E-04,   4.8956281E-04
     +,   4.9429992E-04,   4.9857254E-04,   5.0236011E-04
     +,   5.0564471E-04,   5.0841062E-04,   5.1064545E-04
     +,   5.1233964E-04,   5.1348621E-04,   5.1408168E-04
     +,   5.1412551E-04,   5.1362009E-04,   5.1257090E-04
     +,   5.1098625E-04,   5.0887757E-04,   5.0625863E-04
     +,   5.0314568E-04,   4.9955881E-04,   4.9551862E-04
     +,   4.9104914E-04,   4.8617649E-04,   4.8092849E-04
     +,   4.7533560E-04,   4.6942983E-04,   4.6324581E-04
     +,   4.5681983E-04,   4.5019103E-04,   4.4340090E-04
     +,   4.3649401E-04,   4.2951797E-04,   4.2252417E-04
     +,   4.1556885E-04,   4.0871411E-04,   4.0202719E-04
     +,   3.9558328E-04,   3.8946740E-04,   3.8377347E-04
     +,   3.7860827E-04,   3.7409260E-04,   3.7036263E-04
     +,   3.6757236E-04,   3.6589432E-04,   3.6552205E-04
     +,   3.6667028E-04,   3.6957458E-04,   3.7449208E-04
     +,   3.8169787E-04,   3.9148316E-04,   4.0415017E-04
     +,   4.2000684E-04,   4.3935815E-04,   4.6249924E-04
     +,   4.8970658E-04,   5.2122411E-04,   5.5725599E-04
     +,   5.9795874E-04,   6.4343156E-04,   6.9370796E-04
     +,   7.4875145E-04,   8.0846250E-04,   8.7267440E-04
     +,   9.4115891E-04,   1.0136382E-03,   1.0898063E-03
     +,   1.1693472E-03,   1.2519568E-03,   1.3374005E-03
     +,   1.4255589E-03,   1.5164954E-03,   1.6105573E-03
     +,   1.7084826E-03,   1.8115087E-03,   1.9214614E-03
     +,   2.0408190E-03,   2.1726906E-03,   2.3207068E-03
     +,   2.4887717E-03,   2.6807531E-03,   2.9001727E-03
     +,   3.1499278E-03,   3.4322198E-03,   3.7488018E-03
     +,   4.1014613E-03,   4.4926228E-03,   4.9259556E-03
     +,   5.4068300E-03,   5.9430795E-03,   6.5467027E-03
     +,   7.2374782E-03,   8.0475146E-03,   9.0231337E-03
     +,   1.0218933E-02,   1.1681628E-02,   1.3429999E-02
     +,   1.5447516E-02,   1.7707037E-02,   2.0230347E-02
     +,   2.3147481E-02,   2.6688254E-02,   3.1060779E-02
     +,   3.6275562E-02,   4.2065524E-02,   4.7991257E-02
     +,   5.3642299E-02,   5.8714800E-02,   6.2890321E-02
     +,   6.5977603E-02,   6.8451494E-02,   7.1080185E-02
     +,   7.3692888E-02,   7.5479940E-02,   7.6257698E-02
     +,   7.6285884E-02,   7.5241044E-02,   7.2697319E-02
     +,   6.9396861E-02,   6.6301897E-02,   6.3324235E-02
     +,   5.9907071E-02,   5.5801362E-02,   5.1312469E-02
     +,   4.7101203E-02,   4.3590412E-02,   4.0674083E-02
     +,   3.8012270E-02,   3.5361625E-02,   3.2592673E-02
     +,   2.9664660E-02,   2.6675796E-02,   2.3803614E-02
     +,   2.1170408E-02,   1.8803911E-02,   1.6684003E-02
     +,   1.4783996E-02,   1.3083539E-02,   1.1568720E-02
     +,   1.0226080E-02,   9.0360232E-03,   7.9724463E-03
     +,   7.0093293E-03,   6.1280774E-03,   5.3198775E-03
     +,   4.5834719E-03,   3.9208112E-03,   3.3333902E-03
     +,   2.8204503E-03,   2.3787776E-03,   2.0032017E-03
     +,   1.6872534E-03,   1.4237735E-03,   1.2054676E-03
     +,   1.0253233E-03,   8.7686942E-04,   7.5441389E-04
     +,   6.5309147E-04,   5.6888320E-04,   4.9851980E-04
     +,   4.3939357E-04,   3.8942115E-04,   3.4695072E-04
     +,   3.1065525E-04,   2.7947198E-04,   2.5253597E-04
     +,   2.2914278E-04,   2.0871752E-04,   1.9078478E-04
     +,   1.7495459E-04,   1.6090176E-04,   1.4835803E-04
     +,   1.3709841E-04,   1.2693598E-04,   1.1771355E-04
     +,   1.0930068E-04,   1.0158768E-04,   9.4484167E-05
     +,   8.7914574E-05,   8.1817328E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_hatt100 = Yx/0.497960784313725
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.5013443E-05,   5.6854398E-05
     +,   5.8775837E-05,   6.0782015E-05,   6.2877334E-05
     +,   6.5066284E-05,   6.7353525E-05,   6.9743794E-05
     +,   7.2241863E-05,   7.4852673E-05,   7.7581179E-05
     +,   8.0432284E-05,   8.3410952E-05,   8.6522043E-05
     +,   8.9770452E-05,   9.3160917E-05,   9.6697986E-05
     +,   1.0038613E-04,   1.0422956E-04,   1.0823218E-04
     +,   1.1239776E-04,   1.1672952E-04,   1.2123042E-04
     +,   1.2590323E-04,   1.3074964E-04,   1.3577154E-04
     +,   1.4096983E-04,   1.4634499E-04,   1.5189694E-04
     +,   1.5762480E-04,   1.6352718E-04,   1.6960198E-04
     +,   1.7584627E-04,   1.8225655E-04,   1.8882868E-04
     +,   1.9555750E-04,   2.0243734E-04,   2.0946181E-04
     +,   2.1662415E-04,   2.2391614E-04,   2.3132989E-04
     +,   2.3885639E-04,   2.4648634E-04,   2.5420988E-04
     +,   2.6201687E-04,   2.6989667E-04,   2.7783873E-04
     +,   2.8583233E-04,   2.9386627E-04,   3.0192974E-04
     +,   3.1001226E-04,   3.1810327E-04,   3.2619227E-04
     +,   3.3427041E-04,   3.4232772E-04,   3.5035639E-04
     +,   3.5834845E-04,   3.6629682E-04,   3.7419575E-04
     +,   3.8204016E-04,   3.8982643E-04,   3.9755166E-04
     +,   4.0521420E-04,   4.1281374E-04,   4.2035140E-04
     +,   4.2782933E-04,   4.3525157E-04,   4.4262188E-04
     +,   4.4994731E-04,   4.5723488E-04,   4.6449303E-04
     +,   4.7173150E-04,   4.7896136E-04,   4.8619340E-04
     +,   4.9344043E-04,   5.0071639E-04,   5.0803443E-04
     +,   5.1540812E-04,   5.2285293E-04,   5.3038361E-04
     +,   5.3801347E-04,   5.4575840E-04,   5.5363117E-04
     +,   5.6164543E-04,   5.6981319E-04,   5.7814654E-04
     +,   5.8665493E-04,   5.9534807E-04,   6.0423231E-04
     +,   6.1331387E-04,   6.2259584E-04,   6.3208025E-04
     +,   6.4176589E-04,   6.5164996E-04,   6.6172797E-04
     +,   6.7199091E-04,   6.8242999E-04,   6.9303100E-04
     +,   7.0377975E-04,   7.1465777E-04,   7.2564511E-04
     +,   7.3671906E-04,   7.4785436E-04,   7.5902446E-04
     +,   7.7019935E-04,   7.8134908E-04,   7.9243985E-04
     +,   8.0343749E-04,   8.1430684E-04,   8.2501065E-04
     +,   8.3551108E-04,   8.4577000E-04,   8.5574773E-04
     +,   8.6540618E-04,   8.7470451E-04,   8.8360423E-04
     +,   8.9206593E-04,   9.0005080E-04,   9.0752158E-04
     +,   9.1444113E-04,   9.2077348E-04,   9.2648284E-04
     +,   9.3153701E-04,   9.3590282E-04,   9.3955087E-04
     +,   9.4245211E-04,   9.4458059E-04,   9.4591163E-04
     +,   9.4642449E-04,   9.4609905E-04,   9.4491994E-04
     +,   9.4287342E-04,   9.3995058E-04,   9.3614432E-04
     +,   9.3145180E-04,   9.2587539E-04,   9.1941998E-04
     +,   9.1209600E-04,   9.0391771E-04,   8.9490344E-04
     +,   8.8507799E-04,   8.7446946E-04,   8.6311140E-04
     +,   8.5104076E-04,   8.3830202E-04,   8.2494156E-04
     +,   8.1101089E-04,   7.9656584E-04,   7.8166678E-04
     +,   7.6637615E-04,   7.5075979E-04,   7.3488738E-04
     +,   7.1883149E-04,   7.0266385E-04,   6.8646035E-04
     +,   6.7029684E-04,   6.5425207E-04,   6.3840230E-04
     +,   6.2282587E-04,   6.0760166E-04,   5.9280795E-04
     +,   5.7852297E-04,   5.6482578E-04,   5.5179629E-04
     +,   5.3951488E-04,   5.2806281E-04,   5.1752577E-04
     +,   5.0799135E-04,   4.9955136E-04,   4.9230305E-04
     +,   4.8635234E-04,   4.8181176E-04,   4.7880522E-04
     +,   4.7746816E-04,   4.7795009E-04,   4.8041649E-04
     +,   4.8505023E-04,   4.9205380E-04,   5.0165103E-04
     +,   5.1408831E-04,   5.2963744E-04,   5.4859399E-04
     +,   5.7127763E-04,   5.9803610E-04,   6.2923710E-04
     +,   6.6526909E-04,   7.0653233E-04,   7.5343717E-04
     +,   8.0639037E-04,   8.6577801E-04,   9.3195622E-04
     +,   1.0052308E-03,   1.0858242E-03,   1.1738612E-03
     +,   1.2693391E-03,   1.3721072E-03,   1.4818255E-03
     +,   1.5979585E-03,   1.7197620E-03,   1.8462738E-03
     +,   1.9763124E-03,   2.1085001E-03,   2.2413074E-03
     +,   2.3730814E-03,   2.5021038E-03,   2.6266708E-03
     +,   2.7451667E-03,   2.8561263E-03,   2.9583264E-03
     +,   3.0508668E-03,   3.1332094E-03,   3.2052237E-03
     +,   3.2672174E-03,   3.3199361E-03,   3.3645371E-03
     +,   3.4025449E-03,   3.4357943E-03,   3.4663507E-03
     +,   3.4964227E-03,   3.5282774E-03,   3.5641405E-03
     +,   3.6061313E-03,   3.6561736E-03,   3.7159340E-03
     +,   3.7867869E-03,   3.8697533E-03,   3.9654938E-03
     +,   4.0742555E-03,   4.1959207E-03,   4.3299794E-03
     +,   4.4755857E-03,   4.6316120E-03,   4.7967676E-03
     +,   4.9697058E-03,   5.1491684E-03,   5.3341761E-03
     +,   5.5241967E-03,   5.7192831E-03,   5.9202514E-03
     +,   6.1287573E-03,   6.3472795E-03,   6.5789581E-03
     +,   6.8272408E-03,   7.0953164E-03,   7.3853158E-03
     +,   7.6973448E-03,   8.0287559E-03,   8.3738687E-03
     +,   8.7244865E-03,   9.0715904E-03,   9.4083408E-03
     +,   9.7338809E-03,   1.0057510E-02,   1.0402156E-02
     +,   1.0806371E-02,   1.1323852E-02,   1.2020205E-02
     +,   1.2967356E-02,   1.4235800E-02,   1.5885031E-02
     +,   1.7951837E-02,   2.0438051E-02,   2.3302739E-02
     +,   2.6467843E-02,   2.9846139E-02,   3.3386163E-02
     +,   3.7105646E-02,   4.1074697E-02,   4.5337670E-02
     +,   4.9824037E-02,   5.4334298E-02,   5.8628894E-02
     +,   6.2531337E-02,   6.5943554E-02,   6.8773016E-02
     +,   7.0876770E-02,   7.2093010E-02,   7.2308592E-02
     +,   7.1447037E-02,   6.9382511E-02,   6.5928191E-02
     +,   6.0981780E-02,   5.4717503E-02,   4.7634747E-02
     +,   4.0402222E-02,   3.3615969E-02,   2.7633026E-02
     +,   2.2558708E-02,   1.8333022E-02,   1.4828155E-02
     +,   1.1914215E-02,   9.4875852E-03,   7.4761156E-03
     +,   5.8285547E-03,   4.5017372E-03,   3.4514975E-03
     +,   2.6318461E-03,   1.9979810E-03,   1.5102901E-03
     +,   1.1361558E-03,   8.5007731E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_hatt105 = Yx/0.44086
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4637642E-04,   3.6547665E-04
     +,   3.8534249E-04,   4.0599567E-04,   4.2745564E-04
     +,   4.4973913E-04,   4.7285887E-04,   4.9682398E-04
     +,   5.2163925E-04,   5.4730743E-04,   5.7382806E-04
     +,   6.0120097E-04,   6.2942895E-04,   6.5851986E-04
     +,   6.8849430E-04,   7.1938906E-04,   7.5126428E-04
     +,   7.8421086E-04,   8.1835833E-04,   8.5388171E-04
     +,   8.9100923E-04,   9.3002646E-04,   9.7128149E-04
     +,   1.0151872E-03,   1.0622130E-03,   1.1128864E-03
     +,   1.1677773E-03,   1.2274878E-03,   1.2926358E-03
     +,   1.3638325E-03,   1.4416707E-03,   1.5266995E-03
     +,   1.6194172E-03,   1.7202537E-03,   1.8295700E-03
     +,   1.9476527E-03,   2.0747231E-03,   2.2109230E-03
     +,   2.3563341E-03,   2.5109265E-03,   2.6745657E-03
     +,   2.8469467E-03,   3.0275446E-03,   3.2155598E-03
     +,   3.4099007E-03,   3.6091981E-03,   3.8119322E-03
     +,   4.0166322E-03,   4.2222291E-03,   4.4284612E-03
     +,   4.6363529E-03,   4.8486032E-03,   5.0698570E-03
     +,   5.3066532E-03,   5.5670994E-03,   5.8602169E-03
     +,   6.1950944E-03,   6.5800655E-03,   7.0220847E-03
     +,   7.5264433E-03,   8.0966996E-03,   8.7344740E-03
     +,   9.4387382E-03,   1.0204832E-02,   1.1023291E-02
     +,   1.1880123E-02,   1.2759753E-02,   1.3650333E-02
     +,   1.4550964E-02,   1.5476449E-02,   1.6457504E-02
     +,   1.7533112E-02,   1.8737793E-02,   2.0088747E-02
     +,   2.1584867E-02,   2.3222459E-02,   2.5021769E-02
     +,   2.7040703E-02,   2.9350918E-02,   3.1974804E-02
     +,   3.4817081E-02,   3.7648913E-02,   4.0179819E-02
     +,   4.2198200E-02,   4.3689068E-02,   4.4833899E-02
     +,   4.5882627E-02,   4.6999328E-02,   4.8179530E-02
     +,   4.9250808E-02,   4.9932346E-02,   4.9953103E-02
     +,   4.9204692E-02,   4.7825135E-02,   4.6135124E-02
     +,   4.4482820E-02,   4.3111615E-02,   4.2095065E-02
     +,   4.1313522E-02,   4.0489998E-02,   3.9311092E-02
     +,   3.7585184E-02,   3.5321891E-02,   3.2684363E-02
     +,   2.9875264E-02,   2.7054651E-02,   2.4326082E-02
     +,   2.1758748E-02,   1.9403085E-02,   1.7289942E-02
     +,   1.5426047E-02,   1.3797821E-02,   1.2382867E-02
     +,   1.1158934E-02,   1.0107408E-02,   9.2114843E-03
     +,   8.4542586E-03,   7.8178048E-03,   7.2839833E-03
     +,   6.8352600E-03,   6.4555192E-03,   6.1303130E-03
     +,   5.8469274E-03,   5.5944026E-03,   5.3636110E-03
     +,   5.1472946E-03,   4.9399212E-03,   4.7375881E-03
     +,   4.5376970E-03,   4.3387641E-03,   4.1401382E-03
     +,   3.9418736E-03,   3.7445531E-03,   3.5492296E-03
     +,   3.3572866E-03,   3.1703361E-03,   2.9900896E-03
     +,   2.8182059E-03,   2.6561497E-03,   2.5050880E-03
     +,   2.3658313E-03,   2.2387805E-03,   2.1239349E-03
     +,   2.0209351E-03,   1.9291415E-03,   1.8476733E-03
     +,   1.7755188E-03,   1.7115886E-03,   1.6547807E-03
     +,   1.6040300E-03,   1.5583338E-03,   1.5167869E-03
     +,   1.4785860E-03,   1.4430325E-03,   1.4095344E-03
     +,   1.3776014E-03,   1.3468352E-03,   1.3169227E-03
     +,   1.2876232E-03,   1.2587685E-03,   1.2302460E-03
     +,   1.2019940E-03,   1.1739964E-03,   1.1462762E-03
     +,   1.1188842E-03,   1.0918938E-03,   1.0654007E-03
     +,   1.0395118E-03,   1.0143395E-03,   9.8999776E-04
     +,   9.6659700E-04,   9.4424305E-04,   9.2302548E-04
     +,   9.0302154E-04,   8.8429393E-04,   8.6688279E-04
     +,   8.5081125E-04,   8.3608343E-04,   8.2268304E-04
     +,   8.1057701E-04,   7.9971465E-04,   7.9003203E-04
     +,   7.8145234E-04,   7.7388942E-04,   7.6724892E-04
     +,   7.6143292E-04,   7.5634167E-04,   7.5187453E-04
     +,   7.4793311E-04,   7.4442651E-04,   7.4126606E-04
     +,   7.3837402E-04,   7.3568127E-04,   7.3312700E-04
     +,   7.3066307E-04,   7.2825147E-04,   7.2586484E-04
     +,   7.2348758E-04,   7.2111411E-04,   7.1874919E-04
     +,   7.1640644E-04,   7.1410695E-04,   7.1187929E-04
     +,   7.0975703E-04,   7.0777896E-04,   7.0598535E-04
     +,   7.0441951E-04,   7.0312183E-04,   7.0213404E-04
     +,   7.0149335E-04,   7.0123147E-04,   7.0137682E-04
     +,   7.0194923E-04,   7.0296292E-04,   7.0442160E-04
     +,   7.0632203E-04,   7.0865022E-04,   7.1138376E-04
     +,   7.1449071E-04,   7.1793061E-04,   7.2165392E-04
     +,   7.2560378E-04,   7.2971580E-04,   7.3392043E-04
     +,   7.3814276E-04,   7.4230490E-04,   7.4632623E-04
     +,   7.5012585E-04,   7.5362297E-04,   7.5673865E-04
     +,   7.5939787E-04,   7.6152891E-04,   7.6306699E-04
     +,   7.6395296E-04,   7.6413492E-04,   7.6356949E-04
     +,   7.6222117E-04,   7.6006429E-04,   7.5708173E-04
     +,   7.5326522E-04,   7.4861449E-04,   7.4313878E-04
     +,   7.3685503E-04,   7.2978687E-04,   7.2196405E-04
     +,   7.1342255E-04,   7.0420402E-04,   6.9435185E-04
     +,   6.8391341E-04,   6.7293865E-04,   6.6147855E-04
     +,   6.4958312E-04,   6.3730357E-04,   6.2469050E-04
     +,   6.1179150E-04,   5.9865217E-04,   5.8531674E-04
     +,   5.7182764E-04,   5.5822160E-04,   5.4453453E-04
     +,   5.3079904E-04,   5.1704544E-04,   5.0330040E-04
     +,   4.8958784E-04,   4.7593072E-04,   4.6234892E-04
     +,   4.4885953E-04,   4.3548021E-04,   4.2222603E-04
     +,   4.0911083E-04,   3.9614696E-04,   3.8334742E-04
     +,   3.7072407E-04,   3.5828768E-04,   3.4604853E-04
     +,   3.3401814E-04,   3.2220516E-04,   3.1062035E-04
     +,   2.9927204E-04,   2.8817027E-04,   2.7732225E-04
     +,   2.6673684E-04,   2.5642038E-04,   2.4638028E-04
     +,   2.3662156E-04,   2.2714975E-04,   2.1796863E-04
     +,   2.0908086E-04,   2.0048910E-04,   1.9219385E-04
     +,   1.8419560E-04,   1.7649277E-04,   1.6908390E-04
     +,   1.6196542E-04,   1.5513379E-04,   1.4858379E-04
     +,   1.4231011E-04,   1.3630606E-04,   1.3056488E-04
     +,   1.2507860E-04,   1.1983953E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_hatt75 = Yx/0.4606
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3139419E-04,   2.4398998E-04
     +,   2.5684675E-04,   2.6993666E-04,   2.8323146E-04
     +,   2.9670337E-04,   3.1032576E-04,   3.2407363E-04
     +,   3.3792475E-04,   3.5186086E-04,   3.6586745E-04
     +,   3.7993537E-04,   3.9406182E-04,   4.0825107E-04
     +,   4.2251500E-04,   4.3687434E-04,   4.5135844E-04
     +,   4.6600704E-04,   4.8086973E-04,   4.9600645E-04
     +,   5.1148725E-04,   5.2739249E-04,   5.4381147E-04
     +,   5.6084292E-04,   5.7859137E-04,   5.9716875E-04
     +,   6.1668985E-04,   6.3727173E-04,   6.5903028E-04
     +,   6.8207830E-04,   7.0652337E-04,   7.3246378E-04
     +,   7.5998937E-04,   7.8917650E-04,   8.2009059E-04
     +,   8.5278484E-04,   8.8730332E-04,   9.2368480E-04
     +,   9.6196996E-04,   1.0022053E-03,   1.0444598E-03
     +,   1.0888315E-03,   1.1354632E-03,   1.1845545E-03
     +,   1.2363729E-03,   1.2912689E-03,   1.3496723E-03
     +,   1.4120999E-03,   1.4791450E-03,   1.5514613E-03
     +,   1.6297406E-03,   1.7146842E-03,   1.8069647E-03
     +,   1.9072030E-03,   2.0159180E-03,   2.1335336E-03
     +,   2.2603567E-03,   2.3965992E-03,   2.5424224E-03
     +,   2.6979949E-03,   2.8635676E-03,   3.0395640E-03
     +,   3.2266474E-03,   3.4258112E-03,   3.6384263E-03
     +,   3.8662767E-03,   4.1116327E-03,   4.3772347E-03
     +,   4.6663634E-03,   4.9827485E-03,   5.3304937E-03
     +,   5.7137562E-03,   6.1364304E-03,   6.6015562E-03
     +,   7.1108420E-03,   7.6641194E-03,   8.2587786E-03
     +,   8.8894321E-03,   9.5479377E-03,   1.0224229E-02
     +,   1.0908311E-02,   1.1594452E-02,   1.2285612E-02
     +,   1.2996817E-02,   1.3753202E-02,   1.4581503E-02
     +,   1.5496178E-02,   1.6488079E-02,   1.7524252E-02
     +,   1.8565856E-02,   1.9597720E-02,   2.0651741E-02
     +,   2.1802073E-02,   2.3127353E-02,   2.4660332E-02
     +,   2.6362929E-02,   2.8145619E-02,   2.9916927E-02
     +,   3.1639155E-02,   3.3363406E-02,   3.5217691E-02
     +,   3.7337303E-02,   3.9786000E-02,   4.2524755E-02
     +,   4.5436881E-02,   4.8388913E-02,   5.1314440E-02
     +,   5.4210443E-02,   5.6956384E-02,   5.9241198E-02
     +,   6.0929779E-02,   6.2434837E-02,   6.4350329E-02
     +,   6.6664100E-02,   6.8579294E-02,   6.9179535E-02
     +,   6.8114296E-02,   6.5579079E-02,   6.1832897E-02
     +,   5.7023361E-02,   5.1443741E-02,   4.5665082E-02
     +,   4.0278628E-02,   3.5581823E-02,   3.1551946E-02
     +,   2.8041292E-02,   2.4939043E-02,   2.2198569E-02
     +,   1.9799316E-02,   1.7723674E-02,   1.5951077E-02
     +,   1.4452319E-02,   1.3182264E-02,   1.2083313E-02
     +,   1.1098819E-02,   1.0187143E-02,   9.3272589E-03
     +,   8.5152443E-03,   7.7561545E-03,   7.0566842E-03
     +,   6.4205271E-03,   5.8471253E-03,   5.3323465E-03
     +,   4.8702392E-03,   4.4546314E-03,   4.0800110E-03
     +,   3.7419696E-03,   3.4370956E-03,   3.1626269E-03
     +,   2.9160997E-03,   2.6951253E-03,   2.4972737E-03
     +,   2.3200742E-03,   2.1610542E-03,   2.0178694E-03
     +,   1.8883991E-03,   1.7708024E-03,   1.6635378E-03
     +,   1.5653749E-03,   1.4753799E-03,   1.3928367E-03
     +,   1.3172196E-03,   1.2481359E-03,   1.1852816E-03
     +,   1.1283940E-03,   1.0772322E-03,   1.0315597E-03
     +,   9.9112815E-04,   9.5566973E-04,   9.2489959E-04
     +,   8.9851575E-04,   8.7620266E-04,   8.5763051E-04
     +,   8.4246451E-04,   8.3036616E-04,   8.2100125E-04
     +,   8.1403751E-04,   8.0915273E-04,   8.0603879E-04
     +,   8.0439926E-04,   8.0395682E-04,   8.0445403E-04
     +,   8.0565031E-04,   8.0733071E-04,   8.0929906E-04
     +,   8.1138231E-04,   8.1342971E-04,   8.1531017E-04
     +,   8.1691367E-04,   8.1814802E-04,   8.1894081E-04
     +,   8.1923406E-04,   8.1898447E-04,   8.1816240E-04
     +,   8.1675017E-04,   8.1473956E-04,   8.1213214E-04
     +,   8.0893619E-04,   8.0516760E-04,   8.0084737E-04
     +,   7.9600170E-04,   7.9066108E-04,   7.8486069E-04
     +,   7.7863870E-04,   7.7203754E-04,   7.6510193E-04
     +,   7.5788074E-04,   7.5042527E-04,   7.4279145E-04
     +,   7.3503715E-04,   7.2722224E-04,   7.1941019E-04
     +,   7.1166654E-04,   7.0405687E-04,   6.9664913E-04
     +,   6.8950962E-04,   6.8270526E-04,   6.7629985E-04
     +,   6.7035382E-04,   6.6492369E-04,   6.6006120E-04
     +,   6.5580930E-04,   6.5220584E-04,   6.4927794E-04
     +,   6.4704358E-04,   6.4551039E-04,   6.4467487E-04
     +,   6.4452161E-04,   6.4502395E-04,   6.4614369E-04
     +,   6.4783060E-04,   6.5002393E-04,   6.5265340E-04
     +,   6.5563805E-04,   6.5888971E-04,   6.6231337E-04
     +,   6.6580751E-04,   6.6926779E-04,   6.7258667E-04
     +,   6.7565579E-04,   6.7836855E-04,   6.8062014E-04
     +,   6.8230927E-04,   6.8334094E-04,   6.8362744E-04
     +,   6.8308832E-04,   6.8165321E-04,   6.7926088E-04
     +,   6.7586184E-04,   6.7141821E-04,   6.6590309E-04
     +,   6.5930153E-04,   6.5161154E-04,   6.4284255E-04
     +,   6.3301402E-04,   6.2215730E-04,   6.1031454E-04
     +,   5.9753616E-04,   5.8388076E-04,   5.6941452E-04
     +,   5.5421132E-04,   5.3834869E-04,   5.2190910E-04
     +,   5.0497730E-04,   4.8764161E-04,   4.6998941E-04
     +,   4.5210822E-04,   4.3408529E-04,   4.1600593E-04
     +,   3.9795137E-04,   3.7999934E-04,   3.6222412E-04
     +,   3.4469535E-04,   3.2747650E-04,   3.1062498E-04
     +,   2.9419403E-04,   2.7822878E-04,   2.6277013E-04
     +,   2.4785075E-04,   2.3349942E-04,   2.1973687E-04
     +,   2.0657998E-04,   1.9403838E-04,   1.8211833E-04
     +,   1.7081962E-04,   1.6013907E-04,   1.5006860E-04
     +,   1.4059636E-04,   1.3170847E-04,   1.2338701E-04
     +,   1.1561297E-04,   1.0836422E-04,   1.0161834E-04
     +,   9.5350726E-05,   8.9536821E-05,   8.4150859E-05
     +,   7.9167708E-05,   7.4561533E-05,   7.0307484E-05
     +,   6.6380722E-05,   6.2757557E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_hatt80 = Yx/0.529803921568627
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0324542E-05,   8.2850616E-05
     +,   8.5381260E-05,   8.7912471E-05,   9.0440401E-05
     +,   9.2961352E-05,   9.5471871E-05,   9.7968848E-05
     +,   1.0044952E-04,   1.0291166E-04,   1.0535367E-04
     +,   1.0777457E-04,   1.1017425E-04,   1.1255355E-04
     +,   1.1491438E-04,   1.1725985E-04,   1.1959447E-04
     +,   1.2192431E-04,   1.2425709E-04,   1.2660248E-04
     +,   1.2897207E-04,   1.3137967E-04,   1.3384153E-04
     +,   1.3637639E-04,   1.3900564E-04,   1.4175357E-04
     +,   1.4464727E-04,   1.4771683E-04,   1.5099550E-04
     +,   1.5451945E-04,   1.5832795E-04,   1.6246333E-04
     +,   1.6697057E-04,   1.7189744E-04,   1.7729380E-04
     +,   1.8321190E-04,   1.8970555E-04,   1.9682960E-04
     +,   2.0464003E-04,   2.1319224E-04,   2.2254193E-04
     +,   2.3274311E-04,   2.4384828E-04,   2.5590710E-04
     +,   2.6896613E-04,   2.8306810E-04,   2.9825117E-04
     +,   3.1454850E-04,   3.3198803E-04,   3.5059141E-04
     +,   3.7037570E-04,   3.9135164E-04,   4.1352527E-04
     +,   4.3689992E-04,   4.6147371E-04,   4.8724699E-04
     +,   5.1422050E-04,   5.4239959E-04,   5.7179877E-04
     +,   6.0244545E-04,   6.3438527E-04,   6.6768785E-04
     +,   7.0245191E-04,   7.3881511E-04,   7.7695854E-04
     +,   8.1711088E-04,   8.5955980E-04,   9.0464822E-04
     +,   9.5278537E-04,   1.0044351E-03,   1.0601234E-03
     +,   1.1204147E-03,   1.1859126E-03,   1.2572233E-03
     +,   1.3349450E-03,   1.4196262E-03,   1.5117272E-03
     +,   1.6115821E-03,   1.7193691E-03,   1.8350801E-03
     +,   1.9584843E-03,   2.0891766E-03,   2.2265827E-03
     +,   2.3700793E-03,   2.5190860E-03,   2.6732711E-03
     +,   2.8326882E-03,   2.9980058E-03,   3.1705841E-03
     +,   3.3525901E-03,   3.5469458E-03,   3.7571983E-03
     +,   3.9873985E-03,   4.2419643E-03,   4.5256144E-03
     +,   4.8433836E-03,   5.2006929E-03,   5.6032166E-03
     +,   6.0566813E-03,   6.5661389E-03,   7.1353228E-03
     +,   7.7659208E-03,   8.4577035E-03,   9.2093218E-03
     +,   1.0019968E-02,   1.0890483E-02,   1.1822597E-02
     +,   1.2815701E-02,   1.3862502E-02,   1.4945775E-02
     +,   1.6039766E-02,   1.7118428E-02,   1.8172344E-02
     +,   1.9235784E-02,   2.0412562E-02,   2.1872295E-02
     +,   2.3787392E-02,   2.6232315E-02,   2.9127462E-02
     +,   3.2303594E-02,   3.5639483E-02,   3.9118841E-02
     +,   4.2718533E-02,   4.6249319E-02,   4.9405314E-02
     +,   5.2071530E-02,   5.4530084E-02,   5.7211161E-02
     +,   6.0286578E-02,   6.3676327E-02,   6.7260832E-02
     +,   7.0665240E-02,   7.3145911E-02,   7.4288376E-02
     +,   7.4525893E-02,   7.4627459E-02,   7.4848667E-02
     +,   7.4503265E-02,   7.2511747E-02,   6.8662420E-02
     +,   6.3895211E-02,   5.9190456E-02,   5.4744072E-02
     +,   5.0249770E-02,   4.5491897E-02,   4.0581983E-02
     +,   3.5824355E-02,   3.1460155E-02,   2.7544925E-02
     +,   2.4010254E-02,   2.0781351E-02,   1.7845487E-02
     +,   1.5249425E-02,   1.3050531E-02,   1.1263999E-02
     +,   9.8436307E-03,   8.7025007E-03,   7.7507561E-03
     +,   6.9232569E-03,   6.1862846E-03,   5.5289478E-03
     +,   4.9506398E-03,   4.4517424E-03,   4.0292325E-03
     +,   3.6761481E-03,   3.3829452E-03,   3.1391964E-03
     +,   2.9349553E-03,   2.7615700E-03,   2.6120339E-03
     +,   2.4809567E-03,   2.3643274E-03,   2.2592503E-03
     +,   2.1636866E-03,   2.0762824E-03,   1.9961896E-03
     +,   1.9229768E-03,   1.8565350E-03,   1.7969889E-03
     +,   1.7446262E-03,   1.6998112E-03,   1.6629284E-03
     +,   1.6343110E-03,   1.6141816E-03,   1.6026124E-03
     +,   1.5994915E-03,   1.6044959E-03,   1.6170795E-03
     +,   1.6364784E-03,   1.6617123E-03,   1.6916121E-03
     +,   1.7248546E-03,   1.7599933E-03,   1.7955191E-03
     +,   1.8299116E-03,   1.8617039E-03,   1.8895322E-03
     +,   1.9121986E-03,   1.9287186E-03,   1.9383593E-03
     +,   1.9406611E-03,   1.9354590E-03,   1.9228637E-03
     +,   1.9032547E-03,   1.8772448E-03,   1.8456307E-03
     +,   1.8093510E-03,   1.7694249E-03,   1.7269052E-03
     +,   1.6828167E-03,   1.6381127E-03,   1.5936447E-03
     +,   1.5501287E-03,   1.5081280E-03,   1.4680495E-03
     +,   1.4301487E-03,   1.3945389E-03,   1.3612077E-03
     +,   1.3300393E-03,   1.3008437E-03,   1.2733726E-03
     +,   1.2473511E-03,   1.2224913E-03,   1.1985158E-03
     +,   1.1751646E-03,   1.1522094E-03,   1.1294626E-03
     +,   1.1067721E-03,   1.0840276E-03,   1.0611532E-03
     +,   1.0381102E-03,   1.0148876E-03,   9.9149463E-04
     +,   9.6795947E-04,   9.4432413E-04,   9.2063536E-04
     +,   8.9694338E-04,   8.7330065E-04,   8.4975659E-04
     +,   8.2635425E-04,   8.0313213E-04,   7.8012474E-04
     +,   7.5736025E-04,   7.3486078E-04,   7.1264378E-04
     +,   6.9072377E-04,   6.6911418E-04,   6.4782304E-04
     +,   6.2685984E-04,   6.0623442E-04,   5.8595493E-04
     +,   5.6603085E-04,   5.4647331E-04,   5.2729464E-04
     +,   5.0850713E-04,   4.9012282E-04,   4.7215636E-04
     +,   4.5462145E-04,   4.3753022E-04,   4.2089465E-04
     +,   4.0472587E-04,   3.8903323E-04,   3.7382374E-04
     +,   3.5910166E-04,   3.4487096E-04,   3.3113116E-04
     +,   3.1788010E-04,   3.0511344E-04,   2.9282531E-04
     +,   2.8100691E-04,   2.6964763E-04,   2.5873614E-04
     +,   2.4825981E-04,   2.3820443E-04,   2.2855515E-04
     +,   2.1929736E-04,   2.1041548E-04,   2.0189480E-04
     +,   1.9371964E-04,   1.8587585E-04,   1.7834861E-04
     +,   1.7112470E-04,   1.6419047E-04,   1.5753380E-04
     +,   1.5114241E-04,   1.4500540E-04,   1.3911202E-04
     +,   1.3345203E-04,   1.2801630E-04,   1.2279555E-04
     +,   1.1778166E-04,   1.1296627E-04,   1.0834199E-04
     +,   1.0390113E-04,   9.9637124E-05,   9.5542724E-05
     +,   9.1611764E-05,   8.7837660E-05,   8.4214502E-05
     +,   8.0736092E-05,   7.7396915E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_hatt85 = Yx/0.557117647058823
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4849880E-05,   3.6111589E-05
     +,   3.7429418E-05,   3.8807069E-05,   4.0248349E-05
     +,   4.1757143E-05,   4.3337375E-05,   4.4993056E-05
     +,   4.6728132E-05,   4.8546572E-05,   5.0452232E-05
     +,   5.2448817E-05,   5.4539898E-05,   5.6728804E-05
     +,   5.9018621E-05,   6.1412058E-05,   6.3911561E-05
     +,   6.6519053E-05,   6.9236041E-05,   7.2063514E-05
     +,   7.5001903E-05,   7.8051060E-05,   8.1210135E-05
     +,   8.4477877E-05,   8.7851979E-05,   9.1329806E-05
     +,   9.4907919E-05,   9.8582161E-05,   1.0234784E-04
     +,   1.0619953E-04,   1.1013137E-04,   1.1413698E-04
     +,   1.1820943E-04,   1.2234163E-04,   1.2652615E-04
     +,   1.3075539E-04,   1.3502185E-04,   1.3931796E-04
     +,   1.4363686E-04,   1.4797141E-04,   1.5231576E-04
     +,   1.5666433E-04,   1.6101258E-04,   1.6535701E-04
     +,   1.6969521E-04,   1.7402630E-04,   1.7835079E-04
     +,   1.8267064E-04,   1.8698964E-04,   1.9131327E-04
     +,   1.9564871E-04,   2.0000513E-04,   2.0439326E-04
     +,   2.0882592E-04,   2.1331712E-04,   2.1788281E-04
     +,   2.2254005E-04,   2.2730717E-04,   2.3220343E-04
     +,   2.3724872E-04,   2.4246333E-04,   2.4786769E-04
     +,   2.5348150E-04,   2.5932427E-04,   2.6541456E-04
     +,   2.7176904E-04,   2.7840311E-04,   2.8532962E-04
     +,   2.9255979E-04,   3.0010135E-04,   3.0796029E-04
     +,   3.1613873E-04,   3.2463664E-04,   3.3345044E-04
     +,   3.4257464E-04,   3.5200137E-04,   3.6172054E-04
     +,   3.7172041E-04,   3.8198961E-04,   3.9251696E-04
     +,   4.0329187E-04,   4.1430735E-04,   4.2555886E-04
     +,   4.3704858E-04,   4.4878351E-04,   4.6078002E-04
     +,   4.7306262E-04,   4.8566781E-04,   4.9864221E-04
     +,   5.1204726E-04,   5.2595808E-04,   5.4046401E-04
     +,   5.5567018E-04,   5.7169941E-04,   5.8869144E-04
     +,   6.0680450E-04,   6.2621897E-04,   6.4713613E-04
     +,   6.6978601E-04,   6.9442729E-04,   7.2135642E-04
     +,   7.5091165E-04,   7.8348035E-04,   8.1950548E-04
     +,   8.5949723E-04,   9.0403802E-04,   9.5378759E-04
     +,   1.0094887E-03,   1.0719782E-03,   1.1421867E-03
     +,   1.2211283E-03,   1.3099159E-03,   1.4097294E-03
     +,   1.5218238E-03,   1.6474716E-03,   1.7879681E-03
     +,   1.9445536E-03,   2.1184261E-03,   2.3106940E-03
     +,   2.5224392E-03,   2.7547830E-03,   3.0090231E-03
     +,   3.2868341E-03,   3.5905491E-03,   3.9233747E-03
     +,   4.2895558E-03,   4.6945661E-03,   5.1450385E-03
     +,   5.6488076E-03,   6.2146694E-03,   6.8522822E-03
     +,   7.5717317E-03,   8.3835321E-03,   9.2988228E-03
     +,   1.0331385E-02,   1.1500846E-02,   1.2835828E-02
     +,   1.4373081E-02,   1.6148439E-02,   1.8181860E-02
     +,   2.0466978E-02,   2.2974379E-02,   2.5660586E-02
     +,   2.8470604E-02,   3.1337753E-02,   3.4192074E-02
     +,   3.6967315E-02,   3.9612047E-02,   4.2171799E-02
     +,   4.4943914E-02,   4.8458133E-02,   5.3093001E-02
     +,   5.8679357E-02,   6.4537577E-02,   6.9898359E-02
     +,   7.4542411E-02,   7.9034142E-02,   8.3584562E-02
     +,   8.7207966E-02,   8.9067213E-02,   8.9141481E-02
     +,   8.7122060E-02,   8.2701355E-02,   7.6581948E-02
     +,   6.9694415E-02,   6.2343363E-02,   5.4775506E-02
     +,   4.7464378E-02,   4.0660724E-02,   3.4370963E-02
     +,   2.8672867E-02,   2.3741921E-02,   1.9692579E-02
     +,   1.6503820E-02,   1.4052283E-02,   1.2186388E-02
     +,   1.0786541E-02,   9.7796824E-03,   9.1188429E-03
     +,   8.7579181E-03,   8.6391103E-03,   8.6933803E-03
     +,   8.8473391E-03,   9.0318574E-03,   9.1898013E-03
     +,   9.2819119E-03,   9.2898868E-03,   9.2161233E-03
     +,   9.0795550E-03,   8.9086974E-03,   8.7332353E-03
     +,   8.5764844E-03,   8.4504243E-03,   8.3542513E-03
     +,   8.2764560E-03,   8.1989346E-03,   8.1020528E-03
     +,   7.9688504E-03,   7.7879927E-03,   7.5549493E-03
     +,   7.2718365E-03,   6.9462596E-03,   6.5895622E-03
     +,   6.2149796E-03,   5.8359336E-03,   5.4644835E-03
     +,   5.1103448E-03,   4.7803908E-03,   4.4784951E-03
     +,   4.2058420E-03,   3.9615119E-03,   3.7431305E-03
     +,   3.5475427E-03,   3.3713342E-03,   3.2112594E-03
     +,   3.0645239E-03,   2.9288682E-03,   2.8025738E-03
     +,   2.6844202E-03,   2.5735842E-03,   2.4694966E-03
     +,   2.3717456E-03,   2.2799727E-03,   2.1938111E-03
     +,   2.1128228E-03,   2.0364963E-03,   1.9642569E-03
     +,   1.8954800E-03,   1.8295282E-03,   1.7657882E-03
     +,   1.7037122E-03,   1.6428439E-03,   1.5828323E-03
     +,   1.5234533E-03,   1.4646075E-03,   1.4063056E-03
     +,   1.3486552E-03,   1.2918481E-03,   1.2361279E-03
     +,   1.1817660E-03,   1.1290412E-03,   1.0782256E-03
     +,   1.0295624E-03,   9.8325382E-04,   9.3945407E-04
     +,   8.9826889E-04,   8.5975329E-04,   8.2390883E-04
     +,   7.9069182E-04,   7.6002040E-04,   7.3177577E-04
     +,   7.0580997E-04,   6.8195647E-04,   6.6003110E-04
     +,   6.3983892E-04,   6.2118011E-04,   6.0385495E-04
     +,   5.8766716E-04,   5.7242520E-04,   5.5794790E-04
     +,   5.4406549E-04,   5.3062267E-04,   5.1747647E-04
     +,   5.0450145E-04,   4.9158861E-04,   4.7864541E-04
     +,   4.6559595E-04,   4.5238188E-04,   4.3896114E-04
     +,   4.2530647E-04,   4.1140491E-04,   3.9725818E-04
     +,   3.8288010E-04,   3.6829457E-04,   3.5353468E-04
     +,   3.3864297E-04,   3.2366579E-04,   3.0865686E-04
     +,   2.9367083E-04,   2.7876633E-04,   2.6400006E-04
     +,   2.4943019E-04,   2.3511112E-04,   2.2109599E-04
     +,   2.0743271E-04,   1.9416648E-04,   1.8133620E-04
     +,   1.6897563E-04,   1.5711423E-04,   1.4577425E-04
     +,   1.3497383E-04,   1.2472416E-04,   1.1503256E-04
     +,   1.0590005E-04,   9.7324191E-05,   8.9297304E-05
     +,   8.1808903E-05,   7.4844189E-05,   6.8386478E-05
     +,   6.2415893E-05,   5.6911373E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_hatt90 = Yx/0.552176470588235
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8450187E-05,   3.9318387E-05
     +,   4.0189560E-05,   4.1063257E-05,   4.1939056E-05
     +,   4.2816526E-05,   4.3695283E-05,   4.4574983E-05
     +,   4.5455268E-05,   4.6335896E-05,   4.7216599E-05
     +,   4.8097190E-05,   4.8977505E-05,   4.9857448E-05
     +,   5.0736973E-05,   5.1616113E-05,   5.2494932E-05
     +,   5.3373598E-05,   5.4252308E-05,   5.5131353E-05
     +,   5.6011129E-05,   5.6892073E-05,   5.7774694E-05
     +,   5.8659687E-05,   5.9547667E-05,   6.0439528E-05
     +,   6.1336119E-05,   6.2238483E-05,   6.3147680E-05
     +,   6.4064960E-05,   6.4991655E-05,   6.5929155E-05
     +,   6.6879067E-05,   6.7843001E-05,   6.8822832E-05
     +,   6.9820424E-05,   7.0837865E-05,   7.1877366E-05
     +,   7.2941250E-05,   7.4031981E-05,   7.5152231E-05
     +,   7.6304830E-05,   7.7492718E-05,   7.8718993E-05
     +,   7.9987018E-05,   8.1300233E-05,   8.2662380E-05
     +,   8.4077255E-05,   8.5548963E-05,   8.7081717E-05
     +,   8.8679990E-05,   9.0348447E-05,   9.2091868E-05
     +,   9.3915383E-05,   9.5824122E-05,   9.7823569E-05
     +,   9.9919256E-05,   1.0211692E-04,   1.0442241E-04
     +,   1.0684172E-04,   1.0938085E-04,   1.1204596E-04
     +,   1.1484307E-04,   1.1777831E-04,   1.2085784E-04
     +,   1.2408725E-04,   1.2747246E-04,   1.3101865E-04
     +,   1.3473109E-04,   1.3861422E-04,   1.4267245E-04
     +,   1.4690895E-04,   1.5132697E-04,   1.5592809E-04
     +,   1.6071375E-04,   1.6568422E-04,   1.7083836E-04
     +,   1.7617384E-04,   1.8168734E-04,   1.8737423E-04
     +,   1.9322788E-04,   1.9924062E-04,   2.0540280E-04
     +,   2.1170368E-04,   2.1813018E-04,   2.2466827E-04
     +,   2.3130186E-04,   2.3801396E-04,   2.4478542E-04
     +,   2.5159668E-04,   2.5842714E-04,   2.6525510E-04
     +,   2.7205865E-04,   2.7881621E-04,   2.8550721E-04
     +,   2.9211107E-04,   2.9861022E-04,   3.0498891E-04
     +,   3.1123564E-04,   3.1734214E-04,   3.2330741E-04
     +,   3.2913554E-04,   3.3483980E-04,   3.4044232E-04
     +,   3.4597627E-04,   3.5148815E-04,   3.5703706E-04
     +,   3.6269822E-04,   3.6856325E-04,   3.7474209E-04
     +,   3.8136166E-04,   3.8856833E-04,   3.9652485E-04
     +,   4.0541103E-04,   4.1541946E-04,   4.2675363E-04
     +,   4.3962087E-04,   4.5422910E-04,   4.7077716E-04
     +,   4.8944808E-04,   5.1040162E-04,   5.3376186E-04
     +,   5.5961020E-04,   5.8797875E-04,   6.1884389E-04
     +,   6.5211696E-04,   6.8765163E-04,   7.2523666E-04
     +,   7.6461333E-04,   8.0547592E-04,   8.4749749E-04
     +,   8.9034101E-04,   9.3369460E-04,   9.7728835E-04
     +,   1.0209323E-03,   1.0645458E-03,   1.1081774E-03
     +,   1.1520321E-03,   1.1964919E-03,   1.2421102E-03
     +,   1.2896020E-03,   1.3398181E-03,   1.3937005E-03
     +,   1.4522147E-03,   1.5162547E-03,   1.5865628E-03
     +,   1.6636152E-03,   1.7475119E-03,   1.8378944E-03
     +,   1.9338841E-03,   2.0340518E-03,   2.1364321E-03
     +,   2.2386049E-03,   2.3378276E-03,   2.4312099E-03
     +,   2.5159037E-03,   2.5893329E-03,   2.6494171E-03
     +,   2.6947341E-03,   2.7246452E-03,   2.7393715E-03
     +,   2.7399764E-03,   2.7283090E-03,   2.7068746E-03
     +,   2.6786979E-03,   2.6471794E-03,   2.6159820E-03
     +,   2.5889766E-03,   2.5702999E-03,   2.5645134E-03
     +,   2.5768895E-03,   2.6138164E-03,   2.6832491E-03
     +,   2.7952432E-03,   2.9624912E-03,   3.2010670E-03
     +,   3.5312297E-03,   3.9780149E-03,   4.5707114E-03
     +,   5.3399596E-03,   6.3115465E-03,   7.4983235E-03
     +,   8.8958237E-03,   1.0488998E-02,   1.2275404E-02
     +,   1.4301787E-02,   1.6701005E-02,   1.9703727E-02
     +,   2.3586702E-02,   2.8532956E-02,   3.4472220E-02
     +,   4.1080941E-02,   4.8054121E-02,   5.5431198E-02
     +,   6.3433990E-02,   7.1577594E-02,   7.8184269E-02
     +,   8.1985630E-02,   8.3908886E-02,   8.5368469E-02
     +,   8.6158939E-02,   8.5485473E-02,   8.3094120E-02
     +,   7.9442546E-02,   7.5355187E-02,   7.1335897E-02
     +,   6.7538381E-02,   6.3746303E-02,   5.9520096E-02
     +,   5.4593027E-02,   4.8931967E-02,   4.3031022E-02
     +,   3.7911743E-02,   3.4195915E-02,   3.1541124E-02
     +,   2.9195508E-02,   2.6767205E-02,   2.4375690E-02
     +,   2.2298912E-02,   2.0643603E-02,   1.9305579E-02
     +,   1.8110998E-02,   1.6937612E-02,   1.5743708E-02
     +,   1.4541375E-02,   1.3363510E-02,   1.2243842E-02
     +,   1.1208807E-02,   1.0274765E-02,   9.4469246E-03
     +,   8.7194145E-03,   8.0776298E-03,   7.5027356E-03
     +,   6.9764974E-03,   6.4845094E-03,   6.0172966E-03
     +,   5.5701109E-03,   5.1420075E-03,   4.7347574E-03
     +,   4.3516839E-03,   3.9966032E-03,   3.6727958E-03
     +,   3.3822404E-03,   3.1251695E-03,   2.9001024E-03
     +,   2.7041610E-03,   2.5335506E-03,   2.3840517E-03
     +,   2.2514879E-03,   2.1320558E-03,   2.0224757E-03
     +,   1.9200804E-03,   1.8228046E-03,   1.7291314E-03
     +,   1.6380118E-03,   1.5487979E-03,   1.4611710E-03
     +,   1.3750789E-03,   1.2906675E-03,   1.2082289E-03
     +,   1.1281602E-03,   1.0509045E-03,   9.7690558E-04
     +,   9.0657291E-04,   8.4025913E-04,   7.7822345E-04
     +,   7.2062569E-04,   6.6752540E-04,   6.1888021E-04
     +,   5.7455205E-04,   5.3432572E-04,   4.9792847E-04
     +,   4.6504385E-04,   4.3532872E-04,   4.0843221E-04
     +,   3.8401174E-04,   3.6173832E-04,   3.4131168E-04
     +,   3.2245932E-04,   3.0494513E-04,   2.8856515E-04
     +,   2.7315173E-04,   2.5856568E-04,   2.4469849E-04
     +,   2.3146470E-04,   2.1880135E-04,   2.0666179E-04
     +,   1.9501310E-04,   1.8383451E-04,   1.7311146E-04
     +,   1.6283686E-04,   1.5300544E-04,   1.4361569E-04
     +,   1.3466552E-04,   1.2615381E-04,   1.1807761E-04
     +,   1.1043366E-04,   1.0321608E-04,   9.6418233E-05
     +,   9.0030764E-05,   8.4043408E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_hatt95 = Yx/0.523352941176471
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.0434159E-06,   6.2836857E-06
     +,   6.5267504E-06,   6.7722085E-06,   7.0196334E-06
     +,   7.2685771E-06,   7.5185717E-06,   7.7691311E-06
     +,   8.0197451E-06,   8.2699044E-06,   8.5190686E-06
     +,   8.7666922E-06,   9.0122185E-06,   9.2550872E-06
     +,   9.4947263E-06,   9.7305674E-06,   9.9620393E-06
     +,   1.0188578E-05,   1.0409621E-05,   1.0624617E-05
     +,   1.0833031E-05,   1.1034342E-05,   1.1228048E-05
     +,   1.1413676E-05,   1.1590769E-05,   1.1758915E-05
     +,   1.1917730E-05,   1.2066869E-05,   1.2206036E-05
     +,   1.2334974E-05,   1.2453482E-05,   1.2561418E-05
     +,   1.2658698E-05,   1.2745298E-05,   1.2821270E-05
     +,   1.2886732E-05,   1.2941891E-05,   1.2987020E-05
     +,   1.3022491E-05,   1.3048758E-05,   1.3066367E-05
     +,   1.3075960E-05,   1.3078289E-05,   1.3074196E-05
     +,   1.3064634E-05,   1.3050656E-05,   1.3033436E-05
     +,   1.3014243E-05,   1.2994465E-05,   1.2975591E-05
     +,   1.2959224E-05,   1.2947062E-05,   1.2940918E-05
     +,   1.2942687E-05,   1.2954370E-05,   1.2978041E-05
     +,   1.3015856E-05,   1.3070042E-05,   1.3142877E-05
     +,   1.3236700E-05,   1.3353872E-05,   1.3496781E-05
     +,   1.3667826E-05,   1.3869401E-05,   1.4103880E-05
     +,   1.4373589E-05,   1.4680830E-05,   1.5027794E-05
     +,   1.5416648E-05,   1.5849402E-05,   1.6328013E-05
     +,   1.6854265E-05,   1.7429864E-05,   1.8056311E-05
     +,   1.8735014E-05,   1.9467234E-05,   2.0254018E-05
     +,   2.1096263E-05,   2.1994761E-05,   2.2950155E-05
     +,   2.3962844E-05,   2.5033227E-05,   2.6161415E-05
     +,   2.7347558E-05,   2.8591539E-05,   2.9893286E-05
     +,   3.1252479E-05,   3.2668864E-05,   3.4141936E-05
     +,   3.5671248E-05,   3.7256279E-05,   3.8896291E-05
     +,   4.0590450E-05,   4.2337942E-05,   4.4137785E-05
     +,   4.5988676E-05,   4.7889334E-05,   4.9838021E-05
     +,   5.1832965E-05,   5.3871812E-05,   5.5952100E-05
     +,   5.8070662E-05,   6.0224156E-05,   6.2408428E-05
     +,   6.4618973E-05,   6.6850655E-05,   6.9097543E-05
     +,   7.1353068E-05,   7.3610070E-05,   7.5860742E-05
     +,   7.8096309E-05,   8.0307676E-05,   8.2484818E-05
     +,   8.4617415E-05,   8.6694410E-05,   8.8704561E-05
     +,   9.0636131E-05,   9.2477414E-05,   9.4216397E-05
     +,   9.5841417E-05,   9.7341021E-05,   9.8704048E-05
     +,   9.9919947E-05,   1.0097903E-04,   1.0187246E-04
     +,   1.0259236E-04,   1.0313221E-04,   1.0348669E-04
     +,   1.0365201E-04,   1.0362590E-04,   1.0340768E-04
     +,   1.0299839E-04,   1.0240074E-04,   1.0161920E-04
     +,   1.0065985E-04,   9.9530444E-05,   9.8240358E-05
     +,   9.6800526E-05,   9.5223128E-05,   9.3521689E-05
     +,   9.1710936E-05,   8.9806606E-05,   8.7825189E-05
     +,   8.5783839E-05,   8.3700375E-05,   8.1592785E-05
     +,   7.9479185E-05,   7.7377823E-05,   7.5306692E-05
     +,   7.3283270E-05,   7.1324437E-05,   6.9446411E-05
     +,   6.7664376E-05,   6.5992244E-05,   6.4442545E-05
     +,   6.3026251E-05,   6.1752580E-05,   6.0628594E-05
     +,   5.9659196E-05,   5.8846977E-05,   5.8191916E-05
     +,   5.7691344E-05,   5.7339883E-05,   5.7129339E-05
     +,   5.7048823E-05,   5.7084857E-05,   5.7221660E-05
     +,   5.7441561E-05,   5.7725771E-05,   5.8055291E-05
     +,   5.8412432E-05,   5.8782673E-05,   5.9157337E-05
     +,   5.9536724E-05,   5.9933860E-05,   6.0378607E-05
     +,   6.0921455E-05,   6.1636769E-05,   6.2624262E-05
     +,   6.4008840E-05,   6.5937995E-05,   6.8577581E-05
     +,   7.2107985E-05,   7.6723845E-05,   8.2641658E-05
     +,   9.0121466E-05,   9.9511235E-05,   1.1132029E-04
     +,   1.2632072E-04,   1.4566354E-04,   1.7098375E-04
     +,   2.0443489E-04,   2.4860236E-04,   3.0628988E-04
     +,   3.8026756E-04,   4.7319135E-04,   5.8799761E-04
     +,   7.2900433E-04,   9.0356829E-04,   1.1235557E-03
     +,   1.4054126E-03,   1.7677299E-03,   2.2260337E-03
     +,   2.7859230E-03,   3.4368334E-03,   4.1489378E-03
     +,   4.8739580E-03,   5.5496963E-03,   6.1076018E-03
     +,   6.4826543E-03,   6.6248551E-03,   6.5105329E-03
     +,   6.1497418E-03,   5.5858474E-03,   4.8863934E-03
     +,   4.1282414E-03,   3.3822777E-03,   2.7026294E-03
     +,   2.1223961E-03,   1.6547713E-03,   1.2970088E-03
     +,   1.0356002E-03,   8.5124967E-04,   7.2314061E-04
     +,   6.3222827E-04,   5.6327943E-04,   5.0561718E-04
     +,   4.5282108E-04,   4.0181930E-04,   3.5179555E-04
     +,   3.0320109E-04,   2.5700236E-04,   2.1419307E-04
     +,   1.7553888E-04,   1.4148578E-04,   1.1216088E-04
     +,   8.7436871E-05,   6.7008194E-05,   5.0457664E-05
     +,   3.7310074E-05,   2.7073384E-05,   1.9266905E-05
     +,   1.3439936E-05,   9.1851671E-06,   6.1476335E-06
     +,   4.0284381E-06,   2.5839827E-06,   1.6222203E-06
     +,   9.9674526E-07,   5.9948360E-07,   3.5303174E-07
     +,   2.0367540E-07,   1.1523969E-07,   6.4055442E-08
     +,   3.5075786E-08,   1.9006015E-08,   1.0261714E-08
     +,   5.5771570E-09,   3.0930345E-09,   1.7782935E-09
     +,   1.0752557E-09,   6.8914391E-10,   4.6731369E-10
     +,   3.3198594E-10,   2.4385388E-10,   1.8295102E-10
     +,   1.3890528E-10,   1.0607337E-10,   8.1162486E-11
     +,   6.2087765E-11,   4.7426788E-11,   3.6151637E-11
     +,   2.7489878E-11,   2.0848727E-11,   1.5769074E-11
     +,   1.1894435E-11,   8.9469447E-12,   6.7112613E-12
     +,   5.0202017E-12,   3.7448395E-12,   2.7856821E-12
     +,   2.0664492E-12,   1.5286402E-12,   1.1276625E-12
     +,   8.2954612E-13,   6.0854864E-13,   4.4518534E-13
     +,   3.2476655E-13,   2.3626394E-13,   1.7139908E-13
     +,   1.2399790E-13,   8.9455217E-14,   6.4356418E-14
     +,   4.6170296E-14,   3.3031557E-14,   2.3565732E-14
     +,   1.6765891E-14,   1.1894795E-14,   8.4155688E-15
     +,   5.9373660E-15,   4.1773365E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_hatt100 = Yx/0.0245
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5633219E-05,   1.5759162E-05
     +,   1.5887243E-05,   1.6017528E-05,   1.6150068E-05
     +,   1.6284917E-05,   1.6422113E-05,   1.6561697E-05
     +,   1.6703694E-05,   1.6848133E-05,   1.6995025E-05
     +,   1.7144381E-05,   1.7296199E-05,   1.7450466E-05
     +,   1.7607166E-05,   1.7766277E-05,   1.7927752E-05
     +,   1.8091549E-05,   1.8257613E-05,   1.8425877E-05
     +,   1.8596258E-05,   1.8768675E-05,   1.8943019E-05
     +,   1.9119196E-05,   1.9297069E-05,   1.9476520E-05
     +,   1.9657398E-05,   1.9839556E-05,   2.0022826E-05
     +,   2.0207033E-05,   2.0391994E-05,   2.0577509E-05
     +,   2.0763377E-05,   2.0949381E-05,   2.1135294E-05
     +,   2.1320884E-05,   2.1505910E-05,   2.1690112E-05
     +,   2.1873248E-05,   2.2055036E-05,   2.2235216E-05
     +,   2.2413507E-05,   2.2589631E-05,   2.2763305E-05
     +,   2.2934237E-05,   2.3102149E-05,   2.3266744E-05
     +,   2.3427741E-05,   2.3584855E-05,   2.3737803E-05
     +,   2.3886319E-05,   2.4030138E-05,   2.4169000E-05
     +,   2.4302662E-05,   2.4430898E-05,   2.4553497E-05
     +,   2.4670268E-05,   2.4781035E-05,   2.4885661E-05
     +,   2.4984027E-05,   2.5076040E-05,   2.5161664E-05
     +,   2.5240894E-05,   2.5313748E-05,   2.5380334E-05
     +,   2.5440784E-05,   2.5495292E-05,   2.5544126E-05
     +,   2.5587617E-05,   2.5626174E-05,   2.5660300E-05
     +,   2.5690562E-05,   2.5717649E-05,   2.5742340E-05
     +,   2.5765517E-05,   2.5788209E-05,   2.5811547E-05
     +,   2.5836782E-05,   2.5865342E-05,   2.5898787E-05
     +,   2.5938809E-05,   2.5987301E-05,   2.6046293E-05
     +,   2.6118012E-05,   2.6204842E-05,   2.6309366E-05
     +,   2.6434342E-05,   2.6582726E-05,   2.6757631E-05
     +,   2.6962405E-05,   2.7200529E-05,   2.7475695E-05
     +,   2.7791713E-05,   2.8152601E-05,   2.8562494E-05
     +,   2.9025623E-05,   2.9546383E-05,   3.0129167E-05
     +,   3.0778498E-05,   3.1498836E-05,   3.2294698E-05
     +,   3.3170483E-05,   3.4130531E-05,   3.5178982E-05
     +,   3.6319827E-05,   3.7556834E-05,   3.8893377E-05
     +,   4.0332445E-05,   4.1876701E-05,   4.3528329E-05
     +,   4.5288780E-05,   4.7159116E-05,   4.9139522E-05
     +,   5.1229628E-05,   5.3428055E-05,   5.5732857E-05
     +,   5.8140879E-05,   6.0648337E-05,   6.3250191E-05
     +,   6.5940614E-05,   6.8712805E-05,   7.1558759E-05
     +,   7.4469455E-05,   7.7435063E-05,   8.0444785E-05
     +,   8.3486651E-05,   8.6548163E-05,   8.9615685E-05
     +,   9.2675218E-05,   9.5711788E-05,   9.8710290E-05
     +,   1.0165480E-04,   1.0452961E-04,   1.0731844E-04
     +,   1.1000531E-04,   1.1257447E-04,   1.1501028E-04
     +,   1.1729761E-04,   1.1942221E-04,   1.2137056E-04
     +,   1.2313004E-04,   1.2468912E-04,   1.2603773E-04
     +,   1.2716712E-04,   1.2807002E-04,   1.2874091E-04
     +,   1.2917597E-04,   1.2937322E-04,   1.2933255E-04
     +,   1.2905587E-04,   1.2854695E-04,   1.2781165E-04
     +,   1.2685781E-04,   1.2569515E-04,   1.2433526E-04
     +,   1.2279171E-04,   1.2107976E-04,   1.1921626E-04
     +,   1.1721963E-04,   1.1510977E-04,   1.1290768E-04
     +,   1.1063545E-04,   1.0831618E-04,   1.0597364E-04
     +,   1.0363192E-04,   1.0131534E-04,   9.9048288E-05
     +,   9.6854856E-05,   9.4758347E-05,   9.2781142E-05
     +,   9.0944515E-05,   8.9268200E-05,   8.7770029E-05
     +,   8.6465814E-05,   8.5369371E-05,   8.4492305E-05
     +,   8.3844265E-05,   8.3433384E-05,   8.3266910E-05
     +,   8.3352046E-05,   8.3697298E-05,   8.4313833E-05
     +,   8.5217187E-05,   8.6429071E-05,   8.7978951E-05
     +,   8.9905203E-05,   9.2255643E-05,   9.5087387E-05
     +,   9.8464749E-05,   1.0245574E-04,   1.0712729E-04
     +,   1.1253864E-04,   1.1873307E-04,   1.2572999E-04
     +,   1.3351854E-04,   1.4205243E-04,   1.5124929E-04
     +,   1.6099663E-04,   1.7116597E-04,   1.8163392E-04
     +,   1.9231066E-04,   2.0317675E-04,   2.1432346E-04
     +,   2.2599098E-04,   2.3860221E-04,   2.5279139E-04
     +,   2.6942213E-04,   2.8959784E-04,   3.1467658E-04
     +,   3.4630348E-04,   3.8647000E-04,   4.3761820E-04
     +,   5.0279789E-04,   5.8586564E-04,   6.9167482E-04
     +,   8.2617189E-04,   9.9631655E-04,   1.2096919E-03
     +,   1.4736719E-03,   1.7940853E-03,   2.1735481E-03
     +,   2.6095179E-03,   3.0924932E-03,   3.6048766E-03
     +,   4.1209711E-03,   4.6083210E-03,   5.0306153E-03
     +,   5.3519090E-03,   5.5414750E-03,   5.5783624E-03
     +,   5.4548341E-03,   5.1779165E-03,   4.7685849E-03
     +,   4.2588478E-03,   3.6873238E-03,   3.0939912E-03
     +,   2.5154119E-03,   1.9810623E-03,   1.5111928E-03
     +,   1.1163804E-03,   7.9858617E-04,   5.5311120E-04
     +,   3.7090108E-04,   2.4078447E-04,   1.5132131E-04
     +,   9.2060174E-05,   5.4219810E-05,   3.0915828E-05
     +,   1.7068614E-05,   9.1276879E-06,   4.7306580E-06
     +,   2.3789023E-06,   1.1633753E-06,   5.5576146E-07
     +,   2.6158821E-07,   1.2329716E-07,   5.9857605E-08
     +,   3.1171233E-08,   1.8132756E-08,   1.1968362E-08
     +,   8.7862535E-09,   6.9129844E-09,   5.6461067E-09
     +,   4.6934896E-09,   3.9309622E-09,   3.3014975E-09
     +,   2.7749141E-09,   2.3322053E-09,   1.9594899E-09
     +,   1.6456968E-09,   1.3816491E-09,   1.1596307E-09
     +,   9.7310171E-10,   8.1649293E-10,   6.8508887E-10
     +,   5.7490263E-10,   4.8254745E-10,   4.0517173E-10
     +,   3.4035982E-10,   2.8608330E-10,   2.4062830E-10
     +,   2.0255989E-10,   1.7066870E-10,   1.4394443E-10
     +,   1.2153738E-10,   1.0273978E-10,   8.6957677E-11
     +,   7.3695147E-11,   6.2539446E-11,   5.3144909E-11
     +,   4.5224244E-11,   3.8537153E-11,   3.2883973E-11
     +,   2.8097590E-11,   2.4039335E-11,   2.0592889E-11
     +,   1.7661744E-11,   1.5164805E-11,   1.3034662E-11
     +,   1.1214605E-11,   9.6573114E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_hatt105 = Yx/0.0238
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2766570E-05,   2.3603854E-05
     +,   2.4463725E-05,   2.5348099E-05,   2.6259488E-05
     +,   2.7201138E-05,   2.8177195E-05,   2.9192770E-05
     +,   3.0254128E-05,   3.1368843E-05,   3.2545850E-05
     +,   3.3795583E-05,   3.5130081E-05,   3.6562960E-05
     +,   3.8109516E-05,   3.9786555E-05,   4.1612366E-05
     +,   4.3606458E-05,   4.5789355E-05,   4.8182181E-05
     +,   5.0806244E-05,   5.3682503E-05,   5.6830930E-05
     +,   6.0270046E-05,   6.4015658E-05,   6.8080823E-05
     +,   7.2474482E-05,   7.7200988E-05,   8.2259343E-05
     +,   8.7642613E-05,   9.3337381E-05,   9.9323523E-05
     +,   1.0557403E-04,   1.1205512E-04,   1.1872655E-04
     +,   1.2554241E-04,   1.3245178E-04,   1.3940009E-04
     +,   1.4633105E-04,   1.5318717E-04,   1.5991363E-04
     +,   1.6645911E-04,   1.7277910E-04,   1.7883863E-04
     +,   1.8461503E-04,   1.9010089E-04,   1.9530744E-04
     +,   2.0026710E-04,   2.0503631E-04,   2.0969759E-04
     +,   2.1436116E-04,   2.1916567E-04,   2.2427784E-04
     +,   2.2989168E-04,   2.3622457E-04,   2.4351565E-04
     +,   2.5201988E-04,   2.6200380E-04,   2.7373995E-04
     +,   2.8750117E-04,   3.0355519E-04,   3.2215845E-04
     +,   3.4354674E-04,   3.6792931E-04,   3.9547484E-04
     +,   4.2629402E-04,   4.6042886E-04,   4.9782818E-04
     +,   5.3834665E-04,   5.8174052E-04,   6.2771200E-04
     +,   6.7597540E-04,   7.2640472E-04,   7.7921955E-04
     +,   8.3524256E-04,   8.9614576E-04,   9.6461875E-04
     +,   1.0443649E-03,   1.1398044E-03,   1.2554069E-03
     +,   1.3946773E-03,   1.5590593E-03,   1.7470631E-03
     +,   1.9544768E-03,   2.1763032E-03,   2.4113161E-03
     +,   2.6687121E-03,   2.9743763E-03,   3.3698082E-03
     +,   3.8954616E-03,   4.5585921E-03,   5.3101499E-03
     +,   6.0741077E-03,   6.8372260E-03,   7.7131581E-03
     +,   8.8665765E-03,   1.0348684E-02,   1.2066201E-02
     +,   1.3924942E-02,   1.5922518E-02,   1.8225724E-02
     +,   2.1192849E-02,   2.4737053E-02,   2.7950335E-02
     +,   3.0103566E-02,   3.0847734E-02,   2.9685035E-02
     +,   2.6687963E-02,   2.2909272E-02,   1.9457290E-02
     +,   1.6717030E-02,   1.4537788E-02,   1.2691734E-02
     +,   1.1054159E-02,   9.5587065E-03,   8.1757223E-03
     +,   6.9298521E-03,   5.8512576E-03,   4.9323989E-03
     +,   4.1492074E-03,   3.4890934E-03,   2.9463549E-03
     +,   2.5083662E-03,   2.1545584E-03,   1.8640675E-03
     +,   1.6214384E-03,   1.4170634E-03,   1.2449306E-03
     +,   1.1003234E-03,   9.7887311E-04,   8.7652996E-04
     +,   7.8991381E-04,   7.1643555E-04,   6.5421232E-04
     +,   6.0180522E-04,   5.5799197E-04,   5.2161206E-04
     +,   4.9149798E-04,   4.6647311E-04,   4.4539041E-04
     +,   4.2718177E-04,   4.1090080E-04,   3.9575589E-04
     +,   3.8112770E-04,   3.6657150E-04,   3.5180166E-04
     +,   3.3667029E-04,   3.2114124E-04,   3.0526079E-04
     +,   2.8912921E-04,   2.7287897E-04,   2.5665696E-04
     +,   2.4060931E-04,   2.2487032E-04,   2.0955785E-04
     +,   1.9477081E-04,   1.8058729E-04,   1.6706453E-04
     +,   1.5424137E-04,   1.4214206E-04,   1.3077598E-04
     +,   1.2014159E-04,   1.1022946E-04,   1.0102337E-04
     +,   9.2501468E-05,   8.4638486E-05,   7.7407116E-05
     +,   7.0778318E-05,   6.4721629E-05,   5.9206024E-05
     +,   5.4200635E-05,   4.9674614E-05,   4.5597084E-05
     +,   4.1937670E-05,   3.8667004E-05,   3.5756115E-05
     +,   3.3177028E-05,   3.0903004E-05,   2.8908395E-05
     +,   2.7168722E-05,   2.5660853E-05,   2.4363157E-05
     +,   2.3255390E-05,   2.2318673E-05,   2.1535550E-05
     +,   2.0889995E-05,   2.0367312E-05,   1.9954001E-05
     +,   1.9637782E-05,   1.9407511E-05,   1.9253015E-05
     +,   1.9165052E-05,   1.9135243E-05,   1.9155939E-05
     +,   1.9220161E-05,   1.9321544E-05,   1.9454228E-05
     +,   1.9612822E-05,   1.9792356E-05,   1.9988220E-05
     +,   2.0196127E-05,   2.0412062E-05,   2.0632302E-05
     +,   2.0853355E-05,   2.1071935E-05,   2.1284985E-05
     +,   2.1489652E-05,   2.1683260E-05,   2.1863323E-05
     +,   2.2027563E-05,   2.2173879E-05,   2.2300352E-05
     +,   2.2405246E-05,   2.2487027E-05,   2.2544347E-05
     +,   2.2576047E-05,   2.2581145E-05,   2.2558872E-05
     +,   2.2508626E-05,   2.2430002E-05,   2.2322778E-05
     +,   2.2186898E-05,   2.2022494E-05,   2.1829865E-05
     +,   2.1609467E-05,   2.1361899E-05,   2.1087921E-05
     +,   2.0788437E-05,   2.0464451E-05,   2.0117088E-05
     +,   1.9747593E-05,   1.9357314E-05,   1.8947656E-05
     +,   1.8520082E-05,   1.8076171E-05,   1.7617493E-05
     +,   1.7145667E-05,   1.6662356E-05,   1.6169237E-05
     +,   1.5667956E-05,   1.5160163E-05,   1.4647499E-05
     +,   1.4131599E-05,   1.3614012E-05,   1.3096247E-05
     +,   1.2579801E-05,   1.2066094E-05,   1.1556464E-05
     +,   1.1052166E-05,   1.0554433E-05,   1.0064371E-05
     +,   9.5830028E-06,   9.1112934E-06,   8.6501286E-06
     +,   8.2002680E-06,   7.7623918E-06,   7.3371189E-06
     +,   6.9249813E-06,   6.5263994E-06,   6.1417145E-06
     +,   5.7712127E-06,   5.4151028E-06,   5.0734957E-06
     +,   4.7464378E-06,   4.4339408E-06,   4.1359212E-06
     +,   3.8522426E-06,   3.5827359E-06,   3.3271829E-06
     +,   3.0853030E-06,   2.8567813E-06,   2.6412833E-06
     +,   2.4384433E-06,   2.2478573E-06,   2.0691009E-06
     +,   1.9017515E-06,   1.7453482E-06,   1.5994439E-06
     +,   1.4635640E-06,   1.3372500E-06,   1.2200248E-06
     +,   1.1114307E-06,   1.0109992E-06,   9.1828258E-07
     +,   8.3282947E-07,   7.5421019E-07,   6.8199910E-07
     +,   6.1578407E-07,   5.5517387E-07,   4.9978405E-07
     +,   4.4925309E-07,   4.0322931E-07,   3.6138323E-07
     +,   3.2339668E-07,   2.8897318E-07,   2.5782839E-07
     +,   2.2969826E-07,   2.0433153E-07,   1.8149572E-07
     +,   1.6097086E-07,   1.4255468E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_hatt75 = Yx/0.120536585365854
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5421835E-05,   3.6369194E-05
     +,   3.7315531E-05,   3.8261758E-05,   3.9209372E-05
     +,   4.0160499E-05,   4.1117979E-05,   4.2085478E-05
     +,   4.3067506E-05,   4.4069602E-05,   4.5098299E-05
     +,   4.6161265E-05,   4.7267375E-05,   4.8426726E-05
     +,   4.9650724E-05,   5.0952043E-05,   5.2344691E-05
     +,   5.3843898E-05,   5.5466069E-05,   5.7228648E-05
     +,   5.9149963E-05,   6.1248960E-05,   6.3544896E-05
     +,   6.6057175E-05,   6.8804497E-05,   7.1804934E-05
     +,   7.5074953E-05,   7.8629040E-05,   8.2478989E-05
     +,   8.6633307E-05,   9.1096525E-05,   9.5868505E-05
     +,   1.0094392E-04,   1.0631157E-04,   1.1195401E-04
     +,   1.1784711E-04,   1.2395989E-04,   1.3025434E-04
     +,   1.3668601E-04,   1.4320327E-04,   1.4974919E-04
     +,   1.5626142E-04,   1.6267330E-04,   1.6891530E-04
     +,   1.7491631E-04,   1.8060509E-04,   1.8591234E-04
     +,   1.9077222E-04,   1.9512461E-04,   1.9891681E-04
     +,   2.0210599E-04,   2.0466065E-04,   2.0656304E-04
     +,   2.0781066E-04,   2.0841781E-04,   2.0841711E-04
     +,   2.0786071E-04,   2.0682055E-04,   2.0538956E-04
     +,   2.0368058E-04,   2.0182633E-04,   1.9997769E-04
     +,   1.9830221E-04,   1.9698015E-04,   1.9620176E-04
     +,   1.9616184E-04,   1.9705434E-04,   1.9906562E-04
     +,   2.0236707E-04,   2.0710680E-04,   2.1340216E-04
     +,   2.2133005E-04,   2.3092101E-04,   2.4215058E-04
     +,   2.5493620E-04,   2.6913450E-04,   2.8454018E-04
     +,   3.0089080E-04,   3.1787582E-04,   3.3514714E-04
     +,   3.5233342E-04,   3.6906305E-04,   3.8498276E-04
     +,   3.9978680E-04,   4.1323868E-04,   4.2520120E-04
     +,   4.3565637E-04,   4.4472786E-04,   4.5269114E-04
     +,   4.5997891E-04,   4.6717250E-04,   4.7498263E-04
     +,   4.8421856E-04,   4.9575197E-04,   5.1047560E-04
     +,   5.2926654E-04,   5.5295962E-04,   5.8231916E-04
     +,   6.1802234E-04,   6.6061493E-04,   7.1047811E-04
     +,   7.6778018E-04,   8.3251478E-04,   9.0464513E-04
     +,   9.8448514E-04,   1.0732649E-03,   1.1737855E-03
     +,   1.2908706E-03,   1.4312019E-03,   1.6022058E-03
     +,   1.8100546E-03,   2.0576315E-03,   2.3436132E-03
     +,   2.6641288E-03,   3.0169177E-03,   3.4067184E-03
     +,   3.8487192E-03,   4.3675876E-03,   4.9901837E-03
     +,   5.7327803E-03,   6.5847398E-03,   7.4937353E-03
     +,   8.3612250E-03,   9.0578115E-03,   9.4611971E-03
     +,   9.5040612E-03,   9.2056310E-03,   8.6640259E-03
     +,   8.0104908E-03,   7.3525207E-03,   6.7389566E-03
     +,   6.1635678E-03,   5.5958475E-03,   5.0147944E-03
     +,   4.4248211E-03,   3.8507215E-03,   3.3217904E-03
     +,   2.8580541E-03,   2.4653575E-03,   2.1381944E-03
     +,   1.8654781E-03,   1.6354753E-03,   1.4386022E-03
     +,   1.2683197E-03,   1.1207865E-03,   9.9385285E-04
     +,   8.8599691E-04,   7.9552870E-04,   7.2024419E-04
     +,   6.5751403E-04,   6.0461205E-04,   5.5906014E-04
     +,   5.1884615E-04,   4.8249267E-04,   4.4900822E-04
     +,   4.1777818E-04,   3.8844146E-04,   3.6078869E-04
     +,   3.3469422E-04,   3.1007564E-04,   2.8686688E-04
     +,   2.6501191E-04,   2.4446420E-04,   2.2518604E-04
     +,   2.0714880E-04,   1.9033438E-04,   1.7473481E-04
     +,   1.6034731E-04,   1.4716922E-04,   1.3519420E-04
     +,   1.2440812E-04,   1.1478474E-04,   1.0628301E-04
     +,   9.8847369E-05,   9.2409355E-05,   8.6888220E-05
     +,   8.2194914E-05,   7.8235629E-05,   7.4914868E-05
     +,   7.2138471E-05,   6.9816655E-05,   6.7866160E-05
     +,   6.6211571E-05,   6.4786123E-05,   6.3532141E-05
     +,   6.2401057E-05,   6.1352839E-05,   6.0355240E-05
     +,   5.9383085E-05,   5.8417467E-05,   5.7444613E-05
     +,   5.6455156E-05,   5.5443368E-05,   5.4406377E-05
     +,   5.3343480E-05,   5.2255655E-05,   5.1145205E-05
     +,   5.0015289E-05,   4.8869570E-05,   4.7712048E-05
     +,   4.6546931E-05,   4.5378434E-05,   4.4210585E-05
     +,   4.3047239E-05,   4.1892097E-05,   4.0748459E-05
     +,   3.9619335E-05,   3.8507449E-05,   3.7415208E-05
     +,   3.6344598E-05,   3.5297271E-05,   3.4274661E-05
     +,   3.3277858E-05,   3.2307620E-05,   3.1364427E-05
     +,   3.0448577E-05,   2.9560135E-05,   2.8698907E-05
     +,   2.7864508E-05,   2.7056492E-05,   2.6274191E-05
     +,   2.5516798E-05,   2.4783503E-05,   2.4073392E-05
     +,   2.3385453E-05,   2.2718643E-05,   2.2071938E-05
     +,   2.1444304E-05,   2.0834677E-05,   2.0242009E-05
     +,   1.9665318E-05,   1.9103663E-05,   1.8556111E-05
     +,   1.8021774E-05,   1.7499879E-05,   1.6989659E-05
     +,   1.6490405E-05,   1.6001513E-05,   1.5522432E-05
     +,   1.5052648E-05,   1.4591707E-05,   1.4139245E-05
     +,   1.3694955E-05,   1.3258555E-05,   1.2829812E-05
     +,   1.2408568E-05,   1.1994716E-05,   1.1588148E-05
     +,   1.1188800E-05,   1.0796673E-05,   1.0411762E-05
     +,   1.0034077E-05,   9.6636768E-06,   9.3006338E-06
     +,   8.9450041E-06,   8.5968595E-06,   8.2562919E-06
     +,   7.9233987E-06,   7.5982566E-06,   7.2809307E-06
     +,   6.9715147E-06,   6.6700873E-06,   6.3766952E-06
     +,   6.0913840E-06,   5.8142105E-06,   5.5451947E-06
     +,   5.2843416E-06,   5.0316621E-06,   4.7871522E-06
     +,   4.5507782E-06,   4.3224950E-06,   4.1022554E-06
     +,   3.8900012E-06,   3.6856459E-06,   3.4890902E-06
     +,   3.3002441E-06,   3.1189811E-06,   2.9451869E-06
     +,   2.7787144E-06,   2.6194298E-06,   2.4671692E-06
     +,   2.3217826E-06,   2.1830933E-06,   2.0509365E-06
     +,   1.9251247E-06,   1.8054843E-06,   1.6918244E-06
     +,   1.5839522E-06,   1.4816831E-06,   1.3848190E-06
     +,   1.2931725E-06,   1.2065437E-06,   1.1247465E-06
     +,   1.0475837E-06,   9.7487032E-07,   9.0641362E-07
     +,   8.4203339E-07,   7.8154329E-07,   7.2476843E-07
     +,   6.7152968E-07,   6.2166004E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_hatt80 = Yx/0.05
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9284656E-05,   2.0197538E-05
     +,   2.1131324E-05,   2.2084623E-05,   2.3055876E-05
     +,   2.4043324E-05,   2.5045056E-05,   2.6058959E-05
     +,   2.7082735E-05,   2.8113971E-05,   2.9150053E-05
     +,   3.0188199E-05,   3.1225540E-05,   3.2259039E-05
     +,   3.3285589E-05,   3.4301993E-05,   3.5305005E-05
     +,   3.6291345E-05,   3.7257741E-05,   3.8200975E-05
     +,   3.9117902E-05,   4.0005485E-05,   4.0860872E-05
     +,   4.1681440E-05,   4.2464773E-05,   4.3208849E-05
     +,   4.3911969E-05,   4.4572873E-05,   4.5190816E-05
     +,   4.5765562E-05,   4.6297522E-05,   4.6787758E-05
     +,   4.7238056E-05,   4.7651010E-05,   4.8030008E-05
     +,   4.8379337E-05,   4.8704202E-05,   4.9010738E-05
     +,   4.9306076E-05,   4.9598279E-05,   4.9896407E-05
     +,   5.0210449E-05,   5.0551273E-05,   5.0930605E-05
     +,   5.1360901E-05,   5.1855259E-05,   5.2427251E-05
     +,   5.3090818E-05,   5.3860025E-05,   5.4748845E-05
     +,   5.5770986E-05,   5.6939534E-05,   5.8266709E-05
     +,   5.9763672E-05,   6.1439961E-05,   6.3303494E-05
     +,   6.5360029E-05,   6.7612978E-05,   7.0063084E-05
     +,   7.2708266E-05,   7.5543336E-05,   7.8559991E-05
     +,   8.1746410E-05,   8.5087791E-05,   8.8566143E-05
     +,   9.2160160E-05,   9.5846248E-05,   9.9598001E-05
     +,   1.0338765E-04,   1.0718561E-04,   1.1096217E-04
     +,   1.1468722E-04,   1.1833206E-04,   1.2186931E-04
     +,   1.2527453E-04,   1.2852674E-04,   1.3160906E-04
     +,   1.3450974E-04,   1.3722287E-04,   1.3974884E-04
     +,   1.4209421E-04,   1.4427262E-04,   1.4630395E-04
     +,   1.4821453E-04,   1.5003601E-04,   1.5180487E-04
     +,   1.5356085E-04,   1.5534583E-04,   1.5720190E-04
     +,   1.5916975E-04,   1.6128694E-04,   1.6358557E-04
     +,   1.6609093E-04,   1.6882022E-04,   1.7178117E-04
     +,   1.7497149E-04,   1.7837939E-04,   1.8198385E-04
     +,   1.8575713E-04,   1.8966620E-04,   1.9367716E-04
     +,   1.9775778E-04,   2.0188284E-04,   2.0603732E-04
     +,   2.1022098E-04,   2.1445118E-04,   2.1876438E-04
     +,   2.2321679E-04,   2.2788314E-04,   2.3285407E-04
     +,   2.3823183E-04,   2.4412786E-04,   2.5066012E-04
     +,   2.5795645E-04,   2.6616085E-04,   2.7545122E-04
     +,   2.8606065E-04,   2.9831045E-04,   3.1264150E-04
     +,   3.2964733E-04,   3.5009068E-04,   3.7489631E-04
     +,   4.0511056E-04,   4.4182048E-04,   4.8602617E-04
     +,   5.3847360E-04,   5.9948489E-04,   6.6877878E-04
     +,   7.4536749E-04,   8.2751183E-04,   9.1283442E-04
     +,   9.9854532E-04,   1.0818676E-03,   1.1605750E-03
     +,   1.2336861E-03,   1.3021874E-03,   1.3696934E-03
     +,   1.4428516E-03,   1.5312489E-03,   1.6465329E-03
     +,   1.8005812E-03,   2.0027747E-03,   2.2567827E-03
     +,   2.5575703E-03,   2.8896399E-03,   3.2275061E-03
     +,   3.5386819E-03,   3.7889029E-03,   3.9484818E-03
     +,   3.9980649E-03,   3.9321720E-03,   3.7596403E-03
     +,   3.5009664E-03,   3.1834890E-03,   2.8359564E-03
     +,   2.4839479E-03,   2.1469670E-03,   1.8375015E-03
     +,   1.5617188E-03,   1.3210454E-03,   1.1138859E-03
     +,   9.3716144E-04,   7.8735617E-04,   6.6108210E-04
     +,   5.5531139E-04,   4.6742812E-04,   3.9517909E-04
     +,   3.3658725E-04,   2.8987974E-04,   2.5343808E-04
     +,   2.2576604E-04,   2.0547099E-04,   1.9126640E-04
     +,   1.8198631E-04,   1.7660209E-04,   1.7423287E-04
     +,   1.7415131E-04,   1.7577615E-04,   1.7865571E-04
     +,   1.8244545E-04,   1.8688287E-04,   1.9176300E-04
     +,   1.9691885E-04,   2.0220692E-04,   2.0749765E-04
     +,   2.1267000E-04,   2.1761020E-04,   2.2221246E-04
     +,   2.2637998E-04,   2.3002615E-04,   2.3307660E-04
     +,   2.3546959E-04,   2.3715595E-04,   2.3809964E-04
     +,   2.3827673E-04,   2.3767499E-04,   2.3629304E-04
     +,   2.3413975E-04,   2.3123329E-04,   2.2760051E-04
     +,   2.2327618E-04,   2.1830271E-04,   2.1272842E-04
     +,   2.0660723E-04,   1.9999838E-04,   1.9296411E-04
     +,   1.8556940E-04,   1.7788108E-04,   1.6996665E-04
     +,   1.6189234E-04,   1.5372277E-04,   1.4552036E-04
     +,   1.3734409E-04,   1.2924813E-04,   1.2128180E-04
     +,   1.1348964E-04,   1.0591053E-04,   9.8577177E-05
     +,   9.1516493E-05,   8.4750514E-05,   7.8295219E-05
     +,   7.2161587E-05,   6.6356391E-05,   6.0882285E-05
     +,   5.5737830E-05,   5.0918577E-05,   4.6417728E-05
     +,   4.2226333E-05,   3.8333466E-05,   3.4726971E-05
     +,   3.1394022E-05,   2.8321194E-05,   2.5494515E-05
     +,   2.2899996E-05,   2.0523965E-05,   1.8352728E-05
     +,   1.6372978E-05,   1.4571953E-05,   1.2937330E-05
     +,   1.1457189E-05,   1.0120150E-05,   8.9154610E-06
     +,   7.8328758E-06,   6.8626041E-06,   5.9953868E-06
     +,   5.2225337E-06,   4.5358379E-06,   3.9275365E-06
     +,   3.3903507E-06,   2.9175196E-06,   2.5026839E-06
     +,   2.1399392E-06,   1.8238353E-06,   1.5493381E-06
     +,   1.3117995E-06,   1.1069679E-06,   9.3098004E-07
     +,   7.8032713E-07,   6.5182786E-07,   5.4262472E-07
     +,   4.5016574E-07,   3.7217649E-07,   3.0663506E-07
     +,   2.5175842E-07,   2.0598615E-07,   1.6794921E-07
     +,   1.3645797E-07,   1.1048454E-07,   8.9142972E-08
     +,   7.1672410E-08,   5.7423716E-08,   4.5846697E-08
     +,   3.6475747E-08,   2.8918533E-08,   2.2846541E-08
     +,   1.7986359E-08,   1.4110325E-08,   1.1030848E-08
     +,   8.5931289E-09,   6.6706929E-09,   5.1601270E-09
     +,   3.9776471E-09,   3.0553502E-09,   2.3386810E-09
     +,   1.7838097E-09,   1.3558148E-09,   1.0268864E-09
     +,   7.7501311E-10,   5.8286465E-10,   4.3680684E-10
     +,   3.2619807E-10,   2.4273566E-10,   1.7999235E-10
     +,   1.3299406E-10,   9.7921067E-11,   7.1841443E-11
     +,   5.2521473E-11,   3.8260482E-11,   2.7773098E-11
     +,   2.0088490E-11,   1.4478617E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_hatt85 = Yx/0.0242666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8769795E-05,   2.9912828E-05
     +,   3.1074927E-05,   3.2254731E-05,   3.3450815E-05
     +,   3.4661607E-05,   3.5885467E-05,   3.7120670E-05
     +,   3.8365390E-05,   3.9617771E-05,   4.0875850E-05
     +,   4.2137632E-05,   4.3401054E-05,   4.4664073E-05
     +,   4.5924560E-05,   4.7180438E-05,   4.8429614E-05
     +,   4.9670034E-05,   5.0899685E-05,   5.2116597E-05
     +,   5.3318890E-05,   5.4504799E-05,   5.5672605E-05
     +,   5.6820834E-05,   5.7948022E-05,   5.9052985E-05
     +,   6.0134669E-05,   6.1192230E-05,   6.2225023E-05
     +,   6.3232714E-05,   6.4215143E-05,   6.5172484E-05
     +,   6.6105189E-05,   6.7014029E-05,   6.7900110E-05
     +,   6.8764901E-05,   6.9610243E-05,   7.0438386E-05
     +,   7.1252041E-05,   7.2054310E-05,   7.2848823E-05
     +,   7.3639661E-05,   7.4431482E-05,   7.5229451E-05
     +,   7.6039323E-05,   7.6867400E-05,   7.7720601E-05
     +,   7.8606412E-05,   7.9532925E-05,   8.0508806E-05
     +,   8.1543250E-05,   8.2645951E-05,   8.3827035E-05
     +,   8.5097083E-05,   8.6466782E-05,   8.7947177E-05
     +,   8.9549168E-05,   9.1283604E-05,   9.3161012E-05
     +,   9.5191353E-05,   9.7383905E-05,   9.9747005E-05
     +,   1.0228754E-04,   1.0501123E-04,   1.0792199E-04
     +,   1.1102148E-04,   1.1430949E-04,   1.1778293E-04
     +,   1.2143646E-04,   1.2526136E-04,   1.2924644E-04
     +,   1.3337683E-04,   1.3763503E-04,   1.4199983E-04
     +,   1.4644738E-04,   1.5095083E-04,   1.5548030E-04
     +,   1.6000342E-04,   1.6448594E-04,   1.6889181E-04
     +,   1.7318320E-04,   1.7732210E-04,   1.8126953E-04
     +,   1.8498726E-04,   1.8843742E-04,   1.9158401E-04
     +,   1.9439249E-04,   1.9683118E-04,   1.9887126E-04
     +,   2.0048735E-04,   2.0165804E-04,   2.0236609E-04
     +,   2.0259878E-04,   2.0234802E-04,   2.0161057E-04
     +,   2.0038807E-04,   1.9868673E-04,   1.9651768E-04
     +,   1.9389621E-04,   1.9084213E-04,   1.8737867E-04
     +,   1.8353311E-04,   1.7933537E-04,   1.7481859E-04
     +,   1.7001793E-04,   1.6497044E-04,   1.5971511E-04
     +,   1.5429228E-04,   1.4874287E-04,   1.4310851E-04
     +,   1.3743203E-04,   1.3175575E-04,   1.2612305E-04
     +,   1.2057681E-04,   1.1516071E-04,   1.0991781E-04
     +,   1.0489195E-04,   1.0012631E-04,   9.5664713E-05
     +,   9.1550341E-05,   8.7826142E-05,   8.4534848E-05
     +,   8.1718295E-05,   7.9416946E-05,   7.7669501E-05
     +,   7.6512464E-05,   7.5978845E-05,   7.6097560E-05
     +,   7.6892218E-05,   7.8380122E-05,   8.0571663E-05
     +,   8.3469684E-05,   8.7070970E-05,   9.1368071E-05
     +,   9.6355572E-05,   1.0203878E-04,   1.0844742E-04
     +,   1.1565557E-04,   1.2380804E-04,   1.3315189E-04
     +,   1.4407093E-04,   1.5712163E-04,   1.7306418E-04
     +,   1.9288040E-04,   2.1776721E-04,   2.4910909E-04
     +,   2.8840979E-04,   3.3718476E-04,   3.9682441E-04
     +,   4.6843704E-04,   5.5268075E-04,   6.4960745E-04
     +,   7.5855973E-04,   8.7813853E-04,   1.0062412E-03
     +,   1.1401830E-03,   1.2769122E-03,   1.4132842E-03
     +,   1.5463342E-03,   1.6735130E-03,   1.7928948E-03
     +,   1.9032273E-03,   2.0038683E-03,   2.0946183E-03
     +,   2.1754589E-03,   2.2462534E-03,   2.3064923E-03
     +,   2.3551499E-03,   2.3906936E-03,   2.4112421E-03
     +,   2.4148677E-03,   2.3999759E-03,   2.3656662E-03
     +,   2.3119969E-03,   2.2401067E-03,   2.1521277E-03
     +,   2.0509546E-03,   1.9398989E-03,   1.8223084E-03
     +,   1.7012130E-03,   1.5791060E-03,   1.4578574E-03
     +,   1.3387388E-03,   1.2225558E-03,   1.1098363E-03
     +,   1.0010178E-03,   8.9657540E-04,   7.9707976E-04
     +,   7.0320169E-04,   6.1566086E-04,   5.3511607E-04
     +,   4.6208082E-04,   3.9685264E-04,   3.3946583E-04
     +,   2.8968501E-04,   2.4704254E-04,   2.1089705E-04
     +,   1.8049733E-04,   1.5505093E-04,   1.3378564E-04
     +,   1.1599473E-04,   1.0106186E-04,   8.8471454E-05
     +,   7.7808087E-05,   6.8745663E-05,   6.1029881E-05
     +,   5.4462369E-05,   4.8885002E-05,   4.4166580E-05
     +,   4.0193041E-05,   3.6861697E-05,   3.4077962E-05
     +,   3.1753731E-05,   2.9807310E-05,   2.8164219E-05
     +,   2.6758073E-05,   2.5531117E-05,   2.4434390E-05
     +,   2.3427805E-05,   2.2479720E-05,   2.1566022E-05
     +,   2.0669318E-05,   1.9777963E-05,   1.8884977E-05
     +,   1.7987046E-05,   1.7083683E-05,   1.6176544E-05
     +,   1.5268717E-05,   1.4364163E-05,   1.3467335E-05
     +,   1.2582936E-05,   1.1715602E-05,   1.0869676E-05
     +,   1.0049130E-05,   9.2575747E-06,   8.4980256E-06
     +,   7.7729765E-06,   7.0844267E-06,   6.4338483E-06
     +,   5.8221508E-06,   5.2497794E-06,   4.7167682E-06
     +,   4.2227516E-06,   3.7669715E-06,   3.3483689E-06
     +,   2.9656501E-06,   2.6173025E-06,   2.3016207E-06
     +,   2.0167745E-06,   1.7608761E-06,   1.5319537E-06
     +,   1.3280256E-06,   1.1471301E-06,   9.8734017E-07
     +,   8.4677242E-07,   7.2361922E-07,   6.1616794E-07
     +,   5.2280063E-07,   4.4199641E-07,   3.7234440E-07
     +,   3.1254785E-07,   2.6141856E-07,   2.1787218E-07
     +,   1.8093004E-07,   1.4971575E-07,   1.2344412E-07
     +,   1.0141825E-07,   8.3024716E-08,   6.7724748E-08
     +,   5.5046911E-08,   4.4582173E-08,   3.5977841E-08
     +,   2.8930630E-08,   2.3180698E-08,   1.8507057E-08
     +,   1.4723037E-08,   1.1670775E-08,   9.2183061E-09
     +,   7.2551201E-09,   5.6896745E-09,   4.4460315E-09
     +,   3.4618397E-09,   2.6858569E-09,   2.0763880E-09
     +,   1.5994696E-09,   1.2277039E-09,   9.3897945E-10
     +,   7.1558426E-10,   5.4339400E-10,   4.1115988E-10
     +,   3.0999653E-10,   2.3288629E-10,   1.7433363E-10
     +,   1.3003490E-10,   9.6647003E-11,   7.1574496E-11
     +,   5.2817570E-11,   3.8836448E-11,   2.8454487E-11
     +,   2.0773208E-11,   1.5111445E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_hatt90 = Yx/0.0202758620689655
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1541508E-05,   1.1549479E-05
     +,   1.1548772E-05,   1.1539514E-05,   1.1521866E-05
     +,   1.1496022E-05,   1.1462220E-05,   1.1420721E-05
     +,   1.1371833E-05,   1.1315898E-05,   1.1253290E-05
     +,   1.1184424E-05,   1.1109754E-05,   1.1029767E-05
     +,   1.0944991E-05,   1.0855981E-05,   1.0763340E-05
     +,   1.0667699E-05,   1.0569727E-05,   1.0470127E-05
     +,   1.0369634E-05,   1.0269019E-05,   1.0169088E-05
     +,   1.0070669E-05,   9.9746367E-06,   9.8818828E-06
     +,   9.7933371E-06,   9.7099546E-06,   9.6327249E-06
     +,   9.5626647E-06,   9.5008199E-06,   9.4482675E-06
     +,   9.4061152E-06,   9.3755016E-06,   9.3575973E-06
     +,   9.3536119E-06,   9.3647868E-06,   9.3924082E-06
     +,   9.4378011E-06,   9.5023361E-06,   9.5874366E-06
     +,   9.6945751E-06,   9.8252895E-06,   9.9811741E-06
     +,   1.0163895E-05,   1.0375189E-05,   1.0616871E-05
     +,   1.0890838E-05,   1.1199069E-05,   1.1543637E-05
     +,   1.1926700E-05,   1.2350512E-05,   1.2817404E-05
     +,   1.3329834E-05,   1.3890279E-05,   1.4501357E-05
     +,   1.5165713E-05,   1.5886058E-05,   1.6665141E-05
     +,   1.7505721E-05,   1.8410570E-05,   1.9382427E-05
     +,   2.0423917E-05,   2.1537646E-05,   2.2726092E-05
     +,   2.3991459E-05,   2.5335876E-05,   2.6761049E-05
     +,   2.8268560E-05,   2.9859430E-05,   3.1534470E-05
     +,   3.3293829E-05,   3.5137356E-05,   3.7064103E-05
     +,   3.9072704E-05,   4.1161147E-05,   4.3326618E-05
     +,   4.5565524E-05,   4.7873735E-05,   5.0246341E-05
     +,   5.2677424E-05,   5.5160599E-05,   5.7688419E-05
     +,   6.0253020E-05,   6.2845487E-05,   6.5456574E-05
     +,   6.8076100E-05,   7.0693633E-05,   7.3297982E-05
     +,   7.5877790E-05,   7.8421428E-05,   8.0916892E-05
     +,   8.3352112E-05,   8.5715248E-05,   8.7994595E-05
     +,   9.0178510E-05,   9.2256087E-05,   9.4216695E-05
     +,   9.6050593E-05,   9.7748627E-05,   9.9302772E-05
     +,   1.0070582E-04,   1.0195180E-04,   1.0303585E-04
     +,   1.0395446E-04,   1.0470540E-04,   1.0528775E-04
     +,   1.0570203E-04,   1.0595012E-04,   1.0603530E-04
     +,   1.0596214E-04,   1.0573644E-04,   1.0536534E-04
     +,   1.0485698E-04,   1.0422049E-04,   1.0346592E-04
     +,   1.0260410E-04,   1.0164631E-04,   1.0060435E-04
     +,   9.9490237E-05,   9.8316035E-05,   9.7093805E-05
     +,   9.5835370E-05,   9.4552030E-05,   9.3254559E-05
     +,   9.1953283E-05,   9.0657479E-05,   8.9375862E-05
     +,   8.8116169E-05,   8.6885382E-05,   8.5689710E-05
     +,   8.4534739E-05,   8.3425548E-05,   8.2366991E-05
     +,   8.1363803E-05,   8.0420999E-05,   7.9544145E-05
     +,   7.8739722E-05,   7.8015270E-05,   7.7379817E-05
     +,   7.6844131E-05,   7.6420896E-05,   7.6124816E-05
     +,   7.5972814E-05,   7.5984084E-05,   7.6180069E-05
     +,   7.6584511E-05,   7.7223485E-05,   7.8125457E-05
     +,   7.9321508E-05,   8.0845770E-05,   8.2735802E-05
     +,   8.5033738E-05,   8.7787608E-05,   9.1053138E-05
     +,   9.4895346E-05,   9.9390614E-05,   1.0462844E-04
     +,   1.1071120E-04,   1.1775208E-04,   1.2587203E-04
     +,   1.3519313E-04,   1.4583029E-04,   1.5788394E-04
     +,   1.7143649E-04,   1.8655308E-04,   2.0329171E-04
     +,   2.2172970E-04,   2.4200875E-04,   2.6440297E-04
     +,   2.8941475E-04,   3.1791005E-04,   3.5129074E-04
     +,   3.9169690E-04,   4.4221914E-04,   5.0709496E-04
     +,   5.9180550E-04,   7.0297677E-04,   8.4799086E-04
     +,   1.0342019E-03,   1.2676965E-03,   1.5516703E-03
     +,   1.8846985E-03,   2.2592836E-03,   2.6610894E-03
     +,   3.0692792E-03,   3.4581979E-03,   3.8001975E-03
     +,   4.0690708E-03,   4.2435070E-03,   4.3100053E-03
     +,   4.2645773E-03,   4.1131927E-03,   3.8708814E-03
     +,   3.5596520E-03,   3.2056065E-03,   2.8356635E-03
     +,   2.4742952E-03,   2.1408531E-03,   1.8479476E-03
     +,   1.6010640E-03,   1.3993093E-03,   1.2370731E-03
     +,   1.1061358E-03,   9.9771400E-04,   9.0402667E-04
     +,   8.1925036E-04,   7.3981198E-04,   6.6413888E-04
     +,   5.9210713E-04,   5.2440685E-04,   4.6198248E-04
     +,   4.0563371E-04,   3.5580539E-04,   3.1254333E-04
     +,   2.7554962E-04,   2.4427832E-04,   2.1803906E-04
     +,   1.9608812E-04,   1.7769137E-04,   1.6216065E-04
     +,   1.4887885E-04,   1.3731291E-04,   1.2701786E-04
     +,   1.1763692E-04,   1.0889900E-04,   1.0061223E-04
     +,   9.2653579E-05,   8.4956417E-05,   7.7498204E-05
     +,   7.0288072E-05,   6.3354601E-05,   5.6735418E-05
     +,   5.0469862E-05,   4.4593919E-05,   3.9135357E-05
     +,   3.4112523E-05,   2.9534071E-05,   2.5398991E-05
     +,   2.1697435E-05,   1.8412460E-05,   1.5521748E-05
     +,   1.2998844E-05,   1.0814460E-05,   8.9379364E-06
     +,   7.3383681E-06,   5.9853114E-06,   4.8493794E-06
     +,   3.9028573E-06,   3.1201030E-06,   2.4775832E-06
     +,   1.9540821E-06,   1.5307400E-06,   1.1909498E-06
     +,   9.2024129E-07,   7.0616869E-07,   5.3815029E-07
     +,   4.0726582E-07,   3.0606586E-07,   2.2840038E-07
     +,   1.6924442E-07,   1.2452574E-07,   9.0973110E-08
     +,   6.5987038E-08,   4.7521578E-08,   3.3977535E-08
     +,   2.4118085E-08,   1.6995520E-08,   1.1889358E-08
     +,   8.2564879E-09,   5.6914993E-09,   3.8944301E-09
     +,   2.6450859E-09,   1.7831817E-09,   1.1931459E-09
     +,   7.9237972E-10,   5.2226468E-10,   3.4163969E-10
     +,   2.2179046E-10,   1.4289479E-10,   9.1362494E-11
     +,   5.7969653E-11,   3.6500202E-11,   2.2806357E-11
     +,   1.4140453E-11,   8.7001049E-12,   5.3116153E-12
     +,   3.2177865E-12,   1.9343106E-12,   1.1537574E-12
     +,   6.8286246E-13,   4.0101730E-13,   2.3367780E-13
     +,   1.3510644E-13,   7.7509153E-14,   4.4119537E-14
     +,   2.4918564E-14,   1.3964081E-14,   7.7644681E-15
     +,   4.2835659E-15,   2.3448131E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_hatt95 = Yx/0.0214666666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_hatt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.4457828E-05,   7.7392709E-05
     +,   8.0422098E-05,   8.3545921E-05,   8.6763794E-05
     +,   9.0075067E-05,   9.3478637E-05,   9.6973235E-05
     +,   1.0055696E-04,   1.0422792E-04,   1.0798355E-04
     +,   1.1182107E-04,   1.1573728E-04,   1.1972865E-04
     +,   1.2379134E-04,   1.2792114E-04,   1.3211343E-04
     +,   1.3636341E-04,   1.4066588E-04,   1.4501542E-04
     +,   1.4940629E-04,   1.5383255E-04,   1.5828789E-04
     +,   1.6276620E-04,   1.6726059E-04,   1.7176454E-04
     +,   1.7627112E-04,   1.8077342E-04,   1.8526426E-04
     +,   1.8973667E-04,   1.9418345E-04,   1.9859742E-04
     +,   2.0297148E-04,   2.0729854E-04,   2.1157153E-04
     +,   2.1578341E-04,   2.1992740E-04,   2.2399666E-04
     +,   2.2798477E-04,   2.3188497E-04,   2.3569120E-04
     +,   2.3939728E-04,   2.4299728E-04,   2.4648561E-04
     +,   2.4985697E-04,   2.5310583E-04,   2.5622756E-04
     +,   2.5921757E-04,   2.6207147E-04,   2.6478534E-04
     +,   2.6735559E-04,   2.6977883E-04,   2.7205228E-04
     +,   2.7417345E-04,   2.7614005E-04,   2.7795066E-04
     +,   2.7960385E-04,   2.8109894E-04,   2.8243562E-04
     +,   2.8361403E-04,   2.8463473E-04,   2.8549903E-04
     +,   2.8620841E-04,   2.8676511E-04,   2.8717174E-04
     +,   2.8743147E-04,   2.8754817E-04,   2.8752550E-04
     +,   2.8736857E-04,   2.8708213E-04,   2.8667189E-04
     +,   2.8614368E-04,   2.8550389E-04,   2.8475921E-04
     +,   2.8391674E-04,   2.8298350E-04,   2.8196725E-04
     +,   2.8087580E-04,   2.7971689E-04,   2.7849863E-04
     +,   2.7722924E-04,   2.7591668E-04,   2.7456926E-04
     +,   2.7319486E-04,   2.7180137E-04,   2.7039673E-04
     +,   2.6898843E-04,   2.6758370E-04,   2.6618972E-04
     +,   2.6481305E-04,   2.6346013E-04,   2.6213698E-04
     +,   2.6084937E-04,   2.5960221E-04,   2.5840028E-04
     +,   2.5724815E-04,   2.5614942E-04,   2.5510768E-04
     +,   2.5412586E-04,   2.5320664E-04,   2.5235210E-04
     +,   2.5156411E-04,   2.5084394E-04,   2.5019259E-04
     +,   2.4961110E-04,   2.4909960E-04,   2.4865853E-04
     +,   2.4828783E-04,   2.4798734E-04,   2.4775681E-04
     +,   2.4759592E-04,   2.4750427E-04,   2.4748160E-04
     +,   2.4752764E-04,   2.4764208E-04,   2.4782532E-04
     +,   2.4807735E-04,   2.4839901E-04,   2.4879084E-04
     +,   2.4925446E-04,   2.4979137E-04,   2.5040403E-04
     +,   2.5109478E-04,   2.5186708E-04,   2.5272480E-04
     +,   2.5367233E-04,   2.5471480E-04,   2.5585777E-04
     +,   2.5710778E-04,   2.5847182E-04,   2.5995751E-04
     +,   2.6157277E-04,   2.6332654E-04,   2.6522778E-04
     +,   2.6728582E-04,   2.6951087E-04,   2.7191226E-04
     +,   2.7450002E-04,   2.7728389E-04,   2.8027303E-04
     +,   2.8347617E-04,   2.8690117E-04,   2.9055492E-04
     +,   2.9444319E-04,   2.9856997E-04,   3.0293758E-04
     +,   3.0754684E-04,   3.1239542E-04,   3.1747893E-04
     +,   3.2279067E-04,   3.2832069E-04,   3.3405598E-04
     +,   3.3998032E-04,   3.4607496E-04,   3.5231764E-04
     +,   3.5868297E-04,   3.6514277E-04,   3.7166663E-04
     +,   3.7822212E-04,   3.8477447E-04,   3.9128825E-04
     +,   3.9772893E-04,   4.0406157E-04,   4.1025318E-04
     +,   4.1627442E-04,   4.2210091E-04,   4.2771347E-04
     +,   4.3310155E-04,   4.3826472E-04,   4.4321441E-04
     +,   4.4797582E-04,   4.5259052E-04,   4.5711966E-04
     +,   4.6164540E-04,   4.6627285E-04,   4.7113418E-04
     +,   4.7639068E-04,   4.8223435E-04,   4.8889127E-04
     +,   4.9662427E-04,   5.0573482E-04,   5.1656470E-04
     +,   5.2949670E-04,   5.4495549E-04,   5.6340691E-04
     +,   5.8535190E-04,   6.1132130E-04,   6.4186833E-04
     +,   6.7755580E-04,   7.1893528E-04,   7.6653558E-04
     +,   8.2083954E-04,   8.8225654E-04,   9.5110672E-04
     +,   1.0276019E-03,   1.1118304E-03,   1.2037348E-03
     +,   1.3031102E-03,   1.4096141E-03,   1.5227634E-03
     +,   1.6419577E-03,   1.7665231E-03,   1.8957886E-03
     +,   2.0291845E-03,   2.1663634E-03,   2.3074017E-03
     +,   2.4529691E-03,   2.6044974E-03,   2.7643186E-03
     +,   2.9356983E-03,   3.1227232E-03,   3.3300100E-03
     +,   3.5622881E-03,   3.8238731E-03,   4.1181631E-03
     +,   4.4473261E-03,   4.8124306E-03,   5.2140658E-03
     +,   5.6532505E-03,   6.1322586E-03,   6.6548707E-03
     +,   7.2254529E-03,   7.8468882E-03,   8.5181678E-03
     +,   9.2324885E-03,   9.9765668E-03,   1.0731449E-02
     +,   1.1474775E-02,   1.2183427E-02,   1.2836589E-02
     +,   1.3419011E-02,   1.3923881E-02,   1.4354249E-02
     +,   1.4721297E-02,   1.5039297E-02,   1.5318747E-02
     +,   1.5560227E-02,   1.5751792E-02,   1.5870616E-02
     +,   1.5887827E-02,   1.5774716E-02,   1.5508841E-02
     +,   1.5079477E-02,   1.4492019E-02,   1.3769815E-02
     +,   1.2952129E-02,   1.2087526E-02,   1.1224258E-02
     +,   1.0400928E-02,   9.6406750E-03,   8.9501562E-03
     +,   8.3233463E-03,   7.7476758E-03,   7.2098426E-03
     +,   6.6997213E-03,   6.2117903E-03,   5.7445448E-03
     +,   5.2987668E-03,   4.8757927E-03,   4.4764564E-03
     +,   4.1007590E-03,   3.7480900E-03,   3.4176826E-03
     +,   3.1090514E-03,   2.8222143E-03,   2.5575405E-03
     +,   2.3155182E-03,   2.0964323E-03,   1.9000475E-03
     +,   1.7254344E-03,   1.5709753E-03,   1.4345018E-03
     +,   1.3135063E-03,   1.2053970E-03,   1.1077489E-03
     +,   1.0184860E-03,   9.3596603E-04,   8.5902301E-04
     +,   7.8690972E-04,   7.1923801E-04,   6.5585936E-04
     +,   5.9678510E-04,   5.4208288E-04,   4.9182621E-04
     +,   4.4603468E-04,   4.0466312E-04,   3.6758342E-04
     +,   3.3459501E-04,   3.0543964E-04,   2.7981124E-04
     +,   2.5738124E-04,   2.3780776E-04,   2.2075580E-04
     +,   2.0590250E-04,   1.9294949E-04,   1.8162366E-04
     +,   1.7168275E-04,   1.6291309E-04,   1.5513072E-04
     +,   1.4817757E-04,   1.4192055E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_hatt100 = Yx/0.146023255813954
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_hatt105(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0583674E-04,   2.1445552E-04
     +,   2.2330083E-04,   2.3236946E-04,   2.4165717E-04
     +,   2.5115930E-04,   2.6087015E-04,   2.7078349E-04
     +,   2.8089189E-04,   2.9118819E-04,   3.0166362E-04
     +,   3.1230904E-04,   3.2311474E-04,   3.3407004E-04
     +,   3.4516421E-04,   3.5638580E-04,   3.6772297E-04
     +,   3.7916310E-04,   3.9069363E-04,   4.0230167E-04
     +,   4.1397376E-04,   4.2569681E-04,   4.3745668E-04
     +,   4.4924041E-04,   4.6103343E-04,   4.7282263E-04
     +,   4.8459441E-04,   4.9633457E-04,   5.0803012E-04
     +,   5.1966711E-04,   5.3123262E-04,   5.4271310E-04
     +,   5.5409572E-04,   5.6536734E-04,   5.7651516E-04
     +,   5.8752683E-04,   5.9838954E-04,   6.0909108E-04
     +,   6.1961898E-04,   6.2996167E-04,   6.4010720E-04
     +,   6.5004360E-04,   6.5976003E-04,   6.6924456E-04
     +,   6.7848724E-04,   6.8747636E-04,   6.9620338E-04
     +,   7.0465700E-04,   7.1282889E-04,   7.2071102E-04
     +,   7.2829449E-04,   7.3557225E-04,   7.4253831E-04
     +,   7.4918737E-04,   7.5551349E-04,   7.6151424E-04
     +,   7.6718605E-04,   7.7252736E-04,   7.7753683E-04
     +,   7.8221550E-04,   7.8656350E-04,   7.9058338E-04
     +,   7.9427741E-04,   7.9764926E-04,   8.0070354E-04
     +,   8.0344419E-04,   8.0587674E-04,   8.0800679E-04
     +,   8.0983952E-04,   8.1138074E-04,   8.1263628E-04
     +,   8.1361103E-04,   8.1431028E-04,   8.1473828E-04
     +,   8.1489905E-04,   8.1479590E-04,   8.1443170E-04
     +,   8.1380800E-04,   8.1292668E-04,   8.1178767E-04
     +,   8.1039115E-04,   8.0873637E-04,   8.0682209E-04
     +,   8.0464745E-04,   8.0220937E-04,   7.9950714E-04
     +,   7.9653831E-04,   7.9330150E-04,   7.8979565E-04
     +,   7.8602036E-04,   7.8197505E-04,   7.7766168E-04
     +,   7.7308266E-04,   7.6824048E-04,   7.6313975E-04
     +,   7.5778738E-04,   7.5218943E-04,   7.4635650E-04
     +,   7.4029766E-04,   7.3402509E-04,   7.2755228E-04
     +,   7.2089321E-04,   7.1406347E-04,   7.0707989E-04
     +,   6.9996010E-04,   6.9272268E-04,   6.8538619E-04
     +,   6.7797012E-04,   6.7049445E-04,   6.6297816E-04
     +,   6.5544102E-04,   6.4790231E-04,   6.4038095E-04
     +,   6.3289423E-04,   6.2546006E-04,   6.1809516E-04
     +,   6.1081478E-04,   6.0363329E-04,   5.9656455E-04
     +,   5.8962085E-04,   5.8281311E-04,   5.7615177E-04
     +,   5.6964607E-04,   5.6330365E-04,   5.5713160E-04
     +,   5.5113633E-04,   5.4532220E-04,   5.3969433E-04
     +,   5.3425576E-04,   5.2900979E-04,   5.2395847E-04
     +,   5.1910372E-04,   5.1444682E-04,   5.0998869E-04
     +,   5.0572987E-04,   5.0167035E-04,   4.9781019E-04
     +,   4.9414940E-04,   4.9068715E-04,   4.8742283E-04
     +,   4.8435564E-04,   4.8148452E-04,   4.7880848E-04
     +,   4.7632601E-04,   4.7403626E-04,   4.7193727E-04
     +,   4.7002773E-04,   4.6830619E-04,   4.6677113E-04
     +,   4.6542109E-04,   4.6425444E-04,   4.6327023E-04
     +,   4.6246775E-04,   4.6184642E-04,   4.6140657E-04
     +,   4.6114874E-04,   4.6107493E-04,   4.6118803E-04
     +,   4.6149176E-04,   4.6199217E-04,   4.6269628E-04
     +,   4.6361444E-04,   4.6475782E-04,   4.6614220E-04
     +,   4.6778444E-04,   4.6970643E-04,   4.7193278E-04
     +,   4.7449247E-04,   4.7741857E-04,   4.8074895E-04
     +,   4.8452651E-04,   4.8879738E-04,   4.9361377E-04
     +,   4.9903308E-04,   5.0511491E-04,   5.1192468E-04
     +,   5.1953085E-04,   5.2800454E-04,   5.3741818E-04
     +,   5.4784562E-04,   5.5936124E-04,   5.7203561E-04
     +,   5.8593758E-04,   6.0113193E-04,   6.1767636E-04
     +,   6.3562137E-04,   6.5500784E-04,   6.7586731E-04
     +,   6.9822004E-04,   7.2207185E-04,   7.4741791E-04
     +,   7.7424000E-04,   8.0250495E-04,   8.3216629E-04
     +,   8.6316792E-04,   8.9544099E-04,   9.2890661E-04
     +,   9.6347590E-04,   9.9905755E-04,   1.0355528E-03
     +,   1.0728621E-03,   1.1108840E-03,   1.1495223E-03
     +,   1.1886857E-03,   1.2282890E-03,   1.2682595E-03
     +,   1.3085390E-03,   1.3490833E-03,   1.3898638E-03
     +,   1.4308781E-03,   1.4721423E-03,   1.5136937E-03
     +,   1.5555901E-03,   1.5979125E-03,   1.6407587E-03
     +,   1.6842405E-03,   1.7284759E-03,   1.7735956E-03
     +,   1.8197283E-03,   1.8670001E-03,   1.9155393E-03
     +,   1.9654699E-03,   2.0169260E-03,   2.0700446E-03
     +,   2.1249892E-03,   2.1819584E-03,   2.2411870E-03
     +,   2.3029605E-03,   2.3676176E-03,   2.4355392E-03
     +,   2.5071318E-03,   2.5827943E-03,   2.6629071E-03
     +,   2.7477655E-03,   2.8375629E-03,   2.9323574E-03
     +,   3.0320636E-03,   3.1364621E-03,   3.2452417E-03
     +,   3.3580658E-03,   3.4746705E-03,   3.5949186E-03
     +,   3.7189373E-03,   3.8471615E-03,   3.9804089E-03
     +,   4.1198400E-03,   4.2669298E-03,   4.4234041E-03
     +,   4.5910892E-03,   4.7717514E-03,   4.9670055E-03
     +,   5.1781721E-03,   5.4062107E-03,   5.6517539E-03
     +,   5.9152236E-03,   6.1970023E-03,   6.4976825E-03
     +,   6.8183015E-03,   7.1606240E-03,   7.5270850E-03
     +,   7.9206917E-03,   8.3445832E-03,   8.8014053E-03
     +,   9.2924023E-03,   9.8164976E-03,   1.0369541E-02
     +,   1.0943752E-02,   1.1527707E-02,   1.2106703E-02
     +,   1.2663754E-02,   1.3180914E-02,   1.3640602E-02
     +,   1.4027008E-02,   1.4327251E-02,   1.4531935E-02
     +,   1.4635362E-02,   1.4635311E-02,   1.4532407E-02
     +,   1.4329557E-02,   1.4031122E-02,   1.3642588E-02
     +,   1.3170131E-02,   1.2620705E-02,   1.2002098E-02
     +,   1.1323153E-02,   1.0594058E-02,   9.8262941E-03
     +,   9.0325493E-03,   8.2264617E-03,   7.4219275E-03
     +,   6.6326736E-03,   5.8713309E-03,   5.1490748E-03
     +,   4.4748713E-03,   3.8553921E-03,   3.2947056E-03
     +,   2.7945258E-03,   2.3543176E-03,   1.9717824E-03
     +,   1.6431705E-03,   1.3638311E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_hatt105 = Yx/0.164418604651163
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_hatt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2073140E-04,   1.2571245E-04
     +,   1.3082445E-04,   1.3607270E-04,   1.4146390E-04
     +,   1.4700653E-04,   1.5271090E-04,   1.5858964E-04
     +,   1.6465763E-04,   1.7093272E-04,   1.7743548E-04
     +,   1.8418959E-04,   1.9122205E-04,   1.9856339E-04
     +,   2.0624785E-04,   2.1431311E-04,   2.2280090E-04
     +,   2.3175646E-04,   2.4122898E-04,   2.5127060E-04
     +,   2.6193727E-04,   2.7328738E-04,   2.8538163E-04
     +,   2.9828321E-04,   3.1205497E-04,   3.2676113E-04
     +,   3.4246419E-04,   3.5922520E-04,   3.7710145E-04
     +,   3.9614600E-04,   4.1640678E-04,   4.3792513E-04
     +,   4.6073488E-04,   4.8486271E-04,   5.1032810E-04
     +,   5.3714280E-04,   5.6531373E-04,   5.9484306E-04
     +,   6.2573329E-04,   6.5798446E-04,   6.9160393E-04
     +,   7.2660402E-04,   7.6300657E-04,   8.0084498E-04
     +,   8.4016460E-04,   8.8102266E-04,   9.2348730E-04
     +,   9.6763129E-04,   1.0135318E-03,   1.0612597E-03
     +,   1.1108759E-03,   1.1624218E-03,   1.2159133E-03
     +,   1.2713366E-03,   1.3286398E-03,   1.3877387E-03
     +,   1.4485135E-03,   1.5108193E-03,   1.5744930E-03
     +,   1.6393738E-03,   1.7053140E-03,   1.7722087E-03
     +,   1.8400042E-03,   1.9087325E-03,   1.9785254E-03
     +,   2.0496119E-03,   2.1223426E-03,   2.1971613E-03
     +,   2.2746020E-03,   2.3552345E-03,   2.4396353E-03
     +,   2.5283142E-03,   2.6216663E-03,   2.7198885E-03
     +,   2.8229319E-03,   2.9304519E-03,   3.0417768E-03
     +,   3.1559004E-03,   3.2715120E-03,   3.3870351E-03
     +,   3.5006881E-03,   3.6105860E-03,   3.7148122E-03
     +,   3.8115319E-03,   3.8990451E-03,   3.9758892E-03
     +,   4.0408508E-03,   4.0930272E-03,   4.1318042E-03
     +,   4.1568722E-03,   4.1681742E-03,   4.1659172E-03
     +,   4.1505070E-03,   4.1225366E-03,   4.0827449E-03
     +,   4.0319986E-03,   3.9712423E-03,   3.9014963E-03
     +,   3.8237870E-03,   3.7391493E-03,   3.6485738E-03
     +,   3.5530026E-03,   3.4532759E-03,   3.3501680E-03
     +,   3.2443576E-03,   3.1364611E-03,   3.0270515E-03
     +,   2.9166990E-03,   2.8059776E-03,   2.6955064E-03
     +,   2.5859734E-03,   2.4781153E-03,   2.3727308E-03
     +,   2.2706373E-03,   2.1726592E-03,   2.0795621E-03
     +,   1.9920385E-03,   1.9106454E-03,   1.8357886E-03
     +,   1.7676870E-03,   1.7063679E-03,   1.6516711E-03
     +,   1.6032577E-03,   1.5606293E-03,   1.5231629E-03
     +,   1.4901501E-03,   1.4608266E-03,   1.4344191E-03
     +,   1.4101743E-03,   1.3873944E-03,   1.3654553E-03
     +,   1.3438346E-03,   1.3221083E-03,   1.2999680E-03
     +,   1.2772088E-03,   1.2537196E-03,   1.2294806E-03
     +,   1.2045365E-03,   1.1789838E-03,   1.1529537E-03
     +,   1.1265976E-03,   1.1000724E-03,   1.0735240E-03
     +,   1.0470854E-03,   1.0208702E-03,   9.9496346E-04
     +,   9.6942642E-04,   9.4429788E-04,   9.1959565E-04
     +,   8.9531753E-04,   8.7144919E-04,   8.4796926E-04
     +,   8.2485174E-04,   8.0206804E-04,   7.7959226E-04
     +,   7.5740466E-04,   7.3549279E-04,   7.1385055E-04
     +,   6.9248024E-04,   6.7139452E-04,   6.5061310E-04
     +,   6.3016190E-04,   6.1007496E-04,   5.9039163E-04
     +,   5.7115365E-04,   5.5240572E-04,   5.3419516E-04
     +,   5.1656901E-04,   4.9957330E-04,   4.8325135E-04
     +,   4.6764521E-04,   4.5279361E-04,   4.3873081E-04
     +,   4.2548595E-04,   4.1308522E-04,   4.0154962E-04
     +,   3.9089372E-04,   3.8112956E-04,   3.7226325E-04
     +,   3.6429646E-04,   3.5722638E-04,   3.5104656E-04
     +,   3.4574672E-04,   3.4131296E-04,   3.3772824E-04
     +,   3.3497284E-04,   3.3302486E-04,   3.3185954E-04
     +,   3.3145075E-04,   3.3177063E-04,   3.3279034E-04
     +,   3.3447958E-04,   3.3680760E-04,   3.3974284E-04
     +,   3.4325384E-04,   3.4730896E-04,   3.5187678E-04
     +,   3.5692588E-04,   3.6242587E-04,   3.6834748E-04
     +,   3.7466153E-04,   3.8134051E-04,   3.8835793E-04
     +,   3.9568939E-04,   4.0331078E-04,   4.1120042E-04
     +,   4.1933800E-04,   4.2770462E-04,   4.3628243E-04
     +,   4.4505578E-04,   4.5401003E-04,   4.6313123E-04
     +,   4.7240595E-04,   4.8182264E-04,   4.9136922E-04
     +,   5.0103280E-04,   5.1080063E-04,   5.2065949E-04
     +,   5.3059473E-04,   5.4058951E-04,   5.5062590E-04
     +,   5.6068314E-04,   5.7073735E-04,   5.8076251E-04
     +,   5.9072871E-04,   6.0060428E-04,   6.1035180E-04
     +,   6.1993173E-04,   6.2930235E-04,   6.3841714E-04
     +,   6.4722821E-04,   6.5568381E-04,   6.6373183E-04
     +,   6.7131873E-04,   6.7838939E-04,   6.8488956E-04
     +,   6.9076603E-04,   6.9596671E-04,   7.0044206E-04
     +,   7.0414628E-04,   7.0703716E-04,   7.0907798E-04
     +,   7.1023678E-04,   7.1048812E-04,   7.0981344E-04
     +,   7.0820109E-04,   7.0564693E-04,   7.0215366E-04
     +,   6.9773290E-04,   6.9240312E-04,   6.8619027E-04
     +,   6.7912636E-04,   6.7125174E-04,   6.6261145E-04
     +,   6.5325608E-04,   6.4324052E-04,   6.3262408E-04
     +,   6.2146905E-04,   6.0983957E-04,   5.9780019E-04
     +,   5.8541656E-04,   5.7275448E-04,   5.5987766E-04
     +,   5.4684730E-04,   5.3372310E-04,   5.2056130E-04
     +,   5.0741294E-04,   4.9432693E-04,   4.8134718E-04
     +,   4.6851233E-04,   4.5585583E-04,   4.4340789E-04
     +,   4.3119301E-04,   4.1923081E-04,   4.0753651E-04
     +,   3.9612179E-04,   3.8499350E-04,   3.7415588E-04
     +,   3.6360876E-04,   3.5335036E-04,   3.4337514E-04
     +,   3.3367684E-04,   3.2424612E-04,   3.1507376E-04
     +,   3.0614817E-04,   2.9745843E-04,   2.8899207E-04
     +,   2.8073706E-04,   2.7268205E-04,   2.6481500E-04
     +,   2.5712547E-04,   2.4960274E-04,   2.4223774E-04
     +,   2.3502152E-04,   2.2794677E-04,   2.2100635E-04
     +,   2.1419482E-04,   2.0750702E-04,   2.0093929E-04
     +,   1.9448828E-04,   1.8815203E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_hatt75 = Yx/0.0781052631578947
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_hatt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0600548E-04,   1.0997953E-04
     +,   1.1413943E-04,   1.1849945E-04,   1.2307450E-04
     +,   1.2787998E-04,   1.3293186E-04,   1.3824650E-04
     +,   1.4384031E-04,   1.4973033E-04,   1.5593301E-04
     +,   1.6246497E-04,   1.6934238E-04,   1.7658081E-04
     +,   1.8419516E-04,   1.9219935E-04,   2.0060629E-04
     +,   2.0942719E-04,   2.1867205E-04,   2.2834878E-04
     +,   2.3846346E-04,   2.4902017E-04,   2.6002017E-04
     +,   2.7146310E-04,   2.8334503E-04,   2.9566049E-04
     +,   3.0840130E-04,   3.2155641E-04,   3.3511315E-04
     +,   3.4905644E-04,   3.6336979E-04,   3.7803518E-04
     +,   3.9303378E-04,   4.0834642E-04,   4.2395404E-04
     +,   4.3983795E-04,   4.5598092E-04,   4.7236678E-04
     +,   4.8898265E-04,   5.0581613E-04,   5.2285969E-04
     +,   5.4010696E-04,   5.5755523E-04,   5.7520368E-04
     +,   5.9305481E-04,   6.1111228E-04,   6.2938168E-04
     +,   6.4786832E-04,   6.6657824E-04,   6.8551535E-04
     +,   7.0468133E-04,   7.2407554E-04,   7.4369198E-04
     +,   7.6352287E-04,   7.8355306E-04,   8.0376648E-04
     +,   8.2414440E-04,   8.4467093E-04,   8.6533569E-04
     +,   8.8614126E-04,   9.0711151E-04,   9.2830101E-04
     +,   9.4980287E-04,   9.7176555E-04,   9.9439733E-04
     +,   1.0179732E-03,   1.0428422E-03,   1.0694205E-03
     +,   1.0981850E-03,   1.1296512E-03,   1.1643540E-03
     +,   1.2028045E-03,   1.2454671E-03,   1.2927055E-03
     +,   1.3447651E-03,   1.4017406E-03,   1.4635689E-03
     +,   1.5300391E-03,   1.6008357E-03,   1.6755913E-03
     +,   1.7539490E-03,   1.8356740E-03,   1.9207038E-03
     +,   2.0092530E-03,   2.1018172E-03,   2.1991988E-03
     +,   2.3024266E-03,   2.4126801E-03,   2.5311201E-03
     +,   2.6587455E-03,   2.7962234E-03,   2.9437586E-03
     +,   3.1010353E-03,   3.2672256E-03,   3.4410749E-03
     +,   3.6210259E-03,   3.8054176E-03,   3.9926306E-03
     +,   4.1812253E-03,   4.3699900E-03,   4.5579569E-03
     +,   4.7442983E-03,   4.9282894E-03,   5.1091760E-03
     +,   5.2861720E-03,   5.4583997E-03,   5.6249034E-03
     +,   5.7846652E-03,   5.9365625E-03,   6.0792686E-03
     +,   6.2111183E-03,   6.3299877E-03,   6.4331186E-03
     +,   6.5171323E-03,   6.5781050E-03,   6.6118166E-03
     +,   6.6141533E-03,   6.5815658E-03,   6.5115895E-03
     +,   6.4032190E-03,   6.2572123E-03,   6.0761604E-03
     +,   5.8643348E-03,   5.6273229E-03,   5.3715301E-03
     +,   5.1036594E-03,   4.8300941E-03,   4.5565232E-03
     +,   4.2875628E-03,   4.0266975E-03,   3.7762402E-03
     +,   3.5375822E-03,   3.3113242E-03,   3.0976336E-03
     +,   2.8963962E-03,   2.7074264E-03,   2.5305608E-03
     +,   2.3656837E-03,   2.2126888E-03,   2.0714574E-03
     +,   1.9418023E-03,   1.8234371E-03,   1.7159368E-03
     +,   1.6187632E-03,   1.5312973E-03,   1.4528522E-03
     +,   1.3827103E-03,   1.3201687E-03,   1.2645434E-03
     +,   1.2151782E-03,   1.1714561E-03,   1.1327915E-03
     +,   1.0986279E-03,   1.0684258E-03,   1.0416672E-03
     +,   1.0178529E-03,   9.9650736E-04,   9.7718136E-04
     +,   9.5946016E-04,   9.4297103E-04,   9.2738745E-04
     +,   9.1243081E-04,   8.9787849E-04,   8.8355673E-04
     +,   8.6934032E-04,   8.5514924E-04,   8.4094348E-04
     +,   8.2671503E-04,   8.1248244E-04,   7.9828402E-04
     +,   7.8417320E-04,   7.7021192E-04,   7.5646519E-04
     +,   7.4299896E-04,   7.2987785E-04,   7.1715983E-04
     +,   7.0489838E-04,   6.9314003E-04,   6.8192562E-04
     +,   6.7128724E-04,   6.6125160E-04,   6.5184000E-04
     +,   6.4306951E-04,   6.3495175E-04,   6.2749593E-04
     +,   6.2070915E-04,   6.1459636E-04,   6.0916098E-04
     +,   6.0440559E-04,   6.0033257E-04,   5.9694296E-04
     +,   5.9423823E-04,   5.9221883E-04,   5.9088418E-04
     +,   5.9023267E-04,   5.9026037E-04,   5.9096143E-04
     +,   5.9232721E-04,   5.9434539E-04,   5.9700006E-04
     +,   6.0026994E-04,   6.0412905E-04,   6.0854614E-04
     +,   6.1348418E-04,   6.1889924E-04,   6.2474259E-04
     +,   6.3095812E-04,   6.3748535E-04,   6.4425741E-04
     +,   6.5120228E-04,   6.5824518E-04,   6.6530658E-04
     +,   6.7230483E-04,   6.7915756E-04,   6.8578182E-04
     +,   6.9209503E-04,   6.9801777E-04,   7.0347328E-04
     +,   7.0839055E-04,   7.1270234E-04,   7.1634981E-04
     +,   7.1928144E-04,   7.2145392E-04,   7.2283309E-04
     +,   7.2339439E-04,   7.2312308E-04,   7.2201458E-04
     +,   7.2007300E-04,   7.1731361E-04,   7.1375910E-04
     +,   7.0944126E-04,   7.0439978E-04,   6.9868017E-04
     +,   6.9233385E-04,   6.8541738E-04,   6.7799015E-04
     +,   6.7011424E-04,   6.6185300E-04,   6.5327022E-04
     +,   6.4442819E-04,   6.3538755E-04,   6.2620617E-04
     +,   6.1693887E-04,   6.0763618E-04,   5.9834355E-04
     +,   5.8910134E-04,   5.7994568E-04,   5.7090563E-04
     +,   5.6200469E-04,   5.5326242E-04,   5.4469076E-04
     +,   5.3629751E-04,   5.2808516E-04,   5.2005227E-04
     +,   5.1219226E-04,   5.0449488E-04,   4.9694726E-04
     +,   4.8953335E-04,   4.8223458E-04,   4.7503080E-04
     +,   4.6790048E-04,   4.6082205E-04,   4.5377295E-04
     +,   4.4673032E-04,   4.3967325E-04,   4.3258071E-04
     +,   4.2543307E-04,   4.1821291E-04,   4.1090432E-04
     +,   4.0349335E-04,   3.9596847E-04,   3.8832086E-04
     +,   3.8054408E-04,   3.7263407E-04,   3.6458901E-04
     +,   3.5641054E-04,   3.4810189E-04,   3.3966935E-04
     +,   3.3112071E-04,   3.2246651E-04,   3.1371872E-04
     +,   3.0489135E-04,   2.9599899E-04,   2.8705891E-04
     +,   2.7808774E-04,   2.6910435E-04,   2.6012686E-04
     +,   2.5117412E-04,   2.4226541E-04,   2.3341892E-04
     +,   2.2465362E-04,   2.1598654E-04,   2.0743538E-04
     +,   1.9901560E-04,   1.9074285E-04,   1.8263041E-04
     +,   1.7469173E-04,   1.6693764E-04,   1.5937882E-04
     +,   1.5202357E-04,   1.4487987E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_hatt80 = Yx/0.0966
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_hatt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.4834108E-05,   6.6582768E-05
     +,   6.8353613E-05,   7.0147711E-05,   7.1966453E-05
     +,   7.3811418E-05,   7.5684482E-05,   7.7587814E-05
     +,   7.9523816E-05,   8.1495338E-05,   8.3505431E-05
     +,   8.5557498E-05,   8.7655309E-05,   8.9802939E-05
     +,   9.2004797E-05,   9.4265662E-05,   9.6590629E-05
     +,   9.8985074E-05,   1.0145475E-04,   1.0400567E-04
     +,   1.0664411E-04,   1.0937660E-04,   1.1220991E-04
     +,   1.1515113E-04,   1.1820723E-04,   1.2138567E-04
     +,   1.2469380E-04,   1.2813919E-04,   1.3172945E-04
     +,   1.3547226E-04,   1.3937535E-04,   1.4344649E-04
     +,   1.4769353E-04,   1.5212450E-04,   1.5674729E-04
     +,   1.6157026E-04,   1.6660184E-04,   1.7185071E-04
     +,   1.7732620E-04,   1.8303777E-04,   1.8899582E-04
     +,   1.9521145E-04,   2.0169657E-04,   2.0846406E-04
     +,   2.1552810E-04,   2.2290405E-04,   2.3060867E-04
     +,   2.3866004E-04,   2.4707799E-04,   2.5588323E-04
     +,   2.6509826E-04,   2.7474630E-04,   2.8485138E-04
     +,   2.9543828E-04,   3.0653100E-04,   3.1815315E-04
     +,   3.3032655E-04,   3.4307066E-04,   3.5640155E-04
     +,   3.7033114E-04,   3.8486606E-04,   4.0000686E-04
     +,   4.1574723E-04,   4.3207506E-04,   4.4897170E-04
     +,   4.6641147E-04,   4.8436638E-04,   5.0280499E-04
     +,   5.2169937E-04,   5.4102449E-04,   5.6076865E-04
     +,   5.8093359E-04,   6.0154544E-04,   6.2265527E-04
     +,   6.4435112E-04,   6.6675630E-04,   6.9003465E-04
     +,   7.1438885E-04,   7.4006035E-04,   7.6731940E-04
     +,   7.9645141E-04,   8.2774798E-04,   8.6147856E-04
     +,   8.9787797E-04,   9.3711377E-04,   9.7927463E-04
     +,   1.0243431E-03,   1.0721983E-03,   1.1226072E-03
     +,   1.1752481E-03,   1.2297437E-03,   1.2856972E-03
     +,   1.3427603E-03,   1.4007009E-03,   1.4594694E-03
     +,   1.5192501E-03,   1.5805203E-03,   1.6440547E-03
     +,   1.7109244E-03,   1.7824445E-03,   1.8601096E-03
     +,   1.9454899E-03,   2.0401380E-03,   2.1454697E-03
     +,   2.2626924E-03,   2.3927405E-03,   2.5362205E-03
     +,   2.6933961E-03,   2.8641992E-03,   3.0481820E-03
     +,   3.2444671E-03,   3.4517511E-03,   3.6682361E-03
     +,   3.8917433E-03,   4.1198484E-03,   4.3502776E-03
     +,   4.5812894E-03,   4.8121540E-03,   5.0433590E-03
     +,   5.2764909E-03,   5.5136234E-03,   5.7562725E-03
     +,   6.0042194E-03,   6.2545934E-03,   6.5015885E-03
     +,   6.7371437E-03,   6.9526555E-03,   7.1411515E-03
     +,   7.2995289E-03,   7.4298428E-03,   7.5392486E-03
     +,   7.6383166E-03,   7.7381656E-03,   7.8470493E-03
     +,   7.9675773E-03,   8.0953715E-03,   8.2195112E-03
     +,   8.3248084E-03,   8.3950032E-03,   8.4159812E-03
     +,   8.3781136E-03,   8.2772784E-03,   8.1145279E-03
     +,   7.8950087E-03,   7.6265605E-03,   7.3185074E-03
     +,   6.9808303E-03,   6.6236439E-03,   6.2566660E-03
     +,   5.8886446E-03,   5.5268132E-03,   5.1764068E-03
     +,   4.8404243E-03,   4.5198305E-03,   4.2140898E-03
     +,   3.9219912E-03,   3.6424161E-03,   3.3749042E-03
     +,   3.1199493E-03,   2.8789632E-03,   2.6538479E-03
     +,   2.4465621E-03,   2.2586461E-03,   2.0908616E-03
     +,   1.9430402E-03,   1.8141341E-03,   1.7024302E-03
     +,   1.6058087E-03,   1.5220265E-03,   1.4489557E-03
     +,   1.3847499E-03,   1.3279063E-03,   1.2772710E-03
     +,   1.2319945E-03,   1.1914701E-03,   1.1552506E-03
     +,   1.1229878E-03,   1.0943888E-03,   1.0691762E-03
     +,   1.0470700E-03,   1.0277842E-03,   1.0110242E-03
     +,   9.9648559E-04,   9.8386197E-04,   9.7284821E-04
     +,   9.6314424E-04,   9.5446344E-04,   9.4653375E-04
     +,   9.3910017E-04,   9.3193428E-04,   9.2483428E-04
     +,   9.1762812E-04,   9.1017497E-04,   9.0236927E-04
     +,   8.9413859E-04,   8.8544429E-04,   8.7627891E-04
     +,   8.6666527E-04,   8.5665210E-04,   8.4631040E-04
     +,   8.3573017E-04,   8.2501653E-04,   8.1428327E-04
     +,   8.0364931E-04,   7.9323654E-04,   7.8316242E-04
     +,   7.7353767E-04,   7.6446496E-04,   7.5603335E-04
     +,   7.4831670E-04,   7.4137386E-04,   7.3524512E-04
     +,   7.2995340E-04,   7.2550395E-04,   7.2188291E-04
     +,   7.1906060E-04,   7.1699219E-04,   7.1561709E-04
     +,   7.1486336E-04,   7.1464869E-04,   7.1488129E-04
     +,   7.1546406E-04,   7.1629521E-04,   7.1727106E-04
     +,   7.1828783E-04,   7.1924372E-04,   7.2004058E-04
     +,   7.2058593E-04,   7.2079437E-04,   7.2058866E-04
     +,   7.1990164E-04,   7.1867573E-04,   7.1686413E-04
     +,   7.1443239E-04,   7.1135612E-04,   7.0762297E-04
     +,   7.0323085E-04,   6.9818809E-04,   6.9251284E-04
     +,   6.8623037E-04,   6.7937357E-04,   6.7198084E-04
     +,   6.6409563E-04,   6.5576332E-04,   6.4703060E-04
     +,   6.3794496E-04,   6.2855356E-04,   6.1889924E-04
     +,   6.0902245E-04,   5.9896021E-04,   5.8874342E-04
     +,   5.7839922E-04,   5.6794885E-04,   5.5740867E-04
     +,   5.4678955E-04,   5.3609774E-04,   5.2533584E-04
     +,   5.1450345E-04,   5.0359644E-04,   4.9260905E-04
     +,   4.8153536E-04,   4.7036927E-04,   4.5910431E-04
     +,   4.4773557E-04,   4.3626153E-04,   4.2468152E-04
     +,   4.1299823E-04,   4.0121833E-04,   3.8935163E-04
     +,   3.7741094E-04,   3.6541239E-04,   3.5337560E-04
     +,   3.4132373E-04,   3.2928117E-04,   3.1727448E-04
     +,   3.0533300E-04,   2.9348535E-04,   2.8176230E-04
     +,   2.7019301E-04,   2.5880759E-04,   2.4763352E-04
     +,   2.3669815E-04,   2.2602569E-04,   2.1563939E-04
     +,   2.0555859E-04,   1.9580123E-04,   1.8638156E-04
     +,   1.7731075E-04,   1.6859792E-04,   1.6024819E-04
     +,   1.5226506E-04,   1.4464802E-04,   1.3739534E-04
     +,   1.3050190E-04,   1.2396136E-04,   1.1776476E-04
     +,   1.1190242E-04,   1.0636239E-04,   1.0113255E-04
     +,   9.6199139E-05,   9.1548514E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_hatt85 = Yx/0.111487804878049
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_hatt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.1972932E-05,   8.3727398E-05
     +,   8.5462052E-05,   8.7175467E-05,   8.8866247E-05
     +,   9.0533184E-05,   9.2175156E-05,   9.3791277E-05
     +,   9.5380659E-05,   9.6942764E-05,   9.8476958E-05
     +,   9.9982928E-05,   1.0146043E-04,   1.0290938E-04
     +,   1.0432984E-04,   1.0572193E-04,   1.0708599E-04
     +,   1.0842241E-04,   1.0973166E-04,   1.1101438E-04
     +,   1.1227122E-04,   1.1350296E-04,   1.1471040E-04
     +,   1.1589439E-04,   1.1705584E-04,   1.1819562E-04
     +,   1.1931469E-04,   1.2041388E-04,   1.2149414E-04
     +,   1.2255627E-04,   1.2360109E-04,   1.2462934E-04
     +,   1.2564173E-04,   1.2663890E-04,   1.2762140E-04
     +,   1.2858966E-04,   1.2954415E-04,   1.3048520E-04
     +,   1.3141314E-04,   1.3232822E-04,   1.3323070E-04
     +,   1.3412080E-04,   1.3499885E-04,   1.3586516E-04
     +,   1.3672023E-04,   1.3756470E-04,   1.3839939E-04
     +,   1.3922546E-04,   1.4004433E-04,   1.4085800E-04
     +,   1.4166880E-04,   1.4247978E-04,   1.4329464E-04
     +,   1.4411792E-04,   1.4495495E-04,   1.4581221E-04
     +,   1.4669717E-04,   1.4761863E-04,   1.4858658E-04
     +,   1.4961253E-04,   1.5070941E-04,   1.5189181E-04
     +,   1.5317577E-04,   1.5457913E-04,   1.5612137E-04
     +,   1.5782358E-04,   1.5970839E-04,   1.6179985E-04
     +,   1.6412360E-04,   1.6670616E-04,   1.6957537E-04
     +,   1.7275954E-04,   1.7628756E-04,   1.8018830E-04
     +,   1.8449053E-04,   1.8922279E-04,   1.9441197E-04
     +,   2.0008396E-04,   2.0626318E-04,   2.1297217E-04
     +,   2.2023053E-04,   2.2805625E-04,   2.3646391E-04
     +,   2.4546625E-04,   2.5507205E-04,   2.6528895E-04
     +,   2.7612053E-04,   2.8756965E-04,   2.9963543E-04
     +,   3.1231623E-04,   3.2560929E-04,   3.3950913E-04
     +,   3.5400956E-04,   3.6910403E-04,   3.8478570E-04
     +,   4.0104552E-04,   4.1787626E-04,   4.3526926E-04
     +,   4.5321899E-04,   4.7171969E-04,   4.9077231E-04
     +,   5.1038078E-04,   5.3055980E-04,   5.5133313E-04
     +,   5.7273981E-04,   5.9483619E-04,   6.1769626E-04
     +,   6.4141426E-04,   6.6610449E-04,   6.9189916E-04
     +,   7.1893842E-04,   7.4736873E-04,   7.7732524E-04
     +,   8.0892583E-04,   8.4225013E-04,   8.7733229E-04
     +,   9.1414386E-04,   9.5259171E-04,   9.9251233E-04
     +,   1.0336834E-03,   1.0758417E-03,   1.1187103E-03
     +,   1.1620447E-03,   1.2056942E-03,   1.2496694E-03
     +,   1.2942131E-03,   1.3398987E-03,   1.3876855E-03
     +,   1.4389900E-03,   1.4956933E-03,   1.5601359E-03
     +,   1.6350260E-03,   1.7233334E-03,   1.8280974E-03
     +,   1.9522527E-03,   2.0984304E-03,   2.2687824E-03
     +,   2.4648956E-03,   2.6877886E-03,   2.9380096E-03
     +,   3.2158075E-03,   3.5214096E-03,   3.8553062E-03
     +,   4.2184344E-03,   4.6121706E-03,   5.0381906E-03
     +,   5.4979911E-03,   5.9921555E-03,   6.5195062E-03
     +,   7.0761638E-03,   7.6545677E-03,   8.2426323E-03
     +,   8.8234665E-03,   9.3758237E-03,   9.8756580E-03
     +,   1.0298880E-02,   1.0625061E-02,   1.0841114E-02
     +,   1.0943789E-02,   1.0939970E-02,   1.0844678E-02
     +,   1.0676953E-02,   1.0455161E-02,   1.0193186E-02
     +,   9.8985061E-03,   9.5728114E-03,   9.2144916E-03
     +,   8.8217715E-03,   8.3956374E-03,   7.9414686E-03
     +,   7.4690999E-03,   6.9915815E-03,   6.5232380E-03
     +,   6.0776435E-03,   5.6660976E-03,   5.2964971E-03
     +,   4.9730060E-03,   4.6961419E-03,   4.4631623E-03
     +,   4.2687543E-03,   4.1058869E-03,   3.9667687E-03
     +,   3.8437909E-03,   3.7303809E-03,   3.6216273E-03
     +,   3.5145800E-03,   3.4082083E-03,   3.3029648E-03
     +,   3.2002146E-03,   3.1015296E-03,   3.0080921E-03
     +,   2.9202809E-03,   2.8375599E-03,   2.7585914E-03
     +,   2.6815441E-03,   2.6045048E-03,   2.5258751E-03
     +,   2.4446431E-03,   2.3605237E-03,   2.2739505E-03
     +,   2.1859366E-03,   2.0978532E-03,   2.0111802E-03
     +,   1.9272852E-03,   1.8472649E-03,   1.7718266E-03
     +,   1.7012741E-03,   1.6355352E-03,   1.5742364E-03
     +,   1.5167923E-03,   1.4625101E-03,   1.4106859E-03
     +,   1.3606729E-03,   1.3119286E-03,   1.2640489E-03
     +,   1.2167776E-03,   1.1699982E-03,   1.1237108E-03
     +,   1.0780119E-03,   1.0330696E-03,   9.8909019E-04
     +,   9.4629510E-04,   9.0490544E-04,   8.6512323E-04
     +,   8.2711549E-04,   7.9101353E-04,   7.5691228E-04
     +,   7.2486652E-04,   6.9489377E-04,   6.6698098E-04
     +,   6.4109109E-04,   6.1716582E-04,   5.9513218E-04
     +,   5.7490461E-04,   5.5639603E-04,   5.3951243E-04
     +,   5.2415987E-04,   5.1024620E-04,   4.9768097E-04
     +,   4.8637576E-04,   4.7624507E-04,   4.6720737E-04
     +,   4.5918371E-04,   4.5209823E-04,   4.4587805E-04
     +,   4.4045379E-04,   4.3575870E-04,   4.3172939E-04
     +,   4.2830463E-04,   4.2542678E-04,   4.2304047E-04
     +,   4.2109250E-04,   4.1953209E-04,   4.1831034E-04
     +,   4.1738001E-04,   4.1669482E-04,   4.1621004E-04
     +,   4.1588146E-04,   4.1566550E-04,   4.1551946E-04
     +,   4.1540051E-04,   4.1526713E-04,   4.1507781E-04
     +,   4.1479192E-04,   4.1436983E-04,   4.1377338E-04
     +,   4.1296534E-04,   4.1191097E-04,   4.1057743E-04
     +,   4.0893460E-04,   4.0695479E-04,   4.0461408E-04
     +,   4.0189177E-04,   3.9877079E-04,   3.9523779E-04
     +,   3.9128395E-04,   3.8690402E-04,   3.8209723E-04
     +,   3.7686675E-04,   3.7121965E-04,   3.6516695E-04
     +,   3.5872334E-04,   3.5190646E-04,   3.4473781E-04
     +,   3.3724110E-04,   3.2944264E-04,   3.2137099E-04
     +,   3.1305567E-04,   3.0452863E-04,   2.9582175E-04
     +,   2.8696840E-04,   2.7800104E-04,   2.6895315E-04
     +,   2.5985666E-04,   2.5074379E-04,   2.4164465E-04
     +,   2.3258921E-04,   2.2360476E-04,   2.1471817E-04
     +,   2.0595326E-04,   1.9733321E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_hatt90 = Yx/0.116951219512195
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_hatt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.7261717E-05,   7.1222094E-05
     +,   7.5340635E-05,   7.9614714E-05,   8.4040621E-05
     +,   8.8613546E-05,   9.3327551E-05,   9.8175413E-05
     +,   1.0314871E-04,   1.0823801E-04,   1.1343244E-04
     +,   1.1871996E-04,   1.2408747E-04,   1.2952067E-04
     +,   1.3500423E-04,   1.4052192E-04,   1.4605657E-04
     +,   1.5159024E-04,   1.5710440E-04,   1.6257992E-04
     +,   1.6799742E-04,   1.7333729E-04,   1.7857966E-04
     +,   1.8370530E-04,   1.8869457E-04,   1.9352887E-04
     +,   1.9819009E-04,   2.0266071E-04,   2.0692442E-04
     +,   2.1096598E-04,   2.1477140E-04,   2.1832802E-04
     +,   2.2162484E-04,   2.2465234E-04,   2.2740279E-04
     +,   2.2987009E-04,   2.3205004E-04,   2.3394018E-04
     +,   2.3553993E-04,   2.3685038E-04,   2.3787432E-04
     +,   2.3861641E-04,   2.3908271E-04,   2.3928068E-04
     +,   2.3921933E-04,   2.3890875E-04,   2.3836014E-04
     +,   2.3758563E-04,   2.3659813E-04,   2.3541105E-04
     +,   2.3403837E-04,   2.3249425E-04,   2.3079298E-04
     +,   2.2894883E-04,   2.2697593E-04,   2.2488800E-04
     +,   2.2269845E-04,   2.2042003E-04,   2.1806506E-04
     +,   2.1564505E-04,   2.1317069E-04,   2.1065206E-04
     +,   2.0809840E-04,   2.0551810E-04,   2.0291872E-04
     +,   2.0030711E-04,   1.9768950E-04,   1.9507123E-04
     +,   1.9245723E-04,   1.8985195E-04,   1.8725902E-04
     +,   1.8468231E-04,   1.8212483E-04,   1.7958983E-04
     +,   1.7708031E-04,   1.7459922E-04,   1.7214971E-04
     +,   1.6973530E-04,   1.6735951E-04,   1.6502623E-04
     +,   1.6273995E-04,   1.6050550E-04,   1.5832834E-04
     +,   1.5621439E-04,   1.5417031E-04,   1.5220339E-04
     +,   1.5032155E-04,   1.4853333E-04,   1.4684819E-04
     +,   1.4527616E-04,   1.4382787E-04,   1.4251494E-04
     +,   1.4134945E-04,   1.4034427E-04,   1.3951297E-04
     +,   1.3886973E-04,   1.3842955E-04,   1.3820804E-04
     +,   1.3822144E-04,   1.3848671E-04,   1.3902158E-04
     +,   1.3984427E-04,   1.4097408E-04,   1.4243070E-04
     +,   1.4423476E-04,   1.4640774E-04,   1.4897174E-04
     +,   1.5194979E-04,   1.5536573E-04,   1.5924455E-04
     +,   1.6361149E-04,   1.6849315E-04,   1.7391628E-04
     +,   1.7990866E-04,   1.8649788E-04,   1.9371237E-04
     +,   2.0157926E-04,   2.1012613E-04,   2.1937811E-04
     +,   2.2935933E-04,   2.4009105E-04,   2.5159045E-04
     +,   2.6387002E-04,   2.7693709E-04,   2.9079220E-04
     +,   3.0542639E-04,   3.2082316E-04,   3.3695324E-04
     +,   3.5377787E-04,   3.7124322E-04,   3.8928402E-04
     +,   4.0781914E-04,   4.2675511E-04,   4.4598247E-04
     +,   4.6538064E-04,   4.8481673E-04,   5.0414732E-04
     +,   5.2322110E-04,   5.4188370E-04,   5.5998011E-04
     +,   5.7735719E-04,   5.9387088E-04,   6.0939009E-04
     +,   6.2380359E-04,   6.3702179E-04,   6.4898690E-04
     +,   6.5967557E-04,   6.6910282E-04,   6.7732832E-04
     +,   6.8445946E-04,   6.9065089E-04,   6.9610757E-04
     +,   7.0108200E-04,   7.0587225E-04,   7.1081764E-04
     +,   7.1629172E-04,   7.2269543E-04,   7.3045032E-04
     +,   7.3998980E-04,   7.5175462E-04,   7.6618948E-04
     +,   7.8374572E-04,   8.0488494E-04,   8.3009328E-04
     +,   8.5989945E-04,   8.9489570E-04,   9.3575451E-04
     +,   9.8324672E-04,   1.0382519E-03,   1.1017473E-03
     +,   1.1747761E-03,   1.2584063E-03,   1.3536799E-03
     +,   1.4615563E-03,   1.5828781E-03,   1.7184309E-03
     +,   1.8690695E-03,   2.0359477E-03,   2.2208707E-03
     +,   2.4266769E-03,   2.6575369E-03,   2.9190748E-03
     +,   3.2182473E-03,   3.5629815E-03,   3.9615282E-03
     +,   4.4216844E-03,   4.9500065E-03,   5.5511631E-03
     +,   6.2273610E-03,   6.9778576E-03,   7.7985604E-03
     +,   8.6808475E-03,   9.6095307E-03,   1.0560336E-02
     +,   1.1498289E-02,   1.2378897E-02,   1.3153566E-02
     +,   1.3778438E-02,   1.4223776E-02,   1.4479889E-02
     +,   1.4558366E-02,   1.4488702E-02,   1.4311838E-02
     +,   1.4071531E-02,   1.3804179E-02,   1.3529059E-02
     +,   1.3242494E-02,   1.2920337E-02,   1.2529367E-02
     +,   1.2043395E-02,   1.1457245E-02,   1.0791775E-02
     +,   1.0088422E-02,   9.3959505E-03,   8.7560136E-03
     +,   8.1929304E-03,   7.7107972E-03,   7.2975606E-03
     +,   6.9333371E-03,   6.5991245E-03,   6.2828055E-03
     +,   5.9810760E-03,   5.6975717E-03,   5.4385141E-03
     +,   5.2082585E-03,   5.0062649E-03,   4.8265355E-03
     +,   4.6590809E-03,   4.4927076E-03,   4.3178587E-03
     +,   4.1286214E-03,   3.9234292E-03,   3.7045984E-03
     +,   3.4771126E-03,   3.2471726E-03,   3.0208649E-03
     +,   2.8032972E-03,   2.5981914E-03,   2.4078425E-03
     +,   2.2332997E-03,   2.0747057E-03,   1.9315915E-03
     +,   1.8031134E-03,   1.6882076E-03,   1.5857033E-03
     +,   1.4943916E-03,   1.4130558E-03,   1.3405054E-03
     +,   1.2756081E-03,   1.2173218E-03,   1.1647033E-03
     +,   1.1169176E-03,   1.0732430E-03,   1.0330575E-03
     +,   9.9582085E-04,   9.6106384E-04,   9.2837570E-04
     +,   8.9739048E-04,   8.6777878E-04,   8.3924580E-04
     +,   8.1153354E-04,   7.8441884E-04,   7.5771450E-04
     +,   7.3126989E-04,   7.0497644E-04,   6.7875994E-04
     +,   6.5258215E-04,   6.2643911E-04,   6.0035475E-04
     +,   5.7437515E-04,   5.4856559E-04,   5.2300602E-04
     +,   4.9778546E-04,   4.7299472E-04,   4.4872519E-04
     +,   4.2506595E-04,   4.0209695E-04,   3.7989207E-04
     +,   3.5851143E-04,   3.3800697E-04,   3.1841517E-04
     +,   2.9976401E-04,   2.8206676E-04,   2.6532871E-04
     +,   2.4954297E-04,   2.3469613E-04,   2.2076567E-04
     +,   2.0772291E-04,   1.9553570E-04,   1.8416585E-04
     +,   1.7357428E-04,   1.6371849E-04,   1.5455636E-04
     +,   1.4604416E-04,   1.3813983E-04,   1.3080110E-04
     +,   1.2398798E-04,   1.1766114E-04,   1.1178412E-04
     +,   1.0632150E-04,   1.0124089E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_hatt95 = Yx/0.135333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7033411E-06,   2.8721884E-06
     +,   3.0484471E-06,   3.2322055E-06,   3.4235320E-06
     +,   3.6224803E-06,   3.8290805E-06,   4.0433451E-06
     +,   4.2652609E-06,   4.4948024E-06,   4.7319108E-06
     +,   4.9765063E-06,   5.2284863E-06,   5.4877205E-06
     +,   5.7540533E-06,   6.0273082E-06,   6.3072780E-06
     +,   6.5937325E-06,   6.8864169E-06,   7.1850486E-06
     +,   7.4893305E-06,   7.7989298E-06,   8.1134949E-06
     +,   8.4326794E-06,   8.7560702E-06,   9.0832855E-06
     +,   9.4139068E-06,   9.7475040E-06,   1.0083648E-05
     +,   1.0421898E-05,   1.0761817E-05,   1.1102968E-05
     +,   1.1444926E-05,   1.1787276E-05,   1.2129620E-05
     +,   1.2471591E-05,   1.2812847E-05,   1.3153081E-05
     +,   1.3492050E-05,   1.3829536E-05,   1.4165413E-05
     +,   1.4499603E-05,   1.4832134E-05,   1.5163104E-05
     +,   1.5492733E-05,   1.5821350E-05,   1.6149421E-05
     +,   1.6477545E-05,   1.6806494E-05,   1.7137199E-05
     +,   1.7470789E-05,   1.7808590E-05,   1.8152139E-05
     +,   1.8503230E-05,   1.8863868E-05,   1.9236353E-05
     +,   1.9623247E-05,   2.0027379E-05,   2.0451902E-05
     +,   2.0900243E-05,   2.1376152E-05,   2.1883676E-05
     +,   2.2427133E-05,   2.3011182E-05,   2.3640745E-05
     +,   2.4320960E-05,   2.5057258E-05,   2.5855181E-05
     +,   2.6720541E-05,   2.7659136E-05,   2.8676926E-05
     +,   2.9779741E-05,   3.0973471E-05,   3.2263677E-05
     +,   3.3655804E-05,   3.5154961E-05,   3.6765749E-05
     +,   3.8492206E-05,   4.0337862E-05,   4.2305517E-05
     +,   4.4396966E-05,   4.6613335E-05,   4.8954473E-05
     +,   5.1419440E-05,   5.4005824E-05,   5.6710367E-05
     +,   5.9528218E-05,   6.2453611E-05,   6.5479209E-05
     +,   6.8596717E-05,   7.1796712E-05,   7.5068448E-05
     +,   7.8400219E-05,   8.1779690E-05,   8.5193802E-05
     +,   8.8628723E-05,   9.2070717E-05,   9.5505544E-05
     +,   9.8919641E-05,   1.0229948E-04,   1.0563271E-04
     +,   1.0890781E-04,   1.1211512E-04,   1.1524664E-04
     +,   1.1829702E-04,   1.2126395E-04,   1.2414863E-04
     +,   1.2695655E-04,   1.2969870E-04,   1.3239218E-04
     +,   1.3506108E-04,   1.3773849E-04,   1.4046687E-04
     +,   1.4330033E-04,   1.4630523E-04,   1.4956231E-04
     +,   1.5316691E-04,   1.5723064E-04,   1.6188041E-04
     +,   1.6725897E-04,   1.7352260E-04,   1.8083812E-04
     +,   1.8937881E-04,   1.9931946E-04,   2.1082885E-04
     +,   2.2405993E-04,   2.3914351E-04,   2.5617427E-04
     +,   2.7520498E-04,   2.9623229E-04,   3.1919405E-04
     +,   3.4395847E-04,   3.7032709E-04,   3.9802957E-04
     +,   4.2673532E-04,   4.5605941E-04,   4.8557488E-04
     +,   5.1483058E-04,   5.4337323E-04,   5.7076657E-04
     +,   5.9661118E-04,   6.2056986E-04,   6.4239034E-04
     +,   6.6192506E-04,   6.7915424E-04,   6.9421151E-04
     +,   7.0741400E-04,   7.1929739E-04,   7.3066459E-04
     +,   7.4264285E-04,   7.5674965E-04,   7.7495712E-04
     +,   7.9974270E-04,   8.3410559E-04,   8.8150939E-04
     +,   9.4572309E-04,   1.0305367E-03,   1.1393586E-03
     +,   1.2747048E-03,   1.4376519E-03,   1.6274272E-03
     +,   1.8411857E-03,   2.0741336E-03,   2.3200971E-03
     +,   2.5725355E-03,   2.8258723E-03,   3.0770509E-03
     +,   3.3272575E-03,   3.5836750E-03,   3.8612040E-03
     +,   4.1838228E-03,   4.5844149E-03,   5.1008468E-03
     +,   5.7662907E-03,   6.5951031E-03,   7.5720204E-03
     +,   8.6564664E-03,   9.8139206E-03,   1.1073848E-02
     +,   1.2579068E-02,   1.4555855E-02,   1.7193206E-02
     +,   2.0575140E-02,   2.4744343E-02,   2.9656418E-02
     +,   3.4949511E-02,   4.0228523E-02,   4.6281055E-02
     +,   5.4558489E-02,   6.3890293E-02,   7.1499363E-02
     +,   7.7689655E-02,   8.2609370E-02,   8.7045878E-02
     +,   9.3087204E-02,   9.6187606E-02,   9.4993129E-02
     +,   8.9217842E-02,   7.9706982E-02,   7.2446316E-02
     +,   6.4702243E-02,   5.4225117E-02,   4.5126121E-02
     +,   3.9147563E-02,   3.4406491E-02,   2.9370887E-02
     +,   2.4757870E-02,   2.1572050E-02,   1.9555571E-02
     +,   1.7937558E-02,   1.6341288E-02,   1.4767612E-02
     +,   1.3283665E-02,   1.1912189E-02,   1.0661265E-02
     +,   9.5533216E-03,   8.6217551E-03,   7.8880768E-03
     +,   7.3388754E-03,   6.9214352E-03,   6.5624244E-03
     +,   6.1961203E-03,   5.7844738E-03,   5.3213686E-03
     +,   4.8242351E-03,   4.3209046E-03,   3.8379838E-03
     +,   3.3938820E-03,   2.9967183E-03,   2.6458660E-03
     +,   2.3352499E-03,   2.0568115E-03,   1.8031892E-03
     +,   1.5692423E-03,   1.3524155E-03,   1.1522337E-03
     +,   9.6947176E-04,   8.0528233E-04,   6.6050503E-04
     +,   5.3528149E-04,   4.2897434E-04,   3.4027602E-04
     +,   2.6740978E-04,   2.0835485E-04,   1.6105369E-04
     +,   1.2355584E-04,   9.4099894E-05,   7.1151109E-05
     +,   5.3410076E-05,   3.9799001E-05,   2.9434223E-05
     +,   2.1601063E-05,   1.5727253E-05,   1.1357851E-05
     +,   8.1340359E-06,   5.7754078E-06,   4.0647606E-06
     +,   2.8351269E-06,   1.9592687E-06,   1.3412125E-06
     +,   9.0926767E-07,   6.1036019E-07,   4.0558325E-07
     +,   2.6673109E-07,   1.7357507E-07,   1.1174451E-07
     +,   7.1153686E-08,   4.4804828E-08,   2.7895654E-08
     +,   1.7169247E-08,   1.0444589E-08,   6.2791021E-09
     +,   3.7300603E-09,   2.1891837E-09,   1.2692196E-09
     +,   7.2685230E-10,   4.1110332E-10,   2.2962987E-10
     +,   1.2665605E-10,   6.8981057E-11,   3.7093325E-11
     +,   1.9693339E-11,   1.0322068E-11,   5.3412982E-12
     +,   2.7286172E-12,   1.3762294E-12,   6.8537092E-13
     +,   3.3707195E-13,   1.6377986E-13,   7.8668300E-14
     +,   3.7398927E-14,   1.7631172E-14,   8.2714859E-15
     +,   3.8839578E-15,   1.8428981E-15,   8.9641582E-16
     +,   4.5573560E-16,   2.4723650E-16,   1.4523652E-16
     +,   9.2488739E-17,   6.3059360E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt100 = Yx/0.4298
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.0737715E-06,   7.2663470E-06
     +,   7.4608533E-06,   7.6574270E-06,   7.8562362E-06
     +,   8.0574719E-06,   8.2613587E-06,   8.4681496E-06
     +,   8.6781311E-06,   8.8916222E-06,   9.1089623E-06
     +,   9.3305289E-06,   9.5567211E-06,   9.7879647E-06
     +,   1.0024714E-05,   1.0267441E-05,   1.0516643E-05
     +,   1.0772827E-05,   1.1036525E-05,   1.1308267E-05
     +,   1.1588603E-05,   1.1878078E-05,   1.2177241E-05
     +,   1.2486649E-05,   1.2806822E-05,   1.3138304E-05
     +,   1.3481599E-05,   1.3837206E-05,   1.4205596E-05
     +,   1.4587215E-05,   1.4982489E-05,   1.5391812E-05
     +,   1.5815542E-05,   1.6254015E-05,   1.6707530E-05
     +,   1.7176355E-05,   1.7660748E-05,   1.8160905E-05
     +,   1.8677059E-05,   1.9209363E-05,   1.9758012E-05
     +,   2.0323176E-05,   2.0905036E-05,   2.1503793E-05
     +,   2.2119670E-05,   2.2752940E-05,   2.3403916E-05
     +,   2.4072988E-05,   2.4760608E-05,   2.5467338E-05
     +,   2.6193829E-05,   2.6940865E-05,   2.7709335E-05
     +,   2.8500323E-05,   2.9314977E-05,   3.0154688E-05
     +,   3.1020954E-05,   3.1915464E-05,   3.2840064E-05
     +,   3.3796754E-05,   3.4787688E-05,   3.5815166E-05
     +,   3.6881560E-05,   3.7989401E-05,   3.9141309E-05
     +,   4.0339819E-05,   4.1587642E-05,   4.2887259E-05
     +,   4.4241242E-05,   4.5651890E-05,   4.7121430E-05
     +,   4.8651735E-05,   5.0244536E-05,   5.1901028E-05
     +,   5.3622160E-05,   5.5408404E-05,   5.7259676E-05
     +,   5.9175327E-05,   6.1154242E-05,   6.3194762E-05
     +,   6.5294400E-05,   6.7450390E-05,   6.9659094E-05
     +,   7.1916678E-05,   7.4218457E-05,   7.6559743E-05
     +,   7.8935271E-05,   8.1339902E-05,   8.3768195E-05
     +,   8.6215121E-05,   8.8676039E-05,   9.1146700E-05
     +,   9.3623668E-05,   9.6104784E-05,   9.8589102E-05
     +,   1.0107707E-04,   1.0357115E-04,   1.0607559E-04
     +,   1.0859706E-04,   1.1114429E-04,   1.1372881E-04
     +,   1.1636421E-04,   1.1906688E-04,   1.2185524E-04
     +,   1.2474986E-04,   1.2777330E-04,   1.3094900E-04
     +,   1.3430136E-04,   1.3785488E-04,   1.4163376E-04
     +,   1.4566022E-04,   1.4995477E-04,   1.5453418E-04
     +,   1.5941194E-04,   1.6459591E-04,   1.7008913E-04
     +,   1.7588785E-04,   1.8198253E-04,   1.8835606E-04
     +,   1.9498552E-04,   2.0184180E-04,   2.0889012E-04
     +,   2.1609152E-04,   2.2340483E-04,   2.3078803E-04
     +,   2.3820010E-04,   2.4560472E-04,   2.5297119E-04
     +,   2.6027940E-04,   2.6752014E-04,   2.7470026E-04
     +,   2.8184269E-04,   2.8899044E-04,   2.9620598E-04
     +,   3.0357332E-04,   3.1119707E-04,   3.1920086E-04
     +,   3.2772505E-04,   3.3692466E-04,   3.4696434E-04
     +,   3.5801399E-04,   3.7024415E-04,   3.8382239E-04
     +,   3.9891031E-04,   4.1566000E-04,   4.3421795E-04
     +,   4.5472779E-04,   4.7733754E-04,   5.0220988E-04
     +,   5.2953983E-04,   5.5956910E-04,   5.9259881E-04
     +,   6.2900229E-04,   6.6923164E-04,   7.1380701E-04
     +,   7.6328719E-04,   8.1822730E-04,   8.7911950E-04
     +,   9.4630977E-04,   1.0199076E-03,   1.0997228E-03
     +,   1.1852185E-03,   1.2755187E-03,   1.3695149E-03
     +,   1.4660861E-03,   1.5644213E-03,   1.6644634E-03
     +,   1.7674089E-03,   1.8761869E-03,   1.9957186E-03
     +,   2.1327871E-03,   2.2953281E-03,   2.4910420E-03
     +,   2.7254191E-03,   2.9996240E-03,   3.3091563E-03
     +,   3.6440587E-03,   3.9915252E-03,   4.3408428E-03
     +,   4.6896590E-03,   5.0498527E-03,   5.4519298E-03
     +,   5.9479824E-03,   6.6119637E-03,   7.5300597E-03
     +,   8.7700915E-03,   1.0335388E-02,   1.2148664E-02
     +,   1.4126359E-02,   1.6314751E-02,   1.8904710E-02
     +,   2.2014223E-02,   2.5617167E-02,   3.0024962E-02
     +,   3.5980128E-02,   4.3616854E-02,   5.2542660E-02
     +,   6.2841184E-02,   7.3717922E-02,   8.1838340E-02
     +,   8.4608875E-02,   8.6471811E-02,   8.9388691E-02
     +,   9.0293996E-02,   8.9829512E-02,   8.8283509E-02
     +,   8.3588257E-02,   7.4874483E-02,   6.4302854E-02
     +,   5.4024901E-02,   4.6060842E-02,   4.0434781E-02
     +,   3.5533283E-02,   3.0903628E-02,   2.7006771E-02
     +,   2.4079578E-02,   2.1774473E-02,   1.9660570E-02
     +,   1.7587701E-02,   1.5601078E-02,   1.3801219E-02
     +,   1.2239357E-02,   1.0875952E-02,   9.6331928E-03
     +,   8.4624309E-03,   7.3590553E-03,   6.3403989E-03
     +,   5.4233409E-03,   4.6146242E-03,   3.9107664E-03
     +,   3.3019723E-03,   2.7763916E-03,   2.3227609E-03
     +,   1.9314185E-03,   1.5943595E-03,   1.3049757E-03
     +,   1.0578831E-03,   8.4864983E-04,   6.7341118E-04
     +,   5.2853784E-04,   4.1044602E-04,   3.1555476E-04
     +,   2.4034205E-04,   1.8146515E-04,   1.3588317E-04
     +,   1.0093766E-04,   7.4377851E-05,   5.4350225E-05
     +,   3.9363473E-05,   2.8237748E-05,   2.0047844E-05
     +,   1.4075062E-05,   9.7644024E-06,   6.6888574E-06
     +,   4.5216948E-06,   3.0148999E-06,   1.9820209E-06
     +,   1.2843889E-06,   8.2027452E-07,   5.1624119E-07
     +,   3.2016769E-07,   1.9568508E-07,   1.1787457E-07
     +,   6.9984303E-08,   4.0960060E-08,   2.3634115E-08
     +,   1.3445244E-08,   7.5420452E-09,   4.1718731E-09
     +,   2.2756084E-09,   1.2240020E-09,   6.4921574E-10
     +,   3.3956635E-10,   1.7514115E-10,   8.9085732E-11
     +,   4.4700150E-11,   2.2135772E-11,   1.0830135E-11
     +,   5.2452070E-12,   2.5239138E-12,   1.2143872E-12
     +,   5.9076219E-13,   2.9561290E-13,   1.5577802E-13
     +,   8.8599653E-14,   5.5220677E-14,   3.7606040E-14
     +,   2.7475306E-14,   2.1045752E-14,   1.6579503E-14
     +,   1.3260791E-14,   1.0686359E-14,   8.6405094E-15
     +,   6.9941908E-15,   5.6616652E-15,   4.5805077E-15
     +,   3.7028638E-15,   2.9905572E-15,   2.4128930E-15
     +,   1.9448160E-15,   1.5659306E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt104 = Yx/0.41916
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2628116E-06,   5.0722410E-06
     +,   4.8831498E-06,   4.6960668E-06,   4.5115094E-06
     +,   4.3299719E-06,   4.1519324E-06,   3.9778465E-06
     +,   3.8081541E-06,   3.6432659E-06,   3.4835814E-06
     +,   3.3294773E-06,   3.1813126E-06,   3.0394262E-06
     +,   2.9041419E-06,   2.7757644E-06,   2.6545858E-06
     +,   2.5408833E-06,   2.4349229E-06,   2.3369582E-06
     +,   2.2472352E-06,   2.1659903E-06,   2.0934565E-06
     +,   2.0298562E-06,   1.9754173E-06,   1.9303588E-06
     +,   1.8949033E-06,   1.8692729E-06,   1.8536922E-06
     +,   1.8483910E-06,   1.8536006E-06,   1.8695594E-06
     +,   1.8965106E-06,   1.9347042E-06,   1.9843972E-06
     +,   2.0458519E-06,   2.1193368E-06,   2.2051274E-06
     +,   2.3035077E-06,   2.4147566E-06,   2.5391694E-06
     +,   2.6770344E-06,   2.8286449E-06,   2.9942917E-06
     +,   3.1742641E-06,   3.3688459E-06,   3.5783146E-06
     +,   3.8029380E-06,   4.0429709E-06,   4.2986544E-06
     +,   4.5702122E-06,   4.8578468E-06,   5.1617308E-06
     +,   5.4820330E-06,   5.8188557E-06,   6.1723031E-06
     +,   6.5424256E-06,   6.9292364E-06,   7.3327114E-06
     +,   7.7527793E-06,   8.1893222E-06,   8.6421842E-06
     +,   9.1111260E-06,   9.5958940E-06,   1.0096187E-05
     +,   1.0611599E-05,   1.1141741E-05,   1.1686097E-05
     +,   1.2244181E-05,   1.2815386E-05,   1.3399129E-05
     +,   1.3994720E-05,   1.4601513E-05,   1.5218755E-05
     +,   1.5845742E-05,   1.6481756E-05,   1.7126054E-05
     +,   1.7777906E-05,   1.8436660E-05,   1.9101708E-05
     +,   1.9772457E-05,   2.0448490E-05,   2.1129406E-05
     +,   2.1815036E-05,   2.2505274E-05,   2.3200299E-05
     +,   2.3900404E-05,   2.4606214E-05,   2.5318534E-05
     +,   2.6038510E-05,   2.6767626E-05,   2.7507658E-05
     +,   2.8260733E-05,   2.9029410E-05,   2.9816640E-05
     +,   3.0625695E-05,   3.1460379E-05,   3.2324770E-05
     +,   3.3223467E-05,   3.4161345E-05,   3.5143748E-05
     +,   3.6176272E-05,   3.7264927E-05,   3.8415859E-05
     +,   3.9635586E-05,   4.0930809E-05,   4.2308340E-05
     +,   4.3775050E-05,   4.5338020E-05,   4.7004407E-05
     +,   4.8781192E-05,   5.0675648E-05,   5.2694799E-05
     +,   5.4845994E-05,   5.7136382E-05,   5.9573544E-05
     +,   6.2164945E-05,   6.4918771E-05,   6.7843241E-05
     +,   7.0947499E-05,   7.4241449E-05,   7.7735836E-05
     +,   8.1442529E-05,   8.5375075E-05,   8.9548725E-05
     +,   9.3980227E-05,   9.8688994E-05,   1.0369610E-04
     +,   1.0902577E-04,   1.1470391E-04,   1.2075967E-04
     +,   1.2722367E-04,   1.3412927E-04,   1.4151061E-04
     +,   1.4940350E-04,   1.5784412E-04,   1.6686801E-04
     +,   1.7650970E-04,   1.8680318E-04,   1.9778158E-04
     +,   2.0947684E-04,   2.2192193E-04,   2.3515442E-04
     +,   2.4921892E-04,   2.6417087E-04,   2.8008441E-04
     +,   2.9705721E-04,   3.1521457E-04,   3.3471463E-04
     +,   3.5575041E-04,   3.7854689E-04,   4.0335100E-04
     +,   4.3041943E-04,   4.6000109E-04,   4.9231242E-04
     +,   5.2750867E-04,   5.6566100E-04,   6.0674018E-04
     +,   6.5060728E-04,   6.9701584E-04,   7.4564753E-04
     +,   7.9615315E-04,   8.4821327E-04,   9.0161385E-04
     +,   9.5632166E-04,   1.0125440E-03,   1.0707563E-03
     +,   1.1317095E-03,   1.1964028E-03,   1.2660390E-03
     +,   1.3419950E-03,   1.4258717E-03,   1.5196392E-03
     +,   1.6258976E-03,   1.7481721E-03,   1.8911595E-03
     +,   2.0606280E-03,   2.2628293E-03,   2.5033397E-03
     +,   2.7856263E-03,   3.1099254E-03,   3.4733478E-03
     +,   3.8719729E-03,   4.3047541E-03,   4.7776243E-03
     +,   5.3052106E-03,   5.9085661E-03,   6.6107507E-03
     +,   7.4355309E-03,   8.4111067E-03,   9.5711891E-03
     +,   1.0946903E-02,   1.2562654E-02,   1.4458028E-02
     +,   1.6740624E-02,   1.9605692E-02,   2.3242911E-02
     +,   2.7920907E-02,   3.4188557E-02,   4.1756731E-02
     +,   4.9037613E-02,   5.6262456E-02,   6.5592632E-02
     +,   7.7237971E-02,   8.6272202E-02,   8.5901298E-02
     +,   8.1132866E-02,   8.1963710E-02,   8.6406149E-02
     +,   8.7392189E-02,   8.4378317E-02,   7.7307649E-02
     +,   6.7792676E-02,   5.9820656E-02,   5.4105878E-02
     +,   4.7933903E-02,   4.1444249E-02,   3.5102103E-02
     +,   2.9017089E-02,   2.3618029E-02,   1.9133322E-02
     +,   1.5631972E-02,   1.3099246E-02,   1.1355751E-02
     +,   1.0154044E-02,   9.2891818E-03,   8.5978359E-03
     +,   7.9426318E-03,   7.2290013E-03,   6.4218612E-03
     +,   5.5391337E-03,   4.6294741E-03,   3.7492358E-03
     +,   2.9464499E-03,   2.2526830E-03,   1.6811508E-03
     +,   1.2295886E-03,   8.8534685E-04,   6.3061668E-04
     +,   4.4656915E-04,   3.1595418E-04,   2.2433192E-04
     +,   1.6036366E-04,   1.1559374E-04,   8.3984422E-05
     +,   6.1374129E-05,   4.4965353E-05,   3.2903343E-05
     +,   2.3958652E-05,   1.7303284E-05,   1.2361006E-05
     +,   8.7158060E-06,   6.0561983E-06,   4.1422509E-06
     +,   2.7865381E-06,   1.8426787E-06,   1.1974307E-06
     +,   7.6451335E-07,   4.7950891E-07,   2.9542628E-07
     +,   1.7878523E-07,   1.0627742E-07,   6.2053054E-08
     +,   3.5586723E-08,   2.0046533E-08,   1.1092708E-08
     +,   6.0303056E-09,   3.2216987E-09,   1.6925229E-09
     +,   8.7525975E-10,   4.4637624E-10,   2.2525684E-10
     +,   1.1312645E-10,   5.7080705E-11,   2.9369483E-11
     +,   1.5730039E-11,   8.9735068E-12,   5.5475654E-12
     +,   3.7269359E-12,   2.6869841E-12,   2.0375498E-12
     +,   1.5946486E-12,   1.2703819E-12,   1.0213177E-12
     +,   8.2448414E-13,   6.6655649E-13,   5.3890952E-13
     +,   4.3542175E-13,   3.5145798E-13,   2.8335255E-13
     +,   2.2816154E-13,   1.8348371E-13,   1.4736428E-13
     +,   1.1819919E-13,   9.4682908E-14,   7.5745095E-14
     +,   6.0516018E-14,   4.8284927E-14,   3.8475574E-14
     +,   3.0618591E-14,   2.4334135E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt106 = Yx/0.400857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3165046E-06,   4.1341195E-06
     +,   3.9551296E-06,   3.7799466E-06,   3.6089539E-06
     +,   3.4425198E-06,   3.2809910E-06,   3.1246989E-06
     +,   2.9739533E-06,   2.8290460E-06,   2.6902578E-06
     +,   2.5578552E-06,   2.4320921E-06,   2.3132125E-06
     +,   2.2014522E-06,   2.0970404E-06,   2.0002037E-06
     +,   1.9111653E-06,   1.8301509E-06,   1.7573867E-06
     +,   1.6931037E-06,   1.6375416E-06,   1.5909475E-06
     +,   1.5535774E-06,   1.5257040E-06,   1.5076096E-06
     +,   1.4995948E-06,   1.5019763E-06,   1.5150878E-06
     +,   1.5392825E-06,   1.5749317E-06,   1.6224262E-06
     +,   1.6821756E-06,   1.7546088E-06,   1.8401718E-06
     +,   1.9393276E-06,   2.0525538E-06,   2.1803403E-06
     +,   2.3231964E-06,   2.4816236E-06,   2.6561461E-06
     +,   2.8472812E-06,   3.0555461E-06,   3.2814544E-06
     +,   3.5255084E-06,   3.7881980E-06,   4.0699924E-06
     +,   4.3713380E-06,   4.6926539E-06,   5.0343219E-06
     +,   5.3966846E-06,   5.7800426E-06,   6.1846345E-06
     +,   6.6106750E-06,   7.0582651E-06,   7.5274911E-06
     +,   8.0183436E-06,   8.5307365E-06,   9.0645153E-06
     +,   9.6194344E-06,   1.0195168E-05,   1.0791310E-05
     +,   1.1407329E-05,   1.2042648E-05,   1.2696604E-05
     +,   1.3368381E-05,   1.4057161E-05,   1.4761957E-05
     +,   1.5481784E-05,   1.6215496E-05,   1.6961974E-05
     +,   1.7719927E-05,   1.8488125E-05,   1.9265182E-05
     +,   2.0049765E-05,   2.0840516E-05,   2.1636024E-05
     +,   2.2434886E-05,   2.3235782E-05,   2.4037432E-05
     +,   2.4838550E-05,   2.5638041E-05,   2.6434816E-05
     +,   2.7228030E-05,   2.8016888E-05,   2.8800900E-05
     +,   2.9579678E-05,   3.0353203E-05,   3.1121628E-05
     +,   3.1885484E-05,   3.2645668E-05,   3.3403379E-05
     +,   3.4160261E-05,   3.4918423E-05,   3.5680463E-05
     +,   3.6449397E-05,   3.7228885E-05,   3.8023027E-05
     +,   3.8836588E-05,   3.9674833E-05,   4.0543709E-05
     +,   4.1449635E-05,   4.2399715E-05,   4.3401513E-05
     +,   4.4463177E-05,   4.5593340E-05,   4.6801011E-05
     +,   4.8095491E-05,   4.9486443E-05,   5.0983708E-05
     +,   5.2596959E-05,   5.4336062E-05,   5.6210367E-05
     +,   5.8229092E-05,   6.0400656E-05,   6.2732972E-05
     +,   6.5232802E-05,   6.7906098E-05,   7.0757276E-05
     +,   7.3789546E-05,   7.7004544E-05,   8.0402031E-05
     +,   8.3979903E-05,   8.7734392E-05,   9.1659756E-05
     +,   9.5747993E-05,   9.9989615E-05,   1.0437286E-04
     +,   1.0888479E-04,   1.1351056E-04,   1.1823469E-04
     +,   1.2304042E-04,   1.2791128E-04,   1.3283045E-04
     +,   1.3778241E-04,   1.4275362E-04,   1.4773279E-04
     +,   1.5271262E-04,   1.5769145E-04,   1.6267515E-04
     +,   1.6767968E-04,   1.7273489E-04,   1.7789062E-04
     +,   1.8322395E-04,   1.8884867E-04,   1.9493098E-04
     +,   2.0170581E-04,   2.0949839E-04,   2.1874793E-04
     +,   2.3003183E-04,   2.4408419E-04,   2.6180359E-04
     +,   2.8424134E-04,   3.1256676E-04,   3.4799386E-04
     +,   3.9166803E-04,   4.4452059E-04,   5.0710025E-04
     +,   5.7939201E-04,   6.6064892E-04,   7.4930111E-04
     +,   8.4292638E-04,   9.3832886E-04,   1.0317503E-03
     +,   1.1191908E-03,   1.1967995E-03,   1.2613070E-03
     +,   1.3104626E-03,   1.3433965E-03,   1.3608835E-03
     +,   1.3654862E-03,   1.3615735E-03,   1.3551984E-03
     +,   1.3538486E-03,   1.3660175E-03,   1.4005646E-03
     +,   1.4658121E-03,   1.5683770E-03,   1.7118442E-03
     +,   1.8955530E-03,   2.1138436E-03,   2.3561888E-03
     +,   2.6085945E-03,   2.8563119E-03,   3.0876012E-03
     +,   3.2981229E-03,   3.4951954E-03,   3.7009299E-03
     +,   3.9525265E-03,   4.2977519E-03,   4.7847861E-03
     +,   5.4497896E-03,   6.3112518E-03,   7.3791458E-03
     +,   8.6707585E-03,   1.0207254E-02,   1.1986844E-02
     +,   1.3984882E-02,   1.6228544E-02,   1.8942546E-02
     +,   2.2673279E-02,   2.7987171E-02,   3.4738582E-02
     +,   4.1969921E-02,   4.9146019E-02,   5.7715513E-02
     +,   6.6825271E-02,   7.2428323E-02,   7.6545186E-02
     +,   8.3286032E-02,   9.3171373E-02,   0.1012274    
     +,   0.1007507    ,   9.1434717E-02,   8.3336793E-02
     +,   7.7740394E-02,   6.9920123E-02,   6.0458489E-02
     +,   5.1505513E-02,   4.3911718E-02,   3.7525967E-02
     +,   3.1732202E-02,   2.6742592E-02,   2.3083085E-02
     +,   2.0525448E-02,   1.8284468E-02,   1.5880499E-02
     +,   1.3404220E-02,   1.1130554E-02,   9.1847917E-03
     +,   7.5353594E-03,   6.1127781E-03,   4.8720026E-03
     +,   3.7945702E-03,   2.8766154E-03,   2.1183516E-03
     +,   1.5159335E-03,   1.0570730E-03,   7.2157691E-04
     +,   4.8513326E-04,   3.2354027E-04,   2.1561691E-04
     +,   1.4450229E-04,   9.7759490E-05,   6.6786168E-05
     +,   4.5938054E-05,   3.1651318E-05,   2.1718415E-05
     +,   1.4764037E-05,   9.9028484E-06,   6.5351310E-06
     +,   4.2355550E-06,   2.6934417E-06,   1.6797975E-06
     +,   1.0272939E-06,   6.1606545E-07,   3.6232422E-07
     +,   2.0900048E-07,   1.1824478E-07,   6.5611623E-08
     +,   3.5704169E-08,   1.9053035E-08,   9.9696598E-09
     +,   5.1154121E-09,   2.5746543E-09,   1.2721529E-09
     +,   6.1815753E-10,   2.9643860E-10,   1.4123507E-10
     +,   6.7652252E-11,   3.3225388E-11,   1.7204006E-11
     +,   9.6794699E-12,   6.0268453E-12,   4.1331934E-12
     +,   3.0506723E-12,   2.3589039E-12,   1.8715435E-12
     +,   1.5039597E-12,   1.2154524E-12,   9.8429869E-13
     +,   7.9734337E-13,   6.4554899E-13,   5.2218261E-13
     +,   4.2193403E-13,   3.4054069E-13,   2.7452341E-13
     +,   2.2103635E-13,   1.7775682E-13,   1.4277693E-13
     +,   1.1454128E-13,   9.1776345E-14,   7.3446186E-14
     +,   5.8704215E-14,   4.6863734E-14,   3.7364782E-14
     +,   2.9754499E-14,   2.3664591E-14,   1.8797746E-14
     +,   1.4913064E-14,   1.1816444E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt108 = Yx/0.401142857142857
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3626692E-08,   1.5846021E-08
     +,   1.8397788E-08,   2.1326874E-08,   2.4683420E-08
     +,   2.8523383E-08,   3.2908982E-08,   3.7909373E-08
     +,   4.3601034E-08,   5.0068920E-08,   5.7406400E-08
     +,   6.5716485E-08,   7.5112283E-08,   8.5717872E-08
     +,   9.7668966E-08,   1.1111371E-07,   1.2621351E-07
     +,   1.4314389E-07,   1.6209493E-07,   1.8327262E-07
     +,   2.0689924E-07,   2.3321418E-07,   2.6247432E-07
     +,   2.9495718E-07,   3.3095594E-07,   3.7078755E-07
     +,   4.1478714E-07,   4.6331172E-07,   5.1673959E-07
     +,   5.7547095E-07,   6.3992849E-07,   7.1055672E-07
     +,   7.8782347E-07,   8.7221855E-07,   9.6425470E-07
     +,   1.0644669E-06,   1.1734123E-06,   1.2916682E-06
     +,   1.4198408E-06,   1.5585437E-06,   1.7084247E-06
     +,   1.8701439E-06,   2.0443813E-06,   2.2318368E-06
     +,   2.4332271E-06,   2.6492867E-06,   2.8807651E-06
     +,   3.1284285E-06,   3.3930583E-06,   3.6754502E-06
     +,   3.9764136E-06,   4.2967727E-06,   4.6373589E-06
     +,   4.9990399E-06,   5.3826566E-06,   5.7891079E-06
     +,   6.2192794E-06,   6.6740795E-06,   7.1544341E-06
     +,   7.6612841E-06,   8.1955859E-06,   8.7583267E-06
     +,   9.3504759E-06,   9.9730660E-06,   1.0627158E-05
     +,   1.1313766E-05,   1.2034015E-05,   1.2788954E-05
     +,   1.3579753E-05,   1.4407495E-05,   1.5273376E-05
     +,   1.6178501E-05,   1.7124081E-05,   1.8111217E-05
     +,   1.9141069E-05,   2.0214795E-05,   2.1333435E-05
     +,   2.2497978E-05,   2.3709419E-05,   2.4968658E-05
     +,   2.6276379E-05,   2.7633287E-05,   2.9039760E-05
     +,   3.0496169E-05,   3.2002485E-05,   3.3558648E-05
     +,   3.5164114E-05,   3.6818255E-05,   3.8519902E-05
     +,   4.0267725E-05,   4.2060012E-05,   4.3894575E-05
     +,   4.5768811E-05,   4.7679870E-05,   4.9624508E-05
     +,   5.1598890E-05,   5.3599131E-05,   5.5620723E-05
     +,   5.7659185E-05,   5.9709524E-05,   6.1766877E-05
     +,   6.3826054E-05,   6.5882130E-05,   6.7930079E-05
     +,   6.9965259E-05,   7.1983464E-05,   7.3980751E-05
     +,   7.5953838E-05,   7.7900346E-05,   7.9818696E-05
     +,   8.1708153E-05,   8.3569314E-05,   8.5403735E-05
     +,   8.7214503E-05,   8.9005815E-05,   9.0783484E-05
     +,   9.2554546E-05,   9.4327581E-05,   9.6112439E-05
     +,   9.7920340E-05,   9.9763871E-05,   1.0165651E-04
     +,   1.0361282E-04,   1.0564830E-04,   1.0777917E-04
     +,   1.1002197E-04,   1.1239385E-04,   1.1491182E-04
     +,   1.1759312E-04,   1.2045452E-04,   1.2351280E-04
     +,   1.2678381E-04,   1.3028330E-04,   1.3402589E-04
     +,   1.3802589E-04,   1.4229718E-04,   1.4685270E-04
     +,   1.5170516E-04,   1.5686730E-04,   1.6235212E-04
     +,   1.6817256E-04,   1.7434190E-04,   1.8087457E-04
     +,   1.8778552E-04,   1.9508935E-04,   2.0280118E-04
     +,   2.1093502E-04,   2.1950215E-04,   2.2851009E-04
     +,   2.3796099E-04,   2.4784953E-04,   2.5815982E-04
     +,   2.6886410E-04,   2.7992300E-04,   2.9128446E-04
     +,   3.0288537E-04,   3.1465827E-04,   3.2654079E-04
     +,   3.3849050E-04,   3.5050651E-04,   3.6266231E-04
     +,   3.7514573E-04,   3.8830662E-04,   4.0271325E-04
     +,   4.1920581E-04,   4.3893504E-04,   4.6337038E-04
     +,   4.9425830E-04,   5.3351128E-04,   5.8301259E-04
     +,   6.4433442E-04,   7.1840693E-04,   8.0518797E-04
     +,   9.0340164E-04,   1.0104281E-03,   1.1224790E-03
     +,   1.2350433E-03,   1.3436173E-03,   1.4446712E-03
     +,   1.5366584E-03,   1.6208527E-03,   1.7017779E-03
     +,   1.7870152E-03,   1.8862156E-03,   2.0093103E-03
     +,   2.1641748E-03,   2.3543735E-03,   2.5779305E-03
     +,   2.8280998E-03,   3.0966513E-03,   3.3790197E-03
     +,   3.6788082E-03,   4.0085325E-03,   4.3848781E-03
     +,   4.8209559E-03,   5.3226287E-03,   5.8964896E-03
     +,   6.5693907E-03,   7.4048396E-03,   8.4942654E-03
     +,   9.9212257E-03,   1.1742687E-02,   1.4026552E-02
     +,   1.6859511E-02,   2.0252939E-02,   2.4389567E-02
     +,   3.0121399E-02,   3.7866678E-02,   4.6294175E-02
     +,   5.3781081E-02,   6.0108528E-02,   6.6664070E-02
     +,   7.4529059E-02,   8.4947042E-02,   9.2867106E-02
     +,   9.5863745E-02,   9.8882951E-02,   9.8233655E-02
     +,   9.3027636E-02,   8.0958225E-02,   7.0009358E-02
     +,   6.1877385E-02,   5.4208443E-02,   4.5816936E-02
     +,   3.7729878E-02,   3.0859355E-02,   2.5585556E-02
     +,   2.1580637E-02,   1.7830826E-02,   1.4096318E-02
     +,   1.0810019E-02,   8.2157813E-03,   6.2477323E-03
     +,   4.7473041E-03,   3.5804182E-03,   2.6604119E-03
     +,   1.9361617E-03,   1.3742481E-03,   9.4830187E-04
     +,   6.3488574E-04,   4.1210750E-04,   2.5951915E-04
     +,   1.5881148E-04,   9.4646217E-05,   5.5066022E-05
     +,   3.1349875E-05,   1.7497605E-05,   9.5852347E-06
     +,   5.1548227E-06,   2.7199226E-06,   1.4061410E-06
     +,   7.1091227E-07,   3.5077781E-07,   1.6857825E-07
     +,   7.8759598E-08,   3.5712684E-08,   1.5695880E-08
     +,   6.6796058E-09,   2.7504472E-09,   1.0956055E-09
     +,   4.2252712E-10,   1.5820224E-10,   5.7911419E-11
     +,   2.1063080E-11,   7.8733547E-12,   3.2052150E-12
     +,   1.5183038E-12,   8.5795211E-13,   5.5625670E-13
     +,   3.8954362E-13,   2.8226352E-13,   2.0708046E-13
     +,   1.5240128E-13,   1.1210837E-13,   8.2320971E-14
     +,   6.0313645E-14,   4.4083826E-14,   3.2143183E-14
     +,   2.3379241E-14,   1.6963341E-14,   1.2277883E-14
     +,   8.8649537E-15,   6.3850123E-15,   4.5876524E-15
     +,   3.2881698E-15,   2.3510558E-15,   1.6769248E-15
     +,   1.1931708E-15,   8.4691780E-16,   5.9968154E-16
     +,   4.2359670E-16,   2.9848954E-16,   2.0982642E-16
     +,   1.4714278E-16,   1.0293807E-16,   7.1839723E-17
     +,   5.0016703E-17,   3.4739250E-17,   2.4070951E-17
     +,   1.6638897E-17,   1.1474323E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt110 = Yx/0.381428571428571
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2196776E-09,   2.6404625E-09
     +,   3.1357812E-09,   3.7178129E-09,   4.4005435E-09
     +,   5.1999893E-09,   6.1344703E-09,   7.2248851E-09
     +,   8.4950029E-09,   9.9719069E-09,   1.1686237E-08
     +,   1.3672666E-08,   1.5970389E-08,   1.8623528E-08
     +,   2.1681718E-08,   2.5200631E-08,   2.9242633E-08
     +,   3.3877360E-08,   3.9182442E-08,   4.5244306E-08
     +,   5.2158800E-08,   6.0032072E-08,   6.8981315E-08
     +,   7.9136413E-08,   9.0638949E-08,   1.0364569E-07
     +,   1.1832749E-07,   1.3487126E-07,   1.5348067E-07
     +,   1.7437732E-07,   1.9780143E-07,   2.2401301E-07
     +,   2.5329291E-07,   2.8594346E-07,   3.2228925E-07
     +,   3.6267843E-07,   4.0748287E-07,   4.5709794E-07
     +,   5.1194763E-07,   5.7247513E-07,   6.3915502E-07
     +,   7.1248439E-07,   7.9298627E-07,   8.8120902E-07
     +,   9.7772534E-07,   1.0831313E-06,   1.1980463E-06
     +,   1.3231103E-06,   1.4589831E-06,   1.6063432E-06
     +,   1.7658839E-06,   1.9383119E-06,   2.1243404E-06
     +,   2.3247042E-06,   2.5401177E-06,   2.7713190E-06
     +,   3.0190288E-06,   3.2839637E-06,   3.5668270E-06
     +,   3.8683038E-06,   4.1890576E-06,   4.5297293E-06
     +,   4.8909033E-06,   5.2731548E-06,   5.6770173E-06
     +,   6.1029336E-06,   6.5513464E-06,   7.0225833E-06
     +,   7.5169605E-06,   8.0346690E-06,   8.5758829E-06
     +,   9.1406337E-06,   9.7289394E-06,   1.0340658E-05
     +,   1.0975618E-05,   1.1633560E-05,   1.2314091E-05
     +,   1.3016727E-05,   1.3740950E-05,   1.4486141E-05
     +,   1.5251546E-05,   1.6036434E-05,   1.6839896E-05
     +,   1.7661083E-05,   1.8498997E-05,   1.9352721E-05
     +,   2.0221210E-05,   2.1103549E-05,   2.1998741E-05
     +,   2.2905922E-05,   2.3824334E-05,   2.4753255E-05
     +,   2.5692121E-05,   2.6640608E-05,   2.7598622E-05
     +,   2.8566214E-05,   2.9543877E-05,   3.0532301E-05
     +,   3.1532665E-05,   3.2546432E-05,   3.3575627E-05
     +,   3.4622582E-05,   3.5690246E-05,   3.6781894E-05
     +,   3.7901373E-05,   3.9052997E-05,   4.0241401E-05
     +,   4.1471591E-05,   4.2748954E-05,   4.4079072E-05
     +,   4.5467525E-05,   4.6920039E-05,   4.8441991E-05
     +,   5.0038649E-05,   5.1714564E-05,   5.3473846E-05
     +,   5.5319528E-05,   5.7253790E-05,   5.9277387E-05
     +,   6.1389816E-05,   6.3589054E-05,   6.5871238E-05
     +,   6.8230693E-05,   7.0660048E-05,   7.3150113E-05
     +,   7.5689604E-05,   7.8265766E-05,   8.0863982E-05
     +,   8.3468571E-05,   8.6062297E-05,   8.8627559E-05
     +,   9.1145899E-05,   9.3599192E-05,   9.5969503E-05
     +,   9.8240089E-05,   1.0039585E-04,   1.0242366E-04
     +,   1.0431345E-04,   1.0605891E-04,   1.0765830E-04
     +,   1.0911519E-04,   1.1043985E-04,   1.1165060E-04
     +,   1.1277514E-04,   1.1385223E-04,   1.1493426E-04
     +,   1.1608922E-04,   1.1740380E-04,   1.1898643E-04
     +,   1.2097084E-04,   1.2352013E-04,   1.2682987E-04
     +,   1.3113253E-04,   1.3670085E-04,   1.4385062E-04
     +,   1.5294124E-04,   1.6437536E-04,   1.7859624E-04
     +,   1.9607968E-04,   2.1731957E-04,   2.4281374E-04
     +,   2.7303761E-04,   3.0841408E-04,   3.4927932E-04
     +,   3.9585348E-04,   4.4820653E-04,   5.0623080E-04
     +,   5.6963012E-04,   6.3792575E-04,   7.1046758E-04
     +,   7.8645436E-04,   8.6497481E-04,   9.4505079E-04
     +,   1.0256817E-03,   1.1058880E-03,   1.1848025E-03
     +,   1.2617635E-03,   1.3364450E-03,   1.4090278E-03
     +,   1.4803716E-03,   1.5521254E-03,   1.6267400E-03
     +,   1.7073104E-03,   1.7972202E-03,   1.8996013E-03
     +,   2.0166948E-03,   2.1493020E-03,   2.2965057E-03
     +,   2.4558606E-03,   2.6241480E-03,   2.7988008E-03
     +,   2.9796932E-03,   3.1710304E-03,   3.3827052E-03
     +,   3.6302209E-03,   3.9319429E-03,   4.3030451E-03
     +,   4.7476767E-03,   5.2542118E-03,   5.8000293E-03
     +,   6.3678348E-03,   6.9652828E-03,   7.6324567E-03
     +,   8.4281983E-03,   9.4100581E-03,   1.0652413E-02
     +,   1.2317239E-02,   1.4644952E-02,   1.7702768E-02
     +,   2.1166034E-02,   2.4734523E-02,   2.9042065E-02
     +,   3.5371352E-02,   4.2937163E-02,   4.9713772E-02
     +,   5.8778860E-02,   7.0181720E-02,   7.9345286E-02
     +,   9.1004305E-02,   9.9705547E-02,   0.1011630    
     +,   0.1005357    ,   9.5958151E-02,   8.9692995E-02
     +,   8.4644131E-02,   7.4163139E-02,   6.0853936E-02
     +,   4.9905777E-02,   3.9616629E-02,   3.0311262E-02
     +,   2.2861518E-02,   1.7347842E-02,   1.3317627E-02
     +,   1.0137505E-02,   7.5066271E-03,   5.3283591E-03
     +,   3.5773613E-03,   2.2509543E-03,   1.3206098E-03
     +,   7.2041573E-04,   3.6509134E-04,   1.7201832E-04
     +,   7.5492215E-05,   3.0923016E-05,   1.1843772E-05
     +,   4.2474776E-06,   1.4281350E-06,   4.5138302E-07
     +,   1.3528003E-07,   3.9571258E-08,   1.2280417E-08
     +,   4.7751882E-09,   2.6254798E-09,   1.8595576E-09
     +,   1.4599154E-09,   1.1798995E-09,   9.5915209E-10
     +,   7.7958756E-10,   6.3267142E-10,   5.1250915E-10
     +,   4.1439457E-10,   3.3443820E-10,   2.6940408E-10
     +,   2.1660933E-10,   1.7383674E-10,   1.3925018E-10
     +,   1.1133661E-10,   8.8852870E-11,   7.0778598E-11
     +,   5.6276431E-11,   4.4662527E-11,   3.5379921E-11
     +,   2.7975075E-11,   2.2079262E-11,   1.7393783E-11
     +,   1.3677541E-11,   1.0735451E-11,   8.4108241E-12
     +,   6.5774387E-12,   5.1343183E-12,   4.0004645E-12
     +,   3.1113419E-12,   2.4153902E-12,   1.8717055E-12
     +,   1.4477441E-12,   1.1177833E-12,   8.6145360E-13
     +,   6.6269001E-13,   5.0886389E-13,   3.9003075E-13
     +,   2.9840675E-13,   2.2788902E-13,   1.7372097E-13
     +,   1.3218608E-13,   1.0039970E-13,   7.6117464E-14
     +,   5.7603506E-14,   4.3512933E-14,   3.2809564E-14
     +,   2.4693660E-14,   1.8551670E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt112 = Yx/0.371
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5479037E-07,   7.2091751E-07
     +,   7.9240050E-07,   8.6952298E-07,   9.5256752E-07
     +,   1.0418140E-06,   1.1375378E-06,   1.2400072E-06
     +,   1.3494803E-06,   1.4662086E-06,   1.5904252E-06
     +,   1.7223490E-06,   1.8621795E-06,   2.0100974E-06
     +,   2.1662593E-06,   2.3307955E-06,   2.5038109E-06
     +,   2.6853797E-06,   2.8755451E-06,   3.0743179E-06
     +,   3.2816736E-06,   3.4975544E-06,   3.7218608E-06
     +,   3.9544734E-06,   4.1952112E-06,   4.4438807E-06
     +,   4.7002413E-06,   4.9640207E-06,   5.2349155E-06
     +,   5.5125938E-06,   5.7966949E-06,   6.0868329E-06
     +,   6.3826064E-06,   6.6835937E-06,   6.9893613E-06
     +,   7.2994708E-06,   7.6134797E-06,   7.9309448E-06
     +,   8.2514498E-06,   8.5745578E-06,   8.8998895E-06
     +,   9.2270657E-06,   9.5557480E-06,   9.8856326E-06
     +,   1.0216456E-05,   1.0548001E-05,   1.0880101E-05
     +,   1.1212647E-05,   1.1545584E-05,   1.1878912E-05
     +,   1.2212706E-05,   1.2547092E-05,   1.2882260E-05
     +,   1.3218484E-05,   1.3556059E-05,   1.3895380E-05
     +,   1.4236873E-05,   1.4581020E-05,   1.4928356E-05
     +,   1.5279449E-05,   1.5634903E-05,   1.5995356E-05
     +,   1.6361439E-05,   1.6733822E-05,   1.7113169E-05
     +,   1.7500113E-05,   1.7895309E-05,   1.8299328E-05
     +,   1.8712764E-05,   1.9136100E-05,   1.9569829E-05
     +,   2.0014304E-05,   2.0469884E-05,   2.0936770E-05
     +,   2.1415121E-05,   2.1905020E-05,   2.2406406E-05
     +,   2.2919125E-05,   2.3442955E-05,   2.3977571E-05
     +,   2.4522507E-05,   2.5077272E-05,   2.5641213E-05
     +,   2.6213682E-05,   2.6793874E-05,   2.7381029E-05
     +,   2.7974247E-05,   2.8572715E-05,   2.9175519E-05
     +,   2.9781841E-05,   3.0390909E-05,   3.1001997E-05
     +,   3.1614491E-05,   3.2227959E-05,   3.2842163E-05
     +,   3.3457036E-05,   3.4072837E-05,   3.4690089E-05
     +,   3.5309742E-05,   3.5933077E-05,   3.6561934E-05
     +,   3.7198566E-05,   3.7845868E-05,   3.8507260E-05
     +,   3.9186874E-05,   3.9889524E-05,   4.0620667E-05
     +,   4.1386487E-05,   4.2193944E-05,   4.3050706E-05
     +,   4.3965018E-05,   4.4945889E-05,   4.6002700E-05
     +,   4.7145466E-05,   4.8384343E-05,   4.9729770E-05
     +,   5.1192048E-05,   5.2781397E-05,   5.4507429E-05
     +,   5.6379118E-05,   5.8404577E-05,   6.0590504E-05
     +,   6.2942141E-05,   6.5463064E-05,   6.8154928E-05
     +,   7.1016933E-05,   7.4046249E-05,   7.7237295E-05
     +,   8.0582358E-05,   8.4070853E-05,   8.7690336E-05
     +,   9.1425783E-05,   9.5260861E-05,   9.9177494E-05
     +,   1.0315703E-04,   1.0718079E-04,   1.1123041E-04
     +,   1.1528898E-04,   1.1934226E-04,   1.2337946E-04
     +,   1.2739419E-04,   1.3138547E-04,   1.3535965E-04
     +,   1.3933095E-04,   1.4332205E-04,   1.4736614E-04
     +,   1.5150712E-04,   1.5580004E-04,   1.6031171E-04
     +,   1.6512141E-04,   1.7032048E-04,   1.7601180E-04
     +,   1.8230993E-04,   1.8934085E-04,   1.9724191E-04
     +,   2.0616103E-04,   2.1625675E-04,   2.2769980E-04
     +,   2.4067229E-04,   2.5536667E-04,   2.7198659E-04
     +,   2.9074331E-04,   3.1184917E-04,   3.3550989E-04
     +,   3.6191480E-04,   3.9121963E-04,   4.2352511E-04
     +,   4.5885862E-04,   4.9715640E-04,   5.3824717E-04
     +,   5.8184098E-04,   6.2753813E-04,   6.7485444E-04
     +,   7.2326168E-04,   7.7224511E-04,   8.2139164E-04
     +,   8.7047624E-04,   9.1954391E-04,   9.6897938E-04
     +,   1.0195391E-03,   1.0723162E-03,   1.1286343E-03
     +,   1.1898758E-03,   1.2572546E-03,   1.3315633E-03
     +,   1.4129383E-03,   1.5007278E-03,   1.5934826E-03
     +,   1.6891139E-03,   1.7852279E-03,   1.8796881E-03
     +,   1.9714080E-03,   2.0614651E-03,   2.1546378E-03
     +,   2.2613097E-03,   2.3993698E-03,   2.5951939E-03
     +,   2.8823051E-03,   3.2962488E-03,   3.8654129E-03
     +,   4.6000639E-03,   5.4856562E-03,   6.4874310E-03
     +,   7.5684306E-03,   8.7139634E-03,   9.9483943E-03
     +,   1.1322764E-02,   1.2858909E-02,   1.4492196E-02
     +,   1.6120555E-02,   1.7803414E-02,   1.9962424E-02
     +,   2.3183795E-02,   2.7782243E-02,   3.4542471E-02
     +,   4.4327948E-02,   5.4606255E-02,   6.3968405E-02
     +,   7.6100349E-02,   8.5785747E-02,   9.5396981E-02
     +,   0.1085991    ,   0.1133522    ,   0.1118743    
     +,   0.1006397    ,   8.6030900E-02,   7.8694701E-02
     +,   6.8584606E-02,   5.5420864E-02,   4.2554859E-02
     +,   3.1473503E-02,   2.2766221E-02,   1.5821379E-02
     +,   1.0669068E-02,   7.1220025E-03,   4.6821199E-03
     +,   2.9746410E-03,   1.7972484E-03,   1.0212937E-03
     +,   5.4179510E-04,   2.6736833E-04,   1.2273619E-04
     +,   5.2519063E-05,   2.0995751E-05,   7.8501371E-06
     +,   2.7426856E-06,   8.9294474E-07,   2.6984296E-07
     +,   7.5391512E-08,   1.9423508E-08,   4.6171698E-09
     +,   1.0237241E-09,   2.2223429E-10,   5.5676998E-11
     +,   2.1447812E-11,   1.2942220E-11,   9.4694782E-12
     +,   7.2694142E-12,   5.6338866E-12,   4.3740927E-12
     +,   3.3972779E-12,   2.6388540E-12,   2.0496944E-12
     +,   1.5918744E-12,   1.2360679E-12,   9.5950429E-13
     +,   7.4452407E-13,   5.7743448E-13,   4.4759319E-13
     +,   3.4672075E-13,   2.6838221E-13,   2.0757368E-13
     +,   1.6040121E-13,   1.2382991E-13,   9.5497842E-14
     +,   7.3568206E-14,   5.6608984E-14,   4.3507156E-14
     +,   3.3395612E-14,   2.5601093E-14,   1.9599423E-14
     +,   1.4984186E-14,   1.1439484E-14,   8.7208318E-15
     +,   6.6384412E-15,   5.0457803E-15,   3.8294029E-15
     +,   2.9017589E-15,   2.1954234E-15,   1.6583931E-15
     +,   1.2507458E-15,   9.4178354E-16,   7.0800493E-16
     +,   5.3138580E-16,   3.9817865E-16,   2.9787105E-16
     +,   2.2246680E-16,   1.6587417E-16,   1.2347363E-16
     +,   9.1757127E-17,   6.8074443E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt113 = Yx/0.365142857142857
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2969969E-07,   1.4536568E-07
     +,   1.6267468E-07,   1.8176613E-07,   2.0278746E-07
     +,   2.2589391E-07,   2.5124828E-07,   2.7902104E-07
     +,   3.0938952E-07,   3.4253947E-07,   3.7866170E-07
     +,   4.1795360E-07,   4.6061817E-07,   5.0686259E-07
     +,   5.5689856E-07,   6.1094050E-07,   6.6920472E-07
     +,   7.3190847E-07,   7.9926883E-07,   8.7149999E-07
     +,   9.4881455E-07,   1.0314187E-06,   1.1195120E-06
     +,   1.2132913E-06,   1.3129338E-06,   1.4186153E-06
     +,   1.5304926E-06,   1.6487089E-06,   1.7733905E-06
     +,   1.9046457E-06,   2.0425639E-06,   2.1872113E-06
     +,   2.3386331E-06,   2.4968494E-06,   2.6618582E-06
     +,   2.8336301E-06,   3.0121114E-06,   3.1972211E-06
     +,   3.3888643E-06,   3.5869016E-06,   3.7911923E-06
     +,   4.0015620E-06,   4.2178244E-06,   4.4397725E-06
     +,   4.6671912E-06,   4.8998581E-06,   5.1375432E-06
     +,   5.3800227E-06,   5.6270778E-06,   5.8785058E-06
     +,   6.1341229E-06,   6.3937755E-06,   6.6573411E-06
     +,   6.9247567E-06,   7.1959862E-06,   7.4710829E-06
     +,   7.7501554E-06,   8.0333903E-06,   8.3210753E-06
     +,   8.6135833E-06,   8.9113983E-06,   9.2151258E-06
     +,   9.5254682E-06,   9.8432838E-06,   1.0169567E-05
     +,   1.0505417E-05,   1.0852119E-05,   1.1211059E-05
     +,   1.1583821E-05,   1.1972080E-05,   1.2377705E-05
     +,   1.2802662E-05,   1.3249101E-05,   1.3719244E-05
     +,   1.4215483E-05,   1.4740317E-05,   1.5296317E-05
     +,   1.5886137E-05,   1.6512540E-05,   1.7178358E-05
     +,   1.7886401E-05,   1.8639588E-05,   1.9440771E-05
     +,   2.0292888E-05,   2.1198754E-05,   2.2161263E-05
     +,   2.3183142E-05,   2.4267181E-05,   2.5415968E-05
     +,   2.6632104E-05,   2.7918111E-05,   2.9276331E-05
     +,   3.0708994E-05,   3.2218315E-05,   3.3806420E-05
     +,   3.5475154E-05,   3.7226477E-05,   3.9062037E-05
     +,   4.0983607E-05,   4.2992622E-05,   4.5090659E-05
     +,   4.7278969E-05,   4.9558970E-05,   5.1931725E-05
     +,   5.4398359E-05,   5.6959976E-05,   5.9617309E-05
     +,   6.2370993E-05,   6.5221662E-05,   6.8169757E-05
     +,   7.1215174E-05,   7.4357951E-05,   7.7597368E-05
     +,   8.0932739E-05,   8.4362488E-05,   8.7884968E-05
     +,   9.1497495E-05,   9.5197167E-05,   9.8979872E-05
     +,   1.0284101E-04,   1.0677514E-04,   1.1077555E-04
     +,   1.1483453E-04,   1.1894349E-04,   1.2309274E-04
     +,   1.2727105E-04,   1.3146656E-04,   1.3566570E-04
     +,   1.3985437E-04,   1.4401690E-04,   1.4813723E-04
     +,   1.5219804E-04,   1.5618207E-04,   1.6007115E-04
     +,   1.6384768E-04,   1.6749445E-04,   1.7099494E-04
     +,   1.7433427E-04,   1.7749978E-04,   1.8048183E-04
     +,   1.8327445E-04,   1.8587636E-04,   1.8829237E-04
     +,   1.9053427E-04,   1.9262193E-04,   1.9458485E-04
     +,   1.9646352E-04,   1.9830998E-04,   2.0018946E-04
     +,   2.0218080E-04,   2.0437704E-04,   2.0688515E-04
     +,   2.0982511E-04,   2.1332940E-04,   2.1754019E-04
     +,   2.2260696E-04,   2.2868291E-04,   2.3592132E-04
     +,   2.4447177E-04,   2.5447484E-04,   2.6606006E-04
     +,   2.7934290E-04,   2.9442264E-04,   3.1138441E-04
     +,   3.3030452E-04,   3.5125820E-04,   3.7432986E-04
     +,   3.9963343E-04,   4.2733733E-04,   4.5769487E-04
     +,   4.9107923E-04,   5.2802847E-04,   5.6929432E-04
     +,   6.1588356E-04,   6.6908193E-04,   7.3045999E-04
     +,   8.0181239E-04,   8.8501151E-04,   9.8177174E-04
     +,   1.0933075E-03,   1.2199117E-03,   1.3605258E-03
     +,   1.5124533E-03,   1.6713310E-03,   1.8314748E-03
     +,   1.9866417E-03,   2.1311666E-03,   2.2612147E-03
     +,   2.3757981E-03,   2.4772547E-03,   2.5709912E-03
     +,   2.6644696E-03,   2.7657547E-03,   2.8820708E-03
     +,   3.0187864E-03,   3.1789781E-03,   3.3635036E-03
     +,   3.5713490E-03,   3.7999670E-03,   4.0456569E-03
     +,   4.3045008E-03,   4.5749373E-03,   4.8630624E-03
     +,   5.1908609E-03,   5.6041437E-03,   6.1720330E-03
     +,   6.9667939E-03,   8.0234166E-03,   9.3061570E-03
     +,   1.0733240E-02,   1.2291876E-02,   1.4184633E-02
     +,   1.6804252E-02,   2.0371988E-02,   2.4678640E-02
     +,   2.9741013E-02,   3.6620490E-02,   4.6103638E-02
     +,   5.6270339E-02,   6.5401495E-02,   7.5687326E-02
     +,   8.6631246E-02,   9.6752867E-02,   0.1061791    
     +,   0.1146403    ,   0.1196587    ,   0.1136891    
     +,   0.1010811    ,   8.6554788E-02,   6.9863148E-02
     +,   5.6246713E-02,   4.3954417E-02,   3.2307073E-02
     +,   2.2158042E-02,   1.4323696E-02,   8.8552870E-03
     +,   5.1884381E-03,   2.8180783E-03,   1.3869065E-03
     +,   6.0538744E-04,   2.3062441E-04,   7.6044744E-05
     +,   2.1657486E-05,   5.3321751E-06,   1.1370021E-06
     +,   2.1044710E-07,   3.3919623E-08,   4.8074877E-09
     +,   6.3151229E-10,   1.0113061E-10,   3.4737848E-11
     +,   2.1625002E-11,   1.5415891E-11,   1.1158761E-11
     +,   8.0748143E-12,   5.8323689E-12,   4.2045234E-12
     +,   3.0252706E-12,   2.1726772E-12,   1.5574618E-12
     +,   1.1144071E-12,   7.9595261E-13,   5.6747516E-13
     +,   4.0385108E-13,   2.8689269E-13,   2.0343926E-13
     +,   1.4399910E-13,   1.0174039E-13,   7.1752012E-14
     +,   5.0508825E-14,   3.5487885E-14,   2.4886616E-14
     +,   1.7418799E-14,   1.2168053E-14,   8.4831231E-15
     +,   5.9023060E-15,   4.0982071E-15,   2.8397021E-15
     +,   1.9635238E-15,   1.3548206E-15,   9.3280075E-16
     +,   6.4085533E-16,   4.3931314E-16,   3.0049306E-16
     +,   2.0508007E-16,   1.3965200E-16,   9.4884452E-17
     +,   6.4322180E-17,   4.3506183E-17,   2.9360084E-17
     +,   1.9769211E-17,   1.3281314E-17,   8.9027878E-18
     +,   5.9544278E-18,   3.9737550E-18,   2.6460999E-18
     +,   1.7582353E-18,   1.1657679E-18,   7.7132653E-19
     +,   5.0928042E-19,   3.3558045E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt114 = Yx/0.377571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6538893E-08,   1.9430534E-08
     +,   2.2785393E-08,   2.6669932E-08,   3.1158827E-08
     +,   3.6335784E-08,   4.2294381E-08,   4.9138897E-08
     +,   5.6985236E-08,   6.5962269E-08,   7.6212217E-08
     +,   8.7892019E-08,   1.0117439E-07,   1.1624871E-07
     +,   1.3332227E-07,   1.5262100E-07,   1.7439078E-07
     +,   1.9889796E-07,   2.2643084E-07,   2.5729952E-07
     +,   2.9183755E-07,   3.3040192E-07,   3.7337261E-07
     +,   4.2115687E-07,   4.7418075E-07,   5.3289955E-07
     +,   5.9778870E-07,   6.6934729E-07,   7.4809566E-07
     +,   8.3457445E-07,   9.2934278E-07,   1.0329757E-06
     +,   1.1460621E-06,   1.2692024E-06,   1.4030030E-06
     +,   1.5480759E-06,   1.7050326E-06,   1.8744767E-06
     +,   2.0570139E-06,   2.2532145E-06,   2.4636511E-06
     +,   2.6888579E-06,   2.9293403E-06,   3.1855668E-06
     +,   3.4579632E-06,   3.7469049E-06,   4.0527120E-06
     +,   4.3756481E-06,   4.7159042E-06,   5.0736076E-06
     +,   5.4488087E-06,   5.8414812E-06,   6.2515110E-06
     +,   6.6787347E-06,   7.1228560E-06,   7.5835528E-06
     +,   8.0603977E-06,   8.5528982E-06,   9.0605017E-06
     +,   9.5825962E-06,   1.0118530E-05,   1.0667623E-05
     +,   1.1229145E-05,   1.1802411E-05,   1.2386755E-05
     +,   1.2981495E-05,   1.3586087E-05,   1.4199992E-05
     +,   1.4822866E-05,   1.5454410E-05,   1.6094582E-05
     +,   1.6743434E-05,   1.7401309E-05,   1.8068706E-05
     +,   1.8746425E-05,   1.9435536E-05,   2.0137342E-05
     +,   2.0853406E-05,   2.1585620E-05,   2.2336135E-05
     +,   2.3107259E-05,   2.3901617E-05,   2.4721885E-05
     +,   2.5570964E-05,   2.6451697E-05,   2.7367003E-05
     +,   2.8319586E-05,   2.9312050E-05,   3.0346582E-05
     +,   3.1425039E-05,   3.2548745E-05,   3.3718337E-05
     +,   3.4933666E-05,   3.6193818E-05,   3.7496924E-05
     +,   3.8839953E-05,   4.0218929E-05,   4.1628577E-05
     +,   4.3062617E-05,   4.4513436E-05,   4.5972483E-05
     +,   4.7429974E-05,   4.8875372E-05,   5.0297167E-05
     +,   5.1683346E-05,   5.3021482E-05,   5.4298893E-05
     +,   5.5502940E-05,   5.6621469E-05,   5.7642934E-05
     +,   5.8556638E-05,   5.9353290E-05,   6.0024991E-05
     +,   6.0565792E-05,   6.0971717E-05,   6.1241146E-05
     +,   6.1374907E-05,   6.1376457E-05,   6.1251943E-05
     +,   6.1010269E-05,   6.0663027E-05,   6.0224469E-05
     +,   5.9711329E-05,   5.9142621E-05,   5.8539354E-05
     +,   5.7924302E-05,   5.7321558E-05,   5.6756198E-05
     +,   5.6253750E-05,   5.5839850E-05,   5.5539644E-05
     +,   5.5377397E-05,   5.5375931E-05,   5.5556193E-05
     +,   5.5936787E-05,   5.6533641E-05,   5.7359528E-05
     +,   5.8423819E-05,   5.9732309E-05,   6.1287159E-05
     +,   6.3086562E-05,   6.5125008E-05,   6.7393506E-05
     +,   6.9879832E-05,   7.2568611E-05,   7.5442353E-05
     +,   7.8481804E-05,   8.1666592E-05,   8.4976287E-05
     +,   8.8391695E-05,   9.1896087E-05,   9.5476636E-05
     +,   9.9126795E-05,   1.0284939E-04,   1.0666016E-04
     +,   1.1059261E-04,   1.1470475E-04,   1.1908792E-04
     +,   1.2387698E-04,   1.2926233E-04,   1.3550457E-04
     +,   1.4294795E-04,   1.5203255E-04,   1.6330233E-04
     +,   1.7740630E-04,   1.9508725E-04,   2.1715483E-04
     +,   2.4444205E-04,   2.7774638E-04,   3.1775038E-04
     +,   3.6492964E-04,   4.1946210E-04,   4.8114901E-04
     +,   5.4934988E-04,   6.2294782E-04,   7.0038129E-04
     +,   7.7970501E-04,   8.5870805E-04,   9.3508296E-04
     +,   1.0066362E-03,   1.0714987E-03,   1.1283412E-03
     +,   1.1765761E-03,   1.2165129E-03,   1.2494528E-03
     +,   1.2776954E-03,   1.3044465E-03,   1.3335916E-03
     +,   1.3693055E-03,   1.4155119E-03,   1.4752414E-03
     +,   1.5499796E-03,   1.6391888E-03,   1.7402344E-03
     +,   1.8489235E-03,   1.9607306E-03,   2.0726796E-03
     +,   2.1855889E-03,   2.3062585E-03,   2.4490135E-03
     +,   2.6359940E-03,   2.8953436E-03,   3.2563494E-03
     +,   3.7408469E-03,   4.3520569E-03,   5.0657210E-03
     +,   5.8324607E-03,   6.6011464E-03,   7.3626102E-03
     +,   8.1898617E-03,   9.2333723E-03,   1.0647418E-02
     +,   1.2488442E-02,   1.4693853E-02,   1.7162474E-02
     +,   1.9745830E-02,   2.2173353E-02,   2.4334313E-02
     +,   2.7032796E-02,   3.2552775E-02,   4.2081542E-02
     +,   5.3213749E-02,   6.8920836E-02,   8.9359470E-02
     +,   0.1051970    ,   0.1143902    ,   0.1262373    
     +,   0.1276390    ,   0.1166474    ,   0.1119248    
     +,   9.6192308E-02,   7.2626390E-02,   5.3881619E-02
     +,   3.6390301E-02,   2.1704543E-02,   1.1568268E-02
     +,   5.4125534E-03,   2.1555538E-03,   7.1520905E-04
     +,   1.9506057E-04,   4.3550452E-05,   8.0219679E-06
     +,   1.2351771E-06,   1.6274701E-07,   2.1328423E-08
     +,   5.2945577E-09,   3.2272411E-09,   2.5283122E-09
     +,   2.0308808E-09,   1.6317514E-09,   1.3090824E-09
     +,   1.0485460E-09,   8.3854806E-10,   6.6958067E-10
     +,   5.3385152E-10,   4.2499998E-10,   3.3784883E-10
     +,   2.6818534E-10,   2.1258557E-10,   1.6827703E-10
     +,   1.3302114E-10,   1.0501049E-10,   8.2787555E-11
     +,   6.5180937E-11,   5.1252145E-11,   4.0247576E-11
     +,   3.1564897E-11,   2.4723560E-11,   1.9340357E-11
     +,   1.5109905E-11,   1.1789579E-11,   9.1870357E-12
     +,   7.1498124E-12,   5.5570930E-12,   4.3134689E-12
     +,   3.3437508E-12,   2.5885455E-12,   2.0012091E-12
     +,   1.5450047E-12,   1.1911530E-12,   9.1704064E-13
     +,   7.0500729E-13,   5.4120938E-13,   4.1485996E-13
     +,   3.1753167E-13,   2.4267217E-13,   1.8517647E-13
     +,   1.4108242E-13,   1.0731964E-13,   8.1505881E-14
     +,   6.1801536E-14,   4.6783720E-14,   3.5356941E-14
     +,   2.6676202E-14,   2.0092826E-14,   1.5108178E-14
     +,   1.1340599E-14,   8.4976683E-15,   6.3563025E-15
     +,   4.7460772E-15,   3.5374709E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt115 = Yx/0.359857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2041984E-09,   2.6485478E-09
     +,   3.1765133E-09,   3.8025947E-09,   4.5435535E-09
     +,   5.4187361E-09,   6.4504073E-09,   7.6641387E-09
     +,   9.0892014E-09,   1.0759125E-08,   1.2712069E-08
     +,   1.4991445E-08,   1.7646524E-08,   2.0733061E-08
     +,   2.4314014E-08,   2.8460256E-08,   3.3251450E-08
     +,   3.8776786E-08,   4.5136005E-08,   5.2440214E-08
     +,   6.0812980E-08,   7.0391273E-08,   8.1326341E-08
     +,   9.3785765E-08,   1.0795231E-07,   1.2402803E-07
     +,   1.4223279E-07,   1.6280654E-07,   1.8601011E-07
     +,   2.1212604E-07,   2.4145959E-07,   2.7433944E-07
     +,   3.1111836E-07,   3.5217374E-07,   3.9790748E-07
     +,   4.4874747E-07,   5.0514524E-07,   5.6757699E-07
     +,   6.3654608E-07,   7.1257222E-07,   7.9620412E-07
     +,   8.8800607E-07,   9.8856128E-07,   1.0984688E-06
     +,   1.2183401E-06,   1.3487960E-06,   1.4904635E-06
     +,   1.6439697E-06,   1.8099395E-06,   1.9889883E-06
     +,   2.1817184E-06,   2.3887110E-06,   2.6105176E-06
     +,   2.8476718E-06,   3.1006387E-06,   3.3698641E-06
     +,   3.6557244E-06,   3.9585343E-06,   4.2785405E-06
     +,   4.6159093E-06,   4.9707232E-06,   5.3429781E-06
     +,   5.7325456E-06,   6.1392184E-06,   6.5626850E-06
     +,   7.0024676E-06,   7.4580289E-06,   7.9286410E-06
     +,   8.4135190E-06,   8.9116729E-06,   9.4220568E-06
     +,   9.9434264E-06,   1.0474476E-05,   1.1013718E-05
     +,   1.1559589E-05,   1.2110428E-05,   1.2664430E-05
     +,   1.3219709E-05,   1.3774341E-05,   1.4326335E-05
     +,   1.4873606E-05,   1.5414133E-05,   1.5945812E-05
     +,   1.6466638E-05,   1.6974602E-05,   1.7467833E-05
     +,   1.7944536E-05,   1.8403127E-05,   1.8842164E-05
     +,   1.9260509E-05,   1.9657307E-05,   2.0032048E-05
     +,   2.0384621E-05,   2.0715437E-05,   2.1025429E-05
     +,   2.1316144E-05,   2.1589851E-05,   2.1849559E-05
     +,   2.2099162E-05,   2.2343484E-05,   2.2588345E-05
     +,   2.2840641E-05,   2.3108447E-05,   2.3400964E-05
     +,   2.3728659E-05,   2.4103212E-05,   2.4537483E-05
     +,   2.5045467E-05,   2.5642237E-05,   2.6343763E-05
     +,   2.7166700E-05,   2.8128239E-05,   2.9245641E-05
     +,   3.0536143E-05,   3.2016254E-05,   3.3701610E-05
     +,   3.5606176E-05,   3.7742098E-05,   4.0118721E-05
     +,   4.2742504E-05,   4.5616365E-05,   4.8738977E-05
     +,   5.2104551E-05,   5.5702749E-05,   5.9518279E-05
     +,   6.3530453E-05,   6.7714151E-05,   7.2038973E-05
     +,   7.6470737E-05,   8.0970953E-05,   8.5498672E-05
     +,   9.0010202E-05,   9.4461349E-05,   9.8807330E-05
     +,   1.0300497E-04,   1.0701361E-04,   1.1079595E-04
     +,   1.1431969E-04,   1.1755887E-04,   1.2049478E-04
     +,   1.2311654E-04,   1.2542235E-04,   1.2742025E-04
     +,   1.2912850E-04,   1.3057582E-04,   1.3180215E-04
     +,   1.3285856E-04,   1.3380739E-04,   1.3472233E-04
     +,   1.3568850E-04,   1.3680207E-04,   1.3816990E-04
     +,   1.3990878E-04,   1.4214471E-04,   1.4501093E-04
     +,   1.4864573E-04,   1.5318913E-04,   1.5877925E-04
     +,   1.6554714E-04,   1.7360982E-04,   1.8306480E-04
     +,   1.9398205E-04,   2.0639539E-04,   2.2029606E-04
     +,   2.3562698E-04,   2.5227864E-04,   2.7008596E-04
     +,   2.8883191E-04,   3.0825712E-04,   3.2807194E-04
     +,   3.4797643E-04,   3.6769020E-04,   3.8699087E-04
     +,   4.0575818E-04,   4.2402197E-04,   4.4202161E-04
     +,   4.6025269E-04,   4.7950659E-04,   5.0088693E-04
     +,   5.2579242E-04,   5.5585062E-04,   5.9279718E-04
     +,   6.3830591E-04,   6.9378217E-04,   7.6014205E-04
     +,   8.3761738E-04,   9.2564768E-04,   1.0229041E-03
     +,   1.1274652E-03,   1.2371617E-03,   1.3501088E-03
     +,   1.4653096E-03,   1.5832948E-03,   1.7067216E-03
     +,   1.8408807E-03,   1.9940871E-03,   2.1780336E-03
     +,   2.4081317E-03,   2.7037163E-03,   3.0874293E-03
     +,   3.5822866E-03,   4.2042318E-03,   4.9492698E-03
     +,   5.7792766E-03,   6.6173323E-03,   7.3638237E-03
     +,   7.9310238E-03,   8.2790740E-03,   8.4356982E-03
     +,   8.4976843E-03,   8.6206272E-03,   8.9893974E-03
     +,   9.7557204E-03,   1.0963283E-02,   1.2526370E-02
     +,   1.4315524E-02,   1.6282381E-02,   1.8472428E-02
     +,   2.0994056E-02,   2.4065303E-02,   2.7864071E-02
     +,   3.2446656E-02,   3.8536500E-02,   4.7731712E-02
     +,   6.0713798E-02,   7.8968406E-02,   9.7533278E-02
     +,   0.1116544    ,   0.1250886    ,   0.1320210    
     +,   0.1368410    ,   0.1251151    ,   9.3326844E-02
     +,   6.5533258E-02,   4.1604280E-02,   2.2599710E-02
     +,   1.0010906E-02,   3.3311977E-03,   8.1728236E-04
     +,   1.8832175E-04,   8.2541876E-05,   6.5485750E-05
     +,   5.6520956E-05,   4.7476471E-05,   3.8776059E-05
     +,   3.1175277E-05,   2.5073556E-05,   2.0522390E-05
     +,   1.7332526E-05,   1.5199037E-05,   1.3802950E-05
     +,   1.2873569E-05,   1.2211834E-05,   1.1687451E-05
     +,   1.1223678E-05,   1.0779923E-05,   1.0337335E-05
     +,   9.8888513E-06,   9.4332199E-06,   8.9718042E-06
     +,   8.5070324E-06,   8.0416576E-06,   7.5784064E-06
     +,   7.1198838E-06,   6.6685607E-06,   6.2266517E-06
     +,   5.7961443E-06,   5.3788194E-06,   4.9762102E-06
     +,   4.5895890E-06,   4.2199840E-06,   3.8682165E-06
     +,   3.5348842E-06,   3.2203477E-06,   2.9247728E-06
     +,   2.6481705E-06,   2.3903499E-06,   2.1510059E-06
     +,   1.9296710E-06,   1.7257964E-06,   1.5387122E-06
     +,   1.3676971E-06,   1.2119483E-06,   1.0706386E-06
     +,   9.4289453E-07,   8.2784356E-07,   7.2459699E-07
     +,   6.3227509E-07,   5.5002255E-07,   4.7699757E-07
     +,   4.1239844E-07,   3.5545017E-07,   3.0542586E-07
     +,   2.6163372E-07,   2.2343283E-07,   1.9022215E-07
     +,   1.6145101E-07,   1.3660950E-07,   1.1523565E-07
     +,   9.6906589E-08,   8.1242888E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt116 = Yx/0.351020833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.6846047E-06,   5.9081062E-06
     +,   6.1332930E-06,   6.3597822E-06,   6.5871923E-06
     +,   6.8151394E-06,   7.0432420E-06,   7.2711241E-06
     +,   7.4984237E-06,   7.7247914E-06,   7.9498914E-06
     +,   8.1734106E-06,   8.3950572E-06,   8.6145692E-06
     +,   8.8317165E-06,   9.0463000E-06,   9.2581558E-06
     +,   9.4671659E-06,   9.6732510E-06,   9.8763767E-06
     +,   1.0076558E-05,   1.0273855E-05,   1.0468376E-05
     +,   1.0660296E-05,   1.0849815E-05,   1.1037214E-05
     +,   1.1222804E-05,   1.1406962E-05,   1.1590105E-05
     +,   1.1772704E-05,   1.1955275E-05,   1.2138383E-05
     +,   1.2322626E-05,   1.2508649E-05,   1.2697125E-05
     +,   1.2888765E-05,   1.3084299E-05,   1.3284479E-05
     +,   1.3490087E-05,   1.3701893E-05,   1.3920695E-05
     +,   1.4147277E-05,   1.4382426E-05,   1.4626913E-05
     +,   1.4881489E-05,   1.5146893E-05,   1.5423824E-05
     +,   1.5712949E-05,   1.6014899E-05,   1.6330257E-05
     +,   1.6659553E-05,   1.7003265E-05,   1.7361805E-05
     +,   1.7735541E-05,   1.8124736E-05,   1.8529627E-05
     +,   1.8950339E-05,   1.9386942E-05,   1.9839425E-05
     +,   2.0307691E-05,   2.0791571E-05,   2.1290822E-05
     +,   2.1805086E-05,   2.2333976E-05,   2.2877019E-05
     +,   2.3433622E-05,   2.4003199E-05,   2.4585011E-05
     +,   2.5178339E-05,   2.5782330E-05,   2.6396148E-05
     +,   2.7018845E-05,   2.7649503E-05,   2.8287104E-05
     +,   2.8930657E-05,   2.9579154E-05,   3.0231553E-05
     +,   3.0886815E-05,   3.1543950E-05,   3.2202013E-05
     +,   3.2860025E-05,   3.3517143E-05,   3.4172521E-05
     +,   3.4825473E-05,   3.5475328E-05,   3.6121626E-05
     +,   3.6763951E-05,   3.7402115E-05,   3.8036036E-05
     +,   3.8665883E-05,   3.9292023E-05,   3.9915030E-05
     +,   4.0535739E-05,   4.1155272E-05,   4.1775096E-05
     +,   4.2396907E-05,   4.3022814E-05,   4.3655244E-05
     +,   4.4297063E-05,   4.4951434E-05,   4.5622044E-05
     +,   4.6312889E-05,   4.7028534E-05,   4.7773814E-05
     +,   4.8554117E-05,   4.9375260E-05,   5.0243409E-05
     +,   5.1165094E-05,   5.2147338E-05,   5.3197462E-05
     +,   5.4322998E-05,   5.5531840E-05,   5.6831934E-05
     +,   5.8231508E-05,   5.9738613E-05,   6.1361498E-05
     +,   6.3107997E-05,   6.4985943E-05,   6.7002577E-05
     +,   6.9164773E-05,   7.1478855E-05,   7.3950221E-05
     +,   7.6583427E-05,   7.9382080E-05,   8.2348706E-05
     +,   8.5484244E-05,   8.8788613E-05,   9.2259761E-05
     +,   9.5894458E-05,   9.9687270E-05,   1.0363152E-04
     +,   1.0771809E-04,   1.1193660E-04,   1.1627427E-04
     +,   1.2071696E-04,   1.2524887E-04,   1.2985233E-04
     +,   1.3450834E-04,   1.3919716E-04,   1.4389819E-04
     +,   1.4859020E-04,   1.5325211E-04,   1.5786382E-04
     +,   1.6240655E-04,   1.6686341E-04,   1.7122115E-04
     +,   1.7547095E-04,   1.7960950E-04,   1.8364102E-04
     +,   1.8757932E-04,   1.9144996E-04,   1.9529222E-04
     +,   1.9916218E-04,   2.0313606E-04,   2.0731280E-04
     +,   2.1181654E-04,   2.1680011E-04,   2.2244653E-04
     +,   2.2897104E-04,   2.3661976E-04,   2.4566968E-04
     +,   2.5642486E-04,   2.6921000E-04,   2.8436349E-04
     +,   3.0222713E-04,   3.2313357E-04,   3.4738984E-04
     +,   3.7526182E-04,   4.0695918E-04,   4.4261874E-04
     +,   4.8228615E-04,   5.2590575E-04,   5.7331735E-04
     +,   6.2424841E-04,   6.7831192E-04,   7.3502143E-04
     +,   7.9379510E-04,   8.5396337E-04,   9.1478578E-04
     +,   9.7547332E-04,   1.0352037E-03,   1.0931495E-03
     +,   1.1485289E-03,   1.2006743E-03,   1.2491134E-03
     +,   1.2936724E-03,   1.3345865E-03,   1.3725967E-03
     +,   1.4089929E-03,   1.4455830E-03,   1.4845802E-03
     +,   1.5283802E-03,   1.5792646E-03,   1.6391017E-03
     +,   1.7091342E-03,   1.7899801E-03,   1.8819568E-03
     +,   1.9858642E-03,   2.1042225E-03,   2.2427633E-03
     +,   2.4117930E-03,   2.6268014E-03,   2.9074862E-03
     +,   3.2744817E-03,   3.7437261E-03,   4.3200883E-03
     +,   4.9934974E-03,   5.7421550E-03,   6.5452973E-03
     +,   7.4003506E-03,   8.3296625E-03,   9.3618277E-03
     +,   1.0492816E-02,   1.1663121E-02,   1.2789598E-02
     +,   1.3846107E-02,   1.4937123E-02,   1.6304789E-02
     +,   1.8249145E-02,   2.0996254E-02,   2.4536641E-02
     +,   2.8382771E-02,   3.1897429E-02,   3.6176343E-02
     +,   4.4578739E-02,   5.9242070E-02,   7.6491252E-02
     +,   9.2544116E-02,   0.1109559    ,   0.1330427    
     +,   0.1424631    ,   0.1380207    ,   0.1300463    
     +,   0.1067466    ,   6.8488948E-02,   3.3711143E-02
     +,   1.2259576E-02,   3.1719655E-03,   5.6508736E-04
     +,   6.5446606E-05,   4.6888758E-06,   2.0703105E-07
     +,   9.4062438E-09,   3.5766730E-09,   2.9129008E-09
     +,   2.4266409E-09,   2.0229927E-09,   1.6870592E-09
     +,   1.4072011E-09,   1.1738829E-09,   9.7922337E-10
     +,   8.1672297E-10,   6.8101907E-10,   5.6766558E-10
     +,   4.7296606E-10,   3.9384898E-10,   3.2776107E-10
     +,   2.7257191E-10,   2.2650000E-10,   1.8805585E-10
     +,   1.5599609E-10,   1.2927900E-10,   1.0702998E-10
     +,   8.8516375E-11,   7.3125936E-11,   6.0343369E-11
     +,   4.9737246E-11,   4.0946579E-11,   3.3668915E-11
     +,   2.7650540E-11,   2.2679244E-11,   1.8578038E-11
     +,   1.5198910E-11,   1.2418175E-11,   1.0132747E-11
     +,   8.2569880E-12,   6.7194050E-12,   5.4608124E-12
     +,   4.4319223E-12,   3.5920082E-12,   2.9072701E-12
     +,   2.3498486E-12,   1.8966744E-12,   1.5287908E-12
     +,   1.2305496E-12,   9.8912295E-13,   7.9395887E-13
     +,   6.3641101E-13,   5.0941933E-13,   4.0719663E-13
     +,   3.2503462E-13,   2.5908662E-13,   2.0623265E-13
     +,   1.6393004E-13,   1.3012371E-13,   1.0314375E-13
     +,   8.1644333E-14,   6.4535522E-14,   5.0940944E-14
     +,   4.0153641E-14,   3.1606699E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt117 = Yx/0.351020833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5084535E-07,   1.6826127E-07
     +,   1.8744279E-07,   2.0853835E-07,   2.3170553E-07
     +,   2.5711105E-07,   2.8493102E-07,   3.1535077E-07
     +,   3.4856467E-07,   3.8477776E-07,   4.2420359E-07
     +,   4.6706421E-07,   5.1359160E-07,   5.6402592E-07
     +,   6.1861550E-07,   6.7761675E-07,   7.4129326E-07
     +,   8.0991487E-07,   8.8375816E-07,   9.6310362E-07
     +,   1.0482372E-06,   1.1394469E-06,   1.2370222E-06
     +,   1.3412592E-06,   1.4524436E-06,   1.5708697E-06
     +,   1.6968235E-06,   1.8305876E-06,   1.9724396E-06
     +,   2.1226499E-06,   2.2814806E-06,   2.4491842E-06
     +,   2.6260009E-06,   2.8121599E-06,   3.0078763E-06
     +,   3.2133512E-06,   3.4287687E-06,   3.6542954E-06
     +,   3.8900930E-06,   4.1362837E-06,   4.3929963E-06
     +,   4.6603295E-06,   4.9383707E-06,   5.2271903E-06
     +,   5.5268470E-06,   5.8373871E-06,   6.1588503E-06
     +,   6.4912674E-06,   6.8346658E-06,   7.1890745E-06
     +,   7.5545267E-06,   7.9310639E-06,   8.3187324E-06
     +,   8.7176268E-06,   9.1278180E-06,   9.5494479E-06
     +,   9.9826711E-06,   1.0427691E-05,   1.0884746E-05
     +,   1.1354134E-05,   1.1836208E-05,   1.2331378E-05
     +,   1.2840093E-05,   1.3362909E-05,   1.3900438E-05
     +,   1.4453311E-05,   1.5022299E-05,   1.5608157E-05
     +,   1.6211783E-05,   1.6834030E-05,   1.7475893E-05
     +,   1.8138315E-05,   1.8822340E-05,   1.9528943E-05
     +,   2.0259160E-05,   2.1013999E-05,   2.1794383E-05
     +,   2.2601180E-05,   2.3435221E-05,   2.4297233E-05
     +,   2.5187761E-05,   2.6107284E-05,   2.7056027E-05
     +,   2.8034134E-05,   2.9041432E-05,   3.0077646E-05
     +,   3.1142154E-05,   3.2234202E-05,   3.3352659E-05
     +,   3.4496254E-05,   3.5663459E-05,   3.6852420E-05
     +,   3.8061065E-05,   3.9287148E-05,   4.0528263E-05
     +,   4.1781710E-05,   4.3044794E-05,   4.4314576E-05
     +,   4.5588218E-05,   4.6862700E-05,   4.8135236E-05
     +,   4.9402937E-05,   5.0663246E-05,   5.1913652E-05
     +,   5.3152053E-05,   5.4376669E-05,   5.5586075E-05
     +,   5.6779263E-05,   5.7955906E-05,   5.9116224E-05
     +,   6.0261031E-05,   6.1391991E-05,   6.2511448E-05
     +,   6.3622712E-05,   6.4729880E-05,   6.5838147E-05
     +,   6.6953566E-05,   6.8083413E-05,   6.9235844E-05
     +,   7.0420261E-05,   7.1647126E-05,   7.2927920E-05
     +,   7.4275122E-05,   7.5702272E-05,   7.7223820E-05
     +,   7.8854733E-05,   8.0610771E-05,   8.2507882E-05
     +,   8.4562256E-05,   8.6789725E-05,   8.9205845E-05
     +,   9.1825023E-05,   9.4660718E-05,   9.7724391E-05
     +,   1.0102567E-04,   1.0457178E-04,   1.0836690E-04
     +,   1.1241194E-04,   1.1670474E-04,   1.2123949E-04
     +,   1.2600649E-04,   1.3099243E-04,   1.3618090E-04
     +,   1.4155268E-04,   1.4708561E-04,   1.5275663E-04
     +,   1.5854229E-04,   1.6441973E-04,   1.7036898E-04
     +,   1.7637518E-04,   1.8243086E-04,   1.8853853E-04
     +,   1.9471449E-04,   2.0099299E-04,   2.0743078E-04
     +,   2.1411091E-04,   2.2114854E-04,   2.2869655E-04
     +,   2.3694952E-04,   2.4614716E-04,   2.5657800E-04
     +,   2.6857914E-04,   2.8253172E-04,   2.9885562E-04
     +,   3.1799768E-04,   3.4041487E-04,   3.6655003E-04
     +,   3.9680547E-04,   4.3151487E-04,   4.7090961E-04
     +,   5.1508757E-04,   5.6399009E-04,   6.1739498E-04
     +,   6.7491666E-04,   7.3602085E-04,   8.0007809E-04
     +,   8.6641655E-04,   9.3438488E-04,   1.0034296E-03
     +,   1.0731576E-03,   1.1433667E-03,   1.2140397E-03
     +,   1.2853115E-03,   1.3573946E-03,   1.4304782E-03
     +,   1.5046255E-03,   1.5797096E-03,   1.6553914E-03
     +,   1.7311678E-03,   1.8064658E-03,   1.8808205E-03
     +,   1.9540498E-03,   2.0264138E-03,   2.0987696E-03
     +,   2.1726508E-03,   2.2503149E-03,   2.3347819E-03
     +,   2.4299719E-03,   2.5410096E-03,   2.6747030E-03
     +,   2.8400351E-03,   3.0482085E-03,   3.3115998E-03
     +,   3.6409583E-03,   4.0409705E-03,   4.5057004E-03
     +,   5.0164643E-03,   5.5456706E-03,   6.0682143E-03
     +,   6.5774024E-03,   7.0974817E-03,   7.6853768E-03
     +,   8.4205661E-03,   9.3855979E-03,   1.0634515E-02
     +,   1.2151387E-02,   1.3830755E-02,   1.5517072E-02
     +,   1.7088272E-02,   1.8540658E-02,   2.0047532E-02
     +,   2.1909641E-02,   2.4497436E-02,   2.8607730E-02
     +,   3.5388783E-02,   4.4290353E-02,   5.2366301E-02
     +,   5.8826838E-02,   6.7577764E-02,   8.3687849E-02
     +,   0.1042729    ,   0.1253274    ,   0.1417841    
     +,   0.1479103    ,   0.1246563    ,   7.3237799E-02
     +,   2.6716659E-02,   5.3269616E-03,   5.2889716E-04
     +,   2.4955554E-05,   5.4754673E-07,   7.0520478E-09
     +,   1.3298453E-09,   1.0544727E-09,   8.5260005E-10
     +,   6.9006412E-10,   5.5897581E-10,   4.5309828E-10
     +,   3.6746883E-10,   2.9813846E-10,   2.4194560E-10
     +,   1.9636029E-10,   1.5935543E-10,   1.2930096E-10
     +,   1.0488179E-10,   8.5036894E-11,   6.8909406E-11
     +,   5.5804826E-11,   4.5158991E-11,   3.6513671E-11
     +,   2.9496825E-11,   2.3805444E-11,   1.9192353E-11
     +,   1.5456228E-11,   1.2433293E-11,   9.9897304E-12
     +,   8.0165067E-12,   6.4249244E-12,   5.1426940E-12
     +,   4.1109126E-12,   3.2816748E-12,   2.6161081E-12
     +,   2.0826325E-12,   1.6555988E-12,   1.3142324E-12
     +,   1.0417506E-12,   8.2455061E-13,   6.5168032E-13
     +,   5.1428268E-13,   4.0525081E-13,   3.1885128E-13
     +,   2.5049464E-13,   1.9649157E-13,   1.5389652E-13
     +,   1.2034911E-13,   9.3970377E-14,   7.3259927E-14
     +,   5.7024914E-14,   4.4319047E-14,   3.4390124E-14
     +,   2.6644146E-14,   2.0610322E-14,   1.5918011E-14
     +,   1.2274526E-14,   9.4501772E-15,   7.2641690E-15
     +,   5.5750400E-15,   4.2718730E-15,   3.2681631E-15
     +,   2.4962963E-15,   1.9037163E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt118 = Yx/0.3285625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt1188(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6682351E-07,   4.0045660E-07
     +,   4.3671454E-07,   4.7575543E-07,   5.1774288E-07
     +,   5.6284534E-07,   6.1123598E-07,   6.6309195E-07
     +,   7.1859404E-07,   7.7792834E-07,   8.4128192E-07
     +,   9.0884527E-07,   9.8080966E-07,   1.0573684E-06
     +,   1.1387152E-06,   1.2250429E-06,   1.3165435E-06
     +,   1.4134065E-06,   1.5158191E-06,   1.6239632E-06
     +,   1.7380161E-06,   1.8581492E-06,   1.9845247E-06
     +,   2.1173034E-06,   2.2566219E-06,   2.4026215E-06
     +,   2.5554211E-06,   2.7151307E-06,   2.8818422E-06
     +,   3.0556346E-06,   3.2365660E-06,   3.4246777E-06
     +,   3.6199922E-06,   3.8225080E-06,   4.0322034E-06
     +,   4.2490328E-06,   4.4729254E-06,   4.7037829E-06
     +,   4.9414939E-06,   5.1858951E-06,   5.4368229E-06
     +,   5.6940671E-06,   5.9573945E-06,   6.2265467E-06
     +,   6.5012305E-06,   6.7811284E-06,   7.0658948E-06
     +,   7.3551523E-06,   7.6485012E-06,   7.9455112E-06
     +,   8.2457300E-06,   8.5486809E-06,   8.8538618E-06
     +,   9.1607644E-06,   9.4688339E-06,   9.7775328E-06
     +,   1.0086289E-05,   1.0394525E-05,   1.0701655E-05
     +,   1.1007096E-05,   1.1310258E-05,   1.1610559E-05
     +,   1.1907410E-05,   1.2200264E-05,   1.2488581E-05
     +,   1.2771819E-05,   1.3049505E-05,   1.3321159E-05
     +,   1.3586384E-05,   1.3844786E-05,   1.4096065E-05
     +,   1.4339950E-05,   1.4576259E-05,   1.4804863E-05
     +,   1.5025745E-05,   1.5238964E-05,   1.5444675E-05
     +,   1.5643136E-05,   1.5834741E-05,   1.6020003E-05
     +,   1.6199556E-05,   1.6374195E-05,   1.6544845E-05
     +,   1.6712615E-05,   1.6878756E-05,   1.7044711E-05
     +,   1.7212087E-05,   1.7382692E-05,   1.7558501E-05
     +,   1.7741702E-05,   1.7934670E-05,   1.8139963E-05
     +,   1.8360326E-05,   1.8598708E-05,   1.8858236E-05
     +,   1.9142195E-05,   1.9454064E-05,   1.9797440E-05
     +,   2.0176118E-05,   2.0593976E-05,   2.1055077E-05
     +,   2.1563563E-05,   2.2123744E-05,   2.2740009E-05
     +,   2.3416927E-05,   2.4159237E-05,   2.4971845E-05
     +,   2.5859898E-05,   2.6828920E-05,   2.7884884E-05
     +,   2.9034220E-05,   3.0284258E-05,   3.1643100E-05
     +,   3.3120254E-05,   3.4726614E-05,   3.6475227E-05
     +,   3.8381371E-05,   4.0463554E-05,   4.2743744E-05
     +,   4.5248478E-05,   4.8009624E-05,   5.1065086E-05
     +,   5.4459888E-05,   5.8247486E-05,   6.2490675E-05
     +,   6.7261892E-05,   7.2645133E-05,   7.8735102E-05
     +,   8.5638814E-05,   9.3473405E-05,   1.0236678E-04
     +,   1.1245356E-04,   1.2387411E-04,   1.3676766E-04
     +,   1.5126908E-04,   1.6750128E-04,   1.8556573E-04
     +,   2.0553409E-04,   2.2744037E-04,   2.5127002E-04
     +,   2.7694926E-04,   3.0433858E-04,   3.3322981E-04
     +,   3.6334177E-04,   3.9431945E-04,   4.2574594E-04
     +,   4.5715057E-04,   4.8802272E-04,   5.1783409E-04
     +,   5.4606306E-04,   5.7221891E-04,   5.9586414E-04
     +,   6.1664102E-04,   6.3429179E-04,   6.4867112E-04
     +,   6.5975229E-04,   6.6762842E-04,   6.7250349E-04
     +,   6.7467458E-04,   6.7451125E-04,   6.7242759E-04
     +,   6.6885608E-04,   6.6421926E-04,   6.5891049E-04
     +,   6.5327634E-04,   6.4761378E-04,   6.4217683E-04
     +,   6.3719251E-04,   6.3289312E-04,   6.2955299E-04
     +,   6.2753609E-04,   6.2734220E-04,   6.2964705E-04
     +,   6.3533278E-04,   6.4548873E-04,   6.6139165E-04
     +,   6.8443915E-04,   7.1604847E-04,   7.5751857E-04
     +,   8.0987473E-04,   8.7370566E-04,   9.4902475E-04
     +,   1.0351985E-03,   1.1309658E-03,   1.2345585E-03
     +,   1.3439287E-03,   1.4570747E-03,   1.5724165E-03
     +,   1.6891278E-03,   1.8073773E-03,   1.9284741E-03
     +,   2.0548196E-03,   2.1897843E-03,   2.3375042E-03
     +,   2.5026537E-03,   2.6901290E-03,   2.9045132E-03
     +,   3.1492948E-03,   3.4258624E-03,   3.7324643E-03
     +,   4.0635192E-03,   4.4097300E-03,   4.7589494E-03
     +,   5.0977231E-03,   5.4133860E-03,   5.6971051E-03
     +,   5.9478907E-03,   6.1769113E-03,   6.4096879E-03
     +,   6.6827596E-03,   7.0339241E-03,   7.4901320E-03
     +,   8.0614807E-03,   8.7504163E-03,   9.5792981E-03
     +,   1.0627792E-02,   1.2053179E-02,   1.4045846E-02
     +,   1.6688544E-02,   1.9809512E-02,   2.2992108E-02
     +,   2.5695506E-02,   2.7463228E-02,   2.8489808E-02
     +,   2.9945185E-02,   3.2860216E-02,   3.7304979E-02
     +,   4.4334203E-02,   5.6225631E-02,   7.1897060E-02
     +,   8.6409263E-02,   9.9806584E-02,   0.1182064    
     +,   0.1335263    ,   0.1245095    ,   8.1673741E-02
     +,   3.3089496E-02,   7.5310138E-03,   9.0156146E-04
     +,   5.4475095E-05,   1.6242147E-06,   2.3739538E-08
     +,   2.6973607E-10,   8.3916422E-11,   6.7367882E-11
     +,   5.4692868E-11,   4.4564730E-11,   3.6415503E-11
     +,   2.9821756E-11,   2.4463083E-11,   2.0092601E-11
     +,   1.6518202E-11,   1.3588807E-11,   1.1184276E-11
     +,   9.2081030E-12,   7.5824676E-12,   6.2443661E-12
     +,   5.1424555E-12,   4.2347159E-12,   3.4867452E-12
     +,   2.8703717E-12,   2.3624347E-12,   1.9438494E-12
     +,   1.5989159E-12,   1.3147260E-12,   1.0806185E-12
     +,   8.8780274E-13,   7.2904378E-13,   5.9837340E-13
     +,   4.9085378E-13,   4.0241627E-13,   3.2970992E-13
     +,   2.6996604E-13,   2.2089757E-13,   1.8061839E-13
     +,   1.4757581E-13,   1.2048491E-13,   9.8290218E-14
     +,   8.0118129E-14,   6.5251603E-14,   5.3097768E-14
     +,   4.3169956E-14,   3.5066707E-14,   2.8458681E-14
     +,   2.3074275E-14,   1.8691044E-14,   1.5125921E-14
     +,   1.2228854E-14,   9.8770242E-15,   7.9695094E-15
     +,   6.4239847E-15,   5.1728929E-15,   4.1612450E-15
     +,   3.3439764E-15,   2.6844594E-15,   2.1527524E-15
     +,   1.7245698E-15,   1.3800866E-15,   1.1032581E-15
     +,   8.8101427E-16,   7.0279790E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt1188 = Yx/0.3031875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1042694E-08,   1.2864743E-08
     +,   1.4966375E-08,   1.7386897E-08,   2.0170591E-08
     +,   2.3367223E-08,   2.7032627E-08,   3.1229334E-08
     +,   3.6027203E-08,   4.1504411E-08,   4.7747797E-08
     +,   5.4854052E-08,   6.2930440E-08,   7.2095837E-08
     +,   8.2481584E-08,   9.4232831E-08,   1.0750922E-07
     +,   1.2248644E-07,   1.3935716E-07,   1.5833234E-07
     +,   1.7964265E-07,   2.0353941E-07,   2.3029584E-07
     +,   2.6021044E-07,   2.9360325E-07,   3.3082401E-07
     +,   3.7224765E-07,   4.1827838E-07,   4.6935048E-07
     +,   5.2592873E-07,   5.8851032E-07,   6.5762470E-07
     +,   7.3383580E-07,   8.1774044E-07,   9.0997088E-07
     +,   1.0111934E-06,   1.1221091E-06,   1.2434514E-06
     +,   1.3759943E-06,   1.5205309E-06,   1.6778999E-06
     +,   1.8489596E-06,   2.0345994E-06,   2.2357324E-06
     +,   2.4532926E-06,   2.6882333E-06,   2.9415214E-06
     +,   3.2141334E-06,   3.5070516E-06,   3.8212575E-06
     +,   4.1577264E-06,   4.5174220E-06,   4.9012815E-06
     +,   5.3102422E-06,   5.7451662E-06,   6.2069157E-06
     +,   6.6962839E-06,   7.2140087E-06,   7.7607683E-06
     +,   8.3371688E-06,   8.9437299E-06,   9.5809037E-06
     +,   1.0248998E-05,   1.0948270E-05,   1.1678878E-05
     +,   1.2440783E-05,   1.3233935E-05,   1.4058049E-05
     +,   1.4912816E-05,   1.5797687E-05,   1.6712096E-05
     +,   1.7655220E-05,   1.8626226E-05,   1.9624016E-05
     +,   2.0647474E-05,   2.1695336E-05,   2.2766171E-05
     +,   2.3858427E-05,   2.4970506E-05,   2.6100724E-05
     +,   2.7247217E-05,   2.8408158E-05,   2.9581543E-05
     +,   3.0765455E-05,   3.1957807E-05,   3.3156637E-05
     +,   3.4359829E-05,   3.5565459E-05,   3.6771475E-05
     +,   3.7975999E-05,   3.9177245E-05,   4.0373474E-05
     +,   4.1563027E-05,   4.2744523E-05,   4.3916756E-05
     +,   4.5078614E-05,   4.6229430E-05,   4.7368634E-05
     +,   4.8496193E-05,   4.9612252E-05,   5.0717605E-05
     +,   5.1813393E-05,   5.2901451E-05,   5.3984135E-05
     +,   5.5064636E-05,   5.6146935E-05,   5.7235873E-05
     +,   5.8337253E-05,   5.9458074E-05,   6.0606479E-05
     +,   6.1791812E-05,   6.3024861E-05,   6.4317719E-05
     +,   6.5684064E-05,   6.7138877E-05,   6.8698777E-05
     +,   7.0381597E-05,   7.2206654E-05,   7.4194169E-05
     +,   7.6365584E-05,   7.8742938E-05,   8.1348575E-05
     +,   8.4204788E-05,   8.7333567E-05,   9.0756126E-05
     +,   9.4491836E-05,   9.8558659E-05,   1.0297148E-04
     +,   1.0774276E-04,   1.1288087E-04,   1.1839074E-04
     +,   1.2427229E-04,   1.3052160E-04,   1.3712894E-04
     +,   1.4408046E-04,   1.5135751E-04,   1.5893640E-04
     +,   1.6678928E-04,   1.7488521E-04,   1.8319041E-04
     +,   1.9166876E-04,   2.0028297E-04,   2.0899679E-04
     +,   2.1777563E-04,   2.2658725E-04,   2.3540526E-04
     +,   2.4421012E-04,   2.5299072E-04,   2.6174751E-04
     +,   2.7049537E-04,   2.7926613E-04,   2.8811110E-04
     +,   2.9710488E-04,   3.0634904E-04,   3.1597554E-04
     +,   3.2614844E-04,   3.3706732E-04,   3.4897003E-04
     +,   3.6213250E-04,   3.7686562E-04,   3.9351478E-04
     +,   4.1245087E-04,   4.3406041E-04,   4.5873085E-04
     +,   4.8683552E-04,   5.1871297E-04,   5.5464735E-04
     +,   5.9485587E-04,   6.3948857E-04,   6.8864215E-04
     +,   7.4239617E-04,   8.0087973E-04,   8.6437393E-04
     +,   9.3341270E-04,   1.0088870E-03,   1.0921183E-03
     +,   1.1848379E-03,   1.2890357E-03,   1.4066587E-03
     +,   1.5391421E-03,   1.6868134E-03,   1.8482427E-03
     +,   2.0197418E-03,   2.1951559E-03,   2.3660837E-03
     +,   2.5226639E-03,   2.6549345E-03,   2.7546259E-03
     +,   2.8171036E-03,   2.8431523E-03,   2.8402617E-03
     +,   2.8230427E-03,   2.8125728E-03,   2.8345594E-03
     +,   2.9163365E-03,   3.0830032E-03,   3.3530933E-03
     +,   3.7345325E-03,   4.2217355E-03,   4.7945045E-03
     +,   5.4193912E-03,   6.0543166E-03,   6.6569299E-03
     +,   7.1958434E-03,   7.6612886E-03,   8.0696670E-03
     +,   8.4591564E-03,   8.8811088E-03,   9.3937963E-03
     +,   1.0053409E-02,   1.0887389E-02,   1.1854153E-02
     +,   1.2831199E-02,   1.3675138E-02,   1.4338240E-02
     +,   1.4960065E-02,   1.5839793E-02,   1.7261207E-02
     +,   1.9297704E-02,   2.1814518E-02,   2.4646824E-02
     +,   2.7671330E-02,   3.0963996E-02,   3.5137750E-02
     +,   4.0295672E-02,   4.4544719E-02,   4.6427298E-02
     +,   4.7962341E-02,   5.1531844E-02,   5.6659374E-02
     +,   6.5726869E-02,   8.0241695E-02,   9.2666693E-02
     +,   9.6564025E-02,   8.8263385E-02,   6.3809827E-02
     +,   3.1992406E-02,   1.0184687E-02,   1.9733361E-03
     +,   2.2862368E-04,   1.5725916E-05,   6.4038875E-07
     +,   1.6156601E-08,   9.4246089E-10,   6.0959426E-10
     +,   5.0610632E-10,   4.2091713E-10,   3.4968820E-10
     +,   2.9018205E-10,   2.4052377E-10,   1.9912610E-10
     +,   1.6465267E-10,   1.3597892E-10,   1.1215814E-10
     +,   9.2392330E-11,   7.6010961E-11,   6.2452300E-11
     +,   5.1244602E-11,   4.1991990E-11,   3.4363366E-11
     +,   2.8082337E-11,   2.2918010E-11,   1.8677551E-11
     +,   1.5200372E-11,   1.2353293E-11,   1.0025314E-11
     +,   8.1244499E-12,   6.5746067E-12,   5.3128352E-12
     +,   4.2870325E-12,   3.4542748E-12,   2.7792332E-12
     +,   2.2328717E-12,   1.7912932E-12,   1.4349270E-12
     +,   1.1477719E-12,   9.1672123E-13,   7.3110544E-13
     +,   5.8220296E-13,   4.6294132E-13,   3.6755977E-13
     +,   2.9139603E-13,   2.3066756E-13,   1.8232299E-13
     +,   1.4389332E-13,   1.1339431E-13,   8.9225068E-14
     +,   7.0101090E-14,   5.4993428E-14,   4.3076132E-14
     +,   3.3690647E-14,   2.6309926E-14,   2.0515180E-14
     +,   1.5972360E-14,   1.2416701E-14,   9.6378568E-15
     +,   7.4695948E-15,   5.7802812E-15,   4.4662501E-15
     +,   3.4456604E-15,   2.6542493E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt120 = Yx/0.292063829787234
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1557295E-05,   1.1898383E-05
     +,   1.2250000E-05,   1.2612708E-05,   1.2987145E-05
     +,   1.3374013E-05,   1.3774109E-05,   1.4188331E-05
     +,   1.4617671E-05,   1.5063290E-05,   1.5526455E-05
     +,   1.6008611E-05,   1.6511380E-05,   1.7036571E-05
     +,   1.7586226E-05,   1.8162616E-05,   1.8768260E-05
     +,   1.9405965E-05,   2.0078834E-05,   2.0790263E-05
     +,   2.1543996E-05,   2.2344104E-05,   2.3195003E-05
     +,   2.4101513E-05,   2.5068712E-05,   2.6102138E-05
     +,   2.7207612E-05,   2.8391301E-05,   2.9659661E-05
     +,   3.1019430E-05,   3.2477587E-05,   3.4041270E-05
     +,   3.5717763E-05,   3.7514383E-05,   3.9438466E-05
     +,   4.1497227E-05,   4.3697728E-05,   4.6046680E-05
     +,   4.8550621E-05,   5.1215313E-05,   5.4046253E-05
     +,   5.7048113E-05,   6.0224924E-05,   6.3579850E-05
     +,   6.7115179E-05,   7.0832364E-05,   7.4731848E-05
     +,   7.8813246E-05,   8.3075225E-05,   8.7515691E-05
     +,   9.2131835E-05,   9.6920361E-05,   1.0187751E-04
     +,   1.0699975E-04,   1.1228332E-04,   1.1772548E-04
     +,   1.2332421E-04,   1.2907904E-04,   1.3499134E-04
     +,   1.4106504E-04,   1.4730726E-04,   1.5372882E-04
     +,   1.6034457E-04,   1.6717473E-04,   1.7424548E-04
     +,   1.8158836E-04,   1.8924264E-04,   1.9725398E-04
     +,   2.0567655E-04,   2.1457109E-04,   2.2400725E-04
     +,   2.3406070E-04,   2.4481531E-04,   2.5635923E-04
     +,   2.6878633E-04,   2.8219383E-04,   2.9667895E-04
     +,   3.1233809E-04,   3.2926482E-04,   3.4754717E-04
     +,   3.6726307E-04,   3.8848133E-04,   4.1125575E-04
     +,   4.3562750E-04,   4.6161879E-04,   4.8923754E-04
     +,   5.1847141E-04,   5.4929499E-04,   5.8166246E-04
     +,   6.1551697E-04,   6.5078796E-04,   6.8739231E-04
     +,   7.2523666E-04,   7.6422276E-04,   8.0424990E-04
     +,   8.4521325E-04,   8.8702230E-04,   9.2960009E-04
     +,   9.7291585E-04,   1.0169970E-03,   1.0619836E-03
     +,   1.1081656E-03,   1.1560653E-03,   1.2064949E-03
     +,   1.2606541E-03,   1.3201955E-03,   1.3872731E-03
     +,   1.4645619E-03,   1.5552386E-03,   1.6629105E-03
     +,   1.7915237E-03,   1.9453109E-03,   2.1287040E-03
     +,   2.3463410E-03,   2.6029083E-03,   2.9029215E-03
     +,   3.2501095E-03,   3.6467183E-03,   4.0926808E-03
     +,   4.5855348E-03,   5.1213456E-03,   5.6970948E-03
     +,   6.3143065E-03,   6.9828685E-03,   7.7232234E-03
     +,   8.5653607E-03,   9.5446287E-03,   1.0694925E-02
     +,   1.2041804E-02,   1.3594173E-02,   1.5336380E-02
     +,   1.7224438E-02,   1.9193474E-02,   2.1168949E-02
     +,   2.3071006E-02,   2.4817638E-02,   2.6365751E-02
     +,   2.7794993E-02,   2.9319271E-02,   3.1088367E-02
     +,   3.2952700E-02,   3.4663614E-02,   3.6449082E-02
     +,   3.8914092E-02,   4.1888572E-02,   4.4088803E-02
     +,   4.4806954E-02,   4.5104630E-02,   4.6393462E-02
     +,   4.8647206E-02,   5.0760113E-02,   5.2040216E-02
     +,   5.2666422E-02,   5.3065307E-02,   5.3324174E-02
     +,   5.2841857E-02,   5.0673269E-02,   4.6670116E-02
     +,   4.1895129E-02,   3.7693366E-02,   3.4570381E-02
     +,   3.2070618E-02,   2.9598344E-02,   2.7044138E-02
     +,   2.4635579E-02,   2.2538904E-02,   2.0729490E-02
     +,   1.9082507E-02,   1.7477784E-02,   1.5856478E-02
     +,   1.4243171E-02,   1.2730559E-02,   1.1425851E-02
     +,   1.0391342E-02,   9.6174339E-03,   9.0394979E-03
     +,   8.5771848E-03,   8.1667816E-03,   7.7724005E-03
     +,   7.3804012E-03,   6.9889002E-03,   6.6005397E-03
     +,   6.2199528E-03,   5.8535733E-03,   5.5091493E-03
     +,   5.1941569E-03,   4.9136584E-03,   4.6687964E-03
     +,   4.4566114E-03,   4.2711254E-03,   4.1050809E-03
     +,   3.9517800E-03,   3.8063303E-03,   3.6661739E-03
     +,   3.5308397E-03,   3.4012771E-03,   3.2789644E-03
     +,   3.1651144E-03,   3.0600978E-03,   2.9632207E-03
     +,   2.8727900E-03,   2.7863982E-03,   2.7013132E-03
     +,   2.6149251E-03,   2.5251121E-03,   2.4304683E-03
     +,   2.3304289E-03,   2.2252486E-03,   2.1158671E-03
     +,   2.0037107E-03,   1.8904773E-03,   1.7779208E-03
     +,   1.6676728E-03,   1.5611035E-03,   1.4592517E-03
     +,   1.3628146E-03,   1.2721582E-03,   1.1873627E-03
     +,   1.1082907E-03,   1.0346621E-03,   9.6609857E-04
     +,   9.0218312E-04,   8.4249873E-04,   7.8664703E-04
     +,   7.3425903E-04,   6.8500388E-04,   6.3859130E-04
     +,   5.9476693E-04,   5.5330736E-04,   5.1401928E-04
     +,   4.7674013E-04,   4.4133488E-04,   4.0769004E-04
     +,   3.7571602E-04,   3.4534774E-04,   3.1653483E-04
     +,   2.8924260E-04,   2.6344944E-04,   2.3914082E-04
     +,   2.1630499E-04,   1.9493040E-04,   1.7500471E-04
     +,   1.5651033E-04,   1.3942187E-04,   1.2370656E-04
     +,   1.0932464E-04,   9.6228352E-05,   8.4361840E-05
     +,   7.3663090E-05,   6.4066029E-05,   5.5499655E-05
     +,   4.7890688E-05,   4.1165222E-05,   3.5249366E-05
     +,   3.0070036E-05,   2.5556421E-05,   2.1640975E-05
     +,   1.8259680E-05,   1.5352311E-05,   1.2863033E-05
     +,   1.0740702E-05,   8.9386631E-06,   7.4146178E-06
     +,   6.1306559E-06,   5.0531266E-06,   4.1521553E-06
     +,   3.4015054E-06,   2.7783169E-06,   2.2627339E-06
     +,   1.8375844E-06,   1.4881358E-06,   1.2018306E-06
     +,   9.6799101E-07,   7.7757187E-07,   6.2296374E-07
     +,   4.9780158E-07,   3.9675686E-07,   3.1541381E-07
     +,   2.5010524E-07,   1.9781488E-07,   1.5605616E-07
     +,   1.2279786E-07,   9.6377384E-08,   7.5445065E-08
     +,   5.8903240E-08,   4.5866116E-08,   3.5617951E-08
     +,   2.7583429E-08,   2.1301791E-08,   1.6403760E-08
     +,   1.2595477E-08,   9.6426884E-09,   7.3599762E-09
     +,   5.6003735E-09,   4.2481725E-09,   3.2121663E-09
     +,   2.4209579E-09,   1.8186010E-09,   1.3615444E-09
     +,   1.0158709E-09,   7.5533985E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt75 = Yx/0.41398
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.4144052E-06,   1.0094039E-05
     +,   1.0809683E-05,   1.1562243E-05,   1.2352583E-05
     +,   1.3181532E-05,   1.4049850E-05,   1.4958260E-05
     +,   1.5907404E-05,   1.6897919E-05,   1.7930322E-05
     +,   1.9005092E-05,   2.0122632E-05,   2.1283284E-05
     +,   2.2487302E-05,   2.3734878E-05,   2.5026133E-05
     +,   2.6361089E-05,   2.7739727E-05,   2.9161907E-05
     +,   3.0627441E-05,   3.2136046E-05,   3.3687345E-05
     +,   3.5280988E-05,   3.6916346E-05,   3.8592927E-05
     +,   4.0310064E-05,   4.2067029E-05,   4.3863038E-05
     +,   4.5697274E-05,   4.7568828E-05,   4.9476803E-05
     +,   5.1420229E-05,   5.3398129E-05,   5.5409513E-05
     +,   5.7453402E-05,   5.9528815E-05,   6.1634812E-05
     +,   6.3770618E-05,   6.5935259E-05,   6.8128160E-05
     +,   7.0348651E-05,   7.2596311E-05,   7.4870797E-05
     +,   7.7172015E-05,   7.9500067E-05,   8.1855207E-05
     +,   8.4238083E-05,   8.6649452E-05,   8.9090485E-05
     +,   9.1562579E-05,   9.4067495E-05,   9.6607168E-05
     +,   9.9184108E-05,   1.0180076E-04,   1.0446018E-04
     +,   1.0716550E-04,   1.0992018E-04,   1.1272773E-04
     +,   1.1559197E-04,   1.1851673E-04,   1.2150595E-04
     +,   1.2456351E-04,   1.2769330E-04,   1.3089934E-04
     +,   1.3418515E-04,   1.3755469E-04,   1.4101154E-04
     +,   1.4455963E-04,   1.4820285E-04,   1.5194586E-04
     +,   1.5579371E-04,   1.5975272E-04,   1.6383063E-04
     +,   1.6803748E-04,   1.7238602E-04,   1.7689257E-04
     +,   1.8157779E-04,   1.8646815E-04,   1.9159690E-04
     +,   1.9700447E-04,   2.0274120E-04,   2.0886691E-04
     +,   2.1545375E-04,   2.2258548E-04,   2.3036030E-04
     +,   2.3888980E-04,   2.4830128E-04,   2.5873590E-04
     +,   2.7035060E-04,   2.8331703E-04,   2.9781976E-04
     +,   3.1405658E-04,   3.3223815E-04,   3.5258569E-04
     +,   3.7532789E-04,   4.0070346E-04,   4.2895167E-04
     +,   4.6031675E-04,   4.9503439E-04,   5.3333410E-04
     +,   5.7541981E-04,   6.2146969E-04,   6.7161227E-04
     +,   7.2592148E-04,   7.8439974E-04,   8.4696128E-04
     +,   9.1342925E-04,   9.8354346E-04,   1.0569697E-03
     +,   1.1333165E-03,   1.2121944E-03,   1.2932454E-03
     +,   1.3762271E-03,   1.4610428E-03,   1.5478196E-03
     +,   1.6369077E-03,   1.7289035E-03,   1.8245932E-03
     +,   1.9249115E-03,   2.0308818E-03,   2.1435970E-03
     +,   2.2643420E-03,   2.3948608E-03,   2.5378019E-03
     +,   2.6972394E-03,   2.8791542E-03,   3.0915085E-03
     +,   3.3439116E-03,   3.6467223E-03,   4.0102368E-03
     +,   4.4442555E-03,   4.9585914E-03,   5.5635232E-03
     +,   6.2693069E-03,   7.0844782E-03,   8.0167353E-03
     +,   9.0824449E-03,   1.0324552E-02,   1.1823426E-02
     +,   1.3676529E-02,   1.5940145E-02,   1.8566951E-02
     +,   2.1401688E-02,   2.4277428E-02,   2.7176904E-02
     +,   3.0297238E-02,   3.3868544E-02,   3.7887275E-02
     +,   4.2071886E-02,   4.6130370E-02,   5.0282005E-02
     +,   5.5057272E-02,   6.0249072E-02,   6.5376282E-02
     +,   7.0303679E-02,   7.3879309E-02,   7.4462906E-02
     +,   7.2409749E-02,   6.9866404E-02,   6.8244711E-02
     +,   6.6981047E-02,   6.5226324E-02,   6.2818162E-02
     +,   5.9285332E-02,   5.4445174E-02,   4.9451437E-02
     +,   4.5400366E-02,   4.1929930E-02,   3.8124505E-02
     +,   3.3671048E-02,   2.9000023E-02,   2.4820864E-02
     +,   2.1555835E-02,   1.9161263E-02,   1.7333886E-02
     +,   1.5783142E-02,   1.4366799E-02,   1.3072077E-02
     +,   1.1934830E-02,   1.0981326E-02,   1.0209696E-02
     +,   9.5934998E-03,   9.0917544E-03,   8.6586801E-03
     +,   8.2516838E-03,   7.8379437E-03,   7.3990026E-03
     +,   6.9322521E-03,   6.4484323E-03,   5.9662401E-03
     +,   5.5063567E-03,   5.0864867E-03,   4.7183018E-03
     +,   4.4064620E-03,   4.1493517E-03,   3.9407574E-03
     +,   3.7719216E-03,   3.6333618E-03,   3.5162531E-03
     +,   3.4132085E-03,   3.3184967E-03,   3.2279307E-03
     +,   3.1385806E-03,   3.0484269E-03,   2.9560800E-03
     +,   2.8605908E-03,   2.7613621E-03,   2.6581311E-03
     +,   2.5509540E-03,   2.4402170E-03,   2.3266089E-03
     +,   2.2110466E-03,   2.0945740E-03,   1.9782572E-03
     +,   1.8630881E-03,   1.7499054E-03,   1.6393421E-03
     +,   1.5318301E-03,   1.4276385E-03,   1.3268981E-03
     +,   1.2296727E-03,   1.1360132E-03,   1.0459910E-03
     +,   9.5971167E-04,   8.7732839E-04,   7.9903187E-04
     +,   7.2502624E-04,   6.5549801E-04,   5.9059873E-04
     +,   5.3042808E-04,   4.7501721E-04,   4.2432031E-04
     +,   3.7822043E-04,   3.3654060E-04,   2.9904686E-04
     +,   2.6546622E-04,   2.3550293E-04,   2.0884836E-04
     +,   1.8519115E-04,   1.6422870E-04,   1.4567492E-04
     +,   1.2926343E-04,   1.1474884E-04,   1.0190960E-04
     +,   9.0548281E-05,   8.0489423E-05,   7.1577371E-05
     +,   6.3675434E-05,   5.6664223E-05,   5.0438448E-05
     +,   4.4905864E-05,   3.9985949E-05,   3.5607962E-05
     +,   3.1709522E-05,   2.8235820E-05,   2.5138881E-05
     +,   2.2376429E-05,   1.9911075E-05,   1.7709883E-05
     +,   1.5743963E-05,   1.3987800E-05,   1.2418764E-05
     +,   1.1016864E-05,   9.7645279E-06,   8.6460568E-06
     +,   7.6475108E-06,   6.7565506E-06,   5.9621530E-06
     +,   5.2544137E-06,   4.6244600E-06,   4.0643645E-06
     +,   3.5669855E-06,   3.1258505E-06,   2.7351257E-06
     +,   2.3895727E-06,   2.0844107E-06,   1.8153579E-06
     +,   1.5785073E-06,   1.3703602E-06,   1.1877314E-06
     +,   1.0277729E-06,   8.8789932E-07,   7.6580602E-07
     +,   6.5940827E-07,   5.6685388E-07,   4.8647712E-07
     +,   4.1679402E-07,   3.5648992E-07,   3.0438915E-07
     +,   2.5945664E-07,   2.2077111E-07,   1.8752448E-07
     +,   1.5900045E-07,   1.3457318E-07,   1.1369047E-07
     +,   9.5871350E-08,   8.0693297E-08,   6.7789678E-08
     +,   5.6839539E-08,   4.7565507E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt80 = Yx/0.4627
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1141610E-06,   9.6090844E-06
     +,   1.0124920E-05,   1.0662055E-05,   1.1220844E-05
     +,   1.1801607E-05,   1.2404627E-05,   1.3030151E-05
     +,   1.3678371E-05,   1.4349473E-05,   1.5043564E-05
     +,   1.5760723E-05,   1.6500975E-05,   1.7264316E-05
     +,   1.8050681E-05,   1.8859970E-05,   1.9692043E-05
     +,   2.0546715E-05,   2.1423763E-05,   2.2322942E-05
     +,   2.3243956E-05,   2.4186516E-05,   2.5150270E-05
     +,   2.6134923E-05,   2.7140064E-05,   2.8165396E-05
     +,   2.9210576E-05,   3.0275269E-05,   3.1359195E-05
     +,   3.2462089E-05,   3.3583747E-05,   3.4724006E-05
     +,   3.5882782E-05,   3.7060061E-05,   3.8255919E-05
     +,   3.9470531E-05,   4.0704170E-05,   4.1957235E-05
     +,   4.3230277E-05,   4.4523895E-05,   4.5838948E-05
     +,   4.7176341E-05,   4.8537200E-05,   4.9922750E-05
     +,   5.1334420E-05,   5.2773779E-05,   5.4242566E-05
     +,   5.5742661E-05,   5.7276131E-05,   5.8845173E-05
     +,   6.0452152E-05,   6.2099571E-05,   6.3790052E-05
     +,   6.5526503E-05,   6.7311717E-05,   6.9148860E-05
     +,   7.1041140E-05,   7.2991963E-05,   7.5004871E-05
     +,   7.7083554E-05,   7.9231970E-05,   8.1454236E-05
     +,   8.3754705E-05,   8.6138025E-05,   8.8609275E-05
     +,   9.1173621E-05,   9.3836905E-05,   9.6605079E-05
     +,   9.9484918E-05,   1.0248333E-04,   1.0560801E-04
     +,   1.0886691E-04,   1.1226894E-04,   1.1582301E-04
     +,   1.1953898E-04,   1.2342715E-04,   1.2749808E-04
     +,   1.3176275E-04,   1.3623277E-04,   1.4092021E-04
     +,   1.4583698E-04,   1.5099633E-04,   1.5641112E-04
     +,   1.6209604E-04,   1.6806611E-04,   1.7433886E-04
     +,   1.8093329E-04,   1.8787276E-04,   1.9518414E-04
     +,   2.0290067E-04,   2.1106319E-04,   2.1972126E-04
     +,   2.2893593E-04,   2.3878162E-04,   2.4934817E-04
     +,   2.6074098E-04,   2.7308447E-04,   2.8651953E-04
     +,   3.0120471E-04,   3.1731138E-04,   3.3502182E-04
     +,   3.5451970E-04,   3.7598549E-04,   3.9958008E-04
     +,   4.2543843E-04,   4.5365276E-04,   4.8425715E-04
     +,   5.1721535E-04,   5.5241154E-04,   5.8964198E-04
     +,   6.2860752E-04,   6.6892849E-04,   7.1014802E-04
     +,   7.5176574E-04,   7.9326244E-04,   8.3415437E-04
     +,   8.7403855E-04,   9.1266306E-04,   9.4998104E-04
     +,   9.8621729E-04,   1.0219141E-03,   1.0579535E-03
     +,   1.0955516E-03,   1.1362153E-03,   1.1816473E-03
     +,   1.2336064E-03,   1.2937565E-03,   1.3634900E-03
     +,   1.4438351E-03,   1.5354221E-03,   1.6386606E-03
     +,   1.7540628E-03,   1.8828098E-03,   2.0273323E-03
     +,   2.1918360E-03,   2.3823658E-03,   2.6062466E-03
     +,   2.8709471E-03,   3.1828429E-03,   3.5468170E-03
     +,   3.9675757E-03,   4.4528716E-03,   5.0171139E-03
     +,   5.6825979E-03,   6.4759869E-03,   7.4206311E-03
     +,   8.5292244E-03,   9.8061059E-03,   1.1266692E-02
     +,   1.2965419E-02,   1.4997151E-02,   1.7437687E-02
     +,   2.0247960E-02,   2.3238279E-02,   2.6161563E-02
     +,   2.8927825E-02,   3.1903941E-02,   3.5934202E-02
     +,   4.1516412E-02,   4.8012104E-02,   5.4377772E-02
     +,   6.0143728E-02,   6.5460257E-02,   7.0804380E-02
     +,   7.6286517E-02,   8.1207208E-02,   8.3754994E-02
     +,   8.2686312E-02,   7.9209514E-02,   7.4314557E-02
     +,   6.8461090E-02,   6.3063338E-02,   5.9401546E-02
     +,   5.6566663E-02,   5.2094083E-02,   4.5625053E-02
     +,   3.8975853E-02,   3.3448271E-02,   2.9143114E-02
     +,   2.5642149E-02,   2.2628257E-02,   2.0137634E-02
     +,   1.8310102E-02,   1.7058577E-02,   1.6090563E-02
     +,   1.5146887E-02,   1.4140116E-02,   1.3115959E-02
     +,   1.2153530E-02,   1.1304193E-02,   1.0581971E-02
     +,   9.9769225E-03,   9.4675003E-03,   9.0258289E-03
     +,   8.6207250E-03,   8.2224524E-03,   7.8086606E-03
     +,   7.3687322E-03,   6.9045825E-03,   6.4283437E-03
     +,   5.9581101E-03,   5.5129454E-03,   5.1083765E-03
     +,   4.7532925E-03,   4.4488418E-03,   4.1891444E-03
     +,   3.9636162E-03,   3.7598722E-03,   3.5664455E-03
     +,   3.3747528E-03,   3.1800992E-03,   2.9816574E-03
     +,   2.7816794E-03,   2.5842665E-03,   2.3940611E-03
     +,   2.2151708E-03,   2.0504252E-03,   1.9010833E-03
     +,   1.7669221E-03,   1.6465811E-03,   1.5379818E-03
     +,   1.4387798E-03,   1.3467199E-03,   1.2598707E-03
     +,   1.1767435E-03,   1.0963212E-03,   1.0180318E-03
     +,   9.4166398E-04,   8.6727465E-04,   7.9510367E-04
     +,   7.2549871E-04,   6.5884541E-04,   5.9551181E-04
     +,   5.3581799E-04,   4.8001859E-04,   4.2827780E-04
     +,   3.8067278E-04,   3.3719913E-04,   2.9777508E-04
     +,   2.6225034E-04,   2.3042230E-04,   2.0205238E-04
     +,   1.7687585E-04,   1.5461369E-04,   1.3498540E-04
     +,   1.1771869E-04,   1.0255477E-04,   8.9251938E-05
     +,   7.7590048E-05,   6.7372159E-05,   5.8422345E-05
     +,   5.0585841E-05,   4.3727763E-05,   3.7730344E-05
     +,   3.2490552E-05,   2.7918486E-05,   2.3935643E-05
     +,   2.0472886E-05,   1.7468812E-05,   1.4868957E-05
     +,   1.2624914E-05,   1.0693391E-05,   9.0355334E-06
     +,   7.6166234E-06,   6.4057917E-06,   5.3754206E-06
     +,   4.5010102E-06,   3.7609677E-06,   3.1362738E-06
     +,   2.6102250E-06,   2.1682665E-06,   1.7977952E-06
     +,   1.4879130E-06,   1.2292230E-06,   1.0136785E-06
     +,   8.3442796E-07,   6.8561894E-07,   5.6230800E-07
     +,   4.6029788E-07,   3.7606193E-07,   3.0662162E-07
     +,   2.4948488E-07,   2.0255577E-07,   1.6408694E-07
     +,   1.3261379E-07,   1.0691940E-07,   8.5987395E-08
     +,   6.8973364E-08,   5.5177612E-08,   4.4018428E-08
     +,   3.5015898E-08,   2.7772300E-08,   2.1960679E-08
     +,   1.7311200E-08,   1.3602883E-08,   1.0654182E-08
     +,   8.3171328E-09,   6.4707955E-09,   5.0171334E-09
     +,   3.8764734E-09,   2.9846139E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt85 = Yx/0.4557
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.5746586E-06,   5.8756796E-06
     +,   6.1890601E-06,   6.5150848E-06,   6.8540376E-06
     +,   7.2062062E-06,   7.5718781E-06,   7.9513466E-06
     +,   8.3449086E-06,   8.7528906E-06,   9.1756147E-06
     +,   9.6134327E-06,   1.0066721E-05,   1.0535895E-05
     +,   1.1021410E-05,   1.1523770E-05,   1.2043548E-05
     +,   1.2581389E-05,   1.3138027E-05,   1.3714302E-05
     +,   1.4311175E-05,   1.4929747E-05,   1.5571270E-05
     +,   1.6237218E-05,   1.6929207E-05,   1.7649149E-05
     +,   1.8399171E-05,   1.9181709E-05,   1.9999505E-05
     +,   2.0855647E-05,   2.1753596E-05,   2.2697213E-05
     +,   2.3690782E-05,   2.4739053E-05,   2.5847228E-05
     +,   2.7021009E-05,   2.8266615E-05,   2.9590725E-05
     +,   3.1000625E-05,   3.2503951E-05,   3.4108947E-05
     +,   3.5824218E-05,   3.7658803E-05,   3.9622046E-05
     +,   4.1723575E-05,   4.3973196E-05,   4.6380759E-05
     +,   4.8956092E-05,   5.1708808E-05,   5.4648179E-05
     +,   5.7783003E-05,   6.1121362E-05,   6.4670443E-05
     +,   6.8436595E-05,   7.2424475E-05,   7.6637756E-05
     +,   8.1078200E-05,   8.5745829E-05,   9.0638641E-05
     +,   9.5752548E-05,   1.0108120E-04,   1.0661597E-04
     +,   1.1234542E-04,   1.1825623E-04,   1.2433255E-04
     +,   1.3055572E-04,   1.3690547E-04,   1.4335872E-04
     +,   1.4989130E-04,   1.5647645E-04,   1.6308692E-04
     +,   1.6969358E-04,   1.7626732E-04,   1.8277783E-04
     +,   1.8919558E-04,   1.9549142E-04,   2.0163668E-04
     +,   2.0760395E-04,   2.1336816E-04,   2.1890599E-04
     +,   2.2419644E-04,   2.2922183E-04,   2.3396725E-04
     +,   2.3842187E-04,   2.4257797E-04,   2.4643281E-04
     +,   2.4998715E-04,   2.5324678E-04,   2.5622183E-04
     +,   2.5892732E-04,   2.6138348E-04,   2.6361510E-04
     +,   2.6565223E-04,   2.6752969E-04,   2.6928796E-04
     +,   2.7097177E-04,   2.7263133E-04,   2.7432121E-04
     +,   2.7610079E-04,   2.7803375E-04,   2.8018811E-04
     +,   2.8263495E-04,   2.8544973E-04,   2.8871020E-04
     +,   2.9249708E-04,   2.9689368E-04,   3.0198460E-04
     +,   3.0785648E-04,   3.1459762E-04,   3.2229812E-04
     +,   3.3104929E-04,   3.4094535E-04,   3.5208257E-04
     +,   3.6456290E-04,   3.7849130E-04,   3.9398202E-04
     +,   4.1115613E-04,   4.3014772E-04,   4.5110227E-04
     +,   4.7418283E-04,   4.9957191E-04,   5.2747049E-04
     +,   5.5810355E-04,   5.9172354E-04,   6.2861072E-04
     +,   6.6906866E-04,   7.1343704E-04,   7.6207315E-04
     +,   8.1536453E-04,   8.7370246E-04,   9.3748508E-04
     +,   1.0070759E-03,   1.0827896E-03,   1.1648368E-03
     +,   1.2532866E-03,   1.3480175E-03,   1.4486655E-03
     +,   1.5546134E-03,   1.6650244E-03,   1.7789328E-03
     +,   1.8954291E-03,   2.0139769E-03,   2.1348642E-03
     +,   2.2597630E-03,   2.3923516E-03,   2.5389565E-03
     +,   2.7088795E-03,   2.9141137E-03,   3.1679689E-03
     +,   3.4822726E-03,   3.8633735E-03,   4.3084323E-03
     +,   4.8051854E-03,   5.3391904E-03,   5.9112934E-03
     +,   6.5624444E-03,   7.3924377E-03,   8.5483305E-03
     +,   1.0162329E-02,   1.2255193E-02,   1.4688967E-02
     +,   1.7289849E-02,   2.0154079E-02,   2.3825226E-02
     +,   2.8832069E-02,   3.4811176E-02,   4.0695965E-02
     +,   4.6251483E-02,   5.2253053E-02,   5.9356302E-02
     +,   6.8087891E-02,   7.7572823E-02,   8.5414022E-02
     +,   9.0553023E-02,   9.4025098E-02,   9.7248212E-02
     +,   9.8348424E-02,   9.3075410E-02,   8.2184054E-02
     +,   7.2085366E-02,   6.5628499E-02,   6.0238991E-02
     +,   5.3695552E-02,   4.5973402E-02,   3.9010622E-02
     +,   3.4287002E-02,   3.1205012E-02,   2.8558031E-02
     +,   2.5837706E-02,   2.3123616E-02,   2.0630173E-02
     +,   1.8503979E-02,   1.6791269E-02,   1.5427477E-02
     +,   1.4264959E-02,   1.3161958E-02,   1.2059784E-02
     +,   1.0984173E-02,   9.9927885E-03,   9.1260932E-03
     +,   8.3905915E-03,   7.7679139E-03,   7.2315442E-03
     +,   6.7587639E-03,   6.3349577E-03,   5.9526418E-03
     +,   5.6087319E-03,   5.3017857E-03,   5.0300048E-03
     +,   4.7902102E-03,   4.5776088E-03,   4.3861466E-03
     +,   4.2091105E-03,   4.0398887E-03,   3.8727387E-03
     +,   3.7033733E-03,   3.5293063E-03,   3.3498381E-03
     +,   3.1657552E-03,   2.9788136E-03,   2.7910920E-03
     +,   2.6045048E-03,   2.4204785E-03,   2.2398653E-03
     +,   2.0630490E-03,   1.8901945E-03,   1.7215076E-03
     +,   1.5574173E-03,   1.3986499E-03,   1.2462165E-03
     +,   1.1013197E-03,   9.6518762E-04,   8.3891116E-04
     +,   7.2332902E-04,   6.1895594E-04,   5.2593159E-04
     +,   4.4404768E-04,   3.7280336E-04,   3.1146689E-04
     +,   2.5914903E-04,   2.1488148E-04,   1.7768171E-04
     +,   1.4659690E-04,   1.2073670E-04,   9.9296572E-05
     +,   8.1567749E-05,   6.6935907E-05,   5.4876000E-05
     +,   4.4945355E-05,   3.6774578E-05,   3.0055551E-05
     +,   2.4533294E-05,   1.9997438E-05,   1.6274367E-05
     +,   1.3220710E-05,   1.0718350E-05,   8.6701266E-06
     +,   6.9958928E-06,   5.6294557E-06,   4.5162528E-06
     +,   3.6113202E-06,   2.8775175E-06,   2.2841164E-06
     +,   1.8057335E-06,   1.4214339E-06,   1.1138724E-06
     +,   8.6872944E-07,   6.7420598E-07,   5.2057868E-07
     +,   3.9984548E-07,   3.0545286E-07,   2.3205452E-07
     +,   1.7530120E-07,   1.3166844E-07,   9.8319326E-08
     +,   7.2984683E-08,   5.3854677E-08,   3.9500069E-08
     +,   2.8795533E-08,   2.0863897E-08,   1.5023950E-08
     +,   1.0751936E-08,   7.6468254E-09,   5.4046478E-09
     +,   3.7960022E-09,   2.6494757E-09,   1.8376229E-09
     +,   1.2664982E-09,   8.6738006E-10,   5.9027633E-10
     +,   3.9916206E-10,   2.6821090E-10,   1.7907907E-10
     +,   1.1880651E-10,   7.8319788E-11,   5.1300849E-11
     +,   3.3389409E-11,   2.1592885E-11,   1.3875243E-11
     +,   8.8589830E-12,   5.6202044E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt90 = Yx/0.46788
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.2079371E-07,   7.7207090E-07
     +,   8.2639701E-07,   8.8391965E-07,   9.4479202E-07
     +,   1.0091765E-06,   1.0772436E-06,   1.1491729E-06
     +,   1.2251543E-06,   1.3053925E-06,   1.3901019E-06
     +,   1.4795131E-06,   1.5738724E-06,   1.6734452E-06
     +,   1.7785161E-06,   1.8893918E-06,   2.0064051E-06
     +,   2.1299143E-06,   2.2603078E-06,   2.3980074E-06
     +,   2.5434692E-06,   2.6971873E-06,   2.8596962E-06
     +,   3.0315846E-06,   3.2134697E-06,   3.4060399E-06
     +,   3.6100255E-06,   3.8262169E-06,   4.0554660E-06
     +,   4.2986817E-06,   4.5568440E-06,   4.8309962E-06
     +,   5.1222487E-06,   5.4317843E-06,   5.7608536E-06
     +,   6.1107803E-06,   6.4829565E-06,   6.8788372E-06
     +,   7.2999751E-06,   7.7479399E-06,   8.2244142E-06
     +,   8.7311191E-06,   9.2698374E-06,   9.8424152E-06
     +,   1.0450750E-05,   1.1096791E-05,   1.1782543E-05
     +,   1.2510060E-05,   1.3281440E-05,   1.4098842E-05
     +,   1.4964469E-05,   1.5880592E-05,   1.6849517E-05
     +,   1.7873701E-05,   1.8955561E-05,   2.0097725E-05
     +,   2.1302863E-05,   2.2573791E-05,   2.3913448E-05
     +,   2.5324958E-05,   2.6811616E-05,   2.8376935E-05
     +,   3.0024532E-05,   3.1758405E-05,   3.3582783E-05
     +,   3.5501969E-05,   3.7520749E-05,   3.9643921E-05
     +,   4.1876727E-05,   4.4224358E-05,   4.6692468E-05
     +,   4.9286449E-05,   5.2012136E-05,   5.4874894E-05
     +,   5.7880290E-05,   6.1033632E-05,   6.4339671E-05
     +,   6.7802648E-05,   7.1426402E-05,   7.5213968E-05
     +,   7.9167185E-05,   8.3287210E-05,   8.7573462E-05
     +,   9.2024631E-05,   9.6637297E-05,   1.0140710E-04
     +,   1.0632737E-04,   1.1139044E-04,   1.1658636E-04
     +,   1.2190391E-04,   1.2733050E-04,   1.3285165E-04
     +,   1.3845183E-04,   1.4411481E-04,   1.4982377E-04
     +,   1.5556131E-04,   1.6131077E-04,   1.6705556E-04
     +,   1.7278106E-04,   1.7847377E-04,   1.8412342E-04
     +,   1.8972195E-04,   1.9526589E-04,   2.0075518E-04
     +,   2.0619530E-04,   2.1159707E-04,   2.1697662E-04
     +,   2.2235651E-04,   2.2776591E-04,   2.3324056E-04
     +,   2.3882235E-04,   2.4456065E-04,   2.5051020E-04
     +,   2.5673304E-04,   2.6329682E-04,   2.7027586E-04
     +,   2.7774950E-04,   2.8580442E-04,   2.9453207E-04
     +,   3.0403154E-04,   3.1440853E-04,   3.2577556E-04
     +,   3.3825263E-04,   3.5196845E-04,   3.6706001E-04
     +,   3.8367012E-04,   4.0194998E-04,   4.2205353E-04
     +,   4.4413889E-04,   4.6835924E-04,   4.9486430E-04
     +,   5.2378647E-04,   5.5524352E-04,   5.8932154E-04
     +,   6.2607729E-04,   6.6553190E-04,   7.0766319E-04
     +,   7.5241481E-04,   7.9970353E-04,   8.4943755E-04
     +,   9.0153422E-04,   9.5596595E-04,   1.0128102E-03
     +,   1.0723145E-03,   1.1349706E-03,   1.2016209E-03
     +,   1.2735657E-03,   1.3526933E-03,   1.4416564E-03
     +,   1.5440970E-03,   1.6649100E-03,   1.8104614E-03
     +,   1.9886307E-03,   2.2083842E-03,   2.4785898E-03
     +,   2.8059855E-03,   3.1927188E-03,   3.6343599E-03
     +,   4.1193925E-03,   4.6308050E-03,   5.1495004E-03
     +,   5.6581306E-03,   6.1452426E-03,   6.6115088E-03
     +,   7.0796991E-03,   7.6046721E-03,   8.2704695E-03
     +,   9.1627548E-03,   1.0330930E-02,   1.1790497E-02
     +,   1.3597841E-02,   1.5930688E-02,   1.9034885E-02
     +,   2.2982756E-02,   2.7478702E-02,   3.2245759E-02
     +,   3.7808008E-02,   4.5165472E-02,   5.4190379E-02
     +,   6.2990785E-02,   6.9909766E-02,   7.5510211E-02
     +,   8.1152245E-02,   8.6990602E-02,   9.0897061E-02
     +,   9.1802180E-02,   9.1090582E-02,   8.6896114E-02
     +,   7.9360537E-02,   7.2129220E-02,   6.5382071E-02
     +,   5.7666879E-02,   4.9734443E-02,   4.2764504E-02
     +,   3.7155356E-02,   3.2881033E-02,   2.9329589E-02
     +,   2.6034378E-02,   2.3040025E-02,   2.0474859E-02
     +,   1.8292168E-02,   1.6374411E-02,   1.4659704E-02
     +,   1.3160589E-02,   1.1916396E-02,   1.0940619E-02
     +,   1.0213861E-02,   9.7051095E-03,   9.3743121E-03
     +,   9.1567636E-03,   8.9620985E-03,   8.6996490E-03
     +,   8.3114579E-03,   7.7895545E-03,   7.1701156E-03
     +,   6.5121786E-03,   5.8739115E-03,   5.2960906E-03
     +,   4.7963280E-03,   4.3719490E-03,   4.0074144E-03
     +,   3.6825358E-03,   3.3789629E-03,   3.0838749E-03
     +,   2.7910969E-03,   2.5003199E-03,   2.2152821E-03
     +,   1.9415976E-03,   1.6849118E-03,   1.4496815E-03
     +,   1.2386035E-03,   1.0525568E-03,   8.9089479E-04
     +,   7.5191772E-04,   6.3333928E-04,   5.3263758E-04
     +,   4.4733510E-04,   3.7515824E-04,   3.1410455E-04
     +,   2.6245695E-04,   2.1877217E-04,   1.8185041E-04
     +,   1.5069268E-04,   1.2446281E-04,   1.0245662E-04
     +,   8.4075109E-05,   6.8800888E-05,   5.6181048E-05
     +,   4.5817313E-05,   3.7358881E-05,   3.0495361E-05
     +,   2.4954719E-05,   2.0500858E-05,   1.6930835E-05
     +,   1.4072386E-05,   1.1781614E-05,   9.9401759E-06
     +,   8.4519979E-06,   7.2401276E-06,   6.2438585E-06
     +,   5.4159300E-06,   4.7199183E-06,   4.1279732E-06
     +,   3.6190040E-06,   3.1771590E-06,   2.7904575E-06
     +,   2.4498606E-06,   2.1485096E-06,   1.8811126E-06
     +,   1.6434899E-06,   1.4322765E-06,   1.2446988E-06
     +,   1.0783906E-06,   9.3127676E-07,   8.0150363E-07
     +,   6.8740241E-07,   5.8742478E-07,   5.0015444E-07
     +,   4.2426748E-07,   3.5854717E-07,   3.0186013E-07
     +,   2.5317087E-07,   2.1152296E-07,   1.7605026E-07
     +,   1.4596276E-07,   1.2055244E-07,   9.9182152E-08
     +,   8.1285009E-08,   6.6360684E-08,   5.3967014E-08
     +,   4.3718810E-08,   3.5279655E-08,   2.8359720E-08
     +,   2.2708832E-08,   1.8113786E-08,   1.4392572E-08
     +,   1.1391721E-08,   8.9816252E-09,   7.0541040E-09
     +,   5.5187863E-09,   4.3009725E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_htt95 = Yx/0.4445
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1984517E-05,   1.2436531E-05
     +,   1.2906782E-05,   1.3396008E-05,   1.3904982E-05
     +,   1.4434489E-05,   1.4985338E-05,   1.5558373E-05
     +,   1.6154436E-05,   1.6774427E-05,   1.7419237E-05
     +,   1.8089791E-05,   1.8787026E-05,   1.9511901E-05
     +,   2.0265396E-05,   2.1048501E-05,   2.1862232E-05
     +,   2.2707605E-05,   2.3585659E-05,   2.4497429E-05
     +,   2.5443975E-05,   2.6426351E-05,   2.7445594E-05
     +,   2.8502813E-05,   2.9598985E-05,   3.0735224E-05
     +,   3.1912539E-05,   3.3131942E-05,   3.4394430E-05
     +,   3.5700989E-05,   3.7052545E-05,   3.8450016E-05
     +,   3.9894239E-05,   4.1386033E-05,   4.2926160E-05
     +,   4.4515287E-05,   4.6154022E-05,   4.7842877E-05
     +,   4.9582355E-05,   5.1372674E-05,   5.3214135E-05
     +,   5.5106786E-05,   5.7050605E-05,   5.9045371E-05
     +,   6.1090745E-05,   6.3186191E-05,   6.5331034E-05
     +,   6.7524343E-05,   6.9765047E-05,   7.2051822E-05
     +,   7.4383141E-05,   7.6757264E-05,   7.9172118E-05
     +,   8.1625614E-05,   8.4115141E-05,   8.6638109E-05
     +,   8.9191519E-05,   9.1772235E-05,   9.4376861E-05
     +,   9.7001845E-05,   9.9643403E-05,   1.0229768E-04
     +,   1.0496053E-04,   1.0762787E-04,   1.1029565E-04
     +,   1.1295955E-04,   1.1561557E-04,   1.1825952E-04
     +,   1.2088787E-04,   1.2349669E-04,   1.2608299E-04
     +,   1.2864369E-04,   1.3117657E-04,   1.3367970E-04
     +,   1.3615198E-04,   1.3859304E-04,   1.4100321E-04
     +,   1.4338373E-04,   1.4573699E-04,   1.4806642E-04
     +,   1.5037628E-04,   1.5267232E-04,   1.5496126E-04
     +,   1.5725120E-04,   1.5955126E-04,   1.6187201E-04
     +,   1.6422491E-04,   1.6662279E-04,   1.6907937E-04
     +,   1.7160921E-04,   1.7422822E-04,   1.7695251E-04
     +,   1.7979884E-04,   1.8278482E-04,   1.8592803E-04
     +,   1.8924648E-04,   1.9275825E-04,   1.9648137E-04
     +,   2.0043401E-04,   2.0463398E-04,   2.0909960E-04
     +,   2.1384851E-04,   2.1889938E-04,   2.2427048E-04
     +,   2.2998138E-04,   2.3605282E-04,   2.4250649E-04
     +,   2.4936619E-04,   2.5665868E-04,   2.6441409E-04
     +,   2.7266578E-04,   2.8145258E-04,   2.9081749E-04
     +,   3.0081114E-04,   3.1148863E-04,   3.2291387E-04
     +,   3.3515610E-04,   3.4829346E-04,   3.6240855E-04
     +,   3.7759147E-04,   3.9393629E-04,   4.1153919E-04
     +,   4.3049557E-04,   4.5089977E-04,   4.7283815E-04
     +,   4.9638498E-04,   5.2160001E-04,   5.4851902E-04
     +,   5.7715405E-04,   6.0748128E-04,   6.3944317E-04
     +,   6.7293551E-04,   7.0781360E-04,   7.4387941E-04
     +,   7.8089169E-04,   8.1856071E-04,   8.5655227E-04
     +,   8.9449307E-04,   9.3198440E-04,   9.6860557E-04
     +,   1.0039258E-03,   1.0375192E-03,   1.0689801E-03
     +,   1.0979323E-03,   1.1240419E-03,   1.1470324E-03
     +,   1.1666924E-03,   1.1828780E-03,   1.1955232E-03
     +,   1.2046342E-03,   1.2102926E-03,   1.2126438E-03
     +,   1.2118906E-03,   1.2082864E-03,   1.2021159E-03
     +,   1.1936902E-03,   1.1833333E-03,   1.1713689E-03
     +,   1.1581145E-03,   1.1438770E-03,   1.1289456E-03
     +,   1.1135958E-03,   1.0980897E-03,   1.0826823E-03
     +,   1.0676293E-03,   1.0531917E-03,   1.0396558E-03
     +,   1.0273334E-03,   1.0165813E-03,   1.0078162E-03
     +,   1.0015337E-03,   9.9834020E-04,   9.9899119E-04
     +,   1.0044484E-03,   1.0159585E-03,   1.0351501E-03
     +,   1.0641466E-03,   1.1056842E-03,   1.1632156E-03
     +,   1.2409908E-03,   1.3440797E-03,   1.4783392E-03
     +,   1.6503693E-03,   1.8675190E-03,   2.1379518E-03
     +,   2.4707860E-03,   2.8762291E-03,   3.3655332E-03
     +,   3.9505856E-03,   4.6434095E-03,   5.4566124E-03
     +,   6.4055105E-03,   7.5120688E-03,   8.8081695E-03
     +,   1.0332609E-02,   1.2116377E-02,   1.4159793E-02
     +,   1.6417406E-02,   1.8811814E-02,   2.1276783E-02
     +,   2.3801547E-02,   2.6442042E-02,   2.9292552E-02
     +,   3.2422055E-02,   3.5791107E-02,   3.9252043E-02
     +,   4.2704493E-02,   4.6154033E-02,   4.9428351E-02
     +,   5.2016541E-02,   5.3545456E-02,   5.4271337E-02
     +,   5.4781895E-02,   5.5411216E-02,   5.6149054E-02
     +,   5.6717243E-02,   5.6507450E-02,   5.4910716E-02
     +,   5.1935673E-02,   4.8284639E-02,   4.4814039E-02
     +,   4.1999377E-02,   3.9826121E-02,   3.8029481E-02
     +,   3.6312640E-02,   3.4403820E-02,   3.2129295E-02
     +,   2.9533533E-02,   2.6864719E-02,   2.4402604E-02
     +,   2.2303861E-02,   2.0572348E-02,   1.9116178E-02
     +,   1.7820193E-02,   1.6597325E-02,   1.5407574E-02
     +,   1.4251903E-02,   1.3153617E-02,   1.2139226E-02
     +,   1.1225525E-02,   1.0414202E-02,   9.6935360E-03
     +,   9.0447646E-03,   8.4496019E-03,   7.8961588E-03
     +,   7.3808394E-03,   6.9067408E-03,   6.4797136E-03
     +,   6.1043687E-03,   5.7812301E-03,   5.5057770E-03
     +,   5.2694166E-03,   5.0615752E-03,   4.8719565E-03
     +,   4.6924236E-03,   4.5178789E-03,   4.3463181E-03
     +,   4.1781366E-03,   4.0150979E-03,   3.8592992E-03
     +,   3.7123971E-03,   3.5750775E-03,   3.4468905E-03
     +,   3.3263995E-03,   3.2114871E-03,   3.0997295E-03
     +,   2.9888088E-03,   2.8768294E-03,   2.7625312E-03
     +,   2.6453540E-03,   2.5254239E-03,   2.4034420E-03
     +,   2.2804989E-03,   2.1578821E-03,   2.0369124E-03
     +,   1.9187953E-03,   1.8044983E-03,   1.6947242E-03
     +,   1.5898683E-03,   1.4900675E-03,   1.3952205E-03
     +,   1.3050780E-03,   1.2192776E-03,   1.1374325E-03
     +,   1.0591601E-03,   9.8414125E-04,   9.1212569E-04
     +,   8.4295368E-04,   7.7655754E-04,   7.1293849E-04
     +,   6.5216428E-04,   5.9433433E-04,   5.3957367E-04
     +,   4.8799734E-04,   4.3970897E-04,   3.9477373E-04
     +,   3.5322329E-04,   3.1503907E-04,   2.8016351E-04
     +,   2.4849238E-04,   2.1988999E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt100 = Yx/0.4298
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4904246E-05,   3.5483179E-05
     +,   3.6056434E-05,   3.6623664E-05,   3.7184538E-05
     +,   3.7738777E-05,   3.8286118E-05,   3.8826365E-05
     +,   3.9359311E-05,   3.9884850E-05,   4.0402887E-05
     +,   4.0913383E-05,   4.1416355E-05,   4.1911851E-05
     +,   4.2399966E-05,   4.2880867E-05,   4.3354758E-05
     +,   4.3821889E-05,   4.4282588E-05,   4.4737219E-05
     +,   4.5186185E-05,   4.5629942E-05,   4.6069032E-05
     +,   4.6504018E-05,   4.6935493E-05,   4.7364148E-05
     +,   4.7790672E-05,   4.8215814E-05,   4.8640366E-05
     +,   4.9065166E-05,   4.9491071E-05,   4.9918977E-05
     +,   5.0349834E-05,   5.0784583E-05,   5.1224219E-05
     +,   5.1669758E-05,   5.2122206E-05,   5.2582614E-05
     +,   5.3052088E-05,   5.3531654E-05,   5.4022414E-05
     +,   5.4525470E-05,   5.5041910E-05,   5.5572826E-05
     +,   5.6119348E-05,   5.6682533E-05,   5.7263529E-05
     +,   5.7863414E-05,   5.8483234E-05,   5.9124133E-05
     +,   5.9787166E-05,   6.0473387E-05,   6.1183884E-05
     +,   6.1919716E-05,   6.2681858E-05,   6.3471402E-05
     +,   6.4289350E-05,   6.5136745E-05,   6.6014574E-05
     +,   6.6923778E-05,   6.7865418E-05,   6.8840447E-05
     +,   6.9849790E-05,   7.0894392E-05,   7.1975315E-05
     +,   7.3093368E-05,   7.4249634E-05,   7.5444885E-05
     +,   7.6680226E-05,   7.7956473E-05,   7.9274731E-05
     +,   8.0635888E-05,   8.2041028E-05,   8.3491112E-05
     +,   8.4987340E-05,   8.6530912E-05,   8.8123059E-05
     +,   8.9765119E-05,   9.1458554E-05,   9.3205177E-05
     +,   9.5006624E-05,   9.6865115E-05,   9.8782744E-05
     +,   1.0076220E-04,   1.0280620E-04,   1.0491806E-04
     +,   1.0710122E-04,   1.0935981E-04,   1.1169805E-04
     +,   1.1412091E-04,   1.1663382E-04,   1.1924254E-04
     +,   1.2195330E-04,   1.2477307E-04,   1.2770917E-04
     +,   1.3076923E-04,   1.3396157E-04,   1.3729441E-04
     +,   1.4077660E-04,   1.4441682E-04,   1.4822402E-04
     +,   1.5220670E-04,   1.5637343E-04,   1.6073188E-04
     +,   1.6528937E-04,   1.7005233E-04,   1.7502582E-04
     +,   1.8021346E-04,   1.8561770E-04,   1.9123916E-04
     +,   1.9707590E-04,   2.0312445E-04,   2.0937834E-04
     +,   2.1582899E-04,   2.2246475E-04,   2.2927175E-04
     +,   2.3623262E-04,   2.4332802E-04,   2.5053503E-04
     +,   2.5782888E-04,   2.6518243E-04,   2.7256578E-04
     +,   2.7994724E-04,   2.8729424E-04,   2.9457273E-04
     +,   3.0174750E-04,   3.0878375E-04,   3.1564615E-04
     +,   3.2230082E-04,   3.2871429E-04,   3.3485526E-04
     +,   3.4069401E-04,   3.4620371E-04,   3.5135981E-04
     +,   3.5614148E-04,   3.6053083E-04,   3.6451407E-04
     +,   3.6808025E-04,   3.7122308E-04,   3.7393998E-04
     +,   3.7623153E-04,   3.7810241E-04,   3.7956086E-04
     +,   3.8061821E-04,   3.8128917E-04,   3.8159112E-04
     +,   3.8154432E-04,   3.8117132E-04,   3.8049725E-04
     +,   3.7954916E-04,   3.7835664E-04,   3.7695075E-04
     +,   3.7536497E-04,   3.7363468E-04,   3.7179777E-04
     +,   3.6989426E-04,   3.6796680E-04,   3.6606099E-04
     +,   3.6422524E-04,   3.6251140E-04,   3.6097487E-04
     +,   3.5967454E-04,   3.5867357E-04,   3.5803946E-04
     +,   3.5784385E-04,   3.5816419E-04,   3.5908344E-04
     +,   3.6069192E-04,   3.6308888E-04,   3.6638509E-04
     +,   3.7070594E-04,   3.7619646E-04,   3.8302725E-04
     +,   3.9140144E-04,   4.0156345E-04,   4.1380987E-04
     +,   4.2850102E-04,   4.4607188E-04,   4.6704471E-04
     +,   4.9204269E-04,   5.2179600E-04,   5.5714557E-04
     +,   5.9903605E-04,   6.4850616E-04,   7.0665253E-04
     +,   7.7457755E-04,   8.5332344E-04,   9.4380073E-04
     +,   1.0467117E-03,   1.1624868E-03,   1.2913237E-03
     +,   1.4332999E-03,   1.5886177E-03,   1.7580324E-03
     +,   1.9434078E-03,   2.1482895E-03,   2.3783415E-03
     +,   2.6414965E-03,   2.9476199E-03,   3.3076361E-03
     +,   3.7324114E-03,   4.2318339E-03,   4.8146294E-03
     +,   5.4889088E-03,   6.2630279E-03,   7.1460614E-03
     +,   8.1467591E-03,   9.2712957E-03,   1.0521922E-02
     +,   1.1899045E-02,   1.3407474E-02,   1.5063777E-02
     +,   1.6897827E-02,   1.8938068E-02,   2.1176450E-02
     +,   2.3538696E-02,   2.5912939E-02,   2.8245671E-02
     +,   3.0602837E-02,   3.3089906E-02,   3.5705339E-02
     +,   3.8309604E-02,   4.0718634E-02,   4.2789213E-02
     +,   4.4496205E-02,   4.6033897E-02,   4.7756344E-02
     +,   4.9811166E-02,   5.1812593E-02,   5.3145561E-02
     +,   5.3668868E-02,   5.3727098E-02,   5.3459026E-02
     +,   5.2646127E-02,   5.1154625E-02,   4.9090642E-02
     +,   4.6767607E-02,   4.4618078E-02,   4.2751316E-02
     +,   4.0744472E-02,   3.8182694E-02,   3.5157941E-02
     +,   3.2073211E-02,   2.9191313E-02,   2.6499622E-02
     +,   2.3903878E-02,   2.1439424E-02,   1.9275211E-02
     +,   1.7564112E-02,   1.6326677E-02,   1.5452036E-02
     +,   1.4769479E-02,   1.4123274E-02,   1.3419710E-02
     +,   1.2638861E-02,   1.1816142E-02,   1.1009155E-02
     +,   1.0268036E-02,   9.6191717E-03,   9.0620536E-03
     +,   8.5745798E-03,   8.1229750E-03,   7.6730675E-03
     +,   7.2002746E-03,   6.6953441E-03,   6.1645233E-03
     +,   5.6251916E-03,   5.0993478E-03,   4.6075066E-03
     +,   4.1646725E-03,   3.7789608E-03,   3.4520735E-03
     +,   3.1807679E-03,   2.9585499E-03,   2.7771848E-03
     +,   2.6278065E-03,   2.5016479E-03,   2.3906149E-03
     +,   2.2876246E-03,   2.1869058E-03,   2.0841206E-03
     +,   1.9764395E-03,   1.8624585E-03,   1.7420644E-03
     +,   1.6161711E-03,   1.4864801E-03,   1.3551596E-03
     +,   1.2245824E-03,   1.0970994E-03,   9.7482518E-04
     +,   8.5953588E-04,   7.5256533E-04,   6.5480667E-04
     +,   5.6670263E-04,   4.8831623E-04,   4.1937220E-04
     +,   3.5935431E-04,   3.0756096E-04,   2.6319246E-04
     +,   2.2539793E-04,   1.9333504E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt104 = Yx/0.41916
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3420610E-06,   2.4293186E-06
     +,   2.5196246E-06,   2.6131706E-06,   2.7101748E-06
     +,   2.8108766E-06,   2.9155447E-06,   3.0244762E-06
     +,   3.1379986E-06,   3.2564824E-06,   3.3803260E-06
     +,   3.5099761E-06,   3.6459194E-06,   3.7886903E-06
     +,   3.9388792E-06,   4.0971231E-06,   4.2641218E-06
     +,   4.4406297E-06,   4.6274704E-06,   4.8255306E-06
     +,   5.0357653E-06,   5.2592045E-06,   5.4969451E-06
     +,   5.7501761E-06,   6.0201337E-06,   6.3081584E-06
     +,   6.6156604E-06,   6.9441176E-06,   7.2950957E-06
     +,   7.6702181E-06,   8.0711952E-06,   8.4997910E-06
     +,   8.9578316E-06,   9.4471934E-06,   9.9698045E-06
     +,   1.0527625E-05,   1.1122645E-05,   1.1756848E-05
     +,   1.2432272E-05,   1.3150860E-05,   1.3914606E-05
     +,   1.4725415E-05,   1.5585141E-05,   1.6495551E-05
     +,   1.7458320E-05,   1.8474999E-05,   1.9547000E-05
     +,   2.0675569E-05,   2.1861779E-05,   2.3106497E-05
     +,   2.4410372E-05,   2.5773812E-05,   2.7196938E-05
     +,   2.8679719E-05,   3.0221629E-05,   3.1822063E-05
     +,   3.3479959E-05,   3.5193996E-05,   3.6962523E-05
     +,   3.8783564E-05,   4.0654850E-05,   4.2573778E-05
     +,   4.4537326E-05,   4.6542391E-05,   4.8585494E-05
     +,   5.0662769E-05,   5.2770345E-05,   5.4903878E-05
     +,   5.7059060E-05,   5.9231192E-05,   6.1415703E-05
     +,   6.3607651E-05,   6.5802291E-05,   6.7994566E-05
     +,   7.0179616E-05,   7.2352705E-05,   7.4508942E-05
     +,   7.6643570E-05,   7.8752098E-05,   8.0830243E-05
     +,   8.2873717E-05,   8.4878709E-05,   8.6841370E-05
     +,   8.8758461E-05,   9.0626760E-05,   9.2443581E-05
     +,   9.4206349E-05,   9.5913063E-05,   9.7561882E-05
     +,   9.9151468E-05,   1.0068085E-04,   1.0214933E-04
     +,   1.0355668E-04,   1.0490308E-04,   1.0618912E-04
     +,   1.0741572E-04,   1.0858435E-04,   1.0969677E-04
     +,   1.1075533E-04,   1.1176270E-04,   1.1272223E-04
     +,   1.1363756E-04,   1.1451299E-04,   1.1535327E-04
     +,   1.1616381E-04,   1.1695061E-04,   1.1772029E-04
     +,   1.1848000E-04,   1.1923769E-04,   1.2000195E-04
     +,   1.2078196E-04,   1.2158767E-04,   1.2242963E-04
     +,   1.2331904E-04,   1.2426771E-04,   1.2528787E-04
     +,   1.2639229E-04,   1.2759402E-04,   1.2890632E-04
     +,   1.3034252E-04,   1.3191598E-04,   1.3363955E-04
     +,   1.3552561E-04,   1.3758593E-04,   1.3983130E-04
     +,   1.4227108E-04,   1.4491337E-04,   1.4776413E-04
     +,   1.5082773E-04,   1.5410576E-04,   1.5759766E-04
     +,   1.6129964E-04,   1.6520541E-04,   1.6930499E-04
     +,   1.7358566E-04,   1.7803129E-04,   1.8262219E-04
     +,   1.8733536E-04,   1.9214515E-04,   1.9702282E-04
     +,   2.0193675E-04,   2.0685309E-04,   2.1173625E-04
     +,   2.1654944E-04,   2.2125446E-04,   2.2581319E-04
     +,   2.3018809E-04,   2.3434238E-04,   2.3824097E-04
     +,   2.4185154E-04,   2.4514500E-04,   2.4809618E-04
     +,   2.5068436E-04,   2.5289448E-04,   2.5471760E-04
     +,   2.5615099E-04,   2.5719922E-04,   2.5787461E-04
     +,   2.5819743E-04,   2.5819647E-04,   2.5790874E-04
     +,   2.5738051E-04,   2.5666683E-04,   2.5583160E-04
     +,   2.5494775E-04,   2.5409670E-04,   2.5336884E-04
     +,   2.5286261E-04,   2.5268458E-04,   2.5294934E-04
     +,   2.5377914E-04,   2.5530331E-04,   2.5765938E-04
     +,   2.6099221E-04,   2.6545531E-04,   2.7121097E-04
     +,   2.7843239E-04,   2.8730396E-04,   2.9802389E-04
     +,   3.1080592E-04,   3.2588191E-04,   3.4350049E-04
     +,   3.6392873E-04,   3.8745251E-04,   4.1437199E-04
     +,   4.4499600E-04,   4.7963805E-04,   5.1861210E-04
     +,   5.6222867E-04,   6.1078824E-04,   6.6459971E-04
     +,   7.2399277E-04,   7.8934350E-04,   8.6112489E-04
     +,   9.3996950E-04,   1.0267423E-03,   1.1226126E-03
     +,   1.2291367E-03,   1.3483302E-03,   1.4826852E-03
     +,   1.6351428E-03,   1.8090269E-03,   2.0079534E-03
     +,   2.2357344E-03,   2.4963545E-03,   2.7941125E-03
     +,   3.1337752E-03,   3.5206524E-03,   3.9604749E-03
     +,   4.4588838E-03,   5.0204969E-03,   5.6476463E-03
     +,   6.3388776E-03,   7.0869001E-03,   7.8759296E-03
     +,   8.6798044E-03,   9.4655100E-03,   1.0209142E-02
     +,   1.0927796E-02,   1.1715095E-02,   1.2745224E-02
     +,   1.4206535E-02,   1.6176183E-02,   1.8534303E-02
     +,   2.1035455E-02,   2.3511074E-02,   2.5985278E-02
     +,   2.8552109E-02,   3.1211529E-02,   3.3943258E-02
     +,   3.6858257E-02,   4.0133882E-02,   4.3811280E-02
     +,   4.7515564E-02,   5.0455358E-02,   5.2241251E-02
     +,   5.3423710E-02,   5.4685790E-02,   5.5903975E-02
     +,   5.6299396E-02,   5.5508204E-02,   5.4187756E-02
     +,   5.2963380E-02,   5.1318076E-02,   4.8538622E-02
     +,   4.5158569E-02,   4.2366061E-02,   4.0489733E-02
     +,   3.8885307E-02,   3.6936194E-02,   3.4654904E-02
     +,   3.2353956E-02,   3.0068532E-02,   2.7604867E-02
     +,   2.4953038E-02,   2.2315938E-02,   1.9848758E-02
     +,   1.7576771E-02,   1.5497061E-02,   1.3633975E-02
     +,   1.2011446E-02,   1.0630558E-02,   9.4790095E-03
     +,   8.5422909E-03,   7.8011923E-03,   7.2257686E-03
     +,   6.7765494E-03,   6.4119450E-03,   6.0962420E-03
     +,   5.8042593E-03,   5.5217808E-03,   5.2431906E-03
     +,   4.9679158E-03,   4.6972395E-03,   4.4321292E-03
     +,   4.1723591E-03,   3.9165244E-03,   3.6627979E-03
     +,   3.4096632E-03,   3.1566457E-03,   2.9045176E-03
     +,   2.6553001E-03,   2.4118284E-03,   2.1773204E-03
     +,   1.9547900E-03,   1.7467032E-03,   1.5546826E-03
     +,   1.3794670E-03,   1.2210093E-03,   1.0786202E-03
     +,   9.5122290E-04,   8.3752297E-04,   7.3620101E-04
     +,   6.4599287E-04,   5.6576630E-04,   4.9451372E-04
     +,   4.3136202E-04,   3.7553025E-04,   3.2632233E-04
     +,   2.8309357E-04,   2.4524966E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt106 = Yx/0.400857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1897462E-05,   1.2295445E-05
     +,   1.2703978E-05,   1.3123246E-05,   1.3553427E-05
     +,   1.3994691E-05,   1.4447213E-05,   1.4911161E-05
     +,   1.5386677E-05,   1.5873937E-05,   1.6373066E-05
     +,   1.6884202E-05,   1.7407470E-05,   1.7942975E-05
     +,   1.8490822E-05,   1.9051102E-05,   1.9623880E-05
     +,   2.0209220E-05,   2.0807161E-05,   2.1417740E-05
     +,   2.2040962E-05,   2.2676824E-05,   2.3325294E-05
     +,   2.3986366E-05,   2.4659941E-05,   2.5345984E-05
     +,   2.6044387E-05,   2.6755049E-05,   2.7477850E-05
     +,   2.8212658E-05,   2.8959330E-05,   2.9717688E-05
     +,   3.0487568E-05,   3.1268806E-05,   3.2061198E-05
     +,   3.2864555E-05,   3.3678665E-05,   3.4503337E-05
     +,   3.5338402E-05,   3.6183588E-05,   3.7038772E-05
     +,   3.7903723E-05,   3.8778267E-05,   3.9662249E-05
     +,   4.0555475E-05,   4.1457806E-05,   4.2369105E-05
     +,   4.3289241E-05,   4.4218097E-05,   4.5155579E-05
     +,   4.6101602E-05,   4.7056070E-05,   4.8018930E-05
     +,   4.8990150E-05,   4.9969611E-05,   5.0957336E-05
     +,   5.1953237E-05,   5.2957275E-05,   5.3969390E-05
     +,   5.4989505E-05,   5.6017529E-05,   5.7053399E-05
     +,   5.8096881E-05,   5.9147886E-05,   6.0206217E-05
     +,   6.1271581E-05,   6.2343766E-05,   6.3422332E-05
     +,   6.4506989E-05,   6.5597211E-05,   6.6692570E-05
     +,   6.7792440E-05,   6.8896254E-05,   7.0003298E-05
     +,   7.1112823E-05,   7.2224080E-05,   7.3336225E-05
     +,   7.4448304E-05,   7.5559416E-05,   7.6668672E-05
     +,   7.7774952E-05,   7.8877354E-05,   7.9974816E-05
     +,   8.1066391E-05,   8.2151026E-05,   8.3227817E-05
     +,   8.4295796E-05,   8.5354171E-05,   8.6402077E-05
     +,   8.7438828E-05,   8.8463858E-05,   8.9476554E-05
     +,   9.0476533E-05,   9.1463502E-05,   9.2437287E-05
     +,   9.3397823E-05,   9.4345232E-05,   9.5279684E-05
     +,   9.6201584E-05,   9.7111340E-05,   9.8009616E-05
     +,   9.8897013E-05,   9.9774472E-05,   1.0064277E-04
     +,   1.0150291E-04,   1.0235595E-04,   1.0320289E-04
     +,   1.0404478E-04,   1.0488272E-04,   1.0571771E-04
     +,   1.0655069E-04,   1.0738259E-04,   1.0821413E-04
     +,   1.0904598E-04,   1.0987862E-04,   1.1071238E-04
     +,   1.1154734E-04,   1.1238350E-04,   1.1322051E-04
     +,   1.1405775E-04,   1.1489454E-04,   1.1572982E-04
     +,   1.1656222E-04,   1.1739025E-04,   1.1821219E-04
     +,   1.1902601E-04,   1.1982952E-04,   1.2062033E-04
     +,   1.2139598E-04,   1.2215375E-04,   1.2289097E-04
     +,   1.2360481E-04,   1.2429254E-04,   1.2495140E-04
     +,   1.2557885E-04,   1.2617234E-04,   1.2672962E-04
     +,   1.2724863E-04,   1.2772775E-04,   1.2816567E-04
     +,   1.2856141E-04,   1.2891457E-04,   1.2922521E-04
     +,   1.2949404E-04,   1.2972226E-04,   1.2991174E-04
     +,   1.3006500E-04,   1.3018529E-04,   1.3027638E-04
     +,   1.3034296E-04,   1.3039012E-04,   1.3042385E-04
     +,   1.3045060E-04,   1.3047757E-04,   1.3051240E-04
     +,   1.3056333E-04,   1.3063916E-04,   1.3074905E-04
     +,   1.3090267E-04,   1.3111002E-04,   1.3138157E-04
     +,   1.3172824E-04,   1.3216128E-04,   1.3269258E-04
     +,   1.3333453E-04,   1.3410041E-04,   1.3500436E-04
     +,   1.3606169E-04,   1.3728924E-04,   1.3870577E-04
     +,   1.4033227E-04,   1.4219248E-04,   1.4431369E-04
     +,   1.4672731E-04,   1.4946924E-04,   1.5258137E-04
     +,   1.5611218E-04,   1.6011734E-04,   1.6466116E-04
     +,   1.6981775E-04,   1.7567204E-04,   1.8232048E-04
     +,   1.8987246E-04,   1.9845230E-04,   2.0819971E-04
     +,   2.1927114E-04,   2.3184088E-04,   2.4610461E-04
     +,   2.6228005E-04,   2.8060761E-04,   3.0135608E-04
     +,   3.2482398E-04,   3.5133981E-04,   3.8126635E-04
     +,   4.1500377E-04,   4.5299000E-04,   4.9569830E-04
     +,   5.4363784E-04,   5.9735810E-04,   6.5744860E-04
     +,   7.2453881E-04,   7.9931581E-04,   8.8255486E-04
     +,   9.7516639E-04,   1.0782651E-03,   1.1933161E-03
     +,   1.3223070E-03,   1.4679878E-03,   1.6341549E-03
     +,   1.8259328E-03,   2.0498785E-03,   2.3137406E-03
     +,   2.6256221E-03,   2.9923813E-03,   3.4173022E-03
     +,   3.8976525E-03,   4.4235401E-03,   4.9796375E-03
     +,   5.5507654E-03,   6.1305519E-03,   6.7298878E-03
     +,   7.3791705E-03,   8.1201391E-03,   8.9885592E-03
     +,   9.9969180E-03,   1.1131617E-02,   1.2373125E-02
     +,   1.3728459E-02,   1.5245076E-02,   1.6984958E-02
     +,   1.8980285E-02,   2.1211131E-02,   2.3602014E-02
     +,   2.6029417E-02,   2.8396798E-02,   3.0770980E-02
     +,   3.3414815E-02,   3.6607247E-02,   4.0312126E-02
     +,   4.3944269E-02,   4.6648294E-02,   4.8030399E-02
     +,   4.8519403E-02,   4.8909947E-02,   4.9776021E-02
     +,   5.1161166E-02,   5.2453380E-02,   5.3143948E-02
     +,   5.3458370E-02,   5.3330686E-02,   5.2141510E-02
     +,   4.9883984E-02,   4.7015302E-02,   4.3812115E-02
     +,   4.0691972E-02,   3.8169038E-02,   3.6384765E-02
     +,   3.5099015E-02,   3.3922132E-02,   3.2505140E-02
     +,   3.0613730E-02,   2.8158925E-02,   2.5323300E-02
     +,   2.2545399E-02,   2.0213012E-02,   1.8394059E-02
     +,   1.6888956E-02,   1.5475340E-02,   1.4072319E-02
     +,   1.2726969E-02,   1.1513123E-02,   1.0459371E-02
     +,   9.5435856E-03,   8.7237665E-03,   7.9658171E-03
     +,   7.2525772E-03,   6.5793693E-03,   5.9470106E-03
     +,   5.3569572E-03,   4.8097190E-03,   4.3045641E-03
     +,   3.8399776E-03,   3.4138686E-03,   3.0240128E-03
     +,   2.6681954E-03,   2.3445177E-03,   2.0514133E-03
     +,   1.7876475E-03,   1.5521863E-03,   1.3439208E-03
     +,   1.1615219E-03,   1.0032614E-03,   8.6705072E-04
     +,   7.5048680E-04,   6.5104361E-04,   5.6621240E-04
     +,   4.9366994E-04,   4.3135686E-04,   3.7753989E-04
     +,   3.3079635E-04,   2.8999825E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt108 = Yx/0.401142857142857
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8321354E-05,   1.8513845E-05
     +,   1.8689498E-05,   1.8848104E-05,   1.8989531E-05
     +,   1.9113739E-05,   1.9220757E-05,   1.9310717E-05
     +,   1.9383822E-05,   1.9440375E-05,   1.9480753E-05
     +,   1.9505422E-05,   1.9514935E-05,   1.9509924E-05
     +,   1.9491101E-05,   1.9459256E-05,   1.9415247E-05
     +,   1.9360010E-05,   1.9294543E-05,   1.9219911E-05
     +,   1.9137231E-05,   1.9047677E-05,   1.8952464E-05
     +,   1.8852859E-05,   1.8750165E-05,   1.8645713E-05
     +,   1.8540861E-05,   1.8436995E-05,   1.8335506E-05
     +,   1.8237797E-05,   1.8145282E-05,   1.8059374E-05
     +,   1.7981469E-05,   1.7912957E-05,   1.7855211E-05
     +,   1.7809589E-05,   1.7777407E-05,   1.7759967E-05
     +,   1.7758521E-05,   1.7774288E-05,   1.7808450E-05
     +,   1.7862134E-05,   1.7936422E-05,   1.8032340E-05
     +,   1.8150859E-05,   1.8292900E-05,   1.8459319E-05
     +,   1.8650904E-05,   1.8868397E-05,   1.9112458E-05
     +,   1.9383693E-05,   1.9682642E-05,   2.0009764E-05
     +,   2.0365482E-05,   2.0750116E-05,   2.1163953E-05
     +,   2.1607189E-05,   2.2079972E-05,   2.2582368E-05
     +,   2.3114386E-05,   2.3675984E-05,   2.4267050E-05
     +,   2.4887388E-05,   2.5536770E-05,   2.6214941E-05
     +,   2.6921507E-05,   2.7656102E-05,   2.8418230E-05
     +,   2.9207440E-05,   3.0023126E-05,   3.0864732E-05
     +,   3.1731564E-05,   3.2622997E-05,   3.3538232E-05
     +,   3.4476536E-05,   3.5437122E-05,   3.6419147E-05
     +,   3.7421687E-05,   3.8443868E-05,   3.9484807E-05
     +,   4.0543455E-05,   4.1618918E-05,   4.2710100E-05
     +,   4.3816075E-05,   4.4935688E-05,   4.6067980E-05
     +,   4.7211775E-05,   4.8366066E-05,   4.9529670E-05
     +,   5.0701514E-05,   5.1880481E-05,   5.3065451E-05
     +,   5.4255219E-05,   5.5448687E-05,   5.6644749E-05
     +,   5.7842186E-05,   5.9039943E-05,   6.0236784E-05
     +,   6.1431667E-05,   6.2623374E-05,   6.3810854E-05
     +,   6.4992928E-05,   6.6168570E-05,   6.7336616E-05
     +,   6.8496003E-05,   6.9645721E-05,   7.0784714E-05
     +,   7.1911883E-05,   7.3026276E-05,   7.4126925E-05
     +,   7.5212833E-05,   7.6283126E-05,   7.7336823E-05
     +,   7.8373130E-05,   7.9391131E-05,   8.0390077E-05
     +,   8.1369122E-05,   8.2327584E-05,   8.3264691E-05
     +,   8.4179825E-05,   8.5072345E-05,   8.5941640E-05
     +,   8.6787135E-05,   8.7608350E-05,   8.8404820E-05
     +,   8.9176072E-05,   8.9921741E-05,   9.0641443E-05
     +,   9.1334892E-05,   9.2001792E-05,   9.2641931E-05
     +,   9.3255097E-05,   9.3841147E-05,   9.4399918E-05
     +,   9.4931303E-05,   9.5435324E-05,   9.5911855E-05
     +,   9.6360949E-05,   9.6782598E-05,   9.7176897E-05
     +,   9.7543882E-05,   9.7883640E-05,   9.8196346E-05
     +,   9.8482109E-05,   9.8741075E-05,   9.8973440E-05
     +,   9.9179422E-05,   9.9359269E-05,   9.9513250E-05
     +,   9.9641678E-05,   9.9744932E-05,   9.9823446E-05
     +,   9.9877732E-05,   9.9908437E-05,   9.9916309E-05
     +,   9.9902289E-05,   9.9867488E-05,   9.9813311E-05
     +,   9.9741475E-05,   9.9654055E-05,   9.9553683E-05
     +,   9.9443445E-05,   9.9327262E-05,   9.9209770E-05
     +,   9.9096695E-05,   9.8994875E-05,   9.8912606E-05
     +,   9.8859768E-05,   9.8848242E-05,   9.8892226E-05
     +,   9.9008532E-05,   9.9217090E-05,   9.9541539E-05
     +,   1.0000977E-04,   1.0065460E-04,   1.0151469E-04
     +,   1.0263537E-04,   1.0406974E-04,   1.0587962E-04
     +,   1.0813717E-04,   1.1092603E-04,   1.1434247E-04
     +,   1.1849679E-04,   1.2351469E-04,   1.2953796E-04
     +,   1.3672440E-04,   1.4524766E-04,   1.5529657E-04
     +,   1.6707290E-04,   1.8078605E-04,   1.9665080E-04
     +,   2.1488007E-04,   2.3567617E-04,   2.5922348E-04
     +,   2.8568102E-04,   3.1517359E-04,   3.4778225E-04
     +,   3.8354209E-04,   4.2244367E-04,   4.6443674E-04
     +,   5.0943840E-04,   5.5735483E-04,   6.0811150E-04
     +,   6.6168664E-04,   7.1814738E-04,   7.7770883E-04
     +,   8.4077747E-04,   9.0799038E-04,   9.8026055E-04
     +,   1.0587977E-03,   1.1451083E-03,   1.2409595E-03
     +,   1.3483238E-03,   1.4692898E-03,   1.6059284E-03
     +,   1.7601417E-03,   1.9335308E-03,   2.1273356E-03
     +,   2.3424407E-03,   2.5794841E-03,   2.8391315E-03
     +,   3.1222764E-03,   3.4301870E-03,   3.7645781E-03
     +,   4.1276831E-03,   4.5222761E-03,   4.9516787E-03
     +,   5.4197991E-03,   5.9319530E-03,   6.4985580E-03
     +,   7.1437536E-03,   7.9165185E-03,   8.8921348E-03
     +,   1.0145478E-02,   1.1690560E-02,   1.3422145E-02
     +,   1.5132197E-02,   1.6645169E-02,   1.7995499E-02
     +,   1.9478688E-02,   2.1489263E-02,   2.4236022E-02
     +,   2.7508797E-02,   3.0741585E-02,   3.3531353E-02
     +,   3.6094807E-02,   3.8859196E-02,   4.1671567E-02
     +,   4.3896623E-02,   4.5281850E-02,   4.6435829E-02
     +,   4.8467483E-02,   5.1860876E-02,   5.5711351E-02
     +,   5.8533691E-02,   5.9114382E-02,   5.7310063E-02
     +,   5.4705556E-02,   5.2609723E-02,   5.0611630E-02
     +,   4.8129372E-02,   4.5361575E-02,   4.2772051E-02
     +,   4.0385477E-02,   3.7924260E-02,   3.5444643E-02
     +,   3.3080038E-02,   3.0615298E-02,   2.7797401E-02
     +,   2.4702411E-02,   2.1659167E-02,   1.8964445E-02
     +,   1.6705617E-02,   1.4796486E-02,   1.3110929E-02
     +,   1.1564766E-02,   1.0125116E-02,   8.7956702E-03
     +,   7.5996416E-03,   6.5623540E-03,   5.6955763E-03
     +,   4.9907854E-03,   4.4214991E-03,   3.9521870E-03
     +,   3.5480203E-03,   3.1822664E-03,   2.8390023E-03
     +,   2.5121290E-03,   2.2022221E-03,   1.9129219E-03
     +,   1.6482490E-03,   1.4109154E-03,   1.2018402E-03
     +,   1.0202334E-03,   8.6413632E-04,   7.3092530E-04
     +,   6.1780185E-04,   5.2205141E-04,   4.4122504E-04
     +,   3.7315881E-04,   3.1598168E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt110 = Yx/0.381428571428571
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7066726E-05,   1.7129614E-05
     +,   1.7175778E-05,   1.7205261E-05,   1.7218161E-05
     +,   1.7214650E-05,   1.7194960E-05,   1.7159380E-05
     +,   1.7108263E-05,   1.7042017E-05,   1.6961112E-05
     +,   1.6866075E-05,   1.6757471E-05,   1.6635926E-05
     +,   1.6502110E-05,   1.6356735E-05,   1.6200545E-05
     +,   1.6034330E-05,   1.5858905E-05,   1.5675114E-05
     +,   1.5483827E-05,   1.5285934E-05,   1.5082339E-05
     +,   1.4873941E-05,   1.4661688E-05,   1.4446485E-05
     +,   1.4229262E-05,   1.4010945E-05,   1.3792439E-05
     +,   1.3574650E-05,   1.3358461E-05,   1.3144739E-05
     +,   1.2934334E-05,   1.2728065E-05,   1.2526733E-05
     +,   1.2331104E-05,   1.2141919E-05,   1.1959882E-05
     +,   1.1785664E-05,   1.1619913E-05,   1.1463228E-05
     +,   1.1316180E-05,   1.1179301E-05,   1.1053091E-05
     +,   1.0938017E-05,   1.0834508E-05,   1.0742963E-05
     +,   1.0663749E-05,   1.0597205E-05,   1.0543641E-05
     +,   1.0503343E-05,   1.0476577E-05,   1.0463586E-05
     +,   1.0464598E-05,   1.0479832E-05,   1.0509492E-05
     +,   1.0553781E-05,   1.0612899E-05,   1.0687055E-05
     +,   1.0776454E-05,   1.0881326E-05,   1.1001910E-05
     +,   1.1138466E-05,   1.1291286E-05,   1.1460696E-05
     +,   1.1647036E-05,   1.1850726E-05,   1.2072184E-05
     +,   1.2311923E-05,   1.2570467E-05,   1.2848425E-05
     +,   1.3146450E-05,   1.3465276E-05,   1.3805664E-05
     +,   1.4168474E-05,   1.4554630E-05,   1.4965100E-05
     +,   1.5400905E-05,   1.5863156E-05,   1.6353020E-05
     +,   1.6871676E-05,   1.7420400E-05,   1.8000439E-05
     +,   1.8613140E-05,   1.9259794E-05,   1.9941766E-05
     +,   2.0660325E-05,   2.1416821E-05,   2.2212445E-05
     +,   2.3048418E-05,   2.3925886E-05,   2.4845833E-05
     +,   2.5809117E-05,   2.6816537E-05,   2.7868715E-05
     +,   2.8965997E-05,   3.0108671E-05,   3.1296648E-05
     +,   3.2529744E-05,   3.3807348E-05,   3.5128753E-05
     +,   3.6492784E-05,   3.7898117E-05,   3.9342947E-05
     +,   4.0825282E-05,   4.2342799E-05,   4.3892749E-05
     +,   4.5472068E-05,   4.7077487E-05,   4.8705402E-05
     +,   5.0351813E-05,   5.2012630E-05,   5.3683361E-05
     +,   5.5359462E-05,   5.7036024E-05,   5.8708265E-05
     +,   6.0371040E-05,   6.2019375E-05,   6.3648127E-05
     +,   6.5252316E-05,   6.6827080E-05,   6.8367648E-05
     +,   6.9869384E-05,   7.1328075E-05,   7.2739778E-05
     +,   7.4100826E-05,   7.5408090E-05,   7.6658776E-05
     +,   7.7850731E-05,   7.8982179E-05,   8.0052072E-05
     +,   8.1059865E-05,   8.2005739E-05,   8.2890401E-05
     +,   8.3715364E-05,   8.4482759E-05,   8.5195352E-05
     +,   8.5856642E-05,   8.6470842E-05,   8.7042790E-05
     +,   8.7577988E-05,   8.8082554E-05,   8.8563320E-05
     +,   8.9027642E-05,   8.9483416E-05,   8.9939167E-05
     +,   9.0403904E-05,   9.0887072E-05,   9.1398528E-05
     +,   9.1948641E-05,   9.2548013E-05,   9.3207578E-05
     +,   9.3938543E-05,   9.4752228E-05,   9.5660202E-05
     +,   9.6673983E-05,   9.7805067E-05,   9.9064899E-05
     +,   1.0046473E-04,   1.0201545E-04,   1.0372760E-04
     +,   1.0561133E-04,   1.0767602E-04,   1.0993033E-04
     +,   1.1238221E-04,   1.1503863E-04,   1.1790548E-04
     +,   1.2098724E-04,   1.2428754E-04,   1.2780860E-04
     +,   1.3155106E-04,   1.3551414E-04,   1.3969600E-04
     +,   1.4409333E-04,   1.4870119E-04,   1.5351413E-04
     +,   1.5852571E-04,   1.6372869E-04,   1.6911566E-04
     +,   1.7467979E-04,   1.8041529E-04,   1.8631770E-04
     +,   1.9238493E-04,   1.9861886E-04,   2.0502601E-04
     +,   2.1161827E-04,   2.1841454E-04,   2.2544287E-04
     +,   2.3274090E-04,   2.4035685E-04,   2.4835172E-04
     +,   2.5679963E-04,   2.6578718E-04,   2.7541476E-04
     +,   2.8579537E-04,   2.9705346E-04,   3.0932197E-04
     +,   3.2273956E-04,   3.3744931E-04,   3.5359341E-04
     +,   3.7130943E-04,   3.9072748E-04,   4.1197025E-04
     +,   4.3515136E-04,   4.6037510E-04,   4.8774545E-04
     +,   5.1737146E-04,   5.4937584E-04,   5.8390974E-04
     +,   6.2117010E-04,   6.6141511E-04,   7.0497673E-04
     +,   7.5227820E-04,   8.0384983E-04,   8.6033728E-04
     +,   9.2250539E-04,   9.9125179E-04,   1.0676264E-03
     +,   1.1528489E-03,   1.2483331E-03,   1.3557430E-03
     +,   1.4770193E-03,   1.6143890E-03,   1.7703474E-03
     +,   1.9475931E-03,   2.1488862E-03,   2.3768349E-03
     +,   2.6336445E-03,   2.9207887E-03,   3.2385169E-03
     +,   3.5852510E-03,   3.9570453E-03,   4.3475735E-03
     +,   4.7492101E-03,   5.1559340E-03,   5.5682501E-03
     +,   5.9987749E-03,   6.4756488E-03,   7.0394059E-03
     +,   7.7292477E-03,   8.5611111E-03,   9.5122885E-03
     +,   1.0537224E-02,   1.1624306E-02,   1.2856824E-02
     +,   1.4402304E-02,   1.6393634E-02,   1.8785866E-02
     +,   2.1343349E-02,   2.3795875E-02,   2.6002277E-02
     +,   2.7983738E-02,   2.9959893E-02,   3.2432307E-02
     +,   3.5882715E-02,   4.0008619E-02,   4.3538589E-02
     +,   4.5479309E-02,   4.6583794E-02,   4.8649151E-02
     +,   5.1854029E-02,   5.4375216E-02,   5.5383869E-02
     +,   5.5744763E-02,   5.5931270E-02,   5.5691320E-02
     +,   5.4801807E-02,   5.3432383E-02,   5.2042045E-02
     +,   5.0568361E-02,   4.8099853E-02,   4.4084605E-02
     +,   3.9259676E-02,   3.4735501E-02,   3.0949175E-02
     +,   2.7770756E-02,   2.4987428E-02,   2.2453396E-02
     +,   2.0077486E-02,   1.7859515E-02,   1.5858874E-02
     +,   1.4090933E-02,   1.2489585E-02,   1.0966385E-02
     +,   9.4786165E-03,   8.0455570E-03,   6.7186314E-03
     +,   5.5447957E-03,   4.5469999E-03,   3.7231031E-03
     +,   3.0546694E-03,   2.5162606E-03,   2.0822617E-03
     +,   1.7302259E-03,   1.4422104E-03,   1.2045954E-03
     +,   1.0074275E-03,   8.4340526E-04,   7.0705870E-04
     +,   5.9403671E-04,   5.0071743E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt112 = Yx/0.371
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7905500E-05,   1.8295834E-05
     +,   1.8674071E-05,   1.9039406E-05,   1.9391078E-05
     +,   1.9728410E-05,   2.0050784E-05,   2.0357644E-05
     +,   2.0648535E-05,   2.0923066E-05,   2.1180937E-05
     +,   2.1421929E-05,   2.1645905E-05,   2.1852826E-05
     +,   2.2042734E-05,   2.2215763E-05,   2.2372124E-05
     +,   2.2512118E-05,   2.2636134E-05,   2.2744631E-05
     +,   2.2838143E-05,   2.2917282E-05,   2.2982724E-05
     +,   2.3035205E-05,   2.3075514E-05,   2.3104494E-05
     +,   2.3123028E-05,   2.3132045E-05,   2.3132496E-05
     +,   2.3125363E-05,   2.3111636E-05,   2.3092332E-05
     +,   2.3068455E-05,   2.3041017E-05,   2.3011011E-05
     +,   2.2979424E-05,   2.2947224E-05,   2.2915347E-05
     +,   2.2884693E-05,   2.2856142E-05,   2.2830513E-05
     +,   2.2808592E-05,   2.2791121E-05,   2.2778782E-05
     +,   2.2772212E-05,   2.2771992E-05,   2.2778644E-05
     +,   2.2792647E-05,   2.2814400E-05,   2.2844270E-05
     +,   2.2882556E-05,   2.2929515E-05,   2.2985347E-05
     +,   2.3050197E-05,   2.3124177E-05,   2.3207351E-05
     +,   2.3299737E-05,   2.3401324E-05,   2.3512071E-05
     +,   2.3631901E-05,   2.3760724E-05,   2.3898416E-05
     +,   2.4044848E-05,   2.4199875E-05,   2.4363357E-05
     +,   2.4535118E-05,   2.4715035E-05,   2.4902934E-05
     +,   2.5098696E-05,   2.5302172E-05,   2.5513267E-05
     +,   2.5731864E-05,   2.5957906E-05,   2.6191312E-05
     +,   2.6432062E-05,   2.6680147E-05,   2.6935581E-05
     +,   2.7198384E-05,   2.7468639E-05,   2.7746430E-05
     +,   2.8031858E-05,   2.8325070E-05,   2.8626200E-05
     +,   2.8935443E-05,   2.9252953E-05,   2.9578954E-05
     +,   2.9913623E-05,   3.0257201E-05,   3.0609870E-05
     +,   3.0971856E-05,   3.1343359E-05,   3.1724558E-05
     +,   3.2115615E-05,   3.2516687E-05,   3.2927903E-05
     +,   3.3349326E-05,   3.3781042E-05,   3.4223027E-05
     +,   3.4675264E-05,   3.5137648E-05,   3.5610061E-05
     +,   3.6092268E-05,   3.6584042E-05,   3.7085025E-05
     +,   3.7594826E-05,   3.8113008E-05,   3.8639013E-05
     +,   3.9172228E-05,   3.9711984E-05,   4.0257550E-05
     +,   4.0808096E-05,   4.1362760E-05,   4.1920572E-05
     +,   4.2480573E-05,   4.3041684E-05,   4.3602842E-05
     +,   4.4162884E-05,   4.4720669E-05,   4.5275003E-05
     +,   4.5824694E-05,   4.6368597E-05,   4.6905487E-05
     +,   4.7434212E-05,   4.7953679E-05,   4.8462833E-05
     +,   4.8960661E-05,   4.9446291E-05,   4.9918879E-05
     +,   5.0377756E-05,   5.0822327E-05,   5.1252217E-05
     +,   5.1667146E-05,   5.2067073E-05,   5.2452091E-05
     +,   5.2822514E-05,   5.3178941E-05,   5.3522130E-05
     +,   5.3853113E-05,   5.4173212E-05,   5.4483975E-05
     +,   5.4787244E-05,   5.5085140E-05,   5.5380078E-05
     +,   5.5674798E-05,   5.5972250E-05,   5.6275774E-05
     +,   5.6588953E-05,   5.6915676E-05,   5.7260117E-05
     +,   5.7626767E-05,   5.8020378E-05,   5.8445989E-05
     +,   5.8908921E-05,   5.9414746E-05,   5.9969399E-05
     +,   6.0578968E-05,   6.1249848E-05,   6.1988743E-05
     +,   6.2802625E-05,   6.3698702E-05,   6.4684442E-05
     +,   6.5767672E-05,   6.6956432E-05,   6.8258967E-05
     +,   6.9683876E-05,   7.1240043E-05,   7.2936426E-05
     +,   7.4782198E-05,   7.6786760E-05,   7.8959638E-05
     +,   8.1310209E-05,   8.3847794E-05,   8.6581669E-05
     +,   8.9520829E-05,   9.2673588E-05,   9.6047996E-05
     +,   9.9651406E-05,   1.0349011E-04,   1.0756933E-04
     +,   1.1189348E-04,   1.1646580E-04,   1.2128798E-04
     +,   1.2636036E-04,   1.3168249E-04,   1.3725288E-04
     +,   1.4306886E-04,   1.4912746E-04,   1.5542639E-04
     +,   1.6196426E-04,   1.6874123E-04,   1.7576129E-04
     +,   1.8303341E-04,   1.9057274E-04,   1.9840349E-04
     +,   2.0656176E-04,   2.1509823E-04,   2.2408001E-04
     +,   2.3359501E-04,   2.4375530E-04,   2.5469929E-04
     +,   2.6659347E-04,   2.7963379E-04,   2.9404700E-04
     +,   3.1008825E-04,   3.2803512E-04,   3.4818525E-04
     +,   3.7084662E-04,   3.9632482E-04,   4.2491246E-04
     +,   4.5687761E-04,   4.9245032E-04,   5.3180801E-04
     +,   5.7507184E-04,   6.2230782E-04,   6.7353161E-04
     +,   7.2872103E-04,   7.8784442E-04,   8.5089961E-04
     +,   9.1795129E-04,   9.8916865E-04,   1.0648792E-03
     +,   1.1455972E-03,   1.2320416E-03,   1.3251433E-03
     +,   1.4260400E-03,   1.5360421E-03,   1.6565904E-03
     +,   1.7892214E-03,   1.9355533E-03,   2.0972751E-03
     +,   2.2761596E-03,   2.4741271E-03,   2.6933358E-03
     +,   2.9363337E-03,   3.2063490E-03,   3.5079683E-03
     +,   3.8481255E-03,   4.2370763E-03,   4.6888073E-03
     +,   5.2198595E-03,   5.8467966E-03,   6.5843337E-03
     +,   7.4470271E-03,   8.4541263E-03,   9.6306652E-03
     +,   1.0996534E-02,   1.2545998E-02,   1.4231873E-02
     +,   1.5963318E-02,   1.7618895E-02,   1.9097332E-02
     +,   2.0423269E-02,   2.1823986E-02,   2.3635423E-02
     +,   2.6087379E-02,   2.9177777E-02,   3.2702282E-02
     +,   3.6410384E-02,   4.0106364E-02,   4.3406393E-02
     +,   4.5723133E-02,   4.6964232E-02,   4.7861196E-02
     +,   4.9171250E-02,   5.0804235E-02,   5.2377455E-02
     +,   5.4132793E-02,   5.6132015E-02,   5.7256822E-02
     +,   5.6445353E-02,   5.4474086E-02,   5.2520011E-02
     +,   5.0546095E-02,   4.8379935E-02,   4.5787111E-02
     +,   4.2280618E-02,   3.8081776E-02,   3.3913385E-02
     +,   3.0174602E-02,   2.6758621E-02,   2.3362264E-02
     +,   1.9956941E-02,   1.6846824E-02,   1.4297312E-02
     +,   1.2293295E-02,   1.0642277E-02,   9.1709811E-03
     +,   7.8062639E-03,   6.5475856E-03,   5.4175970E-03
     +,   4.4352766E-03,   3.6073187E-03,   2.9275140E-03
     +,   2.3789590E-03,   1.9391089E-03,   1.5850347E-03
     +,   1.2972903E-03,   1.0611882E-03,   8.6643267E-04
     +,   7.0583372E-04,   5.7413179E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt113 = Yx/0.365142857142857
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8547441E-05,   3.9028419E-05
     +,   3.9485971E-05,   3.9919323E-05,   4.0327748E-05
     +,   4.0710605E-05,   4.1067302E-05,   4.1397332E-05
     +,   4.1700259E-05,   4.1975749E-05,   4.2223521E-05
     +,   4.2443400E-05,   4.2635282E-05,   4.2799154E-05
     +,   4.2935095E-05,   4.3043277E-05,   4.3123953E-05
     +,   4.3177461E-05,   4.3204247E-05,   4.3204836E-05
     +,   4.3179840E-05,   4.3129960E-05,   4.3055985E-05
     +,   4.2958782E-05,   4.2839310E-05,   4.2698601E-05
     +,   4.2537755E-05,   4.2357970E-05,   4.2160489E-05
     +,   4.1946638E-05,   4.1717805E-05,   4.1475443E-05
     +,   4.1221047E-05,   4.0956169E-05,   4.0682415E-05
     +,   4.0401424E-05,   4.0114883E-05,   3.9824507E-05
     +,   3.9532028E-05,   3.9239236E-05,   3.8947885E-05
     +,   3.8659786E-05,   3.8376736E-05,   3.8100545E-05
     +,   3.7833008E-05,   3.7575912E-05,   3.7331036E-05
     +,   3.7100130E-05,   3.6884929E-05,   3.6687117E-05
     +,   3.6508376E-05,   3.6350313E-05,   3.6214493E-05
     +,   3.6102436E-05,   3.6015605E-05,   3.5955392E-05
     +,   3.5923138E-05,   3.5920089E-05,   3.5947432E-05
     +,   3.6006273E-05,   3.6097608E-05,   3.6222387E-05
     +,   3.6381422E-05,   3.6575453E-05,   3.6805133E-05
     +,   3.7070989E-05,   3.7373458E-05,   3.7712845E-05
     +,   3.8089391E-05,   3.8503185E-05,   3.8954240E-05
     +,   3.9442424E-05,   3.9967526E-05,   4.0529183E-05
     +,   4.1126954E-05,   4.1760315E-05,   4.2428579E-05
     +,   4.3130938E-05,   4.3866559E-05,   4.4634475E-05
     +,   4.5433586E-05,   4.6262776E-05,   4.7120735E-05
     +,   4.8006223E-05,   4.8917740E-05,   4.9853908E-05
     +,   5.0813112E-05,   5.1793828E-05,   5.2794367E-05
     +,   5.3813063E-05,   5.4848271E-05,   5.5898199E-05
     +,   5.6961107E-05,   5.8035232E-05,   5.9118895E-05
     +,   6.0210288E-05,   6.1307779E-05,   6.2409592E-05
     +,   6.3514191E-05,   6.4619897E-05,   6.5725268E-05
     +,   6.6828768E-05,   6.7929082E-05,   6.9024827E-05
     +,   7.0114838E-05,   7.1198017E-05,   7.2273346E-05
     +,   7.3339841E-05,   7.4396768E-05,   7.5443480E-05
     +,   7.6479337E-05,   7.7503944E-05,   7.8516976E-05
     +,   7.9518242E-05,   8.0507627E-05,   8.1485225E-05
     +,   8.2451123E-05,   8.3405663E-05,   8.4349143E-05
     +,   8.5282067E-05,   8.6205036E-05,   8.7118700E-05
     +,   8.8023728E-05,   8.8920962E-05,   8.9811321E-05
     +,   9.0695692E-05,   9.1575021E-05,   9.2450304E-05
     +,   9.3322589E-05,   9.4192859E-05,   9.5062169E-05
     +,   9.5931478E-05,   9.6801858E-05,   9.7674143E-05
     +,   9.8549353E-05,   9.9428347E-05,   1.0031189E-04
     +,   1.0120068E-04,   1.0209539E-04,   1.0299667E-04
     +,   1.0390497E-04,   1.0482065E-04,   1.0574407E-04
     +,   1.0667548E-04,   1.0761502E-04,   1.0856272E-04
     +,   1.0951865E-04,   1.1048272E-04,   1.1145476E-04
     +,   1.1243467E-04,   1.1342233E-04,   1.1441756E-04
     +,   1.1542023E-04,   1.1643035E-04,   1.1744801E-04
     +,   1.1847344E-04,   1.1950701E-04,   1.2054937E-04
     +,   1.2160161E-04,   1.2266496E-04,   1.2374121E-04
     +,   1.2483264E-04,   1.2594205E-04,   1.2707282E-04
     +,   1.2822913E-04,   1.2941596E-04,   1.3063906E-04
     +,   1.3190509E-04,   1.3322175E-04,   1.3459790E-04
     +,   1.3604329E-04,   1.3756892E-04,   1.3918706E-04
     +,   1.4091113E-04,   1.4275571E-04,   1.4473683E-04
     +,   1.4687159E-04,   1.4917838E-04,   1.5167653E-04
     +,   1.5438687E-04,   1.5733116E-04,   1.6053198E-04
     +,   1.6401290E-04,   1.6779848E-04,   1.7191420E-04
     +,   1.7638599E-04,   1.8124057E-04,   1.8650612E-04
     +,   1.9221165E-04,   1.9838729E-04,   2.0506555E-04
     +,   2.1228149E-04,   2.2007317E-04,   2.2848303E-04
     +,   2.3755991E-04,   2.4735989E-04,   2.5794725E-04
     +,   2.6939699E-04,   2.8179697E-04,   2.9524940E-04
     +,   3.0987020E-04,   3.2579128E-04,   3.4316131E-04
     +,   3.6214429E-04,   3.8291587E-04,   4.0566488E-04
     +,   4.3058887E-04,   4.5788902E-04,   4.8776873E-04
     +,   5.2043487E-04,   5.5609399E-04,   5.9495278E-04
     +,   6.3722330E-04,   6.8313169E-04,   7.3292363E-04
     +,   7.8686530E-04,   8.4525388E-04,   9.0841443E-04
     +,   9.7669451E-04,   1.0504363E-03,   1.1299694E-03
     +,   1.2155815E-03,   1.3074932E-03,   1.4058662E-03
     +,   1.5108421E-03,   1.6226034E-03,   1.7414682E-03
     +,   1.8680244E-03,   2.0032567E-03,   2.1486084E-03
     +,   2.3059784E-03,   2.4776086E-03,   2.6659269E-03
     +,   2.8733057E-03,   3.1018902E-03,   3.3536232E-03
     +,   3.6304118E-03,   3.9344481E-03,   4.2685727E-03
     +,   4.6364330E-03,   5.0420822E-03,   5.4890877E-03
     +,   5.9793219E-03,   6.5123034E-03,   7.0858467E-03
     +,   7.6990281E-03,   8.3571896E-03,   9.0774605E-03
     +,   9.8916236E-03,   1.0843086E-02,   1.1975085E-02
     +,   1.3309298E-02,   1.4827928E-02,   1.6486621E-02
     +,   1.8273067E-02,   2.0267462E-02,   2.2613866E-02
     +,   2.5366580E-02,   2.8338764E-02,   3.1206489E-02
     +,   3.3919226E-02,   3.6902532E-02,   4.0485237E-02
     +,   4.4167574E-02,   4.7040969E-02,   4.8952170E-02
     +,   5.0528403E-02,   5.2113887E-02,   5.3437833E-02
     +,   5.4242607E-02,   5.4810409E-02,   5.5877320E-02
     +,   5.7713993E-02,   5.9296627E-02,   5.9206281E-02
     +,   5.7130534E-02,   5.3814024E-02,   4.9990162E-02
     +,   4.6007887E-02,   4.2051513E-02,   3.8079638E-02
     +,   3.3964407E-02,   2.9877694E-02,   2.6152326E-02
     +,   2.2848623E-02,   1.9757001E-02,   1.6739288E-02
     +,   1.3889412E-02,   1.1391632E-02,   9.3367565E-03
     +,   7.6869987E-03,   6.3467650E-03,   5.2312007E-03
     +,   4.2876233E-03,   3.4879041E-03,   2.8150491E-03
     +,   2.2553038E-03,   1.7950189E-03,   1.4205622E-03
     +,   1.1187759E-03,   8.7760109E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt114 = Yx/0.377571428571429
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.4956167E-06,   9.8352302E-06
     +,   1.0183830E-05,   1.0541555E-05,   1.0908538E-05
     +,   1.1284909E-05,   1.1670791E-05,   1.2066303E-05
     +,   1.2471547E-05,   1.2886636E-05,   1.3311653E-05
     +,   1.3746676E-05,   1.4191770E-05,   1.4646983E-05
     +,   1.5112350E-05,   1.5587884E-05,   1.6073578E-05
     +,   1.6569404E-05,   1.7075310E-05,   1.7591221E-05
     +,   1.8117025E-05,   1.8652596E-05,   1.9197751E-05
     +,   1.9752317E-05,   2.0316027E-05,   2.0888632E-05
     +,   2.1469821E-05,   2.2059236E-05,   2.2656493E-05
     +,   2.3261158E-05,   2.3872755E-05,   2.4490764E-05
     +,   2.5114625E-05,   2.5743728E-05,   2.6377420E-05
     +,   2.7015009E-05,   2.7655751E-05,   2.8298851E-05
     +,   2.8943517E-05,   2.9588842E-05,   3.0233956E-05
     +,   3.0877909E-05,   3.1519721E-05,   3.2158398E-05
     +,   3.2792897E-05,   3.3422170E-05,   3.4045137E-05
     +,   3.4660708E-05,   3.5267771E-05,   3.5865229E-05
     +,   3.6451951E-05,   3.7026843E-05,   3.7588783E-05
     +,   3.8136717E-05,   3.8669532E-05,   3.9186216E-05
     +,   3.9685747E-05,   4.0167142E-05,   4.0629482E-05
     +,   4.1071868E-05,   4.1493477E-05,   4.1893527E-05
     +,   4.2271302E-05,   4.2626172E-05,   4.2957581E-05
     +,   4.3265009E-05,   4.3548080E-05,   4.3806442E-05
     +,   4.4039884E-05,   4.4248245E-05,   4.4431483E-05
     +,   4.4589633E-05,   4.4722838E-05,   4.4831329E-05
     +,   4.4915436E-05,   4.4975583E-05,   4.5012286E-05
     +,   4.5026165E-05,   4.5017900E-05,   4.4988272E-05
     +,   4.4938159E-05,   4.4868495E-05,   4.4780300E-05
     +,   4.4674660E-05,   4.4552722E-05,   4.4415690E-05
     +,   4.4264823E-05,   4.4101398E-05,   4.3926768E-05
     +,   4.3742290E-05,   4.3549331E-05,   4.3349308E-05
     +,   4.3143627E-05,   4.2933672E-05,   4.2720836E-05
     +,   4.2506512E-05,   4.2292024E-05,   4.2078707E-05
     +,   4.1867836E-05,   4.1660642E-05,   4.1458301E-05
     +,   4.1261941E-05,   4.1072621E-05,   4.0891322E-05
     +,   4.0718969E-05,   4.0556373E-05,   4.0404309E-05
     +,   4.0263451E-05,   4.0134364E-05,   4.0017545E-05
     +,   3.9913401E-05,   3.9822244E-05,   3.9744300E-05
     +,   3.9679708E-05,   3.9628510E-05,   3.9590675E-05
     +,   3.9566094E-05,   3.9554554E-05,   3.9555816E-05
     +,   3.9569535E-05,   3.9595314E-05,   3.9632712E-05
     +,   3.9681239E-05,   3.9740349E-05,   3.9809478E-05
     +,   3.9888037E-05,   3.9975414E-05,   4.0071001E-05
     +,   4.0174196E-05,   4.0284402E-05,   4.0401050E-05
     +,   4.0523610E-05,   4.0651597E-05,   4.0784580E-05
     +,   4.0922205E-05,   4.1064170E-05,   4.1210296E-05
     +,   4.1360487E-05,   4.1514759E-05,   4.1673247E-05
     +,   4.1836236E-05,   4.2004114E-05,   4.2177464E-05
     +,   4.2357013E-05,   4.2543645E-05,   4.2738451E-05
     +,   4.2942709E-05,   4.3157881E-05,   4.3385622E-05
     +,   4.3627861E-05,   4.3886717E-05,   4.4164539E-05
     +,   4.4463930E-05,   4.4787768E-05,   4.5139179E-05
     +,   4.5521600E-05,   4.5938723E-05,   4.6394638E-05
     +,   4.6893707E-05,   4.7440681E-05,   4.8040714E-05
     +,   4.8699443E-05,   4.9422895E-05,   5.0217670E-05
     +,   5.1090967E-05,   5.2050658E-05,   5.3105305E-05
     +,   5.4264219E-05,   5.5537723E-05,   5.6937202E-05
     +,   5.8474947E-05,   6.0164570E-05,   6.2021049E-05
     +,   6.4060914E-05,   6.6301996E-05,   6.8763991E-05
     +,   7.1468370E-05,   7.4438241E-05,   7.7698547E-05
     +,   8.1276186E-05,   8.5199914E-05,   8.9499896E-05
     +,   9.4207753E-05,   9.9356694E-05,   1.0498094E-04
     +,   1.1111501E-04,   1.1779364E-04,   1.2505162E-04
     +,   1.3292309E-04,   1.4144013E-04,   1.5063358E-04
     +,   1.6053182E-04,   1.7115947E-04,   1.8253746E-04
     +,   1.9468294E-04,   2.0760836E-04,   2.2132005E-04
     +,   2.3581825E-04,   2.5109760E-04,   2.6714645E-04
     +,   2.8394390E-04,   3.0146152E-04,   3.1966335E-04
     +,   3.3850429E-04,   3.5792799E-04,   3.7787005E-04
     +,   3.9825638E-04,   4.1900316E-04,   4.4001889E-04
     +,   4.6120980E-04,   4.8248307E-04,   5.0375232E-04
     +,   5.2494963E-04,   5.4603914E-04,   5.6703336E-04
     +,   5.8801012E-04,   6.0913822E-04,   6.3070259E-04
     +,   6.5312814E-04,   6.7700201E-04,   7.0309715E-04
     +,   7.3238357E-04,   7.6602917E-04,   8.0538786E-04
     +,   8.5197570E-04,   9.0742047E-04,   9.7338588E-04
     +,   1.0514737E-03,   1.1431101E-03,   1.2493895E-03
     +,   1.3709072E-03,   1.5075946E-03,   1.6585960E-03
     +,   1.8221851E-03,   1.9957849E-03,   2.1761875E-03
     +,   2.3599367E-03,   2.5439002E-03,   2.7260822E-03
     +,   2.9065404E-03,   3.0882587E-03,   3.2777668E-03
     +,   3.4851988E-03,   3.7234896E-03,   4.0065823E-03
     +,   4.3469612E-03,   4.7535081E-03,   5.2308263E-03
     +,   5.7807919E-03,   6.4055054E-03,   7.1092695E-03
     +,   7.8967195E-03,   8.7686935E-03,   9.7254589E-03
     +,   1.0789384E-02,   1.2042587E-02,   1.3637667E-02
     +,   1.5722854E-02,   1.8289872E-02,   2.1084208E-02
     +,   2.3738490E-02,   2.6061576E-02,   2.8157558E-02
     +,   3.0220740E-02,   3.2318011E-02,   3.4435451E-02
     +,   3.6610525E-02,   3.8971566E-02,   4.1652121E-02
     +,   4.4694960E-02,   4.8201028E-02,   5.1934265E-02
     +,   5.4995246E-02,   5.7528965E-02,   6.0498349E-02
     +,   6.2719099E-02,   6.2542222E-02,   6.0859833E-02
     +,   5.8483455E-02,   5.5516284E-02,   5.2856755E-02
     +,   5.0281558E-02,   4.6765979E-02,   4.2358138E-02
     +,   3.7573460E-02,   3.2800090E-02,   2.8436719E-02
     +,   2.4658382E-02,   2.1226533E-02,   1.7793203E-02
     +,   1.4301052E-02,   1.1001708E-02,   8.1863636E-03
     +,   5.9829741E-03,   4.3523856E-03,   3.1776957E-03
     +,   2.3378583E-03,   1.7359193E-03,   1.3017188E-03
     +,   9.8647375E-04,   7.5693976E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt115 = Yx/0.359857142857143
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9666816E-06,   2.0686841E-06
     +,   2.1747287E-06,   2.2849122E-06,   2.3993316E-06
     +,   2.5180843E-06,   2.6412679E-06,   2.7689819E-06
     +,   2.9013215E-06,   3.0383919E-06,   3.1802915E-06
     +,   3.3271226E-06,   3.4789875E-06,   3.6359922E-06
     +,   3.7982429E-06,   3.9658480E-06,   4.1389189E-06
     +,   4.3175705E-06,   4.5019178E-06,   4.6920836E-06
     +,   4.8881898E-06,   5.0903664E-06,   5.2987421E-06
     +,   5.5134647E-06,   5.7346647E-06,   5.9625017E-06
     +,   6.1971255E-06,   6.4386995E-06,   6.6873913E-06
     +,   6.9433768E-06,   7.2068397E-06,   7.4779700E-06
     +,   7.7569666E-06,   8.0440386E-06,   8.3393979E-06
     +,   8.6432701E-06,   8.9558862E-06,   9.2774808E-06
     +,   9.6083158E-06,   9.9486251E-06,   1.0298687E-05
     +,   1.0658762E-05,   1.1029125E-05,   1.1410052E-05
     +,   1.1801826E-05,   1.2204730E-05,   1.2619048E-05
     +,   1.3045063E-05,   1.3483056E-05,   1.3933308E-05
     +,   1.4396086E-05,   1.4871655E-05,   1.5360258E-05
     +,   1.5862153E-05,   1.6377537E-05,   1.6906632E-05
     +,   1.7449613E-05,   1.8006634E-05,   1.8577821E-05
     +,   1.9163268E-05,   1.9763040E-05,   2.0377169E-05
     +,   2.1005597E-05,   2.1648280E-05,   2.2305130E-05
     +,   2.2975932E-05,   2.3660506E-05,   2.4358535E-05
     +,   2.5069718E-05,   2.5793595E-05,   2.6529755E-05
     +,   2.7277601E-05,   2.8036571E-05,   2.8805935E-05
     +,   2.9584964E-05,   3.0372850E-05,   3.1168674E-05
     +,   3.1971431E-05,   3.2780092E-05,   3.3593580E-05
     +,   3.4410645E-05,   3.5230089E-05,   3.6050540E-05
     +,   3.6870690E-05,   3.7689035E-05,   3.8504157E-05
     +,   3.9314469E-05,   4.0118466E-05,   4.0914489E-05
     +,   4.1700943E-05,   4.2476204E-05,   4.3238590E-05
     +,   4.3986423E-05,   4.4718072E-05,   4.5431923E-05
     +,   4.6126308E-05,   4.6799691E-05,   4.7450470E-05
     +,   4.8077218E-05,   4.8678427E-05,   4.9252787E-05
     +,   4.9798957E-05,   5.0315772E-05,   5.0802064E-05
     +,   5.1256840E-05,   5.1679177E-05,   5.2068281E-05
     +,   5.2423460E-05,   5.2744144E-05,   5.3029911E-05
     +,   5.3280455E-05,   5.3495605E-05,   5.3675325E-05
     +,   5.3819716E-05,   5.3929012E-05,   5.4003605E-05
     +,   5.4043994E-05,   5.4050837E-05,   5.4024884E-05
     +,   5.3967065E-05,   5.3878401E-05,   5.3760028E-05
     +,   5.3613217E-05,   5.3439311E-05,   5.3239772E-05
     +,   5.3016167E-05,   5.2770101E-05,   5.2503321E-05
     +,   5.2217576E-05,   5.1914707E-05,   5.1596595E-05
     +,   5.1265175E-05,   5.0922394E-05,   5.0570230E-05
     +,   5.0210670E-05,   4.9845708E-05,   4.9477352E-05
     +,   4.9107588E-05,   4.8738380E-05,   4.8371632E-05
     +,   4.8009289E-05,   4.7653230E-05,   4.7305271E-05
     +,   4.6967187E-05,   4.6640733E-05,   4.6327612E-05
     +,   4.6029410E-05,   4.5747747E-05,   4.5484197E-05
     +,   4.5240238E-05,   4.5017347E-05,   4.4816967E-05
     +,   4.4640568E-05,   4.4489574E-05,   4.4365475E-05
     +,   4.4269800E-05,   4.4204149E-05,   4.4170250E-05
     +,   4.4169967E-05,   4.4205350E-05,   4.4278710E-05
     +,   4.4392629E-05,   4.4550059E-05,   4.4754343E-05
     +,   4.5009325E-05,   4.5319404E-05,   4.5689587E-05
     +,   4.6125577E-05,   4.6633832E-05,   4.7221689E-05
     +,   4.7897327E-05,   4.8669834E-05,   4.9549333E-05
     +,   5.0546918E-05,   5.1674600E-05,   5.2945394E-05
     +,   5.4373242E-05,   5.5972803E-05,   5.7759393E-05
     +,   5.9748949E-05,   6.1957806E-05,   6.4402324E-05
     +,   6.7098714E-05,   7.0063077E-05,   7.3311006E-05
     +,   7.6857126E-05,   8.0715145E-05,   8.4897983E-05
     +,   8.9417634E-05,   9.4284602E-05,   9.9509263E-05
     +,   1.0510178E-04,   1.1107223E-04,   1.1743190E-04
     +,   1.2419464E-04,   1.3137779E-04,   1.3900305E-04
     +,   1.4709834E-04,   1.5570011E-04,   1.6485392E-04
     +,   1.7461555E-04,   1.8505192E-04,   1.9624240E-04
     +,   2.0827776E-04,   2.2125768E-04,   2.3529094E-04
     +,   2.5049123E-04,   2.6697238E-04,   2.8484466E-04
     +,   3.0421111E-04,   3.2516336E-04,   3.4777616E-04
     +,   3.7210874E-04,   3.9820696E-04,   4.2610793E-04
     +,   4.5584689E-04,   4.8746957E-04,   5.2105222E-04
     +,   5.5671530E-04,   5.9463840E-04,   6.3508382E-04
     +,   6.7840650E-04,   7.2506175E-04,   7.7561062E-04
     +,   8.3072612E-04,   8.9119136E-04,   9.5789914E-04
     +,   1.0318721E-03,   1.1143006E-03,   1.2065906E-03
     +,   1.3104310E-03,   1.4278610E-03,   1.5613199E-03
     +,   1.7135891E-03,   1.8875775E-03,   2.0859761E-03
     +,   2.3106979E-03,   2.5622284E-03,   2.8391196E-03
     +,   3.1378155E-03,   3.4529737E-03,   3.7783515E-03
     +,   4.1081244E-03,   4.4381763E-03,   4.7667869E-03
     +,   5.0942805E-03,   5.4216725E-03,   5.7487604E-03
     +,   6.0728779E-03,   6.3900906E-03,   6.7000943E-03
     +,   7.0142387E-03,   7.3631713E-03,   7.7977828E-03
     +,   8.3784163E-03,   9.1545200E-03,   1.0147657E-02
     +,   1.1352939E-02,   1.2758346E-02,   1.4358848E-02
     +,   1.6139386E-02,   1.8030623E-02,   1.9875987E-02
     +,   2.1464130E-02,   2.2669513E-02,   2.3674523E-02
     +,   2.5061846E-02,   2.7441656E-02,   3.0708797E-02
     +,   3.3870012E-02,   3.6097303E-02,   3.7763860E-02
     +,   3.9979260E-02,   4.3575391E-02,   4.8686694E-02
     +,   5.4541592E-02,   5.9435990E-02,   6.1496362E-02
     +,   6.0787708E-02,   5.9789330E-02,   6.0060017E-02
     +,   6.0544297E-02,   5.9273612E-02,   5.5229861E-02
     +,   4.9528822E-02,   4.4036288E-02,   3.9518114E-02
     +,   3.5667054E-02,   3.1980239E-02,   2.8222481E-02
     +,   2.4342444E-02,   2.0393210E-02,   1.6505305E-02
     +,   1.2840699E-02,   9.5883943E-03,   6.9215265E-03
     +,   4.9073040E-03,   3.4793520E-03,   2.5007538E-03
     +,   1.8359548E-03,   1.3819991E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt116 = Yx/0.351020833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7629085E-05,   1.8211211E-05
     +,   1.8807787E-05,   1.9418732E-05,   2.0043917E-05
     +,   2.0683176E-05,   2.1336307E-05,   2.2003051E-05
     +,   2.2683118E-05,   2.3376182E-05,   2.4081857E-05
     +,   2.4799720E-05,   2.5529291E-05,   2.6270049E-05
     +,   2.7021444E-05,   2.7782849E-05,   2.8553615E-05
     +,   2.9333047E-05,   3.0120393E-05,   3.0914871E-05
     +,   3.1715655E-05,   3.2521886E-05,   3.3332639E-05
     +,   3.4147030E-05,   3.4964032E-05,   3.5782698E-05
     +,   3.6601981E-05,   3.7420843E-05,   3.8238224E-05
     +,   3.9053040E-05,   3.9864201E-05,   4.0670609E-05
     +,   4.1471165E-05,   4.2264764E-05,   4.3050313E-05
     +,   4.3826705E-05,   4.4592889E-05,   4.5347784E-05
     +,   4.6090394E-05,   4.6819656E-05,   4.7534628E-05
     +,   4.8234360E-05,   4.8917933E-05,   4.9584476E-05
     +,   5.0233208E-05,   5.0863313E-05,   5.1474093E-05
     +,   5.2064883E-05,   5.2635078E-05,   5.3184132E-05
     +,   5.3711567E-05,   5.4216951E-05,   5.4699918E-05
     +,   5.5160213E-05,   5.5597582E-05,   5.6011879E-05
     +,   5.6403012E-05,   5.6770954E-05,   5.7115751E-05
     +,   5.7437515E-05,   5.7736390E-05,   5.8012643E-05
     +,   5.8266516E-05,   5.8498386E-05,   5.8708643E-05
     +,   5.8897742E-05,   5.9066173E-05,   5.9214464E-05
     +,   5.9343227E-05,   5.9453054E-05,   5.9544611E-05
     +,   5.9618571E-05,   5.9675662E-05,   5.9716589E-05
     +,   5.9742084E-05,   5.9752943E-05,   5.9749902E-05
     +,   5.9733753E-05,   5.9705239E-05,   5.9665152E-05
     +,   5.9614234E-05,   5.9553255E-05,   5.9482925E-05
     +,   5.9403981E-05,   5.9317110E-05,   5.9222984E-05
     +,   5.9122271E-05,   5.9015536E-05,   5.8903432E-05
     +,   5.8786474E-05,   5.8665188E-05,   5.8540045E-05
     +,   5.8411519E-05,   5.8279998E-05,   5.8145855E-05
     +,   5.8009417E-05,   5.7870981E-05,   5.7730798E-05
     +,   5.7589074E-05,   5.7446014E-05,   5.7301717E-05
     +,   5.7156329E-05,   5.7009882E-05,   5.6862449E-05
     +,   5.6714023E-05,   5.6564586E-05,   5.6414083E-05
     +,   5.6262481E-05,   5.6109675E-05,   5.5955548E-05
     +,   5.5800003E-05,   5.5642911E-05,   5.5484128E-05
     +,   5.5323522E-05,   5.5160956E-05,   5.4996297E-05
     +,   5.4829423E-05,   5.4660199E-05,   5.4488566E-05
     +,   5.4314416E-05,   5.4137705E-05,   5.3958389E-05
     +,   5.3776508E-05,   5.3592092E-05,   5.3405205E-05
     +,   5.3215997E-05,   5.3024654E-05,   5.2831390E-05
     +,   5.2636507E-05,   5.2440369E-05,   5.2243384E-05
     +,   5.2046056E-05,   5.1848951E-05,   5.1652747E-05
     +,   5.1458173E-05,   5.1266084E-05,   5.1077393E-05
     +,   5.0893184E-05,   5.0714581E-05,   5.0542898E-05
     +,   5.0379513E-05,   5.0225990E-05,   5.0084007E-05
     +,   4.9955423E-05,   4.9842227E-05,   4.9746635E-05
     +,   4.9670976E-05,   4.9617855E-05,   4.9590060E-05
     +,   4.9590613E-05,   4.9622759E-05,   4.9690010E-05
     +,   4.9796159E-05,   4.9945302E-05,   5.0141840E-05
     +,   5.0390492E-05,   5.0696304E-05,   5.1064722E-05
     +,   5.1501520E-05,   5.2012900E-05,   5.2605446E-05
     +,   5.3286192E-05,   5.4062544E-05,   5.4942295E-05
     +,   5.5933753E-05,   5.7045618E-05,   5.8286907E-05
     +,   5.9667054E-05,   6.1195824E-05,   6.2883373E-05
     +,   6.4739950E-05,   6.6775974E-05,   6.9002133E-05
     +,   7.1429051E-05,   7.4067117E-05,   7.6926714E-05
     +,   8.0017890E-05,   8.3350089E-05,   8.6932057E-05
     +,   9.0772002E-05,   9.4877265E-05,   9.9253870E-05
     +,   1.0390649E-04,   1.0883882E-04,   1.1405307E-04
     +,   1.1954948E-04,   1.2532664E-04,   1.3138166E-04
     +,   1.3771009E-04,   1.4430496E-04,   1.5115843E-04
     +,   1.5826104E-04,   1.6560149E-04,   1.7316746E-04
     +,   1.8094602E-04,   1.8892401E-04,   1.9708744E-04
     +,   2.0542282E-04,   2.1391809E-04,   2.2256264E-04
     +,   2.3134777E-04,   2.4026788E-04,   2.4932183E-04
     +,   2.5851410E-04,   2.6785457E-04,   2.7736204E-04
     +,   2.8706525E-04,   2.9700404E-04,   3.0723211E-04
     +,   3.1782032E-04,   3.2885888E-04,   3.4045943E-04
     +,   3.5275944E-04,   3.6592505E-04,   3.8015601E-04
     +,   3.9568634E-04,   4.1278952E-04,   4.3178329E-04
     +,   4.5303084E-04,   4.7694182E-04,   5.0397613E-04
     +,   5.3464266E-04,   5.6949374E-04,   6.0911837E-04
     +,   6.5413571E-04,   7.0517632E-04,   7.6285761E-04
     +,   8.2775962E-04,   9.0040098E-04,   9.8120573E-04
     +,   1.0704685E-03,   1.1683443E-03,   1.2748472E-03
     +,   1.3898680E-03,   1.5132084E-03,   1.6446798E-03
     +,   1.7841995E-03,   1.9319041E-03,   2.0882506E-03
     +,   2.2540763E-03,   2.4305282E-03,   2.6188658E-03
     +,   2.8201963E-03,   3.0352182E-03,   3.2641552E-03
     +,   3.5071219E-03,   3.7651167E-03,   4.0415321E-03
     +,   4.3436964E-03,   4.6835304E-03,   5.0764545E-03
     +,   5.5379318E-03,   6.0784342E-03,   6.6993502E-03
     +,   7.3925895E-03,   8.1447940E-03,   8.9437775E-03
     +,   9.7837755E-03,   1.0670217E-02,   1.1629976E-02
     +,   1.2726267E-02,   1.4055493E-02,   1.5696308E-02
     +,   1.7626246E-02,   1.9693259E-02,   2.1720609E-02
     +,   2.3678357E-02,   2.5727499E-02,   2.8039649E-02
     +,   3.0545879E-02,   3.2883823E-02,   3.4689039E-02
     +,   3.6048200E-02,   3.7611652E-02,   4.0156424E-02
     +,   4.3992966E-02,   4.8644669E-02,   5.3051449E-02
     +,   5.6336425E-02,   5.8612429E-02,   6.0647327E-02
     +,   6.2569618E-02,   6.3530847E-02,   6.2744260E-02
     +,   6.0547419E-02,   5.7580102E-02,   5.3628046E-02
     +,   4.8431810E-02,   4.2372350E-02,   3.6070190E-02
     +,   3.0053511E-02,   2.4693944E-02,   2.0149086E-02
     +,   1.6334651E-02,   1.3063312E-02,   1.0226450E-02
     +,   7.8370525E-03,   5.9359102E-03,   4.5021852E-03
     +,   3.4479005E-03,   2.6666310E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt117 = Yx/0.351020833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2508352E-05,   1.2728378E-05
     +,   1.2946881E-05,   1.3163793E-05,   1.3379065E-05
     +,   1.3592651E-05,   1.3804533E-05,   1.4014700E-05
     +,   1.4223157E-05,   1.4429932E-05,   1.4635066E-05
     +,   1.4838613E-05,   1.5040648E-05,   1.5241263E-05
     +,   1.5440568E-05,   1.5638690E-05,   1.5835776E-05
     +,   1.6031985E-05,   1.6227499E-05,   1.6422513E-05
     +,   1.6617245E-05,   1.6811920E-05,   1.7006789E-05
     +,   1.7202114E-05,   1.7398163E-05,   1.7595241E-05
     +,   1.7793642E-05,   1.7993687E-05,   1.8195700E-05
     +,   1.8400026E-05,   1.8607008E-05,   1.8817007E-05
     +,   1.9030385E-05,   1.9247511E-05,   1.9468765E-05
     +,   1.9694522E-05,   1.9925163E-05,   2.0161067E-05
     +,   2.0402629E-05,   2.0650210E-05,   2.0904197E-05
     +,   2.1164960E-05,   2.1432867E-05,   2.1708263E-05
     +,   2.1991505E-05,   2.2282929E-05,   2.2582857E-05
     +,   2.2891605E-05,   2.3209466E-05,   2.3536724E-05
     +,   2.3873637E-05,   2.4220457E-05,   2.4577399E-05
     +,   2.4944684E-05,   2.5322470E-05,   2.5710939E-05
     +,   2.6110214E-05,   2.6520414E-05,   2.6941620E-05
     +,   2.7373895E-05,   2.7817267E-05,   2.8271752E-05
     +,   2.8737308E-05,   2.9213896E-05,   2.9701458E-05
     +,   3.0199866E-05,   3.0709001E-05,   3.1228676E-05
     +,   3.1758733E-05,   3.2298933E-05,   3.2849050E-05
     +,   3.3408774E-05,   3.3977849E-05,   3.4555909E-05
     +,   3.5142624E-05,   3.5737619E-05,   3.6340502E-05
     +,   3.6950798E-05,   3.7568087E-05,   3.8191924E-05
     +,   3.8821763E-05,   3.9457136E-05,   4.0097479E-05
     +,   4.0742259E-05,   4.1390889E-05,   4.2042804E-05
     +,   4.2697367E-05,   4.3354012E-05,   4.4012053E-05
     +,   4.4670884E-05,   4.5329867E-05,   4.5988319E-05
     +,   4.6645568E-05,   4.7300928E-05,   4.7953767E-05
     +,   4.8603346E-05,   4.9249040E-05,   4.9890084E-05
     +,   5.0525890E-05,   5.1155697E-05,   5.1778890E-05
     +,   5.2394756E-05,   5.3002688E-05,   5.3602009E-05
     +,   5.4192096E-05,   5.4772379E-05,   5.5342236E-05
     +,   5.5901095E-05,   5.6448422E-05,   5.6983772E-05
     +,   5.7506597E-05,   5.8016518E-05,   5.8513091E-05
     +,   5.8996022E-05,   5.9464975E-05,   5.9919734E-05
     +,   6.0360082E-05,   6.0785907E-05,   6.1197155E-05
     +,   6.1593790E-05,   6.1975938E-05,   6.2343730E-05
     +,   6.2697378E-05,   6.3037216E-05,   6.3363637E-05
     +,   6.3677086E-05,   6.3978172E-05,   6.4267508E-05
     +,   6.4545864E-05,   6.4814034E-05,   6.5072934E-05
     +,   6.5323555E-05,   6.5566965E-05,   6.5804306E-05
     +,   6.6036773E-05,   6.6265675E-05,   6.6492306E-05
     +,   6.6718021E-05,   6.6944267E-05,   6.7172463E-05
     +,   6.7404057E-05,   6.7640467E-05,   6.7883178E-05
     +,   6.8133559E-05,   6.8393012E-05,   6.8662819E-05
     +,   6.8944231E-05,   6.9238420E-05,   6.9546411E-05
     +,   6.9869158E-05,   7.0207498E-05,   7.0562077E-05
     +,   7.0933391E-05,   7.1321796E-05,   7.1727525E-05
     +,   7.2150549E-05,   7.2590730E-05,   7.3047704E-05
     +,   7.3521049E-05,   7.4010044E-05,   7.4513940E-05
     +,   7.5031880E-05,   7.5562872E-05,   7.6105942E-05
     +,   7.6660086E-05,   7.7224460E-05,   7.7798322E-05
     +,   7.8381119E-05,   7.8972793E-05,   7.9573634E-05
     +,   8.0184633E-05,   8.0807491E-05,   8.1444930E-05
     +,   8.2100858E-05,   8.2780520E-05,   8.3490937E-05
     +,   8.4241023E-05,   8.5041851E-05,   8.5907152E-05
     +,   8.6853521E-05,   8.7900757E-05,   8.9072135E-05
     +,   9.0394678E-05,   9.1899623E-05,   9.3622446E-05
     +,   9.5602969E-05,   9.7885386E-05,   1.0051844E-04
     +,   1.0355506E-04,   1.0705174E-04,   1.1106842E-04
     +,   1.1566776E-04,   1.2091368E-04,   1.2687063E-04
     +,   1.3360262E-04,   1.4117130E-04,   1.4963427E-04
     +,   1.5904311E-04,   1.6944276E-04,   1.8086904E-04
     +,   1.9334619E-04,   2.0688595E-04,   2.2148729E-04
     +,   2.3713463E-04,   2.5379597E-04,   2.7142564E-04
     +,   2.8996417E-04,   3.0933804E-04,   3.2946345E-04
     +,   3.5025075E-04,   3.7160871E-04,   3.9344691E-04
     +,   4.1568596E-04,   4.3826594E-04,   4.6115494E-04
     +,   4.8435843E-04,   5.0793152E-04,   5.3199282E-04
     +,   5.5673433E-04,   5.8242743E-04,   6.0943514E-04
     +,   6.3821126E-04,   6.6929217E-04,   7.0328341E-04
     +,   7.4083917E-04,   7.8262377E-04,   8.2926272E-04
     +,   8.8129175E-04,   9.3910343E-04,   1.0028901E-03
     +,   1.0725979E-03,   1.1479129E-03,   1.2282821E-03
     +,   1.3129733E-03,   1.4011846E-03,   1.4922398E-03
     +,   1.5858116E-03,   1.6821760E-03,   1.7824870E-03
     +,   1.8889841E-03,   2.0050888E-03,   2.1353159E-03
     +,   2.2849808E-03,   2.4596918E-03,   2.6646212E-03
     +,   2.9036391E-03,   3.1784636E-03,   3.4879935E-03
     +,   3.8279700E-03,   4.1912049E-03,   4.5687761E-03
     +,   4.9519776E-03,   5.3350381E-03,   5.7181385E-03
     +,   6.1100675E-03,   6.5298160E-03,   7.0062615E-03
     +,   7.5746723E-03,   8.2683964E-03,   9.1058658E-03
     +,   1.0078886E-02,   1.1152652E-02,   1.2283305E-02
     +,   1.3439776E-02,   1.4605774E-02,   1.5761847E-02
     +,   1.6891159E-02,   1.8042861E-02,   1.9390542E-02
     +,   2.1161642E-02,   2.3441371E-02,   2.6054665E-02
     +,   2.8655186E-02,   3.0868558E-02,   3.2454692E-02
     +,   3.3690982E-02,   3.5507839E-02,   3.8631834E-02
     +,   4.2815972E-02,   4.7506984E-02,   5.2350149E-02
     +,   5.6615978E-02,   5.9510060E-02,   6.0994413E-02
     +,   6.1279856E-02,   6.0176022E-02,   5.7703108E-02
     +,   5.4417945E-02,   5.0794635E-02,   4.6784915E-02
     +,   4.1970890E-02,   3.6105797E-02,   2.9550910E-02
     +,   2.3175066E-02,   1.7791532E-02,   1.3710806E-02
     +,   1.0793024E-02,   8.7294932E-03,   7.2266189E-03
     +,   6.0624140E-03,   5.0921519E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt118 = Yx/0.3285625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt1188(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.7907637E-06,   6.0235402E-06
     +,   6.2640497E-06,   6.5124773E-06,   6.7690103E-06
     +,   7.0338306E-06,   7.3071255E-06,   7.5890775E-06
     +,   7.8798621E-06,   8.1796652E-06,   8.4886588E-06
     +,   8.8070146E-06,   9.1348993E-06,   9.4724755E-06
     +,   9.8199007E-06,   1.0177322E-05,   1.0544885E-05
     +,   1.0922727E-05,   1.1310975E-05,   1.1709744E-05
     +,   1.2119149E-05,   1.2539281E-05,   1.2970227E-05
     +,   1.3412083E-05,   1.3864885E-05,   1.4328703E-05
     +,   1.4803572E-05,   1.5289517E-05,   1.5786547E-05
     +,   1.6294662E-05,   1.6813849E-05,   1.7344069E-05
     +,   1.7885281E-05,   1.8437429E-05,   1.9000428E-05
     +,   1.9574203E-05,   2.0158646E-05,   2.0753638E-05
     +,   2.1359076E-05,   2.1974791E-05,   2.2600652E-05
     +,   2.3236504E-05,   2.3882170E-05,   2.4537483E-05
     +,   2.5202251E-05,   2.5876296E-05,   2.6559423E-05
     +,   2.7251444E-05,   2.7952156E-05,   2.8661376E-05
     +,   2.9378918E-05,   3.0104578E-05,   3.0838182E-05
     +,   3.1579595E-05,   3.2328593E-05,   3.3085067E-05
     +,   3.3848872E-05,   3.4619869E-05,   3.5397959E-05
     +,   3.6183043E-05,   3.6975041E-05,   3.7773916E-05
     +,   3.8579579E-05,   3.9392045E-05,   4.0211333E-05
     +,   4.1037401E-05,   4.1870364E-05,   4.2710202E-05
     +,   4.3557047E-05,   4.4410939E-05,   4.5272034E-05
     +,   4.6140387E-05,   4.7016183E-05,   4.7899495E-05
     +,   4.8790505E-05,   4.9689359E-05,   5.0596173E-05
     +,   5.1511048E-05,   5.2434119E-05,   5.3365529E-05
     +,   5.4305285E-05,   5.5253502E-05,   5.6210156E-05
     +,   5.7175279E-05,   5.8148737E-05,   5.9130500E-05
     +,   6.0120314E-05,   6.1118044E-05,   6.2123319E-05
     +,   6.3135805E-05,   6.4155094E-05,   6.5180619E-05
     +,   6.6211731E-05,   6.7247776E-05,   6.8287962E-05
     +,   6.9331320E-05,   7.0376911E-05,   7.1423579E-05
     +,   7.2470146E-05,   7.3515228E-05,   7.4557480E-05
     +,   7.5595286E-05,   7.6627068E-05,   7.7651042E-05
     +,   7.8665420E-05,   7.9668287E-05,   8.0657628E-05
     +,   8.1631326E-05,   8.2587263E-05,   8.3523293E-05
     +,   8.4437059E-05,   8.5326377E-05,   8.6188862E-05
     +,   8.7022243E-05,   8.7824170E-05,   8.8592380E-05
     +,   8.9324560E-05,   9.0018541E-05,   9.0672133E-05
     +,   9.1283284E-05,   9.1850015E-05,   9.2370472E-05
     +,   9.2842842E-05,   9.3265611E-05,   9.3637304E-05
     +,   9.3956631E-05,   9.4222509E-05,   9.4434057E-05
     +,   9.4590541E-05,   9.4691502E-05,   9.4736672E-05
     +,   9.4726005E-05,   9.4659699E-05,   9.4538205E-05
     +,   9.4362178E-05,   9.4132491E-05,   9.3850307E-05
     +,   9.3517017E-05,   9.3134171E-05,   9.2703558E-05
     +,   9.2227259E-05,   9.1707429E-05,   9.1146525E-05
     +,   9.0547015E-05,   8.9911744E-05,   8.9243549E-05
     +,   8.8545377E-05,   8.7820379E-05,   8.7071785E-05
     +,   8.6302869E-05,   8.5516913E-05,   8.4717351E-05
     +,   8.3907609E-05,   8.3091050E-05,   8.2271137E-05
     +,   8.1451268E-05,   8.0634833E-05,   7.9825208E-05
     +,   7.9025689E-05,   7.8239638E-05,   7.7470286E-05
     +,   7.6720928E-05,   7.5994903E-05,   7.5295524E-05
     +,   7.4626252E-05,   7.3990544E-05,   7.3392184E-05
     +,   7.2835152E-05,   7.2323717E-05,   7.1862603E-05
     +,   7.1457041E-05,   7.1112969E-05,   7.0837043E-05
     +,   7.0636976E-05,   7.0521543E-05,   7.0500901E-05
     +,   7.0586735E-05,   7.0792550E-05,   7.1133887E-05
     +,   7.1628623E-05,   7.2297204E-05,   7.3162955E-05
     +,   7.4252312E-05,   7.5595162E-05,   7.7225086E-05
     +,   7.9179394E-05,   8.1499304E-05,   8.4230051E-05
     +,   8.7421038E-05,   9.1124850E-05,   9.5397700E-05
     +,   1.0029863E-04,   1.0588835E-04,   1.1222834E-04
     +,   1.1938006E-04,   1.2740337E-04,   1.3635401E-04
     +,   1.4628227E-04,   1.5723181E-04,   1.6923712E-04
     +,   1.8232105E-04,   1.9649373E-04,   2.1175276E-04
     +,   2.2808206E-04,   2.4545021E-04,   2.6381580E-04
     +,   2.8312791E-04,   3.0332900E-04,   3.2436123E-04
     +,   3.4617356E-04,   3.6872874E-04,   3.9200869E-04
     +,   4.1602433E-04,   4.4082530E-04,   4.6650428E-04
     +,   4.9320038E-04,   5.2110379E-04,   5.5045821E-04
     +,   5.8155501E-04,   6.1472575E-04,   6.5033970E-04
     +,   6.8878999E-04,   7.3048024E-04,   7.7581150E-04
     +,   8.2517613E-04,   8.7893894E-04,   9.3742250E-04
     +,   1.0008978E-03,   1.0695806E-03,   1.1436215E-03
     +,   1.2231042E-03,   1.3080654E-03,   1.3985402E-03
     +,   1.4946269E-03,   1.5965883E-03,   1.7050194E-03
     +,   1.8210302E-03,   1.9464218E-03,   2.0838268E-03
     +,   2.2367134E-03,   2.4091469E-03,   2.6052257E-03
     +,   2.8282665E-03,   3.0798125E-03,   3.3587194E-03
     +,   3.6606870E-03,   3.9786026E-03,   4.3038055E-03
     +,   4.6280394E-03,   4.9455864E-03,   5.2549727E-03
     +,   5.5593806E-03,   5.8656540E-03,   6.1821472E-03
     +,   6.5163150E-03,   6.8729301E-03,   7.2540115E-03
     +,   7.6610548E-03,   8.0988733E-03,   8.5792486E-03
     +,   9.1214571E-03,   9.7474903E-03,   1.0473372E-02
     +,   1.1303009E-02,   1.2231832E-02,   1.3260297E-02
     +,   1.4404806E-02,   1.5690550E-02,   1.7123327E-02
     +,   1.8657919E-02,   2.0202311E-02,   2.1688858E-02
     +,   2.3173992E-02,   2.4846772E-02,   2.6875043E-02
     +,   2.9212758E-02,   3.1587452E-02,   3.3713710E-02
     +,   3.5527144E-02,   3.7189294E-02,   3.8916983E-02
     +,   4.0876634E-02,   4.3109573E-02,   4.5512207E-02
     +,   4.8060339E-02,   5.0780300E-02,   5.3198423E-02
     +,   5.4249670E-02,   5.3081982E-02,   4.9661435E-02
     +,   4.4615619E-02,   3.8897283E-02,   3.3365987E-02
     +,   2.8351661E-02,   2.3747440E-02,   1.9458251E-02
     +,   1.5590631E-02,   1.2297207E-02,   9.6132802E-03
     +,   7.4605104E-03,   5.7347380E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt1188 = Yx/0.3031875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.5321684E-06,   9.8000819E-06
     +,   1.0071952E-05,   1.0347722E-05,   1.0627343E-05
     +,   1.0910754E-05,   1.1197901E-05,   1.1488723E-05
     +,   1.1783152E-05,   1.2081146E-05,   1.2382633E-05
     +,   1.2687561E-05,   1.2995869E-05,   1.3307500E-05
     +,   1.3622402E-05,   1.3940518E-05,   1.4261804E-05
     +,   1.4586208E-05,   1.4913691E-05,   1.5244216E-05
     +,   1.5577745E-05,   1.5914256E-05,   1.6253716E-05
     +,   1.6596126E-05,   1.6941456E-05,   1.7289722E-05
     +,   1.7640919E-05,   1.7995064E-05,   1.8352184E-05
     +,   1.8712302E-05,   1.9075469E-05,   1.9441730E-05
     +,   1.9811154E-05,   2.0183808E-05,   2.0559783E-05
     +,   2.0939171E-05,   2.1322083E-05,   2.1708629E-05
     +,   2.2098962E-05,   2.2493212E-05,   2.2891536E-05
     +,   2.3294113E-05,   2.3701117E-05,   2.4112755E-05
     +,   2.4529219E-05,   2.4950737E-05,   2.5377543E-05
     +,   2.5809873E-05,   2.6247986E-05,   2.6692138E-05
     +,   2.7142612E-05,   2.7599692E-05,   2.8063654E-05
     +,   2.8534832E-05,   2.9013490E-05,   2.9499979E-05
     +,   2.9994593E-05,   3.0497662E-05,   3.1009517E-05
     +,   3.1530479E-05,   3.2060874E-05,   3.2601038E-05
     +,   3.3151275E-05,   3.3711913E-05,   3.4283297E-05
     +,   3.4865690E-05,   3.5459441E-05,   3.6064797E-05
     +,   3.6682086E-05,   3.7311533E-05,   3.7953443E-05
     +,   3.8608010E-05,   3.9275499E-05,   3.9956085E-05
     +,   4.0649986E-05,   4.1357383E-05,   4.2078413E-05
     +,   4.2813183E-05,   4.3561813E-05,   4.4324424E-05
     +,   4.5101020E-05,   4.5891702E-05,   4.6696419E-05
     +,   4.7515205E-05,   4.8347974E-05,   4.9194728E-05
     +,   5.0055311E-05,   5.0929677E-05,   5.1817613E-05
     +,   5.2719010E-05,   5.3633699E-05,   5.4561420E-05
     +,   5.5501936E-05,   5.6455010E-05,   5.7420377E-05
     +,   5.8397702E-05,   5.9386697E-05,   6.0386956E-05
     +,   6.1398183E-05,   6.2419924E-05,   6.3451807E-05
     +,   6.4493368E-05,   6.5544184E-05,   6.6603716E-05
     +,   6.7671506E-05,   6.8747038E-05,   6.9829730E-05
     +,   7.0918984E-05,   7.2014205E-05,   7.3114796E-05
     +,   7.4219992E-05,   7.5329175E-05,   7.6441553E-05
     +,   7.7556389E-05,   7.8672798E-05,   7.9790014E-05
     +,   8.0907033E-05,   8.2022998E-05,   8.3136852E-05
     +,   8.4247578E-05,   8.5354113E-05,   8.6455329E-05
     +,   8.7549961E-05,   8.8636873E-05,   8.9714733E-05
     +,   9.0782290E-05,   9.1838134E-05,   9.2880866E-05
     +,   9.3909075E-05,   9.4921270E-05,   9.5916017E-05
     +,   9.6891774E-05,   9.7847093E-05,   9.8780394E-05
     +,   9.9690231E-05,   1.0057515E-04,   1.0143362E-04
     +,   1.0226426E-04,   1.0306574E-04,   1.0383674E-04
     +,   1.0457603E-04,   1.0528245E-04,   1.0595500E-04
     +,   1.0659274E-04,   1.0719483E-04,   1.0776061E-04
     +,   1.0828956E-04,   1.0878134E-04,   1.0923566E-04
     +,   1.0965251E-04,   1.1003210E-04,   1.1037467E-04
     +,   1.1068078E-04,   1.1095114E-04,   1.1118675E-04
     +,   1.1138869E-04,   1.1155834E-04,   1.1169726E-04
     +,   1.1180723E-04,   1.1189026E-04,   1.1194854E-04
     +,   1.1198458E-04,   1.1200100E-04,   1.1200069E-04
     +,   1.1198678E-04,   1.1196266E-04,   1.1193190E-04
     +,   1.1189842E-04,   1.1186634E-04,   1.1184013E-04
     +,   1.1182453E-04,   1.1182464E-04,   1.1184593E-04
     +,   1.1189424E-04,   1.1197593E-04,   1.1209775E-04
     +,   1.1226709E-04,   1.1249180E-04,   1.1278044E-04
     +,   1.1314224E-04,   1.1358718E-04,   1.1412607E-04
     +,   1.1477050E-04,   1.1553316E-04,   1.1642770E-04
     +,   1.1746886E-04,   1.1867259E-04,   1.2005626E-04
     +,   1.2163877E-04,   1.2344064E-04,   1.2548447E-04
     +,   1.2779539E-04,   1.3040125E-04,   1.3333329E-04
     +,   1.3662741E-04,   1.4032460E-04,   1.4447245E-04
     +,   1.4912628E-04,   1.5435135E-04,   1.6022458E-04
     +,   1.6683589E-04,   1.7429081E-04,   1.8271257E-04
     +,   1.9224372E-04,   2.0304596E-04,   2.1530189E-04
     +,   2.2921438E-04,   2.4500216E-04,   2.6289758E-04
     +,   2.8314139E-04,   3.0597544E-04,   3.3163125E-04
     +,   3.6032090E-04,   3.9222848E-04,   4.2749790E-04
     +,   4.6621988E-04,   5.0842762E-04,   5.5409566E-04
     +,   6.0313736E-04,   6.5540650E-04,   7.1071723E-04
     +,   7.6885556E-04,   8.2959747E-04,   8.9273328E-04
     +,   9.5810211E-04,   1.0256094E-03,   1.0952501E-03
     +,   1.1671379E-03,   1.2415277E-03,   1.3188294E-03
     +,   1.3996164E-03,   1.4846311E-03,   1.5747822E-03
     +,   1.6711177E-03,   1.7747791E-03,   1.8869676E-03
     +,   2.0088993E-03,   2.1417576E-03,   2.2867115E-03
     +,   2.4449553E-03,   2.6177694E-03,   2.8065471E-03
     +,   3.0128187E-03,   3.2382079E-03,   3.4843618E-03
     +,   3.7529853E-03,   4.0461994E-03,   4.3673720E-03
     +,   4.7222045E-03,   5.1195389E-03,   5.5708690E-03
     +,   6.0873609E-03,   6.6744587E-03,   7.3264078E-03
     +,   8.0244262E-03,   8.7418687E-03,   9.4559416E-03
     +,   1.0160521E-02,   1.0871315E-02,   1.1617570E-02
     +,   1.2421672E-02,   1.3277692E-02,   1.4143749E-02
     +,   1.4959586E-02,   1.5685754E-02,   1.6343065E-02
     +,   1.7020065E-02,   1.7830402E-02,   1.8841676E-02
     +,   2.0040277E-02,   2.1376656E-02,   2.2844173E-02
     +,   2.4487874E-02,   2.6294634E-02,   2.8072132E-02
     +,   2.9552804E-02,   3.0758165E-02,   3.2177333E-02
     +,   3.4309592E-02,   3.6918432E-02,   3.8998075E-02
     +,   3.9816707E-02,   3.9959483E-02,   4.0931959E-02
     +,   4.3427967E-02,   4.6258613E-02,   4.7456913E-02
     +,   4.6183400E-02,   4.3087047E-02,   3.9220758E-02
     +,   3.5197657E-02,   3.1168967E-02,   2.7114501E-02
     +,   2.3061167E-02,   1.9155819E-02,   1.5596762E-02
     +,   1.2527588E-02,   9.9865273E-03,   7.9256697E-03
     +,   6.2597329E-03,   4.9085808E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt120 = Yx/0.292063829787234
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.9142818E-05,   6.1411134E-05
     +,   6.3779742E-05,   6.6253226E-05,   6.8836292E-05
     +,   7.1533846E-05,   7.4350857E-05,   7.7292520E-05
     +,   8.0364123E-05,   8.3571264E-05,   8.6919623E-05
     +,   9.0415146E-05,   9.4064031E-05,   9.7872711E-05
     +,   1.0184805E-04,   1.0599711E-04,   1.1032748E-04
     +,   1.1484703E-04,   1.1956422E-04,   1.2448800E-04
     +,   1.2962782E-04,   1.3499390E-04,   1.4059688E-04
     +,   1.4644857E-04,   1.5256091E-04,   1.5894744E-04
     +,   1.6562216E-04,   1.7260028E-04,   1.7989821E-04
     +,   1.8753350E-04,   1.9552551E-04,   2.0389512E-04
     +,   2.1266527E-04,   2.2186148E-04,   2.3151211E-04
     +,   2.4164896E-04,   2.5230783E-04,   2.6352966E-04
     +,   2.7536158E-04,   2.8785612E-04,   3.0107526E-04
     +,   3.1508863E-04,   3.2997603E-04,   3.4582787E-04
     +,   3.6274610E-04,   3.8084458E-04,   4.0024979E-04
     +,   4.2110105E-04,   4.4355018E-04,   4.6776255E-04
     +,   4.9391721E-04,   5.2220712E-04,   5.5284268E-04
     +,   5.8605376E-04,   6.2209030E-04,   6.6123344E-04
     +,   7.0379605E-04,   7.5013167E-04,   8.0064149E-04
     +,   8.5578091E-04,   9.1606966E-04,   9.8209851E-04
     +,   1.0545360E-03,   1.1341537E-03,   1.2218370E-03
     +,   1.3186047E-03,   1.4256558E-03,   1.5443740E-03
     +,   1.6763795E-03,   1.8235008E-03,   1.9877735E-03
     +,   2.1713362E-03,   2.3763406E-03,   2.6047484E-03
     +,   2.8581924E-03,   3.1378318E-03,   3.4443191E-03
     +,   3.7779901E-03,   4.1393568E-03,   4.5298534E-03
     +,   4.9527842E-03,   5.4143299E-03,   5.9239822E-03
     +,   6.4943773E-03,   7.1400446E-03,   7.8759165E-03
     +,   8.7159863E-03,   9.6737090E-03,   1.0762834E-02
     +,   1.1997642E-02,   1.3389013E-02,   1.4936206E-02
     +,   1.6620507E-02,   1.8413002E-02,   2.0304624E-02
     +,   2.2347920E-02,   2.4670158E-02,   2.7412260E-02
     +,   3.0603610E-02,   3.4062479E-02,   3.7438631E-02
     +,   4.0401362E-02,   4.2827230E-02,   4.4804830E-02
     +,   4.6457965E-02,   4.7776319E-02,   4.8627947E-02
     +,   4.8904359E-02,   4.8612937E-02,   4.7834914E-02
     +,   4.6637587E-02,   4.5051113E-02,   4.3115839E-02
     +,   4.0932149E-02,   3.8655296E-02,   3.6429547E-02
     +,   3.4316275E-02,   3.2275595E-02,   3.0224552E-02
     +,   2.8122716E-02,   2.6017781E-02,   2.4022771E-02
     +,   2.2251397E-02,   2.0762056E-02,   1.9541211E-02
     +,   1.8525029E-02,   1.7635921E-02,   1.6812345E-02
     +,   1.6020715E-02,   1.5251493E-02,   1.4507307E-02
     +,   1.3792291E-02,   1.3107006E-02,   1.2449311E-02
     +,   1.1817571E-02,   1.1212816E-02,   1.0638135E-02
     +,   1.0096216E-02,   9.5869834E-03,   9.1069583E-03
     +,   8.6504463E-03,   8.2118222E-03,   7.7874768E-03
     +,   7.3769568E-03,   6.9827507E-03,   6.6089379E-03
     +,   6.2596775E-03,   5.9377826E-03,   5.6438874E-03
     +,   5.3762598E-03,   5.1312079E-03,   4.9038008E-03
     +,   4.6886564E-03,   4.4806991E-03,   4.2756861E-03
     +,   4.0706373E-03,   3.8639212E-03,   3.6552278E-03
     +,   3.4454025E-03,   3.2362051E-03,   3.0299572E-03
     +,   2.8292462E-03,   2.6366555E-03,   2.4545265E-03
     +,   2.2847860E-03,   2.1288707E-03,   1.9877169E-03
     +,   1.8617727E-03,   1.7510462E-03,   1.6551978E-03
     +,   1.5736248E-03,   1.5055340E-03,   1.4500034E-03
     +,   1.4060384E-03,   1.3726185E-03,   1.3487173E-03
     +,   1.3333187E-03,   1.3254299E-03,   1.3240873E-03
     +,   1.3283603E-03,   1.3373509E-03,   1.3501971E-03
     +,   1.3660743E-03,   1.3842004E-03,   1.4038411E-03
     +,   1.4243094E-03,   1.4449696E-03,   1.4652491E-03
     +,   1.4846399E-03,   1.5026957E-03,   1.5190464E-03
     +,   1.5333965E-03,   1.5455242E-03,   1.5552854E-03
     +,   1.5626111E-03,   1.5675066E-03,   1.5700504E-03
     +,   1.5703810E-03,   1.5686939E-03,   1.5652345E-03
     +,   1.5602885E-03,   1.5541642E-03,   1.5471890E-03
     +,   1.5396920E-03,   1.5319957E-03,   1.5243967E-03
     +,   1.5171674E-03,   1.5105371E-03,   1.5046886E-03
     +,   1.4997468E-03,   1.4957859E-03,   1.4928166E-03
     +,   1.4907939E-03,   1.4896190E-03,   1.4891410E-03
     +,   1.4891676E-03,   1.4894730E-03,   1.4898039E-03
     +,   1.4898903E-03,   1.4894611E-03,   1.4882458E-03
     +,   1.4859879E-03,   1.4824527E-03,   1.4774338E-03
     +,   1.4707579E-03,   1.4622931E-03,   1.4519460E-03
     +,   1.4396632E-03,   1.4254345E-03,   1.4092864E-03
     +,   1.3912828E-03,   1.3715177E-03,   1.3501133E-03
     +,   1.3272110E-03,   1.3029720E-03,   1.2775668E-03
     +,   1.2511729E-03,   1.2239682E-03,   1.1961344E-03
     +,   1.1678388E-03,   1.1392464E-03,   1.1105080E-03
     +,   1.0817656E-03,   1.0531440E-03,   1.0247545E-03
     +,   9.9669502E-04,   9.6904888E-04,   9.4188523E-04
     +,   9.1525825E-04,   8.8921213E-04,   8.6377776E-04
     +,   8.3897472E-04,   8.1481459E-04,   7.9130131E-04
     +,   7.6842791E-04,   7.4618327E-04,   7.2455063E-04
     +,   7.0350891E-04,   6.8303337E-04,   6.6309550E-04
     +,   6.4366637E-04,   6.2471710E-04,   6.0621614E-04
     +,   5.8813288E-04,   5.7043997E-04,   5.5310794E-04
     +,   5.3611147E-04,   5.1942671E-04,   5.0303381E-04
     +,   4.8691282E-04,   4.7104812E-04,   4.5542672E-04
     +,   4.4003976E-04,   4.2487911E-04,   4.0993976E-04
     +,   3.9522097E-04,   3.8072193E-04,   3.6644665E-04
     +,   3.5239835E-04,   3.3858448E-04,   3.2501176E-04
     +,   3.1169006E-04,   2.9862809E-04,   2.8583728E-04
     +,   2.7332708E-04,   2.6110915E-04,   2.4919372E-04
     +,   2.3759040E-04,   2.2630922E-04,   2.1535819E-04
     +,   2.0474564E-04,   1.9447735E-04,   1.8455931E-04
     +,   1.7499474E-04,   1.6578707E-04,   1.5693691E-04
     +,   1.4844465E-04,   1.4030834E-04,   1.3252569E-04
     +,   1.2509212E-04,   1.1800291E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt75 = Yx/0.41398
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9487099E-05,   4.1761985E-05
     +,   4.4150918E-05,   4.6655583E-05,   4.9277241E-05
     +,   5.2016807E-05,   5.4874650E-05,   5.7850681E-05
     +,   6.0944265E-05,   6.4154381E-05,   6.7479326E-05
     +,   7.0916889E-05,   7.4464311E-05,   7.8118377E-05
     +,   8.1875245E-05,   8.5730724E-05,   8.9680099E-05
     +,   9.3718292E-05,   9.7839962E-05,   1.0203954E-04
     +,   1.0631125E-04,   1.1064940E-04,   1.1504824E-04
     +,   1.1950267E-04,   1.2400741E-04,   1.2855825E-04
     +,   1.3315152E-04,   1.3778450E-04,   1.4245568E-04
     +,   1.4716490E-04,   1.5191351E-04,   1.5670464E-04
     +,   1.6154355E-04,   1.6643754E-04,   1.7139624E-04
     +,   1.7643179E-04,   1.8155918E-04,   1.8679581E-04
     +,   1.9216230E-04,   1.9768160E-04,   2.0337991E-04
     +,   2.0928602E-04,   2.1543115E-04,   2.2184916E-04
     +,   2.2857603E-04,   2.3564998E-04,   2.4311044E-04
     +,   2.5099880E-04,   2.5935713E-04,   2.6822885E-04
     +,   2.7765796E-04,   2.8768912E-04,   2.9836723E-04
     +,   3.0973932E-04,   3.2185204E-04,   3.3475563E-04
     +,   3.4850239E-04,   3.6314863E-04,   3.7875702E-04
     +,   3.9539757E-04,   4.1315038E-04,   4.3210867E-04
     +,   4.5238007E-04,   4.7409211E-04,   4.9739541E-04
     +,   5.2246283E-04,   5.4949935E-04,   5.7873770E-04
     +,   6.1044772E-04,   6.4493000E-04,   6.8252528E-04
     +,   7.2360295E-04,   7.6857139E-04,   8.1785920E-04
     +,   8.7192329E-04,   9.3123788E-04,   9.9628069E-04
     +,   1.0675292E-03,   1.1454582E-03,   1.2305288E-03
     +,   1.3231781E-03,   1.4238408E-03,   1.5329324E-03
     +,   1.6508922E-03,   1.7781765E-03,   1.9153188E-03
     +,   2.0629272E-03,   2.2217480E-03,   2.3926443E-03
     +,   2.5766271E-03,   2.7748202E-03,   2.9884009E-03
     +,   3.2185386E-03,   3.4663558E-03,   3.7328668E-03
     +,   4.0189498E-03,   4.3254481E-03,   4.6532257E-03
     +,   5.0034914E-03,   5.3781443E-03,   5.7805008E-03
     +,   6.2161549E-03,   6.6942233E-03,   7.2282343E-03
     +,   7.8365328E-03,   8.5410168E-03,   9.3635749E-03
     +,   1.0320775E-02,   1.1418577E-02,   1.2651076E-02
     +,   1.4007119E-02,   1.5485965E-02,   1.7113689E-02
     +,   1.8949872E-02,   2.1072837E-02,   2.3549115E-02
     +,   2.6401335E-02,   2.9595230E-02,   3.3055868E-02
     +,   3.6714233E-02,   4.0550321E-02,   4.4559821E-02
     +,   4.8606921E-02,   5.2269861E-02,   5.4913294E-02
     +,   5.6067109E-02,   5.5813249E-02,   5.4749399E-02
     +,   5.3530544E-02,   5.2484937E-02,   5.1637355E-02
     +,   5.0900273E-02,   5.0104167E-02,   4.8958372E-02
     +,   4.7176093E-02,   4.4700276E-02,   4.1778538E-02
     +,   3.8807835E-02,   3.6109667E-02,   3.3825554E-02
     +,   3.1951115E-02,   3.0401008E-02,   2.9041681E-02
     +,   2.7719740E-02,   2.6315246E-02,   2.4790820E-02
     +,   2.3193520E-02,   2.1608200E-02,   2.0102076E-02
     +,   1.8696982E-02,   1.7375290E-02,   1.6102694E-02
     +,   1.4850087E-02,   1.3605980E-02,   1.2378272E-02
     +,   1.1188918E-02,   1.0064692E-02,   9.0285847E-03
     +,   8.0941999E-03,   7.2647268E-03,   6.5347948E-03
     +,   5.8943424E-03,   5.3320820E-03,   4.8376163E-03
     +,   4.4022114E-03,   4.0188506E-03,   3.6818050E-03
     +,   3.3862472E-03,   3.1279661E-03,   2.9032903E-03
     +,   2.7090264E-03,   2.5424033E-03,   2.4010187E-03
     +,   2.2828104E-03,   2.1859813E-03,   2.1089434E-03
     +,   2.0502792E-03,   2.0086886E-03,   1.9829581E-03
     +,   1.9719149E-03,   1.9744097E-03,   1.9892843E-03
     +,   2.0153350E-03,   2.0513169E-03,   2.0959051E-03
     +,   2.1477093E-03,   2.2052575E-03,   2.2670217E-03
     +,   2.3314287E-03,   2.3968793E-03,   2.4617871E-03
     +,   2.5246046E-03,   2.5838586E-03,   2.6381928E-03
     +,   2.6863997E-03,   2.7274594E-03,   2.7605526E-03
     +,   2.7851013E-03,   2.8007857E-03,   2.8075343E-03
     +,   2.8055452E-03,   2.7952609E-03,   2.7773478E-03
     +,   2.7526689E-03,   2.7222480E-03,   2.6872200E-03
     +,   2.6487710E-03,   2.6081013E-03,   2.5663639E-03
     +,   2.5246164E-03,   2.4837728E-03,   2.4445814E-03
     +,   2.4075923E-03,   2.3731473E-03,   2.3413731E-03
     +,   2.3122027E-03,   2.2853960E-03,   2.2605592E-03
     +,   2.2371926E-03,   2.2147337E-03,   2.1925881E-03
     +,   2.1701844E-03,   2.1469991E-03,   2.1226008E-03
     +,   2.0966621E-03,   2.0689787E-03,   2.0394754E-03
     +,   2.0082011E-03,   1.9753145E-03,   1.9410658E-03
     +,   1.9057777E-03,   1.8698092E-03,   1.8335356E-03
     +,   1.7973129E-03,   1.7614636E-03,   1.7262503E-03
     +,   1.6918628E-03,   1.6584169E-03,   1.6259397E-03
     +,   1.5943857E-03,   1.5636384E-03,   1.5335231E-03
     +,   1.5038293E-03,   1.4743180E-03,   1.4447431E-03
     +,   1.4148682E-03,   1.3844807E-03,   1.3534008E-03
     +,   1.3214900E-03,   1.2886618E-03,   1.2548786E-03
     +,   1.2201498E-03,   1.1845372E-03,   1.1481405E-03
     +,   1.1110948E-03,   1.0735592E-03,   1.0357155E-03
     +,   9.9775451E-04,   9.5986703E-04,   9.2223927E-04
     +,   8.8504981E-04,   8.4845995E-04,   8.1261067E-04
     +,   7.7762088E-04,   7.4359105E-04,   7.1059377E-04
     +,   6.7868130E-04,   6.4788654E-04,   6.1822380E-04
     +,   5.8969052E-04,   5.6226930E-04,   5.3593540E-04
     +,   5.1065505E-04,   4.8638837E-04,   4.6309130E-04
     +,   4.4072181E-04,   4.1923483E-04,   3.9859008E-04
     +,   3.7874698E-04,   3.5967075E-04,   3.4132833E-04
     +,   3.2369242E-04,   3.0673697E-04,   2.9044220E-04
     +,   2.7478873E-04,   2.5976202E-04,   2.4534835E-04
     +,   2.3153555E-04,   2.1831413E-04,   2.0567336E-04
     +,   1.9360462E-04,   1.8209740E-04,   1.7114257E-04
     +,   1.6072883E-04,   1.5084533E-04,   1.4147918E-04
     +,   1.3261760E-04,   1.2424575E-04,   1.1634896E-04
     +,   1.0891039E-04,   1.0191377E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt80 = Yx/0.4627
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.5481152E-05,   6.6971887E-05
     +,   6.8462985E-05,   6.9954061E-05,   7.1444760E-05
     +,   7.2934919E-05,   7.4424483E-05,   7.5913442E-05
     +,   7.7401994E-05,   7.8890458E-05,   8.0379265E-05
     +,   8.1868951E-05,   8.3360224E-05,   8.4853906E-05
     +,   8.6350919E-05,   8.7852372E-05,   8.9359470E-05
     +,   9.0873524E-05,   9.2396003E-05,   9.3928487E-05
     +,   9.5472620E-05,   9.7030250E-05,   9.8603312E-05
     +,   1.0019389E-04,   1.0180409E-04,   1.0343629E-04
     +,   1.0509292E-04,   1.0677658E-04,   1.0849003E-04
     +,   1.1023616E-04,   1.1201816E-04,   1.1383939E-04
     +,   1.1570334E-04,   1.1761394E-04,   1.1957534E-04
     +,   1.2159206E-04,   1.2366899E-04,   1.2581144E-04
     +,   1.2802535E-04,   1.3031693E-04,   1.3269333E-04
     +,   1.3516202E-04,   1.3773146E-04,   1.4041079E-04
     +,   1.4321004E-04,   1.4614013E-04,   1.4921295E-04
     +,   1.5244148E-04,   1.5583982E-04,   1.5942310E-04
     +,   1.6320769E-04,   1.6721115E-04,   1.7145212E-04
     +,   1.7595057E-04,   1.8072735E-04,   1.8580470E-04
     +,   1.9120553E-04,   1.9695370E-04,   2.0307375E-04
     +,   2.0959105E-04,   2.1653091E-04,   2.2391927E-04
     +,   2.3178135E-04,   2.4014292E-04,   2.4902946E-04
     +,   2.5846483E-04,   2.6847355E-04,   2.7907800E-04
     +,   2.9030154E-04,   3.0216537E-04,   3.1469186E-04
     +,   3.2790215E-04,   3.4181916E-04,   3.5646607E-04
     +,   3.7186872E-04,   3.8805758E-04,   4.0506528E-04
     +,   4.2293078E-04,   4.4170156E-04,   4.6143451E-04
     +,   4.8219503E-04,   5.0406478E-04,   5.2713702E-04
     +,   5.5152620E-04,   5.7736295E-04,   6.0480379E-04
     +,   6.3402735E-04,   6.6524476E-04,   6.9869420E-04
     +,   7.3465239E-04,   7.7343354E-04,   8.1538974E-04
     +,   8.6091430E-04,   9.1044378E-04,   9.6445350E-04
     +,   1.0234461E-03,   1.0879565E-03,   1.1585216E-03
     +,   1.2356838E-03,   1.3199516E-03,   1.4118116E-03
     +,   1.5116809E-03,   1.6199348E-03,   1.7368918E-03
     +,   1.8628710E-03,   1.9982513E-03,   2.1435767E-03
     +,   2.2997204E-03,   2.4680956E-03,   2.6508691E-03
     +,   2.8511470E-03,   3.0731170E-03,   3.3219298E-03
     +,   3.6034116E-03,   3.9233747E-03,   4.2868438E-03
     +,   4.6971370E-03,   5.1554507E-03,   5.6609092E-03
     +,   6.2115830E-03,   6.8058693E-03,   7.4437382E-03
     +,   8.1270244E-03,   8.8584879E-03,   9.6398434E-03
     +,   1.0470272E-02,   1.1347160E-02,   1.2269308E-02
     +,   1.3242343E-02,   1.4283588E-02,   1.5425528E-02
     +,   1.6716775E-02,   1.8223105E-02,   2.0025173E-02
     +,   2.2205956E-02,   2.4818383E-02,   2.7844679E-02
     +,   3.1177042E-02,   3.4639068E-02,   3.8032021E-02
     +,   4.1180514E-02,   4.3970615E-02,   4.6374053E-02
     +,   4.8426222E-02,   5.0152466E-02,   5.1509507E-02
     +,   5.2425526E-02,   5.2922379E-02,   5.3181086E-02
     +,   5.3443164E-02,   5.3794242E-02,   5.4009296E-02
     +,   5.3634856E-02,   5.2291136E-02,   4.9928218E-02
     +,   4.6800721E-02,   4.3251008E-02,   3.9557740E-02
     +,   3.5929393E-02,   3.2526847E-02,   2.9443210E-02
     +,   2.6680902E-02,   2.4166480E-02,   2.1797298E-02
     +,   1.9494994E-02,   1.7241854E-02,   1.5083443E-02
     +,   1.3098185E-02,   1.1355603E-02,   9.8883025E-03
     +,   8.6879376E-03,   7.7186394E-03,   6.9357604E-03
     +,   6.2997383E-03,   5.7819085E-03,   5.3639729E-03
     +,   5.0346246E-03,   4.7859075E-03,   4.6105101E-03
     +,   4.5004557E-03,   4.4468497E-03,   4.4402229E-03
     +,   4.4711251E-03,   4.5306748E-03,   4.6109273E-03
     +,   4.7050612E-03,   4.8073675E-03,   4.9131177E-03
     +,   5.0183944E-03,   5.1198904E-03,   5.2147876E-03
     +,   5.3006993E-03,   5.3756479E-03,   5.4381141E-03
     +,   5.4871156E-03,   5.5222665E-03,   5.5437451E-03
     +,   5.5522644E-03,   5.5489084E-03,   5.5349609E-03
     +,   5.5116620E-03,   5.4800143E-03,   5.4406305E-03
     +,   5.3936485E-03,   5.3387368E-03,   5.2752332E-03
     +,   5.2022683E-03,   5.1190248E-03,   5.0249086E-03
     +,   4.9197036E-03,   4.8036901E-03,   4.6776901E-03
     +,   4.5430032E-03,   4.4012908E-03,   4.2544822E-03
     +,   4.1046008E-03,   3.9536534E-03,   3.8034818E-03
     +,   3.6557163E-03,   3.5117245E-03,   3.3725861E-03
     +,   3.2391045E-03,   3.1118535E-03,   2.9911785E-03
     +,   2.8772482E-03,   2.7700837E-03,   2.6696031E-03
     +,   2.5756555E-03,   2.4880276E-03,   2.4064821E-03
     +,   2.3307838E-03,   2.2607117E-03,   2.1960575E-03
     +,   2.1366361E-03,   2.0822913E-03,   2.0328809E-03
     +,   1.9882685E-03,   1.9483062E-03,   1.9128380E-03
     +,   1.8816583E-03,   1.8545239E-03,   1.8311399E-03
     +,   1.8111502E-03,   1.7941406E-03,   1.7796397E-03
     +,   1.7671278E-03,   1.7560446E-03,   1.7457982E-03
     +,   1.7357807E-03,   1.7253854E-03,   1.7140131E-03
     +,   1.7010951E-03,   1.6861003E-03,   1.6685533E-03
     +,   1.6480398E-03,   1.6242216E-03,   1.5968436E-03
     +,   1.5657368E-03,   1.5308231E-03,   1.4921135E-03
     +,   1.4497144E-03,   1.4038176E-03,   1.3546917E-03
     +,   1.3026767E-03,   1.2481797E-03,   1.1916513E-03
     +,   1.1335786E-03,   1.0744757E-03,   1.0148631E-03
     +,   9.5525617E-04,   8.9614978E-04,   8.3801540E-04
     +,   7.8128435E-04,   7.2633772E-04,   6.7350344E-04
     +,   6.2305859E-04,   5.7521363E-04,   5.3012703E-04
     +,   4.8789557E-04,   4.4856736E-04,   4.1213713E-04
     +,   3.7856228E-04,   3.4775809E-04,   3.1961428E-04
     +,   2.9399316E-04,   2.7074281E-04,   2.4969724E-04
     +,   2.3068477E-04,   2.1353354E-04,   1.9807178E-04
     +,   1.8413510E-04,   1.7156513E-04,   1.6021487E-04
     +,   1.4994660E-04,   1.4063569E-04,   1.3216787E-04
     +,   1.2444181E-04,   1.1736620E-04,   1.1086153E-04
     +,   1.0485721E-04,   9.9292600E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt85 = Yx/0.4557
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4779885E-05,   3.6211019E-05
     +,   3.7691017E-05,   3.9220107E-05,   4.0798401E-05
     +,   4.2425872E-05,   4.4102362E-05,   4.5827550E-05
     +,   4.7600963E-05,   4.9422040E-05,   5.1289997E-05
     +,   5.3203923E-05,   5.5162764E-05,   5.7165311E-05
     +,   5.9210168E-05,   6.1295861E-05,   6.3420754E-05
     +,   6.5583037E-05,   6.7780871E-05,   7.0012225E-05
     +,   7.2275012E-05,   7.4567070E-05,   7.6886085E-05
     +,   7.9229889E-05,   8.1595979E-05,   8.3982188E-05
     +,   8.6386099E-05,   8.8805413E-05,   9.1237911E-05
     +,   9.3681432E-05,   9.6133874E-05,   9.8593388E-05
     +,   1.0105818E-04,   1.0352668E-04,   1.0599753E-04
     +,   1.0846959E-04,   1.1094202E-04,   1.1341424E-04
     +,   1.1588614E-04,   1.1835762E-04,   1.2082933E-04
     +,   1.2330203E-04,   1.2577699E-04,   1.2825587E-04
     +,   1.3074078E-04,   1.3323427E-04,   1.3573922E-04
     +,   1.3825920E-04,   1.4079802E-04,   1.4335987E-04
     +,   1.4594958E-04,   1.4857219E-04,   1.5123321E-04
     +,   1.5393861E-04,   1.5669428E-04,   1.5950689E-04
     +,   1.6238310E-04,   1.6532971E-04,   1.6835381E-04
     +,   1.7146244E-04,   1.7466278E-04,   1.7796189E-04
     +,   1.8136662E-04,   1.8488384E-04,   1.8852022E-04
     +,   1.9228179E-04,   1.9617479E-04,   2.0020438E-04
     +,   2.0437581E-04,   2.0869347E-04,   2.1316163E-04
     +,   2.1778361E-04,   2.2256270E-04,   2.2750124E-04
     +,   2.3260163E-04,   2.3786604E-04,   2.4329632E-04
     +,   2.4889421E-04,   2.5466227E-04,   2.6060373E-04
     +,   2.6672229E-04,   2.7302394E-04,   2.7951563E-04
     +,   2.8620815E-04,   2.9311434E-04,   3.0025182E-04
     +,   3.0764251E-04,   3.1531486E-04,   3.2330290E-04
     +,   3.3164947E-04,   3.4040635E-04,   3.4963424E-04
     +,   3.5940608E-04,   3.6980677E-04,   3.8093590E-04
     +,   3.9290672E-04,   4.0585015E-04,   4.1991350E-04
     +,   4.3526507E-04,   4.5209174E-04,   4.7060518E-04
     +,   4.9103884E-04,   5.1365612E-04,   5.3874712E-04
     +,   5.6663703E-04,   5.9768959E-04,   6.3230871E-04
     +,   6.7094842E-04,   7.1411947E-04,   7.6239719E-04
     +,   8.1642024E-04,   8.7690714E-04,   9.4464235E-04
     +,   1.0204844E-03,   1.1053316E-03,   1.2001161E-03
     +,   1.3057381E-03,   1.4230359E-03,   1.5526946E-03
     +,   1.6952002E-03,   1.8507661E-03,   2.0192787E-03
     +,   2.2002873E-03,   2.3930506E-03,   2.5965993E-03
     +,   2.8098405E-03,   3.0317479E-03,   3.2614975E-03
     +,   3.4986692E-03,   3.7433971E-03,   3.9965552E-03
     +,   4.2598792E-03,   4.5361631E-03,   4.8292880E-03
     +,   5.1442650E-03,   5.4870597E-03,   5.8642444E-03
     +,   6.2827179E-03,   6.7495257E-03,   7.2719776E-03
     +,   7.8578377E-03,   8.5153766E-03,   9.2521477E-03
     +,   1.0072185E-02,   1.0972102E-02,   1.1939165E-02
     +,   1.2954680E-02,   1.4005097E-02,   1.5098411E-02
     +,   1.6275885E-02,   1.7606763E-02,   1.9160824E-02
     +,   2.0969555E-02,   2.3000492E-02,   2.5170293E-02
     +,   2.7404368E-02,   2.9715095E-02,   3.2235160E-02
     +,   3.5135772E-02,   3.8437974E-02,   4.1869301E-02
     +,   4.4956546E-02,   4.7328994E-02,   4.8927069E-02
     +,   4.9884468E-02,   5.0253510E-02,   4.9901240E-02
     +,   4.8627935E-02,   4.6316326E-02,   4.3010667E-02
     +,   3.8951565E-02,   3.4552131E-02,   3.0278502E-02
     +,   2.6495911E-02,   2.3391146E-02,   2.0999936E-02
     +,   1.9277819E-02,   1.8151714E-02,   1.7543882E-02
     +,   1.7384082E-02,   1.7613137E-02,   1.8176300E-02
     +,   1.9012192E-02,   2.0046163E-02,   2.1187950E-02
     +,   2.2329267E-02,   2.3343032E-02,   2.4093861E-02
     +,   2.4466073E-02,   2.4400989E-02,   2.3921894E-02
     +,   2.3128709E-02,   2.2162950E-02,   2.1161385E-02
     +,   2.0220092E-02,   1.9381939E-02,   1.8645206E-02
     +,   1.7983040E-02,   1.7361928E-02,   1.6752513E-02
     +,   1.6132288E-02,   1.5484317E-02,   1.4796481E-02
     +,   1.4064076E-02,   1.3293584E-02,   1.2504199E-02
     +,   1.1724589E-02,   1.0985583E-02,   1.0311678E-02
     +,   9.7155273E-03,   9.1973273E-03,   8.7480787E-03
     +,   8.3544469E-03,   8.0029601E-03,   7.6823751E-03
     +,   7.3843831E-03,   7.1031540E-03,   6.8347724E-03
     +,   6.5767663E-03,   6.3278666E-03,   6.0877404E-03
     +,   5.8567696E-03,   5.6356699E-03,   5.4251039E-03
     +,   5.2252789E-03,   5.0358074E-03,   4.8556426E-03
     +,   4.6832417E-03,   4.5167464E-03,   4.3543498E-03
     +,   4.1945665E-03,   4.0364345E-03,   3.8796286E-03
     +,   3.7244617E-03,   3.5718258E-03,   3.4229783E-03
     +,   3.2793859E-03,   3.1425371E-03,   3.0137708E-03
     +,   2.8941445E-03,   2.7843858E-03,   2.6848505E-03
     +,   2.5955406E-03,   2.5161109E-03,   2.4459276E-03
     +,   2.3841187E-03,   2.3296203E-03,   2.2812241E-03
     +,   2.2376312E-03,   2.1975110E-03,   2.1595403E-03
     +,   2.1224541E-03,   2.0850990E-03,   2.0464668E-03
     +,   2.0057221E-03,   1.9622406E-03,   1.9156029E-03
     +,   1.8656075E-03,   1.8122509E-03,   1.7557106E-03
     +,   1.6963173E-03,   1.6345208E-03,   1.5708548E-03
     +,   1.5058967E-03,   1.4402501E-03,   1.3744964E-03
     +,   1.3091851E-03,   1.2448106E-03,   1.1818061E-03
     +,   1.1205251E-03,   1.0612500E-03,   1.0041923E-03
     +,   9.4949699E-04,   8.9724548E-04,   8.4746914E-04
     +,   8.0016028E-04,   7.5527228E-04,   7.1273977E-04
     +,   6.7247270E-04,   6.3437520E-04,   5.9834047E-04
     +,   5.6426326E-04,   5.3203508E-04,   5.0155487E-04
     +,   4.7272092E-04,   4.4544108E-04,   4.1962625E-04
     +,   3.9519224E-04,   3.7206366E-04,   3.5016635E-04
     +,   3.2943449E-04,   3.0980440E-04,   2.9121820E-04
     +,   2.7362054E-04,   2.5696127E-04,   2.4119169E-04
     +,   2.2626798E-04,   2.1214740E-04,   1.9879195E-04
     +,   1.8616368E-04,   1.7422900E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt90 = Yx/0.46788
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1383580E-05,   1.1868378E-05
     +,   1.2375110E-05,   1.2905116E-05,   1.3459849E-05
     +,   1.4040859E-05,   1.4649805E-05,   1.5288480E-05
     +,   1.5958776E-05,   1.6662736E-05,   1.7402510E-05
     +,   1.8180384E-05,   1.8998779E-05,   1.9860250E-05
     +,   2.0767471E-05,   2.1723275E-05,   2.2730594E-05
     +,   2.3792498E-05,   2.4912173E-05,   2.6092910E-05
     +,   2.7338107E-05,   2.8651235E-05,   3.0035841E-05
     +,   3.1495598E-05,   3.3034077E-05,   3.4655033E-05
     +,   3.6362129E-05,   3.8159014E-05,   4.0049312E-05
     +,   4.2036583E-05,   4.4124248E-05,   4.6315643E-05
     +,   4.8613914E-05,   5.1022027E-05,   5.3542724E-05
     +,   5.6178513E-05,   5.8931557E-05,   6.1803730E-05
     +,   6.4796681E-05,   6.7911351E-05,   7.1148679E-05
     +,   7.4508855E-05,   7.7991783E-05,   8.1596765E-05
     +,   8.5322681E-05,   8.9167843E-05,   9.3130082E-05
     +,   9.7206663E-05,   1.0139425E-04,   1.0568910E-04
     +,   1.1008677E-04,   1.1458244E-04,   1.1917060E-04
     +,   1.2384563E-04,   1.2860089E-04,   1.3342993E-04
     +,   1.3832538E-04,   1.4328001E-04,   1.4828597E-04
     +,   1.5333538E-04,   1.5842011E-04,   1.6353217E-04
     +,   1.6866310E-04,   1.7380503E-04,   1.7895024E-04
     +,   1.8409088E-04,   1.8921992E-04,   1.9433025E-04
     +,   1.9941608E-04,   2.0447139E-04,   2.0949179E-04
     +,   2.1447305E-04,   2.1941244E-04,   2.2430782E-04
     +,   2.2915880E-04,   2.3396582E-04,   2.3873105E-04
     +,   2.4345766E-04,   2.4815093E-04,   2.5281793E-04
     +,   2.5746718E-04,   2.6210962E-04,   2.6675806E-04
     +,   2.7142788E-04,   2.7613685E-04,   2.8090575E-04
     +,   2.8575776E-04,   2.9072029E-04,   2.9582292E-04
     +,   3.0110002E-04,   3.0658991E-04,   3.1233486E-04
     +,   3.1838176E-04,   3.2478245E-04,   3.3159423E-04
     +,   3.3887831E-04,   3.4670223E-04,   3.5513757E-04
     +,   3.6426101E-04,   3.7415259E-04,   3.8489717E-04
     +,   3.9658014E-04,   4.0928987E-04,   4.2311268E-04
     +,   4.3813477E-04,   4.5443760E-04,   4.7209603E-04
     +,   4.9117592E-04,   5.1173434E-04,   5.3381489E-04
     +,   5.5744365E-04,   5.8263302E-04,   6.0937385E-04
     +,   6.3764153E-04,   6.6738867E-04,   6.9855514E-04
     +,   7.3106197E-04,   7.6482480E-04,   7.9975027E-04
     +,   8.3575246E-04,   8.7276072E-04,   9.1072544E-04
     +,   9.4963930E-04,   9.8954781E-04,   1.0305658E-03
     +,   1.0728842E-03,   1.1167940E-03,   1.1626740E-03
     +,   1.2110145E-03,   1.2623895E-03,   1.3174583E-03
     +,   1.3769340E-03,   1.4415659E-03,   1.5120959E-03
     +,   1.5892421E-03,   1.6736703E-03,   1.7659772E-03
     +,   1.8666947E-03,   1.9763159E-03,   2.0953240E-03
     +,   2.2242200E-03,   2.3635845E-03,   2.5141125E-03
     +,   2.6766341E-03,   2.8520825E-03,   3.0414634E-03
     +,   3.2457716E-03,   3.4657870E-03,   3.7018859E-03
     +,   3.9537842E-03,   4.2201974E-03,   4.4984943E-03
     +,   4.7844783E-03,   5.0722593E-03,   5.3543588E-03
     +,   5.6221024E-03,   5.8663669E-03,   6.0786377E-03
     +,   6.2520979E-03,   6.3827159E-03,   6.4700102E-03
     +,   6.5172194E-03,   6.5308260E-03,   6.5194550E-03
     +,   6.4923447E-03,   6.4577521E-03,   6.4216754E-03
     +,   6.3872780E-03,   6.3552898E-03,   6.3254596E-03
     +,   6.2989891E-03,   6.2817712E-03,   6.2877447E-03
     +,   6.3417610E-03,   6.4806463E-03,   6.7515131E-03
     +,   7.2068456E-03,   7.8977365E-03,   8.8692177E-03
     +,   1.0162822E-02,   1.1828429E-02,   1.3937581E-02
     +,   1.6577387E-02,   1.9802747E-02,   2.3557145E-02
     +,   2.7637025E-02,   3.1791370E-02,   3.5920557E-02
     +,   4.0140767E-02,   4.4536341E-02,   4.8813920E-02
     +,   5.2299120E-02,   5.4353759E-02,   5.4839827E-02
     +,   5.4252859E-02,   5.3366352E-02,   5.2604917E-02
     +,   5.1777285E-02,   5.0475124E-02,   4.8596263E-02
     +,   4.6401627E-02,   4.4204831E-02,   4.2118862E-02
     +,   4.0051252E-02,   3.7861448E-02,   3.5527527E-02
     +,   3.3201169E-02,   3.1084357E-02,   2.9232619E-02
     +,   2.7511766E-02,   2.5757849E-02,   2.3939708E-02
     +,   2.2158386E-02,   2.0537190E-02,   1.9141596E-02
     +,   1.7974734E-02,   1.7005326E-02,   1.6187988E-02
     +,   1.5472914E-02,   1.4814242E-02,   1.4177620E-02
     +,   1.3543568E-02,   1.2905308E-02,   1.2263212E-02
     +,   1.1619762E-02,   1.0977091E-02,   1.0336903E-02
     +,   9.7019309E-03,   9.0776756E-03,   8.4731393E-03
     +,   7.9000806E-03,   7.3708682E-03,   6.8958253E-03
     +,   6.4812158E-03,   6.1283316E-03,   5.8337413E-03
     +,   5.5905180E-03,   5.3897738E-03,   5.2221250E-03
     +,   5.0787777E-03,   4.9521336E-03,   4.8360480E-03
     +,   4.7257622E-03,   4.6176189E-03,   4.5088036E-03
     +,   4.3970803E-03,   4.2806598E-03,   4.1581071E-03
     +,   4.0284363E-03,   3.8911782E-03,   3.7464574E-03
     +,   3.5950348E-03,   3.4382639E-03,   3.2779733E-03
     +,   3.1162680E-03,   2.9553417E-03,   2.7972674E-03
     +,   2.6438364E-03,   2.4964227E-03,   2.3559507E-03
     +,   2.2228975E-03,   2.0973408E-03,   1.9790404E-03
     +,   1.8675277E-03,   1.7622235E-03,   1.6624932E-03
     +,   1.5677253E-03,   1.4773742E-03,   1.3909880E-03
     +,   1.3082032E-03,   1.2287527E-03,   1.1524549E-03
     +,   1.0791977E-03,   1.0089165E-03,   9.4158400E-04
     +,   8.7720138E-04,   8.1577571E-04,   7.5732503E-04
     +,   7.0185447E-04,   6.4936996E-04,   5.9985626E-04
     +,   5.5329083E-04,   5.0962978E-04,   4.6881812E-04
     +,   4.3078038E-04,   3.9543226E-04,   3.6267249E-04
     +,   3.3239019E-04,   3.0446873E-04,   2.7878108E-04
     +,   2.5520005E-04,   2.3359305E-04,   2.1382998E-04
     +,   1.9577963E-04,   1.7931640E-04,   1.6431593E-04
     +,   1.5066144E-04,   1.3823956E-04,   1.2694516E-04
     +,   1.1667800E-04,   1.0734608E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_htt95 = Yx/0.4445
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7814627E-05,   1.8439310E-05
     +,   1.9065503E-05,   1.9691959E-05,   2.0317411E-05
     +,   2.0940564E-05,   2.1560103E-05,   2.2174716E-05
     +,   2.2783059E-05,   2.3383836E-05,   2.3975734E-05
     +,   2.4557465E-05,   2.5127763E-05,   2.5685418E-05
     +,   2.6229245E-05,   2.6758122E-05,   2.7270980E-05
     +,   2.7766842E-05,   2.8244780E-05,   2.8703971E-05
     +,   2.9143670E-05,   2.9563244E-05,   2.9962159E-05
     +,   3.0340012E-05,   3.0696479E-05,   3.1031406E-05
     +,   3.1344731E-05,   3.1636537E-05,   3.1907035E-05
     +,   3.2156589E-05,   3.2385666E-05,   3.2594904E-05
     +,   3.2785047E-05,   3.2956996E-05,   3.3111770E-05
     +,   3.3250508E-05,   3.3374487E-05,   3.3485077E-05
     +,   3.3583779E-05,   3.3672182E-05,   3.3751956E-05
     +,   3.3824868E-05,   3.3892746E-05,   3.3957476E-05
     +,   3.4020988E-05,   3.4085242E-05,   3.4152228E-05
     +,   3.4223918E-05,   3.4302288E-05,   3.4389283E-05
     +,   3.4486795E-05,   3.4596676E-05,   3.4720699E-05
     +,   3.4860535E-05,   3.5017758E-05,   3.5193836E-05
     +,   3.5390083E-05,   3.5607674E-05,   3.5847628E-05
     +,   3.6110792E-05,   3.6397811E-05,   3.6709171E-05
     +,   3.7045113E-05,   3.7405705E-05,   3.7790804E-05
     +,   3.8200007E-05,   3.8632741E-05,   3.9088151E-05
     +,   3.9565221E-05,   4.0062667E-05,   4.0579023E-05
     +,   4.1112573E-05,   4.1661460E-05,   4.2223561E-05
     +,   4.2796622E-05,   4.3378212E-05,   4.3965731E-05
     +,   4.4556404E-05,   4.5147393E-05,   4.5735756E-05
     +,   4.6318379E-05,   4.6892183E-05,   4.7453956E-05
     +,   4.8000526E-05,   4.8528655E-05,   4.9035189E-05
     +,   4.9516930E-05,   4.9970829E-05,   5.0393846E-05
     +,   5.0783077E-05,   5.1135754E-05,   5.1449228E-05
     +,   5.1721006E-05,   5.1948809E-05,   5.2130545E-05
     +,   5.2264309E-05,   5.2348481E-05,   5.2381642E-05
     +,   5.2362651E-05,   5.2290645E-05,   5.2165044E-05
     +,   5.1985568E-05,   5.1752224E-05,   5.1465391E-05
     +,   5.1125746E-05,   5.0734292E-05,   5.0292441E-05
     +,   4.9801965E-05,   4.9265003E-05,   4.8684080E-05
     +,   4.8062229E-05,   4.7402802E-05,   4.6709727E-05
     +,   4.5987308E-05,   4.5240449E-05,   4.4474495E-05
     +,   4.3695400E-05,   4.2909611E-05,   4.2124229E-05
     +,   4.1346873E-05,   4.0585732E-05,   3.9849634E-05
     +,   3.9147955E-05,   3.8490529E-05,   3.7887672E-05
     +,   3.7350153E-05,   3.6888978E-05,   3.6515412E-05
     +,   3.6240723E-05,   3.6076126E-05,   3.6032543E-05
     +,   3.6120469E-05,   3.6349720E-05,   3.6729252E-05
     +,   3.7266989E-05,   3.7969647E-05,   3.8842521E-05
     +,   3.9889434E-05,   4.1112729E-05,   4.2513337E-05
     +,   4.4090753E-05,   4.5843368E-05,   4.7768954E-05
     +,   4.9865041E-05,   5.2129286E-05,   5.4560547E-05
     +,   5.7159483E-05,   5.9929112E-05,   6.2875712E-05
     +,   6.6009685E-05,   6.9345828E-05,   7.2903385E-05
     +,   7.6705983E-05,   8.0781429E-05,   8.5160500E-05
     +,   8.9875008E-05,   9.4956253E-05,   1.0043295E-04
     +,   1.0632855E-04,   1.1265802E-04,   1.1942704E-04
     +,   1.2662986E-04,   1.3424856E-04,   1.4225443E-04
     +,   1.5061133E-04,   1.5928039E-04,   1.6822638E-04
     +,   1.7742768E-04,   1.8688815E-04,   1.9664949E-04
     +,   2.0680387E-04,   2.1750786E-04,   2.2899461E-04
     +,   2.4158179E-04,   2.5567386E-04,   2.7176255E-04
     +,   2.9041510E-04,   3.1225427E-04,   3.3793037E-04
     +,   3.6808680E-04,   4.0331410E-04,   4.4409782E-04
     +,   4.9077003E-04,   5.4346467E-04,   6.0207798E-04
     +,   6.6623784E-04,   7.3529891E-04,   8.0836023E-04
     +,   8.8429230E-04,   9.6177933E-04,   1.0393946E-03
     +,   1.1156627E-03,   1.1891155E-03,   1.2583578E-03
     +,   1.3221084E-03,   1.3792214E-03,   1.4286883E-03
     +,   1.4696422E-03,   1.5013543E-03,   1.5232273E-03
     +,   1.5348031E-03,   1.5357872E-03,   1.5260823E-03
     +,   1.5058239E-03,   1.4754194E-03,   1.4355646E-03
     +,   1.3872435E-03,   1.3316995E-03,   1.2703746E-03
     +,   1.2048176E-03,   1.1365897E-03,   1.0671671E-03
     +,   9.9784625E-04,   9.2967571E-04,   8.6342386E-04
     +,   7.9958228E-04,   7.3838938E-04,   6.7987986E-04
     +,   6.2395423E-04,   5.7045219E-04,   5.1920314E-04
     +,   4.7008018E-04,   4.2303069E-04,   3.7808387E-04
     +,   3.3534097E-04,   2.9495932E-04,   2.5712780E-04
     +,   2.2203515E-04,   1.8984085E-04,   1.6065661E-04
     +,   1.3453417E-04,   1.1145639E-04,   9.1337562E-05
     +,   7.4031901E-05,   5.9346061E-05,   4.7049070E-05
     +,   3.6888181E-05,   2.8602584E-05,   2.1933833E-05
     +,   1.6634865E-05,   1.2477380E-05,   9.2563105E-06
     +,   6.7916071E-06,   4.9286177E-06,   3.5374383E-06
     +,   2.5110940E-06,   1.7629590E-06,   1.2240720E-06
     +,   8.4049037E-07,   5.7069832E-07,   3.8317421E-07
     +,   2.5436944E-07,   1.6694912E-07,   1.0832387E-07
     +,   6.9477061E-08,   4.4044377E-08,   2.7595531E-08
     +,   1.7086599E-08,   1.0454384E-08,   6.3201697E-09
     +,   3.7750807E-09,   2.2278228E-09,   1.2989135E-09
     +,   7.4822221E-10,   4.2588166E-10,   2.3957092E-10
     +,   1.3323288E-10,   7.3297222E-11,   3.9929469E-11
     +,   2.1572482E-11,   1.1586974E-11,   6.2111449E-12
     +,   3.3420070E-12,   1.8198574E-12,   1.0138344E-12
     +,   5.8518565E-13,   3.5413282E-13,   2.2639058E-13
     +,   1.5293275E-13,   1.0844278E-13,   7.9855278E-14
     +,   6.0391077E-14,   4.6465575E-14,   3.6125037E-14
     +,   2.8248227E-14,   2.2152266E-14,   1.7390315E-14
     +,   1.3652076E-14,   1.0711042E-14,   8.3955297E-15
     +,   6.5731006E-15,   5.1397646E-15,   4.0137338E-15
     +,   3.1301565E-15,   2.4377822E-15,   1.8959405E-15
     +,   1.4725160E-15,   1.1420708E-15,   8.8456725E-16
     +,   6.8417101E-16,   5.2844850E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt100 = Yx/0.0134615384615385
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0387016E-06,   5.2851142E-06
     +,   5.5378323E-06,   5.7966313E-06,   6.0612574E-06
     +,   6.3314287E-06,   6.6068346E-06,   6.8871409E-06
     +,   7.1719769E-06,   7.4609611E-06,   7.7536770E-06
     +,   8.0496820E-06,   8.3485147E-06,   8.6496921E-06
     +,   8.9527084E-06,   9.2570426E-06,   9.5621572E-06
     +,   9.8675009E-06,   1.0172513E-05,   1.0476617E-05
     +,   1.0779240E-05,   1.1079798E-05,   1.1377709E-05
     +,   1.1672403E-05,   1.1963289E-05,   1.2249816E-05
     +,   1.2531426E-05,   1.2807583E-05,   1.3077763E-05
     +,   1.3341467E-05,   1.3598220E-05,   1.3847575E-05
     +,   1.4089113E-05,   1.4322450E-05,   1.4547236E-05
     +,   1.4763154E-05,   1.4969934E-05,   1.5167343E-05
     +,   1.5355201E-05,   1.5533353E-05,   1.5701711E-05
     +,   1.5860220E-05,   1.6008880E-05,   1.6147736E-05
     +,   1.6276883E-05,   1.6396456E-05,   1.6506647E-05
     +,   1.6607686E-05,   1.6699849E-05,   1.6783457E-05
     +,   1.6858870E-05,   1.6926488E-05,   1.6986744E-05
     +,   1.7040104E-05,   1.7087070E-05,   1.7128164E-05
     +,   1.7163942E-05,   1.7194967E-05,   1.7221833E-05
     +,   1.7245136E-05,   1.7265489E-05,   1.7283510E-05
     +,   1.7299819E-05,   1.7315038E-05,   1.7329785E-05
     +,   1.7344673E-05,   1.7360302E-05,   1.7377264E-05
     +,   1.7396140E-05,   1.7417487E-05,   1.7441858E-05
     +,   1.7469776E-05,   1.7501756E-05,   1.7538285E-05
     +,   1.7579838E-05,   1.7626873E-05,   1.7679829E-05
     +,   1.7739128E-05,   1.7805181E-05,   1.7878394E-05
     +,   1.7959155E-05,   1.8047858E-05,   1.8144883E-05
     +,   1.8250628E-05,   1.8365479E-05,   1.8489845E-05
     +,   1.8624141E-05,   1.8768811E-05,   1.8924302E-05
     +,   1.9091098E-05,   1.9269723E-05,   1.9460718E-05
     +,   1.9664656E-05,   1.9882164E-05,   2.0113912E-05
     +,   2.0360596E-05,   2.0622982E-05,   2.0901862E-05
     +,   2.1198102E-05,   2.1512584E-05,   2.1846283E-05
     +,   2.2200182E-05,   2.2575347E-05,   2.2972867E-05
     +,   2.3393901E-05,   2.3839662E-05,   2.4311375E-05
     +,   2.4810328E-05,   2.5337857E-05,   2.5895353E-05
     +,   2.6484196E-05,   2.7105880E-05,   2.7761840E-05
     +,   2.8453647E-05,   2.9182818E-05,   2.9950972E-05
     +,   3.0759682E-05,   3.1610623E-05,   3.2505413E-05
     +,   3.3445751E-05,   3.4433346E-05,   3.5469860E-05
     +,   3.6556918E-05,   3.7696209E-05,   3.8889386E-05
     +,   4.0137911E-05,   4.1443316E-05,   4.2806856E-05
     +,   4.4229790E-05,   4.5712986E-05,   4.7257261E-05
     +,   4.8862916E-05,   5.0530074E-05,   5.2258187E-05
     +,   5.4046362E-05,   5.5893088E-05,   5.7796049E-05
     +,   5.9752128E-05,   6.1757477E-05,   6.3807260E-05
     +,   6.5895510E-05,   6.8015128E-05,   7.0157992E-05
     +,   7.2314768E-05,   7.4474672E-05,   7.6625882E-05
     +,   7.8755409E-05,   8.0848884E-05,   8.2890940E-05
     +,   8.4865336E-05,   8.6755019E-05,   8.8542176E-05
     +,   9.0208610E-05,   9.1735987E-05,   9.3106144E-05
     +,   9.4301096E-05,   9.5303643E-05,   9.6097589E-05
     +,   9.6668060E-05,   9.7001699E-05,   9.7087162E-05
     +,   9.6915202E-05,   9.6479031E-05,   9.5774478E-05
     +,   9.4800154E-05,   9.3557486E-05,   9.2050970E-05
     +,   9.0288115E-05,   8.8279296E-05,   8.6037900E-05
     +,   8.3580475E-05,   8.0926882E-05,   7.8100609E-05
     +,   7.5129909E-05,   7.2049945E-05,   6.8905269E-05
     +,   6.5754881E-05,   6.2679697E-05,   5.9792597E-05
     +,   5.7252368E-05,   5.5282209E-05,   5.4193260E-05
     +,   5.4411867E-05,   5.6511446E-05,   6.1247163E-05
     +,   6.9589143E-05,   8.2751212E-05,   1.0220897E-04
     +,   1.2969652E-04,   1.6716644E-04,   2.1671411E-04
     +,   2.8044000E-04,   3.6024689E-04,   4.5758751E-04
     +,   5.7317864E-04,   7.0670212E-04,   8.5653970E-04
     +,   1.0196243E-03,   1.1914476E-03,   1.3662351E-03
     +,   1.5373036E-03,   1.6976087E-03,   1.8403827E-03
     +,   1.9597299E-03,   2.0511262E-03,   2.1117413E-03
     +,   2.1404848E-03,   2.1378475E-03,   2.1055890E-03
     +,   2.0463646E-03,   1.9634082E-03,   1.8603300E-03
     +,   1.7410322E-03,   1.6096850E-03,   1.4707119E-03
     +,   1.3287044E-03,   1.1881990E-03,   1.0533594E-03
     +,   9.2764612E-04,   8.1353879E-04,   7.1234821E-04
     +,   6.2423595E-04,   5.4838764E-04,   4.8329082E-04
     +,   4.2707133E-04,   3.7782031E-04,   3.3385082E-04
     +,   2.9384921E-04,   2.5693001E-04,   2.2261054E-04
     +,   1.9073029E-04,   1.6133797E-04,   1.3458023E-04
     +,   1.1061251E-04,   8.9536639E-05,   7.1361457E-05
     +,   5.5996716E-05,   4.3263939E-05,   3.2916578E-05
     +,   2.4665731E-05,   1.8206487E-05,   1.3239381E-05
     +,   9.4853467E-06,   6.6954626E-06,   4.6560394E-06
     +,   3.1894028E-06,   2.1516951E-06,   1.4292895E-06
     +,   9.3454452E-07,   6.0131254E-07,   3.8060907E-07
     +,   2.3691619E-07,   1.4498579E-07,   8.7209166E-08
     +,   5.1546337E-08,   2.9932799E-08,   1.7075434E-08
     +,   9.5692787E-09,   5.2689821E-09,   2.8515279E-09
     +,   1.5180492E-09,   7.9615403E-10,   4.1241149E-10
     +,   2.1194714E-10,   1.0888820E-10,   5.6598438E-11
     +,   3.0290204E-11,   1.7058230E-11,   1.0316163E-11
     +,   6.7666961E-12,   4.7881707E-12,   3.5944359E-12
     +,   2.8076048E-12,   2.2458244E-12,   1.8200129E-12
     +,   1.4846340E-12,   1.2145704E-12,   9.9458517E-13
     +,   8.1438177E-13,   6.6644178E-13,   5.4491291E-13
     +,   4.4511367E-13,   3.6321019E-13,   2.9606005E-13
     +,   2.4105799E-13,   1.9605753E-13,   1.5927896E-13
     +,   1.2925305E-13,   1.0476926E-13,   8.4826020E-14
     +,   6.8601226E-14,   5.5415755E-14,   4.4713477E-14
     +,   3.6036305E-14,   2.9009723E-14,   2.3326066E-14
     +,   1.8734322E-14,   1.5028911E-14,   1.2042457E-14
     +,   9.6381643E-15,   7.7049615E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt104 = Yx/0.0123846153846154
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7335829E-05,   2.7963577E-05
     +,   2.8581826E-05,   2.9189441E-05,   2.9785280E-05
     +,   3.0368241E-05,   3.0937230E-05,   3.1491203E-05
     +,   3.2029129E-05,   3.2550044E-05,   3.3052995E-05
     +,   3.3537104E-05,   3.4001532E-05,   3.4445497E-05
     +,   3.4868284E-05,   3.5269230E-05,   3.5647754E-05
     +,   3.6003326E-05,   3.6335510E-05,   3.6643927E-05
     +,   3.6928275E-05,   3.7188343E-05,   3.7423986E-05
     +,   3.7635149E-05,   3.7821850E-05,   3.7984195E-05
     +,   3.8122344E-05,   3.8236583E-05,   3.8327227E-05
     +,   3.8394701E-05,   3.8439484E-05,   3.8462138E-05
     +,   3.8463295E-05,   3.8443635E-05,   3.8403927E-05
     +,   3.8344973E-05,   3.8267652E-05,   3.8172882E-05
     +,   3.8061629E-05,   3.7934897E-05,   3.7793732E-05
     +,   3.7639209E-05,   3.7472426E-05,   3.7294511E-05
     +,   3.7106602E-05,   3.6909842E-05,   3.6705387E-05
     +,   3.6494392E-05,   3.6278005E-05,   3.6057361E-05
     +,   3.5833575E-05,   3.5607754E-05,   3.5380966E-05
     +,   3.5154251E-05,   3.4928624E-05,   3.4705045E-05
     +,   3.4484437E-05,   3.4267679E-05,   3.4055596E-05
     +,   3.3848955E-05,   3.3648485E-05,   3.3454835E-05
     +,   3.3268600E-05,   3.3090313E-05,   3.2920430E-05
     +,   3.2759377E-05,   3.2607466E-05,   3.2464988E-05
     +,   3.2332133E-05,   3.2209045E-05,   3.2095806E-05
     +,   3.1992418E-05,   3.1898835E-05,   3.1814950E-05
     +,   3.1740597E-05,   3.1675569E-05,   3.1619587E-05
     +,   3.1572359E-05,   3.1533516E-05,   3.1502685E-05
     +,   3.1479442E-05,   3.1463347E-05,   3.1453936E-05
     +,   3.1450742E-05,   3.1453274E-05,   3.1461062E-05
     +,   3.1473635E-05,   3.1490545E-05,   3.1511350E-05
     +,   3.1535648E-05,   3.1563093E-05,   3.1593358E-05
     +,   3.1626183E-05,   3.1661373E-05,   3.1698812E-05
     +,   3.1738433E-05,   3.1780281E-05,   3.1824475E-05
     +,   3.1871237E-05,   3.1920888E-05,   3.1973846E-05
     +,   3.2030646E-05,   3.2091943E-05,   3.2158463E-05
     +,   3.2231088E-05,   3.2310774E-05,   3.2398591E-05
     +,   3.2495707E-05,   3.2603381E-05,   3.2722946E-05
     +,   3.2855805E-05,   3.3003420E-05,   3.3167285E-05
     +,   3.3348933E-05,   3.3549877E-05,   3.3771645E-05
     +,   3.4015684E-05,   3.4283414E-05,   3.4576140E-05
     +,   3.4895074E-05,   3.5241283E-05,   3.5615645E-05
     +,   3.6018846E-05,   3.6451369E-05,   3.6913443E-05
     +,   3.7404992E-05,   3.7925685E-05,   3.8474827E-05
     +,   3.9051451E-05,   3.9654147E-05,   4.0281233E-05
     +,   4.0930572E-05,   4.1599731E-05,   4.2285810E-05
     +,   4.2985619E-05,   4.3695585E-05,   4.4411780E-05
     +,   4.5129913E-05,   4.5845463E-05,   4.6553650E-05
     +,   4.7249392E-05,   4.7927453E-05,   4.8582471E-05
     +,   4.9208986E-05,   4.9801438E-05,   5.0354338E-05
     +,   5.0862262E-05,   5.1319865E-05,   5.1721992E-05
     +,   5.2063762E-05,   5.2340569E-05,   5.2548177E-05
     +,   5.2682753E-05,   5.2740965E-05,   5.2720039E-05
     +,   5.2617819E-05,   5.2432901E-05,   5.2164702E-05
     +,   5.1813669E-05,   5.1381503E-05,   5.0871393E-05
     +,   5.0288436E-05,   4.9640174E-05,   4.8937309E-05
     +,   4.8194423E-05,   4.7431087E-05,   4.6673220E-05
     +,   4.5954490E-05,   4.5317851E-05,   4.4817400E-05
     +,   4.4520184E-05,   4.4507811E-05,   4.4878016E-05
     +,   4.5745965E-05,   4.7244957E-05,   4.9527189E-05
     +,   5.2764037E-05,   5.7146030E-05,   6.2883417E-05
     +,   7.0207825E-05,   7.9374666E-05,   9.0666137E-05
     +,   1.0439715E-04,   1.2092319E-04,   1.4064765E-04
     +,   1.6402696E-04,   1.9157580E-04,   2.2386755E-04
     +,   2.6152481E-04,   3.0519508E-04,   3.5552646E-04
     +,   4.1311973E-04,   4.7846723E-04,   5.5188971E-04
     +,   6.3347205E-04,   7.2299369E-04,   8.1986591E-04
     +,   9.2309923E-04,   1.0312985E-03,   1.1426737E-03
     +,   1.2550806E-03,   1.3661039E-03,   1.4731642E-03
     +,   1.5736322E-03,   1.6649405E-03,   1.7447295E-03
     +,   1.8109508E-03,   1.8619583E-03,   1.8965894E-03
     +,   1.9142097E-03,   1.9147265E-03,   1.8985751E-03
     +,   1.8666819E-03,   1.8203930E-03,   1.7613879E-03
     +,   1.6915847E-03,   1.6130313E-03,   1.5277913E-03
     +,   1.4378561E-03,   1.3450726E-03,   1.2510710E-03
     +,   1.1572401E-03,   1.0647256E-03,   9.7443501E-04
     +,   8.8706228E-04,   8.0312742E-04,   7.2302372E-04
     +,   6.4704637E-04,   5.7541678E-04,   5.0830835E-04
     +,   4.4586018E-04,   3.8817365E-04,   3.3530575E-04
     +,   2.8726712E-04,   2.4401936E-04,   2.0546096E-04
     +,   1.7143154E-04,   1.4171623E-04,   1.1604944E-04
     +,   9.4123163E-05,   7.5600801E-05,   6.0130507E-05
     +,   4.7355661E-05,   3.6925489E-05,   2.8505521E-05
     +,   2.1785127E-05,   1.6481612E-05,   1.2342936E-05
     +,   9.1492366E-06,   6.7123683E-06,   4.8736320E-06
     +,   3.5016481E-06,   2.4894225E-06,   1.7510259E-06
     +,   1.2184449E-06,   8.3866826E-07,   5.7096867E-07
     +,   3.8445680E-07,   2.5602029E-07,   1.6861331E-07
     +,   1.0983579E-07,   7.0782093E-08,   4.5142194E-08
     +,   2.8508941E-08,   1.7846473E-08,   1.1090171E-08
     +,   6.8565238E-09,   4.2313473E-09,   2.6186573E-09
     +,   1.6353334E-09,   1.0386277E-09,   6.7684380E-10
     +,   4.5643464E-10,   3.2046413E-10,   2.3472568E-10
     +,   1.7890282E-10,   1.4103346E-10,   1.1413178E-10
     +,   9.4122043E-11,   7.8622137E-11,   6.6218434E-11
     +,   5.6054085E-11,   4.7587649E-11,   4.0461568E-11
     +,   3.4424488E-11,   2.9291174E-11,   2.4917459E-11
     +,   2.1187309E-11,   1.8005384E-11,   1.5291275E-11
     +,   1.2977192E-11,   1.1005097E-11,   9.3255802E-12
     +,   7.8960987E-12,   6.6804023E-12,   5.6472210E-12
     +,   4.7698850E-12,   4.0254432E-12,   3.3943213E-12
     +,   2.8596702E-12,   2.4071663E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt106 = Yx/0.0142592592592593
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0785377E-05,   5.1473358E-05
     +,   5.2124644E-05,   5.2737912E-05,   5.3311935E-05
     +,   5.3845637E-05,   5.4338027E-05,   5.4788252E-05
     +,   5.5195585E-05,   5.5559438E-05,   5.5879351E-05
     +,   5.6154982E-05,   5.6386150E-05,   5.6572786E-05
     +,   5.6714987E-05,   5.6812958E-05,   5.6867040E-05
     +,   5.6877721E-05,   5.6845602E-05,   5.6771416E-05
     +,   5.6656023E-05,   5.6500379E-05,   5.6305569E-05
     +,   5.6072771E-05,   5.5803266E-05,   5.5498440E-05
     +,   5.5159748E-05,   5.4788710E-05,   5.4386961E-05
     +,   5.3956181E-05,   5.3498079E-05,   5.3014461E-05
     +,   5.2507126E-05,   5.1977950E-05,   5.1428793E-05
     +,   5.0861581E-05,   5.0278202E-05,   4.9680606E-05
     +,   4.9070655E-05,   4.8450285E-05,   4.7821373E-05
     +,   4.7185782E-05,   4.6545349E-05,   4.5901877E-05
     +,   4.5257129E-05,   4.4612825E-05,   4.3970649E-05
     +,   4.3332220E-05,   4.2699114E-05,   4.2072836E-05
     +,   4.1454852E-05,   4.0846560E-05,   4.0249306E-05
     +,   3.9664334E-05,   3.9092880E-05,   3.8536080E-05
     +,   3.7995025E-05,   3.7470731E-05,   3.6964171E-05
     +,   3.6476227E-05,   3.6007757E-05,   3.5559533E-05
     +,   3.5132311E-05,   3.4726756E-05,   3.4343477E-05
     +,   3.3983088E-05,   3.3646094E-05,   3.3333017E-05
     +,   3.3044285E-05,   3.2780335E-05,   3.2541528E-05
     +,   3.2328233E-05,   3.2140753E-05,   3.1979391E-05
     +,   3.1844414E-05,   3.1736050E-05,   3.1654534E-05
     +,   3.1600055E-05,   3.1572799E-05,   3.1572923E-05
     +,   3.1600561E-05,   3.1655843E-05,   3.1738873E-05
     +,   3.1849722E-05,   3.1988446E-05,   3.2155091E-05
     +,   3.2349650E-05,   3.2572123E-05,   3.2822431E-05
     +,   3.3100496E-05,   3.3406195E-05,   3.3739358E-05
     +,   3.4099747E-05,   3.4487100E-05,   3.4901095E-05
     +,   3.5341320E-05,   3.5807341E-05,   3.6298596E-05
     +,   3.6814505E-05,   3.7354344E-05,   3.7917369E-05
     +,   3.8502683E-05,   3.9109360E-05,   3.9736311E-05
     +,   4.0382405E-05,   4.1046416E-05,   4.1726995E-05
     +,   4.2422675E-05,   4.3131968E-05,   4.3853292E-05
     +,   4.4584915E-05,   4.5325152E-05,   4.6072139E-05
     +,   4.6824080E-05,   4.7579048E-05,   4.8335183E-05
     +,   4.9090551E-05,   4.9843322E-05,   5.0591600E-05
     +,   5.1333634E-05,   5.2067739E-05,   5.2792275E-05
     +,   5.3505726E-05,   5.4206761E-05,   5.4894190E-05
     +,   5.5566921E-05,   5.6224133E-05,   5.6865094E-05
     +,   5.7489349E-05,   5.8096532E-05,   5.8686554E-05
     +,   5.9259397E-05,   5.9815280E-05,   6.0354461E-05
     +,   6.0877377E-05,   6.1384453E-05,   6.1876177E-05
     +,   6.2352941E-05,   6.2815139E-05,   6.3263025E-05
     +,   6.3696592E-05,   6.4115651E-05,   6.4519721E-05
     +,   6.4907981E-05,   6.5279200E-05,   6.5631764E-05
     +,   6.5963613E-05,   6.6272245E-05,   6.6554705E-05
     +,   6.6807639E-05,   6.7027308E-05,   6.7209643E-05
     +,   6.7350418E-05,   6.7445268E-05,   6.7489898E-05
     +,   6.7480221E-05,   6.7412606E-05,   6.7284032E-05
     +,   6.7092507E-05,   6.6837194E-05,   6.6518849E-05
     +,   6.6140172E-05,   6.5706168E-05,   6.5224624E-05
     +,   6.4706532E-05,   6.4166474E-05,   6.3623374E-05
     +,   6.3100895E-05,   6.2628082E-05,   6.2240026E-05
     +,   6.1978630E-05,   6.1893435E-05,   6.2042440E-05
     +,   6.2493244E-05,   6.3324071E-05,   6.4625114E-05
     +,   6.6499902E-05,   6.9066671E-05,   7.2459748E-05
     +,   7.6831377E-05,   8.2352955E-05,   8.9215602E-05
     +,   9.7630895E-05,   1.0783147E-04,   1.2006985E-04
     +,   1.3461534E-04,   1.5175091E-04,   1.7176956E-04
     +,   1.9496659E-04,   2.2162813E-04,   2.5202514E-04
     +,   2.8639854E-04,   3.2494304E-04,   3.6779296E-04
     +,   4.1500974E-04,   4.6656336E-04,   5.2231445E-04
     +,   5.8200327E-04,   6.4524397E-04,   7.1151461E-04
     +,   7.8015070E-04,   8.5035275E-04,   9.2119991E-04
     +,   9.9166203E-04,   1.0606120E-03,   1.1268684E-03
     +,   1.1892186E-03,   1.2464504E-03,   1.2973946E-03
     +,   1.3409659E-03,   1.3761958E-03,   1.4022650E-03
     +,   1.4185392E-03,   1.4245906E-03,   1.4202143E-03
     +,   1.4054396E-03,   1.3805291E-03,   1.3459701E-03
     +,   1.3024574E-03,   1.2508748E-03,   1.1922575E-03
     +,   1.1277571E-03,   1.0586110E-03,   9.8609668E-04
     +,   9.1148767E-04,   8.3601975E-04,   7.6086336E-04
     +,   6.8708777E-04,   6.1563426E-04,   5.4730393E-04
     +,   4.8275257E-04,   4.2248145E-04,   3.6683615E-04
     +,   3.1601946E-04,   2.7010735E-04,   2.2905449E-04
     +,   1.9271752E-04,   1.6087560E-04,   1.3324604E-04
     +,   1.0950115E-04,   8.9287183E-05,   7.2240153E-05
     +,   5.7996564E-05,   4.6202917E-05,   3.6525023E-05
     +,   2.8653856E-05,   2.2308275E-05,   1.7236585E-05
     +,   1.3217543E-05,   1.0059769E-05,   7.5993189E-06
     +,   5.6979961E-06,   4.2408178E-06,   3.1331117E-06
     +,   2.2977936E-06,   1.6728814E-06,   1.2090851E-06
     +,   8.6757365E-07,   6.1805338E-07,   4.3715070E-07
     +,   3.0700923E-07,   2.1410386E-07,   1.4828206E-07
     +,   1.0199961E-07,   6.9702232E-08,   4.7330637E-08
     +,   3.1947749E-08,   2.1447057E-08,   1.4329737E-08
     +,   9.5382822E-09,   6.3333792E-09,   4.2025947E-09
     +,   2.7934859E-09,   1.8656439E-09,   1.2565388E-09
     +,   8.5719515E-10,   5.9504673E-10,   4.2222043E-10
     +,   3.0732064E-10,   2.2993413E-10,   1.7685153E-10
     +,   1.3958577E-10,   1.1269600E-10,   9.2708688E-11
     +,   7.7400142E-11,   6.5344861E-11,   5.5618354E-11
     +,   4.7613549E-11,   4.0923893E-11,   3.5268427E-11
     +,   3.0448050E-11,   2.6315429E-11,   2.2758715E-11
     +,   1.9689505E-11,   1.7036627E-11,   1.4741030E-11
     +,   1.2753507E-11,   1.1032005E-11,   9.5407814E-12
     +,   8.2489657E-12,   7.1300444E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt108 = Yx/0.01232
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.9223830E-09,   6.9229991E-09
     +,   8.0803870E-09,   9.4169446E-09,   1.0957915E-08
     +,   1.2731683E-08,   1.4770110E-08,   1.7108883E-08
     +,   1.9787850E-08,   2.2851586E-08,   2.6349616E-08
     +,   3.0336963E-08,   3.4874656E-08,   4.0030219E-08
     +,   4.5878149E-08,   5.2500564E-08,   5.9987656E-08
     +,   6.8438403E-08,   7.7961090E-08,   8.8673929E-08
     +,   1.0070566E-07,   1.1419636E-07,   1.2929729E-07
     +,   1.4617349E-07,   1.6500087E-07,   1.8597071E-07
     +,   2.0928738E-07,   2.3517009E-07,   2.6385229E-07
     +,   2.9558328E-07,   3.3062756E-07,   3.6926554E-07
     +,   4.1179246E-07,   4.5852030E-07,   5.0977593E-07
     +,   5.6590079E-07,   6.2725184E-07,   6.9419821E-07
     +,   7.6712678E-07,   8.4642863E-07,   9.3251356E-07
     +,   1.0257963E-06,   1.1267005E-06,   1.2356552E-06
     +,   1.3530939E-06,   1.4794510E-06,   1.6151597E-06
     +,   1.7606504E-06,   1.9163454E-06,   2.0826581E-06
     +,   2.2599877E-06,   2.4487174E-06,   2.6492071E-06
     +,   2.8618060E-06,   3.0868109E-06,   3.3245137E-06
     +,   3.5751536E-06,   3.8389389E-06,   4.1160320E-06
     +,   4.4065491E-06,   4.7105614E-06,   5.0280901E-06
     +,   5.3590829E-06,   5.7034540E-06,   6.0610646E-06
     +,   6.4316791E-06,   6.8150484E-06,   7.2108151E-06
     +,   7.6186157E-06,   8.0379687E-06,   8.4684007E-06
     +,   8.9093210E-06,   9.3601502E-06,   9.8202045E-06
     +,   1.0288808E-05,   1.0765244E-05,   1.1248746E-05
     +,   1.1738524E-05,   1.2233810E-05,   1.2733833E-05
     +,   1.3237776E-05,   1.3744914E-05,   1.4254474E-05
     +,   1.4765788E-05,   1.5278172E-05,   1.5791064E-05
     +,   1.6303900E-05,   1.6816261E-05,   1.7327748E-05
     +,   1.7838107E-05,   1.8347189E-05,   1.8854915E-05
     +,   1.9361329E-05,   1.9866620E-05,   2.0371112E-05
     +,   2.0875201E-05,   2.1379485E-05,   2.1884620E-05
     +,   2.2391469E-05,   2.2900944E-05,   2.3414173E-05
     +,   2.3932325E-05,   2.4456769E-05,   2.4988922E-05
     +,   2.5530364E-05,   2.6082789E-05,   2.6647962E-05
     +,   2.7227739E-05,   2.7824111E-05,   2.8439154E-05
     +,   2.9074959E-05,   2.9733774E-05,   3.0417816E-05
     +,   3.1129439E-05,   3.1870943E-05,   3.2644741E-05
     +,   3.3453140E-05,   3.4298540E-05,   3.5183170E-05
     +,   3.6109268E-05,   3.7078964E-05,   3.8094160E-05
     +,   3.9156566E-05,   4.0267692E-05,   4.1428739E-05
     +,   4.2640448E-05,   4.3903263E-05,   4.5216959E-05
     +,   4.6580917E-05,   4.7993697E-05,   4.9453331E-05
     +,   5.0956867E-05,   5.2500734E-05,   5.4080250E-05
     +,   5.5689976E-05,   5.7323472E-05,   5.8973234E-05
     +,   6.0630780E-05,   6.2286752E-05,   6.3930886E-05
     +,   6.5551932E-05,   6.7137873E-05,   6.8676127E-05
     +,   7.0153546E-05,   7.1556438E-05,   7.2871044E-05
     +,   7.4083531E-05,   7.5180134E-05,   7.6147502E-05
     +,   7.6972923E-05,   7.7644501E-05,   7.8151330E-05
     +,   7.8483870E-05,   7.8634061E-05,   7.8595636E-05
     +,   7.8364246E-05,   7.7937802E-05,   7.7316668E-05
     +,   7.6503726E-05,   7.5504882E-05,   7.4329051E-05
     +,   7.2988449E-05,   7.1499009E-05,   6.9880502E-05
     +,   6.8156696E-05,   6.6355729E-05,   6.4510416E-05
     +,   6.2658328E-05,   6.0841754E-05,   5.9107726E-05
     +,   5.7507950E-05,   5.6098121E-05,   5.4937063E-05
     +,   5.4085634E-05,   5.3605232E-05,   5.3555461E-05
     +,   5.3991815E-05,   5.4962660E-05,   5.6505822E-05
     +,   5.8645477E-05,   6.1388666E-05,   6.4722160E-05
     +,   6.8610352E-05,   7.2994575E-05,   7.7793571E-05
     +,   8.2905957E-05,   8.8215842E-05,   9.3601644E-05
     +,   9.8947268E-05,   1.0415647E-04,   1.0917183E-04
     +,   1.1399490E-04,   1.1870817E-04,   1.2349818E-04
     +,   1.2867716E-04,   1.3469993E-04,   1.4217365E-04
     +,   1.5185692E-04,   1.6464469E-04,   1.8153380E-04
     +,   2.0356628E-04,   2.3175315E-04,   2.6698253E-04
     +,   3.0991450E-04,   3.6087268E-04,   4.1976699E-04
     +,   4.8603670E-04,   5.5864046E-04,   6.3610799E-04
     +,   7.1664975E-04,   7.9829682E-04,   8.7905792E-04
     +,   9.5707719E-04,   1.0307533E-03,   1.0987861E-03
     +,   1.1601611E-03,   1.2140848E-03,   1.2598837E-03
     +,   1.2968974E-03,   1.3244060E-03,   1.3416149E-03
     +,   1.3476961E-03,   1.3418794E-03,   1.3235811E-03
     +,   1.2925288E-03,   1.2488646E-03,   1.1932109E-03
     +,   1.1266785E-03,   1.0508196E-03,   9.6754992E-04
     +,   8.7904325E-04,   7.8760524E-04,   6.9554255E-04
     +,   6.0505606E-04,   5.1814673E-04,   4.3651939E-04
     +,   3.6152950E-04,   2.9414939E-04,   2.3494837E-04
     +,   1.8409992E-04,   1.4142274E-04,   1.0643929E-04
     +,   7.8443416E-05,   5.6578661E-05,   3.9919367E-05
     +,   2.7540800E-05,   1.8573061E-05,   1.2239611E-05
     +,   7.8797175E-06,   4.9548576E-06,   3.0425981E-06
     +,   1.8242256E-06,   1.0677893E-06,   6.1013952E-07
     +,   3.4030234E-07,   1.8524756E-07,   9.8417807E-08
     +,   5.1028863E-08,   2.5819645E-08,   1.2748241E-08
     +,   6.1420180E-09,   2.8875649E-09,   1.3246297E-09
     +,   5.9290761E-10,   2.5896529E-10,   1.1037717E-10
     +,   4.5915490E-11,   1.8648685E-11,   7.4007432E-12
     +,   2.8739545E-12,   1.0954295E-12,   4.1242891E-13
     +,   1.5534966E-13,   5.9969397E-14,   2.4686796E-14
     +,   1.1381329E-14,   6.0644162E-15,   3.6954671E-15
     +,   2.4724121E-15,   1.7440117E-15,   1.2633463E-15
     +,   9.2697962E-16,   6.8448934E-16,   5.0716484E-16
     +,   3.7654961E-16,   2.7996355E-16,   2.0835631E-16
     +,   1.5516979E-16,   1.1561318E-16,   8.6160416E-17
     +,   6.4214124E-17,   4.7850986E-17,   3.5647339E-17
     +,   2.6544112E-17,   1.9754430E-17,   1.4691168E-17
     +,   1.0917083E-17,   8.1052665E-18,   6.0118709E-18
     +,   4.4544739E-18,   3.2969018E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt110 = Yx/0.00933333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6752863E-05,   1.7116850E-05
     +,   1.7493874E-05,   1.7884080E-05,   1.8287594E-05
     +,   1.8704486E-05,   1.9134803E-05,   1.9578536E-05
     +,   2.0035635E-05,   2.0506026E-05,   2.0989557E-05
     +,   2.1486036E-05,   2.1995227E-05,   2.2516841E-05
     +,   2.3050527E-05,   2.3595885E-05,   2.4152467E-05
     +,   2.4719753E-05,   2.5297188E-05,   2.5884148E-05
     +,   2.6479955E-05,   2.7083879E-05,   2.7695129E-05
     +,   2.8312890E-05,   2.8936238E-05,   2.9564262E-05
     +,   3.0195966E-05,   3.0830313E-05,   3.1466232E-05
     +,   3.2102605E-05,   3.2738277E-05,   3.3372049E-05
     +,   3.4002711E-05,   3.4629003E-05,   3.5249672E-05
     +,   3.5863406E-05,   3.6468911E-05,   3.7064852E-05
     +,   3.7649941E-05,   3.8222814E-05,   3.8782160E-05
     +,   3.9326678E-05,   3.9855055E-05,   4.0366001E-05
     +,   4.0858267E-05,   4.1330608E-05,   4.1781830E-05
     +,   4.2210762E-05,   4.2616273E-05,   4.2997297E-05
     +,   4.3352804E-05,   4.3681812E-05,   4.3983408E-05
     +,   4.4256754E-05,   4.4501034E-05,   4.4715554E-05
     +,   4.4899647E-05,   4.5052744E-05,   4.5174351E-05
     +,   4.5264038E-05,   4.5321463E-05,   4.5346376E-05
     +,   4.5338587E-05,   4.5298009E-05,   4.5224624E-05
     +,   4.5118504E-05,   4.4979781E-05,   4.4808708E-05
     +,   4.4605589E-05,   4.4370816E-05,   4.4104840E-05
     +,   4.3808224E-05,   4.3481552E-05,   4.3125532E-05
     +,   4.2740903E-05,   4.2328455E-05,   4.1889074E-05
     +,   4.1423697E-05,   4.0933286E-05,   4.0418854E-05
     +,   3.9881503E-05,   3.9322302E-05,   3.8742441E-05
     +,   3.8143047E-05,   3.7525373E-05,   3.6890604E-05
     +,   3.6240013E-05,   3.5574827E-05,   3.4896348E-05
     +,   3.4205827E-05,   3.3504519E-05,   3.2793709E-05
     +,   3.2074688E-05,   3.1348682E-05,   3.0616906E-05
     +,   2.9880623E-05,   2.9140991E-05,   2.8399223E-05
     +,   2.7656422E-05,   2.6913751E-05,   2.6172245E-05
     +,   2.5433003E-05,   2.4696985E-05,   2.3965216E-05
     +,   2.3238601E-05,   2.2518016E-05,   2.1804322E-05
     +,   2.1098353E-05,   2.0400839E-05,   1.9712477E-05
     +,   1.9033974E-05,   1.8365914E-05,   1.7708915E-05
     +,   1.7063463E-05,   1.6430091E-05,   1.5809197E-05
     +,   1.5201226E-05,   1.4606491E-05,   1.4025352E-05
     +,   1.3458076E-05,   1.2904889E-05,   1.2366025E-05
     +,   1.1841690E-05,   1.1332029E-05,   1.0837176E-05
     +,   1.0357301E-05,   9.8925038E-06,   9.4429561E-06
     +,   9.0087906E-06,   8.5902220E-06,   8.1874668E-06
     +,   7.8008534E-06,   7.4307522E-06,   7.0776950E-06
     +,   6.7423207E-06,   6.4254468E-06,   6.1281216E-06
     +,   5.8516462E-06,   5.5976016E-06,   5.3679169E-06
     +,   5.1649281E-06,   4.9914224E-06,   4.8506690E-06
     +,   4.7464932E-06,   4.6833302E-06,   4.6662399E-06
     +,   4.7009589E-06,   4.7939170E-06,   4.9522278E-06
     +,   5.1836928E-06,   5.4967613E-06,   5.9004374E-06
     +,   6.4041928E-06,   7.0178685E-06,   7.7515078E-06
     +,   8.6150849E-06,   9.6183021E-06,   1.0770385E-05
     +,   1.2079751E-05,   1.3553530E-05,   1.5197471E-05
     +,   1.7015484E-05,   1.9009174E-05,   2.1177593E-05
     +,   2.3517099E-05,   2.6021036E-05,   2.8679315E-05
     +,   3.1478568E-05,   3.4402288E-05,   3.7430880E-05
     +,   4.0541723E-05,   4.3709861E-05,   4.6908783E-05
     +,   5.0111154E-05,   5.3289437E-05,   5.6417786E-05
     +,   5.9473135E-05,   6.2436593E-05,   6.5295513E-05
     +,   6.8045498E-05,   7.0692426E-05,   7.3254421E-05
     +,   7.5764263E-05,   7.8271856E-05,   8.0846294E-05
     +,   8.3577761E-05,   8.6579617E-05,   8.9990128E-05
     +,   9.3973555E-05,   9.8720360E-05,   1.0444781E-04
     +,   1.1139893E-04,   1.1984014E-04,   1.3005831E-04
     +,   1.4235730E-04,   1.5705204E-04,   1.7445990E-04
     +,   1.9489278E-04,   2.1864841E-04,   2.4599739E-04
     +,   2.7716919E-04,   3.1233879E-04,   3.5161569E-04
     +,   3.9502786E-04,   4.4250386E-04,   4.9386936E-04
     +,   5.4883375E-04,   6.0697924E-04,   6.6776137E-04
     +,   7.3051447E-04,   7.9445448E-04,   8.5868500E-04
     +,   9.2221959E-04,   9.8400633E-04,   1.0429499E-03
     +,   1.0979382E-03,   1.1478778E-03,   1.1917333E-03
     +,   1.2285543E-03,   1.2575075E-03,   1.2779117E-03
     +,   1.2892591E-03,   1.2912335E-03,   1.2837265E-03
     +,   1.2668407E-03,   1.2408859E-03,   1.2063730E-03
     +,   1.1639950E-03,   1.1146009E-03,   1.0591678E-03
     +,   9.9877338E-04,   9.3455595E-04,   8.6767628E-04
     +,   7.9928333E-04,   7.3049113E-04,   6.6233310E-04
     +,   5.9574639E-04,   5.3155527E-04,   4.7045326E-04
     +,   4.1299177E-04,   3.5958263E-04,   3.1050420E-04
     +,   2.6590590E-04,   2.2581668E-04,   1.9016373E-04
     +,   1.5879035E-04,   1.3147014E-04,   1.0792306E-04
     +,   8.7833949E-05,   7.0869370E-05,   5.6686720E-05
     +,   4.4947901E-05,   3.5328758E-05,   2.7524866E-05
     +,   2.1255946E-05,   1.6269520E-05,   1.2342324E-05
     +,   9.2797618E-06,   6.9147568E-06,   5.1062211E-06
     +,   3.7367736E-06,   2.7099486E-06,   1.9474955E-06
     +,   1.3868436E-06,   9.7861755E-07,   6.8425624E-07
     +,   4.7405598E-07,   3.2541831E-07,   2.2133628E-07
     +,   1.4915867E-07,   9.9590075E-08,   6.5880059E-08
     +,   4.3177931E-08,   2.8036805E-08,   1.8036111E-08
     +,   1.1495137E-08,   7.2581829E-09,   4.5404405E-09
     +,   2.8139455E-09,   1.7278432E-09,   1.0511586E-09
     +,   6.3365357E-10,   3.7852130E-10,   2.2411863E-10
     +,   1.3156090E-10,   7.6604063E-11,   4.4275431E-11
     +,   2.5430411E-11,   1.4542076E-11,   8.3022079E-12
     +,   4.7528006E-12,   2.7457106E-12,   1.6151483E-12
     +,   9.7850309E-13,   6.1825377E-13,   4.1179403E-13
     +,   2.9068970E-13,   2.1701979E-13,   1.6993447E-13
     +,   1.3801001E-13,   1.1500122E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt112 = Yx/0.0105
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3680333E-05,   1.4273136E-05
     +,   1.4876219E-05,   1.5488748E-05,   1.6109818E-05
     +,   1.6738470E-05,   1.7373679E-05,   1.8014362E-05
     +,   1.8659364E-05,   1.9307508E-05,   1.9957541E-05
     +,   2.0608160E-05,   2.1258031E-05,   2.1905764E-05
     +,   2.2549952E-05,   2.3189135E-05,   2.3821851E-05
     +,   2.4446595E-05,   2.5061865E-05,   2.5666142E-05
     +,   2.6257901E-05,   2.6835631E-05,   2.7397808E-05
     +,   2.7942971E-05,   2.8469616E-05,   2.8976328E-05
     +,   2.9461702E-05,   2.9924360E-05,   3.0363006E-05
     +,   3.0776373E-05,   3.1163265E-05,   3.1522555E-05
     +,   3.1853178E-05,   3.2154156E-05,   3.2424588E-05
     +,   3.2663658E-05,   3.2870648E-05,   3.3044922E-05
     +,   3.3185956E-05,   3.3293312E-05,   3.3366669E-05
     +,   3.3405795E-05,   3.3410572E-05,   3.3380980E-05
     +,   3.3317119E-05,   3.3219181E-05,   3.3087468E-05
     +,   3.2922380E-05,   3.2724420E-05,   3.2494194E-05
     +,   3.2232401E-05,   3.1939824E-05,   3.1617350E-05
     +,   3.1265918E-05,   3.0886589E-05,   3.0480462E-05
     +,   3.0048714E-05,   2.9592598E-05,   2.9113402E-05
     +,   2.8612483E-05,   2.8091225E-05,   2.7551057E-05
     +,   2.6993464E-05,   2.6419913E-05,   2.5831891E-05
     +,   2.5230949E-05,   2.4618574E-05,   2.3996317E-05
     +,   2.3365656E-05,   2.2728131E-05,   2.2085176E-05
     +,   2.1438296E-05,   2.0788868E-05,   2.0138332E-05
     +,   1.9488014E-05,   1.8839206E-05,   1.8193190E-05
     +,   1.7551200E-05,   1.6914368E-05,   1.6283779E-05
     +,   1.5660511E-05,   1.5045507E-05,   1.4439724E-05
     +,   1.3843975E-05,   1.3259088E-05,   1.2685749E-05
     +,   1.2124651E-05,   1.1576351E-05,   1.1041412E-05
     +,   1.0520279E-05,   1.0013335E-05,   9.5209352E-06
     +,   9.0433723E-06,   8.5808506E-06,   8.1335202E-06
     +,   7.7015184E-06,   7.2848738E-06,   6.8836216E-06
     +,   6.4976989E-06,   6.1270475E-06,   5.7715188E-06
     +,   5.4309735E-06,   5.1051938E-06,   4.7939693E-06
     +,   4.4970288E-06,   4.2140787E-06,   3.9448146E-06
     +,   3.6889135E-06,   3.4460145E-06,   3.2157445E-06
     +,   2.9977357E-06,   2.7915830E-06,   2.5968977E-06
     +,   2.4132601E-06,   2.2402692E-06,   2.0774996E-06
     +,   1.9245458E-06,   1.7809826E-06,   1.6464080E-06
     +,   1.5204084E-06,   1.4025768E-06,   1.2925215E-06
     +,   1.1898562E-06,   1.0941967E-06,   1.0051697E-06
     +,   9.2241947E-07,   8.4559071E-07,   7.7434902E-07
     +,   7.0836234E-07,   6.4731972E-07,   5.9091360E-07
     +,   5.3885668E-07,   4.9086731E-07,   4.4668261E-07
     +,   4.0604692E-07,   3.6871802E-07,   3.3446796E-07
     +,   3.0308072E-07,   2.7434908E-07,   2.4807849E-07
     +,   2.2408675E-07,   2.0220226E-07,   1.8226227E-07
     +,   1.6411450E-07,   1.4761808E-07,   1.3263950E-07
     +,   1.1905428E-07,   1.0674749E-07,   9.5611824E-08
     +,   8.5547200E-08,   7.6460680E-08,   6.8266900E-08
     +,   6.0886819E-08,   5.4247028E-08,   4.8279862E-08
     +,   4.2923496E-08,   3.8121055E-08,   3.3819965E-08
     +,   2.9972178E-08,   2.6534062E-08,   2.3465391E-08
     +,   2.0729468E-08,   1.8293100E-08,   1.6126016E-08
     +,   1.4200640E-08,   1.2492024E-08,   1.0977800E-08
     +,   9.6379624E-09,   8.4548759E-09,   7.4136457E-09
     +,   6.5029058E-09,   5.7161711E-09,   5.0546465E-09
     +,   4.5324571E-09,   4.1859596E-09,   4.0898214E-09
     +,   4.3847246E-09,   5.3236300E-09,   7.3477175E-09
     +,   1.1209056E-08,   1.8164465E-08,   3.0275359E-08
     +,   5.0863633E-08,   8.5193001E-08,   1.4146212E-07
     +,   2.3221753E-07,   3.7633220E-07,   6.0171965E-07
     +,   9.4894500E-07,   1.4758624E-06,   2.2635991E-06
     +,   3.4238151E-06,   5.1072043E-06,   7.5132562E-06
     +,   1.0901016E-05,   1.5599859E-05,   2.2019112E-05
     +,   3.0655894E-05,   4.2100062E-05,   5.7032539E-05
     +,   7.6215350E-05,   1.0047331E-04,   1.3066658E-04
     +,   1.6764906E-04,   2.1221131E-04,   2.6502510E-04
     +,   3.2657158E-04,   3.9706475E-04,   4.7638573E-04
     +,   5.6403049E-04,   6.5906532E-04,   7.6010224E-04
     +,   8.6531625E-04,   9.7249582E-04,   1.0791107E-03
     +,   1.1824092E-03,   1.2795482E-03,   1.3677423E-03
     +,   1.4443947E-03,   1.5072272E-03,   1.5544099E-03
     +,   1.5846400E-03,   1.5971970E-03,   1.5919665E-03
     +,   1.5694236E-03,   1.5305810E-03,   1.4769210E-03
     +,   1.4103017E-03,   1.3328468E-03,   1.2468450E-03
     +,   1.1546488E-03,   1.0585805E-03,   9.6083950E-04
     +,   8.6344715E-04,   7.6820160E-04,   6.7662884E-04
     +,   5.8997126E-04,   5.0918956E-04,   4.3496129E-04
     +,   3.6769366E-04,   3.0755339E-04,   2.5449970E-04
     +,   2.0831286E-04,   1.6862714E-04,   1.3497060E-04
     +,   1.0680057E-04,   8.3532061E-05,   6.4564512E-05
     +,   4.9307360E-05,   3.7199421E-05,   2.7719585E-05
     +,   2.0397873E-05,   1.4820496E-05,   1.0630570E-05
     +,   7.5265507E-06,   5.2591195E-06,   3.6262102E-06
     +,   2.4669750E-06,   1.6557315E-06,   1.0961562E-06
     +,   7.1576437E-07,   4.6094084E-07,   2.9271854E-07
     +,   1.8329013E-07,   1.1315895E-07,   6.8874563E-08
     +,   4.1324693E-08,   2.4441015E-08,   1.4248429E-08
     +,   8.1869036E-09,   4.6360218E-09,   2.5871938E-09
     +,   1.4228482E-09,   7.7109114E-10,   4.1175927E-10
     +,   2.1665671E-10,   1.1232027E-10,   5.7372631E-11
     +,   2.8872120E-11,   1.4314851E-11,   6.9919287E-12
     +,   3.3644769E-12,   1.5948399E-12,   7.4474509E-13
     +,   3.4257593E-13,   1.5523134E-13,   6.9287525E-14
     +,   3.0462557E-14,   1.3192567E-14,   5.6275238E-15
     +,   2.3645734E-15,   9.7862089E-16,   3.9897226E-16
     +,   1.6023080E-16,   6.3405134E-17,   2.4729312E-17
     +,   9.5141040E-18,   3.6162972E-18,   1.3626729E-18
     +,   5.1257213E-19,   1.9519356E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt113 = Yx/0.00943478260869565
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1126476E-06,   9.2525497E-06
     +,   9.3907547E-06,   9.5272144E-06,   9.6618915E-06
     +,   9.7947595E-06,   9.9258095E-06,   1.0055043E-05
     +,   1.0182476E-05,   1.0308148E-05,   1.0432104E-05
     +,   1.0554415E-05,   1.0675164E-05,   1.0794455E-05
     +,   1.0912414E-05,   1.1029183E-05,   1.1144924E-05
     +,   1.1259826E-05,   1.1374091E-05,   1.1487949E-05
     +,   1.1601648E-05,   1.1715462E-05,   1.1829688E-05
     +,   1.1944642E-05,   1.2060659E-05,   1.2178111E-05
     +,   1.2297380E-05,   1.2418873E-05,   1.2543021E-05
     +,   1.2670275E-05,   1.2801112E-05,   1.2936023E-05
     +,   1.3075524E-05,   1.3220149E-05,   1.3370452E-05
     +,   1.3527000E-05,   1.3690386E-05,   1.3861207E-05
     +,   1.4040093E-05,   1.4227661E-05,   1.4424570E-05
     +,   1.4631469E-05,   1.4849023E-05,   1.5077907E-05
     +,   1.5318799E-05,   1.5572390E-05,   1.5839367E-05
     +,   1.6120419E-05,   1.6416241E-05,   1.6727521E-05
     +,   1.7054943E-05,   1.7399194E-05,   1.7760940E-05
     +,   1.8140867E-05,   1.8539606E-05,   1.8957817E-05
     +,   1.9396128E-05,   1.9855148E-05,   2.0335479E-05
     +,   2.0837695E-05,   2.1362346E-05,   2.1909986E-05
     +,   2.2481083E-05,   2.3076142E-05,   2.3695633E-05
     +,   2.4339943E-05,   2.5009494E-05,   2.5704605E-05
     +,   2.6425649E-05,   2.7172846E-05,   2.7946493E-05
     +,   2.8746743E-05,   2.9573806E-05,   3.0427733E-05
     +,   3.1308609E-05,   3.2216489E-05,   3.3151282E-05
     +,   3.4112876E-05,   3.5101129E-05,   3.6115864E-05
     +,   3.7156722E-05,   3.8223421E-05,   3.9315470E-05
     +,   4.0432438E-05,   4.1573679E-05,   4.2738600E-05
     +,   4.3926393E-05,   4.5136287E-05,   4.6367306E-05
     +,   4.7618450E-05,   4.8888644E-05,   5.0176641E-05
     +,   5.1481078E-05,   5.2800548E-05,   5.4133579E-05
     +,   5.5478438E-05,   5.6833440E-05,   5.8196649E-05
     +,   5.9566162E-05,   6.0939808E-05,   6.2315470E-05
     +,   6.3690743E-05,   6.5063330E-05,   6.6430599E-05
     +,   6.7790010E-05,   6.9138900E-05,   7.0474438E-05
     +,   7.1793722E-05,   7.3093877E-05,   7.4371950E-05
     +,   7.5624819E-05,   7.6849487E-05,   7.8042787E-05
     +,   7.9201673E-05,   8.0322978E-05,   8.1403647E-05
     +,   8.2440565E-05,   8.3430801E-05,   8.4371321E-05
     +,   8.5259315E-05,   8.6092019E-05,   8.6866814E-05
     +,   8.7581160E-05,   8.8232773E-05,   8.8819514E-05
     +,   8.9339432E-05,   8.9790869E-05,   9.0172332E-05
     +,   9.0482652E-05,   9.0720969E-05,   9.0886700E-05
     +,   9.0979600E-05,   9.0999783E-05,   9.0947724E-05
     +,   9.0824316E-05,   9.0630776E-05,   9.0368754E-05
     +,   9.0040376E-05,   8.9648092E-05,   8.9194815E-05
     +,   8.8683846E-05,   8.8119006E-05,   8.7504399E-05
     +,   8.6844579E-05,   8.6144515E-05,   8.5409534E-05
     +,   8.4645260E-05,   8.3857747E-05,   8.3053332E-05
     +,   8.2238592E-05,   8.1420330E-05,   8.0605620E-05
     +,   7.9801721E-05,   7.9015888E-05,   7.8255500E-05
     +,   7.7527919E-05,   7.6840435E-05,   7.6200085E-05
     +,   7.5613621E-05,   7.5087453E-05,   7.4627380E-05
     +,   7.4238545E-05,   7.3925279E-05,   7.3690899E-05
     +,   7.3537543E-05,   7.3466013E-05,   7.3475618E-05
     +,   7.3564013E-05,   7.3727017E-05,   7.3958618E-05
     +,   7.4250762E-05,   7.4593387E-05,   7.4974509E-05
     +,   7.5380267E-05,   7.5795062E-05,   7.6201926E-05
     +,   7.6582830E-05,   7.6919154E-05,   7.7192213E-05
     +,   7.7384204E-05,   7.7478791E-05,   7.7462195E-05
     +,   7.7324410E-05,   7.7060395E-05,   7.6671611E-05
     +,   7.6167598E-05,   7.5567936E-05,   7.4904208E-05
     +,   7.4222255E-05,   7.3584924E-05,   7.3074618E-05
     +,   7.2796691E-05,   7.2882875E-05,   7.3494986E-05
     +,   7.4829171E-05,   7.7120327E-05,   8.0646190E-05
     +,   8.5731568E-05,   9.2752176E-05,   1.0213703E-04
     +,   1.1436821E-04,   1.2997862E-04,   1.4954731E-04
     +,   1.7368844E-04,   2.0303196E-04,   2.3820544E-04
     +,   2.7980248E-04,   3.2834298E-04,   3.8423142E-04
     +,   4.4771307E-04,   5.1882112E-04,   5.9732160E-04
     +,   6.8267155E-04,   7.7399006E-04,   8.7003119E-04
     +,   9.6917473E-04,   1.0694521E-03,   1.1685973E-03
     +,   1.2641102E-03,   1.3533431E-03,   1.4336328E-03
     +,   1.5024175E-03,   1.5573675E-03,   1.5965201E-03
     +,   1.6183953E-03,   1.6220827E-03,   1.6072995E-03
     +,   1.5744179E-03,   1.5244435E-03,   1.4589605E-03
     +,   1.3800478E-03,   1.2901641E-03,   1.1920056E-03
     +,   1.0883749E-03,   9.8205230E-04,   8.7565579E-04
     +,   7.7154423E-04,   6.7174801E-04,   5.7790912E-04
     +,   4.9125234E-04,   4.1259491E-04,   3.4237537E-04
     +,   2.8068858E-04,   2.2733540E-04,   1.8188771E-04
     +,   1.4375102E-04,   1.1221907E-04,   8.6524211E-05
     +,   6.5885339E-05,   4.9544476E-05,   3.6789079E-05
     +,   2.6972424E-05,   1.9523892E-05,   1.3951669E-05
     +,   9.8414193E-06,   6.8520189E-06,   4.7084391E-06
     +,   3.1930222E-06,   2.1367434E-06,   1.4108740E-06
     +,   9.1914012E-07,   5.9075518E-07,   3.7456741E-07
     +,   2.3426908E-07,   1.4452775E-07,   8.7945139E-08
     +,   5.2780457E-08,   3.1241573E-08,   1.8238868E-08
     +,   1.0502021E-08,   5.9645893E-09,   3.3418512E-09
     +,   1.8475773E-09,   1.0082937E-09,   5.4350513E-10
     +,   2.8967276E-10,   1.5289106E-10,   8.0123179E-11
     +,   4.1857195E-11,   2.1934647E-11,   1.1635744E-11
     +,   6.3272482E-12,   3.5804575E-12,   2.1399820E-12
     +,   1.3641607E-12,   9.2840297E-13,   6.6939634E-13
     +,   5.0505536E-13,   3.9380012E-13,   3.1412779E-13
     +,   2.5453972E-13,   2.0855298E-13,   1.7228383E-13
     +,   1.4323740E-13,   1.1971712E-13,   1.0050629E-13
     +,   8.4705477E-14,   7.1630032E-14,   6.0752273E-14
     +,   5.1658727E-14,   4.4024226E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt114 = Yx/0.01148
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9842516E-07,   3.3051757E-07
     +,   3.6558922E-07,   4.0386095E-07,   4.4556407E-07
     +,   4.9093990E-07,   5.4023906E-07,   5.9372223E-07
     +,   6.5165835E-07,   7.1432675E-07,   7.8201231E-07
     +,   8.5500727E-07,   9.3361120E-07,   1.0181268E-06
     +,   1.1088617E-06,   1.2061259E-06,   1.3102305E-06
     +,   1.4214855E-06,   1.5401995E-06,   1.6666758E-06
     +,   1.8012129E-06,   1.9441009E-06,   2.0956152E-06
     +,   2.2560321E-06,   2.4255912E-06,   2.6045350E-06
     +,   2.7930751E-06,   2.9914013E-06,   3.1996797E-06
     +,   3.4180480E-06,   3.6466110E-06,   3.8854432E-06
     +,   4.1345811E-06,   4.3940208E-06,   4.6637215E-06
     +,   4.9435948E-06,   5.2335081E-06,   5.5332775E-06
     +,   5.8426867E-06,   6.1614360E-06,   6.4892065E-06
     +,   6.8256049E-06,   7.1701916E-06,   7.5224693E-06
     +,   7.8818875E-06,   8.2478400E-06,   8.6196687E-06
     +,   8.9966588E-06,   9.3780500E-06,   9.7630291E-06
     +,   1.0150735E-05,   1.0540262E-05,   1.0930664E-05
     +,   1.1320974E-05,   1.1710154E-05,   1.2097179E-05
     +,   1.2480974E-05,   1.2860457E-05,   1.3234527E-05
     +,   1.3602081E-05,   1.3962017E-05,   1.4313243E-05
     +,   1.4654659E-05,   1.4985215E-05,   1.5303889E-05
     +,   1.5609665E-05,   1.5901609E-05,   1.6178801E-05
     +,   1.6440421E-05,   1.6685679E-05,   1.6913895E-05
     +,   1.7124439E-05,   1.7316808E-05,   1.7490567E-05
     +,   1.7645407E-05,   1.7781125E-05,   1.7897644E-05
     +,   1.7995002E-05,   1.8073382E-05,   1.8133100E-05
     +,   1.8174616E-05,   1.8198536E-05,   1.8205625E-05
     +,   1.8196792E-05,   1.8173110E-05,   1.8135806E-05
     +,   1.8086272E-05,   1.8026049E-05,   1.7956841E-05
     +,   1.7880506E-05,   1.7799044E-05,   1.7714605E-05
     +,   1.7629482E-05,   1.7546085E-05,   1.7466944E-05
     +,   1.7394706E-05,   1.7332102E-05,   1.7281947E-05
     +,   1.7247117E-05,   1.7230541E-05,   1.7235150E-05
     +,   1.7263901E-05,   1.7319719E-05,   1.7405473E-05
     +,   1.7523982E-05,   1.7677952E-05,   1.7869959E-05
     +,   1.8102417E-05,   1.8377559E-05,   1.8697410E-05
     +,   1.9063713E-05,   1.9477968E-05,   1.9941333E-05
     +,   2.0454667E-05,   2.1018412E-05,   2.1632690E-05
     +,   2.2297130E-05,   2.3011024E-05,   2.3773120E-05
     +,   2.4581776E-05,   2.5434889E-05,   2.6329832E-05
     +,   2.7263502E-05,   2.8232389E-05,   2.9232533E-05
     +,   3.0259433E-05,   3.1308318E-05,   3.2373871E-05
     +,   3.3450582E-05,   3.4532459E-05,   3.5613386E-05
     +,   3.6686874E-05,   3.7746395E-05,   3.8785169E-05
     +,   3.9796436E-05,   4.0773433E-05,   4.1709409E-05
     +,   4.2597705E-05,   4.3431945E-05,   4.4205946E-05
     +,   4.4913817E-05,   4.5550041E-05,   4.6109526E-05
     +,   4.6587702E-05,   4.6980422E-05,   4.7284186E-05
     +,   4.7496080E-05,   4.7613772E-05,   4.7635629E-05
     +,   4.7560676E-05,   4.7388607E-05,   4.7119796E-05
     +,   4.6755307E-05,   4.6296831E-05,   4.5746710E-05
     +,   4.5107892E-05,   4.4383949E-05,   4.3578919E-05
     +,   4.2697324E-05,   4.1744235E-05,   4.0724997E-05
     +,   3.9645292E-05,   3.8511149E-05,   3.7328809E-05
     +,   3.6104590E-05,   3.4844899E-05,   3.3556254E-05
     +,   3.2245152E-05,   3.0917916E-05,   2.9580751E-05
     +,   2.8239758E-05,   2.6900838E-05,   2.5569532E-05
     +,   2.4251143E-05,   2.2950815E-05,   2.1673326E-05
     +,   2.0423262E-05,   1.9205203E-05,   1.8023808E-05
     +,   1.6883991E-05,   1.5791382E-05,   1.4752897E-05
     +,   1.3777353E-05,   1.2876249E-05,   1.2064881E-05
     +,   1.1363554E-05,   1.0798723E-05,   1.0404078E-05
     +,   1.0221439E-05,   1.0301031E-05,   1.0700878E-05
     +,   1.1485204E-05,   1.2721408E-05,   1.4475761E-05
     +,   1.6808250E-05,   1.9766812E-05,   2.3381939E-05
     +,   2.7663747E-05,   3.2603162E-05,   3.8178379E-05
     +,   4.4368586E-05,   5.1176685E-05,   5.8660349E-05
     +,   6.6968438E-05,   7.6379256E-05,   8.7338798E-05
     +,   1.0048886E-04,   1.1668223E-04,   1.3698603E-04
     +,   1.6267563E-04,   1.9522382E-04,   2.3629476E-04
     +,   2.8775437E-04,   3.5169383E-04,   4.3043544E-04
     +,   5.2648078E-04,   6.4235640E-04,   7.8029797E-04
     +,   9.4172137E-04,   1.1264997E-03,   1.3322091E-03
     +,   1.5534189E-03,   1.7812857E-03,   2.0036991E-03
     +,   2.2060922E-03,   2.3728719E-03,   2.4893410E-03
     +,   2.5438201E-03,   2.5294879E-03,   2.4455721E-03
     +,   2.2976422E-03,   2.0968982E-03,   1.8585777E-03
     +,   1.5998583E-03,   1.3376743E-03,   1.0867484E-03
     +,   8.5829705E-04,   6.5945467E-04,   4.9335801E-04
     +,   3.5977265E-04,   2.5603516E-04,   1.7804817E-04
     +,   1.2114385E-04,   8.0740414E-05,   5.2759988E-05
     +,   3.3822445E-05,   2.1275204E-05,   1.3127592E-05
     +,   7.9401252E-06,   4.7028147E-06,   2.7239923E-06
     +,   1.5407886E-06,   8.4986021E-07,   4.5648659E-07
     +,   2.3846974E-07,   1.2102883E-07,   5.9625847E-08
     +,   2.8499043E-08,   1.3212175E-08,   5.9430789E-09
     +,   2.5974216E-09,   1.1065879E-09,   4.6273432E-10
     +,   1.9257160E-10,   8.1836919E-11,   3.6985311E-11
     +,   1.8625221E-11,   1.0726696E-11,   6.9637828E-12
     +,   4.8978577E-12,   3.5958615E-12,   2.6916921E-12
     +,   2.0296035E-12,   1.5329620E-12,   1.1570200E-12
     +,   8.7181288E-13,   6.5554279E-13,   4.9183742E-13
     +,   3.6817348E-13,   2.7497495E-13,   2.0489609E-13
     +,   1.5232835E-13,   1.1298618E-13,   8.3613190E-14
     +,   6.1733598E-14,   4.5475180E-14,   3.3421633E-14
     +,   2.4506337E-14,   1.7928062E-14,   1.3085334E-14
     +,   9.5288623E-15,   6.9229887E-15,   5.0182412E-15
     +,   3.6291423E-15,   2.6185600E-15,   1.8850180E-15
     +,   1.3538622E-15,   9.7012346E-16,   6.9356217E-16
     +,   4.9469763E-16,   3.5204534E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt115 = Yx/0.0105
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3648181E-05,   1.3904996E-05
     +,   1.4165535E-05,   1.4429925E-05,   1.4698291E-05
     +,   1.4970766E-05,   1.5247481E-05,   1.5528576E-05
     +,   1.5814188E-05,   1.6104459E-05,   1.6399532E-05
     +,   1.6699547E-05,   1.7004646E-05,   1.7314973E-05
     +,   1.7630666E-05,   1.7951863E-05,   1.8278699E-05
     +,   1.8611305E-05,   1.8949804E-05,   1.9294319E-05
     +,   1.9644958E-05,   2.0001829E-05,   2.0365018E-05
     +,   2.0734624E-05,   2.1110700E-05,   2.1493321E-05
     +,   2.1882523E-05,   2.2278335E-05,   2.2680768E-05
     +,   2.3089815E-05,   2.3505443E-05,   2.3927611E-05
     +,   2.4356237E-05,   2.4791230E-05,   2.5232470E-05
     +,   2.5679799E-05,   2.6133044E-05,   2.6591993E-05
     +,   2.7056429E-05,   2.7526050E-05,   2.8000581E-05
     +,   2.8479684E-05,   2.8962984E-05,   2.9450082E-05
     +,   2.9940542E-05,   3.0433896E-05,   3.0929637E-05
     +,   3.1427222E-05,   3.1926083E-05,   3.2425614E-05
     +,   3.2925174E-05,   3.3424087E-05,   3.3921660E-05
     +,   3.4417179E-05,   3.4909866E-05,   3.5398964E-05
     +,   3.5883662E-05,   3.6363148E-05,   3.6836587E-05
     +,   3.7303136E-05,   3.7761929E-05,   3.8212125E-05
     +,   3.8652819E-05,   3.9083181E-05,   3.9502356E-05
     +,   3.9909472E-05,   4.0303712E-05,   4.0684245E-05
     +,   4.1050305E-05,   4.1401094E-05,   4.1735901E-05
     +,   4.2054013E-05,   4.2354786E-05,   4.2637588E-05
     +,   4.2901866E-05,   4.3147116E-05,   4.3372875E-05
     +,   4.3578737E-05,   4.3764376E-05,   4.3929540E-05
     +,   4.4074008E-05,   4.4197674E-05,   4.4300472E-05
     +,   4.4382425E-05,   4.4443615E-05,   4.4484234E-05
     +,   4.4504508E-05,   4.4504781E-05,   4.4485427E-05
     +,   4.4446922E-05,   4.4389813E-05,   4.4314700E-05
     +,   4.4222255E-05,   4.4113229E-05,   4.3988402E-05
     +,   4.3848635E-05,   4.3694818E-05,   4.3527903E-05
     +,   4.3348871E-05,   4.3158747E-05,   4.2958567E-05
     +,   4.2749409E-05,   4.2532338E-05,   4.2308464E-05
     +,   4.2078878E-05,   4.1844647E-05,   4.1606858E-05
     +,   4.1366573E-05,   4.1124822E-05,   4.0882587E-05
     +,   4.0640847E-05,   4.0400490E-05,   4.0162413E-05
     +,   3.9927396E-05,   3.9696210E-05,   3.9469516E-05
     +,   3.9247927E-05,   3.9031976E-05,   3.8822127E-05
     +,   3.8618753E-05,   3.8422131E-05,   3.8232487E-05
     +,   3.8049940E-05,   3.7874524E-05,   3.7706173E-05
     +,   3.7544771E-05,   3.7390088E-05,   3.7241818E-05
     +,   3.7099580E-05,   3.6962920E-05,   3.6831298E-05
     +,   3.6704107E-05,   3.6580692E-05,   3.6460322E-05
     +,   3.6342211E-05,   3.6225534E-05,   3.6109417E-05
     +,   3.5992958E-05,   3.5875222E-05,   3.5755242E-05
     +,   3.5632052E-05,   3.5504669E-05,   3.5372112E-05
     +,   3.5233392E-05,   3.5087560E-05,   3.4933659E-05
     +,   3.4770765E-05,   3.4597997E-05,   3.4414516E-05
     +,   3.4219502E-05,   3.4012202E-05,   3.3791912E-05
     +,   3.3558004E-05,   3.3309898E-05,   3.3047068E-05
     +,   3.2769087E-05,   3.2475589E-05,   3.2166288E-05
     +,   3.1840951E-05,   3.1499465E-05,   3.1141772E-05
     +,   3.0767867E-05,   3.0377883E-05,   2.9971996E-05
     +,   2.9550460E-05,   2.9113597E-05,   2.8661827E-05
     +,   2.8195649E-05,   2.7715605E-05,   2.7222306E-05
     +,   2.6716476E-05,   2.6198933E-05,   2.5670552E-05
     +,   2.5132344E-05,   2.4585504E-05,   2.4031422E-05
     +,   2.3471774E-05,   2.2908693E-05,   2.2344906E-05
     +,   2.1783932E-05,   2.1230440E-05,   2.0690726E-05
     +,   2.0173209E-05,   1.9689140E-05,   1.9253504E-05
     +,   1.8886196E-05,   1.8613204E-05,   1.8468209E-05
     +,   1.8494307E-05,   1.8745925E-05,   1.9290899E-05
     +,   2.0212681E-05,   2.1612359E-05,   2.3610795E-05
     +,   2.6350719E-05,   2.9998488E-05,   3.4745372E-05
     +,   4.0809056E-05,   4.8435468E-05,   5.7900153E-05
     +,   6.9509289E-05,   8.3602230E-05,   1.0055539E-04
     +,   1.2078502E-04,   1.4474805E-04,   1.7294877E-04
     +,   2.0593774E-04,   2.4430623E-04,   2.8867851E-04
     +,   3.3969787E-04,   3.9799724E-04,   4.6415464E-04
     +,   5.3864327E-04,   6.2177196E-04,   7.1360561E-04
     +,   8.1388059E-04,   9.2193013E-04,   1.0366263E-03
     +,   1.1563267E-03,   1.2788459E-03,   1.4014998E-03
     +,   1.5211609E-03,   1.6343624E-03,   1.7374611E-03
     +,   1.8268315E-03,   1.8990695E-03,   1.9512017E-03
     +,   1.9808938E-03,   1.9866189E-03,   1.9677682E-03
     +,   1.9247103E-03,   1.8587833E-03,   1.7722080E-03
     +,   1.6679516E-03,   1.5495537E-03,   1.4208928E-03
     +,   1.2859692E-03,   1.1486963E-03,   1.0127029E-03
     +,   8.8116521E-04,   7.5671094E-04,   6.4136402E-04
     +,   5.3652236E-04,   4.4297823E-04,   3.6098578E-04
     +,   2.9034761E-04,   2.3050173E-04,   1.8061692E-04
     +,   1.3969163E-04,   1.0663997E-04,   8.0354024E-05
     +,   5.9763275E-05,   4.3874679E-05,   3.1795622E-05
     +,   2.2746673E-05,   1.6065916E-05,   1.1204856E-05
     +,   7.7185732E-06,   5.2536825E-06,   3.5354137E-06
     +,   2.3542975E-06,   1.5535049E-06,   1.0177480E-06
     +,   6.6384996E-07,   4.3286559E-07,   2.8369101E-07
     +,   1.8817943E-07,   1.2737921E-07,   8.8733884E-08
     +,   6.4058412E-08,   4.8104187E-08,   3.7557136E-08
     +,   3.0353920E-08,   2.5226807E-08,   2.1405990E-08
     +,   1.8428109E-08,   1.6014639E-08,   1.3997985E-08
     +,   1.2275428E-08,   1.0782521E-08,   9.4767305E-09
     +,   8.3286347E-09,   7.3162956E-09,   6.4226309E-09
     +,   5.6334724E-09,   4.9368589E-09,   4.3223016E-09
     +,   3.7805719E-09,   3.3035106E-09,   2.8837874E-09
     +,   2.5149076E-09,   2.1910278E-09,   1.9069739E-09
     +,   1.6580898E-09,   1.4402658E-09,   1.2498105E-09
     +,   1.0834709E-09,   9.3833552E-10,   8.1184093E-10
     +,   7.0170042E-10,   6.0590621E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt116 = Yx/0.0123846153846154
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2122561E-05,   1.2120281E-05
     +,   1.2115528E-05,   1.2108453E-05,   1.2099215E-05
     +,   1.2087976E-05,   1.2074897E-05,   1.2060150E-05
     +,   1.2043907E-05,   1.2026339E-05,   1.2007628E-05
     +,   1.1987951E-05,   1.1967487E-05,   1.1946415E-05
     +,   1.1924920E-05,   1.1903180E-05,   1.1881379E-05
     +,   1.1859692E-05,   1.1838300E-05,   1.1817375E-05
     +,   1.1797092E-05,   1.1777623E-05,   1.1759132E-05
     +,   1.1741780E-05,   1.1725730E-05,   1.1711135E-05
     +,   1.1698142E-05,   1.1686891E-05,   1.1677525E-05
     +,   1.1670176E-05,   1.1664964E-05,   1.1662012E-05
     +,   1.1661432E-05,   1.1663323E-05,   1.1667789E-05
     +,   1.1674916E-05,   1.1684785E-05,   1.1697472E-05
     +,   1.1713044E-05,   1.1731559E-05,   1.1753066E-05
     +,   1.1777612E-05,   1.1805225E-05,   1.1835935E-05
     +,   1.1869759E-05,   1.1906711E-05,   1.1946791E-05
     +,   1.1989996E-05,   1.2036313E-05,   1.2085723E-05
     +,   1.2138201E-05,   1.2193711E-05,   1.2252215E-05
     +,   1.2313669E-05,   1.2378016E-05,   1.2445202E-05
     +,   1.2515161E-05,   1.2587825E-05,   1.2663120E-05
     +,   1.2740969E-05,   1.2821287E-05,   1.2903986E-05
     +,   1.2988977E-05,   1.3076166E-05,   1.3165461E-05
     +,   1.3256751E-05,   1.3349944E-05,   1.3444928E-05
     +,   1.3541607E-05,   1.3639860E-05,   1.3739592E-05
     +,   1.3840679E-05,   1.3943023E-05,   1.4046503E-05
     +,   1.4151009E-05,   1.4256437E-05,   1.4362668E-05
     +,   1.4469590E-05,   1.4577093E-05,   1.4685071E-05
     +,   1.4793405E-05,   1.4901997E-05,   1.5010726E-05
     +,   1.5119499E-05,   1.5228193E-05,   1.5336716E-05
     +,   1.5444954E-05,   1.5552807E-05,   1.5660171E-05
     +,   1.5766940E-05,   1.5873020E-05,   1.5978307E-05
     +,   1.6082695E-05,   1.6186084E-05,   1.6288384E-05
     +,   1.6389489E-05,   1.6489303E-05,   1.6587721E-05
     +,   1.6684649E-05,   1.6779984E-05,   1.6873631E-05
     +,   1.6965483E-05,   1.7055445E-05,   1.7143411E-05
     +,   1.7229280E-05,   1.7312956E-05,   1.7394326E-05
     +,   1.7473283E-05,   1.7549728E-05,   1.7623552E-05
     +,   1.7694643E-05,   1.7762897E-05,   1.7828201E-05
     +,   1.7890441E-05,   1.7949505E-05,   1.8005283E-05
     +,   1.8057655E-05,   1.8106513E-05,   1.8151735E-05
     +,   1.8193206E-05,   1.8230814E-05,   1.8264442E-05
     +,   1.8293966E-05,   1.8319281E-05,   1.8340266E-05
     +,   1.8356814E-05,   1.8368806E-05,   1.8376131E-05
     +,   1.8378691E-05,   1.8376370E-05,   1.8369068E-05
     +,   1.8356684E-05,   1.8339128E-05,   1.8316299E-05
     +,   1.8288116E-05,   1.8254490E-05,   1.8215344E-05
     +,   1.8170613E-05,   1.8120219E-05,   1.8064107E-05
     +,   1.8002225E-05,   1.7934526E-05,   1.7860970E-05
     +,   1.7781524E-05,   1.7696164E-05,   1.7604882E-05
     +,   1.7507658E-05,   1.7404505E-05,   1.7295433E-05
     +,   1.7180464E-05,   1.7059619E-05,   1.6932947E-05
     +,   1.6800497E-05,   1.6662323E-05,   1.6518494E-05
     +,   1.6369089E-05,   1.6214206E-05,   1.6053931E-05
     +,   1.5888372E-05,   1.5717656E-05,   1.5541904E-05
     +,   1.5361242E-05,   1.5175827E-05,   1.4985817E-05
     +,   1.4791362E-05,   1.4592634E-05,   1.4389815E-05
     +,   1.4183103E-05,   1.3972691E-05,   1.3758785E-05
     +,   1.3541618E-05,   1.3321450E-05,   1.3098546E-05
     +,   1.2873224E-05,   1.2645882E-05,   1.2416986E-05
     +,   1.2187141E-05,   1.1957149E-05,   1.1728101E-05
     +,   1.1501464E-05,   1.1279247E-05,   1.1064243E-05
     +,   1.0860253E-05,   1.0672450E-05,   1.0507784E-05
     +,   1.0375556E-05,   1.0288008E-05,   1.0261053E-05
     +,   1.0315176E-05,   1.0476337E-05,   1.0777046E-05
     +,   1.1257523E-05,   1.1966825E-05,   1.2964109E-05
     +,   1.4319979E-05,   1.6117836E-05,   1.8455135E-05
     +,   2.1444950E-05,   2.5217976E-05,   2.9924486E-05
     +,   3.5736477E-05,   4.2850756E-05,   5.1493040E-05
     +,   6.1921892E-05,   7.4431868E-05,   8.9360037E-05
     +,   1.0708908E-04,   1.2804817E-04,   1.5271327E-04
     +,   1.8160435E-04,   2.1527447E-04,   2.5428983E-04
     +,   2.9920565E-04,   3.5053442E-04,   4.0870055E-04
     +,   4.7398385E-04,   5.4646470E-04,   6.2596955E-04
     +,   7.1201049E-04,   8.0372806E-04,   8.9987501E-04
     +,   9.9879643E-04,   1.0984393E-03,   1.1964036E-03
     +,   1.2900281E-03,   1.3764913E-03,   1.4529395E-03
     +,   1.5166441E-03,   1.5651652E-03,   1.5964940E-03
     +,   1.6091865E-03,   1.6024711E-03,   1.5763078E-03
     +,   1.5314008E-03,   1.4691721E-03,   1.3916712E-03
     +,   1.3014587E-03,   1.2014636E-03,   1.0948108E-03
     +,   9.8464417E-04,   8.7397342E-04,   7.6554163E-04
     +,   6.6171132E-04,   5.6438264E-04,   4.7496604E-04
     +,   3.9438606E-04,   3.2310304E-04,   2.6116142E-04
     +,   2.0826563E-04,   1.6386007E-04,   1.2719777E-04
     +,   9.7420081E-05,   7.3622563E-05,   5.4905406E-05
     +,   4.0413335E-05,   2.9365374E-05,   2.1071774E-05
     +,   1.4939807E-05,   1.0473304E-05,   7.2674284E-06
     +,   4.9994674E-06,   3.4174529E-06,   2.3286880E-06
     +,   1.5888476E-06,   1.0919455E-06,   7.6149604E-07
     +,   5.4336908E-07,   3.9993992E-07,   3.0549691E-07
     +,   2.4276690E-07,   2.0034490E-07,   1.7082330E-07
     +,   1.4946298E-07,   1.3327623E-07,   1.2040604E-07
     +,   1.0971245E-07,   1.0049985E-07,   9.2347264E-08
     +,   8.4997311E-08,   7.8291642E-08,   7.2128579E-08
     +,   6.6440919E-08,   6.1179875E-08,   5.6308956E-08
     +,   5.1797581E-08,   4.7620130E-08,   4.3753204E-08
     +,   4.0175451E-08,   3.6867444E-08,   3.3810561E-08
     +,   3.0987806E-08,   2.8382802E-08,   2.5980533E-08
     +,   2.3766550E-08,   2.1727638E-08,   1.9851074E-08
     +,   1.8125233E-08,   1.6538959E-08,   1.5082060E-08
     +,   1.3744795E-08,   1.2518260E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt117 = Yx/0.009625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2378508E-05,   1.2346547E-05
     +,   1.2311692E-05,   1.2274110E-05,   1.2233972E-05
     +,   1.2191456E-05,   1.2146740E-05,   1.2100012E-05
     +,   1.2051458E-05,   1.2001269E-05,   1.1949637E-05
     +,   1.1896759E-05,   1.1842833E-05,   1.1788055E-05
     +,   1.1732627E-05,   1.1676741E-05,   1.1620601E-05
     +,   1.1564402E-05,   1.1508338E-05,   1.1452603E-05
     +,   1.1397388E-05,   1.1342881E-05,   1.1289265E-05
     +,   1.1236720E-05,   1.1185421E-05,   1.1135539E-05
     +,   1.1087242E-05,   1.1040684E-05,   1.0996021E-05
     +,   1.0953398E-05,   1.0912952E-05,   1.0874820E-05
     +,   1.0839121E-05,   1.0805973E-05,   1.0775481E-05
     +,   1.0747747E-05,   1.0722855E-05,   1.0700892E-05
     +,   1.0681922E-05,   1.0666007E-05,   1.0653204E-05
     +,   1.0643548E-05,   1.0637072E-05,   1.0633798E-05
     +,   1.0633737E-05,   1.0636884E-05,   1.0643238E-05
     +,   1.0652773E-05,   1.0665462E-05,   1.0681264E-05
     +,   1.0700127E-05,   1.0721992E-05,   1.0746789E-05
     +,   1.0774443E-05,   1.0804858E-05,   1.0837943E-05
     +,   1.0873588E-05,   1.0911679E-05,   1.0952094E-05
     +,   1.0994702E-05,   1.1039364E-05,   1.1085936E-05
     +,   1.1134262E-05,   1.1184186E-05,   1.1235545E-05
     +,   1.1288166E-05,   1.1341876E-05,   1.1396492E-05
     +,   1.1451835E-05,   1.1507713E-05,   1.1563939E-05
     +,   1.1620319E-05,   1.1676656E-05,   1.1732754E-05
     +,   1.1788413E-05,   1.1843441E-05,   1.1897633E-05
     +,   1.1950790E-05,   1.2002720E-05,   1.2053223E-05
     +,   1.2102106E-05,   1.2149178E-05,   1.2194249E-05
     +,   1.2237138E-05,   1.2277657E-05,   1.2315634E-05
     +,   1.2350895E-05,   1.2383273E-05,   1.2412605E-05
     +,   1.2438736E-05,   1.2461519E-05,   1.2480810E-05
     +,   1.2496470E-05,   1.2508372E-05,   1.2516399E-05
     +,   1.2520432E-05,   1.2520371E-05,   1.2516116E-05
     +,   1.2507581E-05,   1.2494686E-05,   1.2477356E-05
     +,   1.2455534E-05,   1.2429169E-05,   1.2398212E-05
     +,   1.2362631E-05,   1.2322399E-05,   1.2277501E-05
     +,   1.2227932E-05,   1.2173691E-05,   1.2114789E-05
     +,   1.2051249E-05,   1.1983093E-05,   1.1910367E-05
     +,   1.1833109E-05,   1.1751380E-05,   1.1665234E-05
     +,   1.1574751E-05,   1.1480000E-05,   1.1381072E-05
     +,   1.1278059E-05,   1.1171051E-05,   1.1060162E-05
     +,   1.0945506E-05,   1.0827200E-05,   1.0705355E-05
     +,   1.0580115E-05,   1.0451602E-05,   1.0319963E-05
     +,   1.0185331E-05,   1.0047858E-05,   9.9076888E-06
     +,   9.7649809E-06,   9.6198792E-06,   9.4725519E-06
     +,   9.3231511E-06,   9.1718330E-06,   9.0187641E-06
     +,   8.8641118E-06,   8.7080316E-06,   8.5506817E-06
     +,   8.3922296E-06,   8.2328406E-06,   8.0726722E-06
     +,   7.9118754E-06,   7.7506220E-06,   7.5890589E-06
     +,   7.4273362E-06,   7.2656103E-06,   7.1040322E-06
     +,   6.9427442E-06,   6.7818837E-06,   6.6215953E-06
     +,   6.4620199E-06,   6.3032862E-06,   6.1455212E-06
     +,   5.9888594E-06,   5.8334340E-06,   5.6793710E-06
     +,   5.5267992E-06,   5.3758699E-06,   5.2267378E-06
     +,   5.0795738E-06,   4.9346004E-06,   4.7920830E-06
     +,   4.6523583E-06,   4.5158640E-06,   4.3831956E-06
     +,   4.2551474E-06,   4.1327798E-06,   4.0175146E-06
     +,   3.9112647E-06,   3.8165658E-06,   3.7367533E-06
     +,   3.6761858E-06,   3.6405013E-06,   3.6369170E-06
     +,   3.6745676E-06,   3.7649006E-06,   3.9220727E-06
     +,   4.1634185E-06,   4.5098918E-06,   4.9864907E-06
     +,   5.6226563E-06,   6.4526730E-06,   7.5159069E-06
     +,   8.8568622E-06,   1.0525199E-05,   1.2575678E-05
     +,   1.5067804E-05,   1.8065022E-05,   2.1634633E-05
     +,   2.5846946E-05,   3.0774361E-05,   3.6491023E-05
     +,   4.3073007E-05,   5.0598264E-05,   5.9146645E-05
     +,   6.8801462E-05,   7.9652018E-05,   9.1795511E-05
     +,   1.0533903E-04,   1.2040303E-04,   1.3712526E-04
     +,   1.5566211E-04,   1.7618771E-04,   1.9889647E-04
     +,   2.2399824E-04,   2.5171024E-04,   2.8224874E-04
     +,   3.1581800E-04,   3.5259203E-04,   3.9269254E-04
     +,   4.3616944E-04,   4.8298104E-04,   5.3297036E-04
     +,   5.8584195E-04,   6.4114947E-04,   6.9829100E-04
     +,   7.5650448E-04,   8.1486953E-04,   8.7233644E-04
     +,   9.2774729E-04,   9.7986998E-04,   1.0274450E-03
     +,   1.0692382E-03,   1.1040897E-03,   1.1309637E-03
     +,   1.1490007E-03,   1.1575607E-03,   1.1562526E-03
     +,   1.1449574E-03,   1.1238387E-03,   1.0933330E-03
     +,   1.0541352E-03,   1.0071695E-03,   9.5354539E-04
     +,   8.9450984E-04,   8.3140156E-04,   7.6559332E-04
     +,   6.9843559E-04,   6.3121261E-04,   5.6510634E-04
     +,   5.0115882E-04,   4.4024491E-04,   3.8306296E-04
     +,   3.3013386E-04,   2.8180084E-04,   2.3823802E-04
     +,   1.9947124E-04,   1.6540235E-04,   1.3582506E-04
     +,   1.1045345E-04,   8.8946806E-05,   7.0929076E-05
     +,   5.6007630E-05,   4.3790995E-05,   3.3902459E-05
     +,   2.5988549E-05,   1.9725472E-05,   1.4823804E-05
     +,   1.1030162E-05,   8.1264889E-06,   5.9282829E-06
     +,   4.2822790E-06,   3.0632477E-06,   2.1701815E-06
     +,   1.5229547E-06,   1.0589420E-06,   7.2983039E-07
     +,   4.9885284E-07,   3.3843054E-07,   2.2815308E-07
     +,   1.5310097E-07,   1.0250686E-07,   6.8703947E-08
     +,   4.6303036E-08,   3.1557725E-08,   2.1899728E-08
     +,   1.5587043E-08,   1.1453958E-08,   8.7284375E-09
     +,   6.9057551E-09,   5.6591594E-09,   4.7796820E-09
     +,   4.1347885E-09,   3.6413164E-09,   3.2473542E-09
     +,   2.9206890E-09,   2.6413518E-09,   2.3968607E-09
     +,   2.1793440E-09,   1.9836883E-09,   1.8064668E-09
     +,   1.6452431E-09,   1.4982184E-09,   1.3639551E-09
     +,   1.2412822E-09,   1.1291726E-09,   1.0267378E-09
     +,   9.3316155E-10,   8.4771756E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt118 = Yx/0.00827272727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt1188(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.4814895E-06,   9.5194564E-06
     +,   9.5625828E-06,   9.6112735E-06,   9.6659396E-06
     +,   9.7270058E-06,   9.7949032E-06,   9.8700730E-06
     +,   9.9529634E-06,   1.0044037E-05,   1.0143758E-05
     +,   1.0252599E-05,   1.0371041E-05,   1.0499571E-05
     +,   1.0638674E-05,   1.0788851E-05,   1.0950598E-05
     +,   1.1124412E-05,   1.1310798E-05,   1.1510250E-05
     +,   1.1723278E-05,   1.1950372E-05,   1.2192021E-05
     +,   1.2448724E-05,   1.2720947E-05,   1.3009169E-05
     +,   1.3313852E-05,   1.3635435E-05,   1.3974356E-05
     +,   1.4331028E-05,   1.4705849E-05,   1.5099193E-05
     +,   1.5511408E-05,   1.5942824E-05,   1.6393737E-05
     +,   1.6864409E-05,   1.7355069E-05,   1.7865907E-05
     +,   1.8397101E-05,   1.8948731E-05,   1.9520887E-05
     +,   2.0113583E-05,   2.0726784E-05,   2.1360407E-05
     +,   2.2014310E-05,   2.2688298E-05,   2.3382105E-05
     +,   2.4095405E-05,   2.4827810E-05,   2.5578862E-05
     +,   2.6348029E-05,   2.7134709E-05,   2.7938211E-05
     +,   2.8757837E-05,   2.9592687E-05,   3.0441915E-05
     +,   3.1304520E-05,   3.2179450E-05,   3.3065557E-05
     +,   3.3961649E-05,   3.4866425E-05,   3.5778543E-05
     +,   3.6696525E-05,   3.7618898E-05,   3.8544127E-05
     +,   3.9470506E-05,   4.0396404E-05,   4.1320014E-05
     +,   4.2239586E-05,   4.3153203E-05,   4.4059037E-05
     +,   4.4955097E-05,   4.5839482E-05,   4.6710142E-05
     +,   4.7565103E-05,   4.8402380E-05,   4.9219925E-05
     +,   5.0015704E-05,   5.0787738E-05,   5.1534073E-05
     +,   5.2252701E-05,   5.2941759E-05,   5.3599313E-05
     +,   5.4223601E-05,   5.4812816E-05,   5.5365290E-05
     +,   5.5879380E-05,   5.6353583E-05,   5.6786419E-05
     +,   5.7176549E-05,   5.7522746E-05,   5.7823861E-05
     +,   5.8078851E-05,   5.8286831E-05,   5.8447036E-05
     +,   5.8558799E-05,   5.8621608E-05,   5.8635087E-05
     +,   5.8598980E-05,   5.8513182E-05,   5.8377744E-05
     +,   5.8192818E-05,   5.7958721E-05,   5.7675908E-05
     +,   5.7344958E-05,   5.6966572E-05,   5.6541630E-05
     +,   5.6071083E-05,   5.5556058E-05,   5.4997719E-05
     +,   5.4397446E-05,   5.3756619E-05,   5.3076823E-05
     +,   5.2359625E-05,   5.1606785E-05,   5.0820036E-05
     +,   5.0001290E-05,   4.9152412E-05,   4.8275429E-05
     +,   4.7372330E-05,   4.6445140E-05,   4.5495966E-05
     +,   4.4526954E-05,   4.3540178E-05,   4.2537733E-05
     +,   4.1521795E-05,   4.0494404E-05,   3.9457715E-05
     +,   3.8413713E-05,   3.7364494E-05,   3.6311969E-05
     +,   3.5258152E-05,   3.4204855E-05,   3.3153974E-05
     +,   3.2107248E-05,   3.1066342E-05,   3.0032908E-05
     +,   2.9008548E-05,   2.7994694E-05,   2.6992715E-05
     +,   2.6003958E-05,   2.5029685E-05,   2.4071007E-05
     +,   2.3128960E-05,   2.2204569E-05,   2.1298700E-05
     +,   2.0412121E-05,   1.9545572E-05,   1.8699726E-05
     +,   1.7875098E-05,   1.7072131E-05,   1.6291249E-05
     +,   1.5532789E-05,   1.4796970E-05,   1.4083937E-05
     +,   1.3393820E-05,   1.2726682E-05,   1.2082476E-05
     +,   1.1461104E-05,   1.0862464E-05,   1.0286358E-05
     +,   9.7325283E-06,   9.2007213E-06,   8.6906321E-06
     +,   8.2018896E-06,   7.7340919E-06,   7.2868434E-06
     +,   6.8597205E-06,   6.4522592E-06,   6.0639832E-06
     +,   5.6944464E-06,   5.3432136E-06,   5.0098511E-06
     +,   4.6939863E-06,   4.3953505E-06,   4.1137710E-06
     +,   3.8492617E-06,   3.6021070E-06,   3.3729555E-06
     +,   3.1629386E-06,   2.9738760E-06,   2.8085310E-06
     +,   2.6708931E-06,   2.5665747E-06,   2.5033210E-06
     +,   2.4916258E-06,   2.5454767E-06,   2.6832731E-06
     +,   2.9289149E-06,   3.3130395E-06,   3.8745156E-06
     +,   4.6620930E-06,   5.7361531E-06,   7.1706709E-06
     +,   9.0553967E-06,   1.1497942E-05,   1.4625652E-05
     +,   1.8587565E-05,   2.3556346E-05,   2.9729395E-05
     +,   3.7328955E-05,   4.6602061E-05,   5.7819976E-05
     +,   7.1275535E-05,   8.7277505E-05,   1.0614775E-04
     +,   1.2821294E-04,   1.5379363E-04,   1.8319389E-04
     +,   2.1669046E-04,   2.5451672E-04,   2.9684359E-04
     +,   3.4376385E-04,   3.9527882E-04,   4.5127809E-04
     +,   5.1152060E-04,   5.7562377E-04,   6.4305915E-04
     +,   7.1314262E-04,   7.8502967E-04,   8.5773499E-04
     +,   9.3014119E-04,   1.0010148E-03,   1.0690432E-03
     +,   1.1328735E-03,   1.1911491E-03,   1.2425546E-03
     +,   1.2858650E-03,   1.3199989E-03,   1.3440580E-03
     +,   1.3573638E-03,   1.3594948E-03,   1.3503057E-03
     +,   1.3299359E-03,   1.2988118E-03,   1.2576266E-03
     +,   1.2073172E-03,   1.1490301E-03,   1.0840764E-03
     +,   1.0138755E-03,   9.3990506E-04,   8.6365378E-04
     +,   7.8656554E-04,   7.0998917E-04,   6.3514482E-04
     +,   5.6309841E-04,   4.9473700E-04,   4.3075331E-04
     +,   3.7164858E-04,   3.1774526E-04,   2.6918814E-04
     +,   2.2596994E-04,   1.8795610E-04,   1.5490584E-04
     +,   1.2649522E-04,   1.0234468E-04,   8.2042163E-05
     +,   6.5160864E-05,   5.1274972E-05,   3.9974591E-05
     +,   3.0875970E-05,   2.3627339E-05,   1.7912589E-05
     +,   1.3453745E-05,   1.0010913E-05,   7.3797623E-06
     +,   5.3894155E-06,   3.8991743E-06,   2.7947158E-06
     +,   1.9844022E-06,   1.3958587E-06,   9.7269287E-07
     +,   6.7148534E-07,   4.5921638E-07,   3.1110866E-07
     +,   2.0880042E-07,   1.3882403E-07,   9.1437684E-08
     +,   5.9662845E-08,   3.8567219E-08,   2.4698121E-08
     +,   1.5669864E-08,   9.8498001E-09,   6.1346603E-09
     +,   3.7860040E-09,   2.3156461E-09,   1.4039295E-09
     +,   8.4396728E-10,   5.0329818E-10,   2.9793934E-10
     +,   1.7526496E-10,   1.0260812E-10,   5.9923719E-11
     +,   3.5025736E-11,   2.0589044E-11,   1.2250537E-11
     +,   7.4394753E-12,   4.6543828E-12,   3.0271610E-12
     +,   2.0597675E-12,   1.4689268E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt1188 = Yx/0.0102083333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.2473118E-15,   8.8687314E-15
     +,   1.2556228E-14,   1.7729077E-14,   2.4965568E-14
     +,   3.5061140E-14,   4.9106406E-14,   6.8593053E-14
     +,   9.5553834E-14,   1.3275434E-13,   1.8394031E-13
     +,   2.5417602E-13,   3.5028515E-13,   4.8143510E-13
     +,   6.5990789E-13,   9.0210722E-13,   1.2298802E-12
     +,   1.6722335E-12,   2.2675763E-12,   3.0665919E-12
     +,   4.1360010E-12,   5.5633458E-12,   7.4631126E-12
     +,   9.9847786E-12,   1.3322451E-11,   1.7728138E-11
     +,   2.3527369E-11,   3.1139757E-11,   4.1104453E-11
     +,   5.4112170E-11,   7.1044878E-11,   9.3025802E-11
     +,   1.2148064E-10,   1.5821329E-10,   2.0550034E-10
     +,   2.6620406E-10,   3.4391495E-10,   4.4311779E-10
     +,   5.6940991E-10,   7.2972900E-10,   9.3268349E-10
     +,   1.1888898E-09,   1.5114148E-09,   1.9162898E-09
     +,   2.4231113E-09,   3.0557763E-09,   3.8433110E-09
     +,   4.8208686E-09,   6.0308882E-09,   7.5244264E-09
     +,   9.3627204E-09,   1.1618972E-08,   1.4380320E-08
     +,   1.7750462E-08,   2.1851699E-08,   2.6828671E-08
     +,   3.2851212E-08,   4.0118181E-08,   4.8861789E-08
     +,   5.9352029E-08,   7.1901830E-08,   8.6872916E-08
     +,   1.0468028E-07,   1.2580099E-07,   1.5078051E-07
     +,   1.8023650E-07,   2.1487321E-07,   2.5548118E-07
     +,   3.0295453E-07,   3.5828893E-07,   4.2260208E-07
     +,   4.9712742E-07,   5.8323855E-07,   6.8243753E-07
     +,   7.9637971E-07,   9.2687327E-07,   1.0758739E-06
     +,   1.2454933E-06,   1.4380116E-06,   1.6558727E-06
     +,   1.9016519E-06,   2.1781041E-06,   2.4880906E-06
     +,   2.8346399E-06,   3.2208459E-06,   3.6499448E-06
     +,   4.1251883E-06,   4.6499244E-06,   5.2274481E-06
     +,   5.8610740E-06,   6.5540580E-06,   7.3094984E-06
     +,   8.1303278E-06,   9.0193171E-06,   9.9789859E-06
     +,   1.1011432E-05,   1.2118511E-05,   1.3301500E-05
     +,   1.4561337E-05,   1.5898248E-05,   1.7312035E-05
     +,   1.8801657E-05,   2.0365575E-05,   2.2001310E-05
     +,   2.3705776E-05,   2.5475094E-05,   2.7304475E-05
     +,   2.9188306E-05,   3.1120297E-05,   3.3093384E-05
     +,   3.5099551E-05,   3.7130336E-05,   3.9176364E-05
     +,   4.1227948E-05,   4.3274613E-05,   4.5305758E-05
     +,   4.7310208E-05,   4.9276841E-05,   5.1194205E-05
     +,   5.3051099E-05,   5.4836462E-05,   5.6539451E-05
     +,   5.8149650E-05,   5.9657308E-05,   6.1053368E-05
     +,   6.2329447E-05,   6.3478212E-05,   6.4493208E-05
     +,   6.5369219E-05,   6.6102046E-05,   6.6688823E-05
     +,   6.7127861E-05,   6.7418776E-05,   6.7562440E-05
     +,   6.7560977E-05,   6.7417757E-05,   6.7137284E-05
     +,   6.6725181E-05,   6.6188077E-05,   6.5533481E-05
     +,   6.4769738E-05,   6.3905929E-05,   6.2951607E-05
     +,   6.1916733E-05,   6.0811672E-05,   5.9646842E-05
     +,   5.8432666E-05,   5.7179528E-05,   5.5897592E-05
     +,   5.4596570E-05,   5.3285708E-05,   5.1973791E-05
     +,   5.0668968E-05,   4.9378563E-05,   4.8109174E-05
     +,   4.6866626E-05,   4.5655943E-05,   4.4481196E-05
     +,   4.3345619E-05,   4.2251711E-05,   4.1201056E-05
     +,   4.0194453E-05,   3.9232051E-05,   3.8313316E-05
     +,   3.7437021E-05,   3.6601414E-05,   3.5804318E-05
     +,   3.5043147E-05,   3.4314933E-05,   3.3616456E-05
     +,   3.2944372E-05,   3.2295218E-05,   3.1665440E-05
     +,   3.1051532E-05,   3.0450090E-05,   2.9857822E-05
     +,   2.9271587E-05,   2.8688515E-05,   2.8105986E-05
     +,   2.7521632E-05,   2.6933370E-05,   2.6339500E-05
     +,   2.5738651E-05,   2.5129766E-05,   2.4512154E-05
     +,   2.3885568E-05,   2.3250188E-05,   2.2606670E-05
     +,   2.1956268E-05,   2.1301088E-05,   2.0644193E-05
     +,   1.9990026E-05,   1.9344967E-05,   1.8717965E-05
     +,   1.8121376E-05,   1.7572169E-05,   1.7093333E-05
     +,   1.6715510E-05,   1.6478878E-05,   1.6435324E-05
     +,   1.6650776E-05,   1.7207547E-05,   1.8206956E-05
     +,   1.9771973E-05,   2.2049824E-05,   2.5215455E-05
     +,   2.9475210E-05,   3.5071025E-05,   4.2286039E-05
     +,   5.1451705E-05,   6.2954794E-05,   7.7243349E-05
     +,   9.4831543E-05,   1.1630106E-04,   1.4229234E-04
     +,   1.7348243E-04,   2.1055022E-04,   2.5412499E-04
     +,   3.0471219E-04,   3.6259720E-04,   4.2775500E-04
     +,   4.9974408E-04,   5.7761197E-04,   6.5983838E-04
     +,   7.4432348E-04,   8.2842301E-04,   9.0904505E-04
     +,   9.8282471E-04,   1.0463492E-03,   1.0964078E-03
     +,   1.1302551E-03,   1.1458611E-03,   1.1421031E-03
     +,   1.1188801E-03,   1.0771411E-03,   1.0188088E-03
     +,   9.4662240E-04,   8.6391368E-04,   7.7433587E-04
     +,   6.8157673E-04,   5.8910565E-04,   4.9996632E-04
     +,   4.1661918E-04,   3.4085495E-04,   2.7378852E-04
     +,   2.1590797E-04,   1.6715766E-04,   1.2705171E-04
     +,   9.4803807E-05,   6.9450034E-05,   4.9948594E-05
     +,   3.5268389E-05,   2.4450346E-05,   1.6644055E-05
     +,   1.1126356E-05,   7.3052634E-06,   4.7122512E-06
     +,   2.9875323E-06,   1.8627314E-06,   1.1432638E-06
     +,   6.9173910E-07,   4.1354255E-07,   2.4510916E-07
     +,   1.4476842E-07,   8.5837790E-08,   5.1605330E-08
     +,   3.1841427E-08,   2.0418311E-08,   1.3739617E-08
     +,   9.7358246E-09,   7.2377726E-09,   5.5950551E-09
     +,   4.4497814E-09,   3.6058621E-09,   2.9552099E-09
     +,   2.4370028E-09,   2.0154700E-09,   1.6683156E-09
     +,   1.3805131E-09,   1.1412296E-09,   9.4212116E-10
     +,   7.7652579E-10,   6.3895123E-10,   5.2483368E-10
     +,   4.3032847E-10,   3.5221032E-10,   2.8775363E-10
     +,   2.3466695E-10,   1.9102969E-10,   1.5522512E-10
     +,   1.2590415E-10,   1.0193636E-10,   8.2382670E-11
     +,   6.6458908E-11,   5.3516549E-11,   4.3016403E-11
     +,   3.4514187E-11,   2.7642149E-11,   2.2098538E-11
     +,   1.7634630E-11,   1.4047101E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt120 = Yx/0.0063
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4840569E-05,   1.5473011E-05
     +,   1.6145830E-05,   1.6863018E-05,   1.7628774E-05
     +,   1.8447512E-05,   1.9323821E-05,   2.0262463E-05
     +,   2.1268317E-05,   2.2346409E-05,   2.3501827E-05
     +,   2.4739715E-05,   2.6065272E-05,   2.7483720E-05
     +,   2.9000257E-05,   3.0620093E-05,   3.2348420E-05
     +,   3.4190401E-05,   3.6151221E-05,   3.8236016E-05
     +,   4.0450013E-05,   4.2798456E-05,   4.5286681E-05
     +,   4.7920312E-05,   5.0704904E-05,   5.3646567E-05
     +,   5.6751582E-05,   6.0026661E-05,   6.3478976E-05
     +,   6.7116234E-05,   7.0946749E-05,   7.4979405E-05
     +,   7.9223799E-05,   8.3690124E-05,   8.8389206E-05
     +,   9.3332405E-05,   9.8531513E-05,   1.0399847E-04
     +,   1.0974560E-04,   1.1578431E-04,   1.2212599E-04
     +,   1.2878064E-04,   1.3575674E-04,   1.4306062E-04
     +,   1.5069595E-04,   1.5866305E-04,   1.6695830E-04
     +,   1.7557347E-04,   1.8449529E-04,   1.9370500E-04
     +,   2.0317783E-04,   2.1288318E-04,   2.2278426E-04
     +,   2.3283924E-04,   2.4299996E-04,   2.5321505E-04
     +,   2.6342907E-04,   2.7358450E-04,   2.8362341E-04
     +,   2.9348844E-04,   3.0312527E-04,   3.1248393E-04
     +,   3.2152020E-04,   3.3019870E-04,   3.3849347E-04
     +,   3.4638873E-04,   3.5388157E-04,   3.6098098E-04
     +,   3.6770990E-04,   3.7410337E-04,   3.8020936E-04
     +,   3.8608661E-04,   3.9180412E-04,   3.9743743E-04
     +,   4.0306756E-04,   4.0877666E-04,   4.1464518E-04
     +,   4.2074689E-04,   4.2714644E-04,   4.3389507E-04
     +,   4.4102536E-04,   4.4855085E-04,   4.5646130E-04
     +,   4.6472391E-04,   4.7328076E-04,   4.8205291E-04
     +,   4.9094070E-04,   4.9982994E-04,   5.0859590E-04
     +,   5.1710993E-04,   5.2524731E-04,   5.3289125E-04
     +,   5.3994154E-04,   5.4631912E-04,   5.5197021E-04
     +,   5.5686728E-04,   5.6101143E-04,   5.6442845E-04
     +,   5.6716677E-04,   5.6929159E-04,   5.7087891E-04
     +,   5.7200796E-04,   5.7275506E-04,   5.7318615E-04
     +,   5.7335244E-04,   5.7328562E-04,   5.7299697E-04
     +,   5.7247654E-04,   5.7169580E-04,   5.7061040E-04
     +,   5.6916766E-04,   5.6731090E-04,   5.6498690E-04
     +,   5.6215277E-04,   5.5878185E-04,   5.5486872E-04
     +,   5.5043283E-04,   5.4551917E-04,   5.4020016E-04
     +,   5.3457147E-04,   5.2874949E-04,   5.2286650E-04
     +,   5.1706383E-04,   5.1148533E-04,   5.0627056E-04
     +,   5.0154777E-04,   4.9742818E-04,   4.9400073E-04
     +,   4.9132732E-04,   4.8944150E-04,   4.8834679E-04
     +,   4.8801713E-04,   4.8839906E-04,   4.8941455E-04
     +,   4.9096590E-04,   4.9293973E-04,   4.9521355E-04
     +,   4.9765996E-04,   5.0015358E-04,   5.0257472E-04
     +,   5.0481386E-04,   5.0677464E-04,   5.0837611E-04
     +,   5.0955382E-04,   5.1025895E-04,   5.1045790E-04
     +,   5.1013031E-04,   5.0926604E-04,   5.0786324E-04
     +,   5.0592457E-04,   5.0345482E-04,   5.0045911E-04
     +,   4.9694051E-04,   4.9289939E-04,   4.8833236E-04
     +,   4.8323363E-04,   4.7759552E-04,   4.7140929E-04
     +,   4.6466768E-04,   4.5736760E-04,   4.4951044E-04
     +,   4.4110537E-04,   4.3217078E-04,   4.2273573E-04
     +,   4.1283914E-04,   4.0253173E-04,   3.9187487E-04
     +,   3.8094010E-04,   3.6980613E-04,   3.5855814E-04
     +,   3.4728597E-04,   3.3608070E-04,   3.2503204E-04
     +,   3.1422565E-04,   3.0374256E-04,   2.9365451E-04
     +,   2.8402303E-04,   2.7489907E-04,   2.6632074E-04
     +,   2.5831274E-04,   2.5088617E-04,   2.4403998E-04
     +,   2.3776053E-04,   2.3202234E-04,   2.2679006E-04
     +,   2.2202003E-04,   2.1766174E-04,   2.1365908E-04
     +,   2.0995262E-04,   2.0648162E-04,   2.0318480E-04
     +,   2.0000256E-04,   1.9687810E-04,   1.9375878E-04
     +,   1.9059661E-04,   1.8734937E-04,   1.8398116E-04
     +,   1.8046281E-04,   1.7677165E-04,   1.7289158E-04
     +,   1.6881333E-04,   1.6453379E-04,   1.6005534E-04
     +,   1.5538541E-04,   1.5053657E-04,   1.4552475E-04
     +,   1.4036926E-04,   1.3509220E-04,   1.2971762E-04
     +,   1.2427055E-04,   1.1877667E-04,   1.1326218E-04
     +,   1.0775297E-04,   1.0227371E-04,   9.6848067E-05
     +,   9.1498558E-05,   8.6246044E-05,   8.1109152E-05
     +,   7.6104610E-05,   7.1247552E-05,   6.6550514E-05
     +,   6.2024024E-05,   5.7676829E-05,   5.3515752E-05
     +,   4.9545459E-05,   4.5768884E-05,   4.2187588E-05
     +,   3.8801663E-05,   3.5609592E-05,   3.2608728E-05
     +,   2.9795541E-05,   2.7165586E-05,   2.4713459E-05
     +,   2.2433127E-05,   2.0318259E-05,   1.8361878E-05
     +,   1.6556716E-05,   1.4895421E-05,   1.3370478E-05
     +,   1.1974222E-05,   1.0699011E-05,   9.5373689E-06
     +,   8.4819203E-06,   7.5253911E-06,   6.6607222E-06
     +,   5.8811520E-06,   5.1801612E-06,   4.5514712E-06
     +,   3.9891029E-06,   3.4874388E-06,   3.0411200E-06
     +,   2.6451087E-06,   2.2947115E-06,   1.9855418E-06
     +,   1.7135019E-06,   1.4747989E-06,   1.2659495E-06
     +,   1.0837484E-06,   9.2524840E-07,   7.8776208E-07
     +,   6.6885627E-07,   5.6632558E-07,   4.7817349E-07
     +,   4.0260713E-07,   3.3802755E-07,   2.8300170E-07
     +,   2.3625617E-07,   1.9666714E-07,   1.6324201E-07
     +,   1.3510659E-07,   1.1149559E-07,   9.1743225E-08
     +,   7.5270357E-08,   6.1574575E-08,   5.0222649E-08
     +,   4.0843315E-08,   3.3117441E-08,   2.6773790E-08
     +,   2.1581025E-08,   1.7343893E-08,   1.3897138E-08
     +,   1.1102292E-08,   8.8429966E-09,   7.0224941E-09
     +,   5.5600644E-09,   4.3890487E-09,   3.4542813E-09
     +,   2.7104292E-09,   2.1203925E-09,   1.6538079E-09
     +,   1.2860291E-09,   9.9702147E-10,   7.7064410E-10
     +,   5.9386807E-10,   4.5626788E-10,   3.4949094E-10
     +,   2.6689770E-10,   2.0320710E-10,   1.5425002E-10
     +,   1.1673364E-10,   8.8076123E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt75 = Yx/0.01625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6386659E-05,   1.6551525E-05
     +,   1.6715079E-05,   1.6877791E-05,   1.7040251E-05
     +,   1.7203214E-05,   1.7367604E-05,   1.7534547E-05
     +,   1.7705372E-05,   1.7881692E-05,   1.8065348E-05
     +,   1.8258521E-05,   1.8463714E-05,   1.8683782E-05
     +,   1.8921981E-05,   1.9182011E-05,   1.9468020E-05
     +,   1.9784649E-05,   2.0137086E-05,   2.0531077E-05
     +,   2.0972953E-05,   2.1469701E-05,   2.2028935E-05
     +,   2.2659016E-05,   2.3368939E-05,   2.4168514E-05
     +,   2.5068277E-05,   2.6079530E-05,   2.7214370E-05
     +,   2.8485645E-05,   2.9907000E-05,   3.1492804E-05
     +,   3.3258133E-05,   3.5218723E-05,   3.7390873E-05
     +,   3.9791415E-05,   4.2437499E-05,   4.5346533E-05
     +,   4.8536131E-05,   5.2023435E-05,   5.5825596E-05
     +,   5.9958962E-05,   6.4438995E-05,   6.9279922E-05
     +,   7.4494412E-05,   8.0093159E-05,   8.6084583E-05
     +,   9.2474358E-05,   9.9264951E-05,   1.0645542E-04
     +,   1.1404089E-04,   1.2201221E-04,   1.3035559E-04
     +,   1.3905298E-04,   1.4808042E-04,   1.5740968E-04
     +,   1.6700711E-04,   1.7683393E-04,   1.8684666E-04
     +,   1.9699727E-04,   2.0723355E-04,   2.1749984E-04
     +,   2.2773683E-04,   2.3788397E-04,   2.4787916E-04
     +,   2.5765895E-04,   2.6716167E-04,   2.7632609E-04
     +,   2.8509487E-04,   2.9341324E-04,   3.0123245E-04
     +,   3.0850864E-04,   3.1520575E-04,   3.2129456E-04
     +,   3.2675511E-04,   3.3157648E-04,   3.3575686E-04
     +,   3.3930445E-04,   3.4223750E-04,   3.4458379E-04
     +,   3.4638002E-04,   3.4767159E-04,   3.4851115E-04
     +,   3.4895787E-04,   3.4907539E-04,   3.4893071E-04
     +,   3.4859197E-04,   3.4812657E-04,   3.4759927E-04
     +,   3.4706976E-04,   3.4659123E-04,   3.4620790E-04
     +,   3.4595403E-04,   3.4585185E-04,   3.4591160E-04
     +,   3.4613031E-04,   3.4649295E-04,   3.4697205E-04
     +,   3.4753000E-04,   3.4812075E-04,   3.4869229E-04
     +,   3.4918962E-04,   3.4955842E-04,   3.4974838E-04
     +,   3.4971704E-04,   3.4943281E-04,   3.4887824E-04
     +,   3.4805248E-04,   3.4697255E-04,   3.4567423E-04
     +,   3.4421141E-04,   3.4265470E-04,   3.4108903E-04
     +,   3.3960954E-04,   3.3831896E-04,   3.3732216E-04
     +,   3.3672273E-04,   3.3661904E-04,   3.3710207E-04
     +,   3.3825397E-04,   3.4014846E-04,   3.4285299E-04
     +,   3.4643256E-04,   3.5095515E-04,   3.5649870E-04
     +,   3.6315652E-04,   3.7104628E-04,   3.8031285E-04
     +,   3.9113578E-04,   4.0372691E-04,   4.1833235E-04
     +,   4.3522377E-04,   4.5469418E-04,   4.7704153E-04
     +,   5.0255709E-04,   5.3150888E-04,   5.6411797E-04
     +,   6.0054322E-04,   6.4086082E-04,   6.8504730E-04
     +,   7.3295651E-04,   7.8431121E-04,   8.3869469E-04
     +,   8.9554483E-04,   9.5415005E-04,   1.0136642E-03
     +,   1.0731226E-03,   1.1314553E-03,   1.1875220E-03
     +,   1.2401494E-03,   1.2881687E-03,   1.3304516E-03
     +,   1.3659584E-03,   1.3937787E-03,   1.4131629E-03
     +,   1.4235533E-03,   1.4246057E-03,   1.4162040E-03
     +,   1.3984600E-03,   1.3717139E-03,   1.3365167E-03
     +,   1.2936082E-03,   1.2438976E-03,   1.1884259E-03
     +,   1.1283275E-03,   1.0647957E-03,   9.9904940E-04
     +,   9.3228969E-04,   8.6566171E-04,   8.0022810E-04
     +,   7.3694467E-04,   6.7663810E-04,   6.1998621E-04
     +,   5.6751643E-04,   5.1961088E-04,   4.7650040E-04
     +,   4.3828198E-04,   4.0493597E-04,   3.7633916E-04
     +,   3.5228278E-04,   3.3249246E-04,   3.1664807E-04
     +,   3.0439693E-04,   2.9536744E-04,   2.8918197E-04
     +,   2.8546643E-04,   2.8385603E-04,   2.8400111E-04
     +,   2.8557106E-04,   2.8825624E-04,   2.9176997E-04
     +,   2.9584920E-04,   3.0025441E-04,   3.0477019E-04
     +,   3.0920468E-04,   3.1338938E-04,   3.1717782E-04
     +,   3.2044572E-04,   3.2308992E-04,   3.2502727E-04
     +,   3.2619346E-04,   3.2654201E-04,   3.2604308E-04
     +,   3.2468184E-04,   3.2245749E-04,   3.1938130E-04
     +,   3.1547502E-04,   3.1077050E-04,   3.0530719E-04
     +,   2.9913106E-04,   2.9229326E-04,   2.8484955E-04
     +,   2.7685880E-04,   2.6838153E-04,   2.5947942E-04
     +,   2.5021541E-04,   2.4065199E-04,   2.3085055E-04
     +,   2.2087102E-04,   2.1077269E-04,   2.0061176E-04
     +,   1.9044180E-04,   1.8031453E-04,   1.7027851E-04
     +,   1.6037839E-04,   1.5065541E-04,   1.4114776E-04
     +,   1.3188986E-04,   1.2291169E-04,   1.1423929E-04
     +,   1.0589542E-04,   9.7898825E-05,   9.0263857E-05
     +,   8.3001221E-05,   7.6118711E-05,   6.9619986E-05
     +,   6.3505489E-05,   5.7773170E-05,   5.2418196E-05
     +,   4.7432914E-05,   4.2807576E-05,   3.8530878E-05
     +,   3.4589928E-05,   3.0970252E-05,   2.7656439E-05
     +,   2.4632553E-05,   2.1882133E-05,   1.9388259E-05
     +,   1.7133993E-05,   1.5102734E-05,   1.3277948E-05
     +,   1.1643549E-05,   1.0184097E-05,   8.8847655E-06
     +,   7.7313416E-06,   6.7103874E-06,   5.8093292E-06
     +,   5.0163890E-06,   4.3205600E-06,   3.7116574E-06
     +,   3.1803456E-06,   2.7180536E-06,   2.3169291E-06
     +,   1.9698423E-06,   1.6703731E-06,   1.4127024E-06
     +,   1.1916101E-06,   1.0024419E-06,   8.4104880E-07
     +,   7.0373557E-07,   5.8723742E-07,   4.8868355E-07
     +,   4.0555102E-07,   3.3562569E-07,   2.7697800E-07
     +,   2.2793526E-07,   1.8704203E-07,   1.5304681E-07
     +,   1.2486824E-07,   1.0158235E-07,   8.2396326E-08
     +,   6.6637355E-08,   5.3731981E-08,   4.3196639E-08
     +,   3.4622143E-08,   2.7665761E-08,   2.2039638E-08
     +,   1.7503623E-08,   1.3858344E-08,   1.0938072E-08
     +,   8.6062704E-09,   6.7502524E-09,   5.2778359E-09
     +,   4.1134744E-09,   3.1957978E-09,   2.4748770E-09
     +,   1.9104427E-09,   1.4699620E-09,   1.1273875E-09
     +,   8.6182994E-10,   6.5668004E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt80 = Yx/0.0202758620689655
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1304597E-05,   1.1580463E-05
     +,   1.1869110E-05,   1.2171689E-05,   1.2489407E-05
     +,   1.2823521E-05,   1.3175341E-05,   1.3546213E-05
     +,   1.3937526E-05,   1.4350710E-05,   1.4787209E-05
     +,   1.5248488E-05,   1.5736025E-05,   1.6251301E-05
     +,   1.6795782E-05,   1.7370934E-05,   1.7978175E-05
     +,   1.8618897E-05,   1.9294446E-05,   2.0006095E-05
     +,   2.0755057E-05,   2.1542461E-05,   2.2369319E-05
     +,   2.3236604E-05,   2.4145067E-05,   2.5095436E-05
     +,   2.6088244E-05,   2.7123897E-05,   2.8202652E-05
     +,   2.9324598E-05,   3.0489673E-05,   3.1697644E-05
     +,   3.2948108E-05,   3.4240496E-05,   3.5574085E-05
     +,   3.6947968E-05,   3.8361119E-05,   3.9812323E-05
     +,   4.1300354E-05,   4.2823685E-05,   4.4380893E-05
     +,   4.5970377E-05,   4.7590540E-05,   4.9239792E-05
     +,   5.0916562E-05,   5.2619362E-05,   5.4346870E-05
     +,   5.6097906E-05,   5.7871559E-05,   5.9667247E-05
     +,   6.1484738E-05,   6.3324260E-05,   6.5186541E-05
     +,   6.7073044E-05,   6.8985712E-05,   7.0927483E-05
     +,   7.2901996E-05,   7.4913871E-05,   7.6968696E-05
     +,   7.9073121E-05,   8.1234874E-05,   8.3462801E-05
     +,   8.5766747E-05,   8.8157780E-05,   9.0648013E-05
     +,   9.3250281E-05,   9.5978510E-05,   9.8846904E-05
     +,   1.0187048E-04,   1.0506404E-04,   1.0844260E-04
     +,   1.1202027E-04,   1.1581078E-04,   1.1982602E-04
     +,   1.2407654E-04,   1.2857062E-04,   1.3331363E-04
     +,   1.3830762E-04,   1.4355134E-04,   1.4903939E-04
     +,   1.5476139E-04,   1.6070288E-04,   1.6684333E-04
     +,   1.7315785E-04,   1.7961541E-04,   1.8618049E-04
     +,   1.9281160E-04,   1.9946326E-04,   2.0608481E-04
     +,   2.1262238E-04,   2.1901917E-04,   2.2521552E-04
     +,   2.3115057E-04,   2.3676340E-04,   2.4199380E-04
     +,   2.4678287E-04,   2.5107528E-04,   2.5481894E-04
     +,   2.5796724E-04,   2.6047914E-04,   2.6232051E-04
     +,   2.6346429E-04,   2.6389162E-04,   2.6359162E-04
     +,   2.6256204E-04,   2.6080880E-04,   2.5834620E-04
     +,   2.5519659E-04,   2.5138960E-04,   2.4696143E-04
     +,   2.4195494E-04,   2.3641773E-04,   2.3040271E-04
     +,   2.2396570E-04,   2.1716625E-04,   2.1006537E-04
     +,   2.0272651E-04,   1.9521336E-04,   1.8759113E-04
     +,   1.7992487E-04,   1.7227979E-04,   1.6472206E-04
     +,   1.5731850E-04,   1.5013634E-04,   1.4324464E-04
     +,   1.3671543E-04,   1.3062349E-04,   1.2504916E-04
     +,   1.2007819E-04,   1.1580499E-04,   1.1233318E-04
     +,   1.0977859E-04,   1.0827015E-04,   1.0795215E-04
     +,   1.0898468E-04,   1.1154431E-04,   1.1582251E-04
     +,   1.2202303E-04,   1.3035804E-04,   1.4104157E-04
     +,   1.5428077E-04,   1.7026640E-04,   1.8916366E-04
     +,   2.1110146E-04,   2.3616062E-04,   2.6437204E-04
     +,   2.9571174E-04,   3.3010097E-04,   3.6741400E-04
     +,   4.0749222E-04,   4.5015625E-04,   4.9521751E-04
     +,   5.4249371E-04,   5.9181842E-04,   6.4303889E-04
     +,   6.9599820E-04,   7.5051782E-04,   8.0636499E-04
     +,   8.6321146E-04,   9.2058541E-04,   9.7784633E-04
     +,   1.0341575E-03,   1.0884785E-03,   1.1395938E-03
     +,   1.1861628E-03,   1.2267957E-03,   1.2601410E-03
     +,   1.2850001E-03,   1.3004297E-03,   1.3058301E-03
     +,   1.3010092E-03,   1.2862150E-03,   1.2621252E-03
     +,   1.2297948E-03,   1.1905825E-03,   1.1460367E-03
     +,   1.0977808E-03,   1.0474053E-03,   9.9636230E-04
     +,   9.4588875E-04,   8.9696294E-04,   8.5029344E-04
     +,   8.0632995E-04,   7.6529413E-04,   7.2723388E-04
     +,   6.9207879E-04,   6.5969024E-04,   6.2990113E-04
     +,   6.0254947E-04,   5.7749799E-04,   5.5463193E-04
     +,   5.3385674E-04,   5.1508576E-04,   4.9822475E-04
     +,   4.8315508E-04,   4.6972555E-04,   4.5774627E-04
     +,   4.4698807E-04,   4.3718764E-04,   4.2805873E-04
     +,   4.1930511E-04,   4.1063552E-04,   4.0177724E-04
     +,   3.9248972E-04,   3.8257698E-04,   3.7189203E-04
     +,   3.6034267E-04,   3.4789243E-04,   3.3455706E-04
     +,   3.2039886E-04,   3.0551982E-04,   2.9005422E-04
     +,   2.7415808E-04,   2.5799932E-04,   2.4174989E-04
     +,   2.2557894E-04,   2.0964538E-04,   1.9409152E-04
     +,   1.7904086E-04,   1.6459693E-04,   1.5083989E-04
     +,   1.3782793E-04,   1.2559960E-04,   1.1417446E-04
     +,   1.0355483E-04,   9.3729323E-05,   8.4675965E-05
     +,   7.6364049E-05,   6.8756155E-05,   6.1810810E-05
     +,   5.5484830E-05,   4.9734183E-05,   4.4514898E-05
     +,   3.9784441E-05,   3.5502668E-05,   3.1631353E-05
     +,   2.8134888E-05,   2.4980593E-05,   2.2138349E-05
     +,   1.9580377E-05,   1.7281296E-05,   1.5218061E-05
     +,   1.3369608E-05,   1.1716535E-05,   1.0241110E-05
     +,   8.9271516E-06,   7.7597879E-06,   6.7252463E-06
     +,   5.8108662E-06,   5.0050508E-06,   4.2970273E-06
     +,   3.6768683E-06,   3.1354784E-06,   2.6644811E-06
     +,   2.2561562E-06,   1.9034446E-06,   1.5999201E-06
     +,   1.3397346E-06,   1.1175651E-06,   9.2861080E-07
     +,   7.6856566E-07,   6.3357191E-07,   5.2018203E-07
     +,   4.2534151E-07,   3.4636255E-07,   2.8087658E-07
     +,   2.2681553E-07,   1.8238597E-07,   1.4603620E-07
     +,   1.1643003E-07,   9.2425012E-08,   7.3051012E-08
     +,   5.7486865E-08,   4.5040554E-08,   3.5133365E-08
     +,   2.7284452E-08,   2.1094827E-08,   1.6236859E-08
     +,   1.2441718E-08,   9.4910053E-09,   7.2075066E-09
     +,   5.4488072E-09,   4.1006198E-09,   3.0720848E-09
     +,   2.2910835E-09,   1.7008952E-09,   1.2570015E-09
     +,   9.2471736E-10,   6.7717881E-10,   4.9363746E-10
     +,   3.5820336E-10,   2.5873667E-10,   1.8603739E-10
     +,   1.3315163E-10,   9.4864581E-11,   6.7276504E-11
     +,   4.7493242E-11,   3.3373349E-11,   2.3344071E-11
     +,   1.6253665E-11,   1.1265057E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt85 = Yx/0.016
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1702652E-07,   3.5697269E-07
     +,   4.0131889E-07,   4.5046696E-07,   5.0484664E-07
     +,   5.6491552E-07,   6.3116022E-07,   7.0409732E-07
     +,   7.8427161E-07,   8.7226346E-07,   9.6868132E-07
     +,   1.0741654E-06,   1.1893895E-06,   1.3150593E-06
     +,   1.4519132E-06,   1.6007209E-06,   1.7622858E-06
     +,   1.9374440E-06,   2.1270600E-06,   2.3320320E-06
     +,   2.5532893E-06,   2.7917879E-06,   3.0485094E-06
     +,   3.3244785E-06,   3.6207177E-06,   3.9383031E-06
     +,   4.2783163E-06,   4.6418641E-06,   5.0300700E-06
     +,   5.4440811E-06,   5.8850501E-06,   6.3541493E-06
     +,   6.8525583E-06,   7.3814640E-06,   7.9420606E-06
     +,   8.5355396E-06,   9.1631046E-06,   9.8259361E-06
     +,   1.0525258E-05,   1.1262218E-05,   1.2038030E-05
     +,   1.2853868E-05,   1.3710902E-05,   1.4610303E-05
     +,   1.5553251E-05,   1.6540915E-05,   1.7574486E-05
     +,   1.8655162E-05,   1.9784173E-05,   2.0962783E-05
     +,   2.2192293E-05,   2.3474076E-05,   2.4809546E-05
     +,   2.6200310E-05,   2.7647908E-05,   2.9154167E-05
     +,   3.0720963E-05,   3.2350363E-05,   3.4044580E-05
     +,   3.5806021E-05,   3.7637270E-05,   3.9541137E-05
     +,   4.1520474E-05,   4.3578468E-05,   4.5718443E-05
     +,   4.7943620E-05,   5.0257568E-05,   5.2663534E-05
     +,   5.5165008E-05,   5.7764981E-05,   6.0466486E-05
     +,   6.3271800E-05,   6.6183035E-05,   6.9201218E-05
     +,   7.2326817E-05,   7.5559277E-05,   7.8896686E-05
     +,   8.2335711E-05,   8.5871725E-05,   8.9498404E-05
     +,   9.3207243E-05,   9.6988275E-05,   1.0082895E-04
     +,   1.0471512E-04,   1.0862994E-04,   1.1255497E-04
     +,   1.1646913E-04,   1.2034992E-04,   1.2417245E-04
     +,   1.2791061E-04,   1.3153690E-04,   1.3502255E-04
     +,   1.3833809E-04,   1.4145390E-04,   1.4434046E-04
     +,   1.4696855E-04,   1.4931030E-04,   1.5133903E-04
     +,   1.5303030E-04,   1.5436190E-04,   1.5531477E-04
     +,   1.5587297E-04,   1.5602444E-04,   1.5576115E-04
     +,   1.5507947E-04,   1.5398036E-04,   1.5246971E-04
     +,   1.5055839E-04,   1.4826228E-04,   1.4560213E-04
     +,   1.4260411E-04,   1.3929886E-04,   1.3572215E-04
     +,   1.3191384E-04,   1.2791838E-04,   1.2378373E-04
     +,   1.1956165E-04,   1.1530640E-04,   1.1107514E-04
     +,   1.0692635E-04,   1.0291950E-04,   9.9114557E-05
     +,   9.5570642E-05,   9.2344802E-05,   8.9491201E-05
     +,   8.7059976E-05,   8.5095351E-05,   8.3634783E-05
     +,   8.2707003E-05,   8.2330938E-05,   8.2514125E-05
     +,   8.3251427E-05,   8.4524290E-05,   8.6299704E-05
     +,   8.8530345E-05,   9.1154972E-05,   9.4099349E-05
     +,   9.7278651E-05,   1.0060101E-04,   1.0397254E-04
     +,   1.0730381E-04,   1.1051934E-04,   1.1356966E-04
     +,   1.1644619E-04,   1.1919913E-04,   1.2195906E-04
     +,   1.2496024E-04,   1.2856451E-04,   1.3328406E-04
     +,   1.3979968E-04,   1.4897130E-04,   1.6183767E-04
     +,   1.7960439E-04,   2.0362223E-04,   2.3535383E-04
     +,   2.7633164E-04,   3.2811274E-04,   3.9222967E-04
     +,   4.7011639E-04,   5.6299317E-04,   6.7172048E-04
     +,   7.9656532E-04,   9.3689916E-04,   1.0908779E-03
     +,   1.2551695E-03,   1.4247977E-03,   1.5932308E-03
     +,   1.7528188E-03,   1.8955766E-03,   2.0141944E-03
     +,   2.1031345E-03,   2.1595713E-03,   2.1839072E-03
     +,   2.1796883E-03,   2.1529291E-03,   2.1109711E-03
     +,   2.0611270E-03,   2.0094726E-03,   1.9600186E-03
     +,   1.9144261E-03,   1.8722669E-03,   1.8316838E-03
     +,   1.7902188E-03,   1.7455948E-03,   1.6963037E-03
     +,   1.6418955E-03,   1.5829818E-03,   1.5210025E-03
     +,   1.4578719E-03,   1.3955956E-03,   1.3359135E-03
     +,   1.2800813E-03,   1.2287807E-03,   1.1821573E-03
     +,   1.1399558E-03,   1.1016999E-03,   1.0668651E-03
     +,   1.0349863E-03,   1.0056929E-03,   9.7867684E-04
     +,   9.5361820E-04,   9.3009521E-04,   9.0752530E-04
     +,   8.8515767E-04,   8.6212496E-04,   8.3753077E-04
     +,   8.1057113E-04,   7.8065018E-04,   7.4746530E-04
     +,   7.1104860E-04,   6.7176291E-04,   6.3025329E-04
     +,   5.8736291E-04,   5.4403214E-04,   5.0120195E-04
     +,   4.5973313E-04,   4.2033920E-04,   3.8354730E-04
     +,   3.4968884E-04,   3.1891133E-04,   2.9119683E-04
     +,   2.6639926E-04,   2.4428364E-04,   2.2456038E-04
     +,   2.0691667E-04,   1.9104371E-04,   1.7665666E-04
     +,   1.6350500E-04,   1.5137818E-04,   1.4010764E-04
     +,   1.2956522E-04,   1.1965751E-04,   1.1031953E-04
     +,   1.0150911E-04,   9.3201379E-05,   8.5381667E-05
     +,   7.8041739E-05,   7.1176459E-05,   6.4780535E-05
     +,   5.8846181E-05,   5.3362677E-05,   4.8316077E-05
     +,   4.3688899E-05,   3.9460265E-05,   3.5606859E-05
     +,   3.2103922E-05,   2.8925660E-05,   2.6045867E-05
     +,   2.3438773E-05,   2.1079850E-05,   1.8945637E-05
     +,   1.7014394E-05,   1.5266294E-05,   1.3683374E-05
     +,   1.2249422E-05,   1.0950011E-05,   9.7724478E-06
     +,   8.7055068E-06,   7.7391978E-06,   6.8646850E-06
     +,   6.0741691E-06,   5.3606559E-06,   4.7177950E-06
     +,   4.1398116E-06,   3.6214660E-06,   3.1578556E-06
     +,   2.7444273E-06,   2.3769439E-06,   2.0514258E-06
     +,   1.7641034E-06,   1.5114371E-06,   1.2901131E-06
     +,   1.0970226E-06,   9.2924370E-07,   7.8406032E-07
     +,   6.5896683E-07,   5.5163730E-07,   4.5995210E-07
     +,   3.8196674E-07,   3.1592856E-07,   2.6024961E-07
     +,   2.1351502E-07,   1.7445900E-07,   1.4196652E-07
     +,   1.1505271E-07,   9.2860013E-08,   7.4640830E-08
     +,   5.9749560E-08,   4.7633009E-08,   3.7817120E-08
     +,   2.9900725E-08,   2.3543967E-08,   1.8462424E-08
     +,   1.4417881E-08,   1.1213064E-08,   8.6845864E-09
     +,   6.6985986E-09,   5.1454156E-09,   3.9360981E-09
     +,   2.9985623E-09,   2.2749329E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt90 = Yx/0.0214827586206897
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5882166E-07,   1.7847239E-07
     +,   2.0025591E-07,   2.2436411E-07,   2.5100090E-07
     +,   2.8038295E-07,   3.1273933E-07,   3.4831248E-07
     +,   3.8735621E-07,   4.3013961E-07,   4.7694226E-07
     +,   5.2805649E-07,   5.8378686E-07,   6.4444930E-07
     +,   7.1037039E-07,   7.8188737E-07,   8.5934624E-07
     +,   9.4310195E-07,   1.0335175E-06,   1.1309611E-06
     +,   1.2358073E-06,   1.3484350E-06,   1.4692232E-06
     +,   1.5985607E-06,   1.7368234E-06,   1.8844007E-06
     +,   2.0416726E-06,   2.2090164E-06,   2.3868090E-06
     +,   2.5754207E-06,   2.7752187E-06,   2.9865666E-06
     +,   3.2098224E-06,   3.4453419E-06,   3.6934789E-06
     +,   3.9545853E-06,   4.2290171E-06,   4.5171273E-06
     +,   4.8192983E-06,   5.1358893E-06,   5.4673083E-06
     +,   5.8139667E-06,   6.1763089E-06,   6.5548084E-06
     +,   6.9499824E-06,   7.3623883E-06,   7.7926452E-06
     +,   8.2414263E-06,   8.7094768E-06,   9.1976135E-06
     +,   9.7067377E-06,   1.0237834E-05,   1.0791980E-05
     +,   1.1370369E-05,   1.1974244E-05,   1.2605004E-05
     +,   1.3264109E-05,   1.3953125E-05,   1.4673695E-05
     +,   1.5427553E-05,   1.6216487E-05,   1.7042352E-05
     +,   1.7906978E-05,   1.8812265E-05,   1.9760104E-05
     +,   2.0752232E-05,   2.1790445E-05,   2.2876269E-05
     +,   2.4011211E-05,   2.5196443E-05,   2.6433028E-05
     +,   2.7721586E-05,   2.9062561E-05,   3.0455851E-05
     +,   3.1901058E-05,   3.3397326E-05,   3.4943194E-05
     +,   3.6536680E-05,   3.8175327E-05,   3.9856124E-05
     +,   4.1575320E-05,   4.3328790E-05,   4.5111618E-05
     +,   4.6918594E-05,   4.8743739E-05,   5.0580915E-05
     +,   5.2423326E-05,   5.4264103E-05,   5.6095971E-05
     +,   5.7911690E-05,   5.9704056E-05,   6.1465907E-05
     +,   6.3190353E-05,   6.4871034E-05,   6.6502187E-05
     +,   6.8078574E-05,   6.9596084E-05,   7.1051349E-05
     +,   7.2442344E-05,   7.3768104E-05,   7.5029144E-05
     +,   7.6227210E-05,   7.7365643E-05,   7.8449106E-05
     +,   7.9483725E-05,   8.0477039E-05,   8.1437742E-05
     +,   8.2375729E-05,   8.3301864E-05,   8.4227766E-05
     +,   8.5165535E-05,   8.6127620E-05,   8.7126289E-05
     +,   8.8173634E-05,   8.9280904E-05,   9.0458561E-05
     +,   9.1715534E-05,   9.3059389E-05,   9.4495532E-05
     +,   9.6027441E-05,   9.7656215E-05,   9.9380377E-05
     +,   1.0119587E-04,   1.0309617E-04,   1.0507223E-04
     +,   1.0711241E-04,   1.0920323E-04,   1.1132903E-04
     +,   1.1347303E-04,   1.1561711E-04,   1.1774305E-04
     +,   1.1983233E-04,   1.2186746E-04,   1.2383201E-04
     +,   1.2571175E-04,   1.2749515E-04,   1.2917398E-04
     +,   1.3074435E-04,   1.3220766E-04,   1.3357177E-04
     +,   1.3485213E-04,   1.3607382E-04,   1.3727359E-04
     +,   1.3850235E-04,   1.3982819E-04,   1.4133987E-04
     +,   1.4315026E-04,   1.4539974E-04,   1.4825910E-04
     +,   1.5193129E-04,   1.5665096E-04,   1.6268043E-04
     +,   1.7030202E-04,   1.7980621E-04,   1.9147314E-04
     +,   2.0554865E-04,   2.2221793E-04,   2.4157835E-04
     +,   2.6361283E-04,   2.8816736E-04,   3.1494672E-04
     +,   3.4351757E-04,   3.7332912E-04,   4.0375578E-04
     +,   4.3415869E-04,   4.6396189E-04,   4.9274589E-04
     +,   5.2036578E-04,   5.4708385E-04,   5.7371263E-04
     +,   6.0174952E-04,   6.3348009E-04,   6.7199679E-04
     +,   7.2109257E-04,   7.8497065E-04,   8.6778990E-04
     +,   9.7304076E-04,   1.1028269E-03,   1.2571942E-03
     +,   1.4336403E-03,   1.6269240E-03,   1.8292754E-03
     +,   2.0310702E-03,   2.2218444E-03,   2.3914143E-03
     +,   2.5308980E-03,   2.6334429E-03,   2.6945635E-03
     +,   2.7121671E-03,   2.6864761E-03,   2.6199734E-03
     +,   2.5173631E-03,   2.3854335E-03,   2.2326105E-03
     +,   2.0681124E-03,   1.9008709E-03,   1.7384547E-03
     +,   1.5863056E-03,   1.4474915E-03,   1.3230010E-03
     +,   1.2123636E-03,   1.1143272E-03,   1.0273993E-03
     +,   9.5016306E-04,   8.8137831E-04,   8.1992906E-04
     +,   7.6476578E-04,   7.1487314E-04,   6.6927890E-04
     +,   6.2709721E-04,   5.8758730E-04,   5.5018970E-04
     +,   5.1453372E-04,   4.8041873E-04,   4.4778158E-04
     +,   4.1665387E-04,   3.8711407E-04,   3.5924561E-04
     +,   3.3310903E-04,   3.0872546E-04,   2.8606429E-04
     +,   2.6504911E-04,   2.4556875E-04,   2.2749005E-04
     +,   2.1067129E-04,   1.9497685E-04,   1.8028736E-04
     +,   1.6650422E-04,   1.5355006E-04,   1.4136817E-04
     +,   1.2991944E-04,   1.1917643E-04,   1.0911789E-04
     +,   9.9725286E-05,   9.0980386E-05,   8.2861465E-05
     +,   7.5343356E-05,   6.8398076E-05,   6.1994768E-05
     +,   5.6100460E-05,   5.0681654E-05,   4.5705638E-05
     +,   4.1140884E-05,   3.6957343E-05,   3.3127133E-05
     +,   2.9624827E-05,   2.6427067E-05,   2.3512248E-05
     +,   2.0860485E-05,   1.8453627E-05,   1.6274467E-05
     +,   1.4306848E-05,   1.2535595E-05,   1.0946241E-05
     +,   9.5248552E-06,   8.2581246E-06,   7.1334007E-06
     +,   6.1385781E-06,   5.2620685E-06,   4.4928729E-06
     +,   3.8206572E-06,   3.2356854E-06,   2.7288067E-06
     +,   2.2915126E-06,   1.9159638E-06,   1.5949036E-06
     +,   1.3216926E-06,   1.0903067E-06,   8.9529067E-07
     +,   7.3172305E-07,   5.9520801E-07,   4.8184637E-07
     +,   3.8819277E-07,   3.1121510E-07,   2.4827094E-07
     +,   1.9707507E-07,   1.5565200E-07,   1.2231703E-07
     +,   9.5633041E-08,   7.4389625E-08,   5.7568030E-08
     +,   4.4321375E-08,   3.3946215E-08,   2.5865182E-08
     +,   1.9605173E-08,   1.4782889E-08,   1.1088481E-08
     +,   8.2736964E-09,   6.1411103E-09,   4.5342103E-09
     +,   3.3301915E-09,   2.4329829E-09,   1.7681444E-09
     +,   1.2781841E-09,   9.1912500E-10,   6.5743111E-10
     +,   4.6776666E-10,   3.3105546E-10,   2.3306285E-10
     +,   1.6320593E-10,   1.1368422E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_htt95 = Yx/0.0193103448275862
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.3798187E-05,   5.4988512E-05
     +,   5.6197674E-05,   5.7426503E-05,   5.8675872E-05
     +,   5.9946680E-05,   6.1239916E-05,   6.2556617E-05
     +,   6.3897874E-05,   6.5264903E-05,   6.6658868E-05
     +,   6.8081135E-05,   6.9533016E-05,   7.1015951E-05
     +,   7.2531438E-05,   7.4081021E-05,   7.5666365E-05
     +,   7.7289122E-05,   7.8951045E-05,   8.0653946E-05
     +,   8.2399667E-05,   8.4190135E-05,   8.6027263E-05
     +,   8.7913097E-05,   8.9849542E-05,   9.1838716E-05
     +,   9.3882634E-05,   9.5983305E-05,   9.8142729E-05
     +,   1.0036289E-04,   1.0264570E-04,   1.0499302E-04
     +,   1.0740657E-04,   1.0988806E-04,   1.1243899E-04
     +,   1.1506073E-04,   1.1775451E-04,   1.2052126E-04
     +,   1.2336185E-04,   1.2627667E-04,   1.2926602E-04
     +,   1.3232982E-04,   1.3546772E-04,   1.3867891E-04
     +,   1.4196226E-04,   1.4531621E-04,   1.4873888E-04
     +,   1.5222782E-04,   1.5578020E-04,   1.5939272E-04
     +,   1.6306160E-04,   1.6678257E-04,   1.7055088E-04
     +,   1.7436153E-04,   1.7820863E-04,   1.8208634E-04
     +,   1.8598807E-04,   1.8990715E-04,   1.9383633E-04
     +,   1.9776826E-04,   2.0169525E-04,   2.0560960E-04
     +,   2.0950327E-04,   2.1336845E-04,   2.1719745E-04
     +,   2.2098240E-04,   2.2471612E-04,   2.2839126E-04
     +,   2.3200158E-04,   2.3554075E-04,   2.3900351E-04
     +,   2.4238517E-04,   2.4568202E-04,   2.4889116E-04
     +,   2.5201091E-04,   2.5504085E-04,   2.5798145E-04
     +,   2.6083455E-04,   2.6360352E-04,   2.6629309E-04
     +,   2.6890932E-04,   2.7146004E-04,   2.7395421E-04
     +,   2.7640245E-04,   2.7881676E-04,   2.8121061E-04
     +,   2.8359887E-04,   2.8599743E-04,   2.8842353E-04
     +,   2.9089549E-04,   2.9343256E-04,   2.9605452E-04
     +,   2.9878176E-04,   3.0163524E-04,   3.0463602E-04
     +,   3.0780479E-04,   3.1116244E-04,   3.1472859E-04
     +,   3.1852257E-04,   3.2256183E-04,   3.2686314E-04
     +,   3.3144071E-04,   3.3630698E-04,   3.4147160E-04
     +,   3.4694184E-04,   3.5272166E-04,   3.5881138E-04
     +,   3.6520779E-04,   3.7190385E-04,   3.7888848E-04
     +,   3.8614581E-04,   3.9365626E-04,   4.0139511E-04
     +,   4.0933420E-04,   4.1744005E-04,   4.2567626E-04
     +,   4.3400197E-04,   4.4237360E-04,   4.5074406E-04
     +,   4.5906464E-04,   4.6728601E-04,   4.7535702E-04
     +,   4.8322690E-04,   4.9084704E-04,   4.9817073E-04
     +,   5.0515431E-04,   5.1175919E-04,   5.1795173E-04
     +,   5.2370504E-04,   5.2899972E-04,   5.3382484E-04
     +,   5.3817785E-04,   5.4206705E-04,   5.4550963E-04
     +,   5.4853369E-04,   5.5117748E-04,   5.5348943E-04
     +,   5.5552745E-04,   5.5735896E-04,   5.5906002E-04
     +,   5.6071358E-04,   5.6240970E-04,   5.6424452E-04
     +,   5.6631875E-04,   5.6873797E-04,   5.7161105E-04
     +,   5.7505147E-04,   5.7917583E-04,   5.8410520E-04
     +,   5.8996782E-04,   5.9689779E-04,   6.0503854E-04
     +,   6.1454385E-04,   6.2558101E-04,   6.3833187E-04
     +,   6.5299519E-04,   6.6978560E-04,   6.8893842E-04
     +,   7.1070815E-04,   7.3536584E-04,   7.6320436E-04
     +,   7.9453643E-04,   8.2969398E-04,   8.6902833E-04
     +,   9.1291976E-04,   9.6177490E-04,   1.0160267E-03
     +,   1.0761390E-03,   1.1426029E-03,   1.2159253E-03
     +,   1.2966050E-03,   1.3851026E-03,   1.4818048E-03
     +,   1.5869683E-03,   1.7006493E-03,   1.8226670E-03
     +,   1.9525540E-03,   2.0895263E-03,   2.2325022E-03
     +,   2.3801716E-03,   2.5310784E-03,   2.6837417E-03
     +,   2.8368228E-03,   2.9893140E-03,   3.1407264E-03
     +,   3.2913131E-03,   3.4423473E-03,   3.5964909E-03
     +,   3.7581634E-03,   3.9338698E-03,   4.1323546E-03
     +,   4.3642847E-03,   4.6412195E-03,   4.9738949E-03
     +,   5.3698993E-03,   5.8313082E-03,   6.3529848E-03
     +,   6.9225272E-03,   7.5221383E-03,   8.1320703E-03
     +,   8.7348353E-03,   9.3186870E-03,   9.8792827E-03
     +,   1.0418540E-02,   1.0941221E-02,   1.1450340E-02
     +,   1.1942973E-02,   1.2408339E-02,   1.2829254E-02
     +,   1.3186937E-02,   1.3466730E-02,   1.3662795E-02
     +,   1.3779022E-02,   1.3826704E-02,   1.3820195E-02
     +,   1.3773524E-02,   1.3698182E-02,   1.3601966E-02
     +,   1.3487610E-02,   1.3351429E-02,   1.3183508E-02
     +,   1.2970878E-02,   1.2703080E-02,   1.2377425E-02
     +,   1.2000953E-02,   1.1588010E-02,   1.1154681E-02
     +,   1.0713334E-02,   1.0270165E-02,   9.8262429E-03
     +,   9.3809180E-03,   8.9353034E-03,   8.4938742E-03
     +,   8.0640679E-03,   7.6544634E-03,   7.2725043E-03
     +,   6.9230404E-03,   6.6078524E-03,   6.3258177E-03
     +,   6.0737533E-03,   5.8472352E-03,   5.6414055E-03
     +,   5.4514743E-03,   5.2730227E-03,   5.1021231E-03
     +,   4.9353363E-03,   4.7696810E-03,   4.6026474E-03
     +,   4.4323392E-03,   4.2576818E-03,   4.0785903E-03
     +,   3.8961442E-03,   3.7125531E-03,   3.5309677E-03
     +,   3.3551084E-03,   3.1888040E-03,   3.0355174E-03
     +,   2.8979010E-03,   2.7775152E-03,   2.6747051E-03
     +,   2.5886584E-03,   2.5175805E-03,   2.4589528E-03
     +,   2.4098526E-03,   2.3672536E-03,   2.3282669E-03
     +,   2.2903415E-03,   2.2513825E-03,   2.2098091E-03
     +,   2.1645494E-03,   2.1150056E-03,   2.0609861E-03
     +,   2.0026278E-03,   1.9403044E-03,   1.8745500E-03
     +,   1.8059991E-03,   1.7353164E-03,   1.6631666E-03
     +,   1.5901702E-03,   1.5169032E-03,   1.4438663E-03
     +,   1.3715083E-03,   1.3002043E-03,   1.2302852E-03
     +,   1.1620274E-03,   1.0956756E-03,   1.0314359E-03
     +,   9.6948753E-04,   9.0998935E-04,   8.5306994E-04
     +,   7.9883955E-04,   7.4737845E-04,   6.9874455E-04
     +,   6.5296289E-04,   6.1003480E-04,   5.6992687E-04
     +,   5.3258328E-04,   4.9791712E-04,   4.6582305E-04
     +,   4.3617122E-04,   4.0882087E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt100 = Yx/0.17675
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.6544748E-05,   4.8016016E-05
     +,   4.9515758E-05,   5.1043968E-05,   5.2600652E-05
     +,   5.4185792E-05,   5.5799333E-05,   5.7441233E-05
     +,   5.9111357E-05,   6.0809652E-05,   6.2535910E-05
     +,   6.4289954E-05,   6.6071509E-05,   6.7880283E-05
     +,   6.9715919E-05,   7.1577997E-05,   7.3465955E-05
     +,   7.5379256E-05,   7.7317171E-05,   7.9278936E-05
     +,   8.1263621E-05,   8.3270235E-05,   8.5297594E-05
     +,   8.7344517E-05,   8.9409456E-05,   9.1490925E-05
     +,   9.3587172E-05,   9.5696283E-05,   9.7816228E-05
     +,   9.9944737E-05,   1.0207944E-04,   1.0421776E-04
     +,   1.0635691E-04,   1.0849397E-04,   1.1062588E-04
     +,   1.1274929E-04,   1.1486087E-04,   1.1695698E-04
     +,   1.1903399E-04,   1.2108798E-04,   1.2311507E-04
     +,   1.2511118E-04,   1.2707223E-04,   1.2899407E-04
     +,   1.3087249E-04,   1.3270330E-04,   1.3448232E-04
     +,   1.3620543E-04,   1.3786858E-04,   1.3946781E-04
     +,   1.4099933E-04,   1.4245950E-04,   1.4384484E-04
     +,   1.4515221E-04,   1.4637853E-04,   1.4752122E-04
     +,   1.4857789E-04,   1.4954664E-04,   1.5042571E-04
     +,   1.5121390E-04,   1.5191043E-04,   1.5251496E-04
     +,   1.5302749E-04,   1.5344867E-04,   1.5377952E-04
     +,   1.5402163E-04,   1.5417705E-04,   1.5424832E-04
     +,   1.5423857E-04,   1.5415136E-04,   1.5399080E-04
     +,   1.5376139E-04,   1.5346824E-04,   1.5311682E-04
     +,   1.5271310E-04,   1.5226331E-04,   1.5177431E-04
     +,   1.5125310E-04,   1.5070710E-04,   1.5014391E-04
     +,   1.4957158E-04,   1.4899815E-04,   1.4843195E-04
     +,   1.4788135E-04,   1.4735493E-04,   1.4686107E-04
     +,   1.4640841E-04,   1.4600532E-04,   1.4566015E-04
     +,   1.4538103E-04,   1.4517605E-04,   1.4505287E-04
     +,   1.4501896E-04,   1.4508140E-04,   1.4524700E-04
     +,   1.4552209E-04,   1.4591253E-04,   1.4642386E-04
     +,   1.4706088E-04,   1.4782813E-04,   1.4872941E-04
     +,   1.4976799E-04,   1.5094664E-04,   1.5226741E-04
     +,   1.5373202E-04,   1.5534132E-04,   1.5709567E-04
     +,   1.5899482E-04,   1.6103806E-04,   1.6322418E-04
     +,   1.6555116E-04,   1.6801685E-04,   1.7061822E-04
     +,   1.7335228E-04,   1.7621520E-04,   1.7920320E-04
     +,   1.8231162E-04,   1.8553613E-04,   1.8887167E-04
     +,   1.9231324E-04,   1.9585574E-04,   1.9949359E-04
     +,   2.0322121E-04,   2.0703321E-04,   2.1092390E-04
     +,   2.1488765E-04,   2.1891878E-04,   2.2301158E-04
     +,   2.2716074E-04,   2.3136036E-04,   2.3560539E-04
     +,   2.3989008E-04,   2.4420948E-04,   2.4855835E-04
     +,   2.5293187E-04,   2.5732550E-04,   2.6173479E-04
     +,   2.6615549E-04,   2.7058439E-04,   2.7501848E-04
     +,   2.7945530E-04,   2.8389314E-04,   2.8833133E-04
     +,   2.9277056E-04,   2.9721230E-04,   3.0165946E-04
     +,   3.0611709E-04,   3.1059168E-04,   3.1509128E-04
     +,   3.1962700E-04,   3.2421228E-04,   3.2886307E-04
     +,   3.3359864E-04,   3.3844169E-04,   3.4341941E-04
     +,   3.4856307E-04,   3.5390901E-04,   3.5950032E-04
     +,   3.6538701E-04,   3.7162661E-04,   3.7828725E-04
     +,   3.8544787E-04,   3.9319918E-04,   4.0164677E-04
     +,   4.1091209E-04,   4.2113403E-04,   4.3246904E-04
     +,   4.4509262E-04,   4.5920012E-04,   4.7500525E-04
     +,   4.9273792E-04,   5.1264162E-04,   5.3497287E-04
     +,   5.5999524E-04,   5.8797473E-04,   6.1917817E-04
     +,   6.5387308E-04,   6.9232140E-04,   7.3478295E-04
     +,   7.8152341E-04,   8.3281659E-04,   8.8894798E-04
     +,   9.5022400E-04,   1.0169799E-03,   1.0895794E-03
     +,   1.1683998E-03,   1.2538255E-03,   1.3462291E-03
     +,   1.4459365E-03,   1.5531816E-03,   1.6680916E-03
     +,   1.7906543E-03,   1.9207000E-03,   2.0579249E-03
     +,   2.2019418E-03,   2.3523348E-03,   2.5087132E-03
     +,   2.6707840E-03,   2.8383932E-03,   3.0115373E-03
     +,   3.1903724E-03,   3.3753002E-03,   3.5671513E-03
     +,   3.7674936E-03,   3.9790208E-03,   4.2059664E-03
     +,   4.4542756E-03,   4.7312551E-03,   5.0446675E-03
     +,   5.4012416E-03,   5.8048754E-03,   6.2551228E-03
     +,   6.7466469E-03,   7.2700423E-03,   7.8139976E-03
     +,   8.3681606E-03,   8.9258924E-03,   9.4857905E-03
     +,   1.0051643E-02,   1.0631436E-02,   1.1236132E-02
     +,   1.1877730E-02,   1.2565252E-02,   1.3297779E-02
     +,   1.4056348E-02,   1.4800197E-02,   1.5472854E-02
     +,   1.6018642E-02,   1.6401652E-02,   1.6615937E-02
     +,   1.6680120E-02,   1.6620772E-02,   1.6455995E-02
     +,   1.6192349E-02,   1.5836077E-02,   1.5409219E-02
     +,   1.4956004E-02,   1.4532033E-02,   1.4181189E-02
     +,   1.3914951E-02,   1.3706767E-02,   1.3504431E-02
     +,   1.3252225E-02,   1.2910966E-02,   1.2467684E-02
     +,   1.1933711E-02,   1.1335609E-02,   1.0704236E-02
     +,   1.0066306E-02,   9.4403187E-03,   8.8362060E-03
     +,   8.2579255E-03,   7.7068768E-03,   7.1847453E-03
     +,   6.6946829E-03,   6.2411893E-03,   5.8287499E-03
     +,   5.4602739E-03,   5.1359213E-03,   4.8528141E-03
     +,   4.6055149E-03,   4.3870294E-03,   4.1899788E-03
     +,   4.0076314E-03,   3.8345677E-03,   3.6669413E-03
     +,   3.5024458E-03,   3.3401020E-03,   3.1799136E-03
     +,   3.0225269E-03,   2.8689185E-03,   2.7201695E-03
     +,   2.5772573E-03,   2.4409152E-03,   2.3115941E-03
     +,   2.1894523E-03,   2.0743706E-03,   1.9660338E-03
     +,   1.8639780E-03,   1.7676842E-03,   1.6766136E-03
     +,   1.5902778E-03,   1.5082405E-03,   1.4301569E-03
     +,   1.3557443E-03,   1.2847998E-03,   1.2171619E-03
     +,   1.1527031E-03,   1.0913172E-03,   1.0328930E-03
     +,   9.7731955E-04,   9.2446653E-04,   8.7419857E-04
     +,   8.2636112E-04,   7.8080170E-04,   7.3736103E-04
     +,   6.9589197E-04,   6.5625191E-04,   6.1831885E-04
     +,   5.8198289E-04,   5.4715760E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt104 = Yx/0.179136363636364
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7156238E-05,   3.8680697E-05
     +,   4.0247469E-05,   4.1855765E-05,   4.3504639E-05
     +,   4.5192988E-05,   4.6919551E-05,   4.8682938E-05
     +,   5.0481522E-05,   5.2313680E-05,   5.4177493E-05
     +,   5.6070934E-05,   5.7991871E-05,   5.9937978E-05
     +,   6.1906838E-05,   6.3895910E-05,   6.5902510E-05
     +,   6.7923887E-05,   6.9957176E-05,   7.1999384E-05
     +,   7.4047581E-05,   7.6098608E-05,   7.8149373E-05
     +,   8.0196805E-05,   8.2237617E-05,   8.4268766E-05
     +,   8.6287095E-05,   8.8289489E-05,   9.0272930E-05
     +,   9.2234470E-05,   9.4171221E-05,   9.6080432E-05
     +,   9.7959477E-05,   9.9805868E-05,   1.0161732E-04
     +,   1.0339163E-04,   1.0512698E-04,   1.0682152E-04
     +,   1.0847391E-04,   1.1008277E-04,   1.1164723E-04
     +,   1.1316650E-04,   1.1464021E-04,   1.1606827E-04
     +,   1.1745074E-04,   1.1878821E-04,   1.2008136E-04
     +,   1.2133144E-04,   1.2253977E-04,   1.2370813E-04
     +,   1.2483858E-04,   1.2593347E-04,   1.2699542E-04
     +,   1.2802747E-04,   1.2903276E-04,   1.3001477E-04
     +,   1.3097729E-04,   1.3192420E-04,   1.3285960E-04
     +,   1.3378789E-04,   1.3471345E-04,   1.3564086E-04
     +,   1.3657479E-04,   1.3751989E-04,   1.3848094E-04
     +,   1.3946256E-04,   1.4046942E-04,   1.4150607E-04
     +,   1.4257690E-04,   1.4368608E-04,   1.4483764E-04
     +,   1.4603537E-04,   1.4728271E-04,   1.4858284E-04
     +,   1.4993853E-04,   1.5135219E-04,   1.5282590E-04
     +,   1.5436100E-04,   1.5595881E-04,   1.5761993E-04
     +,   1.5934437E-04,   1.6113186E-04,   1.6298149E-04
     +,   1.6489199E-04,   1.6686133E-04,   1.6888736E-04
     +,   1.7096718E-04,   1.7309759E-04,   1.7527485E-04
     +,   1.7749502E-04,   1.7975373E-04,   1.8204625E-04
     +,   1.8436754E-04,   1.8671257E-04,   1.8907609E-04
     +,   1.9145252E-04,   1.9383644E-04,   1.9622238E-04
     +,   1.9860503E-04,   2.0097895E-04,   2.0333919E-04
     +,   2.0568074E-04,   2.0799905E-04,   2.1028976E-04
     +,   2.1254893E-04,   2.1477324E-04,   2.1695947E-04
     +,   2.1910484E-04,   2.2120746E-04,   2.2326571E-04
     +,   2.2527826E-04,   2.2724469E-04,   2.2916473E-04
     +,   2.3103895E-04,   2.3286804E-04,   2.3465342E-04
     +,   2.3639675E-04,   2.3810030E-04,   2.3976628E-04
     +,   2.4139755E-04,   2.4299721E-04,   2.4456839E-04
     +,   2.4611430E-04,   2.4763864E-04,   2.4914482E-04
     +,   2.5063634E-04,   2.5211676E-04,   2.5358962E-04
     +,   2.5505823E-04,   2.5652591E-04,   2.5799611E-04
     +,   2.5947188E-04,   2.6095661E-04,   2.6245345E-04
     +,   2.6396583E-04,   2.6549751E-04,   2.6705241E-04
     +,   2.6863487E-04,   2.7025002E-04,   2.7190382E-04
     +,   2.7360328E-04,   2.7535614E-04,   2.7717228E-04
     +,   2.7906298E-04,   2.8104094E-04,   2.8312174E-04
     +,   2.8532275E-04,   2.8766386E-04,   2.9016737E-04
     +,   2.9285875E-04,   2.9576567E-04,   2.9891875E-04
     +,   3.0235067E-04,   3.0609686E-04,   3.1019494E-04
     +,   3.1468383E-04,   3.1960351E-04,   3.2499543E-04
     +,   3.3090112E-04,   3.3736168E-04,   3.4441741E-04
     +,   3.5210836E-04,   3.6047230E-04,   3.6954536E-04
     +,   3.7936296E-04,   3.8995926E-04,   4.0136685E-04
     +,   4.1361805E-04,   4.2674679E-04,   4.4078924E-04
     +,   4.5578243E-04,   4.7176887E-04,   4.8879615E-04
     +,   5.0691771E-04,   5.2619231E-04,   5.4668711E-04
     +,   5.6847680E-04,   5.9164246E-04,   6.1627274E-04
     +,   6.4246706E-04,   6.7033496E-04,   6.9999875E-04
     +,   7.3159701E-04,   7.6529238E-04,   8.0127607E-04
     +,   8.3977007E-04,   8.8103412E-04,   9.2537189E-04
     +,   9.7312435E-04,   1.0246633E-03,   1.0803858E-03
     +,   1.1406927E-03,   1.2059696E-03,   1.2765607E-03
     +,   1.3527594E-03,   1.4347929E-03,   1.5228139E-03
     +,   1.6169264E-03,   1.7172167E-03,   1.8238046E-03
     +,   1.9368909E-03,   2.0568282E-03,   2.1842041E-03
     +,   2.3198978E-03,   2.4651475E-03,   2.6216931E-03
     +,   2.7918846E-03,   2.9788378E-03,   3.1865563E-03
     +,   3.4199650E-03,   3.6846776E-03,   3.9863801E-03
     +,   4.3298565E-03,   4.7177002E-03,   5.1489673E-03
     +,   5.6182491E-03,   6.1158086E-03,   6.6290963E-03
     +,   7.1453867E-03,   7.6548643E-03,   8.1531024E-03
     +,   8.6415485E-03,   9.1261175E-03,   9.6147256E-03
     +,   1.0115286E-02,   1.0635232E-02,   1.1182036E-02
     +,   1.1763493E-02,   1.2386334E-02,   1.3053750E-02
     +,   1.3763036E-02,   1.4504749E-02,   1.5262173E-02
     +,   1.6010024E-02,   1.6714184E-02,   1.7335424E-02
     +,   1.7838797E-02,   1.8203963E-02,   1.8430157E-02
     +,   1.8531723E-02,   1.8529752E-02,   1.8446056E-02
     +,   1.8301502E-02,   1.8113662E-02,   1.7890863E-02
     +,   1.7625572E-02,   1.7293682E-02,   1.6862422E-02
     +,   1.6303563E-02,   1.5605122E-02,   1.4777084E-02
     +,   1.3850503E-02,   1.2871278E-02,   1.1890874E-02
     +,   1.0956416E-02,   1.0102656E-02,   9.3473699E-03
     +,   8.6912410E-03,   8.1220241E-03,   7.6213526E-03
     +,   7.1712541E-03,   6.7584366E-03,   6.3754008E-03
     +,   6.0192351E-03,   5.6892964E-03,   5.3850459E-03
     +,   5.1049106E-03,   4.8461081E-03,   4.6050292E-03
     +,   4.3778485E-03,   4.1610720E-03,   3.9518392E-03
     +,   3.7480239E-03,   3.5481669E-03,   3.3513983E-03
     +,   3.1573351E-03,   2.9659590E-03,   2.7776044E-03
     +,   2.5928803E-03,   2.4126645E-03,   2.2379919E-03
     +,   2.0700074E-03,   1.9098107E-03,   1.7583839E-03
     +,   1.6164661E-03,   1.4845323E-03,   1.3627483E-03
     +,   1.2510031E-03,   1.1489686E-03,   1.0561323E-03
     +,   9.7188493E-04,   8.9555117E-04,   8.2645280E-04
     +,   7.6391827E-04,   7.0731615E-04,   6.5604993E-04
     +,   6.0957193E-04,   5.6737219E-04,   5.2898796E-04
     +,   4.9399107E-04,   4.6199773E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt106 = Yx/0.1904
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7677352E-05,   2.8385899E-05
     +,   2.9103612E-05,   2.9830064E-05,   3.0564759E-05
     +,   3.1307220E-05,   3.2056905E-05,   3.2813310E-05
     +,   3.3575856E-05,   3.4344026E-05,   3.5117235E-05
     +,   3.5894915E-05,   3.6676509E-05,   3.7461461E-05
     +,   3.8249222E-05,   3.9039245E-05,   3.9831044E-05
     +,   4.0624138E-05,   4.1418094E-05,   4.2212494E-05
     +,   4.3006981E-05,   4.3801279E-05,   4.4595123E-05
     +,   4.5388391E-05,   4.6180943E-05,   4.6972807E-05
     +,   4.7764050E-05,   4.8554859E-05,   4.9345508E-05
     +,   5.0136376E-05,   5.0927993E-05,   5.1720959E-05
     +,   5.2516036E-05,   5.3314085E-05,   5.4116117E-05
     +,   5.4923275E-05,   5.5736815E-05,   5.6558165E-05
     +,   5.7388861E-05,   5.8230533E-05,   5.9085018E-05
     +,   5.9954222E-05,   6.0840190E-05,   6.1745013E-05
     +,   6.2671017E-05,   6.3620464E-05,   6.4595799E-05
     +,   6.5599503E-05,   6.6634100E-05,   6.7702131E-05
     +,   6.8806228E-05,   6.9948976E-05,   7.1132905E-05
     +,   7.2360650E-05,   7.3634576E-05,   7.4957221E-05
     +,   7.6330834E-05,   7.7757672E-05,   7.9239806E-05
     +,   8.0779137E-05,   8.2377446E-05,   8.4036321E-05
     +,   8.5757049E-05,   8.7540844E-05,   8.9388639E-05
     +,   9.1300957E-05,   9.3278373E-05,   9.5320851E-05
     +,   9.7428405E-05,   9.9600431E-05,   1.0183637E-04
     +,   1.0413507E-04,   1.0649538E-04,   1.0891558E-04
     +,   1.1139386E-04,   1.1392823E-04,   1.1651618E-04
     +,   1.1915499E-04,   1.2184176E-04,   1.2457352E-04
     +,   1.2734674E-04,   1.3015799E-04,   1.3300334E-04
     +,   1.3587903E-04,   1.3878071E-04,   1.4170435E-04
     +,   1.4464527E-04,   1.4759919E-04,   1.5056113E-04
     +,   1.5352652E-04,   1.5649051E-04,   1.5944801E-04
     +,   1.6239392E-04,   1.6532316E-04,   1.6823066E-04
     +,   1.7111086E-04,   1.7395869E-04,   1.7676862E-04
     +,   1.7953533E-04,   1.8225322E-04,   1.8491691E-04
     +,   1.8752069E-04,   1.9005916E-04,   1.9252668E-04
     +,   1.9491768E-04,   1.9722671E-04,   1.9944817E-04
     +,   2.0157658E-04,   2.0360654E-04,   2.0553288E-04
     +,   2.0735027E-04,   2.0905386E-04,   2.1063864E-04
     +,   2.1210009E-04,   2.1343370E-04,   2.1463555E-04
     +,   2.1570170E-04,   2.1662893E-04,   2.1741397E-04
     +,   2.1805451E-04,   2.1854830E-04,   2.1889379E-04
     +,   2.1908994E-04,   2.1913630E-04,   2.1903301E-04
     +,   2.1878083E-04,   2.1838130E-04,   2.1783657E-04
     +,   2.1714931E-04,   2.1632331E-04,   2.1536270E-04
     +,   2.1427257E-04,   2.1305859E-04,   2.1172734E-04
     +,   2.1028596E-04,   2.0874236E-04,   2.0710517E-04
     +,   2.0538385E-04,   2.0358834E-04,   2.0172921E-04
     +,   1.9981805E-04,   1.9786690E-04,   1.9588835E-04
     +,   1.9389574E-04,   1.9190309E-04,   1.8992506E-04
     +,   1.8797681E-04,   1.8607423E-04,   1.8423420E-04
     +,   1.8247378E-04,   1.8081097E-04,   1.7926461E-04
     +,   1.7785410E-04,   1.7659992E-04,   1.7552303E-04
     +,   1.7464577E-04,   1.7399107E-04,   1.7358328E-04
     +,   1.7344746E-04,   1.7361045E-04,   1.7410031E-04
     +,   1.7494672E-04,   1.7618136E-04,   1.7783788E-04
     +,   1.7995281E-04,   1.8256565E-04,   1.8571921E-04
     +,   1.8946070E-04,   1.9384229E-04,   1.9892227E-04
     +,   2.0476537E-04,   2.1144401E-04,   2.1903995E-04
     +,   2.2764510E-04,   2.3736147E-04,   2.4830311E-04
     +,   2.6059727E-04,   2.7438204E-04,   2.8980756E-04
     +,   3.0703624E-04,   3.2623968E-04,   3.4759496E-04
     +,   3.7128292E-04,   3.9748507E-04,   4.2637807E-04
     +,   4.5812709E-04,   4.9288088E-04,   5.3077057E-04
     +,   5.7190185E-04,   6.1634934E-04,   6.6416024E-04
     +,   7.1535184E-04,   7.6990825E-04,   8.2778558E-04
     +,   8.8891998E-04,   9.5322519E-04,   1.0205925E-03
     +,   1.0908943E-03,   1.1639893E-03,   1.2397126E-03
     +,   1.3178757E-03,   1.3982706E-03,   1.4806904E-03
     +,   1.5649530E-03,   1.6509347E-03,   1.7386572E-03
     +,   1.8283547E-03,   1.9205527E-03,   2.0161525E-03
     +,   2.1164697E-03,   2.2232200E-03,   2.3384197E-03
     +,   2.4642202E-03,   2.6026813E-03,   2.7554629E-03
     +,   2.9235212E-03,   3.1068642E-03,   3.3044324E-03
     +,   3.5141262E-03,   3.7330666E-03,   3.9581768E-03
     +,   4.1869730E-03,   4.4185291E-03,   4.6545267E-03
     +,   4.9000834E-03,   5.1641171E-03,   5.4589966E-03
     +,   5.7993354E-03,   6.2002558E-03,   6.6753351E-03
     +,   7.2349445E-03,   7.8853788E-03,   8.6288610E-03
     +,   9.4636306E-03,   1.0383310E-02,   1.1374740E-02
     +,   1.2414021E-02,   1.3463141E-02,   1.4471557E-02
     +,   1.5385671E-02,   1.6164476E-02,   1.6794644E-02
     +,   1.7297054E-02,   1.7720867E-02,   1.8127797E-02
     +,   1.8570393E-02,   1.9070007E-02,   1.9602248E-02
     +,   2.0098200E-02,   2.0464459E-02,   2.0612752E-02
     +,   2.0484593E-02,   2.0061655E-02,   1.9366030E-02
     +,   1.8456824E-02,   1.7424205E-02,   1.6374130E-02
     +,   1.5400952E-02,   1.4558538E-02,   1.3847638E-02
     +,   1.3227210E-02,   1.2641799E-02,   1.2048066E-02
     +,   1.1427719E-02,   1.0785628E-02,   1.0139680E-02
     +,   9.5106270E-03,   8.9152418E-03,   8.3628017E-03
     +,   7.8538526E-03,   7.3812990E-03,   6.9334293E-03
     +,   6.4983740E-03,   6.0681375E-03,   5.6408918E-03
     +,   5.2207243E-03,   4.8153549E-03,   4.4334130E-03
     +,   4.0818821E-03,   3.7648163E-03,   3.4828689E-03
     +,   3.2338337E-03,   3.0134006E-03,   2.8162210E-03
     +,   2.6367255E-03,   2.4698980E-03,   2.3116765E-03
     +,   2.1592074E-03,   2.0108663E-03,   1.8660665E-03
     +,   1.7250575E-03,   1.5885972E-03,   1.4577197E-03
     +,   1.3334688E-03,   1.2167695E-03,   1.1082961E-03
     +,   1.0084601E-03,   9.1738056E-04,   8.3493703E-04
     +,   7.6078932E-04,   6.9444953E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt108 = Yx/0.190555555555556
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.6670943E-06,   9.0532985E-06
     +,   9.4626412E-06,   9.8963465E-06,   1.0355668E-05
     +,   1.0841865E-05,   1.1356220E-05,   1.1900031E-05
     +,   1.2474574E-05,   1.3081167E-05,   1.3721082E-05
     +,   1.4395581E-05,   1.5105918E-05,   1.5853295E-05
     +,   1.6638885E-05,   1.7463813E-05,   1.8329141E-05
     +,   1.9235857E-05,   2.0184871E-05,   2.1177011E-05
     +,   2.2213004E-05,   2.3293465E-05,   2.4418860E-05
     +,   2.5589605E-05,   2.6805852E-05,   2.8067716E-05
     +,   2.9375084E-05,   3.0727690E-05,   3.2125081E-05
     +,   3.3566619E-05,   3.5051478E-05,   3.6578615E-05
     +,   3.8146791E-05,   3.9754545E-05,   4.1400221E-05
     +,   4.3081913E-05,   4.4797511E-05,   4.6544686E-05
     +,   4.8320959E-05,   5.0123475E-05,   5.1949370E-05
     +,   5.3795462E-05,   5.5658409E-05,   5.7534682E-05
     +,   5.9420610E-05,   6.1312363E-05,   6.3205938E-05
     +,   6.5097280E-05,   6.6982182E-05,   6.8856374E-05
     +,   7.0715556E-05,   7.2555325E-05,   7.4371295E-05
     +,   7.6159202E-05,   7.7914599E-05,   7.9633312E-05
     +,   8.1311162E-05,   8.2944069E-05,   8.4528132E-05
     +,   8.6059641E-05,   8.7535016E-05,   8.8950954E-05
     +,   9.0304304E-05,   9.1592316E-05,   9.2812479E-05
     +,   9.3962473E-05,   9.5040516E-05,   9.6044925E-05
     +,   9.6974574E-05,   9.7828597E-05,   9.8606557E-05
     +,   9.9308316E-05,   9.9934266E-05,   1.0048506E-04
     +,   1.0096181E-04,   1.0136598E-04,   1.0169948E-04
     +,   1.0196451E-04,   1.0216366E-04,   1.0229996E-04
     +,   1.0237659E-04,   1.0239724E-04,   1.0236572E-04
     +,   1.0228628E-04,   1.0216331E-04,   1.0200146E-04
     +,   1.0180555E-04,   1.0158059E-04,   1.0133175E-04
     +,   1.0106423E-04,   1.0078343E-04,   1.0049466E-04
     +,   1.0020333E-04,   9.9914840E-05,   9.9634512E-05
     +,   9.9367586E-05,   9.9119214E-05,   9.8894445E-05
     +,   9.8698125E-05,   9.8534976E-05,   9.8409473E-05
     +,   9.8325887E-05,   9.8288307E-05,   9.8300479E-05
     +,   9.8365985E-05,   9.8488097E-05,   9.8669792E-05
     +,   9.8913835E-05,   9.9222649E-05,   9.9598445E-05
     +,   1.0004311E-04,   1.0055838E-04,   1.0114564E-04
     +,   1.0180612E-04,   1.0254079E-04,   1.0335045E-04
     +,   1.0423575E-04,   1.0519715E-04,   1.0623497E-04
     +,   1.0734948E-04,   1.0854085E-04,   1.0980914E-04
     +,   1.1115431E-04,   1.1257645E-04,   1.1407556E-04
     +,   1.1565152E-04,   1.1730445E-04,   1.1903420E-04
     +,   1.2084092E-04,   1.2272445E-04,   1.2468497E-04
     +,   1.2672233E-04,   1.2883656E-04,   1.3102742E-04
     +,   1.3329474E-04,   1.3563834E-04,   1.3805763E-04
     +,   1.4055180E-04,   1.4312009E-04,   1.4576143E-04
     +,   1.4847430E-04,   1.5125684E-04,   1.5410699E-04
     +,   1.5702251E-04,   1.6000048E-04,   1.6303791E-04
     +,   1.6613158E-04,   1.6927788E-04,   1.7247310E-04
     +,   1.7571377E-04,   1.7899650E-04,   1.8231822E-04
     +,   1.8567631E-04,   1.8906915E-04,   1.9249658E-04
     +,   1.9595948E-04,   1.9946074E-04,   2.0300597E-04
     +,   2.0660370E-04,   2.1026534E-04,   2.1400681E-04
     +,   2.1784846E-04,   2.2181553E-04,   2.2593903E-04
     +,   2.3025628E-04,   2.3481122E-04,   2.3965415E-04
     +,   2.4484275E-04,   2.5044166E-04,   2.5652212E-04
     +,   2.6316146E-04,   2.7044135E-04,   2.7844860E-04
     +,   2.8727209E-04,   2.9700031E-04,   3.0772068E-04
     +,   3.1951696E-04,   3.3246508E-04,   3.4663134E-04
     +,   3.6207133E-04,   3.7882643E-04,   3.9692118E-04
     +,   4.1636260E-04,   4.3714195E-04,   4.5923365E-04
     +,   4.8259535E-04,   5.0717290E-04,   5.3290412E-04
     +,   5.5972399E-04,   5.8756577E-04,   6.1637291E-04
     +,   6.4610166E-04,   6.7672541E-04,   7.0823939E-04
     +,   7.4066734E-04,   7.7406049E-04,   8.0849702E-04
     +,   8.4407994E-04,   8.8094262E-04,   9.1924204E-04
     +,   9.5915660E-04,   1.0008928E-03,   1.0446907E-03
     +,   1.0908373E-03,   1.1396696E-03,   1.1916077E-03
     +,   1.2471685E-03,   1.3069848E-03,   1.3718206E-03
     +,   1.4425887E-03,   1.5203350E-03,   1.6062027E-03
     +,   1.7013872E-03,   1.8070514E-03,   1.9242057E-03
     +,   2.0535751E-03,   2.1954600E-03,   2.3496372E-03
     +,   2.5152988E-03,   2.6910885E-03,   2.8752894E-03
     +,   3.0661342E-03,   3.2621843E-03,   3.4627756E-03
     +,   3.6683618E-03,   3.8806212E-03,   4.1022813E-03
     +,   4.3367338E-03,   4.5874761E-03,   4.8574954E-03
     +,   5.1486650E-03,   5.4611340E-03,   5.7928264E-03
     +,   6.1392696E-03,   6.4943968E-03,   6.8530552E-03
     +,   7.2149509E-03,   7.5887232E-03,   7.9937251E-03
     +,   8.4570786E-03,   9.0056416E-03,   9.6561732E-03
     +,   1.0409234E-02,   1.1251163E-02,   1.2162810E-02
     +,   1.3128855E-02,   1.4140390E-02,   1.5190654E-02
     +,   1.6270351E-02,   1.7369270E-02,   1.8478878E-02
     +,   1.9582894E-02,   2.0635318E-02,   2.1547584E-02
     +,   2.2209179E-02,   2.2536801E-02,   2.2515217E-02
     +,   2.2195114E-02,   2.1652177E-02,   2.0944480E-02
     +,   2.0100815E-02,   1.9142848E-02,   1.8115135E-02
     +,   1.7095311E-02,   1.6176201E-02,   1.5433752E-02
     +,   1.4899985E-02,   1.4551731E-02,   1.4318389E-02
     +,   1.4107048E-02,   1.3833653E-02,   1.3444836E-02
     +,   1.2922491E-02,   1.2275156E-02,   1.1526285E-02
     +,   1.0705847E-02,   9.8455101E-03,   8.9761931E-03
     +,   8.1255585E-03,   7.3159407E-03,   6.5624649E-03
     +,   5.8728238E-03,   5.2481471E-03,   4.6852846E-03
     +,   4.1789575E-03,   3.7236465E-03,   3.3143808E-03
     +,   2.9469954E-03,   2.6180022E-03,   2.3242866E-03
     +,   2.0630276E-03,   1.8315368E-03,   1.6272796E-03
     +,   1.4477705E-03,   1.2906088E-03,   1.1534111E-03
     +,   1.0338732E-03,   9.2976034E-04,   8.3898206E-04
     +,   7.5960485E-04,   6.8990281E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt110 = Yx/0.197711111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0898226E-05,   2.1439375E-05
     +,   2.1988333E-05,   2.2545259E-05,   2.3110348E-05
     +,   2.3683831E-05,   2.4265981E-05,   2.4857109E-05
     +,   2.5457581E-05,   2.6067808E-05,   2.6688245E-05
     +,   2.7319396E-05,   2.7961825E-05,   2.8616138E-05
     +,   2.9282990E-05,   2.9963086E-05,   3.0657204E-05
     +,   3.1366151E-05,   3.2090778E-05,   3.2831984E-05
     +,   3.3590721E-05,   3.4367953E-05,   3.5164692E-05
     +,   3.5981997E-05,   3.6820897E-05,   3.7682490E-05
     +,   3.8567847E-05,   3.9478022E-05,   4.0414106E-05
     +,   4.1377145E-05,   4.2368134E-05,   4.3388085E-05
     +,   4.4437889E-05,   4.5518438E-05,   4.6630514E-05
     +,   4.7774829E-05,   4.8952013E-05,   5.0162544E-05
     +,   5.1406874E-05,   5.2685209E-05,   5.3997737E-05
     +,   5.5344441E-05,   5.6725152E-05,   5.8139565E-05
     +,   5.9587208E-05,   6.1067440E-05,   6.2579456E-05
     +,   6.4122287E-05,   6.5694789E-05,   6.7295659E-05
     +,   6.8923458E-05,   7.0576592E-05,   7.2253271E-05
     +,   7.3951713E-05,   7.5669872E-05,   7.7405712E-05
     +,   7.9157093E-05,   8.0921818E-05,   8.2697639E-05
     +,   8.4482330E-05,   8.6273700E-05,   8.8069537E-05
     +,   8.9867703E-05,   9.1666210E-05,   9.3463284E-05
     +,   9.5257026E-05,   9.7046039E-05,   9.8828845E-05
     +,   1.0060447E-04,   1.0237195E-04,   1.0413076E-04
     +,   1.0588048E-04,   1.0762131E-04,   1.0935334E-04
     +,   1.1107729E-04,   1.1279415E-04,   1.1450511E-04
     +,   1.1621162E-04,   1.1791562E-04,   1.1961922E-04
     +,   1.2132462E-04,   1.2303457E-04,   1.2475155E-04
     +,   1.2647860E-04,   1.2821850E-04,   1.2997439E-04
     +,   1.3174904E-04,   1.3354557E-04,   1.3536653E-04
     +,   1.3721455E-04,   1.3909205E-04,   1.4100100E-04
     +,   1.4294304E-04,   1.4491932E-04,   1.4693083E-04
     +,   1.4897756E-04,   1.5105930E-04,   1.5317500E-04
     +,   1.5532320E-04,   1.5750150E-04,   1.5970721E-04
     +,   1.6193643E-04,   1.6418505E-04,   1.6644801E-04
     +,   1.6871971E-04,   1.7099398E-04,   1.7326405E-04
     +,   1.7552238E-04,   1.7776139E-04,   1.7997297E-04
     +,   1.8214852E-04,   1.8427949E-04,   1.8635692E-04
     +,   1.8837216E-04,   1.9031625E-04,   1.9218084E-04
     +,   1.9395741E-04,   1.9563823E-04,   1.9721568E-04
     +,   1.9868300E-04,   2.0003412E-04,   2.0126349E-04
     +,   2.0236654E-04,   2.0333972E-04,   2.0418034E-04
     +,   2.0488676E-04,   2.0545833E-04,   2.0589566E-04
     +,   2.0620041E-04,   2.0637519E-04,   2.0642389E-04
     +,   2.0635150E-04,   2.0616390E-04,   2.0586807E-04
     +,   2.0547182E-04,   2.0498397E-04,   2.0441395E-04
     +,   2.0377213E-04,   2.0306918E-04,   2.0231657E-04
     +,   2.0152592E-04,   2.0070933E-04,   1.9987905E-04
     +,   1.9904725E-04,   1.9822632E-04,   1.9742825E-04
     +,   1.9666490E-04,   1.9594796E-04,   1.9528833E-04
     +,   1.9469664E-04,   1.9418278E-04,   1.9375612E-04
     +,   1.9342518E-04,   1.9319760E-04,   1.9308043E-04
     +,   1.9307958E-04,   1.9320031E-04,   1.9344685E-04
     +,   1.9382259E-04,   1.9433004E-04,   1.9497095E-04
     +,   1.9574635E-04,   1.9665650E-04,   1.9770098E-04
     +,   1.9887928E-04,   2.0019030E-04,   2.0163289E-04
     +,   2.0320609E-04,   2.0490927E-04,   2.0674260E-04
     +,   2.0870719E-04,   2.1080555E-04,   2.1304211E-04
     +,   2.1542385E-04,   2.1796023E-04,   2.2066427E-04
     +,   2.2355316E-04,   2.2664823E-04,   2.2997586E-04
     +,   2.3356805E-04,   2.3746259E-04,   2.4170319E-04
     +,   2.4633968E-04,   2.5142817E-04,   2.5703057E-04
     +,   2.6321408E-04,   2.7004996E-04,   2.7761416E-04
     +,   2.8598538E-04,   2.9524349E-04,   3.0547031E-04
     +,   3.1674828E-04,   3.2915993E-04,   3.4278890E-04
     +,   3.5772214E-04,   3.7405294E-04,   3.9188264E-04
     +,   4.1132740E-04,   4.3252582E-04,   4.5564672E-04
     +,   4.8089569E-04,   5.0852564E-04,   5.3884817E-04
     +,   5.7224045E-04,   6.0914643E-04,   6.5008650E-04
     +,   6.9564808E-04,   7.4647367E-04,   8.0323947E-04
     +,   8.6662913E-04,   9.3728717E-04,   1.0157599E-03
     +,   1.1024334E-03,   1.1974738E-03,   1.3007611E-03
     +,   1.4118232E-03,   1.5298214E-03,   1.6535586E-03
     +,   1.7815216E-03,   1.9119690E-03,   2.0430926E-03
     +,   2.1731725E-03,   2.3007630E-03,   2.4248632E-03
     +,   2.5450669E-03,   2.6616280E-03,   2.7754779E-03
     +,   2.8882285E-03,   3.0021521E-03,   3.1201746E-03
     +,   3.2459188E-03,   3.3837813E-03,   3.5389983E-03
     +,   3.7175934E-03,   3.9261198E-03,   4.1712108E-03
     +,   4.4587841E-03,   4.7930451E-03,   5.1754620E-03
     +,   5.6039691E-03,   6.0726423E-03,   6.5721120E-03
     +,   7.0909844E-03,   7.6182075E-03,   8.1463298E-03
     +,   8.6754002E-03,   9.2170220E-03,   9.7967125E-03
     +,   1.0451618E-02,   1.1221060E-02,   1.2131034E-02
     +,   1.3178764E-02,   1.4327440E-02,   1.5516852E-02
     +,   1.6685670E-02,   1.7793808E-02,   1.8833986E-02
     +,   1.9827621E-02,   2.0804429E-02,   2.1775268E-02
     +,   2.2714857E-02,   2.3568803E-02,   2.4277473E-02
     +,   2.4794903E-02,   2.5088431E-02,   2.5130376E-02
     +,   2.4897734E-02,   2.4381211E-02,   2.3592303E-02
     +,   2.2564527E-02,   2.1354061E-02,   2.0042259E-02
     +,   1.8733200E-02,   1.7535791E-02,   1.6529709E-02
     +,   1.5729578E-02,   1.5071700E-02,   1.4437955E-02
     +,   1.3705648E-02,   1.2796967E-02,   1.1703962E-02
     +,   1.0482918E-02,   9.2262933E-03,   8.0289068E-03
     +,   6.9609690E-03,   6.0560182E-03,   5.3127925E-03
     +,   4.7067460E-03,   4.2040562E-03,   3.7727405E-03
     +,   3.3889229E-03,   3.0380248E-03,   2.7131580E-03
     +,   2.4122114E-03,   2.1353744E-03,   1.8833008E-03
     +,   1.6562778E-03,   1.4538573E-03,   1.2749566E-03
     +,   1.1179761E-03,   9.8104251E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt112 = Yx/0.206111111111111
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6237496E-05,   2.6782845E-05
     +,   2.7332062E-05,   2.7884942E-05,   2.8441285E-05
     +,   2.9000901E-05,   2.9563562E-05,   3.0129062E-05
     +,   3.0697182E-05,   3.1267737E-05,   3.1840475E-05
     +,   3.2415206E-05,   3.2991691E-05,   3.3569730E-05
     +,   3.4149107E-05,   3.4729601E-05,   3.5311008E-05
     +,   3.5893110E-05,   3.6475714E-05,   3.7058628E-05
     +,   3.7641665E-05,   3.8224629E-05,   3.8807331E-05
     +,   3.9389659E-05,   3.9971397E-05,   4.0552444E-05
     +,   4.1132655E-05,   4.1711908E-05,   4.2290103E-05
     +,   4.2867174E-05,   4.3443029E-05,   4.4017619E-05
     +,   4.4590914E-05,   4.5162909E-05,   4.5733610E-05
     +,   4.6303048E-05,   4.6871261E-05,   4.7438338E-05
     +,   4.8004385E-05,   4.8569498E-05,   4.9133840E-05
     +,   4.9697574E-05,   5.0260889E-05,   5.0824005E-05
     +,   5.1387149E-05,   5.1950574E-05,   5.2514562E-05
     +,   5.3079406E-05,   5.3645403E-05,   5.4212884E-05
     +,   5.4782202E-05,   5.5353685E-05,   5.5927660E-05
     +,   5.6504548E-05,   5.7084635E-05,   5.7668323E-05
     +,   5.8255941E-05,   5.8847829E-05,   5.9444290E-05
     +,   6.0045655E-05,   6.0652179E-05,   6.1264131E-05
     +,   6.1881707E-05,   6.2505074E-05,   6.3134430E-05
     +,   6.3769803E-05,   6.4411281E-05,   6.5058790E-05
     +,   6.5712324E-05,   6.6371671E-05,   6.7036701E-05
     +,   6.7707057E-05,   6.8382476E-05,   6.9062473E-05
     +,   6.9746544E-05,   7.0434166E-05,   7.1124632E-05
     +,   7.1817187E-05,   7.2511044E-05,   7.3205301E-05
     +,   7.3898955E-05,   7.4590971E-05,   7.5280201E-05
     +,   7.5965509E-05,   7.6645578E-05,   7.7319120E-05
     +,   7.7984718E-05,   7.8641009E-05,   7.9286503E-05
     +,   7.9919708E-05,   8.0539110E-05,   8.1143167E-05
     +,   8.1730323E-05,   8.2299033E-05,   8.2847779E-05
     +,   8.3375024E-05,   8.3879291E-05,   8.4359097E-05
     +,   8.4813102E-05,   8.5239888E-05,   8.5638232E-05
     +,   8.6006898E-05,   8.6344822E-05,   8.6650922E-05
     +,   8.6924309E-05,   8.7164190E-05,   8.7369859E-05
     +,   8.7540757E-05,   8.7676424E-05,   8.7776614E-05
     +,   8.7841108E-05,   8.7869943E-05,   8.7863220E-05
     +,   8.7821223E-05,   8.7744389E-05,   8.7633285E-05
     +,   8.7488690E-05,   8.7311448E-05,   8.7102635E-05
     +,   8.6863431E-05,   8.6595144E-05,   8.6299260E-05
     +,   8.5977430E-05,   8.5631407E-05,   8.5263055E-05
     +,   8.4874373E-05,   8.4467523E-05,   8.4044761E-05
     +,   8.3608400E-05,   8.3160950E-05,   8.2704930E-05
     +,   8.2243052E-05,   8.1777958E-05,   8.1312544E-05
     +,   8.0849648E-05,   8.0392201E-05,   7.9943216E-05
     +,   7.9505793E-05,   7.9082958E-05,   7.8677869E-05
     +,   7.8293655E-05,   7.7933553E-05,   7.7600722E-05
     +,   7.7298369E-05,   7.7029734E-05,   7.6798002E-05
     +,   7.6606397E-05,   7.6458098E-05,   7.6356315E-05
     +,   7.6304183E-05,   7.6304867E-05,   7.6361488E-05
     +,   7.6477139E-05,   7.6654971E-05,   7.6898054E-05
     +,   7.7209450E-05,   7.7592384E-05,   7.8050020E-05
     +,   7.8585726E-05,   7.9202953E-05,   7.9905352E-05
     +,   8.0697071E-05,   8.1582555E-05,   8.2566869E-05
     +,   8.3655992E-05,   8.4856882E-05,   8.6177854E-05
     +,   8.7628920E-05,   8.9222303E-05,   9.0972884E-05
     +,   9.2898779E-05,   9.5021889E-05,   9.7369026E-05
     +,   9.9972400E-05,   1.0287034E-04,   1.0610857E-04
     +,   1.0974089E-04,   1.1382970E-04,   1.1844668E-04
     +,   1.2367360E-04,   1.2960225E-04,   1.3633372E-04
     +,   1.4397789E-04,   1.5265275E-04,   1.6248216E-04
     +,   1.7359261E-04,   1.8611053E-04,   2.0015943E-04
     +,   2.1585514E-04,   2.3329930E-04,   2.5257791E-04
     +,   2.7375534E-04,   2.9686838E-04,   3.2192416E-04
     +,   3.4889922E-04,   3.7773713E-04,   4.0834639E-04
     +,   4.4060458E-04,   4.7436365E-04,   5.0945370E-04
     +,   5.4568640E-04,   5.8286521E-04,   6.2079547E-04
     +,   6.5928983E-04,   6.9817278E-04,   7.3729444E-04
     +,   7.7653240E-04,   8.1579323E-04,   8.5501838E-04
     +,   8.9418766E-04,   9.3331619E-04,   9.7245339E-04
     +,   1.0116820E-03,   1.0511206E-03,   1.0909188E-03
     +,   1.1312519E-03,   1.1723210E-03,   1.2143549E-03
     +,   1.2576015E-03,   1.3023218E-03,   1.3487965E-03
     +,   1.3973238E-03,   1.4482235E-03,   1.5018630E-03
     +,   1.5587003E-03,   1.6193498E-03,   1.6846757E-03
     +,   1.7559264E-03,   1.8348957E-03,   1.9240906E-03
     +,   2.0268902E-03,   2.1476636E-03,   2.2918361E-03
     +,   2.4657852E-03,   2.6765014E-03,   2.9309620E-03
     +,   3.2350058E-03,   3.5918066E-03,   4.0003690E-03
     +,   4.4546910E-03,   4.9445466E-03,   5.4585752E-03
     +,   5.9893555E-03,   6.5384102E-03,   7.1178260E-03
     +,   7.7455528E-03,   8.4343525E-03,   9.1785695E-03
     +,   9.9461954E-03,   1.0683592E-02,   1.1334166E-02
     +,   1.1864248E-02,   1.2284150E-02,   1.2653312E-02
     +,   1.3063290E-02,   1.3602710E-02,   1.4320400E-02
     +,   1.5208575E-02,   1.6218612E-02,   1.7294370E-02
     +,   1.8392559E-02,   1.9475544E-02,   2.0495657E-02
     +,   2.1400372E-02,   2.2159211E-02,   2.2777056E-02
     +,   2.3264410E-02,   2.3589110E-02,   2.3676423E-02
     +,   2.3482392E-02,   2.3074323E-02,   2.2628944E-02
     +,   2.2333220E-02,   2.2255279E-02,   2.2272535E-02
     +,   2.2113515E-02,   2.1505259E-02,   2.0338237E-02
     +,   1.8731127E-02,   1.6949937E-02,   1.5249857E-02
     +,   1.3760505E-02,   1.2475941E-02,   1.1321747E-02
     +,   1.0226788E-02,   9.1571659E-03,   8.1130983E-03
     +,   7.1126055E-03,   6.1782743E-03,   5.3300229E-03
     +,   4.5818877E-03,   3.9397050E-03,   3.4005761E-03
     +,   2.9538323E-03,   2.5839237E-03,   2.2737314E-03
     +,   2.0076667E-03,   1.7734884E-03,   1.5629625E-03
     +,   1.3713979E-03,   1.1967059E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt113 = Yx/0.201288888888889
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.7517948E-05,   4.8477541E-05
     +,   4.9419319E-05,   5.0341590E-05,   5.1242725E-05
     +,   5.2121144E-05,   5.2975371E-05,   5.3803928E-05
     +,   5.4605469E-05,   5.5378739E-05,   5.6122564E-05
     +,   5.6835845E-05,   5.7517649E-05,   5.8167112E-05
     +,   5.8783484E-05,   5.9366204E-05,   5.9914761E-05
     +,   6.0428825E-05,   6.0908202E-05,   6.1352803E-05
     +,   6.1762730E-05,   6.2138213E-05,   6.2479565E-05
     +,   6.2787323E-05,   6.3062114E-05,   6.3304724E-05
     +,   6.3516069E-05,   6.3697204E-05,   6.3849293E-05
     +,   6.3973624E-05,   6.4071646E-05,   6.4144850E-05
     +,   6.4194886E-05,   6.4223430E-05,   6.4232358E-05
     +,   6.4223495E-05,   6.4198830E-05,   6.4160369E-05
     +,   6.4110201E-05,   6.4050386E-05,   6.3983091E-05
     +,   6.3910447E-05,   6.3834632E-05,   6.3757790E-05
     +,   6.3682070E-05,   6.3609572E-05,   6.3542422E-05
     +,   6.3482599E-05,   6.3432133E-05,   6.3392916E-05
     +,   6.3366802E-05,   6.3355554E-05,   6.3360836E-05
     +,   6.3384214E-05,   6.3427164E-05,   6.3491017E-05
     +,   6.3576983E-05,   6.3686224E-05,   6.3819673E-05
     +,   6.3978172E-05,   6.4162392E-05,   6.4372944E-05
     +,   6.4610205E-05,   6.4874483E-05,   6.5165870E-05
     +,   6.5484368E-05,   6.5829838E-05,   6.6201916E-05
     +,   6.6600252E-05,   6.7024215E-05,   6.7473120E-05
     +,   6.7946123E-05,   6.8442314E-05,   6.8960580E-05
     +,   6.9499773E-05,   7.0058653E-05,   7.0635826E-05
     +,   7.1229821E-05,   7.1839153E-05,   7.2462222E-05
     +,   7.3097370E-05,   7.3742958E-05,   7.4397161E-05
     +,   7.5058320E-05,   7.5724623E-05,   7.6394339E-05
     +,   7.7065641E-05,   7.7736870E-05,   7.8406221E-05
     +,   7.9072102E-05,   7.9732883E-05,   8.0386984E-05
     +,   8.1032937E-05,   8.1669328E-05,   8.2294908E-05
     +,   8.2908431E-05,   8.3508879E-05,   8.4095205E-05
     +,   8.4666674E-05,   8.5222520E-05,   8.5762258E-05
     +,   8.6285472E-05,   8.6791959E-05,   8.7281602E-05
     +,   8.7754503E-05,   8.8210974E-05,   8.8651403E-05
     +,   8.9076406E-05,   8.9486806E-05,   8.9883506E-05
     +,   9.0267626E-05,   9.0640504E-05,   9.1003538E-05
     +,   9.1358335E-05,   9.1706701E-05,   9.2050526E-05
     +,   9.2391812E-05,   9.2732756E-05,   9.3075629E-05
     +,   9.3422852E-05,   9.3776856E-05,   9.4140276E-05
     +,   9.4515701E-05,   9.4905881E-05,   9.5313568E-05
     +,   9.5741481E-05,   9.6192562E-05,   9.6669501E-05
     +,   9.7175194E-05,   9.7712385E-05,   9.8283905E-05
     +,   9.8892488E-05,   9.9540841E-05,   1.0023161E-04
     +,   1.0096741E-04,   1.0175082E-04,   1.0258432E-04
     +,   1.0347031E-04,   1.0441121E-04,   1.0540940E-04
     +,   1.0646714E-04,   1.0758667E-04,   1.0877031E-04
     +,   1.1002029E-04,   1.1133886E-04,   1.1272833E-04
     +,   1.1419118E-04,   1.1572971E-04,   1.1734648E-04
     +,   1.1904418E-04,   1.2082572E-04,   1.2269408E-04
     +,   1.2465230E-04,   1.2670396E-04,   1.2885277E-04
     +,   1.3110256E-04,   1.3345749E-04,   1.3592214E-04
     +,   1.3850133E-04,   1.4120000E-04,   1.4402351E-04
     +,   1.4697765E-04,   1.5006811E-04,   1.5330088E-04
     +,   1.5668245E-04,   1.6021926E-04,   1.6391769E-04
     +,   1.6778428E-04,   1.7182567E-04,   1.7604856E-04
     +,   1.8045928E-04,   1.8506381E-04,   1.8986834E-04
     +,   1.9487900E-04,   2.0010074E-04,   2.0553905E-04
     +,   2.1119897E-04,   2.1708498E-04,   2.2320138E-04
     +,   2.2955265E-04,   2.3614337E-04,   2.4297796E-04
     +,   2.5006098E-04,   2.5739832E-04,   2.6499655E-04
     +,   2.7286322E-04,   2.8100709E-04,   2.8943949E-04
     +,   2.9817404E-04,   3.0722600E-04,   3.1661446E-04
     +,   3.2636145E-04,   3.3649200E-04,   3.4703471E-04
     +,   3.5802223E-04,   3.6949140E-04,   3.8148201E-04
     +,   3.9403801E-04,   4.0720779E-04,   4.2104581E-04
     +,   4.3560995E-04,   4.5096534E-04,   4.6718662E-04
     +,   4.8435936E-04,   5.0258200E-04,   5.2197202E-04
     +,   5.4266944E-04,   5.6483928E-04,   5.8867817E-04
     +,   6.1441859E-04,   6.4232893E-04,   6.7271234E-04
     +,   7.0590479E-04,   7.4226846E-04,   7.8218017E-04
     +,   8.2601304E-04,   8.7411987E-04,   9.2681794E-04
     +,   9.8436826E-04,   1.0469600E-03,   1.1147126E-03
     +,   1.1876910E-03,   1.2659201E-03,   1.3494502E-03
     +,   1.4384318E-03,   1.5332155E-03,   1.6344602E-03
     +,   1.7432609E-03,   1.8612631E-03,   1.9907106E-03
     +,   2.1344086E-03,   2.2955455E-03,   2.4773786E-03
     +,   2.6826733E-03,   2.9130001E-03,   3.1680027E-03
     +,   3.4447110E-03,   3.7371260E-03,   4.0363437E-03
     +,   4.3313727E-03,   4.6106093E-03,   4.8639141E-03
     +,   5.0849998E-03,   5.2735023E-03,   5.4361108E-03
     +,   5.5863117E-03,   5.7423511E-03,   5.9237536E-03
     +,   6.1471849E-03,   6.4230072E-03,   6.7544174E-03
     +,   7.1401205E-03,   7.5806044E-03,   8.0856448E-03
     +,   8.6786207E-03,   9.3927672E-03,   1.0257893E-02
     +,   1.1282648E-02,   1.2442387E-02,   1.3681550E-02
     +,   1.4931707E-02,   1.6137771E-02,   1.7282343E-02
     +,   1.8397966E-02,   1.9553937E-02,   2.0807257E-02
     +,   2.2129709E-02,   2.3366779E-02,   2.4290172E-02
     +,   2.4740908E-02,   2.4759319E-02,   2.4580592E-02
     +,   2.4484050E-02,   2.4617286E-02,   2.4929104E-02
     +,   2.5230888E-02,   2.5308611E-02,   2.5005175E-02
     +,   2.4252657E-02,   2.3071753E-02,   2.1554377E-02
     +,   1.9835893E-02,   1.8061524E-02,   1.6358428E-02
     +,   1.4815260E-02,   1.3469226E-02,   1.2300907E-02
     +,   1.1246224E-02,   1.0226088E-02,   9.1811391E-03
     +,   8.0941841E-03,   6.9902656E-03,   5.9199138E-03
     +,   4.9363417E-03,   4.0782075E-03,   3.3616144E-03
     +,   2.7817059E-03,   2.3194328E-03,   1.9501928E-03
     +,   1.6505937E-03,   1.4023597E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt114 = Yx/0.2058
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2063936E-05,   2.2877317E-05
     +,   2.3710450E-05,   2.4563056E-05,   2.5434811E-05
     +,   2.6325355E-05,   2.7234291E-05,   2.8161186E-05
     +,   2.9105551E-05,   3.0066940E-05,   3.1044798E-05
     +,   3.2038595E-05,   3.3047789E-05,   3.4071782E-05
     +,   3.5110017E-05,   3.6161910E-05,   3.7226895E-05
     +,   3.8304406E-05,   3.9393883E-05,   4.0494811E-05
     +,   4.1606687E-05,   4.2729043E-05,   4.3861430E-05
     +,   4.5003526E-05,   4.6154895E-05,   4.7315360E-05
     +,   4.8484631E-05,   4.9662565E-05,   5.0849081E-05
     +,   5.2044114E-05,   5.3247721E-05,   5.4460019E-05
     +,   5.5681154E-05,   5.6911384E-05,   5.8150999E-05
     +,   5.9400372E-05,   6.0659902E-05,   6.1930034E-05
     +,   6.3211330E-05,   6.4504216E-05,   6.5809319E-05
     +,   6.7127148E-05,   6.8458292E-05,   6.9803209E-05
     +,   7.1162431E-05,   7.2536401E-05,   7.3925483E-05
     +,   7.5329976E-05,   7.6750031E-05,   7.8185760E-05
     +,   7.9637059E-05,   8.1103739E-05,   8.2585379E-05
     +,   8.4081512E-05,   8.5591215E-05,   8.7113614E-05
     +,   8.8647437E-05,   9.0191264E-05,   9.1743459E-05
     +,   9.3302042E-05,   9.4864845E-05,   9.6429452E-05
     +,   9.7993099E-05,   9.9552934E-05,   1.0110581E-04
     +,   1.0264826E-04,   1.0417676E-04,   1.0568742E-04
     +,   1.0717635E-04,   1.0863935E-04,   1.1007219E-04
     +,   1.1147045E-04,   1.1282980E-04,   1.1414565E-04
     +,   1.1541353E-04,   1.1662906E-04,   1.1778777E-04
     +,   1.1888536E-04,   1.1991768E-04,   1.2088080E-04
     +,   1.2177084E-04,   1.2258433E-04,   1.2331792E-04
     +,   1.2396874E-04,   1.2453410E-04,   1.2501176E-04
     +,   1.2539985E-04,   1.2569687E-04,   1.2590183E-04
     +,   1.2601403E-04,   1.2603337E-04,   1.2596010E-04
     +,   1.2579499E-04,   1.2553917E-04,   1.2519430E-04
     +,   1.2476246E-04,   1.2424609E-04,   1.2364810E-04
     +,   1.2297172E-04,   1.2222056E-04,   1.2139855E-04
     +,   1.2050990E-04,   1.1955915E-04,   1.1855100E-04
     +,   1.1749037E-04,   1.1638225E-04,   1.1523189E-04
     +,   1.1404463E-04,   1.1282571E-04,   1.1158041E-04
     +,   1.1031418E-04,   1.0903216E-04,   1.0773964E-04
     +,   1.0644150E-04,   1.0514285E-04,   1.0384830E-04
     +,   1.0256250E-04,   1.0128975E-04,   1.0003432E-04
     +,   9.8800025E-05,   9.7590550E-05,   9.6409407E-05
     +,   9.5259828E-05,   9.4144765E-05,   9.3066970E-05
     +,   9.2029004E-05,   9.1033158E-05,   9.0081609E-05
     +,   8.9176276E-05,   8.8318986E-05,   8.7511384E-05
     +,   8.6755041E-05,   8.6051368E-05,   8.5401800E-05
     +,   8.4807645E-05,   8.4270207E-05,   8.3790830E-05
     +,   8.3370898E-05,   8.3011786E-05,   8.2714956E-05
     +,   8.2482045E-05,   8.2314735E-05,   8.2214814E-05
     +,   8.2184262E-05,   8.2225168E-05,   8.2339859E-05
     +,   8.2530765E-05,   8.2800492E-05,   8.3151841E-05
     +,   8.3587714E-05,   8.4111271E-05,   8.4725711E-05
     +,   8.5434382E-05,   8.6240754E-05,   8.7148401E-05
     +,   8.8160887E-05,   8.9281784E-05,   9.0514775E-05
     +,   9.1863447E-05,   9.3331226E-05,   9.4921546E-05
     +,   9.6637741E-05,   9.8482837E-05,   1.0045971E-04
     +,   1.0257113E-04,   1.0481952E-04,   1.0720716E-04
     +,   1.0973585E-04,   1.1240750E-04,   1.1522372E-04
     +,   1.1818585E-04,   1.2129511E-04,   1.2455293E-04
     +,   1.2796077E-04,   1.3152020E-04,   1.3523331E-04
     +,   1.3910291E-04,   1.4313242E-04,   1.4732633E-04
     +,   1.5169065E-04,   1.5623341E-04,   1.6096421E-04
     +,   1.6589517E-04,   1.7104168E-04,   1.7642240E-04
     +,   1.8205946E-04,   1.8797904E-04,   1.9421232E-04
     +,   2.0079539E-04,   2.0776891E-04,   2.1517939E-04
     +,   2.2307884E-04,   2.3152398E-04,   2.4057650E-04
     +,   2.5030307E-04,   2.6077419E-04,   2.7206304E-04
     +,   2.8424399E-04,   2.9739353E-04,   3.1158727E-04
     +,   3.2689841E-04,   3.4339697E-04,   3.6115028E-04
     +,   3.8022094E-04,   4.0066568E-04,   4.2253800E-04
     +,   4.4588916E-04,   4.7076656E-04,   4.9721793E-04
     +,   5.2529643E-04,   5.5506121E-04,   5.8657728E-04
     +,   6.1992311E-04,   6.5519195E-04,   6.9249171E-04
     +,   7.3194481E-04,   7.7368587E-04,   8.1786513E-04
     +,   8.6464250E-04,   9.1417826E-04,   9.6664077E-04
     +,   1.0221985E-03,   1.0810153E-03,   1.1432545E-03
     +,   1.2090832E-03,   1.2786739E-03,   1.3522016E-03
     +,   1.4298551E-03,   1.5118519E-03,   1.5984500E-03
     +,   1.6899699E-03,   1.7868414E-03,   1.8896734E-03
     +,   1.9993237E-03,   2.1169556E-03,   2.2441263E-03
     +,   2.3827734E-03,   2.5351611E-03,   2.7037521E-03
     +,   2.8910397E-03,   3.0993286E-03,   3.3305457E-03
     +,   3.5861116E-03,   3.8668842E-03,   4.1730744E-03
     +,   4.5040669E-03,   4.8582139E-03,   5.2325674E-03
     +,   5.6227054E-03,   6.0231313E-03,   6.4287605E-03
     +,   6.8375473E-03,   7.2538806E-03,   7.6912139E-03
     +,   8.1714066E-03,   8.7188715E-03,   9.3502766E-03
     +,   1.0064561E-02,   1.0840471E-02,   1.1645934E-02
     +,   1.2456200E-02,   1.3269035E-02,   1.4103036E-02
     +,   1.4975999E-02,   1.5876595E-02,   1.6756242E-02
     +,   1.7560003E-02,   1.8285822E-02,   1.9025099E-02
     +,   1.9935010E-02,   2.1144530E-02,   2.2657104E-02
     +,   2.4322193E-02,   2.5889963E-02,   2.7108602E-02
     +,   2.7813436E-02,   2.7970497E-02,   2.7657261E-02
     +,   2.6995726E-02,   2.6087347E-02,   2.4988588E-02
     +,   2.3725059E-02,   2.2316359E-02,   2.0797474E-02
     +,   1.9226938E-02,   1.7671982E-02,   1.6176779E-02
     +,   1.4744687E-02,   1.3351829E-02,   1.1976446E-02
     +,   1.0618234E-02,   9.2973979E-03,   8.0443760E-03
     +,   6.8893321E-03,   5.8558988E-03,   4.9569178E-03
     +,   4.1933209E-03,   3.5554662E-03,   3.0272959E-03
     +,   2.5905527E-03,   2.2280838E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt115 = Yx/0.205488888888889
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1872074E-05,   3.2873901E-05
     +,   3.3896937E-05,   3.4941266E-05,   3.6006928E-05
     +,   3.7093963E-05,   3.8202390E-05,   3.9332201E-05
     +,   4.0483341E-05,   4.1655807E-05,   4.2849482E-05
     +,   4.4064254E-05,   4.5299974E-05,   4.6556455E-05
     +,   4.7833491E-05,   4.9130809E-05,   5.0448096E-05
     +,   5.1785035E-05,   5.3141193E-05,   5.4516149E-05
     +,   5.5909397E-05,   5.7320365E-05,   5.8748425E-05
     +,   6.0192968E-05,   6.1653147E-05,   6.3128231E-05
     +,   6.4617336E-05,   6.6119479E-05,   6.7633657E-05
     +,   6.9158785E-05,   7.0693677E-05,   7.2237082E-05
     +,   7.3787698E-05,   7.5344076E-05,   7.6904777E-05
     +,   7.8468234E-05,   8.0032805E-05,   8.1596780E-05
     +,   8.3158433E-05,   8.4715815E-05,   8.6267115E-05
     +,   8.7810309E-05,   8.9343361E-05,   9.0864189E-05
     +,   9.2370654E-05,   9.3860588E-05,   9.5331758E-05
     +,   9.6781958E-05,   9.8208875E-05,   9.9610290E-05
     +,   1.0098387E-04,   1.0232734E-04,   1.0363846E-04
     +,   1.0491505E-04,   1.0615477E-04,   1.0735560E-04
     +,   1.0851533E-04,   1.0963199E-04,   1.1070356E-04
     +,   1.1172819E-04,   1.1270405E-04,   1.1362953E-04
     +,   1.1450296E-04,   1.1532298E-04,   1.1608830E-04
     +,   1.1679767E-04,   1.1745014E-04,   1.1804479E-04
     +,   1.1858107E-04,   1.1905828E-04,   1.1947619E-04
     +,   1.1983460E-04,   1.2013350E-04,   1.2037322E-04
     +,   1.2055404E-04,   1.2067661E-04,   1.2074169E-04
     +,   1.2075026E-04,   1.2070348E-04,   1.2060269E-04
     +,   1.2044942E-04,   1.2024536E-04,   1.1999242E-04
     +,   1.1969259E-04,   1.1934808E-04,   1.1896119E-04
     +,   1.1853446E-04,   1.1807044E-04,   1.1757189E-04
     +,   1.1704162E-04,   1.1648254E-04,   1.1589767E-04
     +,   1.1529010E-04,   1.1466292E-04,   1.1401932E-04
     +,   1.1336256E-04,   1.1269577E-04,   1.1202223E-04
     +,   1.1134521E-04,   1.1066781E-04,   1.0999326E-04
     +,   1.0932468E-04,   1.0866504E-04,   1.0801744E-04
     +,   1.0738470E-04,   1.0676965E-04,   1.0617499E-04
     +,   1.0560336E-04,   1.0505717E-04,   1.0453878E-04
     +,   1.0405038E-04,   1.0359406E-04,   1.0317174E-04
     +,   1.0278515E-04,   1.0243592E-04,   1.0212552E-04
     +,   1.0185522E-04,   1.0162618E-04,   1.0143936E-04
     +,   1.0129557E-04,   1.0119555E-04,   1.0113975E-04
     +,   1.0112865E-04,   1.0116242E-04,   1.0124123E-04
     +,   1.0136505E-04,   1.0153379E-04,   1.0174719E-04
     +,   1.0200500E-04,   1.0230680E-04,   1.0265214E-04
     +,   1.0304047E-04,   1.0347122E-04,   1.0394385E-04
     +,   1.0445759E-04,   1.0501191E-04,   1.0560611E-04
     +,   1.0623950E-04,   1.0691148E-04,   1.0762148E-04
     +,   1.0836885E-04,   1.0915306E-04,   1.0997369E-04
     +,   1.1083023E-04,   1.1172234E-04,   1.1264966E-04
     +,   1.1361198E-04,   1.1460909E-04,   1.1564085E-04
     +,   1.1670712E-04,   1.1780806E-04,   1.1894361E-04
     +,   1.2011387E-04,   1.2131907E-04,   1.2255953E-04
     +,   1.2383552E-04,   1.2514734E-04,   1.2649562E-04
     +,   1.2788095E-04,   1.2930385E-04,   1.3076536E-04
     +,   1.3226637E-04,   1.3380808E-04,   1.3539183E-04
     +,   1.3701936E-04,   1.3869262E-04,   1.4041405E-04
     +,   1.4218628E-04,   1.4401272E-04,   1.4589734E-04
     +,   1.4784453E-04,   1.4985968E-04,   1.5194895E-04
     +,   1.5411960E-04,   1.5637970E-04,   1.5873906E-04
     +,   1.6120846E-04,   1.6380055E-04,   1.6652947E-04
     +,   1.6941177E-04,   1.7246626E-04,   1.7571413E-04
     +,   1.7917974E-04,   1.8289097E-04,   1.8687986E-04
     +,   1.9118264E-04,   1.9584082E-04,   2.0090207E-04
     +,   2.0642110E-04,   2.1245982E-04,   2.1908946E-04
     +,   2.2639093E-04,   2.3445593E-04,   2.4338777E-04
     +,   2.5330315E-04,   2.6433231E-04,   2.7661881E-04
     +,   2.9031956E-04,   3.0560564E-04,   3.2265965E-04
     +,   3.4167193E-04,   3.6283818E-04,   3.8635559E-04
     +,   4.1241603E-04,   4.4119541E-04,   4.7285066E-04
     +,   5.0750765E-04,   5.4524967E-04,   5.8610953E-04
     +,   6.3006434E-04,   6.7702855E-04,   7.2684698E-04
     +,   7.7929714E-04,   8.3410437E-04,   8.9094450E-04
     +,   9.4946037E-04,   1.0092895E-03,   1.0700931E-03
     +,   1.1315816E-03,   1.1935433E-03,   1.2558759E-03
     +,   1.3186097E-03,   1.3819129E-03,   1.4460965E-03
     +,   1.5116083E-03,   1.5790015E-03,   1.6488925E-03
     +,   1.7219140E-03,   1.7986671E-03,   1.8796588E-03
     +,   1.9652434E-03,   2.0555884E-03,   2.1506527E-03
     +,   2.2501773E-03,   2.3536845E-03,   2.4605417E-03
     +,   2.5700165E-03,   2.6813527E-03,   2.7938958E-03
     +,   2.9072280E-03,   3.0212977E-03,   3.1365652E-03
     +,   3.2541442E-03,   3.3759316E-03,   3.5046691E-03
     +,   3.6439390E-03,   3.7980354E-03,   3.9716759E-03
     +,   4.1694562E-03,   4.3950817E-03,   4.6505779E-03
     +,   4.9355882E-03,   5.2471068E-03,   5.5800052E-03
     +,   5.9285900E-03,   6.2889992E-03,   6.6622533E-03
     +,   7.0571029E-03,   7.4913208E-03,   7.9896189E-03
     +,   8.5771112E-03,   9.2692059E-03,   1.0062132E-02
     +,   1.0930241E-02,   1.1835133E-02,   1.2745111E-02
     +,   1.3654908E-02,   1.4592430E-02,   1.5605229E-02
     +,   1.6732238E-02,   1.7977573E-02,   1.9303001E-02
     +,   2.0640377E-02,   2.1911271E-02,   2.3041571E-02
     +,   2.3974301E-02,   2.4691131E-02,   2.5239613E-02
     +,   2.5738848E-02,   2.6333479E-02,   2.7102113E-02
     +,   2.7977198E-02,   2.8736206E-02,   2.9073911E-02
     +,   2.8718339E-02,   2.7537014E-02,   2.5590336E-02
     +,   2.3106476E-02,   2.0391738E-02,   1.7723465E-02
     +,   1.5278867E-02,   1.3121375E-02,   1.1236157E-02
     +,   9.5806886E-03,   8.1214113E-03,   6.8424577E-03
     +,   5.7366211E-03,   4.7933576E-03,   3.9952709E-03
     +,   3.3213915E-03,   2.7526834E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt116 = Yx/0.206266666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3747956E-05,   2.4033296E-05
     +,   2.4314737E-05,   2.4592153E-05,   2.4865429E-05
     +,   2.5134474E-05,   2.5399206E-05,   2.5659552E-05
     +,   2.5915466E-05,   2.6166907E-05,   2.6413862E-05
     +,   2.6656324E-05,   2.6894313E-05,   2.7127873E-05
     +,   2.7357049E-05,   2.7581931E-05,   2.7802609E-05
     +,   2.8019218E-05,   2.8231898E-05,   2.8440829E-05
     +,   2.8646191E-05,   2.8848226E-05,   2.9047162E-05
     +,   2.9243287E-05,   2.9436898E-05,   2.9628320E-05
     +,   2.9817920E-05,   3.0006080E-05,   3.0193210E-05
     +,   3.0379766E-05,   3.0566214E-05,   3.0753072E-05
     +,   3.0940857E-05,   3.1130148E-05,   3.1321539E-05
     +,   3.1515658E-05,   3.1713160E-05,   3.1914729E-05
     +,   3.2121105E-05,   3.2333013E-05,   3.2551241E-05
     +,   3.2776603E-05,   3.3009932E-05,   3.3252101E-05
     +,   3.3503988E-05,   3.3766530E-05,   3.4040662E-05
     +,   3.4327364E-05,   3.4627625E-05,   3.4942474E-05
     +,   3.5272933E-05,   3.5620080E-05,   3.5984976E-05
     +,   3.6368725E-05,   3.6772428E-05,   3.7197220E-05
     +,   3.7644211E-05,   3.8114544E-05,   3.8609356E-05
     +,   3.9129791E-05,   3.9676997E-05,   4.0252104E-05
     +,   4.0856215E-05,   4.1490472E-05,   4.2155989E-05
     +,   4.2853801E-05,   4.3585016E-05,   4.4350611E-05
     +,   4.5151639E-05,   4.5989014E-05,   4.6863704E-05
     +,   4.7776542E-05,   4.8728412E-05,   4.9720038E-05
     +,   5.0752165E-05,   5.1825515E-05,   5.2940632E-05
     +,   5.4098018E-05,   5.5298198E-05,   5.6541576E-05
     +,   5.7828434E-05,   5.9159047E-05,   6.0533548E-05
     +,   6.1952072E-05,   6.3414569E-05,   6.4921071E-05
     +,   6.6471308E-05,   6.8065179E-05,   6.9702270E-05
     +,   7.1382252E-05,   7.3104733E-05,   7.4869189E-05
     +,   7.6674914E-05,   7.8521356E-05,   8.0407845E-05
     +,   8.2333499E-05,   8.4297608E-05,   8.6299158E-05
     +,   8.8337343E-05,   9.0411042E-05,   9.2519345E-05
     +,   9.4661009E-05,   9.6835050E-05,   9.9040109E-05
     +,   1.0127498E-04,   1.0353839E-04,   1.0582887E-04
     +,   1.0814489E-04,   1.1048493E-04,   1.1284737E-04
     +,   1.1523034E-04,   1.1763207E-04,   1.2005035E-04
     +,   1.2248316E-04,   1.2492803E-04,   1.2738258E-04
     +,   1.2984389E-04,   1.3230927E-04,   1.3477537E-04
     +,   1.3723894E-04,   1.3969638E-04,   1.4214378E-04
     +,   1.4457694E-04,   1.4699157E-04,   1.4938299E-04
     +,   1.5174625E-04,   1.5407620E-04,   1.5636739E-04
     +,   1.5861425E-04,   1.6081076E-04,   1.6295104E-04
     +,   1.6502880E-04,   1.6703772E-04,   1.6897135E-04
     +,   1.7082324E-04,   1.7258697E-04,   1.7425614E-04
     +,   1.7582429E-04,   1.7728534E-04,   1.7863343E-04
     +,   1.7986284E-04,   1.8096821E-04,   1.8194471E-04
     +,   1.8278780E-04,   1.8349355E-04,   1.8405865E-04
     +,   1.8448022E-04,   1.8475624E-04,   1.8488540E-04
     +,   1.8486705E-04,   1.8470157E-04,   1.8438982E-04
     +,   1.8393376E-04,   1.8333631E-04,   1.8260104E-04
     +,   1.8173258E-04,   1.8073642E-04,   1.7961902E-04
     +,   1.7838768E-04,   1.7705062E-04,   1.7561695E-04
     +,   1.7409658E-04,   1.7250044E-04,   1.7084018E-04
     +,   1.6912830E-04,   1.6737801E-04,   1.6560346E-04
     +,   1.6381961E-04,   1.6204205E-04,   1.6028724E-04
     +,   1.5857237E-04,   1.5691547E-04,   1.5533532E-04
     +,   1.5385138E-04,   1.5248411E-04,   1.5125445E-04
     +,   1.5018437E-04,   1.4929655E-04,   1.4861437E-04
     +,   1.4816207E-04,   1.4796447E-04,   1.4804714E-04
     +,   1.4843610E-04,   1.4915803E-04,   1.5024003E-04
     +,   1.5170942E-04,   1.5359382E-04,   1.5592085E-04
     +,   1.5871842E-04,   1.6201401E-04,   1.6583528E-04
     +,   1.7020977E-04,   1.7516484E-04,   1.8072767E-04
     +,   1.8692616E-04,   1.9378870E-04,   2.0134432E-04
     +,   2.0962312E-04,   2.1865798E-04,   2.2848390E-04
     +,   2.3913897E-04,   2.5066498E-04,   2.6310855E-04
     +,   2.7652230E-04,   2.9096272E-04,   3.0649421E-04
     +,   3.2318689E-04,   3.4111657E-04,   3.6036462E-04
     +,   3.8101809E-04,   4.0316844E-04,   4.2690701E-04
     +,   4.5232492E-04,   4.7951218E-04,   5.0855265E-04
     +,   5.3952058E-04,   5.7247950E-04,   6.0748227E-04
     +,   6.4457179E-04,   6.8377791E-04,   7.2513154E-04
     +,   7.6866749E-04,   8.1443577E-04,   8.6251349E-04
     +,   9.1302674E-04,   9.6615672E-04,   1.0221503E-03
     +,   1.0813264E-03,   1.1440796E-03,   1.2108699E-03
     +,   1.2821987E-03,   1.3585930E-03,   1.4405819E-03
     +,   1.5286689E-03,   1.6232969E-03,   1.7248517E-03
     +,   1.8336535E-03,   1.9499533E-03,   2.0739625E-03
     +,   2.2059001E-03,   2.3460323E-03,   2.4947147E-03
     +,   2.6524691E-03,   2.8200441E-03,   2.9984536E-03
     +,   3.1889721E-03,   3.3930962E-03,   3.6124168E-03
     +,   3.8483983E-03,   4.1020429E-03,   4.3736426E-03
     +,   4.6625966E-03,   4.9675116E-03,   5.2869529E-03
     +,   5.6206924E-03,   5.9714057E-03,   6.3462020E-03
     +,   6.7572151E-03,   7.2203362E-03,   7.7516069E-03
     +,   8.3617019E-03,   9.0501495E-03,   9.8019782E-03
     +,   1.0589739E-02,   1.1382784E-02,   1.2161671E-02
     +,   1.2929271E-02,   1.3709264E-02,   1.4528049E-02
     +,   1.5388643E-02,   1.6255410E-02,   1.7067911E-02
     +,   1.7783707E-02,   1.8422745E-02,   1.9071814E-02
     +,   1.9833930E-02,   2.0760052E-02,   2.1821534E-02
     +,   2.2945015E-02,   2.4069546E-02,   2.5171947E-02
     +,   2.6241392E-02,   2.7236244E-02,   2.8063148E-02
     +,   2.8591806E-02,   2.8691288E-02,   2.8270738E-02
     +,   2.7304336E-02,   2.5823716E-02,   2.3890635E-02
     +,   2.1587480E-02,   1.9031096E-02,   1.6379276E-02
     +,   1.3803350E-02,   1.1446364E-02,   9.3955453E-03
     +,   7.6827025E-03,   6.2986305E-03,   5.2091377E-03
     +,   4.3659485E-03,   3.7151868E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt117 = Yx/0.204244444444444
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.6875881E-05,   5.8339789E-05
     +,   5.9816812E-05,   6.1305422E-05,   6.2804058E-05
     +,   6.4311032E-05,   6.5824635E-05,   6.7343055E-05
     +,   6.8864370E-05,   7.0386755E-05,   7.1908253E-05
     +,   7.3426803E-05,   7.4940428E-05,   7.6447061E-05
     +,   7.7944671E-05,   7.9431178E-05,   8.0904574E-05
     +,   8.2362822E-05,   8.3803978E-05,   8.5226071E-05
     +,   8.6627224E-05,   8.8005676E-05,   8.9359615E-05
     +,   9.0687499E-05,   9.1987691E-05,   9.3258888E-05
     +,   9.4499708E-05,   9.5709038E-05,   9.6885793E-05
     +,   9.8029159E-05,   9.9138415E-05,   1.0021296E-04
     +,   1.0125247E-04,   1.0225672E-04,   1.0322567E-04
     +,   1.0415945E-04,   1.0505843E-04,   1.0592305E-04
     +,   1.0675401E-04,   1.0755216E-04,   1.0831853E-04
     +,   1.0905424E-04,   1.0976066E-04,   1.1043924E-04
     +,   1.1109155E-04,   1.1171932E-04,   1.1232436E-04
     +,   1.1290860E-04,   1.1347399E-04,   1.1402258E-04
     +,   1.1455646E-04,   1.1507771E-04,   1.1558846E-04
     +,   1.1609079E-04,   1.1658678E-04,   1.1707840E-04
     +,   1.1756759E-04,   1.1805620E-04,   1.1854594E-04
     +,   1.1903841E-04,   1.1953503E-04,   1.2003713E-04
     +,   1.2054578E-04,   1.2106189E-04,   1.2158616E-04
     +,   1.2211909E-04,   1.2266089E-04,   1.2321162E-04
     +,   1.2377107E-04,   1.2433869E-04,   1.2491383E-04
     +,   1.2549548E-04,   1.2608251E-04,   1.2667339E-04
     +,   1.2726644E-04,   1.2785981E-04,   1.2845133E-04
     +,   1.2903860E-04,   1.2961925E-04,   1.3019056E-04
     +,   1.3074967E-04,   1.3129368E-04,   1.3181943E-04
     +,   1.3232385E-04,   1.3280372E-04,   1.3325583E-04
     +,   1.3367683E-04,   1.3406358E-04,   1.3441284E-04
     +,   1.3472156E-04,   1.3498669E-04,   1.3520532E-04
     +,   1.3537474E-04,   1.3549243E-04,   1.3555602E-04
     +,   1.3556337E-04,   1.3551266E-04,   1.3540227E-04
     +,   1.3523090E-04,   1.3499764E-04,   1.3470172E-04
     +,   1.3434286E-04,   1.3392119E-04,   1.3343709E-04
     +,   1.3289136E-04,   1.3228520E-04,   1.3162024E-04
     +,   1.3089845E-04,   1.3012224E-04,   1.2929439E-04
     +,   1.2841818E-04,   1.2749714E-04,   1.2653535E-04
     +,   1.2553720E-04,   1.2450754E-04,   1.2345149E-04
     +,   1.2237467E-04,   1.2128294E-04,   1.2018257E-04
     +,   1.1908026E-04,   1.1798280E-04,   1.1689751E-04
     +,   1.1583198E-04,   1.1479390E-04,   1.1379139E-04
     +,   1.1283274E-04,   1.1192640E-04,   1.1108117E-04
     +,   1.1030574E-04,   1.0960918E-04,   1.0900052E-04
     +,   1.0848889E-04,   1.0808341E-04,   1.0779320E-04
     +,   1.0762732E-04,   1.0759471E-04,   1.0770414E-04
     +,   1.0796414E-04,   1.0838298E-04,   1.0896860E-04
     +,   1.0972857E-04,   1.1066983E-04,   1.1179899E-04
     +,   1.1312193E-04,   1.1464382E-04,   1.1636913E-04
     +,   1.1830158E-04,   1.2044387E-04,   1.2279765E-04
     +,   1.2536380E-04,   1.2814201E-04,   1.3113087E-04
     +,   1.3432748E-04,   1.3772814E-04,   1.4132790E-04
     +,   1.4512026E-04,   1.4909757E-04,   1.5325101E-04
     +,   1.5757073E-04,   1.6204525E-04,   1.6666239E-04
     +,   1.7140892E-04,   1.7627038E-04,   1.8123159E-04
     +,   1.8627680E-04,   1.9138984E-04,   1.9655397E-04
     +,   2.0175191E-04,   2.0696709E-04,   2.1218305E-04
     +,   2.1738331E-04,   2.2255226E-04,   2.2767571E-04
     +,   2.3274057E-04,   2.3773461E-04,   2.4264834E-04
     +,   2.4747432E-04,   2.5220698E-04,   2.5684384E-04
     +,   2.6138566E-04,   2.6583674E-04,   2.7020465E-04
     +,   2.7450122E-04,   2.7874298E-04,   2.8295116E-04
     +,   2.8715155E-04,   2.9137527E-04,   2.9565932E-04
     +,   3.0004617E-04,   3.0458395E-04,   3.0932721E-04
     +,   3.1433589E-04,   3.1967604E-04,   3.2541904E-04
     +,   3.3164173E-04,   3.3842577E-04,   3.4585645E-04
     +,   3.5402208E-04,   3.6301362E-04,   3.7292257E-04
     +,   3.8383898E-04,   3.9585060E-04,   4.0904185E-04
     +,   4.2349118E-04,   4.3926816E-04,   4.5643450E-04
     +,   4.7504235E-04,   4.9513218E-04,   5.1673345E-04
     +,   5.3986785E-04,   5.6455063E-04,   5.9079030E-04
     +,   6.1859569E-04,   6.4798375E-04,   6.7898241E-04
     +,   7.1163528E-04,   7.4601203E-04,   7.8221416E-04
     +,   8.2038075E-04,   8.6068799E-04,   9.0335781E-04
     +,   9.4865490E-04,   9.9688058E-04,   1.0483721E-03
     +,   1.1034947E-03,   1.1626328E-03,   1.2261783E-03
     +,   1.2945210E-03,   1.3680534E-03,   1.4471634E-03
     +,   1.5322416E-03,   1.6236962E-03,   1.7219835E-03
     +,   1.8276311E-03,   1.9412482E-03,   2.0635505E-03
     +,   2.1953390E-03,   2.3374292E-03,   2.4905568E-03
     +,   2.6552456E-03,   2.8316299E-03,   3.0192735E-03
     +,   3.2170853E-03,   3.4233290E-03,   3.6357902E-03
     +,   3.8521001E-03,   4.0702610E-03,   4.2892136E-03
     +,   4.5093293E-03,   4.7325799E-03,   4.9623461E-03
     +,   5.2026291E-03,   5.4568825E-03,   5.7267556E-03
     +,   6.0114921E-03,   6.3083270E-03,   6.6143312E-03
     +,   6.9292462E-03,   7.2581521E-03,   7.6122158E-03
     +,   8.0063473E-03,   8.4539056E-03,   8.9605013E-03
     +,   9.5201293E-03,   1.0116694E-02,   1.0731816E-02
     +,   1.1355049E-02,   1.1990950E-02,   1.2657161E-02
     +,   1.3371790E-02,   1.4135985E-02,   1.4923264E-02
     +,   1.5687035E-02,   1.6387902E-02,   1.7028078E-02
     +,   1.7671918E-02,   1.8435182E-02,   1.9442642E-02
     +,   2.0771941E-02,   2.2411229E-02,   2.4250574E-02
     +,   2.6106896E-02,   2.7767962E-02,   2.9038575E-02
     +,   2.9786289E-02,   2.9975802E-02,   2.9674182E-02
     +,   2.9013069E-02,   2.8121319E-02,   2.7068125E-02
     +,   2.5848422E-02,   2.4412528E-02,   2.2718504E-02
     +,   2.0776028E-02,   1.8659914E-02,   1.6487144E-02
     +,   1.4376367E-02,   1.2414286E-02,   1.0644736E-02
     +,   9.0761250E-03,   7.6965070E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt118 = Yx/0.223533333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt1188(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5268356E-05,   4.6668374E-05
     +,   4.8076810E-05,   4.9491493E-05,   5.0910185E-05
     +,   5.2330564E-05,   5.3750267E-05,   5.5166875E-05
     +,   5.6577890E-05,   5.7980873E-05,   5.9373288E-05
     +,   6.0752609E-05,   6.2116284E-05,   6.3461841E-05
     +,   6.4786749E-05,   6.6088571E-05,   6.7364868E-05
     +,   6.8613270E-05,   6.9831527E-05,   7.1017377E-05
     +,   7.2168688E-05,   7.3283445E-05,   7.4359668E-05
     +,   7.5395605E-05,   7.6389493E-05,   7.7339813E-05
     +,   7.8245117E-05,   7.9104124E-05,   7.9915684E-05
     +,   8.0678808E-05,   8.1392674E-05,   8.2056598E-05
     +,   8.2670085E-05,   8.3232750E-05,   8.3744402E-05
     +,   8.4205014E-05,   8.4614701E-05,   8.4973726E-05
     +,   8.5282511E-05,   8.5541615E-05,   8.5751752E-05
     +,   8.5913751E-05,   8.6028573E-05,   8.6097294E-05
     +,   8.6121123E-05,   8.6101332E-05,   8.6039319E-05
     +,   8.5936554E-05,   8.5794592E-05,   8.5615029E-05
     +,   8.5399566E-05,   8.5149906E-05,   8.4867839E-05
     +,   8.4555126E-05,   8.4213585E-05,   8.3845072E-05
     +,   8.3451407E-05,   8.3034436E-05,   8.2595980E-05
     +,   8.2137900E-05,   8.1661914E-05,   8.1169906E-05
     +,   8.0663602E-05,   8.0144724E-05,   7.9614954E-05
     +,   7.9075995E-05,   7.8529491E-05,   7.7977056E-05
     +,   7.7420293E-05,   7.6860757E-05,   7.6299977E-05
     +,   7.5739576E-05,   7.5180986E-05,   7.4625787E-05
     +,   7.4075528E-05,   7.3531744E-05,   7.2996016E-05
     +,   7.2470000E-05,   7.1955314E-05,   7.1453767E-05
     +,   7.0967108E-05,   7.0497219E-05,   7.0046153E-05
     +,   6.9615977E-05,   6.9208967E-05,   6.8827452E-05
     +,   6.8473993E-05,   6.8151334E-05,   6.7862304E-05
     +,   6.7610039E-05,   6.7397799E-05,   6.7229099E-05
     +,   6.7107663E-05,   6.7037457E-05,   6.7022629E-05
     +,   6.7067624E-05,   6.7177061E-05,   6.7355810E-05
     +,   6.7608933E-05,   6.7941655E-05,   6.8359455E-05
     +,   6.8867877E-05,   6.9472662E-05,   7.0179543E-05
     +,   7.0994363E-05,   7.1922994E-05,   7.2971168E-05
     +,   7.4144511E-05,   7.5448537E-05,   7.6888515E-05
     +,   7.8469260E-05,   8.0195423E-05,   8.2070910E-05
     +,   8.4099323E-05,   8.6283391E-05,   8.8625318E-05
     +,   9.1126261E-05,   9.3786781E-05,   9.6606062E-05
     +,   9.9582532E-05,   1.0271352E-04,   1.0599491E-04
     +,   1.0942141E-04,   1.1298653E-04,   1.1668260E-04
     +,   1.2050015E-04,   1.2442897E-04,   1.2845694E-04
     +,   1.3257124E-04,   1.3675717E-04,   1.4099955E-04
     +,   1.4528142E-04,   1.4958554E-04,   1.5389326E-04
     +,   1.5818542E-04,   1.6244258E-04,   1.6664452E-04
     +,   1.7077087E-04,   1.7480145E-04,   1.7871647E-04
     +,   1.8249605E-04,   1.8612128E-04,   1.8957410E-04
     +,   1.9283760E-04,   1.9589587E-04,   1.9873478E-04
     +,   2.0134174E-04,   2.0370618E-04,   2.0581917E-04
     +,   2.0767444E-04,   2.0926766E-04,   2.1059693E-04
     +,   2.1166276E-04,   2.1246840E-04,   2.1301940E-04
     +,   2.1332377E-04,   2.1339212E-04,   2.1323746E-04
     +,   2.1287511E-04,   2.1232254E-04,   2.1159946E-04
     +,   2.1072733E-04,   2.0972961E-04,   2.0863116E-04
     +,   2.0745838E-04,   2.0623872E-04,   2.0500080E-04
     +,   2.0377402E-04,   2.0258798E-04,   2.0147303E-04
     +,   2.0045941E-04,   1.9957745E-04,   1.9885713E-04
     +,   1.9832767E-04,   1.9801810E-04,   1.9795624E-04
     +,   1.9816901E-04,   1.9868230E-04,   1.9952033E-04
     +,   2.0070627E-04,   2.0226155E-04,   2.0420585E-04
     +,   2.0655715E-04,   2.0933157E-04,   2.1254357E-04
     +,   2.1620534E-04,   2.2032716E-04,   2.2491766E-04
     +,   2.2998377E-04,   2.3553037E-04,   2.4156133E-04
     +,   2.4807965E-04,   2.5508748E-04,   2.6258655E-04
     +,   2.7058015E-04,   2.7907299E-04,   2.8807210E-04
     +,   2.9758801E-04,   3.0763721E-04,   3.1824256E-04
     +,   3.2943478E-04,   3.4125353E-04,   3.5375063E-04
     +,   3.6699095E-04,   3.8105124E-04,   3.9602493E-04
     +,   4.1202153E-04,   4.2916572E-04,   4.4759928E-04
     +,   4.6748144E-04,   4.8898865E-04,   5.1231164E-04
     +,   5.3765654E-04,   5.6524441E-04,   5.9530861E-04
     +,   6.2809134E-04,   6.6384079E-04,   7.0281059E-04
     +,   7.4525701E-04,   7.9142652E-04,   8.4156264E-04
     +,   8.9590054E-04,   9.5466268E-04,   1.0180626E-03
     +,   1.0863134E-03,   1.1596340E-03,   1.2382519E-03
     +,   1.3224148E-03,   1.4124049E-03,   1.5085340E-03
     +,   1.6111290E-03,   1.7205183E-03,   1.8370156E-03
     +,   1.9608783E-03,   2.0922583E-03,   2.2312033E-03
     +,   2.3776228E-03,   2.5312896E-03,   2.6918659E-03
     +,   2.8589505E-03,   3.0321255E-03,   3.2109569E-03
     +,   3.3950217E-03,   3.5838722E-03,   3.7769380E-03
     +,   3.9733946E-03,   4.1720341E-03,   4.3712221E-03
     +,   4.5689279E-03,   4.7629564E-03,   4.9514705E-03
     +,   5.1336419E-03,   5.3104698E-03,   5.4855417E-03
     +,   5.6656562E-03,   5.8610667E-03,   6.0853348E-03
     +,   6.3545909E-03,   6.6860812E-03,   7.0956703E-03
     +,   7.5942730E-03,   8.1839766E-03,   8.8549955E-03
     +,   9.5852418E-03,   1.0343505E-02,   1.1095678E-02
     +,   1.1810993E-02,   1.2466113E-02,   1.3047568E-02
     +,   1.3555618E-02,   1.4010997E-02,   1.4459879E-02
     +,   1.4967172E-02,   1.5593966E-02,   1.6369313E-02
     +,   1.7276937E-02,   1.8268900E-02,   1.9294832E-02
     +,   2.0324394E-02,   2.1352248E-02,   2.2395555E-02
     +,   2.3490565E-02,   2.4679692E-02,   2.5972769E-02
     +,   2.7293975E-02,   2.8456891E-02,   2.9213898E-02
     +,   2.9372299E-02,   2.8898397E-02,   2.7918339E-02
     +,   2.6609719E-02,   2.5082933E-02,   2.3353625E-02
     +,   2.1405479E-02,   1.9262271E-02,   1.7006017E-02
     +,   1.4749369E-02,   1.2599641E-02,   1.0638809E-02
     +,   8.9157820E-03,   7.4468395E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt1188 = Yx/0.219022222222222
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9323844E-05,   4.0432180E-05
     +,   4.1562271E-05,   4.2713953E-05,   4.3887012E-05
     +,   4.5081197E-05,   4.6296234E-05,   4.7531787E-05
     +,   4.8787464E-05,   5.0062885E-05,   5.1357594E-05
     +,   5.2671079E-05,   5.4002805E-05,   5.5352197E-05
     +,   5.6718596E-05,   5.8101348E-05,   5.9499707E-05
     +,   6.0912935E-05,   6.2340216E-05,   6.3780695E-05
     +,   6.5233435E-05,   6.6697510E-05,   6.8171939E-05
     +,   6.9655718E-05,   7.1147697E-05,   7.2646821E-05
     +,   7.4151911E-05,   7.5661752E-05,   7.7175129E-05
     +,   7.8690755E-05,   8.0207326E-05,   8.1723498E-05
     +,   8.3237901E-05,   8.4749117E-05,   8.6255735E-05
     +,   8.7756271E-05,   8.9249297E-05,   9.0733243E-05
     +,   9.2206690E-05,   9.3668037E-05,   9.5115793E-05
     +,   9.6548392E-05,   9.7964345E-05,   9.9362071E-05
     +,   1.0074005E-04,   1.0209678E-04,   1.0343074E-04
     +,   1.0474047E-04,   1.0602448E-04,   1.0728138E-04
     +,   1.0850976E-04,   1.0970830E-04,   1.1087564E-04
     +,   1.1201060E-04,   1.1311191E-04,   1.1417849E-04
     +,   1.1520924E-04,   1.1620318E-04,   1.1715935E-04
     +,   1.1807694E-04,   1.1895518E-04,   1.1979340E-04
     +,   1.2059100E-04,   1.2134750E-04,   1.2206256E-04
     +,   1.2273586E-04,   1.2336725E-04,   1.2395660E-04
     +,   1.2450403E-04,   1.2500962E-04,   1.2547370E-04
     +,   1.2589655E-04,   1.2627877E-04,   1.2662081E-04
     +,   1.2692346E-04,   1.2718749E-04,   1.2741382E-04
     +,   1.2760342E-04,   1.2775742E-04,   1.2787699E-04
     +,   1.2796340E-04,   1.2801806E-04,   1.2804236E-04
     +,   1.2803779E-04,   1.2800592E-04,   1.2794838E-04
     +,   1.2786681E-04,   1.2776295E-04,   1.2763844E-04
     +,   1.2749515E-04,   1.2733479E-04,   1.2715909E-04
     +,   1.2696990E-04,   1.2676892E-04,   1.2655786E-04
     +,   1.2633843E-04,   1.2611233E-04,   1.2588112E-04
     +,   1.2564637E-04,   1.2540956E-04,   1.2517213E-04
     +,   1.2493540E-04,   1.2470061E-04,   1.2446892E-04
     +,   1.2424143E-04,   1.2401900E-04,   1.2380263E-04
     +,   1.2359297E-04,   1.2339065E-04,   1.2319622E-04
     +,   1.2301009E-04,   1.2283251E-04,   1.2266371E-04
     +,   1.2250371E-04,   1.2235252E-04,   1.2220994E-04
     +,   1.2207575E-04,   1.2194959E-04,   1.2183105E-04
     +,   1.2171963E-04,   1.2161478E-04,   1.2151582E-04
     +,   1.2142205E-04,   1.2133279E-04,   1.2124726E-04
     +,   1.2116472E-04,   1.2108443E-04,   1.2100560E-04
     +,   1.2092756E-04,   1.2084965E-04,   1.2077130E-04
     +,   1.2069200E-04,   1.2061140E-04,   1.2052914E-04
     +,   1.2044519E-04,   1.2035960E-04,   1.2027255E-04
     +,   1.2018465E-04,   1.2009646E-04,   1.2000911E-04
     +,   1.1992382E-04,   1.1984231E-04,   1.1976656E-04
     +,   1.1969906E-04,   1.1964282E-04,   1.1960133E-04
     +,   1.1957862E-04,   1.1957958E-04,   1.1960966E-04
     +,   1.1967533E-04,   1.1978394E-04,   1.1994394E-04
     +,   1.2016486E-04,   1.2045782E-04,   1.2083515E-04
     +,   1.2131104E-04,   1.2190129E-04,   1.2262391E-04
     +,   1.2349899E-04,   1.2454887E-04,   1.2579845E-04
     +,   1.2727547E-04,   1.2901028E-04,   1.3103624E-04
     +,   1.3338985E-04,   1.3611058E-04,   1.3924105E-04
     +,   1.4282667E-04,   1.4691602E-04,   1.5156022E-04
     +,   1.5681279E-04,   1.6272892E-04,   1.6936559E-04
     +,   1.7678124E-04,   1.8503336E-04,   1.9417993E-04
     +,   2.0427768E-04,   2.1538055E-04,   2.2753931E-04
     +,   2.4080121E-04,   2.5520878E-04,   2.7079761E-04
     +,   2.8759614E-04,   3.0562576E-04,   3.2490020E-04
     +,   3.4542190E-04,   3.6718420E-04,   3.9017067E-04
     +,   4.1435551E-04,   4.3969971E-04,   4.6615623E-04
     +,   4.9366796E-04,   5.2216637E-04,   5.5157428E-04
     +,   5.8180717E-04,   6.1277481E-04,   6.4437767E-04
     +,   6.7651278E-04,   7.0907554E-04,   7.4196130E-04
     +,   7.7506457E-04,   8.0828206E-04,   8.4152003E-04
     +,   8.7469292E-04,   9.0772205E-04,   9.4054773E-04
     +,   9.7312388E-04,   1.0054221E-03,   1.0374336E-03
     +,   1.0691744E-03,   1.1006837E-03,   1.1320257E-03
     +,   1.1632901E-03,   1.1946011E-03,   1.2261141E-03
     +,   1.2580202E-03,   1.2905492E-03,   1.3239788E-03
     +,   1.3586311E-03,   1.3948788E-03,   1.4331464E-03
     +,   1.4739113E-03,   1.5176958E-03,   1.5650629E-03
     +,   1.6166142E-03,   1.6729787E-03,   1.7347992E-03
     +,   1.8027237E-03,   1.8774046E-03,   1.9594883E-03
     +,   2.0496063E-03,   2.1483668E-03,   2.2563706E-03
     +,   2.3741950E-03,   2.5023764E-03,   2.6414248E-03
     +,   2.7918059E-03,   2.9539098E-03,   3.1280469E-03
     +,   3.3144576E-03,   3.5133010E-03,   3.7246374E-03
     +,   3.9484706E-03,   4.1847345E-03,   4.4332426E-03
     +,   4.6935747E-03,   4.9650036E-03,   5.2464502E-03
     +,   5.5365139E-03,   5.8336882E-03,   6.1368267E-03
     +,   6.4456323E-03,   6.7612217E-03,   7.0865462E-03
     +,   7.4265236E-03,   7.7876579E-03,   8.1768157E-03
     +,   8.5994871E-03,   9.0581002E-03,   9.5517635E-03
     +,   1.0078388E-02,   1.0638398E-02,   1.1236752E-02
     +,   1.1879292E-02,   1.2563406E-02,   1.3268786E-02
     +,   1.3958268E-02,   1.4594509E-02,   1.5167158E-02
     +,   1.5711997E-02,   1.6302783E-02,   1.7010463E-02
     +,   1.7848685E-02,   1.8740665E-02,   1.9536074E-02
     +,   2.0077104E-02,   2.0279847E-02,   2.0183533E-02
     +,   1.9939728E-02,   1.9748101E-02,   1.9776514E-02
     +,   2.0105049E-02,   2.0714011E-02,   2.1509044E-02
     +,   2.2358948E-02,   2.3123328E-02,   2.3664473E-02
     +,   2.3854738E-02,   2.3595115E-02,   2.2843705E-02
     +,   2.1635907E-02,   2.0077044E-02,   1.8308884E-02
     +,   1.6467463E-02,   1.4655190E-02,   1.2934656E-02
     +,   1.1339260E-02,   9.8866858E-03,   8.5871918E-03
     +,   7.4443161E-03,   6.4534345E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt120 = Yx/0.220804347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1888720E-04,   1.2277781E-04
     +,   1.2670485E-04,   1.3066480E-04,   1.3465423E-04
     +,   1.3866983E-04,   1.4270857E-04,   1.4676785E-04
     +,   1.5084550E-04,   1.5493984E-04,   1.5904997E-04
     +,   1.6317581E-04,   1.6731810E-04,   1.7147878E-04
     +,   1.7566116E-04,   1.7986978E-04,   1.8411115E-04
     +,   1.8839336E-04,   1.9272677E-04,   1.9712375E-04
     +,   2.0159938E-04,   2.0617111E-04,   2.1085922E-04
     +,   2.1568743E-04,   2.2068164E-04,   2.2587154E-04
     +,   2.3128952E-04,   2.3697133E-04,   2.4295530E-04
     +,   2.4928257E-04,   2.5599668E-04,   2.6314304E-04
     +,   2.7076877E-04,   2.7892194E-04,   2.8765103E-04
     +,   2.9700474E-04,   3.0703063E-04,   3.1777544E-04
     +,   3.2928493E-04,   3.4160173E-04,   3.5476848E-04
     +,   3.6882487E-04,   3.8380970E-04,   3.9976125E-04
     +,   4.1671790E-04,   4.3471876E-04,   4.5380485E-04
     +,   4.7401982E-04,   4.9541099E-04,   5.1802880E-04
     +,   5.4192741E-04,   5.6716404E-04,   5.9379754E-04
     +,   6.2189053E-04,   6.5150362E-04,   6.8270316E-04
     +,   7.1555778E-04,   7.5014733E-04,   7.8657025E-04
     +,   8.2495861E-04,   8.6549489E-04,   9.0843916E-04
     +,   9.5415110E-04,   1.0031277E-03,   1.0560312E-03
     +,   1.1137065E-03,   1.1772092E-03,   1.2477918E-03
     +,   1.3268968E-03,   1.4160952E-03,   1.5170440E-03
     +,   1.6313810E-03,   1.7606666E-03,   1.9062883E-03
     +,   2.0694509E-03,   2.2511766E-03,   2.4523565E-03
     +,   2.6738741E-03,   2.9167365E-03,   3.1821802E-03
     +,   3.4716835E-03,   3.7869983E-03,   4.1299378E-03
     +,   4.5022895E-03,   4.9055354E-03,   5.3408421E-03
     +,   5.8089220E-03,   6.3102487E-03,   6.8449783E-03
     +,   7.4130176E-03,   8.0137076E-03,   8.6452663E-03
     +,   9.3041258E-03,   9.9843945E-03,   1.0677552E-02
     +,   1.1372641E-02,   1.2057080E-02,   1.2717345E-02
     +,   1.3339872E-02,   1.3911054E-02,   1.4417091E-02
     +,   1.4843323E-02,   1.5174286E-02,   1.5394285E-02
     +,   1.5489222E-02,   1.5448747E-02,   1.5268588E-02
     +,   1.4951860E-02,   1.4509167E-02,   1.3957166E-02
     +,   1.3316690E-02,   1.2610261E-02,   1.1860397E-02
     +,   1.1088568E-02,   1.0314647E-02,   9.5566753E-03
     +,   8.8306656E-03,   8.1499116E-03,   7.5244708E-03
     +,   6.9604381E-03,   6.4598001E-03,   6.0208258E-03
     +,   5.6387968E-03,   5.3070802E-03,   5.0183446E-03
     +,   4.7654961E-03,   4.5423009E-03,   4.3437243E-03
     +,   4.1659228E-03,   4.0061004E-03,   3.8622655E-03
     +,   3.7330019E-03,   3.6172627E-03,   3.5142289E-03
     +,   3.4231928E-03,   3.3435056E-03,   3.2745185E-03
     +,   3.2155581E-03,   3.1658905E-03,   3.1247383E-03
     +,   3.0912911E-03,   3.0647146E-03,   3.0441855E-03
     +,   3.0289132E-03,   3.0181555E-03,   3.0112134E-03
     +,   3.0074327E-03,   3.0061710E-03,   3.0067943E-03
     +,   3.0086543E-03,   3.0110646E-03,   3.0133040E-03
     +,   3.0146218E-03,   3.0142441E-03,   3.0114008E-03
     +,   3.0053477E-03,   2.9953946E-03,   2.9809237E-03
     +,   2.9614349E-03,   2.9365567E-03,   2.9060543E-03
     +,   2.8698554E-03,   2.8280495E-03,   2.7808873E-03
     +,   2.7287728E-03,   2.6722394E-03,   2.6119468E-03
     +,   2.5486422E-03,   2.4831390E-03,   2.4162738E-03
     +,   2.3488952E-03,   2.2818164E-03,   2.2157908E-03
     +,   2.1514934E-03,   2.0895009E-03,   2.0302760E-03
     +,   1.9741685E-03,   1.9214036E-03,   1.8721055E-03
     +,   1.8262888E-03,   1.7838830E-03,   1.7447488E-03
     +,   1.7086952E-03,   1.6754922E-03,   1.6448881E-03
     +,   1.6166273E-03,   1.5904608E-03,   1.5661503E-03
     +,   1.5434796E-03,   1.5222557E-03,   1.5023141E-03
     +,   1.4835104E-03,   1.4657311E-03,   1.4488798E-03
     +,   1.4328801E-03,   1.4176687E-03,   1.4032009E-03
     +,   1.3894367E-03,   1.3763476E-03,   1.3639071E-03
     +,   1.3520985E-03,   1.3409059E-03,   1.3303163E-03
     +,   1.3203179E-03,   1.3109016E-03,   1.3020565E-03
     +,   1.2937733E-03,   1.2860371E-03,   1.2788326E-03
     +,   1.2721379E-03,   1.2659247E-03,   1.2601598E-03
     +,   1.2547972E-03,   1.2497865E-03,   1.2450651E-03
     +,   1.2405625E-03,   1.2361999E-03,   1.2318917E-03
     +,   1.2275454E-03,   1.2230701E-03,   1.2183706E-03
     +,   1.2133563E-03,   1.2079419E-03,   1.2020528E-03
     +,   1.1956228E-03,   1.1886008E-03,   1.1809516E-03
     +,   1.1726582E-03,   1.1637171E-03,   1.1541464E-03
     +,   1.1439790E-03,   1.1332643E-03,   1.1220663E-03
     +,   1.1104564E-03,   1.0985199E-03,   1.0863434E-03
     +,   1.0740168E-03,   1.0616318E-03,   1.0492745E-03
     +,   1.0370234E-03,   1.0249513E-03,   1.0131198E-03
     +,   1.0015783E-03,   9.9036249E-04,   9.7949617E-04
     +,   9.6898928E-04,   9.5883937E-04,   9.4903097E-04
     +,   9.3953731E-04,   9.3032350E-04,   9.2134351E-04
     +,   9.1254705E-04,   9.0387661E-04,   8.9527271E-04
     +,   8.8667107E-04,   8.7800861E-04,   8.6922216E-04
     +,   8.6024986E-04,   8.5103256E-04,   8.4151386E-04
     +,   8.3164254E-04,   8.2137232E-04,   8.1066164E-04
     +,   7.9947413E-04,   7.8778161E-04,   7.7556021E-04
     +,   7.6279370E-04,   7.4947183E-04,   7.3559210E-04
     +,   7.2115863E-04,   7.0618035E-04,   6.9067441E-04
     +,   6.7466486E-04,   6.5818016E-04,   6.4125378E-04
     +,   6.2392734E-04,   6.0624408E-04,   5.8825349E-04
     +,   5.7000667E-04,   5.5156002E-04,   5.3296942E-04
     +,   5.1429420E-04,   4.9559324E-04,   4.7692590E-04
     +,   4.5835041E-04,   4.3992433E-04,   4.2170176E-04
     +,   4.0373465E-04,   3.8607250E-04,   3.6875979E-04
     +,   3.5183845E-04,   3.3534414E-04,   3.1931023E-04
     +,   3.0376291E-04,   2.8872615E-04,   2.7421687E-04
     +,   2.6024977E-04,   2.4683276E-04,   2.3397179E-04
     +,   2.2166717E-04,   2.0991711E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt75 = Yx/0.182795454545455
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.9657450E-05,   6.0782346E-05
     +,   6.1923587E-05,   6.3083011E-05,   6.4262604E-05
     +,   6.5464585E-05,   6.6691318E-05,   6.7945395E-05
     +,   6.9229616E-05,   7.0547023E-05,   7.1900824E-05
     +,   7.3294505E-05,   7.4731761E-05,   7.6216566E-05
     +,   7.7753088E-05,   7.9345795E-05,   8.0999438E-05
     +,   8.2718980E-05,   8.4509702E-05,   8.6377171E-05
     +,   8.8327230E-05,   9.0366040E-05,   9.2500035E-05
     +,   9.4736075E-05,   9.7081233E-05,   9.9542973E-05
     +,   1.0212920E-04,   1.0484812E-04,   1.0770834E-04
     +,   1.1071891E-04,   1.1388930E-04,   1.1722953E-04
     +,   1.2074995E-04,   1.2446161E-04,   1.2837583E-04
     +,   1.3250478E-04,   1.3686094E-04,   1.4145744E-04
     +,   1.4630823E-04,   1.5142727E-04,   1.5682979E-04
     +,   1.6253110E-04,   1.6854718E-04,   1.7489462E-04
     +,   1.8159035E-04,   1.8865186E-04,   1.9609713E-04
     +,   2.0394412E-04,   2.1221167E-04,   2.2091829E-04
     +,   2.3008326E-04,   2.3972566E-04,   2.4986462E-04
     +,   2.6052017E-04,   2.7171121E-04,   2.8345783E-04
     +,   2.9577958E-04,   3.0869624E-04,   3.2222780E-04
     +,   3.3639453E-04,   3.5121688E-04,   3.6671679E-04
     +,   3.8291575E-04,   3.9983858E-04,   4.1751238E-04
     +,   4.3596621E-04,   4.5523580E-04,   4.7536107E-04
     +,   4.9639220E-04,   5.1838747E-04,   5.4142071E-04
     +,   5.6557899E-04,   5.9097091E-04,   6.1772554E-04
     +,   6.4600044E-04,   6.7598507E-04,   7.0790190E-04
     +,   7.4201397E-04,   7.7862956E-04,   8.1810605E-04
     +,   8.6084515E-04,   9.0730155E-04,   9.5796888E-04
     +,   1.0133776E-03,   1.0740701E-03,   1.1405889E-03
     +,   1.2134375E-03,   1.2930635E-03,   1.3798121E-03
     +,   1.4739189E-03,   1.5754945E-03,   1.6845292E-03
     +,   1.8009329E-03,   1.9245986E-03,   2.0554950E-03
     +,   2.1937368E-03,   2.3397354E-03,   2.4942143E-03
     +,   2.6583099E-03,   2.8334758E-03,   3.0214335E-03
     +,   3.2239163E-03,   3.4424686E-03,   3.6781083E-03
     +,   3.9311145E-03,   4.2008245E-03,   4.4856020E-03
     +,   4.7830376E-03,   5.0903163E-03,   5.4047052E-03
     +,   5.7240669E-03,   6.0473168E-03,   6.3744951E-03
     +,   6.7065852E-03,   7.0448243E-03,   7.3898314E-03
     +,   7.7405628E-03,   8.0936151E-03,   8.4428154E-03
     +,   8.7796226E-03,   9.0940064E-03,   9.3757305E-03
     +,   9.6157184E-03,   9.8071583E-03,   9.9459365E-03
     +,   1.0030511E-02,   1.0061293E-02,   1.0039711E-02
     +,   9.9675283E-03,   9.8464265E-03,   9.6780583E-03
     +,   9.4645303E-03,   9.2089409E-03,   8.9159412E-03
     +,   8.5919313E-03,   8.2449587E-03,   7.8843553E-03
     +,   7.5201602E-03,   7.1623772E-03,   6.8204873E-03
     +,   6.5028169E-03,   6.2161624E-03,   5.9653278E-03
     +,   5.7529071E-03,   5.5791899E-03,   5.4421644E-03
     +,   5.3378670E-03,   5.2608405E-03,   5.2047749E-03
     +,   5.1631699E-03,   5.1299362E-03,   5.0998405E-03
     +,   5.0687473E-03,   5.0336733E-03,   4.9926438E-03
     +,   4.9444856E-03,   4.8885937E-03,   4.8246966E-03
     +,   4.7527296E-03,   4.6727937E-03,   4.5851786E-03
     +,   4.4903816E-03,   4.3892404E-03,   4.2829178E-03
     +,   4.1728942E-03,   4.0609227E-03,   3.9488701E-03
     +,   3.8385941E-03,   3.7317523E-03,   3.6296644E-03
     +,   3.5332381E-03,   3.4428947E-03,   3.3585897E-03
     +,   3.2798653E-03,   3.2059706E-03,   3.1359401E-03
     +,   3.0687382E-03,   3.0033672E-03,   2.9389367E-03
     +,   2.8747220E-03,   2.8101935E-03,   2.7450237E-03
     +,   2.6790625E-03,   2.6123009E-03,   2.5448452E-03
     +,   2.4768861E-03,   2.4086649E-03,   2.3404539E-03
     +,   2.2725428E-03,   2.2052478E-03,   2.1388864E-03
     +,   2.0737906E-03,   2.0103073E-03,   1.9487902E-03
     +,   1.8895883E-03,   1.8330410E-03,   1.7794685E-03
     +,   1.7291545E-03,   1.6823356E-03,   1.6391912E-03
     +,   1.5998379E-03,   1.5643293E-03,   1.5326493E-03
     +,   1.5047179E-03,   1.4804062E-03,   1.4595380E-03
     +,   1.4419007E-03,   1.4272621E-03,   1.4153772E-03
     +,   1.4059967E-03,   1.3988802E-03,   1.3938022E-03
     +,   1.3905502E-03,   1.3889410E-03,   1.3888055E-03
     +,   1.3900001E-03,   1.3923999E-03,   1.3958970E-03
     +,   1.4003903E-03,   1.4057946E-03,   1.4120202E-03
     +,   1.4189827E-03,   1.4265896E-03,   1.4347433E-03
     +,   1.4433363E-03,   1.4522531E-03,   1.4613689E-03
     +,   1.4705473E-03,   1.4796482E-03,   1.4885287E-03
     +,   1.4970420E-03,   1.5050457E-03,   1.5124028E-03
     +,   1.5189856E-03,   1.5246789E-03,   1.5293790E-03
     +,   1.5330020E-03,   1.5354768E-03,   1.5367520E-03
     +,   1.5367889E-03,   1.5355636E-03,   1.5330667E-03
     +,   1.5292955E-03,   1.5242561E-03,   1.5179565E-03
     +,   1.5104108E-03,   1.5016294E-03,   1.4916235E-03
     +,   1.4803990E-03,   1.4679611E-03,   1.4543115E-03
     +,   1.4394490E-03,   1.4233731E-03,   1.4060840E-03
     +,   1.3875854E-03,   1.3678846E-03,   1.3469979E-03
     +,   1.3249498E-03,   1.3017736E-03,   1.2775159E-03
     +,   1.2522320E-03,   1.2259920E-03,   1.1988736E-03
     +,   1.1709672E-03,   1.1423707E-03,   1.1131892E-03
     +,   1.0835312E-03,   1.0535112E-03,   1.0232454E-03
     +,   9.9284574E-04,   9.6242351E-04,   9.3208591E-04
     +,   9.0193574E-04,   8.7206630E-04,   8.4256392E-04
     +,   8.1350899E-04,   7.8496948E-04,   7.5700897E-04
     +,   7.2967703E-04,   7.0301967E-04,   6.7706982E-04
     +,   6.5185700E-04,   6.2739931E-04,   6.0371181E-04
     +,   5.8080000E-04,   5.5866648E-04,   5.3730689E-04
     +,   5.1671319E-04,   4.9687410E-04,   4.7777369E-04
     +,   4.5939517E-04,   4.4171661E-04,   4.2471735E-04
     +,   4.0837255E-04,   3.9265852E-04,   3.7754854E-04
     +,   3.6301755E-04,   3.4903872E-04,   3.3558678E-04
     +,   3.2263523E-04,   3.1015987E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt80 = Yx/0.162139534883721
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.5870913E-05,   9.8941622E-05
     +,   1.0204799E-04,   1.0518737E-04,   1.0835710E-04
     +,   1.1155439E-04,   1.1477651E-04,   1.1802062E-04
     +,   1.2128396E-04,   1.2456381E-04,   1.2785745E-04
     +,   1.3116215E-04,   1.3447535E-04,   1.3779456E-04
     +,   1.4111729E-04,   1.4444125E-04,   1.4776428E-04
     +,   1.5108436E-04,   1.5439953E-04,   1.5770808E-04
     +,   1.6100834E-04,   1.6429898E-04,   1.6757853E-04
     +,   1.7084603E-04,   1.7410031E-04,   1.7734058E-04
     +,   1.8056607E-04,   1.8377618E-04,   1.8697030E-04
     +,   1.9014793E-04,   1.9330870E-04,   1.9645215E-04
     +,   1.9957790E-04,   2.0268562E-04,   2.0577484E-04
     +,   2.0884507E-04,   2.1189571E-04,   2.1492611E-04
     +,   2.1793570E-04,   2.2092344E-04,   2.2388846E-04
     +,   2.2682975E-04,   2.2974616E-04,   2.3263654E-04
     +,   2.3549955E-04,   2.3833400E-04,   2.4113872E-04
     +,   2.4391252E-04,   2.4665458E-04,   2.4936421E-04
     +,   2.5204095E-04,   2.5468477E-04,   2.5729631E-04
     +,   2.5987669E-04,   2.6242767E-04,   2.6495193E-04
     +,   2.6745294E-04,   2.6993518E-04,   2.7240434E-04
     +,   2.7486723E-04,   2.7733159E-04,   2.7980676E-04
     +,   2.8230323E-04,   2.8483281E-04,   2.8740885E-04
     +,   2.9004540E-04,   2.9275837E-04,   2.9556427E-04
     +,   2.9848111E-04,   3.0152770E-04,   3.0472397E-04
     +,   3.0809047E-04,   3.1164871E-04,   3.1542091E-04
     +,   3.1943026E-04,   3.2370127E-04,   3.2825908E-04
     +,   3.3313033E-04,   3.3834385E-04,   3.4393120E-04
     +,   3.4992592E-04,   3.5636622E-04,   3.6329441E-04
     +,   3.7075879E-04,   3.7881342E-04,   3.8752091E-04
     +,   3.9695058E-04,   4.0718282E-04,   4.1830610E-04
     +,   4.3042013E-04,   4.4363528E-04,   4.5807124E-04
     +,   4.7385771E-04,   4.9113482E-04,   5.1005062E-04
     +,   5.3075951E-04,   5.5342395E-04,   5.7820952E-04
     +,   6.0528796E-04,   6.3483126E-04,   6.6701777E-04
     +,   7.0202199E-04,   7.4002525E-04,   7.8120560E-04
     +,   8.2574482E-04,   8.7382912E-04,   9.2564529E-04
     +,   9.8138675E-04,   1.0412639E-03,   1.1055074E-03
     +,   1.1743708E-03,   1.2481578E-03,   1.3272171E-03
     +,   1.4119757E-03,   1.5029298E-03,   1.6006788E-03
     +,   1.7058981E-03,   1.8193652E-03,   1.9419176E-03
     +,   2.0744444E-03,   2.2178502E-03,   2.3729764E-03
     +,   2.5405462E-03,   2.7210983E-03,   2.9148804E-03
     +,   3.1217495E-03,   3.3411488E-03,   3.5720367E-03
     +,   3.8130020E-03,   4.0623136E-03,   4.3181828E-03
     +,   4.5789485E-03,   4.8433677E-03,   5.1107267E-03
     +,   5.3809434E-03,   5.6544351E-03,   5.9318417E-03
     +,   6.2136534E-03,   6.4998595E-03,   6.7895167E-03
     +,   7.0804893E-03,   7.3692985E-03,   7.6512392E-03
     +,   7.9205139E-03,   8.1705712E-03,   8.3947154E-03
     +,   8.5866265E-03,   8.7410724E-03,   8.8545345E-03
     +,   8.9256288E-03,   8.9552067E-03,   8.9462064E-03
     +,   8.9030098E-03,   8.8306814E-03,   8.7340781E-03
     +,   8.6171934E-03,   8.4826639E-03,   8.3318129E-03
     +,   8.1649125E-03,   7.9818182E-03,   7.7825901E-03
     +,   7.5680651E-03,   7.3402515E-03,   7.1023577E-03
     +,   6.8586040E-03,   6.6137952E-03,   6.3728094E-03
     +,   6.1400076E-03,   5.9187687E-03,   5.7111611E-03
     +,   5.5178436E-03,   5.3381408E-03,   5.1703188E-03
     +,   5.0120098E-03,   4.8607411E-03,   4.7143740E-03
     +,   4.5715361E-03,   4.4318610E-03,   4.2960495E-03
     +,   4.1657151E-03,   4.0431386E-03,   3.9308583E-03
     +,   3.8312727E-03,   3.7462332E-03,   3.6767703E-03
     +,   3.6228900E-03,   3.5835456E-03,   3.5566853E-03
     +,   3.5394498E-03,   3.5283996E-03,   3.5198012E-03
     +,   3.5099234E-03,   3.4953093E-03,   3.4729943E-03
     +,   3.4406867E-03,   3.3968703E-03,   3.3408452E-03
     +,   3.2726997E-03,   3.1932287E-03,   3.1038141E-03
     +,   3.0062736E-03,   2.9027066E-03,   2.7953205E-03
     +,   2.6862915E-03,   2.5776748E-03,   2.4712738E-03
     +,   2.3686176E-03,   2.2709281E-03,   2.1791153E-03
     +,   2.0937969E-03,   2.0153353E-03,   1.9438815E-03
     +,   1.8794147E-03,   1.8217752E-03,   1.7707065E-03
     +,   1.7258840E-03,   1.6869395E-03,   1.6534670E-03
     +,   1.6250398E-03,   1.6012203E-03,   1.5815588E-03
     +,   1.5656012E-03,   1.5528913E-03,   1.5429716E-03
     +,   1.5353920E-03,   1.5297116E-03,   1.5255087E-03
     +,   1.5223811E-03,   1.5199537E-03,   1.5178866E-03
     +,   1.5158743E-03,   1.5136531E-03,   1.5110023E-03
     +,   1.5077401E-03,   1.5037324E-03,   1.4988848E-03
     +,   1.4931422E-03,   1.4864848E-03,   1.4789290E-03
     +,   1.4705212E-03,   1.4613337E-03,   1.4514637E-03
     +,   1.4410297E-03,   1.4301663E-03,   1.4190228E-03
     +,   1.4077593E-03,   1.3965472E-03,   1.3855575E-03
     +,   1.3749652E-03,   1.3649426E-03,   1.3556539E-03
     +,   1.3472509E-03,   1.3398707E-03,   1.3336270E-03
     +,   1.3286085E-03,   1.3248698E-03,   1.3224332E-03
     +,   1.3212783E-03,   1.3213431E-03,   1.3225202E-03
     +,   1.3246570E-03,   1.3275583E-03,   1.3309839E-03
     +,   1.3346599E-03,   1.3382754E-03,   1.3414968E-03
     +,   1.3439758E-03,   1.3453523E-03,   1.3452714E-03
     +,   1.3433892E-03,   1.3393849E-03,   1.3329695E-03
     +,   1.3238963E-03,   1.3119640E-03,   1.2970252E-03
     +,   1.2789916E-03,   1.2578346E-03,   1.2335865E-03
     +,   1.2063363E-03,   1.1762326E-03,   1.1434684E-03
     +,   1.1082881E-03,   1.0709672E-03,   1.0318146E-03
     +,   9.9115609E-04,   9.4933360E-04,   9.0669049E-04
     +,   8.6356455E-04,   8.2028814E-04,   7.7716948E-04
     +,   7.3450099E-04,   6.9254264E-04,   6.5153115E-04
     +,   6.1166496E-04,   5.7311717E-04,   5.3602247E-04
     +,   5.0049013E-04,   4.6659462E-04,   4.3438762E-04
     +,   4.0389164E-04,   3.7511124E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt85 = Yx/0.149604651162791
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.6617835E-05,   4.7757658E-05
     +,   4.8937694E-05,   5.0161318E-05,   5.1432085E-05
     +,   5.2753843E-05,   5.4130658E-05,   5.5566816E-05
     +,   5.7066769E-05,   5.8635331E-05,   6.0277347E-05
     +,   6.1997947E-05,   6.3802356E-05,   6.5696004E-05
     +,   6.7684319E-05,   6.9772927E-05,   7.1967414E-05
     +,   7.4273376E-05,   7.6696386E-05,   7.9241880E-05
     +,   8.1915183E-05,   8.4721367E-05,   8.7665248E-05
     +,   9.0751499E-05,   9.3983937E-05,   9.7366494E-05
     +,   1.0090214E-04,   1.0459342E-04,   1.0844217E-04
     +,   1.1244952E-04,   1.1661573E-04,   1.2094025E-04
     +,   1.2542156E-04,   1.3005716E-04,   1.3484356E-04
     +,   1.3977608E-04,   1.4484898E-04,   1.5005530E-04
     +,   1.5538724E-04,   1.6083526E-04,   1.6638922E-04
     +,   1.7203749E-04,   1.7776740E-04,   1.8356538E-04
     +,   1.8941665E-04,   1.9530547E-04,   2.0121562E-04
     +,   2.0712972E-04,   2.1303019E-04,   2.1889880E-04
     +,   2.2471696E-04,   2.3046628E-04,   2.3612799E-04
     +,   2.4168426E-04,   2.4711710E-04,   2.5240961E-04
     +,   2.5754602E-04,   2.6251140E-04,   2.6729278E-04
     +,   2.7187870E-04,   2.7625990E-04,   2.8042949E-04
     +,   2.8438293E-04,   2.8811916E-04,   2.9164006E-04
     +,   2.9495082E-04,   2.9806065E-04,   3.0098250E-04
     +,   3.0373369E-04,   3.0633592E-04,   3.0881510E-04
     +,   3.1120196E-04,   3.1353193E-04,   3.1584466E-04
     +,   3.1818461E-04,   3.2060069E-04,   3.2314524E-04
     +,   3.2587454E-04,   3.2884820E-04,   3.3212834E-04
     +,   3.3577858E-04,   3.3986426E-04,   3.4445035E-04
     +,   3.4960144E-04,   3.5538009E-04,   3.6184638E-04
     +,   3.6905595E-04,   3.7706009E-04,   3.8590288E-04
     +,   3.9562289E-04,   4.0625059E-04,   4.1780726E-04
     +,   4.3030549E-04,   4.4374968E-04,   4.5813498E-04
     +,   4.7344650E-04,   4.8966322E-04,   5.0675392E-04
     +,   5.2468374E-04,   5.4340932E-04,   5.6288572E-04
     +,   5.8306265E-04,   6.0389045E-04,   6.2531728E-04
     +,   6.4729329E-04,   6.6977239E-04,   6.9271022E-04
     +,   7.1606686E-04,   7.3981186E-04,   7.6392258E-04
     +,   7.8838342E-04,   8.1319566E-04,   8.3837169E-04
     +,   8.6394761E-04,   8.8997668E-04,   9.1654283E-04
     +,   9.4375678E-04,   9.7176671E-04,   1.0007562E-03
     +,   1.0309486E-03,   1.0626059E-03,   1.0960238E-03
     +,   1.1315251E-03,   1.1694512E-03,   1.2101455E-03
     +,   1.2539317E-03,   1.3011011E-03,   1.3518849E-03
     +,   1.4064434E-03,   1.4648485E-03,   1.5270868E-03
     +,   1.5930568E-03,   1.6625996E-03,   1.7355083E-03
     +,   1.8115840E-03,   1.8906557E-03,   1.9726192E-03
     +,   2.0574657E-03,   2.1453153E-03,   2.2364315E-03
     +,   2.3312343E-03,   2.4303326E-03,   2.5345734E-03
     +,   2.6450907E-03,   2.7633687E-03,   2.8913312E-03
     +,   3.0313777E-03,   3.1863779E-03,   3.3595951E-03
     +,   3.5544867E-03,   3.7743649E-03,   4.0218686E-03
     +,   4.2983615E-03,   4.6033016E-03,   4.9336301E-03
     +,   5.2833925E-03,   5.6438474E-03,   6.0040518E-03
     +,   6.3519659E-03,   6.6759605E-03,   6.9665364E-03
     +,   7.2177197E-03,   7.4278703E-03,   7.5996122E-03
     +,   7.7389665E-03,   7.8536123E-03,   7.9509923E-03
     +,   8.0365334E-03,   8.1125302E-03,   8.1778746E-03
     +,   8.2288450E-03,   8.2606422E-03,   8.2694003E-03
     +,   8.2541537E-03,   8.2181748E-03,   8.1693791E-03
     +,   8.1193978E-03,   8.0815013E-03,   8.0676889E-03
     +,   8.0857063E-03,   8.1367437E-03,   8.2144812E-03
     +,   8.3057731E-03,   8.3929989E-03,   8.4572583E-03
     +,   8.4817410E-03,   8.4544653E-03,   8.3697326E-03
     +,   8.2282387E-03,   8.0360677E-03,   7.8029013E-03
     +,   7.5402069E-03,   7.2595677E-03,   6.9715208E-03
     +,   6.6847908E-03,   6.4059440E-03,   6.1393464E-03
     +,   5.8872406E-03,   5.6500160E-03,   5.4266825E-03
     +,   5.2154940E-03,   5.0146012E-03,   4.8226486E-03
     +,   4.6391827E-03,   4.4647590E-03,   4.3007121E-03
     +,   4.1487250E-03,   4.0103160E-03,   3.8863139E-03
     +,   3.7765617E-03,   3.6798108E-03,   3.5938772E-03
     +,   3.5159502E-03,   3.4429375E-03,   3.3718846E-03
     +,   3.3002433E-03,   3.2260772E-03,   3.1481395E-03
     +,   3.0658497E-03,   2.9792171E-03,   2.8887081E-03
     +,   2.7951272E-03,   2.6995048E-03,   2.6029923E-03
     +,   2.5067916E-03,   2.4120992E-03,   2.3200708E-03
     +,   2.2317839E-03,   2.1482017E-03,   2.0701487E-03
     +,   1.9982974E-03,   1.9331434E-03,   1.8749936E-03
     +,   1.8239664E-03,   1.7800110E-03,   1.7429050E-03
     +,   1.7122879E-03,   1.6876847E-03,   1.6685388E-03
     +,   1.6542268E-03,   1.6440958E-03,   1.6374858E-03
     +,   1.6337387E-03,   1.6322230E-03,   1.6323354E-03
     +,   1.6335123E-03,   1.6352336E-03,   1.6370190E-03
     +,   1.6384325E-03,   1.6390814E-03,   1.6386121E-03
     +,   1.6367113E-03,   1.6331056E-03,   1.6275581E-03
     +,   1.6198728E-03,   1.6098927E-03,   1.5975002E-03
     +,   1.5826204E-03,   1.5652158E-03,   1.5452923E-03
     +,   1.5228936E-03,   1.4980992E-03,   1.4710241E-03
     +,   1.4418119E-03,   1.4106332E-03,   1.3776782E-03
     +,   1.3431524E-03,   1.3072740E-03,   1.2702661E-03
     +,   1.2323527E-03,   1.1937545E-03,   1.1546891E-03
     +,   1.1153658E-03,   1.0759810E-03,   1.0367197E-03
     +,   9.9775777E-04,   9.5925154E-04,   9.2134892E-04
     +,   8.8417897E-04,   8.4785908E-04,   8.1248838E-04
     +,   7.7815447E-04,   7.4492692E-04,   7.1286171E-04
     +,   6.8199763E-04,   6.5236120E-04,   6.2396203E-04
     +,   5.9679564E-04,   5.7084713E-04,   5.4608594E-04
     +,   5.2247476E-04,   4.9996359E-04,   4.7849814E-04
     +,   4.5801612E-04,   4.3845366E-04,   4.1974342E-04
     +,   4.0181918E-04,   3.8461489E-04,   3.6806954E-04
     +,   3.5212393E-04,   3.3672614E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt90 = Yx/0.152209302325581
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_htt95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2490486E-05,   5.3230771E-05
     +,   5.3963326E-05,   5.4688328E-05,   5.5406068E-05
     +,   5.6116918E-05,   5.6821365E-05,   5.7519974E-05
     +,   5.8213413E-05,   5.8902511E-05,   5.9588219E-05
     +,   6.0271552E-05,   6.0953756E-05,   6.1636129E-05
     +,   6.2320207E-05,   6.3007668E-05,   6.3700318E-05
     +,   6.4400236E-05,   6.5109598E-05,   6.5830856E-05
     +,   6.6566667E-05,   6.7319896E-05,   6.8093650E-05
     +,   6.8891328E-05,   6.9716487E-05,   7.0573107E-05
     +,   7.1465300E-05,   7.2397546E-05,   7.3374642E-05
     +,   7.4401622E-05,   7.5483877E-05,   7.6627075E-05
     +,   7.7837256E-05,   7.9120691E-05,   8.0484053E-05
     +,   8.1934180E-05,   8.3478328E-05,   8.5123858E-05
     +,   8.6878608E-05,   8.8750276E-05,   9.0747126E-05
     +,   9.2877279E-05,   9.5148978E-05,   9.7570628E-05
     +,   1.0015046E-04,   1.0289672E-04,   1.0581731E-04
     +,   1.0892007E-04,   1.1221232E-04,   1.1570100E-04
     +,   1.1939249E-04,   1.2329253E-04,   1.2740596E-04
     +,   1.3173698E-04,   1.3628836E-04,   1.4106228E-04
     +,   1.4605917E-04,   1.5127844E-04,   1.5671781E-04
     +,   1.6237363E-04,   1.6824031E-04,   1.7431096E-04
     +,   1.8057621E-04,   1.8702538E-04,   1.9364605E-04
     +,   2.0042306E-04,   2.0734042E-04,   2.1437930E-04
     +,   2.2151993E-04,   2.2874006E-04,   2.3601674E-04
     +,   2.4332467E-04,   2.5063829E-04,   2.5792999E-04
     +,   2.6517236E-04,   2.7233711E-04,   2.7939561E-04
     +,   2.8631926E-04,   2.9308037E-04,   2.9965211E-04
     +,   3.0600833E-04,   3.1212522E-04,   3.1798042E-04
     +,   3.2355450E-04,   3.2883056E-04,   3.3379509E-04
     +,   3.3843800E-04,   3.4275366E-04,   3.4673998E-04
     +,   3.5040011E-04,   3.5374163E-04,   3.5677737E-04
     +,   3.5952465E-04,   3.6200695E-04,   3.6425219E-04
     +,   3.6629327E-04,   3.6816869E-04,   3.6992118E-04
     +,   3.7159800E-04,   3.7324993E-04,   3.7493216E-04
     +,   3.7670197E-04,   3.7861944E-04,   3.8074612E-04
     +,   3.8314454E-04,   3.8587712E-04,   3.8900608E-04
     +,   3.9259132E-04,   3.9669126E-04,   4.0136089E-04
     +,   4.0665106E-04,   4.1260821E-04,   4.1927354E-04
     +,   4.2668273E-04,   4.3486455E-04,   4.4384249E-04
     +,   4.5363227E-04,   4.6424419E-04,   4.7568112E-04
     +,   4.8794088E-04,   5.0101615E-04,   5.1489426E-04
     +,   5.2955898E-04,   5.4499210E-04,   5.6117494E-04
     +,   5.7808770E-04,   5.9571431E-04,   6.1403995E-04
     +,   6.3305831E-04,   6.5276795E-04,   6.7317893E-04
     +,   6.9430948E-04,   7.1619480E-04,   7.3888019E-04
     +,   7.6243136E-04,   7.8693021E-04,   8.1247668E-04
     +,   8.3918986E-04,   8.6720986E-04,   8.9669926E-04
     +,   9.2783448E-04,   9.6081273E-04,   9.9584810E-04
     +,   1.0331696E-03,   1.0730128E-03,   1.1156281E-03
     +,   1.1612740E-03,   1.2102121E-03,   1.2627145E-03
     +,   1.3190730E-03,   1.3796018E-03,   1.4446438E-03
     +,   1.5145878E-03,   1.5898821E-03,   1.6710400E-03
     +,   1.7586241E-03,   1.8532337E-03,   1.9554675E-03
     +,   2.0658418E-03,   2.1846851E-03,   2.3120274E-03
     +,   2.4474557E-03,   2.5899790E-03,   2.7379484E-03
     +,   2.8890704E-03,   3.0405002E-03,   3.1890841E-03
     +,   3.3317483E-03,   3.4659929E-03,   3.5903868E-03
     +,   3.7050352E-03,   3.8118847E-03,   3.9148061E-03
     +,   4.0193964E-03,   4.1325162E-03,   4.2616962E-03
     +,   4.4144685E-03,   4.5977375E-03,   4.8174346E-03
     +,   5.0783413E-03,   5.3841653E-03,   5.7376469E-03
     +,   6.1405669E-03,   6.5934160E-03,   7.0945537E-03
     +,   7.6389080E-03,   8.2166409E-03,   8.8124024E-03
     +,   9.4057396E-03,   9.9731591E-03,   1.0491821E-02
     +,   1.0943670E-02,   1.1318537E-02,   1.1615035E-02
     +,   1.1838318E-02,   1.1995759E-02,   1.2092242E-02
     +,   1.2127314E-02,   1.2095697E-02,   1.1990538E-02
     +,   1.1808173E-02,   1.1551932E-02,   1.1233125E-02
     +,   1.0868990E-02,   1.0478526E-02,   1.0078067E-02
     +,   9.6784355E-03,   9.2844032E-03,   8.8962605E-03
     +,   8.5123368E-03,   8.1313802E-03,   7.7538602E-03
     +,   7.3822085E-03,   7.0200847E-03,   6.6715572E-03
     +,   6.3404003E-03,   6.0295500E-03,   5.7409233E-03
     +,   5.4753115E-03,   5.2323793E-03,   5.0106747E-03
     +,   4.8077912E-03,   4.6207071E-03,   4.4461642E-03
     +,   4.2810650E-03,   4.1228156E-03,   3.9695213E-03
     +,   3.8200009E-03,   3.6737141E-03,   3.5306588E-03
     +,   3.3912968E-03,   3.2564863E-03,   3.1274669E-03
     +,   3.0058268E-03,   2.8934742E-03,   2.7924746E-03
     +,   2.7048909E-03,   2.6325569E-03,   2.5768462E-03
     +,   2.5384738E-03,   2.5173915E-03,   2.5127372E-03
     +,   2.5228856E-03,   2.5455654E-03,   2.5780308E-03
     +,   2.6172404E-03,   2.6600582E-03,   2.7034155E-03
     +,   2.7444621E-03,   2.7806528E-03,   2.8098384E-03
     +,   2.8302830E-03,   2.8406875E-03,   2.8401769E-03
     +,   2.8282669E-03,   2.8048377E-03,   2.7700842E-03
     +,   2.7244741E-03,   2.6686981E-03,   2.6036210E-03
     +,   2.5302456E-03,   2.4496682E-03,   2.3630417E-03
     +,   2.2715384E-03,   2.1763423E-03,   2.0786012E-03
     +,   1.9794197E-03,   1.8798532E-03,   1.7808838E-03
     +,   1.6834043E-03,   1.5882192E-03,   1.4960385E-03
     +,   1.4074744E-03,   1.3230158E-03,   1.2430500E-03
     +,   1.1678551E-03,   1.0975937E-03,   1.0323328E-03
     +,   9.7203261E-04,   9.1657531E-04,   8.6576008E-04
     +,   8.1932859E-04,   7.7697006E-04,   7.3834363E-04
     +,   7.0308184E-04,   6.7081692E-04,   6.4117933E-04
     +,   6.1381643E-04,   5.8839796E-04,   5.6461955E-04
     +,   5.4221123E-04,   5.2093557E-04,   5.0059246E-04
     +,   4.8101373E-04,   4.6206571E-04,   4.4364354E-04
     +,   4.2567088E-04,   4.0809324E-04,   3.9087771E-04
     +,   3.7400567E-04,   3.5747426E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_htt95 = Yx/0.158232558139535
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4107917E-09,   1.7251032E-09
     +,   2.1050448E-09,   2.5633105E-09,   3.1148406E-09
     +,   3.7771639E-09,   4.5708011E-09,   5.5197007E-09
     +,   6.6517352E-09,   7.9993407E-09,   9.6000248E-09
     +,   1.1497159E-08,   1.3740711E-08,   1.6388135E-08
     +,   1.9505263E-08,   2.3167413E-08,   2.7460409E-08
     +,   3.2481903E-08,   3.8342627E-08,   4.5167777E-08
     +,   5.3098603E-08,   6.2293999E-08,   7.2931925E-08
     +,   8.5212228E-08,   9.9356321E-08,   1.1561200E-07
     +,   1.3425296E-07,   1.5558206E-07,   1.7993314E-07
     +,   2.0767291E-07,   2.3920305E-07,   2.7496205E-07
     +,   3.1542737E-07,   3.6111692E-07,   4.1259062E-07
     +,   4.7045182E-07,   5.3534876E-07,   6.0797305E-07
     +,   6.8906809E-07,   7.7941337E-07,   8.7984444E-07
     +,   9.9123429E-07,   1.1145031E-06,   1.2506099E-06
     +,   1.4005534E-06,   1.5653684E-06,   1.7461199E-06
     +,   1.9438990E-06,   2.1598196E-06,   2.3950083E-06
     +,   2.6506000E-06,   2.9277285E-06,   3.2275141E-06
     +,   3.5510784E-06,   3.8994776E-06,   4.2737661E-06
     +,   4.6749246E-06,   5.1038783E-06,   5.5614755E-06
     +,   6.0484772E-06,   6.5655481E-06,   7.1132408E-06
     +,   7.6919541E-06,   8.3019913E-06,   8.9435080E-06
     +,   9.6164404E-06,   1.0320637E-05,   1.1055674E-05
     +,   1.1821040E-05,   1.2615925E-05,   1.3439421E-05
     +,   1.4290314E-05,   1.5167287E-05,   1.6068712E-05
     +,   1.6992839E-05,   1.7937717E-05,   1.8901152E-05
     +,   1.9880757E-05,   2.0874038E-05,   2.1878344E-05
     +,   2.2890790E-05,   2.3908493E-05,   2.4928340E-05
     +,   2.5947289E-05,   2.6962100E-05,   2.7969660E-05
     +,   2.8966744E-05,   2.9950315E-05,   3.0917294E-05
     +,   3.1864856E-05,   3.2790351E-05,   3.3691314E-05
     +,   3.4565575E-05,   3.5411391E-05,   3.6227426E-05
     +,   3.7012745E-05,   3.7767099E-05,   3.8490729E-05
     +,   3.9184721E-05,   3.9850805E-05,   4.0491650E-05
     +,   4.1110761E-05,   4.1712698E-05,   4.2302938E-05
     +,   4.2888092E-05,   4.3475819E-05,   4.4074801E-05
     +,   4.4694774E-05,   4.5346445E-05,   4.6041401E-05
     +,   4.6791891E-05,   4.7610811E-05,   4.8511269E-05
     +,   4.9506525E-05,   5.0609528E-05,   5.1832718E-05
     +,   5.3187439E-05,   5.4683846E-05,   5.6330118E-05
     +,   5.8132406E-05,   6.0094277E-05,   6.2216248E-05
     +,   6.4495514E-05,   6.6925903E-05,   6.9497561E-05
     +,   7.2196555E-05,   7.5005562E-05,   7.7903278E-05
     +,   8.0865357E-05,   8.3864164E-05,   8.6869928E-05
     +,   8.9850670E-05,   9.2773509E-05,   9.5604977E-05
     +,   9.8312157E-05,   1.0086350E-04,   1.0322943E-04
     +,   1.0538346E-04,   1.0730323E-04,   1.0897133E-04
     +,   1.1037638E-04,   1.1151446E-04,   1.1239114E-04
     +,   1.1302384E-04,   1.1344523E-04,   1.1370805E-04
     +,   1.1389127E-04,   1.1410748E-04,   1.1451206E-04
     +,   1.1531281E-04,   1.1677953E-04,   1.1925188E-04
     +,   1.2314366E-04,   1.2894282E-04,   1.3720454E-04
     +,   1.4853739E-04,   1.6358544E-04,   1.8300985E-04
     +,   2.0747168E-04,   2.3762032E-04,   2.7409845E-04
     +,   3.1754954E-04,   3.6861966E-04,   4.2794712E-04
     +,   4.9611687E-04,   5.7355914E-04,   6.6040206E-04
     +,   7.5632968E-04,   8.6052530E-04,   9.7179163E-04
     +,   1.0889730E-03,   1.2117542E-03,   1.3417332E-03
     +,   1.4834482E-03,   1.6448923E-03,   1.8371178E-03
     +,   2.0728810E-03,   2.3650369E-03,   2.7256557E-03
     +,   3.1657564E-03,   3.6939643E-03,   4.3126037E-03
     +,   5.0122757E-03,   5.7681915E-03,   6.5422608E-03
     +,   7.2967350E-03,   8.0280704E-03,   8.8366503E-03
     +,   1.0021997E-02,   1.2030330E-02,   1.5062054E-02
     +,   1.8778497E-02,   2.2680074E-02,   2.6518874E-02
     +,   3.0131841E-02,   3.3145588E-02,   3.5554651E-02
     +,   3.7711110E-02,   4.0591620E-02,   4.4255607E-02
     +,   4.3536015E-02,   3.7427172E-02,   3.1334456E-02
     +,   2.7103608E-02,   2.2806725E-02,   1.8371737E-02
     +,   1.5208883E-02,   1.3270530E-02,   1.1704288E-02
     +,   1.0179776E-02,   8.7310467E-03,   7.4398969E-03
     +,   6.3752956E-03,   5.5311965E-03,   4.8284405E-03
     +,   4.2013889E-03,   3.6448014E-03,   3.1851365E-03
     +,   2.8377336E-03,   2.5916367E-03,   2.4170089E-03
     +,   2.2783345E-03,   2.1447530E-03,   1.9959987E-03
     +,   1.8241925E-03,   1.6321781E-03,   1.4296761E-03
     +,   1.2288230E-03,   1.0404920E-03,   8.7217119E-04
     +,   7.2739914E-04,   6.0632348E-04,   5.0682540E-04
     +,   4.2570059E-04,   3.5956461E-04,   3.0536574E-04
     +,   2.6060297E-04,   2.2332728E-04,   1.9204129E-04
     +,   1.6558511E-04,   1.4304710E-04,   1.2370251E-04
     +,   1.0697335E-04,   9.2402515E-05,   7.9635742E-05
     +,   6.8403533E-05,   5.8501995E-05,   4.9775430E-05
     +,   4.2102125E-05,   3.5383240E-05,   2.9532548E-05
     +,   2.4471683E-05,   2.0126934E-05,   1.6427208E-05
     +,   1.3303387E-05,   1.0688881E-05,   8.5203274E-06
     +,   6.7380020E-06,   5.2863952E-06,   4.1148528E-06
     +,   3.1779236E-06,   2.4353571E-06,   1.8520163E-06
     +,   1.3977394E-06,   1.0470225E-06,   7.7852309E-07
     +,   5.7465525E-07,   4.2111787E-07,   3.0640513E-07
     +,   2.2136312E-07,   1.5879813E-07,   1.1311825E-07
     +,   8.0015958E-08,   5.6204257E-08,   3.9200906E-08
     +,   2.7148806E-08,   1.8668125E-08,   1.2744685E-08
     +,   8.6376142E-09,   5.8112688E-09,   3.8807162E-09
     +,   2.5721070E-09,   1.6918058E-09,   1.1042544E-09
     +,   7.1514300E-10,   4.5950993E-10,   2.9290917E-10
     +,   1.8521065E-10,   1.1616412E-10,   7.2261690E-11
     +,   4.4581866E-11,   2.7276155E-11,   1.6548988E-11
     +,   9.9560603E-12,   5.9391745E-12,   3.5128081E-12
     +,   2.0600210E-12,   1.1977029E-12,   6.9038167E-13
     +,   3.9451656E-13,   2.2350306E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz100 = Yx/0.165395348837209
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3731877E-10,   1.7249950E-10
     +,   2.1619824E-10,   2.7034786E-10,   3.3728736E-10
     +,   4.1983936E-10,   5.2140198E-10,   6.4605293E-10
     +,   7.9867257E-10,   9.8509167E-10,   1.2122464E-09
     +,   1.4883721E-09,   1.8232164E-09,   2.2282876E-09
     +,   2.7171292E-09,   3.3056411E-09,   4.0124273E-09
     +,   4.8592046E-09,   5.8712288E-09,   7.0778161E-09
     +,   8.5128642E-09,   1.0215473E-08,   1.2230555E-08
     +,   1.4609755E-08,   1.7411779E-08,   2.0703846E-08
     +,   2.4562087E-08,   2.9072725E-08,   3.4333077E-08
     +,   4.0452527E-08,   4.7553836E-08,   5.5773963E-08
     +,   6.5265532E-08,   7.6197900E-08,   8.8758242E-08
     +,   1.0315279E-07,   1.1960795E-07,   1.3837092E-07
     +,   1.5971241E-07,   1.8392365E-07,   2.1132207E-07
     +,   2.4224761E-07,   2.7706506E-07,   3.1616355E-07
     +,   3.5995646E-07,   4.0888082E-07,   4.6339613E-07
     +,   5.2398298E-07,   5.9114228E-07,   6.6539138E-07
     +,   7.4726313E-07,   8.3730117E-07,   9.3605604E-07
     +,   1.0440891E-06,   1.1619486E-06,   1.2901893E-06
     +,   1.4293481E-06,   1.5799470E-06,   1.7424857E-06
     +,   1.9174333E-06,   2.1052258E-06,   2.3062591E-06
     +,   2.5208685E-06,   2.7493545E-06,   2.9919556E-06
     +,   3.2488276E-06,   3.5200894E-06,   3.8057549E-06
     +,   4.1058024E-06,   4.4201024E-06,   4.7484900E-06
     +,   5.0906974E-06,   5.4464317E-06,   5.8153073E-06
     +,   6.1969222E-06,   6.5908484E-06,   6.9966145E-06
     +,   7.4137452E-06,   7.8418152E-06,   8.2804399E-06
     +,   8.7292610E-06,   9.1880675E-06,   9.6567146E-06
     +,   1.0135266E-05,   1.0623900E-05,   1.1123072E-05
     +,   1.1633409E-05,   1.2155866E-05,   1.2691629E-05
     +,   1.3242239E-05,   1.3809568E-05,   1.4395794E-05
     +,   1.5003434E-05,   1.5635387E-05,   1.6294880E-05
     +,   1.6985394E-05,   1.7710769E-05,   1.8474995E-05
     +,   1.9282355E-05,   2.0137148E-05,   2.1043850E-05
     +,   2.2006812E-05,   2.3030399E-05,   2.4118668E-05
     +,   2.5275507E-05,   2.6504445E-05,   2.7808501E-05
     +,   2.9190158E-05,   3.0651423E-05,   3.2193682E-05
     +,   3.3817520E-05,   3.5523088E-05,   3.7309699E-05
     +,   3.9176331E-05,   4.1121286E-05,   4.3142762E-05
     +,   4.5238536E-05,   4.7406753E-05,   4.9645547E-05
     +,   5.1953888E-05,   5.4331649E-05,   5.6779834E-05
     +,   5.9301034E-05,   6.1900013E-05,   6.4583910E-05
     +,   6.7362227E-05,   7.0247821E-05,   7.3256371E-05
     +,   7.6407137E-05,   7.9722289E-05,   8.3227533E-05
     +,   8.6950684E-05,   9.0922236E-05,   9.5173426E-05
     +,   9.9736048E-05,   1.0464080E-04,   1.0991547E-04
     +,   1.1558334E-04,   1.2166199E-04,   1.2816093E-04
     +,   1.3507959E-04,   1.4240635E-04,   1.5011789E-04
     +,   1.5817865E-04,   1.6654056E-04,   1.7514611E-04
     +,   1.8393039E-04,   1.9282458E-04,   2.0176178E-04
     +,   2.1068408E-04,   2.1954926E-04,   2.2833813E-04
     +,   2.3706252E-04,   2.4577300E-04,   2.5456329E-04
     +,   2.6357226E-04,   2.7298409E-04,   2.8302375E-04
     +,   2.9394776E-04,   3.0603021E-04,   3.1954877E-04
     +,   3.3476562E-04,   3.5190929E-04,   3.7115978E-04
     +,   3.9264039E-04,   4.1641327E-04,   4.4248256E-04
     +,   4.7080647E-04,   5.0131546E-04,   5.3392682E-04
     +,   5.6855474E-04,   6.0511532E-04,   6.4352300E-04
     +,   6.8367663E-04,   7.2544732E-04,   7.6870137E-04
     +,   8.1335928E-04,   8.5952115E-04,   9.0767432E-04
     +,   9.5895905E-04,   1.0154287E-03,   1.0802377E-03
     +,   1.1576881E-03,   1.2531275E-03,   1.3728070E-03
     +,   1.5239457E-03,   1.7153013E-03,   1.9581602E-03
     +,   2.2669150E-03,   2.6579017E-03,   3.1465821E-03
     +,   3.7457745E-03,   4.4676606E-03,   5.3287833E-03
     +,   6.3657067E-03,   7.6789139E-03,   9.4497176E-03
     +,   1.1777299E-02,   1.4471334E-02,   1.7374866E-02
     +,   2.0746917E-02,   2.4407236E-02,   2.7740188E-02
     +,   3.1768125E-02,   3.7006091E-02,   3.9890878E-02
     +,   3.8844924E-02,   3.6949519E-02,   3.6331866E-02
     +,   3.5868030E-02,   3.3159092E-02,   2.8414063E-02
     +,   2.3818955E-02,   1.9941362E-02,   1.6417934E-02
     +,   1.3439520E-02,   1.1147249E-02,   9.3101906E-03
     +,   7.6873349E-03,   6.2684864E-03,   5.1587936E-03
     +,   4.3883207E-03,   3.8805667E-03,   3.5253519E-03
     +,   3.2361962E-03,   2.9627965E-03,   2.6822949E-03
     +,   2.3889332E-03,   2.0870778E-03,   1.7865420E-03
     +,   1.4988789E-03,   1.2343953E-03,   1.0002314E-03
     +,   7.9971913E-04,   6.3277053E-04,   4.9680792E-04
     +,   3.8789437E-04,   3.0166475E-04,   2.3393109E-04
     +,   1.8100071E-04,   1.3978807E-04,   1.0779493E-04
     +,   8.3029066E-05,   6.3911597E-05,   4.9195180E-05
     +,   3.7894748E-05,   2.9232202E-05,   2.2595073E-05
     +,   1.7505112E-05,   1.3592597E-05,   1.0573835E-05
     +,   8.2337701E-06,   6.4108640E-06,   4.9843593E-06
     +,   3.8641010E-06,   2.9826647E-06,   2.2892295E-06
     +,   1.7449104E-06,   1.3194407E-06,   9.8888836E-07
     +,   7.3406176E-07,   5.3938459E-07,   3.9214322E-07
     +,   2.8197908E-07,   2.0049890E-07,   1.4094277E-07
     +,   9.7936265E-08,   6.7262988E-08,   4.5657924E-08
     +,   3.0629270E-08,   2.0305681E-08,   1.3303142E-08
     +,   8.6128500E-09,   5.5104197E-09,   3.4838381E-09
     +,   2.1765996E-09,   1.3437910E-09,   8.1984258E-10
     +,   4.9426524E-10,   2.9446581E-10,   1.7335655E-10
     +,   1.0085337E-10,   5.7978920E-11,   3.2937899E-11
     +,   1.8490570E-11,   1.0257727E-11,   5.6232740E-12
     +,   3.0461861E-12,   1.6306831E-12,   8.6260214E-13
     +,   4.5091963E-13,   2.3292468E-13,   1.1889913E-13
     +,   5.9974920E-14,   2.9895611E-14,   1.4725629E-14
     +,   7.1678063E-15,   3.4476896E-15,   1.6387624E-15
     +,   7.6971800E-16,   3.5726796E-16
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz104 = Yx/0.153348837209302
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7310024E-06,   3.9874799E-06
     +,   4.2553565E-06,   4.5346319E-06,   4.8252623E-06
     +,   5.1271586E-06,   5.4401903E-06,   5.7641814E-06
     +,   6.0989037E-06,   6.4441015E-06,   6.7994570E-06
     +,   7.1646173E-06,   7.5391804E-06,   7.9227066E-06
     +,   8.3147170E-06,   8.7146955E-06,   9.1220872E-06
     +,   9.5363121E-06,   9.9567551E-06,   1.0382782E-05
     +,   1.0813731E-05,   1.1248929E-05,   1.1687680E-05
     +,   1.2129307E-05,   1.2573078E-05,   1.3018315E-05
     +,   1.3464311E-05,   1.3910375E-05,   1.4355833E-05
     +,   1.4800022E-05,   1.5242304E-05,   1.5682064E-05
     +,   1.6118713E-05,   1.6551692E-05,   1.6980479E-05
     +,   1.7404584E-05,   1.7823555E-05,   1.8236968E-05
     +,   1.8644474E-05,   1.9045705E-05,   1.9440395E-05
     +,   1.9828274E-05,   2.0209127E-05,   2.0582776E-05
     +,   2.0949074E-05,   2.1307911E-05,   2.1659211E-05
     +,   2.2002916E-05,   2.2339002E-05,   2.2667458E-05
     +,   2.2988306E-05,   2.3301565E-05,   2.3607272E-05
     +,   2.3905479E-05,   2.4196219E-05,   2.4479548E-05
     +,   2.4755504E-05,   2.5024108E-05,   2.5285390E-05
     +,   2.5539342E-05,   2.5785948E-05,   2.6025169E-05
     +,   2.6256932E-05,   2.6481157E-05,   2.6697724E-05
     +,   2.6906469E-05,   2.7107229E-05,   2.7299775E-05
     +,   2.7483880E-05,   2.7659264E-05,   2.7825632E-05
     +,   2.7982655E-05,   2.8129987E-05,   2.8267254E-05
     +,   2.8394081E-05,   2.8510078E-05,   2.8614841E-05
     +,   2.8707969E-05,   2.8789089E-05,   2.8857821E-05
     +,   2.8913830E-05,   2.8956809E-05,   2.8986489E-05
     +,   2.9002675E-05,   2.9005225E-05,   2.8994078E-05
     +,   2.8969278E-05,   2.8930957E-05,   2.8879378E-05
     +,   2.8814920E-05,   2.8738123E-05,   2.8649656E-05
     +,   2.8550388E-05,   2.8441342E-05,   2.8323733E-05
     +,   2.8198980E-05,   2.8068698E-05,   2.7934731E-05
     +,   2.7799104E-05,   2.7664099E-05,   2.7532189E-05
     +,   2.7406059E-05,   2.7288608E-05,   2.7182939E-05
     +,   2.7092339E-05,   2.7020247E-05,   2.6970289E-05
     +,   2.6946202E-05,   2.6951839E-05,   2.6991134E-05
     +,   2.7068072E-05,   2.7186665E-05,   2.7350909E-05
     +,   2.7564744E-05,   2.7832011E-05,   2.8156459E-05
     +,   2.8541606E-05,   2.8990815E-05,   2.9507131E-05
     +,   3.0093366E-05,   3.0751991E-05,   3.1485099E-05
     +,   3.2294363E-05,   3.3181132E-05,   3.4146386E-05
     +,   3.5190649E-05,   3.6314294E-05,   3.7517380E-05
     +,   3.8800103E-05,   4.0162740E-05,   4.1606287E-05
     +,   4.3132608E-05,   4.4745342E-05,   4.6450292E-05
     +,   4.8256672E-05,   5.0178121E-05,   5.2233885E-05
     +,   5.4450382E-05,   5.6863046E-05,   5.9517883E-05
     +,   6.2473002E-05,   6.5800232E-05,   6.9586407E-05
     +,   7.3933908E-05,   7.8959616E-05,   8.4794454E-05
     +,   9.1579976E-05,   9.9463577E-05,   1.0859234E-04
     +,   1.1910585E-04,   1.3112633E-04,   1.4474716E-04
     +,   1.6002210E-04,   1.7695568E-04,   1.9549284E-04
     +,   2.1551018E-04,   2.3681327E-04,   2.5913891E-04
     +,   2.8215980E-04,   3.0549418E-04,   3.2872777E-04
     +,   3.5143443E-04,   3.7320171E-04,   3.9366228E-04
     +,   4.1252482E-04,   4.2960039E-04,   4.4482385E-04
     +,   4.5827145E-04,   4.7016656E-04,   4.8087302E-04
     +,   4.9087725E-04,   5.0076150E-04,   5.1116711E-04
     +,   5.2275369E-04,   5.3615874E-04,   5.5197056E-04
     +,   5.7071570E-04,   5.9287192E-04,   6.1891554E-04
     +,   6.4939546E-04,   6.8502006E-04,   7.2672631E-04
     +,   7.7570236E-04,   8.3333056E-04,   9.0104149E-04
     +,   9.8012341E-04,   1.0716147E-03,   1.1764395E-03
     +,   1.2960321E-03,   1.4337461E-03,   1.5973462E-03
     +,   1.8022264E-03,   2.0737096E-03,   2.4451441E-03
     +,   2.9494436E-03,   3.6078191E-03,   4.4271126E-03
     +,   5.4142536E-03,   6.5998374E-03,   8.0437101E-03
     +,   9.7825499E-03,   1.1734149E-02,   1.3753283E-02
     +,   1.5945576E-02,   1.8662961E-02,   2.1899762E-02
     +,   2.5508989E-02,   2.9881986E-02,   3.4820553E-02
     +,   3.9024133E-02,   4.1213494E-02,   4.0488768E-02
     +,   3.6932472E-02,   3.2029409E-02,   2.7565865E-02
     +,   2.4118120E-02,   2.0933209E-02,   1.7288944E-02
     +,   1.3570945E-02,   1.0586018E-02,   8.5517978E-03
     +,   7.2290995E-03,   6.3616708E-03,   5.7462659E-03
     +,   5.2107181E-03,   4.6526454E-03,   4.0538553E-03
     +,   3.4467918E-03,   2.8737222E-03,   2.3644492E-03
     +,   1.9313567E-03,   1.5730131E-03,   1.2802432E-03
     +,   1.0415396E-03,   8.4638537E-04,   6.8639399E-04
     +,   5.5517629E-04,   4.4772829E-04,   3.5990807E-04
     +,   2.8818310E-04,   2.2957190E-04,   1.8163686E-04
     +,   1.4244633E-04,   1.1049654E-04,   8.4613996E-05
     +,   6.3855696E-05,   4.7427526E-05,   3.4632030E-05
     +,   2.4843539E-05,   1.7499817E-05,   1.2100688E-05
     +,   8.2126853E-06,   5.4709808E-06,   3.5776368E-06
     +,   2.2968841E-06,   1.4480011E-06,   8.9656351E-07
     +,   5.4534473E-07,   3.2592314E-07,   1.9141541E-07
     +,   1.1048940E-07,   6.2689594E-08,   3.4963744E-08
     +,   1.9168356E-08,   1.0330082E-08,   5.4719402E-09
     +,   2.8487239E-09,   1.4574449E-09,   7.3269002E-10
     +,   3.6187978E-10,   1.7556956E-10,   8.3660141E-11
     +,   3.9148788E-11,   1.7987663E-11,   8.1136617E-12
     +,   3.5926563E-12,   1.5613674E-12,   6.6601233E-13
     +,   2.7882378E-13,   1.1458576E-13,   4.6240901E-14
     +,   1.8340854E-14,   7.1628968E-15,   2.7651869E-15
     +,   1.0633224E-15,   4.1349316E-16,   1.6700770E-16
     +,   7.2889812E-17,   3.5810717E-17,   2.0134724E-17
     +,   1.2695406E-17,   8.6317786E-18,   6.1151403E-18
     +,   4.4176846E-18,   3.2176554E-18,   2.3500034E-18
     +,   1.7167645E-18,   1.2530983E-18,   9.1347726E-19
     +,   6.6489388E-19,   4.8319559E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz106 = Yx/0.142604651162791
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1692543E-06,   1.2755360E-06
     +,   1.3898352E-06,   1.5126008E-06,   1.6442914E-06
     +,   1.7853793E-06,   1.9363454E-06,   2.0976822E-06
     +,   2.2698878E-06,   2.4534768E-06,   2.6489638E-06
     +,   2.8568711E-06,   3.0777280E-06,   3.3120668E-06
     +,   3.5604248E-06,   3.8233388E-06,   4.1013491E-06
     +,   4.3949954E-06,   4.7048143E-06,   5.0313406E-06
     +,   5.3751046E-06,   5.7366319E-06,   6.1164328E-06
     +,   6.5150343E-06,   6.9329099E-06,   7.3705628E-06
     +,   7.8284593E-06,   8.3070490E-06,   8.8067727E-06
     +,   9.3280405E-06,   9.8712435E-06,   1.0436747E-05
     +,   1.1024879E-05,   1.1635945E-05,   1.2270208E-05
     +,   1.2927887E-05,   1.3609167E-05,   1.4314165E-05
     +,   1.5042990E-05,   1.5795624E-05,   1.6572052E-05
     +,   1.7372162E-05,   1.8195762E-05,   1.9042613E-05
     +,   1.9912357E-05,   2.0804579E-05,   2.1718748E-05
     +,   2.2654254E-05,   2.3610382E-05,   2.4586301E-05
     +,   2.5581085E-05,   2.6593676E-05,   2.7622908E-05
     +,   2.8667546E-05,   2.9726125E-05,   3.0797179E-05
     +,   3.1879052E-05,   3.2970005E-05,   3.4068158E-05
     +,   3.5171539E-05,   3.6278074E-05,   3.7385584E-05
     +,   3.8491758E-05,   3.9594273E-05,   4.0690738E-05
     +,   4.1778581E-05,   4.2855339E-05,   4.3918360E-05
     +,   4.4965109E-05,   4.5992914E-05,   4.6999216E-05
     +,   4.7981383E-05,   4.8936919E-05,   4.9863283E-05
     +,   5.0758066E-05,   5.1618987E-05,   5.2443778E-05
     +,   5.3230302E-05,   5.3976622E-05,   5.4680946E-05
     +,   5.5341574E-05,   5.5957076E-05,   5.6526140E-05
     +,   5.7047735E-05,   5.7520967E-05,   5.7945257E-05
     +,   5.8320195E-05,   5.8645677E-05,   5.8921833E-05
     +,   5.9149032E-05,   5.9328024E-05,   5.9459744E-05
     +,   5.9545509E-05,   5.9586921E-05,   5.9585920E-05
     +,   5.9544807E-05,   5.9466252E-05,   5.9353304E-05
     +,   5.9209447E-05,   5.9038615E-05,   5.8845184E-05
     +,   5.8634076E-05,   5.8410729E-05,   5.8181195E-05
     +,   5.7952133E-05,   5.7730849E-05,   5.7525409E-05
     +,   5.7344583E-05,   5.7197954E-05,   5.7095876E-05
     +,   5.7049605E-05,   5.7071207E-05,   5.7173624E-05
     +,   5.7370627E-05,   5.7676782E-05,   5.8107453E-05
     +,   5.8678583E-05,   5.9406764E-05,   6.0308885E-05
     +,   6.1402148E-05,   6.2703788E-05,   6.4230677E-05
     +,   6.5999186E-05,   6.8024870E-05,   7.0322145E-05
     +,   7.2903495E-05,   7.5779753E-05,   7.8958838E-05
     +,   8.2446255E-05,   8.6243599E-05,   9.0349153E-05
     +,   9.4756513E-05,   9.9455290E-05,   1.0442959E-04
     +,   1.0965893E-04,   1.1511774E-04,   1.2077481E-04
     +,   1.2659389E-04,   1.3253438E-04,   1.3855129E-04
     +,   1.4459559E-04,   1.5061523E-04,   1.5655682E-04
     +,   1.6236618E-04,   1.6798920E-04,   1.7337469E-04
     +,   1.7847551E-04,   1.8325010E-04,   1.8766495E-04
     +,   1.9169712E-04,   1.9533586E-04,   1.9858485E-04
     +,   2.0146433E-04,   2.0401312E-04,   2.0628996E-04
     +,   2.0837410E-04,   2.1036608E-04,   2.1238693E-04
     +,   2.1457653E-04,   2.1709042E-04,   2.2009577E-04
     +,   2.2376553E-04,   2.2827089E-04,   2.3377266E-04
     +,   2.4041189E-04,   2.4829939E-04,   2.5750478E-04
     +,   2.6804724E-04,   2.7988842E-04,   2.9292805E-04
     +,   3.0700184E-04,   3.2188845E-04,   3.3732248E-04
     +,   3.5301442E-04,   3.6867711E-04,   3.8406643E-04
     +,   3.9902327E-04,   4.1352119E-04,   4.2771685E-04
     +,   4.4199554E-04,   4.5700284E-04,   4.7365821E-04
     +,   4.9314240E-04,   5.1685283E-04,   5.4632261E-04
     +,   5.8310601E-04,   6.2864990E-04,   6.8417098E-04
     +,   7.5055996E-04,   8.2834199E-04,   9.1776293E-04
     +,   1.0190136E-03,   1.1326689E-03,   1.2603780E-03
     +,   1.4056697E-03,   1.5744985E-03,   1.7751040E-03
     +,   2.0170617E-03,   2.3101331E-03,   2.6645528E-03
     +,   3.0963500E-03,   3.6429956E-03,   4.3865032E-03
     +,   5.4500946E-03,   6.9120987E-03,   8.6717987E-03
     +,   1.0483979E-02,   1.2285553E-02,   1.4476229E-02
     +,   1.7741565E-02,   2.2481130E-02,   2.8251167E-02
     +,   3.3758026E-02,   3.7812088E-02,   4.0145200E-02
     +,   4.0306497E-02,   3.7876058E-02,   3.4408905E-02
     +,   3.1222967E-02,   2.7297998E-02,   2.2212012E-02
     +,   1.7375421E-02,   1.3864930E-02,   1.1568164E-02
     +,   9.8982165E-03,   8.3883833E-03,   6.8957047E-03
     +,   5.5251694E-03,   4.4026244E-03,   3.5446167E-03
     +,   2.8890518E-03,   2.3653526E-03,   1.9262359E-03
     +,   1.5483523E-03,   1.2238367E-03,   9.5150096E-04
     +,   7.3035236E-04,   5.5646501E-04,   4.2298113E-04
     +,   3.2177358E-04,   2.4519040E-04,   1.8702353E-04
     +,   1.4267091E-04,   1.0884774E-04,   8.3185660E-05
     +,   6.3899461E-05,   4.9574959E-05,   3.9058694E-05
     +,   3.1408013E-05,   2.5864689E-05,   2.1833093E-05
     +,   1.8859848E-05,   1.6610653E-05,   1.4846684E-05
     +,   1.3402857E-05,   1.2169121E-05,   1.1075028E-05
     +,   1.0077474E-05,   9.1515312E-06,   8.2838942E-06
     +,   7.4683289E-06,   6.7025085E-06,   5.9859872E-06
     +,   5.3190347E-06,   4.7019957E-06,   4.1347957E-06
     +,   3.6168492E-06,   3.1470545E-06,   2.7237882E-06
     +,   2.3449477E-06,   2.0080759E-06,   1.7104719E-06
     +,   1.4492473E-06,   1.2213990E-06,   1.0239021E-06
     +,   8.5378832E-07,   7.0815395E-07,   5.8424644E-07
     +,   4.7945730E-07,   3.9137666E-07,   3.1777904E-07
     +,   2.5665341E-07,   2.0618344E-07,   1.6476007E-07
     +,   1.3095892E-07,   1.0354042E-07,   8.1427920E-08
     +,   6.3697314E-08,   4.9563393E-08,   3.8360614E-08
     +,   2.9532625E-08,   2.2615328E-08,   1.7226458E-08
     +,   1.3051884E-08,   9.8365502E-09,   7.3738891E-09
     +,   5.4984866E-09,   4.0782453E-09,   3.0088219E-09
     +,   2.2080209E-09,   1.6117677E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz108 = Yx/0.1345
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5662353E-08,   1.8357193E-08
     +,   2.1475456E-08,   2.5076430E-08,   2.9226511E-08
     +,   3.3999797E-08,   3.9478877E-08,   4.5755446E-08
     +,   5.2930957E-08,   6.1117916E-08,   7.0439910E-08
     +,   8.1032873E-08,   9.3045742E-08,   1.0664133E-07
     +,   1.2199695E-07,   1.3930534E-07,   1.5877514E-07
     +,   1.8063199E-07,   2.0511840E-07,   2.3249520E-07
     +,   2.6304087E-07,   2.9705291E-07,   3.3484665E-07
     +,   3.7675886E-07,   4.2313994E-07,   4.7436382E-07
     +,   5.3081925E-07,   5.9291250E-07,   6.6106651E-07
     +,   7.3571834E-07,   8.1731946E-07,   9.0633188E-07
     +,   1.0032285E-06,   1.1084890E-06,   1.2225985E-06
     +,   1.3460444E-06,   1.4793128E-06,   1.6228835E-06
     +,   1.7772387E-06,   1.9428312E-06,   2.1201172E-06
     +,   2.3095226E-06,   2.5114527E-06,   2.7262852E-06
     +,   2.9543662E-06,   3.1960055E-06,   3.4514728E-06
     +,   3.7209945E-06,   4.0047494E-06,   4.3028649E-06
     +,   4.6154169E-06,   4.9424225E-06,   5.2838382E-06
     +,   5.6395825E-06,   6.0094762E-06,   6.3933226E-06
     +,   6.7908418E-06,   7.2017065E-06,   7.6255415E-06
     +,   8.0619166E-06,   8.5103684E-06,   8.9704045E-06
     +,   9.4414727E-06,   9.9230456E-06,   1.0414589E-05
     +,   1.0915526E-05,   1.1425362E-05,   1.1943563E-05
     +,   1.2469715E-05,   1.3003389E-05,   1.3544304E-05
     +,   1.4092195E-05,   1.4646979E-05,   1.5208613E-05
     +,   1.5777250E-05,   1.6353182E-05,   1.6936830E-05
     +,   1.7528773E-05,   1.8129813E-05,   1.8740924E-05
     +,   1.9363213E-05,   1.9998044E-05,   2.0646890E-05
     +,   2.1311480E-05,   2.1993623E-05,   2.2695380E-05
     +,   2.3418872E-05,   2.4166455E-05,   2.4940487E-05
     +,   2.5743542E-05,   2.6578258E-05,   2.7447319E-05
     +,   2.8353466E-05,   2.9299559E-05,   3.0288533E-05
     +,   3.1323245E-05,   3.2406773E-05,   3.3542095E-05
     +,   3.4732406E-05,   3.5980822E-05,   3.7290705E-05
     +,   3.8665356E-05,   4.0108349E-05,   4.1623236E-05
     +,   4.3213793E-05,   4.4883956E-05,   4.6637680E-05
     +,   4.8479033E-05,   5.0412305E-05,   5.2441861E-05
     +,   5.4571901E-05,   5.6806955E-05,   5.9151185E-05
     +,   6.1609040E-05,   6.4184540E-05,   6.6881905E-05
     +,   6.9704874E-05,   7.2657327E-05,   7.5742675E-05
     +,   7.8964331E-05,   8.2325598E-05,   8.5829299E-05
     +,   8.9477966E-05,   9.3274117E-05,   9.7219803E-05
     +,   1.0131615E-04,   1.0556402E-04,   1.0996265E-04
     +,   1.1451048E-04,   1.1920340E-04,   1.2403565E-04
     +,   1.2899780E-04,   1.3407751E-04,   1.3925768E-04
     +,   1.4451686E-04,   1.4982827E-04,   1.5515913E-04
     +,   1.6047058E-04,   1.6571817E-04,   1.7085155E-04
     +,   1.7581474E-04,   1.8054729E-04,   1.8498562E-04
     +,   1.8906410E-04,   1.9271644E-04,   1.9587835E-04
     +,   1.9848906E-04,   2.0049341E-04,   2.0184409E-04
     +,   2.0250384E-04,   2.0244690E-04,   2.0166053E-04
     +,   2.0014639E-04,   1.9792096E-04,   1.9501586E-04
     +,   1.9147796E-04,   1.8736848E-04,   1.8276197E-04
     +,   1.7774510E-04,   1.7241563E-04,   1.6688004E-04
     +,   1.6125226E-04,   1.5565268E-04,   1.5020688E-04
     +,   1.4504406E-04,   1.4029775E-04,   1.3610607E-04
     +,   1.3261253E-04,   1.2996767E-04,   1.2833157E-04
     +,   1.2787693E-04,   1.2879200E-04,   1.3128348E-04
     +,   1.3557887E-04,   1.4192653E-04,   1.5059397E-04
     +,   1.6186194E-04,   1.7601241E-04,   1.9331294E-04
     +,   2.1399587E-04,   2.3823202E-04,   2.6610098E-04
     +,   2.9756650E-04,   3.3246112E-04,   3.7048277E-04
     +,   4.1121154E-04,   4.5416423E-04,   4.9888750E-04
     +,   5.4508675E-04,   5.9278926E-04,   6.4253545E-04
     +,   6.9553300E-04,   7.5372763E-04,   8.1974105E-04
     +,   8.9662813E-04,   9.8747248E-04,   1.0948880E-03
     +,   1.2205386E-03,   1.3647607E-03,   1.5264009E-03
     +,   1.7031765E-03,   1.8931292E-03,   2.0976837E-03
     +,   2.3259954E-03,   2.5983953E-03,   2.9449461E-03
     +,   3.3982273E-03,   3.9936411E-03,   4.8053460E-03
     +,   6.0271332E-03,   8.0259759E-03,   1.1200457E-02
     +,   1.5592858E-02,   2.0605236E-02,   2.5456654E-02
     +,   3.0053444E-02,   3.4320869E-02,   3.8512010E-02
     +,   4.3013915E-02,   4.4623155E-02,   4.0634200E-02
     +,   3.3945758E-02,   2.8090872E-02,   2.3015913E-02
     +,   1.8628361E-02,   1.5383563E-02,   1.2772673E-02
     +,   1.0331265E-02,   8.1608379E-03,   6.4017870E-03
     +,   5.0085415E-03,   3.8818915E-03,   2.9637739E-03
     +,   2.2275832E-03,   1.6517125E-03,   1.2108778E-03
     +,   8.7837636E-04,   6.3051080E-04,   4.4867166E-04
     +,   3.1838319E-04,   2.2754662E-04,   1.6568086E-04
     +,   1.2409835E-04,   9.6179450E-05,   7.7272583E-05
     +,   6.4280248E-05,   5.5179211E-05,   4.8637805E-05
     +,   4.3764838E-05,   3.9958457E-05,   3.6814792E-05
     +,   3.4070206E-05,   3.1560572E-05,   2.9190533E-05
     +,   2.6910659E-05,   2.4700823E-05,   2.2558432E-05
     +,   2.0490157E-05,   1.8506540E-05,   1.6618864E-05
     +,   1.4837417E-05,   1.3170373E-05,   1.1623280E-05
     +,   1.0199129E-05,   8.8986235E-06,   7.7201421E-06
     +,   6.6602215E-06,   5.7139378E-06,   4.8751585E-06
     +,   4.1368244E-06,   3.4913103E-06,   2.9307273E-06
     +,   2.4470928E-06,   2.0324976E-06,   1.6793069E-06
     +,   1.3803002E-06,   1.1286825E-06,   9.1821823E-07
     +,   7.4319837E-07,   5.9850453E-07,   4.7955655E-07
     +,   3.8233048E-07,   3.0329622E-07,   2.3940797E-07
     +,   1.8804127E-07,   1.4696793E-07,   1.1429994E-07
     +,   8.8454954E-08,   6.8117508E-08,   5.2197223E-08
     +,   3.9800959E-08,   3.0198578E-08,   2.2799737E-08
     +,   1.7128144E-08,   1.2803545E-08,   9.5230117E-09
     +,   7.0476389E-09,   5.1894591E-09,   3.8019805E-09
     +,   2.7713374E-09,   2.0098396E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz110 = Yx/0.1275
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2740941E-07,   1.4432564E-07
     +,   1.6321928E-07,   1.8428345E-07,   2.0772508E-07
     +,   2.3376573E-07,   2.6264129E-07,   2.9460259E-07
     +,   3.2991500E-07,   3.6886067E-07,   4.1173539E-07
     +,   4.5885020E-07,   5.1053058E-07,   5.6711701E-07
     +,   6.2896345E-07,   6.9643619E-07,   7.6991415E-07
     +,   8.4978728E-07,   9.3645582E-07,   1.0303279E-06
     +,   1.1318183E-06,   1.2413486E-06,   1.3593396E-06
     +,   1.4862228E-06,   1.6224147E-06,   1.7683427E-06
     +,   1.9244212E-06,   2.0910572E-06,   2.2686497E-06
     +,   2.4575825E-06,   2.6582256E-06,   2.8709305E-06
     +,   3.0960291E-06,   3.3338304E-06,   3.5846203E-06
     +,   3.8486587E-06,   4.1261783E-06,   4.4173789E-06
     +,   4.7224516E-06,   5.0415256E-06,   5.3747367E-06
     +,   5.7221760E-06,   6.0839138E-06,   6.4599981E-06
     +,   6.8504660E-06,   7.2553330E-06,   7.6746164E-06
     +,   8.1083244E-06,   8.5564798E-06,   9.0191143E-06
     +,   9.4962861E-06,   9.9880826E-06,   1.0494637E-05
     +,   1.1016160E-05,   1.1552873E-05,   1.2105143E-05
     +,   1.2673381E-05,   1.3258111E-05,   1.3859964E-05
     +,   1.4479699E-05,   1.5118194E-05,   1.5776479E-05
     +,   1.6455666E-05,   1.7157075E-05,   1.7882148E-05
     +,   1.8632401E-05,   1.9409565E-05,   2.0215371E-05
     +,   2.1051757E-05,   2.1920610E-05,   2.2823975E-05
     +,   2.3763792E-05,   2.4742083E-05,   2.5760695E-05
     +,   2.6821432E-05,   2.7925951E-05,   2.9075623E-05
     +,   3.0271533E-05,   3.1514541E-05,   3.2805096E-05
     +,   3.4143126E-05,   3.5528210E-05,   3.6959231E-05
     +,   3.8434675E-05,   3.9952225E-05,   4.1509109E-05
     +,   4.3101711E-05,   4.4725923E-05,   4.6376783E-05
     +,   4.8048816E-05,   4.9735940E-05,   5.1431343E-05
     +,   5.3127718E-05,   5.4817399E-05,   5.6492288E-05
     +,   5.8143869E-05,   5.9763624E-05,   6.1342733E-05
     +,   6.2872627E-05,   6.4344640E-05,   6.5750603E-05
     +,   6.7082532E-05,   6.8333153E-05,   6.9495654E-05
     +,   7.0564063E-05,   7.1533250E-05,   7.2398972E-05
     +,   7.3158015E-05,   7.3808267E-05,   7.4348769E-05
     +,   7.4779673E-05,   7.5102354E-05,   7.5319345E-05
     +,   7.5434371E-05,   7.5452263E-05,   7.5378994E-05
     +,   7.5221506E-05,   7.4987707E-05,   7.4686366E-05
     +,   7.4327014E-05,   7.3919793E-05,   7.3475443E-05
     +,   7.3005052E-05,   7.2520066E-05,   7.2031995E-05
     +,   7.1552473E-05,   7.1092931E-05,   7.0664697E-05
     +,   7.0278664E-05,   6.9945338E-05,   6.9674570E-05
     +,   6.9475682E-05,   6.9357113E-05,   6.9326525E-05
     +,   6.9390713E-05,   6.9555506E-05,   6.9825735E-05
     +,   7.0205206E-05,   7.0696777E-05,   7.1302333E-05
     +,   7.2022747E-05,   7.2858027E-05,   7.3807416E-05
     +,   7.4869509E-05,   7.6042234E-05,   7.7323253E-05
     +,   7.8710014E-05,   8.0199985E-05,   8.1790808E-05
     +,   8.3480816E-05,   8.5269210E-05,   8.7156222E-05
     +,   8.9143563E-05,   9.1235015E-05,   9.3436553E-05
     +,   9.5756659E-05,   9.8206772E-05,   1.0080176E-04
     +,   1.0356017E-04,   1.0650411E-04,   1.0965981E-04
     +,   1.1305758E-04,   1.1673119E-04,   1.2071776E-04
     +,   1.2505749E-04,   1.2979246E-04,   1.3496519E-04
     +,   1.4061754E-04,   1.4678942E-04,   1.5351672E-04
     +,   1.6082916E-04,   1.6874878E-04,   1.7728948E-04
     +,   1.8645632E-04,   1.9624535E-04,   2.0664828E-04
     +,   2.1765748E-04,   2.2927389E-04,   2.4152092E-04
     +,   2.5446346E-04,   2.6822946E-04,   2.8303560E-04
     +,   2.9921599E-04,   3.1724852E-04,   3.3777131E-04
     +,   3.6158192E-04,   3.8961423E-04,   4.2288523E-04
     +,   4.6240201E-04,   5.0903280E-04,   5.6336704E-04
     +,   6.2556384E-04,   6.9522433E-04,   7.7133294E-04
     +,   8.5229153E-04,   9.3606050E-04,   1.0204151E-03
     +,   1.1033169E-03,   1.1833437E-03,   1.2601070E-03
     +,   1.3346055E-03,   1.4094774E-03,   1.4891040E-03
     +,   1.5794828E-03,   1.6878446E-03,   1.8223369E-03
     +,   1.9929819E-03,   2.2158471E-03,   2.5204609E-03
     +,   2.9557338E-03,   3.5902709E-03,   4.5142542E-03
     +,   5.8416114E-03,   7.6649529E-03,   9.9665895E-03
     +,   1.2674390E-02,   1.5838539E-02,   1.9429678E-02
     +,   2.3098696E-02,   2.6933864E-02,   3.1651746E-02
     +,   3.6899053E-02,   4.0729918E-02,   4.1205037E-02
     +,   3.9049469E-02,   3.5591062E-02,   3.0093165E-02
     +,   2.3558687E-02,   1.8256091E-02,   1.4697719E-02
     +,   1.2101461E-02,   9.7127156E-03,   7.3203240E-03
     +,   5.1221731E-03,   3.3614030E-03,   2.1093138E-03
     +,   1.2879515E-03,   7.7616423E-04,   4.6971510E-04
     +,   2.9215685E-04,   1.9078561E-04,   1.3196154E-04
     +,   9.6329022E-05,   7.3762742E-05,   5.9151422E-05
     +,   4.9727514E-05,   4.3755226E-05,   4.0018233E-05
     +,   3.7646256E-05,   3.6040459E-05,   3.4814522E-05
     +,   3.3737757E-05,   3.2684107E-05,   3.1592255E-05
     +,   3.0437966E-05,   2.9216848E-05,   2.7934489E-05
     +,   2.6601079E-05,   2.5228599E-05,   2.3829589E-05
     +,   2.2416585E-05,   2.1001650E-05,   1.9596073E-05
     +,   1.8210281E-05,   1.6853881E-05,   1.5535299E-05
     +,   1.4261868E-05,   1.3039866E-05,   1.1874438E-05
     +,   1.0769536E-05,   9.7280417E-06,   8.7518883E-06
     +,   7.8420553E-06,   6.9985877E-06,   6.2207664E-06
     +,   5.5072660E-06,   4.8560792E-06,   4.2648021E-06
     +,   3.7305626E-06,   3.2502621E-06,   2.8205227E-06
     +,   2.4378928E-06,   2.0988050E-06,   1.7997352E-06
     +,   1.5371734E-06,   1.3077408E-06,   1.1081685E-06
     +,   9.3535306E-07,   7.8639113E-07,   6.5855590E-07
     +,   5.4934571E-07,   4.5645234E-07,   3.7778955E-07
     +,   3.1146308E-07,   2.5578424E-07,   2.0924206E-07
     +,   1.7050627E-07,   1.3840280E-07,   1.1191069E-07
     +,   9.0139878E-08,   7.2325264E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz112 = Yx/0.122833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2774558E-07,   1.4475837E-07
     +,   1.6376460E-07,   1.8495963E-07,   2.0855313E-07
     +,   2.3476963E-07,   2.6384885E-07,   2.9604612E-07
     +,   3.3163232E-07,   3.7089617E-07,   4.1414140E-07
     +,   4.6168890E-07,   5.1387667E-07,   5.7105927E-07
     +,   6.3360812E-07,   7.0191157E-07,   7.7637486E-07
     +,   8.5741897E-07,   9.4548227E-07,   1.0410180E-06
     +,   1.1444952E-06,   1.2563985E-06,   1.3772254E-06
     +,   1.5074966E-06,   1.6477313E-06,   1.7984789E-06
     +,   1.9602933E-06,   2.1337448E-06,   2.3194166E-06
     +,   2.5179054E-06,   2.7298206E-06,   2.9557877E-06
     +,   3.1964421E-06,   3.4524364E-06,   3.7244354E-06
     +,   4.0131195E-06,   4.3191808E-06,   4.6433256E-06
     +,   4.9862906E-06,   5.3487943E-06,   5.7316033E-06
     +,   6.1354781E-06,   6.5611930E-06,   7.0095371E-06
     +,   7.4813029E-06,   7.9772899E-06,   8.4982958E-06
     +,   9.0451176E-06,   9.6185368E-06,   1.0219321E-05
     +,   1.0848212E-05,   1.1505914E-05,   1.2193075E-05
     +,   1.2910334E-05,   1.3658171E-05,   1.4437066E-05
     +,   1.5247348E-05,   1.6089243E-05,   1.6962833E-05
     +,   1.7868057E-05,   1.8804665E-05,   1.9772244E-05
     +,   2.0770096E-05,   2.1797381E-05,   2.2853012E-05
     +,   2.3935529E-05,   2.5043348E-05,   2.6174443E-05
     +,   2.7326645E-05,   2.8497327E-05,   2.9683715E-05
     +,   3.0882569E-05,   3.2090524E-05,   3.3303753E-05
     +,   3.4518293E-05,   3.5729940E-05,   3.6934180E-05
     +,   3.8126316E-05,   3.9301583E-05,   4.0455110E-05
     +,   4.1581839E-05,   4.2676878E-05,   4.3735221E-05
     +,   4.4752116E-05,   4.5722831E-05,   4.6643010E-05
     +,   4.7508449E-05,   4.8315425E-05,   4.9060513E-05
     +,   4.9740840E-05,   5.0354047E-05,   5.0898321E-05
     +,   5.1372455E-05,   5.1775947E-05,   5.2108961E-05
     +,   5.2372357E-05,   5.2567724E-05,   5.2697367E-05
     +,   5.2764339E-05,   5.2772353E-05,   5.2725838E-05
     +,   5.2629857E-05,   5.2490075E-05,   5.2312724E-05
     +,   5.2104519E-05,   5.1872608E-05,   5.1624491E-05
     +,   5.1367988E-05,   5.1111092E-05,   5.0861923E-05
     +,   5.0628656E-05,   5.0419425E-05,   5.0242215E-05
     +,   5.0104827E-05,   5.0014769E-05,   4.9979182E-05
     +,   5.0004772E-05,   5.0097740E-05,   5.0263723E-05
     +,   5.0507748E-05,   5.0834133E-05,   5.1246490E-05
     +,   5.1747640E-05,   5.2339597E-05,   5.3023592E-05
     +,   5.3799875E-05,   5.4667900E-05,   5.5626151E-05
     +,   5.6672241E-05,   5.7802776E-05,   5.9013550E-05
     +,   6.0299310E-05,   6.1654035E-05,   6.3070722E-05
     +,   6.4541644E-05,   6.6058281E-05,   6.7611378E-05
     +,   6.9190981E-05,   7.0786795E-05,   7.2388066E-05
     +,   7.3983669E-05,   7.5562384E-05,   7.7113124E-05
     +,   7.8625046E-05,   8.0087542E-05,   8.1490813E-05
     +,   8.2825878E-05,   8.4084742E-05,   8.5260668E-05
     +,   8.6348526E-05,   8.7344895E-05,   8.8248205E-05
     +,   8.9059111E-05,   8.9780653E-05,   9.0418544E-05
     +,   9.0981310E-05,   9.1480666E-05,   9.1932030E-05
     +,   9.2354749E-05,   9.2772796E-05,   9.3215407E-05
     +,   9.3718118E-05,   9.4323535E-05,   9.5082971E-05
     +,   9.6057534E-05,   9.7320037E-05,   9.8956436E-05
     +,   1.0106737E-04,   1.0376982E-04,   1.0719798E-04
     +,   1.1150303E-04,   1.1685240E-04,   1.2342804E-04
     +,   1.3142212E-04,   1.4103032E-04,   1.5244581E-04
     +,   1.6584857E-04,   1.8139381E-04,   1.9919992E-04
     +,   2.1933828E-04,   2.4182136E-04,   2.6659315E-04
     +,   2.9352613E-04,   3.2242475E-04,   3.5303290E-04
     +,   3.8504793E-04,   4.1814693E-04,   4.5202262E-04
     +,   4.8641837E-04,   5.2116642E-04,   5.5623142E-04
     +,   5.9173355E-04,   6.2795222E-04,   6.6530454E-04
     +,   7.0428656E-04,   7.4537355E-04,   7.8888948E-04
     +,   8.3488697E-04,   8.8307197E-04,   9.3284389E-04
     +,   9.8352833E-04,   1.0348966E-03,   1.0879943E-03
     +,   1.1462396E-03,   1.2165861E-03,   1.3104402E-03
     +,   1.4440158E-03,   1.6382709E-03,   1.9189708E-03
     +,   2.3164542E-03,   2.8612365E-03,   3.5700751E-03
     +,   4.4276118E-03,   5.3920727E-03,   6.4639417E-03
     +,   7.8093144E-03,   9.7874086E-03,   1.2643307E-02
     +,   1.6033186E-02,   1.9168533E-02,   2.1933537E-02
     +,   2.5773071E-02,   3.1959556E-02,   3.8516473E-02
     +,   4.2348135E-02,   4.3149106E-02,   4.0941980E-02
     +,   3.5685856E-02,   2.9074626E-02,   2.2495819E-02
     +,   1.6816130E-02,   1.2516851E-02,   9.3643917E-03
     +,   6.9491346E-03,   5.0319759E-03,   3.5056747E-03
     +,   2.3346343E-03,   1.5005635E-03,   9.5788570E-04
     +,   6.3256972E-04,   4.4768752E-04,   3.4327671E-04
     +,   2.8084122E-04,   2.3895739E-04,   2.0708620E-04
     +,   1.8066957E-04,   1.5801525E-04,   1.3858434E-04
     +,   1.2216753E-04,   1.0854931E-04,   9.7411030E-05
     +,   8.8348737E-05,   8.0928170E-05,   7.4739633E-05
     +,   6.9436173E-05,   6.4751162E-05,   6.0497179E-05
     +,   5.6553221E-05,   5.2847565E-05,   4.9341699E-05
     +,   4.6017001E-05,   4.2864976E-05,   3.9880961E-05
     +,   3.7061065E-05,   3.4400859E-05,   3.1894437E-05
     +,   2.9534909E-05,   2.7314920E-05,   2.5226878E-05
     +,   2.3263243E-05,   2.1416901E-05,   1.9681469E-05
     +,   1.8051187E-05,   1.6520853E-05,   1.5085851E-05
     +,   1.3742238E-05,   1.2486285E-05,   1.1314738E-05
     +,   1.0224398E-05,   9.2123264E-06,   8.2755032E-06
     +,   7.4110221E-06,   6.6158186E-06,   5.8868604E-06
     +,   5.2209393E-06,   4.6148557E-06,   4.0652731E-06
     +,   3.5688099E-06,   3.1221032E-06,   2.7217220E-06
     +,   2.3643131E-06,   2.0465252E-06,   1.7651251E-06
     +,   1.5169413E-06,   1.2989589E-06,   1.1082705E-06
     +,   9.4215085E-07,   7.9801572E-07,   6.7347395E-07
     +,   5.6629369E-07,   4.7443561E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz113 = Yx/0.120536585365854
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7953872E-06,   1.9416675E-06
     +,   2.0973464E-06,   2.2627923E-06,   2.4383685E-06
     +,   2.6244293E-06,   2.8213176E-06,   3.0293654E-06
     +,   3.2488849E-06,   3.4801806E-06,   3.7235277E-06
     +,   3.9791826E-06,   4.2473753E-06,   4.5283105E-06
     +,   4.8221614E-06,   5.1290676E-06,   5.4491388E-06
     +,   5.7824441E-06,   6.1290170E-06,   6.4888513E-06
     +,   6.8618942E-06,   7.2480593E-06,   7.6471997E-06
     +,   8.0591617E-06,   8.4836920E-06,   8.9205450E-06
     +,   9.3694043E-06,   9.8299224E-06,   1.0301704E-05
     +,   1.0784323E-05,   1.1277317E-05,   1.1780195E-05
     +,   1.2292438E-05,   1.2813511E-05,   1.3342860E-05
     +,   1.3879925E-05,   1.4424150E-05,   1.4974976E-05
     +,   1.5531896E-05,   1.6094371E-05,   1.6661961E-05
     +,   1.7234244E-05,   1.7810864E-05,   1.8391545E-05
     +,   1.8976094E-05,   1.9564419E-05,   2.0156544E-05
     +,   2.0752614E-05,   2.1352922E-05,   2.1957905E-05
     +,   2.2568167E-05,   2.3184484E-05,   2.3807801E-05
     +,   2.4439301E-05,   2.5080284E-05,   2.5732323E-05
     +,   2.6397140E-05,   2.7076661E-05,   2.7773014E-05
     +,   2.8488490E-05,   2.9225546E-05,   2.9986801E-05
     +,   3.0774932E-05,   3.1592786E-05,   3.2443266E-05
     +,   3.3329208E-05,   3.4253564E-05,   3.5219095E-05
     +,   3.6228557E-05,   3.7284448E-05,   3.8389171E-05
     +,   3.9544688E-05,   4.0752813E-05,   4.2014803E-05
     +,   4.3331580E-05,   4.4703596E-05,   4.6130652E-05
     +,   4.7611971E-05,   4.9146234E-05,   5.0731487E-05
     +,   5.2364947E-05,   5.4043354E-05,   5.5762594E-05
     +,   5.7518075E-05,   5.9304417E-05,   6.1115868E-05
     +,   6.2945932E-05,   6.4787979E-05,   6.6634762E-05
     +,   6.8479050E-05,   7.0313494E-05,   7.2130679E-05
     +,   7.3923453E-05,   7.5685050E-05,   7.7409313E-05
     +,   7.9090554E-05,   8.0724181E-05,   8.2306418E-05
     +,   8.3834821E-05,   8.5308086E-05,   8.6726526E-05
     +,   8.8091714E-05,   8.9407098E-05,   9.0677502E-05
     +,   9.1909504E-05,   9.3111339E-05,   9.4292649E-05
     +,   9.5464507E-05,   9.6639327E-05,   9.7830634E-05
     +,   9.9052668E-05,   1.0032042E-04,   1.0164907E-04
     +,   1.0305388E-04,   1.0454963E-04,   1.0615060E-04
     +,   1.0786985E-04,   1.0971923E-04,   1.1170871E-04
     +,   1.1384640E-04,   1.1613825E-04,   1.1858748E-04
     +,   1.2119475E-04,   1.2395807E-04,   1.2687271E-04
     +,   1.2993084E-04,   1.3312236E-04,   1.3643416E-04
     +,   1.3985137E-04,   1.4335646E-04,   1.4693075E-04
     +,   1.5055368E-04,   1.5420426E-04,   1.5786049E-04
     +,   1.6150057E-04,   1.6510309E-04,   1.6864712E-04
     +,   1.7211282E-04,   1.7548208E-04,   1.7873845E-04
     +,   1.8186738E-04,   1.8485643E-04,   1.8769558E-04
     +,   1.9037725E-04,   1.9289581E-04,   1.9524831E-04
     +,   1.9743397E-04,   1.9945385E-04,   2.0131104E-04
     +,   2.0301054E-04,   2.0455895E-04,   2.0596429E-04
     +,   2.0723605E-04,   2.0838511E-04,   2.0942382E-04
     +,   2.1036551E-04,   2.1122540E-04,   2.1202007E-04
     +,   2.1276799E-04,   2.1348940E-04,   2.1420677E-04
     +,   2.1494488E-04,   2.1573094E-04,   2.1659452E-04
     +,   2.1756813E-04,   2.1868639E-04,   2.1998642E-04
     +,   2.2150707E-04,   2.2328903E-04,   2.2537392E-04
     +,   2.2780386E-04,   2.3062091E-04,   2.3386648E-04
     +,   2.3758104E-04,   2.4180286E-04,   2.4656893E-04
     +,   2.5191411E-04,   2.5787082E-04,   2.6446953E-04
     +,   2.7173883E-04,   2.7970524E-04,   2.8839250E-04
     +,   2.9782069E-04,   3.0800706E-04,   3.1896270E-04
     +,   3.3069259E-04,   3.4319400E-04,   3.5645743E-04
     +,   3.7046877E-04,   3.8521047E-04,   4.0067223E-04
     +,   4.1686030E-04,   4.3381090E-04,   4.5161039E-04
     +,   4.7041496E-04,   4.9047178E-04,   5.1213283E-04
     +,   5.3586089E-04,   5.6222337E-04,   5.9186388E-04
     +,   6.2546501E-04,   6.6372380E-04,   7.0738664E-04
     +,   7.5739488E-04,   8.1518694E-04,   8.8315731E-04
     +,   9.6512720E-04,   1.0666668E-03,   1.1952680E-03
     +,   1.3606718E-03,   1.5756203E-03,   1.8564885E-03
     +,   2.2230141E-03,   2.7003735E-03,   3.3335844E-03
     +,   4.2166854E-03,   5.5043311E-03,   7.3549948E-03
     +,   9.8223072E-03,   1.2819801E-02,   1.6297370E-02
     +,   2.0555757E-02,   2.6152357E-02,   3.2949235E-02
     +,   3.9371319E-02,   4.3459058E-02,   4.4692490E-02
     +,   4.3663330E-02,   4.0456444E-02,   3.5043351E-02
     +,   2.8279467E-02,   2.1459809E-02,   1.5505036E-02
     +,   1.0718788E-02,   7.0583834E-03,   4.4222982E-03
     +,   2.6734276E-03,   1.6068195E-03,   9.9952251E-04
     +,   6.6689926E-04,   4.8068486E-04,   3.6442844E-04
     +,   2.8034201E-04,   2.1380032E-04,   1.6068017E-04
     +,   1.1989303E-04,   9.0272915E-05,   6.9931433E-05
     +,   5.6585141E-05,   4.8036221E-05,   4.2489621E-05
     +,   3.8661696E-05,   3.5735393E-05,   3.3246288E-05
     +,   3.0961863E-05,   2.8784963E-05,   2.6688545E-05
     +,   2.4676641E-05,   2.2763503E-05,   2.0963780E-05
     +,   1.9288518E-05,   1.7743752E-05,   1.6330505E-05
     +,   1.5045579E-05,   1.3882581E-05,   1.2832597E-05
     +,   1.1885244E-05,   1.1029499E-05,   1.0254289E-05
     +,   9.5489477E-06,   8.9036503E-06,   8.3096684E-06
     +,   7.7594495E-06,   7.2465978E-06,   6.7658748E-06
     +,   6.3131383E-06,   5.8851156E-06,   5.4793704E-06
     +,   5.0940580E-06,   4.7278859E-06,   4.3798991E-06
     +,   4.0494606E-06,   3.7360808E-06,   3.4394245E-06
     +,   3.1591774E-06,   2.8950835E-06,   2.6468458E-06
     +,   2.4141405E-06,   2.1966259E-06,   1.9938832E-06
     +,   1.8054733E-06,   1.6308873E-06,   1.4695979E-06
     +,   1.3210228E-06,   1.1845706E-06,   1.0596110E-06
     +,   9.4551751E-07,   8.4164020E-07,   7.4734402E-07
     +,   6.6198476E-07,   5.8494112E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz114 = Yx/0.122166666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.2103222E-10,   6.6080502E-10
     +,   8.3755985E-10,   1.0608329E-09,   1.3425153E-09
     +,   1.6973947E-09,   2.1438171E-09,   2.7044691E-09
     +,   3.4073180E-09,   4.2867860E-09,   5.3850124E-09
     +,   6.7534893E-09,   8.4548875E-09,   1.0565230E-08
     +,   1.3176397E-08,   1.6399021E-08,   2.0365814E-08
     +,   2.5235357E-08,   3.1196382E-08,   3.8472578E-08
     +,   4.7328044E-08,   5.8073123E-08,   7.1070808E-08
     +,   8.6745047E-08,   1.0558572E-07,   1.2816035E-07
     +,   1.5512002E-07,   1.8720942E-07,   2.2527604E-07
     +,   2.7027951E-07,   3.2330044E-07,   3.8554970E-07
     +,   4.5837621E-07,   5.4327433E-07,   6.4189032E-07
     +,   7.5602566E-07,   8.8764051E-07,   1.0388499E-06
     +,   1.2119348E-06,   1.4093039E-06,   1.6335262E-06
     +,   1.8872807E-06,   2.1733547E-06,   2.4946146E-06
     +,   2.8539796E-06,   3.2543860E-06,   3.6987472E-06
     +,   4.1899084E-06,   4.7306003E-06,   5.3233812E-06
     +,   5.9705822E-06,   6.6742464E-06,   7.4360487E-06
     +,   8.2573015E-06,   9.1387474E-06,   1.0080681E-05
     +,   1.1082744E-05,   1.2143938E-05,   1.3262565E-05
     +,   1.4436187E-05,   1.5661606E-05,   1.6934850E-05
     +,   1.8251087E-05,   1.9604793E-05,   2.0989712E-05
     +,   2.2398715E-05,   2.3824214E-05,   2.5257832E-05
     +,   2.6690872E-05,   2.8114047E-05,   2.9517967E-05
     +,   3.0892872E-05,   3.2229145E-05,   3.3517113E-05
     +,   3.4747438E-05,   3.5911184E-05,   3.6999852E-05
     +,   3.8005612E-05,   3.8921477E-05,   3.9741375E-05
     +,   4.0460160E-05,   4.1073854E-05,   4.1579588E-05
     +,   4.1975760E-05,   4.2261963E-05,   4.2439086E-05
     +,   4.2509208E-05,   4.2475651E-05,   4.2342868E-05
     +,   4.2116390E-05,   4.1802716E-05,   4.1409254E-05
     +,   4.0944178E-05,   4.0416260E-05,   3.9834795E-05
     +,   3.9209473E-05,   3.8550170E-05,   3.7866917E-05
     +,   3.7169655E-05,   3.6468242E-05,   3.5772191E-05
     +,   3.5090769E-05,   3.4432695E-05,   3.3806289E-05
     +,   3.3219228E-05,   3.2678621E-05,   3.2190994E-05
     +,   3.1762287E-05,   3.1397820E-05,   3.1102376E-05
     +,   3.0880292E-05,   3.0735453E-05,   3.0671465E-05
     +,   3.0691688E-05,   3.0799394E-05,   3.0997930E-05
     +,   3.1290765E-05,   3.1681760E-05,   3.2175212E-05
     +,   3.2776101E-05,   3.3490192E-05,   3.4324177E-05
     +,   3.5285779E-05,   3.6383903E-05,   3.7628710E-05
     +,   3.9031445E-05,   4.0604664E-05,   4.2361818E-05
     +,   4.4317356E-05,   4.6486075E-05,   4.8883125E-05
     +,   5.1523068E-05,   5.4419790E-05,   5.7585195E-05
     +,   6.1029023E-05,   6.4757784E-05,   6.8773603E-05
     +,   7.3073541E-05,   7.7649063E-05,   8.2485050E-05
     +,   8.7558787E-05,   9.2839895E-05,   9.8290409E-05
     +,   1.0386458E-04,   1.0950864E-04,   1.1516271E-04
     +,   1.2076123E-04,   1.2623415E-04,   1.3150886E-04
     +,   1.3651281E-04,   1.4117513E-04,   1.4542890E-04
     +,   1.4921410E-04,   1.5247987E-04,   1.5518689E-04
     +,   1.5730907E-04,   1.5883549E-04,   1.5977189E-04
     +,   1.6014096E-04,   1.5998282E-04,   1.5935449E-04
     +,   1.5832862E-04,   1.5699214E-04,   1.5544391E-04
     +,   1.5379151E-04,   1.5214839E-04,   1.5063032E-04
     +,   1.4935120E-04,   1.4841931E-04,   1.4793339E-04
     +,   1.4797921E-04,   1.4862594E-04,   1.4992380E-04
     +,   1.5190206E-04,   1.5456803E-04,   1.5790758E-04
     +,   1.6188670E-04,   1.6645412E-04,   1.7154614E-04
     +,   1.7709302E-04,   1.8302609E-04,   1.8928577E-04
     +,   1.9583086E-04,   2.0264782E-04,   2.0975822E-04
     +,   2.1722451E-04,   2.2515428E-04,   2.3370174E-04
     +,   2.4306643E-04,   2.5349009E-04,   2.6525761E-04
     +,   2.7870003E-04,   2.9420605E-04,   3.1224548E-04
     +,   3.3340743E-04,   3.5844746E-04,   3.8833640E-04
     +,   4.2430169E-04,   4.6783846E-04,   5.2066462E-04
     +,   5.8460637E-04,   6.6143228E-04,   7.5267535E-04
     +,   8.5949659E-04,   9.8264928E-04,   1.1225690E-03
     +,   1.2793955E-03,   1.4527496E-03,   1.6412551E-03
     +,   1.8423103E-03,   2.0532138E-03,   2.2747815E-03
     +,   2.5168774E-03,   2.8019170E-03,   3.1603100E-03
     +,   3.6182238E-03,   4.1960962E-03,   4.9464800E-03
     +,   6.0197893E-03,   7.6577780E-03,   9.9980794E-03
     +,   1.2785315E-02,   1.5440673E-02,   1.7975392E-02
     +,   2.1876160E-02,   2.8636044E-02,   3.6892660E-02
     +,   4.2946167E-02,   4.5434777E-02,   4.5148477E-02
     +,   4.0948786E-02,   3.2741338E-02,   2.4083335E-02
     +,   1.7093858E-02,   1.1288948E-02,   6.7407028E-03
     +,   3.7847629E-03,   2.1180080E-03,   1.2447509E-03
     +,   8.0159062E-04,   5.5938750E-04,   3.9930354E-04
     +,   2.7816882E-04,   1.8621156E-04,   1.2107421E-04
     +,   7.8959260E-05,   5.4050288E-05,   4.0261843E-05
     +,   3.2713910E-05,   2.8216471E-05,   2.5018278E-05
     +,   2.2307111E-05,   1.9774885E-05,   1.7342365E-05
     +,   1.5017017E-05,   1.2830382E-05,   1.0813844E-05
     +,   8.9903842E-06,   7.3726446E-06,   5.9636204E-06
     +,   4.7581793E-06,   3.7447194E-06,   2.9069854E-06
     +,   2.2259146E-06,   1.6812195E-06,   1.2525308E-06
     +,   9.2044365E-07,   6.6720196E-07,   4.7706322E-07
     +,   3.3647487E-07,   2.3409198E-07,   1.6065295E-07
     +,   1.0876102E-07,   7.2635089E-08,   4.7853888E-08
     +,   3.1104136E-08,   1.9946446E-08,   1.2621534E-08
     +,   7.8813427E-09,   4.8575872E-09,   2.9557694E-09
     +,   1.7763157E-09,   1.0548217E-09,   6.1941791E-10
     +,   3.6006423E-10,   2.0751202E-10,   1.1882428E-10
     +,   6.7806580E-11,   3.8721713E-11,   2.2248087E-11
     +,   1.2948118E-11,   7.6902599E-12,   4.6955747E-12
     +,   2.9640656E-12,   1.9393673E-12,   1.3137033E-12
     +,   9.1737403E-13,   6.5639090E-13,   4.7817360E-13
     +,   3.5264882E-13,   2.6210826E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz115 = Yx/0.11319512195122
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.2651937E-08,   4.9273837E-08
     +,   5.6818827E-08,   6.5398353E-08,   7.5134629E-08
     +,   8.6161371E-08,   9.8624582E-08,   1.1268292E-07
     +,   1.2850830E-07,   1.4628729E-07,   1.6622053E-07
     +,   1.8852364E-07,   2.1342777E-07,   2.4117998E-07
     +,   2.7204291E-07,   3.0629587E-07,   3.4423360E-07
     +,   3.8616722E-07,   4.3242341E-07,   4.8334391E-07
     +,   5.3928494E-07,   6.0061706E-07,   6.6772191E-07
     +,   7.4099796E-07,   8.2084574E-07,   9.0768299E-07
     +,   1.0019299E-06,   1.1040141E-06,   1.2143666E-06
     +,   1.3334192E-06,   1.4616039E-06,   1.5993509E-06
     +,   1.7470850E-06,   1.9052228E-06,   2.0741732E-06
     +,   2.2543347E-06,   2.4460915E-06,   2.6498096E-06
     +,   2.8658533E-06,   3.0945450E-06,   3.3362132E-06
     +,   3.5911548E-06,   3.8596490E-06,   4.1419571E-06
     +,   4.4383250E-06,   4.7489780E-06,   5.0741287E-06
     +,   5.4139755E-06,   5.7687048E-06,   6.1384958E-06
     +,   6.5235236E-06,   6.9239595E-06,   7.3399701E-06
     +,   7.7717523E-06,   8.2194647E-06,   8.6833243E-06
     +,   9.1635338E-06,   9.6603198E-06,   1.0173920E-05
     +,   1.0704598E-05,   1.1252627E-05,   1.1818310E-05
     +,   1.2401920E-05,   1.3003791E-05,   1.3624252E-05
     +,   1.4263581E-05,   1.4922108E-05,   1.5600062E-05
     +,   1.6297725E-05,   1.7015236E-05,   1.7752758E-05
     +,   1.8510282E-05,   1.9287796E-05,   2.0085072E-05
     +,   2.0901824E-05,   2.1737605E-05,   2.2591752E-05
     +,   2.3463412E-05,   2.4351570E-05,   2.5255005E-05
     +,   2.6172169E-05,   2.7101391E-05,   2.8040620E-05
     +,   2.8987699E-05,   2.9940074E-05,   3.0895080E-05
     +,   3.1849711E-05,   3.2800832E-05,   3.3745018E-05
     +,   3.4678786E-05,   3.5598485E-05,   3.6500347E-05
     +,   3.7380574E-05,   3.8235405E-05,   3.9061200E-05
     +,   3.9854378E-05,   4.0611681E-05,   4.1330051E-05
     +,   4.2006948E-05,   4.2640186E-05,   4.3228283E-05
     +,   4.3770331E-05,   4.4266260E-05,   4.4716842E-05
     +,   4.5123812E-05,   4.5489989E-05,   4.5819277E-05
     +,   4.6116787E-05,   4.6388912E-05,   4.6643319E-05
     +,   4.6888945E-05,   4.7136062E-05,   4.7396119E-05
     +,   4.7681770E-05,   4.8006674E-05,   4.8385391E-05
     +,   4.8833121E-05,   4.9365543E-05,   4.9998387E-05
     +,   5.0747243E-05,   5.1627161E-05,   5.2652129E-05
     +,   5.3834723E-05,   5.5185723E-05,   5.6713641E-05
     +,   5.8424055E-05,   6.0319617E-05,   6.2399144E-05
     +,   6.4657899E-05,   6.7086650E-05,   6.9672213E-05
     +,   7.2396673E-05,   7.5238109E-05,   7.8170066E-05
     +,   8.1162420E-05,   8.4181571E-05,   8.7190681E-05
     +,   9.0150592E-05,   9.3020695E-05,   9.5759533E-05
     +,   9.8325516E-05,   1.0067807E-04,   1.0277865E-04
     +,   1.0459156E-04,   1.0608457E-04,   1.0723022E-04
     +,   1.0800626E-04,   1.0839642E-04,   1.0839082E-04
     +,   1.0798660E-04,   1.0718805E-04,   1.0600690E-04
     +,   1.0446240E-04,   1.0258119E-04,   1.0039716E-04
     +,   9.7951488E-05,   9.5292329E-05,   9.2474234E-05
     +,   8.9558001E-05,   8.6610657E-05,   8.3704472E-05
     +,   8.0916805E-05,   7.8329766E-05,   7.6029522E-05
     +,   7.4105323E-05,   7.2648909E-05,   7.1753573E-05
     +,   7.1512521E-05,   7.2017421E-05,   7.3356641E-05
     +,   7.5612814E-05,   7.8860481E-05,   8.3163490E-05
     +,   8.8572291E-05,   9.5120311E-05,   1.0282238E-04
     +,   1.1167194E-04,   1.2163865E-04,   1.3266750E-04
     +,   1.4467955E-04,   1.5757234E-04,   1.7122057E-04
     +,   1.8548036E-04,   2.0019367E-04,   2.1519298E-04
     +,   2.3030512E-04,   2.4535769E-04,   2.6018545E-04
     +,   2.7463376E-04,   2.8856017E-04,   3.0184042E-04
     +,   3.1436706E-04,   3.2604963E-04,   3.3681552E-04
     +,   3.4661297E-04,   3.5541656E-04,   3.6324273E-04
     +,   3.7018166E-04,   3.7645313E-04,   3.8249372E-04
     +,   3.8908486E-04,   3.9751647E-04,   4.0976444E-04
     +,   4.2863094E-04,   4.5776222E-04,   5.0145743E-04
     +,   5.6419289E-04,   6.4988708E-04,   7.6109858E-04
     +,   8.9846557E-04,   1.0606890E-03,   1.2452025E-03
     +,   1.4494627E-03,   1.6726542E-03,   1.9176429E-03
     +,   2.1929895E-03,   2.5142869E-03,   2.9033984E-03
     +,   3.3864812E-03,   4.0018465E-03,   4.8378860E-03
     +,   6.0865032E-03,   7.9979971E-03,   1.0626213E-02
     +,   1.3762736E-02,   1.7658601E-02,   2.3273505E-02
     +,   3.0817948E-02,   3.8338441E-02,   4.3699943E-02
     +,   4.6884030E-02,   4.7009967E-02,   4.1882016E-02
     +,   3.1329077E-02,   1.9342043E-02,   1.0137051E-02
     +,   4.7282795E-03,   2.1414084E-03,   1.1198755E-03
     +,   7.6326687E-04,   6.2525354E-04,   5.4828409E-04
     +,   4.8586898E-04,   4.2478868E-04,   3.6383903E-04
     +,   3.0611543E-04,   2.5469152E-04,   2.1099969E-04
     +,   1.7496366E-04,   1.4568379E-04,   1.2200928E-04
     +,   1.0285897E-04,   8.7334338E-05,   7.4720672E-05
     +,   6.4449072E-05,   5.6057223E-05,   4.9161739E-05
     +,   4.3442225E-05,   3.8634105E-05,   3.4525019E-05
     +,   3.0950523E-05,   2.7787813E-05,   2.4948509E-05
     +,   2.2371441E-05,   2.0015883E-05,   1.7855011E-05
     +,   1.5871365E-05,   1.4053346E-05,   1.2392464E-05
     +,   1.0881512E-05,   9.5136566E-06,   8.2819170E-06
     +,   7.1788018E-06,   6.1962246E-06,   5.3256904E-06
     +,   4.5585184E-06,   3.8858389E-06,   3.2989681E-06
     +,   2.7893809E-06,   2.3489958E-06,   1.9701249E-06
     +,   1.6456568E-06,   1.3689902E-06,   1.1341342E-06
     +,   9.3563068E-07,   7.6860130E-07,   6.2867264E-07
     +,   5.1196793E-07,   4.1508048E-07,   3.3500908E-07
     +,   2.6914870E-07,   2.1523044E-07,   1.7130461E-07
     +,   1.3569229E-07,   1.0696530E-07,   8.3907850E-08
     +,   6.5496636E-08,   5.0870394E-08,   3.9312432E-08
     +,   3.0226662E-08,   2.3122706E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz116 = Yx/0.104487804878049
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2544092E-05,   1.2807911E-05
     +,   1.3068645E-05,   1.3326026E-05,   1.3579793E-05
     +,   1.3829707E-05,   1.4075544E-05,   1.4317101E-05
     +,   1.4554189E-05,   1.4786657E-05,   1.5014361E-05
     +,   1.5237187E-05,   1.5455047E-05,   1.5667878E-05
     +,   1.5875645E-05,   1.6078338E-05,   1.6275981E-05
     +,   1.6468623E-05,   1.6656339E-05,   1.6839243E-05
     +,   1.7017474E-05,   1.7191194E-05,   1.7360608E-05
     +,   1.7525945E-05,   1.7687453E-05,   1.7845427E-05
     +,   1.8000175E-05,   1.8152037E-05,   1.8301378E-05
     +,   1.8448589E-05,   1.8594083E-05,   1.8738296E-05
     +,   1.8881678E-05,   1.9024703E-05,   1.9167863E-05
     +,   1.9311661E-05,   1.9456607E-05,   1.9603227E-05
     +,   1.9752057E-05,   1.9903628E-05,   2.0058482E-05
     +,   2.0217161E-05,   2.0380205E-05,   2.0548141E-05
     +,   2.0721496E-05,   2.0900796E-05,   2.1086544E-05
     +,   2.1279231E-05,   2.1479345E-05,   2.1687349E-05
     +,   2.1903696E-05,   2.2128821E-05,   2.2363134E-05
     +,   2.2607052E-05,   2.2860942E-05,   2.3125192E-05
     +,   2.3400155E-05,   2.3686187E-05,   2.3983626E-05
     +,   2.4292818E-05,   2.4614103E-05,   2.4947834E-05
     +,   2.5294357E-05,   2.5654055E-05,   2.6027352E-05
     +,   2.6414644E-05,   2.6816428E-05,   2.7233189E-05
     +,   2.7665521E-05,   2.8114018E-05,   2.8579398E-05
     +,   2.9062381E-05,   2.9563844E-05,   3.0084670E-05
     +,   3.0625888E-05,   3.1188596E-05,   3.1773965E-05
     +,   3.2383243E-05,   3.3017812E-05,   3.3679120E-05
     +,   3.4368641E-05,   3.5087985E-05,   3.5838741E-05
     +,   3.6622601E-05,   3.7441197E-05,   3.8296250E-05
     +,   3.9189355E-05,   4.0122148E-05,   4.1096089E-05
     +,   4.2112584E-05,   4.3172928E-05,   4.4278157E-05
     +,   4.5429089E-05,   4.6626352E-05,   4.7870311E-05
     +,   4.9160884E-05,   5.0497809E-05,   5.1880277E-05
     +,   5.3307231E-05,   5.4777011E-05,   5.6287699E-05
     +,   5.7836707E-05,   5.9421196E-05,   6.1037630E-05
     +,   6.2682171E-05,   6.4350519E-05,   6.6037865E-05
     +,   6.7738918E-05,   6.9448193E-05,   7.1159819E-05
     +,   7.2867471E-05,   7.4564850E-05,   7.6245218E-05
     +,   7.7901961E-05,   7.9528174E-05,   8.1117199E-05
     +,   8.2662234E-05,   8.4156891E-05,   8.5594751E-05
     +,   8.6969871E-05,   8.8276633E-05,   8.9509784E-05
     +,   9.0664507E-05,   9.1736583E-05,   9.2722374E-05
     +,   9.3618692E-05,   9.4423129E-05,   9.5133764E-05
     +,   9.5749434E-05,   9.6269541E-05,   9.6694173E-05
     +,   9.7024058E-05,   9.7260512E-05,   9.7405435E-05
     +,   9.7461430E-05,   9.7431577E-05,   9.7319571E-05
     +,   9.7129639E-05,   9.6866606E-05,   9.6535841E-05
     +,   9.6143383E-05,   9.5695941E-05,   9.5200849E-05
     +,   9.4666277E-05,   9.4101393E-05,   9.3516348E-05
     +,   9.2922499E-05,   9.2332673E-05,   9.1761285E-05
     +,   9.1224632E-05,   9.0741189E-05,   9.0331909E-05
     +,   9.0020520E-05,   8.9833869E-05,   8.9802088E-05
     +,   8.9959205E-05,   9.0343019E-05,   9.0995338E-05
     +,   9.1962327E-05,   9.3293878E-05,   9.5043790E-05
     +,   9.7269061E-05,   1.0002906E-04,   1.0338447E-04
     +,   1.0739615E-04,   1.1212343E-04,   1.1762162E-04
     +,   1.2394003E-04,   1.3111973E-04,   1.3919074E-04
     +,   1.4816853E-04,   1.5805170E-04,   1.6882019E-04
     +,   1.8043256E-04,   1.9282319E-04,   2.0590353E-04
     +,   2.1956088E-04,   2.3365859E-04,   2.4803868E-04
     +,   2.6252581E-04,   2.7693118E-04,   2.9105649E-04
     +,   3.0470212E-04,   3.1767474E-04,   3.2979570E-04
     +,   3.4090827E-04,   3.5088896E-04,   3.5965719E-04
     +,   3.6718469E-04,   3.7350415E-04,   3.7872107E-04
     +,   3.8302131E-04,   3.8668033E-04,   3.9007328E-04
     +,   3.9368399E-04,   3.9811592E-04,   4.0410299E-04
     +,   4.1252156E-04,   4.2440067E-04,   4.4092612E-04
     +,   4.6342955E-04,   4.9335486E-04,   5.3219503E-04
     +,   5.8139017E-04,   6.4220408E-04,   7.1564788E-04
     +,   8.0250180E-04,   9.0352242E-04,   1.0198395E-03
     +,   1.1533470E-03,   1.3066363E-03,   1.4820243E-03
     +,   1.6797766E-03,   1.8969077E-03,   2.1292770E-03
     +,   2.3794125E-03,   2.6684713E-03,   3.0440693E-03
     +,   3.5716237E-03,   4.3035480E-03,   5.2435729E-03
     +,   6.3495822E-03,   7.6067890E-03,   9.1365594E-03
     +,   1.1248842E-02,   1.4331251E-02,   1.8542096E-02
     +,   2.3581788E-02,   2.8925326E-02,   3.4313161E-02
     +,   3.9625444E-02,   4.3629549E-02,   4.3591525E-02
     +,   3.7915681E-02,   2.8422153E-02,   1.8598380E-02
     +,   1.0813075E-02,   5.7297563E-03,   2.9524863E-03
     +,   1.6514980E-03,   1.0627159E-03,   7.4169418E-04
     +,   5.1923853E-04,   3.5427578E-04,   2.3791255E-04
     +,   1.6134650E-04,   1.1318817E-04,   8.3082865E-05
     +,   6.3748048E-05,   5.0850183E-05,   4.2004944E-05
     +,   3.5854064E-05,   3.1514035E-05,   2.8340573E-05
     +,   2.5858637E-05,   2.3742594E-05,   2.1794864E-05
     +,   1.9914763E-05,   1.8065335E-05,   1.6245924E-05
     +,   1.4473116E-05,   1.2769027E-05,   1.1154975E-05
     +,   9.6486729E-06,   8.2632223E-06,   7.0066226E-06
     +,   5.8822316E-06,   4.8893494E-06,   4.0238197E-06
     +,   3.2787013E-06,   2.6450753E-06,   2.1127580E-06
     +,   1.6708618E-06,   1.3083001E-06,   1.0142537E-06
     +,   7.7851286E-07,   5.9163978E-07,   4.4517367E-07
     +,   3.3164545E-07,   2.4462466E-07,   1.7864858E-07
     +,   1.2917593E-07,   9.2477840E-08,   6.5550857E-08
     +,   4.6003915E-08,   3.1966760E-08,   2.1993111E-08
     +,   1.4981532E-08,   1.0104646E-08,   6.7479844E-09
     +,   4.4620263E-09,   2.9214027E-09,   1.8939712E-09
     +,   1.2158468E-09,   7.7292767E-10,   4.8659088E-10
     +,   3.0339059E-10,   1.8736371E-10,   1.1462826E-10
     +,   6.9486021E-11,   4.1748643E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz117 = Yx/0.104125
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.0605666E-06,   6.3069556E-06
     +,   6.5593263E-06,   6.8176200E-06,   7.0817664E-06
     +,   7.3516844E-06,   7.6272809E-06,   7.9084566E-06
     +,   8.1950939E-06,   8.4870817E-06,   8.7842873E-06
     +,   9.0865724E-06,   9.3937915E-06,   9.7057955E-06
     +,   1.0022432E-05,   1.0343541E-05,   1.0668969E-05
     +,   1.0998555E-05,   1.1332147E-05,   1.1669597E-05
     +,   1.2010768E-05,   1.2355531E-05,   1.2703774E-05
     +,   1.3055424E-05,   1.3410388E-05,   1.3768655E-05
     +,   1.4130210E-05,   1.4495095E-05,   1.4863393E-05
     +,   1.5235244E-05,   1.5610842E-05,   1.5990447E-05
     +,   1.6374393E-05,   1.6763097E-05,   1.7157061E-05
     +,   1.7556877E-05,   1.7963250E-05,   1.8376973E-05
     +,   1.8798999E-05,   1.9230338E-05,   1.9672183E-05
     +,   2.0125828E-05,   2.0592708E-05,   2.1074396E-05
     +,   2.1572590E-05,   2.2089129E-05,   2.2625974E-05
     +,   2.3185223E-05,   2.3769064E-05,   2.4379804E-05
     +,   2.5019825E-05,   2.5691581E-05,   2.6397560E-05
     +,   2.7140321E-05,   2.7922320E-05,   2.8746079E-05
     +,   2.9613981E-05,   3.0528317E-05,   3.1491232E-05
     +,   3.2504660E-05,   3.3570323E-05,   3.4689656E-05
     +,   3.5863701E-05,   3.7093210E-05,   3.8378515E-05
     +,   3.9719365E-05,   4.1115185E-05,   4.2564639E-05
     +,   4.4066041E-05,   4.5616871E-05,   4.7214216E-05
     +,   4.8854316E-05,   5.0532977E-05,   5.2245148E-05
     +,   5.3985339E-05,   5.5747492E-05,   5.7524849E-05
     +,   5.9310176E-05,   6.1095961E-05,   6.2874278E-05
     +,   6.4636843E-05,   6.6375382E-05,   6.8081419E-05
     +,   6.9746777E-05,   7.1363298E-05,   7.2923423E-05
     +,   7.4419964E-05,   7.5846670E-05,   7.7198005E-05
     +,   7.8469660E-05,   7.9658617E-05,   8.0763304E-05
     +,   8.1783764E-05,   8.2722079E-05,   8.3582301E-05
     +,   8.4370680E-05,   8.5095984E-05,   8.5769367E-05
     +,   8.6404769E-05,   8.7018743E-05,   8.7630724E-05
     +,   8.8262786E-05,   8.8939785E-05,   8.9689027E-05
     +,   9.0540205E-05,   9.1525028E-05,   9.2676826E-05
     +,   9.4030001E-05,   9.5619624E-05,   9.7480581E-05
     +,   9.9646757E-05,   1.0215037E-04,   1.0502068E-04
     +,   1.0828346E-04,   1.1195929E-04,   1.1606331E-04
     +,   1.2060336E-04,   1.2557984E-04,   1.3098387E-04
     +,   1.3679762E-04,   1.4299330E-04,   1.4953250E-04
     +,   1.5636627E-04,   1.6343605E-04,   1.7067371E-04
     +,   1.7800152E-04,   1.8533519E-04,   1.9258331E-04
     +,   1.9965088E-04,   2.0643968E-04,   2.1285194E-04
     +,   2.1879109E-04,   2.2416562E-04,   2.2888988E-04
     +,   2.3288799E-04,   2.3609458E-04,   2.3845685E-04
     +,   2.3993672E-04,   2.4051165E-04,   2.4017505E-04
     +,   2.3893744E-04,   2.3682584E-04,   2.3388339E-04
     +,   2.3016837E-04,   2.2575379E-04,   2.2072463E-04
     +,   2.1517689E-04,   2.0921565E-04,   2.0295300E-04
     +,   1.9650569E-04,   1.8999318E-04,   1.8353655E-04
     +,   1.7725640E-04,   1.7127072E-04,   1.6569445E-04
     +,   1.6063890E-04,   1.5621049E-04,   1.5251026E-04
     +,   1.4963410E-04,   1.4767288E-04,   1.4671187E-04
     +,   1.4683137E-04,   1.4810647E-04,   1.5060665E-04
     +,   1.5439544E-04,   1.5952962E-04,   1.6605723E-04
     +,   1.7401576E-04,   1.8343038E-04,   1.9431041E-04
     +,   2.0664524E-04,   2.2040098E-04,   2.3551748E-04
     +,   2.5190430E-04,   2.6943526E-04,   2.8794949E-04
     +,   3.0724853E-04,   3.2709533E-04,   3.4721734E-04
     +,   3.6731202E-04,   3.8705237E-04,   4.0609334E-04
     +,   4.2408498E-04,   4.4068563E-04,   4.5557474E-04
     +,   4.6846690E-04,   4.7912778E-04,   4.8738901E-04
     +,   4.9316051E-04,   4.9644080E-04,   4.9732893E-04
     +,   4.9602927E-04,   4.9286062E-04,   4.8826190E-04
     +,   4.8279829E-04,   4.7717144E-04,   4.7222778E-04
     +,   4.6896786E-04,   4.6855144E-04,   4.7229647E-04
     +,   4.8166577E-04,   4.9824000E-04,   5.2367779E-04
     +,   5.5966951E-04,   6.0788944E-04,   6.6999323E-04
     +,   7.4765948E-04,   8.4271590E-04,   9.5734966E-04
     +,   1.0943621E-03,   1.2573285E-03,   1.4504893E-03
     +,   1.6781933E-03,   1.9436888E-03,   2.2473249E-03
     +,   2.5850451E-03,   2.9496918E-03,   3.3387186E-03
     +,   3.7693202E-03,   4.2924746E-03,   4.9866717E-03
     +,   5.9195790E-03,   7.1006138E-03,   8.4683122E-03
     +,   9.9252127E-03,   1.1420896E-02,   1.3134499E-02
     +,   1.5671188E-02,   1.9885464E-02,   2.6273374E-02
     +,   3.4518667E-02,   4.3271471E-02,   4.9879942E-02
     +,   5.0975014E-02,   4.4717256E-02,   3.2907743E-02
     +,   2.0108892E-02,   1.0292316E-02,   4.6240808E-03
     +,   2.0712051E-03,   1.1342595E-03,   8.2215195E-04
     +,   6.9558725E-04,   6.1076501E-04,   5.3370045E-04
     +,   4.6033997E-04,   3.9148497E-04,   3.2788384E-04
     +,   2.7024365E-04,   2.1930691E-04,   1.7556736E-04
     +,   1.3909853E-04,   1.0957371E-04,   8.6358566E-05
     +,   6.8609945E-05,   5.5374865E-05,   4.5689008E-05
     +,   3.8662492E-05,   3.3539323E-05,   2.9723597E-05
     +,   2.6776219E-05,   2.4393397E-05,   2.2377824E-05
     +,   2.0609918E-05,   1.9022746E-05,   1.7582019E-05
     +,   1.6272055E-05,   1.5086456E-05,   1.4022205E-05
     +,   1.3076436E-05,   1.2245052E-05,   1.1522288E-05
     +,   1.0900727E-05,   1.0371628E-05,   9.9254312E-06
     +,   9.5522410E-06,   9.2421269E-06,   8.9855539E-06
     +,   8.7735361E-06,   8.5978900E-06,   8.4512758E-06
     +,   8.3272762E-06,   8.2203669E-06,   8.1258977E-06
     +,   8.0400059E-06,   7.9595575E-06,   7.8820422E-06
     +,   7.8054900E-06,   7.7284021E-06,   7.6496408E-06
     +,   7.5683924E-06,   7.4840805E-06,   7.3963351E-06
     +,   7.3049277E-06,   7.2097646E-06,   7.1108229E-06
     +,   7.0081687E-06,   6.9019006E-06,   6.7921701E-06
     +,   6.6791449E-06,   6.5630256E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz118 = Yx/0.112682926829268
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz1188(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4519584E-05,   1.5036372E-05
     +,   1.5562924E-05,   1.6098658E-05,   1.6642922E-05
     +,   1.7194996E-05,   1.7754081E-05,   1.8319304E-05
     +,   1.8889716E-05,   1.9464318E-05,   2.0042013E-05
     +,   2.0621650E-05,   2.1202011E-05,   2.1781821E-05
     +,   2.2359744E-05,   2.2934395E-05,   2.3504344E-05
     +,   2.4068122E-05,   2.4624231E-05,   2.5171137E-05
     +,   2.5707313E-05,   2.6231204E-05,   2.6741254E-05
     +,   2.7235956E-05,   2.7713768E-05,   2.8173225E-05
     +,   2.8612883E-05,   2.9031351E-05,   2.9427298E-05
     +,   2.9799474E-05,   3.0146704E-05,   3.0467905E-05
     +,   3.0762101E-05,   3.1028423E-05,   3.1266118E-05
     +,   3.1474567E-05,   3.1653282E-05,   3.1801916E-05
     +,   3.1920277E-05,   3.2008316E-05,   3.2066153E-05
     +,   3.2094060E-05,   3.2092488E-05,   3.2062038E-05
     +,   3.2003485E-05,   3.1917785E-05,   3.1806052E-05
     +,   3.1669577E-05,   3.1509793E-05,   3.1328331E-05
     +,   3.1126961E-05,   3.0907609E-05,   3.0672363E-05
     +,   3.0423444E-05,   3.0163237E-05,   2.9894236E-05
     +,   2.9619077E-05,   2.9340517E-05,   2.9061424E-05
     +,   2.8784772E-05,   2.8513632E-05,   2.8251166E-05
     +,   2.8000622E-05,   2.7765305E-05,   2.7548585E-05
     +,   2.7353890E-05,   2.7184669E-05,   2.7044422E-05
     +,   2.6936630E-05,   2.6864824E-05,   2.6832475E-05
     +,   2.6843047E-05,   2.6899967E-05,   2.7006583E-05
     +,   2.7166181E-05,   2.7381951E-05,   2.7656961E-05
     +,   2.7994134E-05,   2.8396238E-05,   2.8865894E-05
     +,   2.9405443E-05,   3.0017083E-05,   3.0702675E-05
     +,   3.1463882E-05,   3.2301974E-05,   3.3217988E-05
     +,   3.4212520E-05,   3.5285870E-05,   3.6437832E-05
     +,   3.7667887E-05,   3.8975082E-05,   4.0357918E-05
     +,   4.1814426E-05,   4.3342276E-05,   4.4938617E-05
     +,   4.6599995E-05,   4.8322680E-05,   5.0102222E-05
     +,   5.1933963E-05,   5.3812575E-05,   5.5732507E-05
     +,   5.7687612E-05,   5.9671584E-05,   6.1677623E-05
     +,   6.3698746E-05,   6.5727836E-05,   6.7757443E-05
     +,   6.9779970E-05,   7.1787988E-05,   7.3773990E-05
     +,   7.5730459E-05,   7.7650235E-05,   7.9526166E-05
     +,   8.1351674E-05,   8.3120271E-05,   8.4826264E-05
     +,   8.6464177E-05,   8.8029410E-05,   8.9517816E-05
     +,   9.0926107E-05,   9.2251823E-05,   9.3493290E-05
     +,   9.4649673E-05,   9.5721196E-05,   9.6709060E-05
     +,   9.7615339E-05,   9.8443226E-05,   9.9196935E-05
     +,   9.9881625E-05,   1.0050362E-04,   1.0107004E-04
     +,   1.0158916E-04,   1.0207006E-04,   1.0252275E-04
     +,   1.0295806E-04,   1.0338763E-04,   1.0382372E-04
     +,   1.0427931E-04,   1.0476794E-04,   1.0530362E-04
     +,   1.0590092E-04,   1.0657463E-04,   1.0734012E-04
     +,   1.0821295E-04,   1.0920897E-04,   1.1034439E-04
     +,   1.1163584E-04,   1.1310015E-04,   1.1475455E-04
     +,   1.1661676E-04,   1.1870501E-04,   1.2103788E-04
     +,   1.2363443E-04,   1.2651434E-04,   1.2969768E-04
     +,   1.3320462E-04,   1.3705522E-04,   1.4126966E-04
     +,   1.4586734E-04,   1.5086608E-04,   1.5628242E-04
     +,   1.6213040E-04,   1.6842052E-04,   1.7515913E-04
     +,   1.8234835E-04,   1.8998438E-04,   1.9805675E-04
     +,   2.0654824E-04,   2.1543457E-04,   2.2468458E-04
     +,   2.3425935E-04,   2.4411379E-04,   2.5419821E-04
     +,   2.6445949E-04,   2.7484237E-04,   2.8529309E-04
     +,   2.9576255E-04,   3.0620777E-04,   3.1659618E-04
     +,   3.2690991E-04,   3.3714823E-04,   3.4732971E-04
     +,   3.5749597E-04,   3.6771421E-04,   3.7807890E-04
     +,   3.8871256E-04,   3.9976757E-04,   4.1142866E-04
     +,   4.2391435E-04,   4.3747813E-04,   4.5241436E-04
     +,   4.6906256E-04,   4.8781038E-04,   5.0910050E-04
     +,   5.3343305E-04,   5.6136324E-04,   5.9349037E-04
     +,   6.3044683E-04,   6.7288522E-04,   7.2146981E-04
     +,   7.7688805E-04,   8.3989149E-04,   9.1137504E-04
     +,   9.9245796E-04,   1.0845328E-03,   1.1892593E-03
     +,   1.3084185E-03,   1.4436410E-03,   1.5961080E-03
     +,   1.7663583E-03,   1.9543446E-03,   2.1598355E-03
     +,   2.3830994E-03,   2.6255767E-03,   2.8901240E-03
     +,   3.1806638E-03,   3.5015310E-03,   3.8571043E-03
     +,   4.2524892E-03,   4.6966146E-03,   5.2094222E-03
     +,   5.8306186E-03,   6.6193989E-03,   7.6396298E-03
     +,   8.9524556E-03,   1.0634240E-02,   1.2770609E-02
     +,   1.5410821E-02,   1.8628869E-02,   2.2657542E-02
     +,   2.7659370E-02,   3.3127844E-02,   3.7632670E-02
     +,   3.9217401E-02,   3.6309462E-02,   2.8996708E-02
     +,   1.9561833E-02,   1.1110132E-02,   5.4758880E-03
     +,   2.5905841E-03,   1.4225662E-03,   1.0202007E-03
     +,   8.6208154E-04,   7.4951310E-04,   6.3419633E-04
     +,   5.1823590E-04,   4.1296572E-04,   3.2554506E-04
     +,   2.5701220E-04,   2.0452714E-04,   1.6416083E-04
     +,   1.3264416E-04,   1.0784312E-04,   8.8478206E-05
     +,   7.3673764E-05,   6.2655636E-05,   5.4648175E-05
     +,   4.8896283E-05,   4.4725886E-05,   4.1589221E-05
     +,   3.9078433E-05,   3.6913501E-05,   3.4917390E-05
     +,   3.2988457E-05,   3.1076077E-05,   2.9161369E-05
     +,   2.7243990E-05,   2.5333546E-05,   2.3444036E-05
     +,   2.1590566E-05,   1.9787683E-05,   1.8048562E-05
     +,   1.6384372E-05,   1.4804038E-05,   1.3314306E-05
     +,   1.1919972E-05,   1.0623676E-05,   9.4264624E-06
     +,   8.3276345E-06,   7.3252927E-06,   6.4162714E-06
     +,   5.5966148E-06,   4.8615566E-06,   4.2059287E-06
     +,   3.6241374E-06,   3.1105017E-06,   2.6592452E-06
     +,   2.2646714E-06,   1.9212898E-06,   1.6237988E-06
     +,   1.3672286E-06,   1.1469015E-06,   9.5851942E-07
     +,   7.9811775E-07,   6.6211629E-07,   5.4726786E-07
     +,   4.5068160E-07,   3.6977437E-07,   3.0227554E-07
     +,   2.4618299E-07,   1.9975653E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz1188 = Yx/0.10045
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0549480E-06,   2.1842363E-06
     +,   2.3201515E-06,   2.4629394E-06,   2.6128509E-06
     +,   2.7701424E-06,   2.9350740E-06,   3.1079114E-06
     +,   3.2889234E-06,   3.4783925E-06,   3.6765989E-06
     +,   3.8838293E-06,   4.1003809E-06,   4.3265518E-06
     +,   4.5626507E-06,   4.8089919E-06,   5.0658950E-06
     +,   5.3336903E-06,   5.6127124E-06,   5.9033059E-06
     +,   6.2058216E-06,   6.5206204E-06,   6.8480622E-06
     +,   7.1885420E-06,   7.5424200E-06,   7.9101019E-06
     +,   8.2919860E-06,   8.6884747E-06,   9.0999811E-06
     +,   9.5269243E-06,   9.9697281E-06,   1.0428817E-05
     +,   1.0904619E-05,   1.1397568E-05,   1.1908085E-05
     +,   1.2436600E-05,   1.2983529E-05,   1.3549274E-05
     +,   1.4134257E-05,   1.4738828E-05,   1.5363375E-05
     +,   1.6008238E-05,   1.6673723E-05,   1.7360115E-05
     +,   1.8067662E-05,   1.8796572E-05,   1.9547000E-05
     +,   2.0319052E-05,   2.1112779E-05,   2.1928168E-05
     +,   2.2765136E-05,   2.3623526E-05,   2.4503088E-05
     +,   2.5403546E-05,   2.6324426E-05,   2.7265280E-05
     +,   2.8225482E-05,   2.9204341E-05,   3.0201050E-05
     +,   3.1214706E-05,   3.2244294E-05,   3.3288718E-05
     +,   3.4346725E-05,   3.5417037E-05,   3.6498281E-05
     +,   3.7588910E-05,   3.8687445E-05,   3.9792176E-05
     +,   4.0901519E-05,   4.2013697E-05,   4.3127060E-05
     +,   4.4239816E-05,   4.5350334E-05,   4.6456895E-05
     +,   4.7557965E-05,   4.8652117E-05,   4.9737951E-05
     +,   5.0814266E-05,   5.1880103E-05,   5.2934734E-05
     +,   5.3977605E-05,   5.5008557E-05,   5.6027682E-05
     +,   5.7035482E-05,   5.8032801E-05,   5.9021018E-05
     +,   6.0001817E-05,   6.0977502E-05,   6.1950792E-05
     +,   6.2924999E-05,   6.3903986E-05,   6.4892185E-05
     +,   6.5894550E-05,   6.6916749E-05,   6.7965062E-05
     +,   6.9046328E-05,   7.0168171E-05,   7.1338720E-05
     +,   7.2567011E-05,   7.3862655E-05,   7.5236159E-05
     +,   7.6698729E-05,   7.8262638E-05,   7.9940954E-05
     +,   8.1747967E-05,   8.3699138E-05,   8.5811182E-05
     +,   8.8102206E-05,   9.0592126E-05,   9.3302646E-05
     +,   9.6257136E-05,   9.9481411E-05,   1.0300300E-04
     +,   1.0685223E-04,   1.1106094E-04,   1.1566366E-04
     +,   1.2069603E-04,   1.2619572E-04,   1.3220041E-04
     +,   1.3874810E-04,   1.4587569E-04,   1.5361716E-04
     +,   1.6200241E-04,   1.7105594E-04,   1.8079468E-04
     +,   1.9122478E-04,   2.0234179E-04,   2.1412600E-04
     +,   2.2654302E-04,   2.3953964E-04,   2.5304532E-04
     +,   2.6696821E-04,   2.8119877E-04,   2.9560633E-04
     +,   3.1004415E-04,   3.2435043E-04,   3.3835002E-04
     +,   3.5185961E-04,   3.6469335E-04,   3.7666698E-04
     +,   3.8760246E-04,   3.9733521E-04,   4.0571968E-04
     +,   4.1263385E-04,   4.1798403E-04,   4.2170909E-04
     +,   4.2378320E-04,   4.2421659E-04,   4.2305709E-04
     +,   4.2038775E-04,   4.1632529E-04,   4.1101637E-04
     +,   4.0463280E-04,   3.9736601E-04,   3.8942086E-04
     +,   3.8101018E-04,   3.7234789E-04,   3.6364232E-04
     +,   3.5509080E-04,   3.4687619E-04,   3.3916059E-04
     +,   3.3208326E-04,   3.2575912E-04,   3.2027694E-04
     +,   3.1569897E-04,   3.1206233E-04,   3.0938114E-04
     +,   3.0764830E-04,   3.0683921E-04,   3.0691540E-04
     +,   3.0782953E-04,   3.0952971E-04,   3.1196597E-04
     +,   3.1509550E-04,   3.1888974E-04,   3.2334088E-04
     +,   3.2846915E-04,   3.3432842E-04,   3.4101240E-04
     +,   3.4865947E-04,   3.5745351E-04,   3.6762198E-04
     +,   3.7943077E-04,   3.9317290E-04,   4.0915355E-04
     +,   4.2766758E-04,   4.4897627E-04,   4.7328571E-04
     +,   5.0072500E-04,   5.3132983E-04,   5.6504703E-04
     +,   6.0174498E-04,   6.4123893E-04,   6.8333012E-04
     +,   7.2785106E-04,   7.7469501E-04,   8.2382269E-04
     +,   8.7524578E-04,   9.2897634E-04,   9.8495290E-04
     +,   1.0429745E-03,   1.1027072E-03,   1.1638080E-03
     +,   1.2262049E-03,   1.2905470E-03,   1.3587795E-03
     +,   1.4346654E-03,   1.5240023E-03,   1.6342835E-03
     +,   1.7735774E-03,   1.9486430E-03,   2.1628044E-03
     +,   2.4146719E-03,   2.6990501E-03,   3.0106932E-03
     +,   3.3500236E-03,   3.7277711E-03,   4.1646464E-03
     +,   4.6841777E-03,   5.3013167E-03,   6.0138707E-03
     +,   6.8043601E-03,   7.6558068E-03,   8.5734054E-03
     +,   9.5910300E-03,   1.0748897E-02,   1.2065665E-02
     +,   1.3555103E-02,   1.5289769E-02,   1.7414615E-02
     +,   1.9997124E-02,   2.2754805E-02,   2.4909293E-02
     +,   2.5427109E-02,   2.3611093E-02,   1.9622628E-02
     +,   1.4476835E-02,   9.4851460E-03,   5.5906516E-03
     +,   3.0680306E-03,   1.6729621E-03,   9.8091748E-04
     +,   6.3968456E-04,   4.4764721E-04,   3.1985971E-04
     +,   2.2931087E-04,   1.6750506E-04,   1.2842227E-04
     +,   1.0546628E-04,   9.2455455E-05,   8.4654486E-05
     +,   7.9011748E-05,   7.3863011E-05,   6.8481386E-05
     +,   6.2683233E-05,   5.6554742E-05,   5.0287799E-05
     +,   4.4091383E-05,   3.8148530E-05,   3.2599419E-05
     +,   2.7537852E-05,   2.3014190E-05,   1.9042171E-05
     +,   1.5607880E-05,   1.2678555E-05,   1.0209476E-05
     +,   8.1504240E-06,   6.4502060E-06,   5.0594163E-06
     +,   3.9321230E-06,   3.0268413E-06,   2.3068351E-06
     +,   1.7399357E-06,   1.2982653E-06,   9.5795190E-07
     +,   6.9877967E-07,   5.0375724E-07,   3.5883292E-07
     +,   2.5249801E-07,   1.7549296E-07,   1.2045714E-07
     +,   8.1647826E-08,   5.4645280E-08,   3.6111320E-08
     +,   2.3560665E-08,   1.5176921E-08,   9.6519939E-09
     +,   6.0600081E-09,   3.7563104E-09,   2.2986084E-09
     +,   1.3886591E-09,   8.2820384E-10,   4.8764542E-10
     +,   2.8345279E-10,   1.6266075E-10,   9.2149829E-11
     +,   5.1538600E-11,   2.8456550E-11,   1.5511818E-11
     +,   8.3475934E-12,   4.4350786E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz120 = Yx/0.0852564102564103
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0997052E-06,   1.1832946E-06
     +,   1.2721988E-06,   1.3666712E-06,   1.4669715E-06
     +,   1.5733656E-06,   1.6861258E-06,   1.8055302E-06
     +,   1.9318607E-06,   2.0654113E-06,   2.2064764E-06
     +,   2.3553589E-06,   2.5123677E-06,   2.6778187E-06
     +,   2.8520340E-06,   3.0353456E-06,   3.2280934E-06
     +,   3.4306240E-06,   3.6432984E-06,   3.8664862E-06
     +,   4.1005719E-06,   4.3459536E-06,   4.6030414E-06
     +,   4.8722832E-06,   5.1541169E-06,   5.4490347E-06
     +,   5.7575394E-06,   6.0801694E-06,   6.4174965E-06
     +,   6.7701299E-06,   7.1387276E-06,   7.5239873E-06
     +,   7.9266674E-06,   8.3475788E-06,   8.7875997E-06
     +,   9.2476766E-06,   9.7288330E-06,   1.0232158E-05
     +,   1.0758871E-05,   1.1310218E-05,   1.1887600E-05
     +,   1.2492488E-05,   1.3126463E-05,   1.3791208E-05
     +,   1.4488519E-05,   1.5220287E-05,   1.5988509E-05
     +,   1.6795275E-05,   1.7642757E-05,   1.8533205E-05
     +,   1.9468920E-05,   2.0452242E-05,   2.1485512E-05
     +,   2.2571132E-05,   2.3711329E-05,   2.4908391E-05
     +,   2.6164429E-05,   2.7481414E-05,   2.8861161E-05
     +,   3.0305255E-05,   3.1815038E-05,   3.3391621E-05
     +,   3.5035737E-05,   3.6747973E-05,   3.8528680E-05
     +,   4.0377807E-05,   4.2295462E-05,   4.4281489E-05
     +,   4.6336190E-05,   4.8460010E-05,   5.0654442E-05
     +,   5.2921809E-05,   5.5266450E-05,   5.7694710E-05
     +,   6.0216214E-05,   6.2844629E-05,   6.5598477E-05
     +,   6.8502537E-05,   7.1589326E-05,   7.4900512E-05
     +,   7.8488127E-05,   8.2417253E-05,   8.6767097E-05
     +,   9.1634422E-05,   9.7135358E-05,   1.0341005E-04
     +,   1.1062570E-04,   1.1898331E-04,   1.2872217E-04
     +,   1.4012882E-04,   1.5354414E-04,   1.6937053E-04
     +,   1.8807953E-04,   2.1021935E-04,   2.3641865E-04
     +,   2.6738527E-04,   3.0391183E-04,   3.4686390E-04
     +,   3.9718219E-04,   4.5585778E-04,   5.2392314E-04
     +,   6.0239882E-04,   6.9225422E-04,   7.9430471E-04
     +,   9.0912584E-04,   1.0369401E-03,   1.1775350E-03
     +,   1.3302973E-03,   1.4944215E-03,   1.6693228E-03
     +,   1.8552293E-03,   2.0538943E-03,   2.2690268E-03
     +,   2.5063683E-03,   2.7730328E-03,   3.0765501E-03
     +,   3.4241416E-03,   3.8241402E-03,   4.2908820E-03
     +,   4.8530498E-03,   5.5596931E-03,   6.4734323E-03
     +,   7.6427883E-03,   9.0595018E-03,   1.0624505E-02
     +,   1.2151386E-02,   1.3421537E-02,   1.4273687E-02
     +,   1.4683980E-02,   1.4782635E-02,   1.4788597E-02
     +,   1.4892794E-02,   1.5149609E-02,   1.5443855E-02
     +,   1.5584352E-02,   1.5476378E-02,   1.5214178E-02
     +,   1.4996944E-02,   1.4962197E-02,   1.5087775E-02
     +,   1.5211357E-02,   1.5144560E-02,   1.4816931E-02
     +,   1.4328456E-02,   1.3843634E-02,   1.3434880E-02
     +,   1.3037493E-02,   1.2533304E-02,   1.1850359E-02
     +,   1.0995972E-02,   1.0033993E-02,   9.0501886E-03
     +,   8.1256935E-03,   7.3191733E-03,   6.6583105E-03
     +,   6.1411792E-03,   5.7438710E-03,   5.4294611E-03
     +,   5.1567969E-03,   4.8892745E-03,   4.6023563E-03
     +,   4.2872080E-03,   3.9491649E-03,   3.6023911E-03
     +,   3.2636030E-03,   2.9473244E-03,   2.6634696E-03
     +,   2.4169555E-03,   2.2085432E-03,   2.0361855E-03
     +,   1.8963070E-03,   1.7847397E-03,   1.6973073E-03
     +,   1.6301104E-03,   1.5795785E-03,   1.5424161E-03
     +,   1.5155431E-03,   1.4960659E-03,   1.4812824E-03
     +,   1.4687115E-03,   1.4561525E-03,   1.4417282E-03
     +,   1.4239256E-03,   1.4016236E-03,   1.3741065E-03
     +,   1.3410662E-03,   1.3025813E-03,   1.2590808E-03
     +,   1.2112936E-03,   1.1601899E-03,   1.1068938E-03
     +,   1.0526105E-03,   9.9854951E-04,   9.4584795E-04
     +,   8.9550676E-04,   8.4834750E-04,   8.0498657E-04
     +,   7.6581776E-04,   7.3101447E-04,   7.0054753E-04
     +,   6.7421270E-04,   6.5165997E-04,   6.3242635E-04
     +,   6.1597250E-04,   6.0171675E-04,   5.8906141E-04
     +,   5.7742011E-04,   5.6624063E-04,   5.5502186E-04
     +,   5.4332678E-04,   5.3079368E-04,   5.1714305E-04
     +,   5.0218072E-04,   4.8579604E-04,   4.6795976E-04
     +,   4.4871893E-04,   4.2818731E-04,   4.0653363E-04
     +,   3.8397088E-04,   3.6074588E-04,   3.3712259E-04
     +,   3.1337200E-04,   2.8976257E-04,   2.6654889E-04
     +,   2.4396233E-04,   2.2220628E-04,   2.0145325E-04
     +,   1.8184123E-04,   1.6347136E-04,   1.4641069E-04
     +,   1.3069484E-04,   1.1632998E-04,   1.0329549E-04
     +,   9.1549213E-05,   8.1032755E-05,   7.1673188E-05
     +,   6.3388441E-05,   5.6091252E-05,   4.9691618E-05
     +,   4.4099215E-05,   3.9226088E-05,   3.4988614E-05
     +,   3.1308344E-05,   2.8112669E-05,   2.5335634E-05
     +,   2.2918224E-05,   2.0808142E-05,   1.8959419E-05
     +,   1.7332253E-05,   1.5892629E-05,   1.4611514E-05
     +,   1.3464454E-05,   1.2431104E-05,   1.1494582E-05
     +,   1.0640930E-05,   9.8587216E-06,   9.1386846E-06
     +,   8.4732692E-06,   7.8563007E-06,   7.2827434E-06
     +,   6.7485125E-06,   6.2502295E-06,   5.7850407E-06
     +,   5.3505310E-06,   4.9446585E-06,   4.5655897E-06
     +,   4.2116899E-06,   3.8814965E-06,   3.5736598E-06
     +,   3.2868975E-06,   3.0200040E-06,   2.7718565E-06
     +,   2.5413781E-06,   2.3275290E-06,   2.1293149E-06
     +,   1.9458037E-06,   1.7760794E-06,   1.6192904E-06
     +,   1.4746036E-06,   1.3412454E-06,   1.2184612E-06
     +,   1.1055524E-06,   1.0018402E-06,   9.0669784E-07
     +,   8.1951833E-07,   7.3974138E-07,   6.6682952E-07
     +,   6.0027770E-07,   5.3961685E-07,   4.8439773E-07
     +,   4.3420604E-07,   3.8864664E-07,   3.4735530E-07
     +,   3.0998535E-07,   2.7621826E-07,   2.4575183E-07
     +,   2.1830853E-07,   1.9362604E-07,   1.7146427E-07
     +,   1.5159711E-07,   1.3381774E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz75 = Yx/0.138833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8560864E-05,   1.8812572E-05
     +,   1.9056755E-05,   1.9293044E-05,   1.9521058E-05
     +,   1.9740450E-05,   1.9950865E-05,   2.0151969E-05
     +,   2.0343436E-05,   2.0524960E-05,   2.0696250E-05
     +,   2.0857027E-05,   2.1007039E-05,   2.1146043E-05
     +,   2.1273827E-05,   2.1390193E-05,   2.1494970E-05
     +,   2.1588014E-05,   2.1669204E-05,   2.1738442E-05
     +,   2.1795664E-05,   2.1840830E-05,   2.1873928E-05
     +,   2.1894984E-05,   2.1904047E-05,   2.1901194E-05
     +,   2.1886550E-05,   2.1860253E-05,   2.1822489E-05
     +,   2.1773469E-05,   2.1713446E-05,   2.1642692E-05
     +,   2.1561531E-05,   2.1470318E-05,   2.1369431E-05
     +,   2.1259302E-05,   2.1140388E-05,   2.1013188E-05
     +,   2.0878226E-05,   2.0736092E-05,   2.0587388E-05
     +,   2.0432772E-05,   2.0272939E-05,   2.0108628E-05
     +,   1.9940626E-05,   1.9769761E-05,   1.9596911E-05
     +,   1.9423012E-05,   1.9249046E-05,   1.9076049E-05
     +,   1.8905117E-05,   1.8737404E-05,   1.8574128E-05
     +,   1.8416560E-05,   1.8266050E-05,   1.8123996E-05
     +,   1.7991864E-05,   1.7871194E-05,   1.7763577E-05
     +,   1.7670660E-05,   1.7594151E-05,   1.7535800E-05
     +,   1.7497408E-05,   1.7480792E-05,   1.7487801E-05
     +,   1.7520288E-05,   1.7580111E-05,   1.7669094E-05
     +,   1.7789042E-05,   1.7941698E-05,   1.8128752E-05
     +,   1.8351802E-05,   1.8612398E-05,   1.8911967E-05
     +,   1.9251895E-05,   1.9633528E-05,   2.0058182E-05
     +,   2.0527234E-05,   2.1042253E-05,   2.1605108E-05
     +,   2.2218084E-05,   2.2884249E-05,   2.3607579E-05
     +,   2.4393492E-05,   2.5249075E-05,   2.6183767E-05
     +,   2.7209719E-05,   2.8342645E-05,   2.9602197E-05
     +,   3.1012925E-05,   3.2604887E-05,   3.4414141E-05
     +,   3.6483463E-05,   3.8862916E-05,   4.1610161E-05
     +,   4.4790329E-05,   4.8476682E-05,   5.2749740E-05
     +,   5.7698184E-05,   6.3417778E-05,   7.0013011E-05
     +,   7.7596604E-05,   8.6292930E-05,   9.6238669E-05
     +,   1.0758829E-04,   1.2051762E-04,   1.3522750E-04
     +,   1.5194825E-04,   1.7094470E-04,   1.9251864E-04
     +,   2.1701142E-04,   2.4481994E-04,   2.7641378E-04
     +,   3.1238748E-04,   3.5352915E-04,   4.0094330E-04
     +,   4.5619151E-04,   5.2148395E-04,   5.9985666E-04
     +,   6.9536886E-04,   8.1326708E-04,   9.6009084E-04
     +,   1.1436470E-03,   1.3726305E-03,   1.6554967E-03
     +,   1.9982338E-03,   2.4012839E-03,   2.8563596E-03
     +,   3.3456718E-03,   3.8458703E-03,   4.3391008E-03
     +,   4.8301639E-03,   5.3657671E-03,   6.0456600E-03
     +,   7.0098387E-03,   8.3806207E-03,   1.0159357E-02
     +,   1.2145899E-02,   1.4003018E-02,   1.5481094E-02
     +,   1.6608091E-02,   1.7661894E-02,   1.8989582E-02
     +,   2.0807568E-02,   2.3054704E-02,   2.5430314E-02
     +,   2.7548222E-02,   2.8947739E-02,   2.9168086E-02
     +,   2.8119680E-02,   2.6252974E-02,   2.4208946E-02
     +,   2.2384224E-02,   2.0806490E-02,   1.9319171E-02
     +,   1.7843395E-02,   1.6489811E-02,   1.5448802E-02
     +,   1.4762751E-02,   1.4235931E-02,   1.3598722E-02
     +,   1.2721767E-02,   1.1655309E-02,   1.0517617E-02
     +,   9.3925716E-03,   8.3179353E-03,   7.3220227E-03
     +,   6.4427853E-03,   5.7147504E-03,   5.1484867E-03
     +,   4.7237594E-03,   4.3990095E-03,   4.1279881E-03
     +,   3.8737524E-03,   3.6152834E-03,   3.3469782E-03
     +,   3.0741249E-03,   2.8071764E-03,   2.5569813E-03
     +,   2.3318215E-03,   2.1363443E-03,   1.9717794E-03
     +,   1.8368005E-03,   1.7285198E-03,   1.6433246E-03
     +,   1.5774153E-03,   1.5270879E-03,   1.4888470E-03
     +,   1.4594340E-03,   1.4358301E-03,   1.4152757E-03
     +,   1.3953211E-03,   1.3739066E-03,   1.3494446E-03
     +,   1.3208784E-03,   1.2877070E-03,   1.2499640E-03
     +,   1.2081390E-03,   1.1630625E-03,   1.1157686E-03
     +,   1.0673575E-03,   1.0188684E-03,   9.7117462E-04
     +,   9.2492456E-04,   8.8051998E-04,   8.3811779E-04
     +,   7.9766696E-04,   7.5896573E-04,   7.2171760E-04
     +,   6.8558747E-04,   6.5025588E-04,   6.1546027E-04
     +,   5.8101659E-04,   5.4682995E-04,   5.1289622E-04
     +,   4.7929471E-04,   4.4616970E-04,   4.1370900E-04
     +,   3.8212599E-04,   3.5164272E-04,   3.2246776E-04
     +,   2.9478502E-04,   2.6874608E-04,   2.4446208E-04
     +,   2.2199968E-04,   2.0138310E-04,   1.8259838E-04
     +,   1.6559605E-04,   1.5029611E-04,   1.3659550E-04
     +,   1.2437564E-04,   1.1350710E-04,   1.0385494E-04
     +,   9.5284639E-05,   8.7666449E-05,   8.0877246E-05
     +,   7.4803560E-05,   6.9343449E-05,   6.4406609E-05
     +,   5.9914400E-05,   5.5799788E-05,   5.2006904E-05
     +,   4.8489695E-05,   4.5210651E-05,   4.2139920E-05
     +,   3.9254228E-05,   3.6535563E-05,   3.3969965E-05
     +,   3.1546802E-05,   2.9258152E-05,   2.7097678E-05
     +,   2.5060315E-05,   2.3141916E-05,   2.1338796E-05
     +,   1.9647352E-05,   1.8064009E-05,   1.6585209E-05
     +,   1.5207228E-05,   1.3926051E-05,   1.2737486E-05
     +,   1.1637255E-05,   1.0620934E-05,   9.6839385E-06
     +,   8.8216457E-06,   8.0295222E-06,   7.3029910E-06
     +,   6.6375660E-06,   6.0289303E-06,   5.4729130E-06
     +,   4.9654764E-06,   4.5027859E-06,   4.0812438E-06
     +,   3.6974648E-06,   3.3482536E-06,   3.0306412E-06
     +,   2.7419042E-06,   2.4794881E-06,   2.2410773E-06
     +,   2.0245166E-06,   1.8278606E-06,   1.6493078E-06
     +,   1.4872392E-06,   1.3401586E-06,   1.2067270E-06
     +,   1.0857073E-06,   9.7599366E-07,   8.7656895E-07
     +,   7.8651067E-07,   7.0498783E-07,   6.3123440E-07
     +,   5.6456270E-07,   5.0433681E-07,   4.4998512E-07
     +,   4.0097839E-07,   3.5683982E-07,   3.1712696E-07
     +,   2.8144086E-07,   2.4941087E-07,   2.2070209E-07
     +,   1.9500362E-07,   1.7203419E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz80 = Yx/0.167363636363636
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6961872E-08,   4.2363876E-08
     +,   4.8544528E-08,   5.5615111E-08,   6.3702558E-08
     +,   7.2951600E-08,   8.3526871E-08,   9.5615640E-08
     +,   1.0943049E-07,   1.2521318E-07,   1.4323700E-07
     +,   1.6381126E-07,   1.8728521E-07,   2.1405260E-07
     +,   2.4455659E-07,   2.7929445E-07,   3.1882379E-07
     +,   3.6376741E-07,   4.1482051E-07,   4.7275574E-07
     +,   5.3843115E-07,   6.1279525E-07,   6.9689366E-07
     +,   7.9188203E-07,   8.9901636E-07,   1.0196808E-06
     +,   1.1553753E-06,   1.3077305E-06,   1.4785062E-06
     +,   1.6695998E-06,   1.8830422E-06,   2.1210044E-06
     +,   2.3857904E-06,   2.6798368E-06,   3.0057065E-06
     +,   3.3660799E-06,   3.7637433E-06,   4.2015677E-06
     +,   4.6825303E-06,   5.2096070E-06,   5.7858629E-06
     +,   6.4143264E-06,   7.0980100E-06,   7.8398589E-06
     +,   8.6427181E-06,   9.5092837E-06,   1.0442069E-05
     +,   1.1443343E-05,   1.2515097E-05,   1.3658980E-05
     +,   1.4876255E-05,   1.6167758E-05,   1.7533788E-05
     +,   1.8974228E-05,   2.0488193E-05,   2.2074346E-05
     +,   2.3730599E-05,   2.5454194E-05,   2.7241651E-05
     +,   2.9088767E-05,   3.0990599E-05,   3.2941520E-05
     +,   3.4935034E-05,   3.6964131E-05,   3.9021157E-05
     +,   4.1097661E-05,   4.3184897E-05,   4.5273442E-05
     +,   4.7353748E-05,   4.9415721E-05,   5.1449384E-05
     +,   5.3444452E-05,   5.5391043E-05,   5.7279180E-05
     +,   5.9099508E-05,   6.0843140E-05,   6.2501786E-05
     +,   6.4067950E-05,   6.5535271E-05,   6.6898436E-05
     +,   6.8153313E-05,   6.9297297E-05,   7.0329210E-05
     +,   7.1249604E-05,   7.2060720E-05,   7.2766772E-05
     +,   7.3373812E-05,   7.3890064E-05,   7.4325762E-05
     +,   7.4693409E-05,   7.5007738E-05,   7.5285781E-05
     +,   7.5546966E-05,   7.5813157E-05,   7.6108692E-05
     +,   7.6460434E-05,   7.6897908E-05,   7.7453296E-05
     +,   7.8161538E-05,   7.9060344E-05,   8.0190344E-05
     +,   8.1594910E-05,   8.3320483E-05,   8.5416090E-05
     +,   8.7933629E-05,   9.0927570E-05,   9.4454408E-05
     +,   9.8572447E-05,   1.0334162E-04,   1.0882274E-04
     +,   1.1507637E-04,   1.2216362E-04,   1.3014408E-04
     +,   1.3907795E-04,   1.4902440E-04,   1.6004592E-04
     +,   1.7220898E-04,   1.8559283E-04,   2.0029506E-04
     +,   2.1644788E-04,   2.3423530E-04,   2.5391634E-04
     +,   2.7585568E-04,   3.0055977E-04,   3.2871083E-04
     +,   3.6119265E-04,   3.9911226E-04,   4.4377902E-04
     +,   4.9666519E-04,   5.5929762E-04,   6.3313008E-04
     +,   7.1935263E-04,   8.1874593E-04,   9.3156885E-04
     +,   1.0576539E-03,   1.1967194E-03,   1.3489256E-03
     +,   1.5155752E-03,   1.6996855E-03,   1.9062990E-03
     +,   2.1428692E-03,   2.4206310E-03,   2.7575071E-03
     +,   3.1810012E-03,   3.7265487E-03,   4.4269320E-03
     +,   5.2966257E-03,   6.3331537E-03,   7.5611211E-03
     +,   9.0893321E-03,   1.1065588E-02,   1.3482488E-02
     +,   1.6067605E-02,   1.8518168E-02,   2.0829264E-02
     +,   2.3247933E-02,   2.5933847E-02,   2.8795654E-02
     +,   3.1911835E-02,   3.5475481E-02,   3.8105693E-02
     +,   3.7784141E-02,   3.5876047E-02,   3.5034262E-02
     +,   3.4537505E-02,   3.2729216E-02,   2.9862925E-02
     +,   2.6863329E-02,   2.4328712E-02,   2.2384802E-02
     +,   2.0593587E-02,   1.8440042E-02,   1.5853550E-02
     +,   1.3181487E-02,   1.0867555E-02,   9.1607776E-03
     +,   8.0343848E-03,   7.3035266E-03,   6.7763277E-03
     +,   6.3257664E-03,   5.8884071E-03,   5.4394118E-03
     +,   4.9754255E-03,   4.5081200E-03,   4.0587247E-03
     +,   3.6491456E-03,   3.2935070E-03,   2.9950347E-03
     +,   2.7486628E-03,   2.5459919E-03,   2.3791771E-03
     +,   2.2425090E-03,   2.1320693E-03,   2.0445928E-03
     +,   1.9765121E-03,   1.9235171E-03,   1.8806808E-03
     +,   1.8428994E-03,   1.8054553E-03,   1.7645119E-03
     +,   1.7174339E-03,   1.6629013E-03,   1.6008489E-03
     +,   1.5322720E-03,   1.4589635E-03,   1.3831917E-03
     +,   1.3073903E-03,   1.2338746E-03,   1.1645943E-03
     +,   1.1009568E-03,   1.0437377E-03,   9.9307729E-04
     +,   9.4853999E-04,   9.0923626E-04,   8.7398617E-04
     +,   8.4149017E-04,   8.1048341E-04,   7.7985978E-04
     +,   7.4876210E-04,   7.1662728E-04,   6.8318512E-04
     +,   6.4843264E-04,   6.1258773E-04,   5.7602365E-04
     +,   5.3920376E-04,   5.0262298E-04,   4.6676141E-04
     +,   4.3204418E-04,   3.9881506E-04,   3.6732646E-04
     +,   3.3774099E-04,   3.1013510E-04,   2.8450988E-04
     +,   2.6080807E-04,   2.3893274E-04,   2.1875766E-04
     +,   2.0014380E-04,   1.8295107E-04,   1.6704555E-04
     +,   1.5230404E-04,   1.3861828E-04,   1.2589710E-04
     +,   1.1406475E-04,   1.0305875E-04,   9.2828741E-05
     +,   8.3334526E-05,   7.4542942E-05,   6.6424815E-05
     +,   5.8954036E-05,   5.2106265E-05,   4.5856450E-05
     +,   4.0178726E-05,   3.5046265E-05,   3.0430640E-05
     +,   2.6301570E-05,   2.2627579E-05,   1.9376484E-05
     +,   1.6515558E-05,   1.4011780E-05,   1.1832602E-05
     +,   9.9464223E-06,   8.3228051E-06,   6.9326957E-06
     +,   5.7488337E-06,   4.7459966E-06,   3.9008851E-06
     +,   3.1923109E-06,   2.6012247E-06,   2.1105973E-06
     +,   1.7053198E-06,   1.3721321E-06,   1.0995057E-06
     +,   8.7746810E-07,   6.9744516E-07,   5.5213405E-07
     +,   4.3536468E-07,   3.4193175E-07,   2.6749640E-07
     +,   2.0844287E-07,   1.6179203E-07,   1.2508983E-07
     +,   9.6335761E-08,   7.3899749E-08,   5.6466465E-08
     +,   4.2974964E-08,   3.2577351E-08,   2.4596741E-08
     +,   1.8496285E-08,   1.3852592E-08,   1.0332244E-08
     +,   7.6748181E-09,   5.6771139E-09,   4.1818109E-09
     +,   3.0672784E-09,   2.2401949E-09,   1.6290532E-09
     +,   1.1794893E-09,   8.5022855E-10,   6.1017263E-10
     +,   4.3593265E-10,   3.1004807E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz85 = Yx/0.191068181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7075741E-08,   3.1649073E-08
     +,   3.6963904E-08,   4.3135000E-08,   5.0293693E-08
     +,   5.8590079E-08,   6.8195490E-08,   7.9304932E-08
     +,   9.2139899E-08,   1.0695210E-07,   1.2402572E-07
     +,   1.4368177E-07,   1.6628167E-07,   1.9223127E-07
     +,   2.2198509E-07,   2.5605081E-07,   2.9499327E-07
     +,   3.3943971E-07,   3.9008398E-07,   4.4769092E-07
     +,   5.1310076E-07,   5.8723344E-07,   6.7109016E-07
     +,   7.6576453E-07,   8.7242807E-07,   9.9235376E-07
     +,   1.1268987E-06,   1.2775133E-06,   1.4457355E-06
     +,   1.6331891E-06,   1.8415790E-06,   2.0726825E-06
     +,   2.3283435E-06,   2.6104592E-06,   2.9209682E-06
     +,   3.2618336E-06,   3.6350293E-06,   4.0425061E-06
     +,   4.4862122E-06,   4.9679843E-06,   5.4896263E-06
     +,   6.0527982E-06,   6.6590205E-06,   7.3096448E-06
     +,   8.0058080E-06,   8.7484132E-06,   9.5380892E-06
     +,   1.0375162E-05,   1.1259625E-05,   1.2191113E-05
     +,   1.3168866E-05,   1.4191728E-05,   1.5258090E-05
     +,   1.6365975E-05,   1.7512837E-05,   1.8695804E-05
     +,   1.9911489E-05,   2.1156087E-05,   2.2425371E-05
     +,   2.3714732E-05,   2.5019190E-05,   2.6333473E-05
     +,   2.7651948E-05,   2.8968869E-05,   3.0278319E-05
     +,   3.1574156E-05,   3.2850381E-05,   3.4100856E-05
     +,   3.5319743E-05,   3.6501202E-05,   3.7639842E-05
     +,   3.8730439E-05,   3.9768343E-05,   4.0749237E-05
     +,   4.1669449E-05,   4.2525917E-05,   4.3316162E-05
     +,   4.4038406E-05,   4.4691686E-05,   4.5275749E-05
     +,   4.5791086E-05,   4.6239034E-05,   4.6621641E-05
     +,   4.6941765E-05,   4.7202953E-05,   4.7409496E-05
     +,   4.7566286E-05,   4.7678848E-05,   4.7753212E-05
     +,   4.7795893E-05,   4.7813766E-05,   4.7814010E-05
     +,   4.7804049E-05,   4.7791367E-05,   4.7783531E-05
     +,   4.7788024E-05,   4.7812169E-05,   4.7863061E-05
     +,   4.7947466E-05,   4.8071724E-05,   4.8241720E-05
     +,   4.8462789E-05,   4.8739690E-05,   4.9076505E-05
     +,   4.9476712E-05,   4.9943112E-05,   5.0477829E-05
     +,   5.1082345E-05,   5.1757597E-05,   5.2503990E-05
     +,   5.3321455E-05,   5.4209693E-05,   5.5168122E-05
     +,   5.6196273E-05,   5.7293746E-05,   5.8460675E-05
     +,   5.9697792E-05,   6.1007035E-05,   6.2391679E-05
     +,   6.3857151E-05,   6.5411768E-05,   6.7067500E-05
     +,   6.8841466E-05,   7.0757837E-05,   7.2850096E-05
     +,   7.5163858E-05,   7.7761266E-05,   8.0724894E-05
     +,   8.4164007E-05,   8.8219742E-05,   9.3072143E-05
     +,   9.8945005E-05,   1.0611167E-04,   1.1489619E-04
     +,   1.2567399E-04,   1.3886733E-04,   1.5493616E-04
     +,   1.7436834E-04,   1.9767258E-04,   2.2537692E-04
     +,   2.5804242E-04,   2.9630770E-04,   3.4097157E-04
     +,   3.9311455E-04,   4.5425823E-04,   5.2658818E-04
     +,   6.1324105E-04,   7.1872491E-04,   8.4959785E-04
     +,   1.0154627E-03,   1.2300705E-03,   1.5118829E-03
     +,   1.8828623E-03,   2.3640783E-03,   2.9674519E-03
     +,   3.6851356E-03,   4.4807517E-03,   5.2885232E-03
     +,   6.0255523E-03,   6.6191480E-03,   7.0462087E-03
     +,   7.3770965E-03,   7.8047044E-03,   8.6219087E-03
     +,   1.0155617E-02,   1.2723760E-02,   1.6502423E-02
     +,   2.1094047E-02,   2.5427645E-02,   2.9099224E-02
     +,   3.3217117E-02,   3.7708696E-02,   4.0194683E-02
     +,   4.0754344E-02,   4.2719033E-02,   4.5292236E-02
     +,   4.3626077E-02,   3.7882019E-02,   3.2222643E-02
     +,   2.7836666E-02,   2.4169911E-02,   2.1275457E-02
     +,   1.8858816E-02,   1.6561586E-02,   1.4471414E-02
     +,   1.2696061E-02,   1.1194421E-02,   9.9355150E-03
     +,   8.9163845E-03,   8.0901990E-03,   7.3809074E-03
     +,   6.7398907E-03,   6.1574914E-03,   5.6402264E-03
     +,   5.1924638E-03,   4.8116646E-03,   4.4893767E-03
     +,   4.2125434E-03,   3.9651399E-03,   3.7312785E-03
     +,   3.4993833E-03,   3.2652782E-03,   3.0322855E-03
     +,   2.8083951E-03,   2.6022359E-03,   2.4197486E-03
     +,   2.2627674E-03,   2.1292721E-03,   2.0145655E-03
     +,   1.9126346E-03,   1.8173130E-03,   1.7231195E-03
     +,   1.6258314E-03,   1.5228422E-03,   1.4133073E-03
     +,   1.2980531E-03,   1.1792533E-03,   1.0599315E-03
     +,   9.4342011E-04,   8.3286641E-04,   7.3081569E-04
     +,   6.3899712E-04,   5.5826432E-04,   4.8865977E-04
     +,   4.2957353E-04,   3.7995356E-04,   3.3851102E-04
     +,   3.0388974E-04,   2.7479330E-04,   2.5006980E-04
     +,   2.2875145E-04,   2.1006010E-04,   1.9339297E-04
     +,   1.7829950E-04,   1.6445405E-04,   1.5162546E-04
     +,   1.3965419E-04,   1.2843324E-04,   1.1789140E-04
     +,   1.0798084E-04,   9.8669232E-05,   8.9934001E-05
     +,   8.1757455E-05,   7.4123287E-05,   6.7015557E-05
     +,   6.0417999E-05,   5.4313070E-05,   4.8681464E-05
     +,   4.3502681E-05,   3.8755745E-05,   3.4418434E-05
     +,   3.0468134E-05,   2.6882322E-05,   2.3638477E-05
     +,   2.0714075E-05,   1.8086997E-05,   1.5735794E-05
     +,   1.3639553E-05,   1.1777875E-05,   1.0131110E-05
     +,   8.6805185E-06,   7.4081672E-06,   6.2969311E-06
     +,   5.3306399E-06,   4.4941830E-06,   3.7733591E-06
     +,   3.1549919E-06,   2.6269734E-06,   2.1781957E-06
     +,   1.7985195E-06,   1.4787871E-06,   1.2107927E-06
     +,   9.8721296E-07,   8.0154393E-07,   6.4806483E-07
     +,   5.2178683E-07,   4.1835833E-07,   3.3403663E-07
     +,   2.6559974E-07,   2.1030976E-07,   1.6583886E-07
     +,   1.3023231E-07,   1.0184805E-07,   7.9322831E-08
     +,   6.1524879E-08,   4.7524651E-08,   3.6559545E-08
     +,   2.8008701E-08,   2.1369949E-08,   1.6237671E-08
     +,   1.2287420E-08,   9.2598684E-09,   6.9496227E-09
     +,   5.1942077E-09,   3.8661945E-09,   2.8657718E-09
     +,   2.1154245E-09,   1.5550249E-09,   1.1383213E-09
     +,   8.2978396E-10,   6.0233957E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz90 = Yx/0.191068181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7688516E-06,   2.9576613E-06
     +,   3.1543630E-06,   3.3588497E-06,   3.5709702E-06
     +,   3.7905299E-06,   4.0172890E-06,   4.2509596E-06
     +,   4.4912058E-06,   4.7376548E-06,   4.9898777E-06
     +,   5.2474029E-06,   5.5097153E-06,   5.7762572E-06
     +,   6.0464317E-06,   6.3196026E-06,   6.5951017E-06
     +,   6.8722284E-06,   7.1502591E-06,   7.4284449E-06
     +,   7.7060195E-06,   7.9822084E-06,   8.2562265E-06
     +,   8.5273032E-06,   8.7946482E-06,   9.0575086E-06
     +,   9.3151384E-06,   9.5668211E-06,   9.8118699E-06
     +,   1.0049642E-05,   1.0279536E-05,   1.0501005E-05
     +,   1.0713559E-05,   1.0916775E-05,   1.1110298E-05
     +,   1.1293841E-05,   1.1467214E-05,   1.1630292E-05
     +,   1.1783056E-05,   1.1925559E-05,   1.2057965E-05
     +,   1.2180526E-05,   1.2293596E-05,   1.2397620E-05
     +,   1.2493160E-05,   1.2580866E-05,   1.2661500E-05
     +,   1.2735917E-05,   1.2805075E-05,   1.2870038E-05
     +,   1.2931966E-05,   1.2992119E-05,   1.3051856E-05
     +,   1.3112637E-05,   1.3176013E-05,   1.3243640E-05
     +,   1.3317265E-05,   1.3398737E-05,   1.3489993E-05
     +,   1.3593080E-05,   1.3710136E-05,   1.3843401E-05
     +,   1.3995201E-05,   1.4167974E-05,   1.4364271E-05
     +,   1.4586703E-05,   1.4838024E-05,   1.5121041E-05
     +,   1.5438693E-05,   1.5793967E-05,   1.6189981E-05
     +,   1.6629876E-05,   1.7116909E-05,   1.7654340E-05
     +,   1.8245508E-05,   1.8893779E-05,   1.9602498E-05
     +,   2.0374966E-05,   2.1214502E-05,   2.2124364E-05
     +,   2.3107623E-05,   2.4167342E-05,   2.5306292E-05
     +,   2.6527194E-05,   2.7832377E-05,   2.9224089E-05
     +,   3.0704090E-05,   3.2273991E-05,   3.3934844E-05
     +,   3.5687473E-05,   3.7532263E-05,   3.9469072E-05
     +,   4.1497271E-05,   4.3615903E-05,   4.5823541E-05
     +,   4.8118083E-05,   5.0497292E-05,   5.2958174E-05
     +,   5.5497698E-05,   5.8112146E-05,   6.0797895E-05
     +,   6.3550768E-05,   6.6366876E-05,   6.9241971E-05
     +,   7.2172195E-05,   7.5154050E-05,   7.8184217E-05
     +,   8.1260005E-05,   8.4379702E-05,   8.7542569E-05
     +,   9.0748661E-05,   9.3999806E-05,   9.7298805E-05
     +,   1.0065054E-04,   1.0406110E-04,   1.0753876E-04
     +,   1.1109302E-04,   1.1473552E-04,   1.1847886E-04
     +,   1.2233718E-04,   1.2632561E-04,   1.3045939E-04
     +,   1.3475385E-04,   1.3922398E-04,   1.4388376E-04
     +,   1.4874514E-04,   1.5381876E-04,   1.5911242E-04
     +,   1.6463239E-04,   1.7038250E-04,   1.7636613E-04
     +,   1.8258615E-04,   1.8904817E-04,   1.9576104E-04
     +,   2.0274149E-04,   2.1001606E-04,   2.1762456E-04
     +,   2.2562328E-04,   2.3408877E-04,   2.4311976E-04
     +,   2.5283784E-04,   2.6338856E-04,   2.7494188E-04
     +,   2.8769029E-04,   3.0184610E-04,   3.1764276E-04
     +,   3.3533396E-04,   3.5519490E-04,   3.7752741E-04
     +,   4.0267018E-04,   4.3100960E-04,   4.6299465E-04
     +,   4.9915951E-04,   5.4015382E-04,   5.8677659E-04
     +,   6.4001611E-04,   7.0111331E-04,   7.7164359E-04
     +,   8.5361529E-04,   9.4955770E-04,   1.0625647E-03
     +,   1.1961176E-03,   1.3535509E-03,   1.5371215E-03
     +,   1.7469518E-03,   1.9806037E-03,   2.2345344E-03
     +,   2.5085595E-03,   2.8130587E-03,   3.1761015E-03
     +,   3.6452732E-03,   4.2795674E-03,   5.1348628E-03
     +,   6.2604221E-03,   7.7165389E-03,   9.5670260E-03
     +,   1.1781915E-02,   1.4170145E-02,   1.6585635E-02
     +,   1.9207099E-02,   2.2280727E-02,   2.5537705E-02
     +,   2.8606534E-02,   3.2039043E-02,   3.6426987E-02
     +,   4.0878978E-02,   4.3965716E-02,   4.4093486E-02
     +,   4.0520322E-02,   3.5970274E-02,   3.2919556E-02
     +,   3.0318951E-02,   2.7015826E-02,   2.3435509E-02
     +,   1.9877637E-02,   1.6442809E-02,   1.3473725E-02
     +,   1.1186272E-02,   9.4979592E-03,   8.2139038E-03
     +,   7.1957014E-03,   6.3783671E-03,   5.7243602E-03
     +,   5.1946798E-03,   4.7460236E-03,   4.3402757E-03
     +,   3.9539752E-03,   3.5807968E-03,   3.2271247E-03
     +,   2.9043101E-03,   2.6217378E-03,   2.3832258E-03
     +,   2.1869563E-03,   2.0274182E-03,   1.8975443E-03
     +,   1.7900964E-03,   1.6982545E-03,   1.6158498E-03
     +,   1.5375606E-03,   1.4591551E-03,   1.3777070E-03
     +,   1.2917146E-03,   1.2010349E-03,   1.1066319E-03
     +,   1.0102122E-03,   9.1383292E-04,   8.1956014E-04
     +,   7.2920026E-04,   6.4414309E-04,   5.6532008E-04
     +,   4.9323519E-04,   4.2803527E-04,   3.6959717E-04
     +,   3.1762524E-04,   2.7172724E-04,   2.3145732E-04
     +,   1.9635446E-04,   1.6596216E-04,   1.3983244E-04
     +,   1.1752770E-04,   9.8624652E-05,   8.2717197E-05
     +,   6.9417671E-05,   5.8360660E-05,   4.9208349E-05
     +,   4.1654694E-05,   3.5427096E-05,   3.0287396E-05
     +,   2.6032127E-05,   2.2491127E-05,   1.9524039E-05
     +,   1.7017423E-05,   1.4881148E-05,   1.3044398E-05
     +,   1.1452025E-05,   1.0061462E-05,   8.8399875E-06
     +,   7.7622826E-06,   6.8084960E-06,   5.9628696E-06
     +,   5.2126811E-06,   4.5473525E-06,   3.9578399E-06
     +,   3.4362799E-06,   2.9757612E-06,   2.5700319E-06
     +,   2.2134384E-06,   1.9008601E-06,   1.6276256E-06
     +,   1.3894544E-06,   1.1824532E-06,   1.0030958E-06
     +,   8.4818038E-07,   7.1480321E-07,   6.0034586E-07
     +,   5.0246575E-07,   4.1904957E-07,   3.4822008E-07
     +,   2.8829572E-07,   2.3779232E-07,   1.9538997E-07
     +,   1.5993182E-07,   1.3039734E-07,   1.0589886E-07
     +,   8.5660268E-08,   6.9011932E-08,   5.5374372E-08
     +,   4.4250495E-08,   3.5216665E-08,   2.7911531E-08
     +,   2.2030406E-08,   1.7316168E-08,   1.3554144E-08
     +,   1.0565054E-08,   8.2007414E-09,   6.3387828E-09
     +,   4.8790336E-09,   3.7396184E-09,   2.8542479E-09
     +,   2.1692885E-09,   1.6417651E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ttz95 = Yx/0.176590909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0275322E-05,   1.0714108E-05
     +,   1.1165131E-05,   1.1628423E-05,   1.2103997E-05
     +,   1.2591860E-05,   1.3092000E-05,   1.3604390E-05
     +,   1.4128992E-05,   1.4665777E-05,   1.5214665E-05
     +,   1.5775595E-05,   1.6348482E-05,   1.6933231E-05
     +,   1.7529743E-05,   1.8137905E-05,   1.8757593E-05
     +,   1.9388692E-05,   2.0031066E-05,   2.0684583E-05
     +,   2.1349102E-05,   2.2024486E-05,   2.2710583E-05
     +,   2.3407296E-05,   2.4114439E-05,   2.4831928E-05
     +,   2.5559621E-05,   2.6297419E-05,   2.7045215E-05
     +,   2.7802924E-05,   2.8570481E-05,   2.9347835E-05
     +,   3.0134950E-05,   3.0931824E-05,   3.1738469E-05
     +,   3.2554930E-05,   3.3381275E-05,   3.4217606E-05
     +,   3.5064091E-05,   3.5920857E-05,   3.6788151E-05
     +,   3.7666217E-05,   3.8555339E-05,   3.9455863E-05
     +,   4.0368148E-05,   4.1292638E-05,   4.2229804E-05
     +,   4.3180153E-05,   4.4144264E-05,   4.5122746E-05
     +,   4.6116264E-05,   4.7125523E-05,   4.8151283E-05
     +,   4.9194390E-05,   5.0255636E-05,   5.1335977E-05
     +,   5.2436346E-05,   5.3557698E-05,   5.4701086E-05
     +,   5.5867560E-05,   5.7058223E-05,   5.8274207E-05
     +,   5.9516598E-05,   6.0786624E-05,   6.2085499E-05
     +,   6.3414343E-05,   6.4774445E-05,   6.6166933E-05
     +,   6.7593071E-05,   6.9053975E-05,   7.0550865E-05
     +,   7.2084789E-05,   7.3656927E-05,   7.5268224E-05
     +,   7.6919663E-05,   7.8612247E-05,   8.0346705E-05
     +,   8.2123719E-05,   8.3943938E-05,   8.5807915E-05
     +,   8.7715875E-05,   8.9668138E-05,   9.1664588E-05
     +,   9.3705254E-05,   9.5789597E-05,   9.7917240E-05
     +,   1.0008721E-04,   1.0229869E-04,   1.0455015E-04
     +,   1.0684021E-04,   1.0916705E-04,   1.1152852E-04
     +,   1.1392211E-04,   1.1634520E-04,   1.1879482E-04
     +,   1.2126751E-04,   1.2375979E-04,   1.2626758E-04
     +,   1.2878679E-04,   1.3131282E-04,   1.3384109E-04
     +,   1.3636648E-04,   1.3888399E-04,   1.4138814E-04
     +,   1.4387358E-04,   1.4633493E-04,   1.4876657E-04
     +,   1.5116300E-04,   1.5351892E-04,   1.5582939E-04
     +,   1.5808931E-04,   1.6029445E-04,   1.6244073E-04
     +,   1.6452490E-04,   1.6654424E-04,   1.6849714E-04
     +,   1.7038269E-04,   1.7220151E-04,   1.7395524E-04
     +,   1.7564731E-04,   1.7728280E-04,   1.7886875E-04
     +,   1.8041447E-04,   1.8193177E-04,   1.8343539E-04
     +,   1.8494308E-04,   1.8647627E-04,   1.8806028E-04
     +,   1.8972489E-04,   1.9150454E-04,   1.9343919E-04
     +,   1.9557431E-04,   1.9796184E-04,   2.0065994E-04
     +,   2.0373370E-04,   2.0725546E-04,   2.1130389E-04
     +,   2.1596426E-04,   2.2132814E-04,   2.2749162E-04
     +,   2.3455417E-04,   2.4261636E-04,   2.5177826E-04
     +,   2.6213590E-04,   2.7377668E-04,   2.8677762E-04
     +,   3.0119991E-04,   3.1708353E-04,   3.3444352E-04
     +,   3.5326713E-04,   3.7350884E-04,   3.9508645E-04
     +,   4.1787999E-04,   4.4173372E-04,   4.6645544E-04
     +,   4.9181818E-04,   5.1756768E-04,   5.4342992E-04
     +,   5.6911999E-04,   5.9434999E-04,   6.1884767E-04
     +,   6.4236735E-04,   6.6470442E-04,   6.8571407E-04
     +,   7.0533017E-04,   7.2358164E-04,   7.4061053E-04
     +,   7.5668830E-04,   7.7223516E-04,   7.8782724E-04
     +,   8.0419995E-04,   8.2224270E-04,   8.4298296E-04
     +,   8.6755154E-04,   8.9713739E-04,   9.3293487E-04
     +,   9.7608735E-04,   1.0276333E-03,   1.0884750E-03
     +,   1.1593805E-03,   1.2410021E-03,   1.3339211E-03
     +,   1.4387098E-03,   1.5559857E-03,   1.6864272E-03
     +,   1.8307455E-03,   1.9896554E-03,   2.1638654E-03
     +,   2.3541492E-03,   2.5615159E-03,   2.7876231E-03
     +,   3.0351656E-03,   3.3081206E-03,   3.6114831E-03
     +,   3.9503085E-03,   4.3280944E-03,   4.7453688E-03
     +,   5.1999004E-03,   5.6896629E-03,   6.2182243E-03
     +,   6.8005873E-03,   7.4662347E-03,   8.2565239E-03
     +,   9.2143295E-03,   1.0364817E-02,   1.1691853E-02
     +,   1.3125330E-02,   1.4558530E-02,   1.5891341E-02
     +,   1.7060878E-02,   1.8032463E-02,   1.8781263E-02
     +,   1.9312559E-02,   1.9698979E-02,   2.0058338E-02
     +,   2.0459045E-02,   2.0847579E-02,   2.1082219E-02
     +,   2.1031978E-02,   2.0638339E-02,   1.9914607E-02
     +,   1.8933883E-02,   1.7823942E-02,   1.6732531E-02
     +,   1.5759148E-02,   1.4909111E-02,   1.4114594E-02
     +,   1.3300745E-02,   1.2436999E-02,   1.1540251E-02
     +,   1.0646457E-02,   9.7870827E-03,   8.9856088E-03
     +,   8.2628429E-03,   7.6353373E-03,   7.1059028E-03
     +,   6.6571068E-03,   6.2553189E-03,   5.8630933E-03
     +,   5.4520629E-03,   5.0100735E-03,   4.5411140E-03
     +,   4.0603271E-03,   3.5874913E-03,   3.1415296E-03
     +,   2.7371589E-03,   2.3835613E-03,   2.0846042E-03
     +,   1.8398588E-03,   1.6458399E-03,   1.4970640E-03
     +,   1.3870108E-03,   1.3088172E-03,   1.2557949E-03
     +,   1.2217842E-03,   1.2013727E-03,   1.1899845E-03
     +,   1.1838796E-03,   1.1800843E-03,   1.1762987E-03
     +,   1.1707827E-03,   1.1622556E-03,   1.1498048E-03
     +,   1.1328229E-03,   1.1109563E-03,   1.0840669E-03
     +,   1.0522077E-03,   1.0156031E-03,   9.7462657E-04
     +,   9.2977594E-04,   8.8165072E-04,   8.3093031E-04
     +,   7.7834417E-04,   7.2464003E-04,   6.7056203E-04
     +,   6.1683019E-04,   5.6410796E-04,   5.1299861E-04
     +,   4.6401727E-04,   4.1759489E-04,   3.7406202E-04
     +,   3.3365842E-04,   2.9652615E-04,   2.6272581E-04
     +,   2.3223547E-04,   2.0497061E-04,   1.8078816E-04
     +,   1.5950245E-04,   1.4089861E-04,   1.2473928E-04
     +,   1.1077958E-04,   9.8771648E-05,   8.8475797E-05
     +,   7.9662663E-05,   7.2120398E-05,   6.5654975E-05
     +,   6.0093749E-05,   5.5284159E-05,   5.1094921E-05
     +,   4.7413676E-05,   4.4146669E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz100 = Yx/0.165395348837209
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.5012535E-06,   7.8962830E-06
     +,   8.3051473E-06,   8.7278740E-06,   9.1644561E-06
     +,   9.6148569E-06,   1.0079007E-05,   1.0556803E-05
     +,   1.1048095E-05,   1.1552728E-05,   1.2070481E-05
     +,   1.2601105E-05,   1.3144318E-05,   1.3699804E-05
     +,   1.4267201E-05,   1.4846119E-05,   1.5436130E-05
     +,   1.6036771E-05,   1.6647547E-05,   1.7267930E-05
     +,   1.7897359E-05,   1.8535244E-05,   1.9180954E-05
     +,   1.9833882E-05,   2.0493311E-05,   2.1158594E-05
     +,   2.1828997E-05,   2.2503800E-05,   2.3182260E-05
     +,   2.3863633E-05,   2.4547142E-05,   2.5232031E-05
     +,   2.5917529E-05,   2.6602860E-05,   2.7287257E-05
     +,   2.7969967E-05,   2.8650233E-05,   2.9327304E-05
     +,   3.0000498E-05,   3.0669071E-05,   3.1332373E-05
     +,   3.1989734E-05,   3.2640535E-05,   3.3284181E-05
     +,   3.3920114E-05,   3.4547811E-05,   3.5166788E-05
     +,   3.5776608E-05,   3.6376878E-05,   3.6967245E-05
     +,   3.7547423E-05,   3.8117170E-05,   3.8676280E-05
     +,   3.9224658E-05,   3.9762192E-05,   4.0288902E-05
     +,   4.0804836E-05,   4.1310115E-05,   4.1804931E-05
     +,   4.2289554E-05,   4.2764317E-05,   4.3229629E-05
     +,   4.3685977E-05,   4.4133940E-05,   4.4574186E-05
     +,   4.5007440E-05,   4.5434561E-05,   4.5856432E-05
     +,   4.6274108E-05,   4.6688689E-05,   4.7101385E-05
     +,   4.7513513E-05,   4.7926496E-05,   4.8341833E-05
     +,   4.8761169E-05,   4.9186230E-05,   4.9618837E-05
     +,   5.0060920E-05,   5.0514507E-05,   5.0981762E-05
     +,   5.1464860E-05,   5.1966133E-05,   5.2487947E-05
     +,   5.3032774E-05,   5.3603093E-05,   5.4201500E-05
     +,   5.4830547E-05,   5.5492881E-05,   5.6191049E-05
     +,   5.6927682E-05,   5.7705369E-05,   5.8526541E-05
     +,   5.9393627E-05,   6.0308939E-05,   6.1274746E-05
     +,   6.2292987E-05,   6.3365682E-05,   6.4494430E-05
     +,   6.5680862E-05,   6.6926215E-05,   6.8231704E-05
     +,   6.9598136E-05,   7.1026334E-05,   7.2516763E-05
     +,   7.4069867E-05,   7.5686017E-05,   7.7365417E-05
     +,   7.9108322E-05,   8.0915241E-05,   8.2786915E-05
     +,   8.4724321E-05,   8.6729291E-05,   8.8804081E-05
     +,   9.0952308E-05,   9.3178511E-05,   9.5489137E-05
     +,   9.7892087E-05,   1.0039791E-04,   1.0301934E-04
     +,   1.0577227E-04,   1.0867596E-04,   1.1175308E-04
     +,   1.1503029E-04,   1.1853862E-04,   1.2231361E-04
     +,   1.2639465E-04,   1.3082620E-04,   1.3565618E-04
     +,   1.4093680E-04,   1.4672254E-04,   1.5307059E-04
     +,   1.6003838E-04,   1.6768319E-04,   1.7605933E-04
     +,   1.8521736E-04,   1.9520117E-04,   2.0604531E-04
     +,   2.1777260E-04,   2.3039294E-04,   2.4389972E-04
     +,   2.5826725E-04,   2.7344917E-04,   2.8937819E-04
     +,   3.0596470E-04,   3.2309396E-04,   3.4063065E-04
     +,   3.5841804E-04,   3.7627920E-04,   3.9402055E-04
     +,   4.1143739E-04,   4.2831665E-04,   4.4444102E-04
     +,   4.5959491E-04,   4.7357229E-04,   4.8617981E-04
     +,   4.9724261E-04,   5.0661009E-04,   5.1416119E-04
     +,   5.1980675E-04,   5.2349333E-04,   5.2520487E-04
     +,   5.2496366E-04,   5.2282965E-04,   5.1889982E-04
     +,   5.1330519E-04,   5.0620723E-04,   4.9779500E-04
     +,   4.8827962E-04,   4.7788903E-04,   4.6686307E-04
     +,   4.5544864E-04,   4.4389465E-04,   4.3244634E-04
     +,   4.2134133E-04,   4.1080869E-04,   4.0106304E-04
     +,   3.9230552E-04,   3.8472316E-04,   3.7848964E-04
     +,   3.7376690E-04,   3.7070905E-04,   3.6946678E-04
     +,   3.7019196E-04,   3.7304257E-04,   3.7818859E-04
     +,   3.8581586E-04,   3.9613066E-04,   4.0936435E-04
     +,   4.2577897E-04,   4.4567321E-04,   4.6940040E-04
     +,   4.9739087E-04,   5.3018861E-04,   5.6850788E-04
     +,   6.1330874E-04,   6.6588464E-04,   7.2794856E-04
     +,   8.0170500E-04,   8.8987022E-04,   9.9558360E-04
     +,   1.1221695E-03,   1.2727429E-03,   1.4496720E-03
     +,   1.6539821E-03,   1.8848816E-03,   2.1397888E-03
     +,   2.4150517E-03,   2.7076653E-03,   3.0179457E-03
     +,   3.3525091E-03,   3.7261932E-03,   4.1612023E-03
     +,   4.6822368E-03,   5.3081564E-03,   6.0432684E-03
     +,   6.8732393E-03,   7.7690529E-03,   8.6967368E-03
     +,   9.6255150E-03,   1.0528733E-02,   1.1381098E-02
     +,   1.2161618E-02,   1.2865776E-02,   1.3515697E-02
     +,   1.4155117E-02,   1.4832778E-02,   1.5586529E-02
     +,   1.6424583E-02,   1.7295115E-02,   1.8073434E-02
     +,   1.8618202E-02,   1.8881237E-02,   1.8961478E-02
     +,   1.9028671E-02,   1.9181877E-02,   1.9371489E-02
     +,   1.9430332E-02,   1.9166449E-02,   1.8464724E-02
     +,   1.7361999E-02,   1.6049743E-02,   1.4776696E-02
     +,   1.3708911E-02,   1.2853510E-02,   1.2095949E-02
     +,   1.1301422E-02,   1.0397548E-02,   9.3948860E-03
     +,   8.3573693E-03,   7.3590302E-03,   6.4540873E-03
     +,   5.6683044E-03,   5.0044563E-03,   4.4521983E-03
     +,   3.9964691E-03,   3.6225216E-03,   3.3178111E-03
     +,   3.0717379E-03,   2.8745057E-03,   2.7161227E-03
     +,   2.5861438E-03,   2.4742512E-03,   2.3712819E-03
     +,   2.2701926E-03,   2.1665839E-03,   2.0586308E-03
     +,   1.9466256E-03,   1.8322704E-03,   1.7179466E-03
     +,   1.6060917E-03,   1.4987718E-03,   1.3974552E-03
     +,   1.3029248E-03,   1.2153238E-03,   1.1342901E-03
     +,   1.0591326E-03,   9.8898192E-04,   9.2296075E-04
     +,   8.6027896E-04,   8.0032129E-04,   7.4265990E-04
     +,   6.8706763E-04,   6.3347374E-04,   5.8193842E-04
     +,   5.3259305E-04,   4.8561321E-04,   4.4117103E-04
     +,   3.9941457E-04,   3.6045458E-04,   3.2434656E-04
     +,   2.9109870E-04,   2.6066432E-04,   2.3295822E-04
     +,   2.0785518E-04,   1.8520679E-04,   1.6484318E-04
     +,   1.4658688E-04,   1.3025456E-04,   1.1566734E-04
     +,   1.0265115E-04,   9.1043803E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz104 = Yx/0.153348837209302
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5944468E-05,   1.6277358E-05
     +,   1.6604441E-05,   1.6925178E-05,   1.7239061E-05
     +,   1.7545581E-05,   1.7844257E-05,   1.8134637E-05
     +,   1.8416282E-05,   1.8688799E-05,   1.8951814E-05
     +,   1.9204992E-05,   1.9448027E-05,   1.9680656E-05
     +,   1.9902662E-05,   2.0113859E-05,   2.0314113E-05
     +,   2.0503332E-05,   2.0681480E-05,   2.0848554E-05
     +,   2.1004624E-05,   2.1149788E-05,   2.1284213E-05
     +,   2.1408119E-05,   2.1521766E-05,   2.1625487E-05
     +,   2.1719656E-05,   2.1804708E-05,   2.1881127E-05
     +,   2.1949454E-05,   2.2010283E-05,   2.2064251E-05
     +,   2.2112063E-05,   2.2154456E-05,   2.2192216E-05
     +,   2.2226188E-05,   2.2257240E-05,   2.2286296E-05
     +,   2.2314305E-05,   2.2342259E-05,   2.2371180E-05
     +,   2.2402108E-05,   2.2436116E-05,   2.2474298E-05
     +,   2.2517761E-05,   2.2567619E-05,   2.2625001E-05
     +,   2.2691031E-05,   2.2766839E-05,   2.2853543E-05
     +,   2.2952241E-05,   2.3064040E-05,   2.3189985E-05
     +,   2.3331148E-05,   2.3488506E-05,   2.3663051E-05
     +,   2.3855717E-05,   2.4067382E-05,   2.4298890E-05
     +,   2.4551015E-05,   2.4824481E-05,   2.5119958E-05
     +,   2.5438019E-05,   2.5779218E-05,   2.6144007E-05
     +,   2.6532754E-05,   2.6945798E-05,   2.7383350E-05
     +,   2.7845605E-05,   2.8332619E-05,   2.8844455E-05
     +,   2.9381019E-05,   2.9942246E-05,   3.0527917E-05
     +,   3.1137835E-05,   3.1771720E-05,   3.2429252E-05
     +,   3.3110053E-05,   3.3813754E-05,   3.4540008E-05
     +,   3.5288365E-05,   3.6058507E-05,   3.6850026E-05
     +,   3.7662674E-05,   3.8496128E-05,   3.9350289E-05
     +,   4.0225012E-05,   4.1120391E-05,   4.2036518E-05
     +,   4.2973759E-05,   4.3932632E-05,   4.4913791E-05
     +,   4.5918110E-05,   4.6946745E-05,   4.8001115E-05
     +,   4.9082828E-05,   5.0193885E-05,   5.1336454E-05
     +,   5.2513158E-05,   5.3726810E-05,   5.4980657E-05
     +,   5.6278121E-05,   5.7623110E-05,   5.9019640E-05
     +,   6.0472150E-05,   6.1985316E-05,   6.3563930E-05
     +,   6.5212989E-05,   6.6937675E-05,   6.8743226E-05
     +,   7.0634742E-05,   7.2617411E-05,   7.4696065E-05
     +,   7.6875447E-05,   7.9159719E-05,   8.1552811E-05
     +,   8.4057763E-05,   8.6677210E-05,   8.9412642E-05
     +,   9.2264832E-05,   9.5233510E-05,   9.8317054E-05
     +,   1.0151249E-04,   1.0481577E-04,   1.0822133E-04
     +,   1.1172177E-04,   1.1530863E-04,   1.1897137E-04
     +,   1.2269830E-04,   1.2647582E-04,   1.3028921E-04
     +,   1.3412192E-04,   1.3795655E-04,   1.4177410E-04
     +,   1.4555498E-04,   1.4927877E-04,   1.5292433E-04
     +,   1.5647018E-04,   1.5989519E-04,   1.6317841E-04
     +,   1.6629933E-04,   1.6923841E-04,   1.7197760E-04
     +,   1.7450032E-04,   1.7679181E-04,   1.7883968E-04
     +,   1.8063423E-04,   1.8216841E-04,   1.8343815E-04
     +,   1.8444307E-04,   1.8518623E-04,   1.8567427E-04
     +,   1.8591786E-04,   1.8593167E-04,   1.8573446E-04
     +,   1.8534916E-04,   1.8480278E-04,   1.8412668E-04
     +,   1.8335637E-04,   1.8253174E-04,   1.8169671E-04
     +,   1.8089960E-04,   1.8019311E-04,   1.7963431E-04
     +,   1.7928469E-04,   1.7921046E-04,   1.7948252E-04
     +,   1.8017649E-04,   1.8137314E-04,   1.8315788E-04
     +,   1.8562119E-04,   1.8885759E-04,   1.9296595E-04
     +,   1.9804854E-04,   2.0420953E-04,   2.1155472E-04
     +,   2.2019008E-04,   2.3021927E-04,   2.4174294E-04
     +,   2.5485814E-04,   2.6965718E-04,   2.8622546E-04
     +,   3.0464318E-04,   3.2498702E-04,   3.4733137E-04
     +,   3.7175021E-04,   3.9832114E-04,   4.2713355E-04
     +,   4.5829272E-04,   4.9192476E-04,   5.2818906E-04
     +,   5.6728662E-04,   6.0946267E-04,   6.5501657E-04
     +,   7.0430705E-04,   7.5774698E-04,   8.1579125E-04
     +,   8.7892148E-04,   9.4762829E-04,   1.0223784E-03
     +,   1.1035835E-03,   1.1915811E-03,   1.2866427E-03
     +,   1.3889885E-03,   1.4988320E-03,   1.6164695E-03
     +,   1.7423448E-03,   1.8770694E-03,   2.0213670E-03
     +,   2.1759267E-03,   2.3411650E-03,   2.5170641E-03
     +,   2.7032616E-03,   2.8995778E-03,   3.1069198E-03
     +,   3.3283343E-03,   3.5697347E-03,   3.8397377E-03
     +,   4.1482844E-03,   4.5042634E-03,   4.9128765E-03
     +,   5.3733066E-03,   5.8774417E-03,   6.4102034E-03
     +,   6.9520236E-03,   7.4839965E-03,   7.9954723E-03
     +,   8.4918570E-03,   8.9983018E-03,   9.5543554E-03
     +,   1.0197896E-02,   1.0942800E-02,   1.1761747E-02
     +,   1.2588356E-02,   1.3348849E-02,   1.4014157E-02
     +,   1.4637153E-02,   1.5331476E-02,   1.6186269E-02
     +,   1.7173214E-02,   1.8125193E-02,   1.8815733E-02
     +,   1.9086856E-02,   1.8932257E-02,   1.8479357E-02
     +,   1.7892065E-02,   1.7273502E-02,   1.6633462E-02
     +,   1.5919866E-02,   1.5070274E-02,   1.4049282E-02
     +,   1.2868498E-02,   1.1591232E-02,   1.0317027E-02
     +,   9.1457069E-03,   8.1386212E-03,   7.3011429E-03
     +,   6.5955548E-03,   5.9717763E-03,   5.3939889E-03
     +,   4.8503247E-03,   4.3468755E-03,   3.8957496E-03
     +,   3.5056083E-03,   3.1778545E-03,   2.9072803E-03
     +,   2.6848076E-03,   2.5001294E-03,   2.3434279E-03
     +,   2.2062219E-03,   2.0816596E-03,   1.9645572E-03
     +,   1.8512873E-03,   1.7396105E-03,   1.6284670E-03
     +,   1.5177395E-03,   1.4079686E-03,   1.3001397E-03
     +,   1.1954393E-03,   1.0951004E-03,   1.0002377E-03
     +,   9.1177115E-04,   8.3033857E-04,   7.5629307E-04
     +,   6.8968616E-04,   6.3031836E-04,   5.7777151E-04
     +,   5.3147197E-04,   4.9075217E-04,   4.5489403E-04
     +,   4.2318276E-04,   3.9493421E-04,   3.6952528E-04
     +,   3.4640357E-04,   3.2510085E-04,   3.0522892E-04
     +,   2.8648239E-04,   2.6862725E-04,   2.5149726E-04
     +,   2.3498021E-04,   2.1901204E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz106 = Yx/0.142604651162791
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.7836421E-06,   7.9908441E-06
     +,   8.1992093E-06,   8.4085850E-06,   8.6188229E-06
     +,   8.8297684E-06,   9.0412741E-06,   9.2532018E-06
     +,   9.4654069E-06,   9.6777676E-06,   9.8901546E-06
     +,   1.0102455E-05,   1.0314566E-05,   1.0526394E-05
     +,   1.0737864E-05,   1.0948908E-05,   1.1159489E-05
     +,   1.1369570E-05,   1.1579150E-05,   1.1788243E-05
     +,   1.1996882E-05,   1.2205133E-05,   1.2413086E-05
     +,   1.2620871E-05,   1.2828617E-05,   1.3036517E-05
     +,   1.3244792E-05,   1.3453689E-05,   1.3663492E-05
     +,   1.3874534E-05,   1.4087173E-05,   1.4301828E-05
     +,   1.4518938E-05,   1.4738997E-05,   1.4962547E-05
     +,   1.5190159E-05,   1.5422462E-05,   1.5660120E-05
     +,   1.5903854E-05,   1.6154407E-05,   1.6412589E-05
     +,   1.6679236E-05,   1.6955237E-05,   1.7241513E-05
     +,   1.7539012E-05,   1.7848741E-05,   1.8171724E-05
     +,   1.8509012E-05,   1.8861707E-05,   1.9230896E-05
     +,   1.9617726E-05,   2.0023330E-05,   2.0448872E-05
     +,   2.0895528E-05,   2.1364454E-05,   2.1856840E-05
     +,   2.2373850E-05,   2.2916649E-05,   2.3486378E-05
     +,   2.4084189E-05,   2.4711182E-05,   2.5368467E-05
     +,   2.6057080E-05,   2.6778074E-05,   2.7532487E-05
     +,   2.8321234E-05,   2.9145303E-05,   3.0005534E-05
     +,   3.0902847E-05,   3.1837986E-05,   3.2811789E-05
     +,   3.3824937E-05,   3.4878183E-05,   3.5972087E-05
     +,   3.7107307E-05,   3.8284430E-05,   3.9503950E-05
     +,   4.0766285E-05,   4.2071908E-05,   4.3421227E-05
     +,   4.4814482E-05,   4.6252044E-05,   4.7734011E-05
     +,   4.9260620E-05,   5.0831848E-05,   5.2447765E-05
     +,   5.4108172E-05,   5.5812947E-05,   5.7561658E-05
     +,   5.9353879E-05,   6.1189050E-05,   6.3066356E-05
     +,   6.4984742E-05,   6.6943103E-05,   6.8940113E-05
     +,   7.0974012E-05,   7.3043033E-05,   7.5144846E-05
     +,   7.7277124E-05,   7.9436919E-05,   8.1621241E-05
     +,   8.3826482E-05,   8.6048938E-05,   8.8284309E-05
     +,   9.0528090E-05,   9.2775423E-05,   9.5021009E-05
     +,   9.7259159E-05,   9.9483994E-05,   1.0168939E-04
     +,   1.0386866E-04,   1.0601525E-04,   1.0812203E-04
     +,   1.1018210E-04,   1.1218809E-04,   1.1413293E-04
     +,   1.1600927E-04,   1.1781015E-04,   1.1952843E-04
     +,   1.2115741E-04,   1.2269075E-04,   1.2412225E-04
     +,   1.2544624E-04,   1.2665767E-04,   1.2775206E-04
     +,   1.2872540E-04,   1.2957466E-04,   1.3029737E-04
     +,   1.3089209E-04,   1.3135810E-04,   1.3169568E-04
     +,   1.3190611E-04,   1.3199153E-04,   1.3195525E-04
     +,   1.3180145E-04,   1.3153537E-04,   1.3116330E-04
     +,   1.3069251E-04,   1.3013111E-04,   1.2948831E-04
     +,   1.2877406E-04,   1.2799933E-04,   1.2717571E-04
     +,   1.2631551E-04,   1.2543189E-04,   1.2453839E-04
     +,   1.2364914E-04,   1.2277873E-04,   1.2194210E-04
     +,   1.2115441E-04,   1.2043106E-04,   1.1978748E-04
     +,   1.1923919E-04,   1.1880159E-04,   1.1848988E-04
     +,   1.1831911E-04,   1.1830393E-04,   1.1845864E-04
     +,   1.1879716E-04,   1.1933282E-04,   1.2007851E-04
     +,   1.2104669E-04,   1.2224933E-04,   1.2369794E-04
     +,   1.2540394E-04,   1.2737866E-04,   1.2963358E-04
     +,   1.3218065E-04,   1.3503272E-04,   1.3820415E-04
     +,   1.4171090E-04,   1.4557142E-04,   1.4980734E-04
     +,   1.5444419E-04,   1.5951146E-04,   1.6504411E-04
     +,   1.7108276E-04,   1.7767397E-04,   1.8487054E-04
     +,   1.9273254E-04,   2.0132643E-04,   2.1072439E-04
     +,   2.2100360E-04,   2.3224587E-04,   2.4453559E-04
     +,   2.5795613E-04,   2.7258808E-04,   2.8850659E-04
     +,   3.0577715E-04,   3.2444907E-04,   3.4455463E-04
     +,   3.6610314E-04,   3.8907546E-04,   4.1342209E-04
     +,   4.3906280E-04,   4.6588620E-04,   4.9375056E-04
     +,   5.2249164E-04,   5.5193680E-04,   5.8191753E-04
     +,   6.1228988E-04,   6.4296240E-04,   6.7393173E-04
     +,   7.0531759E-04,   7.3739880E-04,   7.7066006E-04
     +,   8.0581987E-04,   8.4384752E-04,   8.8595634E-04
     +,   9.3356805E-04,   9.8822312E-04,   1.0514453E-03
     +,   1.1245656E-03,   1.2085290E-03,   1.3036921E-03
     +,   1.4096759E-03,   1.5253117E-03,   1.6487283E-03
     +,   1.7775442E-03,   1.9091576E-03,   2.0411289E-03
     +,   2.1715320E-03,   2.2993393E-03,   2.4249391E-03
     +,   2.5508897E-03,   2.6829310E-03,   2.8309524E-03
     +,   3.0092376E-03,   3.2349930E-03,   3.5247109E-03
     +,   3.8894766E-03,   4.3321652E-03,   4.8498046E-03
     +,   5.4411772E-03,   6.1142868E-03,   6.8861893E-03
     +,   7.7721337E-03,   8.7726843E-03,   9.8705422E-03
     +,   1.1038145E-02,   1.2244249E-02,   1.3453949E-02
     +,   1.4631986E-02,   1.5753385E-02,   1.6799998E-02
     +,   1.7727295E-02,   1.8439760E-02,   1.8837295E-02
     +,   1.8915547E-02,   1.8797742E-02,   1.8625753E-02
     +,   1.8421762E-02,   1.8090699E-02,   1.7556321E-02
     +,   1.6859416E-02,   1.6113162E-02,   1.5389299E-02
     +,   1.4662800E-02,   1.3851708E-02,   1.2894534E-02
     +,   1.1797721E-02,   1.0630653E-02,   9.4859004E-03
     +,   8.4365550E-03,   7.5143846E-03,   6.7137582E-03
     +,   6.0111247E-03,   5.3835590E-03,   4.8172236E-03
     +,   4.3063634E-03,   3.8486293E-03,   3.4414446E-03
     +,   3.0808297E-03,   2.7618245E-03,   2.4793020E-03
     +,   2.2284824E-03,   2.0050334E-03,   1.8051340E-03
     +,   1.6253726E-03,   1.4627804E-03,   1.3147922E-03
     +,   1.1793113E-03,   1.0546902E-03,   9.3974639E-04
     +,   8.3368295E-04,   7.3603523E-04,   6.4655137E-04
     +,   5.6510081E-04,   4.9159443E-04,   4.2589541E-04
     +,   3.6778938E-04,   3.1694182E-04,   2.7290839E-04
     +,   2.3513590E-04,   2.0299989E-04,   1.7582893E-04
     +,   1.5294828E-04,   1.3370448E-04,   1.1749676E-04
     +,   1.0378867E-04,   9.2120907E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz108 = Yx/0.1345
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.8797436E-06,   9.9956105E-06
     +,   1.0110525E-05,   1.0224498E-05,   1.0337531E-05
     +,   1.0449638E-05,   1.0560840E-05,   1.0671150E-05
     +,   1.0780597E-05,   1.0889215E-05,   1.0997031E-05
     +,   1.1104090E-05,   1.1210434E-05,   1.1316119E-05
     +,   1.1421194E-05,   1.1525728E-05,   1.1629786E-05
     +,   1.1733448E-05,   1.1836797E-05,   1.1939920E-05
     +,   1.2042920E-05,   1.2145909E-05,   1.2248994E-05
     +,   1.2352320E-05,   1.2456010E-05,   1.2560222E-05
     +,   1.2665118E-05,   1.2770875E-05,   1.2877683E-05
     +,   1.2985747E-05,   1.3095288E-05,   1.3206543E-05
     +,   1.3319773E-05,   1.3435249E-05,   1.3553273E-05
     +,   1.3674158E-05,   1.3798252E-05,   1.3925911E-05
     +,   1.4057535E-05,   1.4193532E-05,   1.4334356E-05
     +,   1.4480473E-05,   1.4632389E-05,   1.4790638E-05
     +,   1.4955785E-05,   1.5128426E-05,   1.5309197E-05
     +,   1.5498756E-05,   1.5697804E-05,   1.5907075E-05
     +,   1.6127329E-05,   1.6359372E-05,   1.6604026E-05
     +,   1.6862170E-05,   1.7134682E-05,   1.7422490E-05
     +,   1.7726545E-05,   1.8047811E-05,   1.8387291E-05
     +,   1.8745992E-05,   1.9124942E-05,   1.9525180E-05
     +,   1.9947725E-05,   2.0393640E-05,   2.0863963E-05
     +,   2.1359700E-05,   2.1881890E-05,   2.2431475E-05
     +,   2.3009448E-05,   2.3616680E-05,   2.4254092E-05
     +,   2.4922447E-05,   2.5622545E-05,   2.6355025E-05
     +,   2.7120519E-05,   2.7919565E-05,   2.8752589E-05
     +,   2.9619881E-05,   3.0521696E-05,   3.1458178E-05
     +,   3.2429256E-05,   3.3434866E-05,   3.4474677E-05
     +,   3.5548372E-05,   3.6655347E-05,   3.7795024E-05
     +,   3.8966507E-05,   4.0168943E-05,   4.1401163E-05
     +,   4.2662010E-05,   4.3950167E-05,   4.5264129E-05
     +,   4.6602257E-05,   4.7962876E-05,   4.9344235E-05
     +,   5.0744311E-05,   5.2161195E-05,   5.3592714E-05
     +,   5.5036802E-05,   5.6491164E-05,   5.7953624E-05
     +,   5.9421804E-05,   6.0893475E-05,   6.2366205E-05
     +,   6.3837731E-05,   6.5305772E-05,   6.6767978E-05
     +,   6.8222042E-05,   6.9665766E-05,   7.1097027E-05
     +,   7.2513605E-05,   7.3913521E-05,   7.5294680E-05
     +,   7.6655233E-05,   7.7993216E-05,   7.9306963E-05
     +,   8.0594640E-05,   8.1854691E-05,   8.3085491E-05
     +,   8.4285573E-05,   8.5453539E-05,   8.6587999E-05
     +,   8.7687651E-05,   8.8751280E-05,   8.9777779E-05
     +,   9.0766021E-05,   9.1715017E-05,   9.2623763E-05
     +,   9.3491457E-05,   9.4317242E-05,   9.5100491E-05
     +,   9.5840551E-05,   9.6536955E-05,   9.7189368E-05
     +,   9.7797565E-05,   9.8361546E-05,   9.8881501E-05
     +,   9.9357741E-05,   9.9791010E-05,   1.0018220E-04
     +,   1.0053263E-04,   1.0084385E-04,   1.0111793E-04
     +,   1.0135733E-04,   1.0156498E-04,   1.0174435E-04
     +,   1.0189951E-04,   1.0203500E-04,   1.0215610E-04
     +,   1.0226875E-04,   1.0237950E-04,   1.0249573E-04
     +,   1.0262542E-04,   1.0277735E-04,   1.0296108E-04
     +,   1.0318682E-04,   1.0346555E-04,   1.0380892E-04
     +,   1.0422931E-04,   1.0473964E-04,   1.0535345E-04
     +,   1.0608492E-04,   1.0694857E-04,   1.0795940E-04
     +,   1.0913286E-04,   1.1048480E-04,   1.1203114E-04
     +,   1.1378818E-04,   1.1577255E-04,   1.1800101E-04
     +,   1.2049055E-04,   1.2325826E-04,   1.2632173E-04
     +,   1.2969882E-04,   1.3340755E-04,   1.3746659E-04
     +,   1.4189525E-04,   1.4671320E-04,   1.5194069E-04
     +,   1.5759934E-04,   1.6371155E-04,   1.7030042E-04
     +,   1.7739001E-04,   1.8500598E-04,   1.9317528E-04
     +,   2.0192511E-04,   2.1128383E-04,   2.2128121E-04
     +,   2.3194791E-04,   2.4331427E-04,   2.5541274E-04
     +,   2.6827690E-04,   2.8194155E-04,   2.9644492E-04
     +,   3.1183232E-04,   3.2815701E-04,   3.4548502E-04
     +,   3.6390070E-04,   3.8351427E-04,   4.0446728E-04
     +,   4.2693692E-04,   4.5114246E-04,   4.7734697E-04
     +,   5.0585257E-04,   5.3698709E-04,   5.7109114E-04
     +,   6.0848921E-04,   6.4945279E-04,   6.9416314E-04
     +,   7.4267149E-04,   7.9486181E-04,   8.5041678E-04
     +,   9.0881187E-04,   9.6932973E-04,   1.0310953E-03
     +,   1.0931329E-03,   1.1544556E-03,   1.2141614E-03
     +,   1.2715211E-03,   1.3260494E-03,   1.3775622E-03
     +,   1.4261836E-03,   1.4723336E-03,   1.5167078E-03
     +,   1.5602628E-03,   1.6042194E-03,   1.6500822E-03
     +,   1.6996504E-03,   1.7550078E-03,   1.8184328E-03
     +,   1.8922972E-03,   1.9790085E-03,   2.0811174E-03
     +,   2.2016133E-03,   2.3443711E-03,   2.5147167E-03
     +,   2.7199355E-03,   2.9699046E-03,   3.2779078E-03
     +,   3.6612544E-03,   4.1403058E-03,   4.7340808E-03
     +,   5.4519847E-03,   6.2848306E-03,   7.2015012E-03
     +,   8.1576472E-03,   9.1169411E-03,   1.0076642E-02
     +,   1.1080927E-02,   1.2201409E-02,   1.3476250E-02
     +,   1.4837231E-02,   1.6099147E-02,   1.7066158E-02
     +,   1.7694820E-02,   1.8150633E-02,   1.8657472E-02
     +,   1.9259099E-02,   1.9743938E-02,   1.9831583E-02
     +,   1.9424818E-02,   1.8656559E-02,   1.7708486E-02
     +,   1.6633242E-02,   1.5370240E-02,   1.3896484E-02
     +,   1.2319368E-02,   1.0822424E-02,   9.5470119E-03
     +,   8.5300189E-03,   7.7256905E-03,   7.0611169E-03
     +,   6.4759720E-03,   5.9346892E-03,   5.4221298E-03
     +,   4.9346532E-03,   4.4727996E-03,   4.0375693E-03
     +,   3.6294593E-03,   3.2491856E-03,   2.8980793E-03
     +,   2.5778231E-03,   2.2893511E-03,   2.0320287E-03
     +,   1.8033832E-03,   1.5997335E-03,   1.4170719E-03
     +,   1.2519448E-03,   1.1019186E-03,   9.6555188E-04
     +,   8.4214489E-04,   7.3131808E-04,   6.3271431E-04
     +,   5.4578023E-04,   4.6974199E-04,   4.0362545E-04
     +,   3.4636605E-04,   2.9688148E-04,   2.5415744E-04
     +,   2.1727475E-04,   1.8543717E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz110 = Yx/0.1275
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.7840875E-06,   1.0007841E-05
     +,   1.0234472E-05,   1.0463971E-05,   1.0696337E-05
     +,   1.0931570E-05,   1.1169666E-05,   1.1410631E-05
     +,   1.1654467E-05,   1.1901190E-05,   1.2150806E-05
     +,   1.2403334E-05,   1.2658794E-05,   1.2917212E-05
     +,   1.3178619E-05,   1.3443054E-05,   1.3710558E-05
     +,   1.3981191E-05,   1.4255003E-05,   1.4532072E-05
     +,   1.4812472E-05,   1.5096289E-05,   1.5383628E-05
     +,   1.5674606E-05,   1.5969328E-05,   1.6267955E-05
     +,   1.6570621E-05,   1.6877506E-05,   1.7188777E-05
     +,   1.7504643E-05,   1.7825321E-05,   1.8151039E-05
     +,   1.8482051E-05,   1.8818635E-05,   1.9161082E-05
     +,   1.9509704E-05,   1.9864838E-05,   2.0226837E-05
     +,   2.0596099E-05,   2.0973004E-05,   2.1357990E-05
     +,   2.1751515E-05,   2.2154041E-05,   2.2566068E-05
     +,   2.2988115E-05,   2.3420720E-05,   2.3864455E-05
     +,   2.4319894E-05,   2.4787636E-05,   2.5268306E-05
     +,   2.5762538E-05,   2.6270976E-05,   2.6794271E-05
     +,   2.7333117E-05,   2.7888149E-05,   2.8460059E-05
     +,   2.9049510E-05,   2.9657154E-05,   3.0283638E-05
     +,   3.0929597E-05,   3.1595635E-05,   3.2282325E-05
     +,   3.2990178E-05,   3.3719709E-05,   3.4471384E-05
     +,   3.5245543E-05,   3.6042551E-05,   3.6862621E-05
     +,   3.7705966E-05,   3.8572605E-05,   3.9462589E-05
     +,   4.0375740E-05,   4.1311894E-05,   4.2270643E-05
     +,   4.3251563E-05,   4.4254084E-05,   4.5277458E-05
     +,   4.6320769E-05,   4.7383055E-05,   4.8463215E-05
     +,   4.9559869E-05,   5.0671657E-05,   5.1796924E-05
     +,   5.2934021E-05,   5.4081011E-05,   5.5235982E-05
     +,   5.6396733E-05,   5.7561116E-05,   5.8726677E-05
     +,   5.9891045E-05,   6.1051731E-05,   6.2206069E-05
     +,   6.3351392E-05,   6.4485008E-05,   6.5604276E-05
     +,   6.6706365E-05,   6.7788664E-05,   6.8848392E-05
     +,   6.9883012E-05,   7.0889866E-05,   7.1866569E-05
     +,   7.2810704E-05,   7.3720104E-05,   7.4592586E-05
     +,   7.5426316E-05,   7.6219541E-05,   7.6970653E-05
     +,   7.7678349E-05,   7.8341473E-05,   7.8959158E-05
     +,   7.9530670E-05,   8.0055637E-05,   8.0533784E-05
     +,   8.0965197E-05,   8.1350110E-05,   8.1689032E-05
     +,   8.1982675E-05,   8.2231971E-05,   8.2438026E-05
     +,   8.2602150E-05,   8.2725855E-05,   8.2810722E-05
     +,   8.2858540E-05,   8.2871164E-05,   8.2850558E-05
     +,   8.2798724E-05,   8.2717779E-05,   8.2609768E-05
     +,   8.2476843E-05,   8.2321021E-05,   8.2144405E-05
     +,   8.1948972E-05,   8.1736609E-05,   8.1509206E-05
     +,   8.1268474E-05,   8.1016056E-05,   8.0753496E-05
     +,   8.0482198E-05,   8.0203514E-05,   7.9918631E-05
     +,   7.9628677E-05,   7.9334692E-05,   7.9037643E-05
     +,   7.8738456E-05,   7.8438032E-05,   7.8137244E-05
     +,   7.7837016E-05,   7.7538323E-05,   7.7242228E-05
     +,   7.6949873E-05,   7.6662582E-05,   7.6381846E-05
     +,   7.6109369E-05,   7.5847071E-05,   7.5597171E-05
     +,   7.5362143E-05,   7.5144817E-05,   7.4948286E-05
     +,   7.4776042E-05,   7.4631927E-05,   7.4520111E-05
     +,   7.4445212E-05,   7.4412135E-05,   7.4426236E-05
     +,   7.4493248E-05,   7.4619289E-05,   7.4810931E-05
     +,   7.5075142E-05,   7.5419433E-05,   7.5851822E-05
     +,   7.6380929E-05,   7.7016055E-05,   7.7767327E-05
     +,   7.8645782E-05,   7.9663499E-05,   8.0833866E-05
     +,   8.2171711E-05,   8.3693398E-05,   8.5417181E-05
     +,   8.7363347E-05,   8.9554531E-05,   9.2015594E-05
     +,   9.4773946E-05,   9.7859811E-05,   1.0130608E-04
     +,   1.0514826E-04,   1.0942439E-04,   1.1417525E-04
     +,   1.1944423E-04,   1.2527630E-04,   1.3171896E-04
     +,   1.3882176E-04,   1.4663565E-04,   1.5521300E-04
     +,   1.6460885E-04,   1.7487996E-04,   1.8608499E-04
     +,   1.9828498E-04,   2.1154441E-04,   2.2593104E-04
     +,   2.4151508E-04,   2.5836908E-04,   2.7656893E-04
     +,   2.9619108E-04,   3.1730888E-04,   3.3999362E-04
     +,   3.6430990E-04,   3.9030972E-04,   4.1803080E-04
     +,   4.4749465E-04,   4.7870225E-04,   5.1162922E-04
     +,   5.4622605E-04,   5.8241945E-04,   6.2010990E-04
     +,   6.5916928E-04,   6.9944421E-04,   7.4076251E-04
     +,   7.8293605E-04,   8.2577142E-04,   8.6910021E-04
     +,   9.1281137E-04,   9.5689675E-04,   1.0015174E-03
     +,   1.0470765E-03,   1.0942848E-03,   1.1442133E-03
     +,   1.1983234E-03,   1.2584644E-03,   1.3268174E-03
     +,   1.4058013E-03,   1.4979645E-03,   1.6058626E-03
     +,   1.7319348E-03,   1.8783781E-03,   2.0470342E-03
     +,   2.2391842E-03,   2.4551996E-03,   2.6940794E-03
     +,   2.9528621E-03,   3.2260939E-03,   3.5056928E-03
     +,   3.7816660E-03,   4.0440303E-03,   4.2858510E-03
     +,   4.5068860E-03,   4.7166361E-03,   4.9349815E-03
     +,   5.1889280E-03,   5.5050580E-03,   5.8994330E-03
     +,   6.3691833E-03,   6.8914769E-03,   7.4341190E-03
     +,   7.9760784E-03,   8.5286200E-03,   9.1438890E-03
     +,   9.9006174E-03,   1.0867347E-02,   1.2056614E-02
     +,   1.3392946E-02,   1.4716779E-02,   1.5832379E-02
     +,   1.6584614E-02,   1.6927218E-02,   1.6939495E-02
     +,   1.6771151E-02,   1.6547570E-02,   1.6306531E-02
     +,   1.6013445E-02,   1.5626298E-02,   1.5135670E-02
     +,   1.4552043E-02,   1.3882406E-02,   1.3135304E-02
     +,   1.2337450E-02,   1.1526800E-02,   1.0725660E-02
     +,   9.9261645E-03,   9.1053760E-03,   8.2530128E-03
     +,   7.3860358E-03,   6.5396931E-03,   5.7470081E-03
     +,   5.0232969E-03,   4.3653091E-03,   3.7607327E-03
     +,   3.1992891E-03,   2.6784325E-03,   2.2025430E-03
     +,   1.7789525E-03,   1.4136301E-03,   1.1088306E-03
     +,   8.6248020E-04,   6.6904153E-04,   5.2080036E-04
     +,   4.0928141E-04,   3.2629230E-04,   2.6465053E-04
     +,   2.1848999E-04,   1.8331798E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz112 = Yx/0.122833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1337895E-05,   2.1642973E-05
     +,   2.1941818E-05,   2.2234470E-05,   2.2521019E-05
     +,   2.2801611E-05,   2.3076438E-05,   2.3345754E-05
     +,   2.3609848E-05,   2.3869086E-05,   2.4123881E-05
     +,   2.4374689E-05,   2.4622026E-05,   2.4866464E-05
     +,   2.5108617E-05,   2.5349153E-05,   2.5588786E-05
     +,   2.5828280E-05,   2.6068428E-05,   2.6310059E-05
     +,   2.6554060E-05,   2.6801321E-05,   2.7052763E-05
     +,   2.7309348E-05,   2.7572016E-05,   2.7841756E-05
     +,   2.8119541E-05,   2.8406330E-05,   2.8703098E-05
     +,   2.9010796E-05,   2.9330346E-05,   2.9662642E-05
     +,   3.0008552E-05,   3.0368898E-05,   3.0744439E-05
     +,   3.1135889E-05,   3.1543892E-05,   3.1969030E-05
     +,   3.2411812E-05,   3.2872627E-05,   3.3351822E-05
     +,   3.3849625E-05,   3.4366163E-05,   3.4901463E-05
     +,   3.5455440E-05,   3.6027897E-05,   3.6618530E-05
     +,   3.7226899E-05,   3.7852475E-05,   3.8494589E-05
     +,   3.9152455E-05,   3.9825187E-05,   4.0511753E-05
     +,   4.1211071E-05,   4.1921856E-05,   4.2642820E-05
     +,   4.3372529E-05,   4.4109453E-05,   4.4851990E-05
     +,   4.5598477E-05,   4.6347177E-05,   4.7096306E-05
     +,   4.7843991E-05,   4.8588379E-05,   4.9327624E-05
     +,   5.0059763E-05,   5.0782935E-05,   5.1495230E-05
     +,   5.2194824E-05,   5.2879859E-05,   5.3548607E-05
     +,   5.4199343E-05,   5.4830471E-05,   5.5440429E-05
     +,   5.6027799E-05,   5.6591256E-05,   5.7129615E-05
     +,   5.7641744E-05,   5.8126741E-05,   5.8583821E-05
     +,   5.9012302E-05,   5.9411708E-05,   5.9781683E-05
     +,   6.0122075E-05,   6.0432827E-05,   6.0714112E-05
     +,   6.0966202E-05,   6.1189574E-05,   6.1384810E-05
     +,   6.1552688E-05,   6.1694074E-05,   6.1810002E-05
     +,   6.1901614E-05,   6.1970168E-05,   6.2017018E-05
     +,   6.2043619E-05,   6.2051506E-05,   6.2042258E-05
     +,   6.2017549E-05,   6.1979044E-05,   6.1928476E-05
     +,   6.1867569E-05,   6.1798019E-05,   6.1721563E-05
     +,   6.1639854E-05,   6.1554558E-05,   6.1467217E-05
     +,   6.1379396E-05,   6.1292485E-05,   6.1207851E-05
     +,   6.1126753E-05,   6.1050327E-05,   6.0979623E-05
     +,   6.0915543E-05,   6.0858896E-05,   6.0810366E-05
     +,   6.0770471E-05,   6.0739658E-05,   6.0718208E-05
     +,   6.0706265E-05,   6.0703922E-05,   6.0711078E-05
     +,   6.0727587E-05,   6.0753162E-05,   6.0787443E-05
     +,   6.0829967E-05,   6.0880247E-05,   6.0937695E-05
     +,   6.1001709E-05,   6.1071631E-05,   6.1146849E-05
     +,   6.1226681E-05,   6.1310529E-05,   6.1397797E-05
     +,   6.1487968E-05,   6.1580613E-05,   6.1675360E-05
     +,   6.1771985E-05,   6.1870378E-05,   6.1970633E-05
     +,   6.2072962E-05,   6.2177809E-05,   6.2285777E-05
     +,   6.2397768E-05,   6.2514875E-05,   6.2638479E-05
     +,   6.2770239E-05,   6.2912099E-05,   6.3066262E-05
     +,   6.3235362E-05,   6.3422260E-05,   6.3630214E-05
     +,   6.3862768E-05,   6.4123909E-05,   6.4417967E-05
     +,   6.4749642E-05,   6.5124004E-05,   6.5546592E-05
     +,   6.6023298E-05,   6.6560489E-05,   6.7164969E-05
     +,   6.7844063E-05,   6.8605492E-05,   6.9457536E-05
     +,   7.0409042E-05,   7.1469483E-05,   7.2648858E-05
     +,   7.3957781E-05,   7.5407661E-05,   7.7010598E-05
     +,   7.8779383E-05,   8.0727586E-05,   8.2869607E-05
     +,   8.5220730E-05,   8.7796849E-05,   9.0614820E-05
     +,   9.3692375E-05,   9.7047610E-05,   1.0069944E-04
     +,   1.0466730E-04,   1.0897126E-04,   1.1363123E-04
     +,   1.1866721E-04,   1.2409926E-04,   1.2994709E-04
     +,   1.3622931E-04,   1.4296346E-04,   1.5016615E-04
     +,   1.5785231E-04,   1.6603402E-04,   1.7472180E-04
     +,   1.8392339E-04,   1.9364305E-04,   2.0388133E-04
     +,   2.1463602E-04,   2.2590105E-04,   2.3766572E-04
     +,   2.4991500E-04,   2.6263073E-04,   2.7579060E-04
     +,   2.8936705E-04,   3.0332865E-04,   3.1764089E-04
     +,   3.3226542E-04,   3.4715858E-04,   3.6227528E-04
     +,   3.7756690E-04,   3.9298180E-04,   4.0846632E-04
     +,   4.2396857E-04,   4.3943769E-04,   4.5482631E-04
     +,   4.7009508E-04,   4.8521702E-04,   5.0018175E-04
     +,   5.1499921E-04,   5.2970584E-04,   5.4437038E-04
     +,   5.5909541E-04,   5.7401677E-04,   5.8930641E-04
     +,   6.0516619E-04,   6.2182004E-04,   6.3950836E-04
     +,   6.5847993E-04,   6.7898916E-04,   7.0129544E-04
     +,   7.2567695E-04,   7.5245486E-04,   7.8202854E-04
     +,   8.1491872E-04,   8.5181976E-04,   8.9364708E-04
     +,   9.4156858E-04,   9.9699700E-04,   1.0615580E-03
     +,   1.1369906E-03,   1.2249779E-03,   1.3269379E-03
     +,   1.4437821E-03,   1.5756803E-03,   1.7218980E-03
     +,   1.8808106E-03,   2.0501560E-03,   2.2275292E-03
     +,   2.4111513E-03,   2.6009674E-03,   2.8000588E-03
     +,   3.0162761E-03,   3.2637715E-03,   3.5635801E-03
     +,   3.9417231E-03,   4.4235922E-03,   5.0249840E-03
     +,   5.7428554E-03,   6.5512769E-03,   7.4072741E-03
     +,   8.2660327E-03,   9.0976404E-03,   9.8961713E-03
     +,   1.0678781E-02,   1.1480590E-02,   1.2348763E-02
     +,   1.3328901E-02,   1.4437093E-02,   1.5629478E-02
     +,   1.6798386E-02,   1.7810160E-02,   1.8561227E-02
     +,   1.9007301E-02,   1.9146495E-02,   1.8985322E-02
     +,   1.8529074E-02,   1.7801668E-02,   1.6861390E-02
     +,   1.5786186E-02,   1.4643363E-02,   1.3478177E-02
     +,   1.2326002E-02,   1.1223979E-02,   1.0201809E-02
     +,   9.2644533E-03,   8.3896890E-03,   7.5473264E-03
     +,   6.7220517E-03,   5.9219529E-03,   5.1689236E-03
     +,   4.4829473E-03,   3.8720889E-03,   3.3321946E-03
     +,   2.8530066E-03,   2.4244073E-03,   2.0399396E-03
     +,   1.6968107E-03,   1.3943608E-03,   1.1321425E-03
     +,   9.0886414E-04,   7.2199095E-04,   5.6802778E-04
     +,   4.4290166E-04,   3.4242769E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz113 = Yx/0.120536585365854
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5883943E-05,   1.6375625E-05
     +,   1.6875487E-05,   1.7383383E-05,   1.7899160E-05
     +,   1.8422656E-05,   1.8953702E-05,   1.9492119E-05
     +,   2.0037711E-05,   2.0590314E-05,   2.1149714E-05
     +,   2.1715710E-05,   2.2288095E-05,   2.2866665E-05
     +,   2.3451197E-05,   2.4041479E-05,   2.4637295E-05
     +,   2.5238418E-05,   2.5844629E-05,   2.6455704E-05
     +,   2.7071428E-05,   2.7691574E-05,   2.8315915E-05
     +,   2.8944261E-05,   2.9576362E-05,   3.0212028E-05
     +,   3.0851046E-05,   3.1493204E-05,   3.2138298E-05
     +,   3.2786142E-05,   3.3436525E-05,   3.4089258E-05
     +,   3.4744164E-05,   3.5401059E-05,   3.6059748E-05
     +,   3.6720085E-05,   3.7381877E-05,   3.8044953E-05
     +,   3.8709193E-05,   3.9374383E-05,   4.0040413E-05
     +,   4.0707124E-05,   4.1374358E-05,   4.2041982E-05
     +,   4.2709860E-05,   4.3377848E-05,   4.4045832E-05
     +,   4.4713674E-05,   4.5381272E-05,   4.6048510E-05
     +,   4.6715279E-05,   4.7381487E-05,   4.8047048E-05
     +,   4.8711929E-05,   4.9376013E-05,   5.0039325E-05
     +,   5.0701816E-05,   5.1363510E-05,   5.2024447E-05
     +,   5.2684696E-05,   5.3344378E-05,   5.4003645E-05
     +,   5.4662672E-05,   5.5321754E-05,   5.5981240E-05
     +,   5.6641464E-05,   5.7302965E-05,   5.7966274E-05
     +,   5.8632064E-05,   5.9301074E-05,   5.9974227E-05
     +,   6.0652492E-05,   6.1337036E-05,   6.2029088E-05
     +,   6.2730112E-05,   6.3441708E-05,   6.4165608E-05
     +,   6.4903688E-05,   6.5658089E-05,   6.6431101E-05
     +,   6.7225126E-05,   6.8042864E-05,   6.8887050E-05
     +,   6.9760747E-05,   7.0667018E-05,   7.1609262E-05
     +,   7.2590818E-05,   7.3615331E-05,   7.4686403E-05
     +,   7.5807788E-05,   7.6983320E-05,   7.8216763E-05
     +,   7.9511810E-05,   8.0872291E-05,   8.2301784E-05
     +,   8.3803665E-05,   8.5381296E-05,   8.7037566E-05
     +,   8.8775239E-05,   9.0596557E-05,   9.2503491E-05
     +,   9.4497322E-05,   9.6579082E-05,   9.8748897E-05
     +,   1.0100645E-04,   1.0335080E-04,   1.0578003E-04
     +,   1.0829149E-04,   1.1088183E-04,   1.1354693E-04
     +,   1.1628152E-04,   1.1907976E-04,   1.2193465E-04
     +,   1.2483865E-04,   1.2778302E-04,   1.3075862E-04
     +,   1.3375502E-04,   1.3676164E-04,   1.3976665E-04
     +,   1.4275816E-04,   1.4572350E-04,   1.4864971E-04
     +,   1.5152321E-04,   1.5433061E-04,   1.5705841E-04
     +,   1.5969285E-04,   1.6222059E-04,   1.6462835E-04
     +,   1.6690356E-04,   1.6903382E-04,   1.7100776E-04
     +,   1.7281435E-04,   1.7444394E-04,   1.7588731E-04
     +,   1.7713678E-04,   1.7818551E-04,   1.7902807E-04
     +,   1.7966008E-04,   1.8007885E-04,   1.8028264E-04
     +,   1.8027128E-04,   1.8004593E-04,   1.7960911E-04
     +,   1.7896459E-04,   1.7811749E-04,   1.7707402E-04
     +,   1.7584166E-04,   1.7442892E-04,   1.7284534E-04
     +,   1.7110126E-04,   1.6920772E-04,   1.6717664E-04
     +,   1.6502055E-04,   1.6275221E-04,   1.6038479E-04
     +,   1.5793182E-04,   1.5540700E-04,   1.5282402E-04
     +,   1.5019640E-04,   1.4753788E-04,   1.4486186E-04
     +,   1.4218138E-04,   1.3950953E-04,   1.3685906E-04
     +,   1.3424222E-04,   1.3167107E-04,   1.2915746E-04
     +,   1.2671314E-04,   1.2434940E-04,   1.2207747E-04
     +,   1.1990868E-04,   1.1785437E-04,   1.1592591E-04
     +,   1.1413499E-04,   1.1249379E-04,   1.1101488E-04
     +,   1.0971155E-04,   1.0859793E-04,   1.0768921E-04
     +,   1.0700151E-04,   1.0655238E-04,   1.0636091E-04
     +,   1.0644765E-04,   1.0683496E-04,   1.0754714E-04
     +,   1.0861044E-04,   1.1005316E-04,   1.1190579E-04
     +,   1.1420099E-04,   1.1697321E-04,   1.2025912E-04
     +,   1.2409700E-04,   1.2852644E-04,   1.3358794E-04
     +,   1.3932247E-04,   1.4577119E-04,   1.5297359E-04
     +,   1.6096736E-04,   1.6978745E-04,   1.7946532E-04
     +,   1.9002632E-04,   2.0148924E-04,   2.1386624E-04
     +,   2.2716081E-04,   2.4136556E-04,   2.5646403E-04
     +,   2.7242882E-04,   2.8922065E-04,   3.0678898E-04
     +,   3.2507468E-04,   3.4400937E-04,   3.6351601E-04
     +,   3.8351250E-04,   4.0391527E-04,   4.2464101E-04
     +,   4.4560971E-04,   4.6674887E-04,   4.8799938E-04
     +,   5.0931924E-04,   5.3068594E-04,   5.5210595E-04
     +,   5.7361729E-04,   5.9529534E-04,   6.1725889E-04
     +,   6.3967780E-04,   6.6277746E-04,   6.8684079E-04
     +,   7.1221322E-04,   7.3930196E-04,   7.6857337E-04
     +,   8.0053892E-04,   8.3574449E-04,   8.7475579E-04
     +,   9.1813412E-04,   9.6641295E-04,   1.0200914E-03
     +,   1.0796171E-03,   1.1453803E-03,   1.2177174E-03
     +,   1.2969163E-03,   1.3832046E-03,   1.4767292E-03
     +,   1.5775373E-03,   1.6855738E-03,   1.8007148E-03
     +,   1.9228841E-03,   2.0523006E-03,   2.1898299E-03
     +,   2.3373507E-03,   2.4979925E-03,   2.6761631E-03
     +,   2.8771600E-03,   3.1065440E-03,   3.3696031E-03
     +,   3.6713216E-03,   4.0170820E-03,   4.4137449E-03
     +,   4.8702681E-03,   5.3968146E-03,   6.0020620E-03
     +,   6.6900286E-03,   7.4584670E-03,   8.3001805E-03
     +,   9.2060948E-03,   1.0167381E-02,   1.1173799E-02
     +,   1.2207463E-02,   1.3236661E-02,   1.4217062E-02
     +,   1.5104035E-02,   1.5869234E-02,   1.6508231E-02
     +,   1.7032072E-02,   1.7450884E-02,   1.7764132E-02
     +,   1.7960420E-02,   1.8019071E-02,   1.7910194E-02
     +,   1.7601751E-02,   1.7076816E-02,   1.6349096E-02
     +,   1.5460876E-02,   1.4461434E-02,   1.3384673E-02
     +,   1.2243006E-02,   1.1040367E-02,   9.7899865E-03
     +,   8.5232034E-03,   7.2848978E-03,   6.1208629E-03
     +,   5.0667608E-03,   4.1422583E-03,   3.3519247E-03
     +,   2.6893409E-03,   2.1424221E-03,   1.6971248E-03
     +,   1.3395702E-03,   1.0564777E-03,   8.3527929E-04
     +,   6.6413643E-04,   5.3232705E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz114 = Yx/0.122166666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0594940E-06,   9.2279543E-06
     +,   9.3979552E-06,   9.5695077E-06,   9.7426291E-06
     +,   9.9173340E-06,   1.0093635E-05,   1.0271548E-05
     +,   1.0451086E-05,   1.0632271E-05,   1.0815112E-05
     +,   1.0999623E-05,   1.1185815E-05,   1.1373699E-05
     +,   1.1563284E-05,   1.1754578E-05,   1.1947583E-05
     +,   1.2142302E-05,   1.2338736E-05,   1.2536879E-05
     +,   1.2736719E-05,   1.2938247E-05,   1.3141445E-05
     +,   1.3346295E-05,   1.3552764E-05,   1.3760829E-05
     +,   1.3970448E-05,   1.4181581E-05,   1.4394174E-05
     +,   1.4608180E-05,   1.4823535E-05,   1.5040170E-05
     +,   1.5258015E-05,   1.5476991E-05,   1.5697015E-05
     +,   1.5917994E-05,   1.6139833E-05,   1.6362435E-05
     +,   1.6585700E-05,   1.6809512E-05,   1.7033770E-05
     +,   1.7258359E-05,   1.7483175E-05,   1.7708107E-05
     +,   1.7933051E-05,   1.8157914E-05,   1.8382596E-05
     +,   1.8607025E-05,   1.8831135E-05,   1.9054876E-05
     +,   1.9278219E-05,   1.9501162E-05,   1.9723731E-05
     +,   1.9945992E-05,   2.0168032E-05,   2.0390013E-05
     +,   2.0612129E-05,   2.0834637E-05,   2.1057860E-05
     +,   2.1282205E-05,   2.1508156E-05,   2.1736294E-05
     +,   2.1967287E-05,   2.2201939E-05,   2.2441181E-05
     +,   2.2686047E-05,   2.2937757E-05,   2.3197646E-05
     +,   2.3467264E-05,   2.3748307E-05,   2.4042693E-05
     +,   2.4352501E-05,   2.4680076E-05,   2.5027939E-05
     +,   2.5398878E-05,   2.5795907E-05,   2.6222280E-05
     +,   2.6681473E-05,   2.7177246E-05,   2.7713611E-05
     +,   2.8294759E-05,   2.8925180E-05,   2.9609502E-05
     +,   3.0352636E-05,   3.1159580E-05,   3.2035565E-05
     +,   3.2985830E-05,   3.4015815E-05,   3.5130859E-05
     +,   3.6336358E-05,   3.7637692E-05,   3.9039958E-05
     +,   4.0548075E-05,   4.2166776E-05,   4.3900436E-05
     +,   4.5752851E-05,   4.7727495E-05,   4.9827020E-05
     +,   5.2053634E-05,   5.4408491E-05,   5.6892175E-05
     +,   5.9504018E-05,   6.2242660E-05,   6.5105276E-05
     +,   6.8088171E-05,   7.1186441E-05,   7.4393756E-05
     +,   7.7702411E-05,   8.1103673E-05,   8.4587511E-05
     +,   8.8142231E-05,   9.1755348E-05,   9.5412717E-05
     +,   9.9099496E-05,   1.0279936E-04,   1.0649545E-04
     +,   1.1016969E-04,   1.1380375E-04,   1.1737832E-04
     +,   1.2087406E-04,   1.2427146E-04,   1.2755090E-04
     +,   1.3069282E-04,   1.3367846E-04,   1.3648953E-04
     +,   1.3910841E-04,   1.4151880E-04,   1.4370531E-04
     +,   1.4565422E-04,   1.4735314E-04,   1.4879157E-04
     +,   1.4996066E-04,   1.5085371E-04,   1.5146587E-04
     +,   1.5179437E-04,   1.5183873E-04,   1.5160037E-04
     +,   1.5108292E-04,   1.5029201E-04,   1.4923529E-04
     +,   1.4792224E-04,   1.4636421E-04,   1.4457403E-04
     +,   1.4256612E-04,   1.4035623E-04,   1.3796121E-04
     +,   1.3539870E-04,   1.3268749E-04,   1.2984686E-04
     +,   1.2689621E-04,   1.2385540E-04,   1.2074436E-04
     +,   1.1758303E-04,   1.1439090E-04,   1.1118713E-04
     +,   1.0799057E-04,   1.0481952E-04,   1.0169156E-04
     +,   9.8623466E-05,   9.5631774E-05,   9.2731920E-05
     +,   8.9938738E-05,   8.7266555E-05,   8.4729123E-05
     +,   8.2339480E-05,   8.0110243E-05,   7.8053767E-05
     +,   7.6182143E-05,   7.4507159E-05,   7.3040450E-05
     +,   7.1793896E-05,   7.0779352E-05,   7.0008769E-05
     +,   6.9494410E-05,   6.9248832E-05,   6.9284855E-05
     +,   6.9615744E-05,   7.0254930E-05,   7.1216164E-05
     +,   7.2513474E-05,   7.4160977E-05,   7.6172750E-05
     +,   7.8562727E-05,   8.1344566E-05,   8.4531588E-05
     +,   8.8136148E-05,   9.2169626E-05,   9.6642521E-05
     +,   1.0156402E-04,   1.0694116E-04,   1.1277957E-04
     +,   1.1908301E-04,   1.2585243E-04,   1.3308649E-04
     +,   1.4078165E-04,   1.4893175E-04,   1.5752767E-04
     +,   1.6655707E-04,   1.7600605E-04,   1.8585769E-04
     +,   1.9609212E-04,   2.0668698E-04,   2.1761845E-04
     +,   2.2886066E-04,   2.4038483E-04,   2.5216179E-04
     +,   2.6416098E-04,   2.7635010E-04,   2.8869594E-04
     +,   3.0116577E-04,   3.1372628E-04,   3.2634352E-04
     +,   3.3898349E-04,   3.5161359E-04,   3.6420190E-04
     +,   3.7671640E-04,   3.8912622E-04,   4.0140306E-04
     +,   4.1352044E-04,   4.2545426E-04,   4.3718604E-04
     +,   4.4870435E-04,   4.6000798E-04,   4.7111115E-04
     +,   4.8205222E-04,   4.9290282E-04,   5.0377805E-04
     +,   5.1485375E-04,   5.2638270E-04,   5.3871149E-04
     +,   5.5229466E-04,   5.6770677E-04,   5.8564724E-04
     +,   6.0693128E-04,   6.3246954E-04,   6.6323776E-04
     +,   7.0023345E-04,   7.4442319E-04,   7.9670007E-04
     +,   8.5785211E-04,   9.2855020E-04,   1.0093525E-03
     +,   1.1007397E-03,   1.2031625E-03,   1.3170565E-03
     +,   1.4428013E-03,   1.5806265E-03,   1.7304361E-03
     +,   1.8915951E-03,   2.0627540E-03,   2.2419051E-03
     +,   2.4266832E-03,   2.6150218E-03,   2.8061075E-03
     +,   3.0014454E-03,   3.2057529E-03,   3.4273996E-03
     +,   3.6780641E-03,   3.9712107E-03,   4.3191095E-03
     +,   4.7286330E-03,   5.1973592E-03,   5.7127099E-03
     +,   6.2570521E-03,   6.8192603E-03,   7.4081868E-03
     +,   8.0578635E-03,   8.8159610E-03,   9.7160870E-03
     +,   1.0749565E-02,   1.1857821E-02,   1.2955833E-02
     +,   1.3973475E-02,   1.4887001E-02,   1.5718415E-02
     +,   1.6501125E-02,   1.7229689E-02,   1.7828312E-02
     +,   1.8171761E-02,   1.8154899E-02,   1.7760074E-02
     +,   1.7067814E-02,   1.6205648E-02,   1.5279109E-02
     +,   1.4332745E-02,   1.3358719E-02,   1.2332957E-02
     +,   1.1247383E-02,   1.0117961E-02,   8.9723412E-03
     +,   7.8356145E-03,   6.7255399E-03,   5.6578615E-03
     +,   4.6522352E-03,   3.7331388E-03,   2.9241801E-03
     +,   2.2412429E-03,   1.6881151E-03,   1.2569916E-03
     +,   9.3179190E-04,   6.9262862E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz115 = Yx/0.11319512195122
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5684815E-06,   4.7414537E-06
     +,   4.9198447E-06,   5.1038046E-06,   5.2934897E-06
     +,   5.4890565E-06,   5.6906692E-06,   5.8984970E-06
     +,   6.1127043E-06,   6.3334737E-06,   6.5609779E-06
     +,   6.7954029E-06,   7.0369265E-06,   7.2857401E-06
     +,   7.5420303E-06,   7.8059893E-06,   8.0778109E-06
     +,   8.3576851E-06,   8.6458058E-06,   8.9423665E-06
     +,   9.2475602E-06,   9.5615787E-06,   9.8846012E-06
     +,   1.0216832E-05,   1.0558428E-05,   1.0909584E-05
     +,   1.1270460E-05,   1.1641222E-05,   1.2022025E-05
     +,   1.2413011E-05,   1.2814316E-05,   1.3226065E-05
     +,   1.3648364E-05,   1.4081317E-05,   1.4525000E-05
     +,   1.4979480E-05,   1.5444806E-05,   1.5920992E-05
     +,   1.6408079E-05,   1.6906015E-05,   1.7414788E-05
     +,   1.7934335E-05,   1.8464563E-05,   1.9005371E-05
     +,   1.9556619E-05,   2.0118132E-05,   2.0689726E-05
     +,   2.1271167E-05,   2.1862208E-05,   2.2462558E-05
     +,   2.3071902E-05,   2.3689890E-05,   2.4316128E-05
     +,   2.4950237E-05,   2.5591726E-05,   2.6240150E-05
     +,   2.6894990E-05,   2.7555694E-05,   2.8221712E-05
     +,   2.8892422E-05,   2.9567196E-05,   3.0245399E-05
     +,   3.0926298E-05,   3.1609205E-05,   3.2293407E-05
     +,   3.2978107E-05,   3.3662582E-05,   3.4345961E-05
     +,   3.5027497E-05,   3.5706304E-05,   3.6381596E-05
     +,   3.7052472E-05,   3.7718106E-05,   3.8377613E-05
     +,   3.9030125E-05,   3.9674804E-05,   4.0310752E-05
     +,   4.0937091E-05,   4.1552998E-05,   4.2157637E-05
     +,   4.2750118E-05,   4.3329677E-05,   4.3895470E-05
     +,   4.4446741E-05,   4.4982695E-05,   4.5502624E-05
     +,   4.6005778E-05,   4.6491496E-05,   4.6959078E-05
     +,   4.7407928E-05,   4.7837442E-05,   4.8247046E-05
     +,   4.8636204E-05,   4.9004415E-05,   4.9351253E-05
     +,   4.9676248E-05,   4.9979059E-05,   5.0259314E-05
     +,   5.0516719E-05,   5.0751009E-05,   5.0961968E-05
     +,   5.1149389E-05,   5.1313153E-05,   5.1453149E-05
     +,   5.1569310E-05,   5.1661616E-05,   5.1730123E-05
     +,   5.1774852E-05,   5.1795942E-05,   5.1793515E-05
     +,   5.1767773E-05,   5.1718958E-05,   5.1647305E-05
     +,   5.1553176E-05,   5.1436909E-05,   5.1298903E-05
     +,   5.1139628E-05,   5.0959556E-05,   5.0759256E-05
     +,   5.0539304E-05,   5.0300343E-05,   5.0043080E-05
     +,   4.9768274E-05,   4.9476745E-05,   4.9169365E-05
     +,   4.8847087E-05,   4.8510930E-05,   4.8162015E-05
     +,   4.7801503E-05,   4.7430702E-05,   4.7050966E-05
     +,   4.6663812E-05,   4.6270819E-05,   4.5873738E-05
     +,   4.5474440E-05,   4.5074914E-05,   4.4677356E-05
     +,   4.4284123E-05,   4.3897726E-05,   4.3520886E-05
     +,   4.3156542E-05,   4.2807857E-05,   4.2478187E-05
     +,   4.2171163E-05,   4.1890653E-05,   4.1640775E-05
     +,   4.1425912E-05,   4.1250718E-05,   4.1120107E-05
     +,   4.1039246E-05,   4.1013554E-05,   4.1048697E-05
     +,   4.1150546E-05,   4.1325173E-05,   4.1578838E-05
     +,   4.1917912E-05,   4.2348842E-05,   4.2878139E-05
     +,   4.3512315E-05,   4.4257737E-05,   4.5120676E-05
     +,   4.6107212E-05,   4.7223028E-05,   4.8473423E-05
     +,   4.9863269E-05,   5.1396899E-05,   5.3077856E-05
     +,   5.4908905E-05,   5.6892066E-05,   5.9028447E-05
     +,   6.1317951E-05,   6.3759398E-05,   6.6350563E-05
     +,   6.9088070E-05,   7.1966992E-05,   7.4981377E-05
     +,   7.8124074E-05,   8.1386461E-05,   8.4758736E-05
     +,   8.8230168E-05,   9.1789036E-05,   9.5422503E-05
     +,   9.9116944E-05,   1.0285848E-04,   1.0663283E-04
     +,   1.1042538E-04,   1.1422161E-04,   1.1800764E-04
     +,   1.2177038E-04,   1.2549735E-04,   1.2917772E-04
     +,   1.3280245E-04,   1.3636422E-04,   1.3985820E-04
     +,   1.4328244E-04,   1.4663805E-04,   1.4992943E-04
     +,   1.5316455E-04,   1.5635557E-04,   1.5951884E-04
     +,   1.6267473E-04,   1.6584799E-04,   1.6906775E-04
     +,   1.7236739E-04,   1.7578348E-04,   1.7935626E-04
     +,   1.8312859E-04,   1.8714447E-04,   1.9144853E-04
     +,   1.9608485E-04,   2.0109516E-04,   2.0651726E-04
     +,   2.1238338E-04,   2.1871933E-04,   2.2554297E-04
     +,   2.3286269E-04,   2.4067788E-04,   2.4897995E-04
     +,   2.5775316E-04,   2.6697689E-04,   2.7663072E-04
     +,   2.8669889E-04,   2.9717552E-04,   3.0807185E-04
     +,   3.1942458E-04,   3.3130136E-04,   3.4380719E-04
     +,   3.5708968E-04,   3.7134471E-04,   3.8681726E-04
     +,   4.0380302E-04,   4.2264955E-04,   4.4375932E-04
     +,   4.6759110E-04,   4.9465953E-04,   5.2554201E-04
     +,   5.6087546E-04,   6.0134486E-04,   6.4766395E-04
     +,   7.0054090E-04,   7.6061941E-04,   8.2839665E-04
     +,   9.0413366E-04,   9.8776328E-04,   1.0787954E-03
     +,   1.1762391E-03,   1.2785705E-03,   1.3837438E-03
     +,   1.4892402E-03,   1.5921652E-03,   1.6894548E-03
     +,   1.7781281E-03,   1.8556594E-03,   1.9204704E-03
     +,   1.9724993E-03,   2.0137762E-03,   2.0489236E-03
     +,   2.0855120E-03,   2.1341769E-03,   2.2084839E-03
     +,   2.3243092E-03,   2.4983266E-03,   2.7449969E-03
     +,   3.0717675E-03,   3.4734691E-03,   3.9289864E-03
     +,   4.4043697E-03,   4.8656780E-03,   5.2998764E-03
     +,   5.7349275E-03,   6.2455088E-03,   6.9346265E-03
     +,   7.8945942E-03,   9.1644889E-03,   1.0702654E-02
     +,   1.2382557E-02,   1.4013944E-02,   1.5393670E-02
     +,   1.6388733E-02,   1.7018812E-02,   1.7471941E-02
     +,   1.7998103E-02,   1.8719967E-02,   1.9504961E-02
     +,   2.0030430E-02,   1.9999597E-02,   1.9313768E-02
     +,   1.8066837E-02,   1.6423484E-02,   1.4523492E-02
     +,   1.2471834E-02,   1.0371384E-02,   8.3425101E-03
     +,   6.5075816E-03,   4.9569816E-03,   3.7233641E-03
     +,   2.7839036E-03,   2.0839090E-03,   1.5642337E-03
     +,   1.1768910E-03,   8.8806270E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz116 = Yx/0.104487804878049
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.1265531E-07,   9.6066594E-07
     +,   1.0107440E-06,   1.0629590E-06,   1.1173845E-06
     +,   1.1740954E-06,   1.2331705E-06,   1.2946917E-06
     +,   1.3587432E-06,   1.4254174E-06,   1.4948070E-06
     +,   1.5670113E-06,   1.6421350E-06,   1.7202880E-06
     +,   1.8015885E-06,   1.8861591E-06,   1.9741342E-06
     +,   2.0656539E-06,   2.1608685E-06,   2.2599395E-06
     +,   2.3630396E-06,   2.4703529E-06,   2.5820768E-06
     +,   2.6984305E-06,   2.8196343E-06,   2.9459420E-06
     +,   3.0776157E-06,   3.2149421E-06,   3.3582266E-06
     +,   3.5078006E-06,   3.6640183E-06,   3.8272601E-06
     +,   3.9979368E-06,   4.1764861E-06,   4.3633781E-06
     +,   4.5591155E-06,   4.7642379E-06,   4.9793143E-06
     +,   5.2049663E-06,   5.4418324E-06,   5.6906115E-06
     +,   5.9520326E-06,   6.2268691E-06,   6.5159352E-06
     +,   6.8200939E-06,   7.1402424E-06,   7.4773275E-06
     +,   7.8323346E-06,   8.2062907E-06,   8.6002574E-06
     +,   9.0153389E-06,   9.4526677E-06,   9.9134040E-06
     +,   1.0398759E-05,   1.0909916E-05,   1.1448126E-05
     +,   1.2014621E-05,   1.2610643E-05,   1.3237431E-05
     +,   1.3896209E-05,   1.4588180E-05,   1.5314527E-05
     +,   1.6076343E-05,   1.6874734E-05,   1.7710743E-05
     +,   1.8585251E-05,   1.9499168E-05,   2.0453175E-05
     +,   2.1447986E-05,   2.2484030E-05,   2.3561757E-05
     +,   2.4681303E-05,   2.5842804E-05,   2.7046060E-05
     +,   2.8290793E-05,   2.9576539E-05,   3.0902542E-05
     +,   3.2267824E-05,   3.3671262E-05,   3.5111541E-05
     +,   3.6586942E-05,   3.8095710E-05,   3.9635655E-05
     +,   4.1204556E-05,   4.2799787E-05,   4.4418659E-05
     +,   4.6058085E-05,   4.7714992E-05,   4.9385868E-05
     +,   5.1067222E-05,   5.2755393E-05,   5.4446449E-05
     +,   5.6136385E-05,   5.7821155E-05,   5.9496659E-05
     +,   6.1158629E-05,   6.2802930E-05,   6.4425258E-05
     +,   6.6021545E-05,   6.7587607E-05,   6.9119546E-05
     +,   7.0613372E-05,   7.2065479E-05,   7.3472227E-05
     +,   7.4830343E-05,   7.6136770E-05,   7.7388635E-05
     +,   7.8583333E-05,   7.9718673E-05,   8.0792706E-05
     +,   8.1803795E-05,   8.2750696E-05,   8.3632403E-05
     +,   8.4448424E-05,   8.5198437E-05,   8.5882624E-05
     +,   8.6501394E-05,   8.7055545E-05,   8.7546141E-05
     +,   8.7974629E-05,   8.8342684E-05,   8.8652225E-05
     +,   8.8905479E-05,   8.9104797E-05,   8.9252782E-05
     +,   8.9352143E-05,   8.9405752E-05,   8.9416550E-05
     +,   8.9387533E-05,   8.9321729E-05,   8.9222201E-05
     +,   8.9091882E-05,   8.8933732E-05,   8.8750603E-05
     +,   8.8545181E-05,   8.8320048E-05,   8.8077642E-05
     +,   8.7820168E-05,   8.7549713E-05,   8.7268061E-05
     +,   8.6976863E-05,   8.6677559E-05,   8.6371307E-05
     +,   8.6059117E-05,   8.5741784E-05,   8.5419939E-05
     +,   8.5094012E-05,   8.4764324E-05,   8.4431100E-05
     +,   8.4094456E-05,   8.3754458E-05,   8.3411243E-05
     +,   8.3064937E-05,   8.2715778E-05,   8.2364146E-05
     +,   8.2010672E-05,   8.1656210E-05,   8.1301994E-05
     +,   8.0949583E-05,   8.0601108E-05,   8.0259109E-05
     +,   7.9926780E-05,   7.9607991E-05,   7.9307334E-05
     +,   7.9030171E-05,   7.8782694E-05,   7.8572048E-05
     +,   7.8406258E-05,   7.8294375E-05,   7.8246427E-05
     +,   7.8273435E-05,   7.8387515E-05,   7.8601734E-05
     +,   7.8930127E-05,   7.9387690E-05,   7.9990241E-05
     +,   8.0754413E-05,   8.1697428E-05,   8.2837018E-05
     +,   8.4191299E-05,   8.5778564E-05,   8.7616958E-05
     +,   8.9724308E-05,   9.2117967E-05,   9.4814452E-05
     +,   9.7828954E-05,   1.0117506E-04,   1.0486480E-04
     +,   1.0890799E-04,   1.1331149E-04,   1.1807957E-04
     +,   1.2321337E-04,   1.2871007E-04,   1.3456293E-04
     +,   1.4076142E-04,   1.4729073E-04,   1.5413115E-04
     +,   1.6125827E-04,   1.6864370E-04,   1.7625450E-04
     +,   1.8405305E-04,   1.9199775E-04,   2.0004397E-04
     +,   2.0814406E-04,   2.1624756E-04,   2.2430281E-04
     +,   2.3225798E-04,   2.4006091E-04,   2.4766137E-04
     +,   2.5501204E-04,   2.6207007E-04,   2.6879786E-04
     +,   2.7516487E-04,   2.8114996E-04,   2.8674246E-04
     +,   2.9194361E-04,   2.9676891E-04,   3.0125034E-04
     +,   3.0543795E-04,   3.0940110E-04,   3.1323169E-04
     +,   3.1704514E-04,   3.2098204E-04,   3.2520926E-04
     +,   3.2992134E-04,   3.3533986E-04,   3.4171322E-04
     +,   3.4931448E-04,   3.5843934E-04,   3.6940209E-04
     +,   3.8252948E-04,   3.9815411E-04,   4.1660940E-04
     +,   4.3821914E-04,   4.6328706E-04,   4.9209187E-04
     +,   5.2487710E-04,   5.6184269E-04,   6.0314155E-04
     +,   6.4888434E-04,   6.9914298E-04,   7.5396273E-04
     +,   8.1338547E-04,   8.7748212E-04,   9.4637705E-04
     +,   1.0202623E-03,   1.0993964E-03,   1.1840704E-03
     +,   1.2745224E-03,   1.3708051E-03,   1.4726691E-03
     +,   1.5794431E-03,   1.6900081E-03,   1.8029058E-03
     +,   1.9166068E-03,   2.0298678E-03,   2.1421176E-03
     +,   2.2537964E-03,   2.3665465E-03,   2.4832773E-03
     +,   2.6081493E-03,   2.7465024E-03,   2.9046023E-03
     +,   3.0889709E-03,   3.3052831E-03,   3.5572804E-03
     +,   3.8464016E-03,   4.1727293E-03,   4.5366734E-03
     +,   4.9398737E-03,   5.3845588E-03,   5.8747469E-03
     +,   6.4253979E-03,   7.0803547E-03,   7.9232501E-03
     +,   9.0525569E-03,   1.0510011E-02,   1.2204572E-02
     +,   1.3915176E-02,   1.5406319E-02,   1.6576771E-02
     +,   1.7500242E-02,   1.8314501E-02,   1.9064615E-02
     +,   1.9645892E-02,   1.9880671E-02,   1.9645477E-02
     +,   1.8941678E-02,   1.7866228E-02,   1.6520616E-02
     +,   1.4947576E-02,   1.3152060E-02,   1.1177073E-02
     +,   9.1475435E-03,   7.2371699E-03,   5.5906908E-03
     +,   4.2706253E-03,   3.2584451E-03,   2.4930700E-03
     +,   1.9093497E-03,   1.4576860E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz117 = Yx/0.104125
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3268654E-05,   4.4676173E-05
     +,   4.6102981E-05,   4.7547743E-05,   4.9009031E-05
     +,   5.0485298E-05,   5.1974988E-05,   5.3476400E-05
     +,   5.4987762E-05,   5.6507295E-05,   5.8033085E-05
     +,   5.9563172E-05,   6.1095532E-05,   6.2628060E-05
     +,   6.4158652E-05,   6.5685104E-05,   6.7205256E-05
     +,   6.8716807E-05,   7.0217495E-05,   7.1705050E-05
     +,   7.3177158E-05,   7.4631513E-05,   7.6065793E-05
     +,   7.7477765E-05,   7.8865087E-05,   8.0225611E-05
     +,   8.1557111E-05,   8.2857405E-05,   8.4124425E-05
     +,   8.5356158E-05,   8.6550637E-05,   8.7706001E-05
     +,   8.8820459E-05,   8.9892346E-05,   9.0920090E-05
     +,   9.1902279E-05,   9.2837530E-05,   9.3724659E-05
     +,   9.4562645E-05,   9.5350559E-05,   9.6087606E-05
     +,   9.6773227E-05,   9.7406919E-05,   9.7988501E-05
     +,   9.8517754E-05,   9.8994809E-05,   9.9419893E-05
     +,   9.9793382E-05,   1.0011590E-04,   1.0038823E-04
     +,   1.0061129E-04,   1.0078624E-04,   1.0091432E-04
     +,   1.0099700E-04,   1.0103593E-04,   1.0103289E-04
     +,   1.0098986E-04,   1.0090890E-04,   1.0079228E-04
     +,   1.0064231E-04,   1.0046157E-04,   1.0025266E-04
     +,   1.0001830E-04,   9.9761310E-05,   9.9484605E-05
     +,   9.9191151E-05,   9.8884026E-05,   9.8566314E-05
     +,   9.8241137E-05,   9.7911652E-05,   9.7581018E-05
     +,   9.7252443E-05,   9.6928983E-05,   9.6613781E-05
     +,   9.6309908E-05,   9.6020318E-05,   9.5747928E-05
     +,   9.5495583E-05,   9.5265983E-05,   9.5061703E-05
     +,   9.4885239E-05,   9.4738905E-05,   9.4624855E-05
     +,   9.4545045E-05,   9.4501345E-05,   9.4495357E-05
     +,   9.4528499E-05,   9.4601972E-05,   9.4716808E-05
     +,   9.4873787E-05,   9.5073447E-05,   9.5316143E-05
     +,   9.5601958E-05,   9.5930751E-05,   9.6302203E-05
     +,   9.6715667E-05,   9.7170414E-05,   9.7665274E-05
     +,   9.8199074E-05,   9.8770266E-05,   9.9377256E-05
     +,   1.0001810E-04,   1.0069081E-04,   1.0139311E-04
     +,   1.0212265E-04,   1.0287690E-04,   1.0365320E-04
     +,   1.0444877E-04,   1.0526078E-04,   1.0608628E-04
     +,   1.0692225E-04,   1.0776570E-04,   1.0861351E-04
     +,   1.0946266E-04,   1.1031007E-04,   1.1115280E-04
     +,   1.1198782E-04,   1.1281230E-04,   1.1362343E-04
     +,   1.1441859E-04,   1.1519524E-04,   1.1595097E-04
     +,   1.1668354E-04,   1.1739093E-04,   1.1807132E-04
     +,   1.1872304E-04,   1.1934473E-04,   1.1993513E-04
     +,   1.2049341E-04,   1.2101880E-04,   1.2151097E-04
     +,   1.2196970E-04,   1.2239523E-04,   1.2278784E-04
     +,   1.2314843E-04,   1.2347785E-04,   1.2377753E-04
     +,   1.2404902E-04,   1.2429422E-04,   1.2451546E-04
     +,   1.2471527E-04,   1.2489643E-04,   1.2506219E-04
     +,   1.2521603E-04,   1.2536181E-04,   1.2550371E-04
     +,   1.2564614E-04,   1.2579405E-04,   1.2595249E-04
     +,   1.2612699E-04,   1.2632344E-04,   1.2654804E-04
     +,   1.2680715E-04,   1.2710782E-04,   1.2745717E-04
     +,   1.2786266E-04,   1.2833215E-04,   1.2887380E-04
     +,   1.2949597E-04,   1.3020732E-04,   1.3101676E-04
     +,   1.3193335E-04,   1.3296631E-04,   1.3412493E-04
     +,   1.3541852E-04,   1.3685643E-04,   1.3844779E-04
     +,   1.4020156E-04,   1.4212642E-04,   1.4423071E-04
     +,   1.4652211E-04,   1.4900764E-04,   1.5169366E-04
     +,   1.5458565E-04,   1.5768781E-04,   1.6100341E-04
     +,   1.6453442E-04,   1.6828101E-04,   1.7224187E-04
     +,   1.7641415E-04,   1.8079320E-04,   1.8537215E-04
     +,   1.9014218E-04,   1.9509267E-04,   2.0021100E-04
     +,   2.0548205E-04,   2.1088895E-04,   2.1641314E-04
     +,   2.2203427E-04,   2.2773004E-04,   2.3347716E-04
     +,   2.3925155E-04,   2.4502777E-04,   2.5078037E-04
     +,   2.5648400E-04,   2.6211428E-04,   2.6764721E-04
     +,   2.7306075E-04,   2.7833524E-04,   2.8345393E-04
     +,   2.8840324E-04,   2.9317368E-04,   2.9776062E-04
     +,   3.0216505E-04,   3.0639349E-04,   3.1045923E-04
     +,   3.1438255E-04,   3.1819165E-04,   3.2192230E-04
     +,   3.2561910E-04,   3.2933598E-04,   3.3313551E-04
     +,   3.3709014E-04,   3.4128234E-04,   3.4580432E-04
     +,   3.5075849E-04,   3.5625705E-04,   3.6242240E-04
     +,   3.6938657E-04,   3.7728931E-04,   3.8627844E-04
     +,   3.9650805E-04,   4.0813489E-04,   4.2131616E-04
     +,   4.3620617E-04,   4.5295092E-04,   4.7168072E-04
     +,   4.9250474E-04,   5.1550346E-04,   5.4072088E-04
     +,   5.6815328E-04,   5.9774338E-04,   6.2937645E-04
     +,   6.6287408E-04,   6.9799065E-04,   7.3442474E-04
     +,   7.7182223E-04,   8.0979086E-04,   8.4792025E-04
     +,   8.8580995E-04,   9.2309387E-04,   9.5946965E-04
     +,   9.9472993E-04,   1.0287932E-03,   1.0617259E-03
     +,   1.0937614E-03,   1.1253201E-03,   1.1570230E-03
     +,   1.1897009E-03,   1.2243970E-03,   1.2623724E-03
     +,   1.3050936E-03,   1.3542027E-03,   1.4114701E-03
     +,   1.4787186E-03,   1.5577360E-03,   1.6501587E-03
     +,   1.7574035E-03,   1.8806214E-03,   2.0207223E-03
     +,   2.1784368E-03,   2.3544137E-03,   2.5492948E-03
     +,   2.7636788E-03,   2.9979988E-03,   3.2524269E-03
     +,   3.5269139E-03,   3.8215211E-03,   4.1371807E-03
     +,   4.4767279E-03,   4.8458404E-03,   5.2534700E-03
     +,   5.7116007E-03,   6.2339748E-03,   6.8338844E-03
     +,   7.5210184E-03,   8.2983142E-03,   9.1591896E-03
     +,   1.0087934E-02,   1.1063649E-02,   1.2068525E-02
     +,   1.3095669E-02,   1.4151781E-02,   1.5249000E-02
     +,   1.6387269E-02,   1.7533733E-02,   1.8610951E-02
     +,   1.9501336E-02,   2.0069016E-02,   2.0191737E-02
     +,   1.9791942E-02,   1.8857090E-02,   1.7444042E-02
     +,   1.5666675E-02,   1.3672198E-02,   1.1612310E-02
     +,   9.6192826E-03,   7.7902824E-03,   6.1835782E-03
     +,   4.8222472E-03,   3.7032170E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz118 = Yx/0.112682926829268
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz1188(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1041044E-05,   1.1465486E-05
     +,   1.1909469E-05,   1.2373642E-05,   1.2858641E-05
     +,   1.3365100E-05,   1.3893640E-05,   1.4444862E-05
     +,   1.5019345E-05,   1.5617668E-05,   1.6240367E-05
     +,   1.6887952E-05,   1.7560906E-05,   1.8259681E-05
     +,   1.8984687E-05,   1.9736301E-05,   2.0514843E-05
     +,   2.1320604E-05,   2.2153807E-05,   2.3014647E-05
     +,   2.3903232E-05,   2.4819639E-05,   2.5763844E-05
     +,   2.6735854E-05,   2.7735454E-05,   2.8762515E-05
     +,   2.9816752E-05,   3.0897831E-05,   3.2005333E-05
     +,   3.3138782E-05,   3.4297620E-05,   3.5481200E-05
     +,   3.6688834E-05,   3.7919730E-05,   3.9173032E-05
     +,   4.0447812E-05,   4.1743078E-05,   4.3057738E-05
     +,   4.4390730E-05,   4.5740773E-05,   4.7106678E-05
     +,   4.8487127E-05,   4.9880764E-05,   5.1286184E-05
     +,   5.2701951E-05,   5.4126602E-05,   5.5558634E-05
     +,   5.6996527E-05,   5.8438713E-05,   5.9883678E-05
     +,   6.1329883E-05,   6.2775754E-05,   6.4219763E-05
     +,   6.5660461E-05,   6.7096269E-05,   6.8525820E-05
     +,   6.9947659E-05,   7.1360439E-05,   7.2762843E-05
     +,   7.4153613E-05,   7.5531592E-05,   7.6895674E-05
     +,   7.8244710E-05,   7.9577825E-05,   8.0894162E-05
     +,   8.2192841E-05,   8.3473249E-05,   8.4734638E-05
     +,   8.5976593E-05,   8.7198569E-05,   8.8400273E-05
     +,   8.9581372E-05,   9.0741742E-05,   9.1881193E-05
     +,   9.2999733E-05,   9.4097406E-05,   9.5174320E-05
     +,   9.6230542E-05,   9.7266384E-05,   9.8282086E-05
     +,   9.9277910E-05,   1.0025423E-04,   1.0121131E-04
     +,   1.0214960E-04,   1.0306942E-04,   1.0397116E-04
     +,   1.0485509E-04,   1.0572161E-04,   1.0657098E-04
     +,   1.0740347E-04,   1.0821927E-04,   1.0901854E-04
     +,   1.0980133E-04,   1.1056768E-04,   1.1131759E-04
     +,   1.1205082E-04,   1.1276724E-04,   1.1346647E-04
     +,   1.1414817E-04,   1.1481182E-04,   1.1545685E-04
     +,   1.1608256E-04,   1.1668823E-04,   1.1727295E-04
     +,   1.1783587E-04,   1.1837589E-04,   1.1889191E-04
     +,   1.1938284E-04,   1.1984739E-04,   1.2028430E-04
     +,   1.2069222E-04,   1.2106980E-04,   1.2141562E-04
     +,   1.2172830E-04,   1.2200634E-04,   1.2224841E-04
     +,   1.2245304E-04,   1.2261882E-04,   1.2274449E-04
     +,   1.2282870E-04,   1.2287022E-04,   1.2286786E-04
     +,   1.2282055E-04,   1.2272736E-04,   1.2258734E-04
     +,   1.2239977E-04,   1.2216395E-04,   1.2187951E-04
     +,   1.2154600E-04,   1.2116329E-04,   1.2073132E-04
     +,   1.2025028E-04,   1.1972050E-04,   1.1914254E-04
     +,   1.1851710E-04,   1.1784513E-04,   1.1712781E-04
     +,   1.1636657E-04,   1.1556296E-04,   1.1471881E-04
     +,   1.1383623E-04,   1.1291763E-04,   1.1196552E-04
     +,   1.1098272E-04,   1.0997243E-04,   1.0893794E-04
     +,   1.0788289E-04,   1.0681120E-04,   1.0572710E-04
     +,   1.0463504E-04,   1.0353971E-04,   1.0244616E-04
     +,   1.0135977E-04,   1.0028610E-04,   9.9230987E-05
     +,   9.8200610E-05,   9.7201453E-05,   9.6240168E-05
     +,   9.5323718E-05,   9.4459429E-05,   9.3654700E-05
     +,   9.2917304E-05,   9.2255192E-05,   9.1676549E-05
     +,   9.1189788E-05,   9.0803420E-05,   9.0526199E-05
     +,   9.0367001E-05,   9.0334775E-05,   9.0438662E-05
     +,   9.0687732E-05,   9.1091169E-05,   9.1658112E-05
     +,   9.2397633E-05,   9.3318689E-05,   9.4430186E-05
     +,   9.5740746E-05,   9.7258737E-05,   9.8992161E-05
     +,   1.0094870E-04,   1.0313567E-04,   1.0555964E-04
     +,   1.0822662E-04,   1.1114209E-04,   1.1431075E-04
     +,   1.1773634E-04,   1.2142172E-04,   1.2536887E-04
     +,   1.2957903E-04,   1.3405195E-04,   1.3878683E-04
     +,   1.4378213E-04,   1.4903506E-04,   1.5454220E-04
     +,   1.6030010E-04,   1.6630525E-04,   1.7255392E-04
     +,   1.7904304E-04,   1.8577112E-04,   1.9273857E-04
     +,   1.9994771E-04,   2.0740382E-04,   2.1511661E-04
     +,   2.2310014E-04,   2.3137293E-04,   2.3995969E-04
     +,   2.4889110E-04,   2.5820319E-04,   2.6793778E-04
     +,   2.7814234E-04,   2.8886873E-04,   3.0017077E-04
     +,   3.1210316E-04,   3.2471996E-04,   3.3807129E-04
     +,   3.5219933E-04,   3.6713615E-04,   3.8290187E-04
     +,   3.9950068E-04,   4.1691778E-04,   4.3512008E-04
     +,   4.5405547E-04,   4.7365201E-04,   4.9382151E-04
     +,   5.1446538E-04,   5.3547794E-04,   5.5675348E-04
     +,   5.7819445E-04,   5.9972168E-04,   6.2128389E-04
     +,   6.4286252E-04,   6.6448166E-04,   6.8621692E-04
     +,   7.0819544E-04,   7.3059695E-04,   7.5365615E-04
     +,   7.7765691E-04,   8.0292294E-04,   8.2980911E-04
     +,   8.5869373E-04,   8.8996097E-04,   9.2398195E-04
     +,   9.6110423E-04,   1.0016372E-03,   1.0458400E-03
     +,   1.0939147E-03,   1.1460187E-03,   1.2022929E-03
     +,   1.2629031E-03,   1.3281037E-03,   1.3983356E-03
     +,   1.4743146E-03,   1.5571184E-03,   1.6482448E-03
     +,   1.7496214E-03,   1.8635194E-03,   1.9923900E-03
     +,   2.1386419E-03,   2.3044210E-03,   2.4914497E-03
     +,   2.7009798E-03,   2.9339551E-03,   3.1912620E-03
     +,   3.4738693E-03,   3.7826367E-03,   4.1177087E-03
     +,   4.4773421E-03,   4.8566884E-03,   5.2471221E-03
     +,   5.6367465E-03,   6.0123107E-03,   6.3621192E-03
     +,   6.6791754E-03,   6.9633843E-03,   7.2222976E-03
     +,   7.4706310E-03,   7.7291839E-03,   8.0235405E-03
     +,   8.3823167E-03,   8.8338107E-03,   9.4002318E-03
     +,   1.0089236E-02,   1.0885725E-02,   1.1747687E-02
     +,   1.2610845E-02,   1.3401777E-02,   1.4055399E-02
     +,   1.4528017E-02,   1.4799902E-02,   1.4867322E-02
     +,   1.4729654E-02,   1.4380527E-02,   1.3807748E-02
     +,   1.3002137E-02,   1.1970508E-02,   1.0745253E-02
     +,   9.3860840E-03,   7.9715978E-03,   6.5849540E-03
     +,   5.2981651E-03,   4.1616224E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz1188 = Yx/0.10045
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1822301E-05,   2.1983084E-05
     +,   2.2141770E-05,   2.2298647E-05,   2.2454058E-05
     +,   2.2608365E-05,   2.2761966E-05,   2.2915312E-05
     +,   2.3068884E-05,   2.3223221E-05,   2.3378896E-05
     +,   2.3536530E-05,   2.3696806E-05,   2.3860446E-05
     +,   2.4028248E-05,   2.4201046E-05,   2.4379751E-05
     +,   2.4565326E-05,   2.4758809E-05,   2.4961293E-05
     +,   2.5173964E-05,   2.5398060E-05,   2.5634912E-05
     +,   2.5885918E-05,   2.6152547E-05,   2.6436388E-05
     +,   2.6739081E-05,   2.7062360E-05,   2.7408050E-05
     +,   2.7778076E-05,   2.8174429E-05,   2.8599226E-05
     +,   2.9054634E-05,   2.9542947E-05,   3.0066523E-05
     +,   3.0627834E-05,   3.1229396E-05,   3.1873842E-05
     +,   3.2563905E-05,   3.3302302E-05,   3.4091921E-05
     +,   3.4935649E-05,   3.5836430E-05,   3.6797264E-05
     +,   3.7821177E-05,   3.8911207E-05,   4.0070408E-05
     +,   4.1301824E-05,   4.2608452E-05,   4.3993274E-05
     +,   4.5459179E-05,   4.7009005E-05,   4.8645441E-05
     +,   5.0371171E-05,   5.2188512E-05,   5.4099819E-05
     +,   5.6107132E-05,   5.8212281E-05,   6.0416867E-05
     +,   6.2722189E-05,   6.5129250E-05,   6.7638786E-05
     +,   7.0250964E-05,   7.2965828E-05,   7.5783006E-05
     +,   7.8701429E-05,   8.1719983E-05,   8.4836691E-05
     +,   8.8049543E-05,   9.1355614E-05,   9.4751900E-05
     +,   9.8234545E-05,   1.0179965E-04,   1.0544234E-04
     +,   1.0915763E-04,   1.1294020E-04,   1.1678390E-04
     +,   1.2068234E-04,   1.2462895E-04,   1.2861678E-04
     +,   1.3263831E-04,   1.3668627E-04,   1.4075264E-04
     +,   1.4482980E-04,   1.4890953E-04,   1.5298404E-04
     +,   1.5704523E-04,   1.6108537E-04,   1.6509657E-04
     +,   1.6907144E-04,   1.7300274E-04,   1.7688359E-04
     +,   1.8070730E-04,   1.8446786E-04,   1.8815971E-04
     +,   1.9177761E-04,   1.9531712E-04,   1.9877400E-04
     +,   2.0214499E-04,   2.0542716E-04,   2.0861841E-04
     +,   2.1171689E-04,   2.1472169E-04,   2.1763208E-04
     +,   2.2044814E-04,   2.2317035E-04,   2.2579958E-04
     +,   2.2833692E-04,   2.3078402E-04,   2.3314255E-04
     +,   2.3541444E-04,   2.3760181E-04,   2.3970644E-04
     +,   2.4173045E-04,   2.4367544E-04,   2.4554308E-04
     +,   2.4733448E-04,   2.4905059E-04,   2.5069172E-04
     +,   2.5225789E-04,   2.5374847E-04,   2.5516219E-04
     +,   2.5649727E-04,   2.5775126E-04,   2.5892124E-04
     +,   2.6000335E-04,   2.6099352E-04,   2.6188674E-04
     +,   2.6267770E-04,   2.6336056E-04,   2.6392911E-04
     +,   2.6437672E-04,   2.6469669E-04,   2.6488191E-04
     +,   2.6492556E-04,   2.6482050E-04,   2.6456005E-04
     +,   2.6413769E-04,   2.6354720E-04,   2.6278297E-04
     +,   2.6183983E-04,   2.6071363E-04,   2.5940046E-04
     +,   2.5789771E-04,   2.5620367E-04,   2.5431736E-04
     +,   2.5223917E-04,   2.4997033E-04,   2.4751364E-04
     +,   2.4487253E-04,   2.4205184E-04,   2.3905752E-04
     +,   2.3589691E-04,   2.3257810E-04,   2.2911030E-04
     +,   2.2550390E-04,   2.2177036E-04,   2.1792171E-04
     +,   2.1397095E-04,   2.0993207E-04,   2.0581952E-04
     +,   2.0164822E-04,   1.9743400E-04,   1.9319319E-04
     +,   1.8894223E-04,   1.8469784E-04,   1.8047739E-04
     +,   1.7629850E-04,   1.7217862E-04,   1.6813545E-04
     +,   1.6418712E-04,   1.6035169E-04,   1.5664723E-04
     +,   1.5309182E-04,   1.4970398E-04,   1.4650183E-04
     +,   1.4350374E-04,   1.4072808E-04,   1.3819331E-04
     +,   1.3591774E-04,   1.3391950E-04,   1.3221687E-04
     +,   1.3082786E-04,   1.2977008E-04,   1.2906089E-04
     +,   1.2871737E-04,   1.2875571E-04,   1.2919174E-04
     +,   1.3004040E-04,   1.3131554E-04,   1.3303013E-04
     +,   1.3519611E-04,   1.3782392E-04,   1.4092270E-04
     +,   1.4450039E-04,   1.4856372E-04,   1.5311792E-04
     +,   1.5816676E-04,   1.6371356E-04,   1.6976061E-04
     +,   1.7630940E-04,   1.8336099E-04,   1.9091692E-04
     +,   1.9897909E-04,   2.0754951E-04,   2.1663182E-04
     +,   2.2623119E-04,   2.3635384E-04,   2.4700738E-04
     +,   2.5820261E-04,   2.6995165E-04,   2.8226778E-04
     +,   2.9516578E-04,   3.0866245E-04,   3.2277536E-04
     +,   3.3752169E-04,   3.5291849E-04,   3.6898447E-04
     +,   3.8573789E-04,   4.0319611E-04,   4.2138019E-04
     +,   4.4031415E-04,   4.6002699E-04,   4.8055439E-04
     +,   5.0194672E-04,   5.2426936E-04,   5.4760627E-04
     +,   5.7206507E-04,   5.9778203E-04,   6.2492309E-04
     +,   6.5368344E-04,   6.8428455E-04,   7.1697502E-04
     +,   7.5201772E-04,   7.8967673E-04,   8.3020545E-04
     +,   8.7382761E-04,   9.2071114E-04,   9.7094546E-04
     +,   1.0245256E-03,   1.0813253E-03,   1.1410799E-03
     +,   1.2033781E-03,   1.2676684E-03,   1.3332680E-03
     +,   1.3993870E-03,   1.4651709E-03,   1.5297612E-03
     +,   1.5923616E-03,   1.6523050E-03,   1.7091569E-03
     +,   1.7627924E-03,   1.8134790E-03,   1.8619403E-03
     +,   1.9094172E-03,   1.9576675E-03,   2.0089473E-03
     +,   2.0659412E-03,   2.1316712E-03,   2.2093616E-03
     +,   2.3022813E-03,   2.4136074E-03,   2.5462683E-03
     +,   2.7027712E-03,   2.8849703E-03,   3.0938629E-03
     +,   3.3293127E-03,   3.5897908E-03,   3.8723338E-03
     +,   4.1726967E-03,   4.4858055E-03,   4.8064427E-03
     +,   5.1300852E-03,   5.4536602E-03,   5.7758423E-03
     +,   6.0970243E-03,   6.4189737E-03,   6.7443270E-03
     +,   7.0763533E-03,   7.4188653E-03,   7.7763414E-03
     +,   8.1534851E-03,   8.5540172E-03,   8.9782402E-03
     +,   9.4201509E-03,   9.8646721E-03,   1.0286481E-02
     +,   1.0651225E-02,   1.0919319E-02,   1.1051754E-02
     +,   1.1016434E-02,   1.0793646E-02,   1.0379399E-02
     +,   9.7860275E-03,   9.0404144E-03,   8.1800967E-03
     +,   7.2487406E-03,   6.2909876E-03,   5.3484226E-03
     +,   4.4559864E-03,   3.6401490E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz120 = Yx/0.0852564102564103
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1943244E-05,   2.2270593E-05
     +,   2.2601876E-05,   2.2937638E-05,   2.3278499E-05
     +,   2.3625156E-05,   2.3978391E-05,   2.4339117E-05
     +,   2.4708306E-05,   2.5087120E-05,   2.5476809E-05
     +,   2.5878795E-05,   2.6294676E-05,   2.6726231E-05
     +,   2.7175442E-05,   2.7644526E-05,   2.8135943E-05
     +,   2.8652415E-05,   2.9196966E-05,   2.9772926E-05
     +,   3.0383966E-05,   3.1034102E-05,   3.1727741E-05
     +,   3.2469721E-05,   3.3265209E-05,   3.4119897E-05
     +,   3.5039880E-05,   3.6031692E-05,   3.7102342E-05
     +,   3.8259284E-05,   3.9510411E-05,   4.0864037E-05
     +,   4.2328862E-05,   4.3913995E-05,   4.5628847E-05
     +,   4.7483121E-05,   4.9486796E-05,   5.1650004E-05
     +,   5.3983156E-05,   5.6496545E-05,   5.9200796E-05
     +,   6.2106432E-05,   6.5224041E-05,   6.8564332E-05
     +,   7.2138064E-05,   7.5956137E-05,   8.0029851E-05
     +,   8.4370855E-05,   8.8991532E-05,   9.3905153E-05
     +,   9.9126228E-05,   1.0467100E-04,   1.1055775E-04
     +,   1.1680799E-04,   1.2344582E-04,   1.3050069E-04
     +,   1.3800671E-04,   1.4600501E-04,   1.5454470E-04
     +,   1.6368498E-04,   1.7349761E-04,   1.8406952E-04
     +,   1.9550568E-04,   2.0793463E-04,   2.2151285E-04
     +,   2.3642824E-04,   2.5291019E-04,   2.7123102E-04
     +,   2.9171736E-04,   3.1474989E-04,   3.4077300E-04
     +,   3.7028996E-04,   4.0387045E-04,   4.4214012E-04
     +,   4.8578947E-04,   5.3557550E-04,   5.9233588E-04
     +,   6.5702328E-04,   7.3076517E-04,   8.1493508E-04
     +,   9.1122725E-04,   1.0217531E-03,   1.1490551E-03
     +,   1.2961052E-03,   1.4661505E-03,   1.6625292E-03
     +,   1.8883288E-03,   2.1461041E-03,   2.4375035E-03
     +,   2.7630881E-03,   3.1221334E-03,   3.5125520E-03
     +,   3.9309501E-03,   4.3729478E-03,   4.8338342E-03
     +,   5.3097103E-03,   5.7992269E-03,   6.3050012E-03
     +,   6.8343538E-03,   7.3977169E-03,   8.0047818E-03
     +,   8.6581595E-03,   9.3473596E-03,   1.0045393E-02
     +,   1.0711322E-02,   1.1298791E-02,   1.1767997E-02
     +,   1.2095985E-02,   1.2280401E-02,   1.2334871E-02
     +,   1.2279317E-02,   1.2131613E-02,   1.1905997E-02
     +,   1.1619279E-02,   1.1299593E-02,   1.0989344E-02
     +,   1.0737571E-02,   1.0583323E-02,   1.0539563E-02
     +,   1.0586241E-02,   1.0676717E-02,   1.0753226E-02
     +,   1.0763880E-02,   1.0674343E-02,   1.0472089E-02
     +,   1.0164467E-02,   9.7734015E-03,   9.3286010E-03
     +,   8.8606346E-03,   8.3952947E-03,   7.9497322E-03
     +,   7.5316103E-03,   7.1407380E-03,   6.7726560E-03
     +,   6.4223316E-03,   6.0870270E-03,   5.7674260E-03
     +,   5.4669958E-03,   5.1903604E-03,   4.9413657E-03
     +,   4.7215992E-03,   4.5297304E-03,   4.3616719E-03
     +,   4.2114416E-03,   4.0722350E-03,   3.9374353E-03
     +,   3.8014364E-03,   3.6601245E-03,   3.5110787E-03
     +,   3.3535189E-03,   3.1881314E-03,   3.0167603E-03
     +,   2.8420154E-03,   2.6668885E-03,   2.4943983E-03
     +,   2.3273204E-03,   2.1679755E-03,   2.0181260E-03
     +,   1.8789680E-03,   1.7511831E-03,   1.6349992E-03
     +,   1.5302878E-03,   1.4366608E-03,   1.3535337E-03
     +,   1.2801826E-03,   1.2157984E-03,   1.1595257E-03
     +,   1.1104920E-03,   1.0678341E-03,   1.0307276E-03
     +,   9.9841226E-04,   9.7020704E-04,   9.4551739E-04
     +,   9.2384830E-04,   9.0479944E-04,   8.8805507E-04
     +,   8.7337231E-04,   8.6056819E-04,   8.4950053E-04
     +,   8.4005069E-04,   8.3211059E-04,   8.2557183E-04
     +,   8.2031370E-04,   8.1620051E-04,   8.1307796E-04
     +,   8.1077090E-04,   8.0908928E-04,   8.0782815E-04
     +,   8.0677407E-04,   8.0570992E-04,   8.0442155E-04
     +,   8.0270268E-04,   8.0035988E-04,   7.9721911E-04
     +,   7.9312827E-04,   7.8796223E-04,   7.8162370E-04
     +,   7.7404658E-04,   7.6519628E-04,   7.5506774E-04
     +,   7.4368785E-04,   7.3111110E-04,   7.1741600E-04
     +,   7.0270529E-04,   6.8710127E-04,   6.7073904E-04
     +,   6.5376650E-04,   6.3633773E-04,   6.1861117E-04
     +,   6.0074200E-04,   5.8288139E-04,   5.6517392E-04
     +,   5.4775330E-04,   5.3073943E-04,   5.1423785E-04
     +,   4.9833918E-04,   4.8311724E-04,   4.6862796E-04
     +,   4.5491106E-04,   4.4199143E-04,   4.2987723E-04
     +,   4.1856323E-04,   4.0803204E-04,   3.9825554E-04
     +,   3.8919551E-04,   3.8080645E-04,   3.7303742E-04
     +,   3.6583355E-04,   3.5913658E-04,   3.5288726E-04
     +,   3.4702662E-04,   3.4149719E-04,   3.3624322E-04
     +,   3.3121204E-04,   3.2635519E-04,   3.2162786E-04
     +,   3.1698961E-04,   3.1240526E-04,   3.0784460E-04
     +,   3.0328153E-04,   2.9869474E-04,   2.9406781E-04
     +,   2.8938841E-04,   2.8464786E-04,   2.7984104E-04
     +,   2.7496612E-04,   2.7002435E-04,   2.6501884E-04
     +,   2.5995451E-04,   2.5483876E-04,   2.4967943E-04
     +,   2.4448545E-04,   2.3926653E-04,   2.3403289E-04
     +,   2.2879438E-04,   2.2356074E-04,   2.1834177E-04
     +,   2.1314697E-04,   2.0798465E-04,   2.0286282E-04
     +,   1.9778883E-04,   1.9276964E-04,   1.8781101E-04
     +,   1.8291781E-04,   1.7809495E-04,   1.7334601E-04
     +,   1.6867412E-04,   1.6408201E-04,   1.5957178E-04
     +,   1.5514495E-04,   1.5080253E-04,   1.4654538E-04
     +,   1.4237416E-04,   1.3828874E-04,   1.3428900E-04
     +,   1.3037487E-04,   1.2654564E-04,   1.2280088E-04
     +,   1.1913962E-04,   1.1556129E-04,   1.1206469E-04
     +,   1.0864908E-04,   1.0531317E-04,   1.0205611E-04
     +,   9.8876524E-05,   9.5773496E-05,   9.2745679E-05
     +,   8.9791836E-05,   8.6910863E-05,   8.4101361E-05
     +,   8.1362261E-05,   7.8692115E-05,   7.6089840E-05
     +,   7.3553972E-05,   7.1083436E-05,   6.8676774E-05
     +,   6.6332912E-05,   6.4050422E-05,   6.1828250E-05
     +,   5.9665028E-05,   5.7559693E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz75 = Yx/0.138833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2971113E-05,   2.3826373E-05
     +,   2.4714383E-05,   2.5636129E-05,   2.6592594E-05
     +,   2.7584727E-05,   2.8613458E-05,   2.9679693E-05
     +,   3.0784264E-05,   3.1928008E-05,   3.3111661E-05
     +,   3.4335910E-05,   3.5601359E-05,   3.6908528E-05
     +,   3.8257866E-05,   3.9649705E-05,   4.1084262E-05
     +,   4.2561678E-05,   4.4081924E-05,   4.5644880E-05
     +,   4.7250298E-05,   4.8897775E-05,   5.0586776E-05
     +,   5.2316729E-05,   5.4086759E-05,   5.5896064E-05
     +,   5.7743644E-05,   5.9628408E-05,   6.1549239E-05
     +,   6.3504973E-05,   6.5494401E-05,   6.7516376E-05
     +,   6.9569833E-05,   7.1653805E-05,   7.3767500E-05
     +,   7.5910379E-05,   7.8082187E-05,   8.0283033E-05
     +,   8.2513601E-05,   8.4774940E-05,   8.7068867E-05
     +,   8.9397960E-05,   9.1765549E-05,   9.4175957E-05
     +,   9.6634547E-05,   9.9147837E-05,   1.0172368E-04
     +,   1.0437124E-04,   1.0710120E-04,   1.0992582E-04
     +,   1.1285907E-04,   1.1591673E-04,   1.1911637E-04
     +,   1.2247774E-04,   1.2602223E-04,   1.2977365E-04
     +,   1.3375776E-04,   1.3800232E-04,   1.4253728E-04
     +,   1.4739452E-04,   1.5260786E-04,   1.5821276E-04
     +,   1.6424587E-04,   1.7074548E-04,   1.7775063E-04
     +,   1.8530007E-04,   1.9343346E-04,   2.0218831E-04
     +,   2.1160224E-04,   2.2170940E-04,   2.3254278E-04
     +,   2.4413051E-04,   2.5649814E-04,   2.6966509E-04
     +,   2.8364710E-04,   2.9845425E-04,   3.1408994E-04
     +,   3.3055118E-04,   3.4782969E-04,   3.6591114E-04
     +,   3.8477336E-04,   4.0439176E-04,   4.2473545E-04
     +,   4.4577522E-04,   4.6748243E-04,   4.8983935E-04
     +,   5.1284308E-04,   5.3652149E-04,   5.6094292E-04
     +,   5.8624067E-04,   6.1263592E-04,   6.4046698E-04
     +,   6.7022844E-04,   7.0261920E-04,   7.3859195E-04
     +,   7.7940599E-04,   8.2669099E-04,   8.8248285E-04
     +,   9.4926287E-04,   1.0299349E-03,   1.1277768E-03
     +,   1.2462909E-03,   1.3890261E-03,   1.5593023E-03
     +,   1.7600126E-03,   1.9935125E-03,   2.2617474E-03
     +,   2.5667376E-03,   2.9113342E-03,   3.2998798E-03
     +,   3.7382639E-03,   4.2329910E-03,   4.7888360E-03
     +,   5.4062326E-03,   6.0794707E-03,   6.7978981E-03
     +,   7.5501576E-03,   8.3306124E-03,   9.1437120E-03
     +,   1.0002970E-02,   1.0921843E-02,   1.1899060E-02
     +,   1.2906171E-02,   1.3887239E-02,   1.4776537E-02
     +,   1.5529064E-02,   1.6147351E-02,   1.6685698E-02
     +,   1.7227978E-02,   1.7851103E-02,   1.8590406E-02
     +,   1.9413104E-02,   2.0204376E-02,   2.0782070E-02
     +,   2.0957008E-02,   2.0622227E-02,   1.9816389E-02
     +,   1.8709557E-02,   1.7515540E-02,   1.6389400E-02
     +,   1.5377510E-02,   1.4440355E-02,   1.3516409E-02
     +,   1.2575218E-02,   1.1629678E-02,   1.0714990E-02
     +,   9.8626427E-03,   9.0883300E-03,   8.3945077E-03
     +,   7.7775079E-03,   7.2317705E-03,   6.7505487E-03
     +,   6.3257092E-03,   5.9482758E-03,   5.6093638E-03
     +,   5.3004478E-03,   5.0129700E-03,   4.7381725E-03
     +,   4.4677393E-03,   4.1951095E-03,   3.9167386E-03
     +,   3.6327713E-03,   3.3467703E-03,   3.0645896E-03
     +,   2.7929102E-03,   2.5379241E-03,   2.3043917E-03
     +,   2.0951880E-03,   1.9112884E-03,   1.7520718E-03
     +,   1.6157667E-03,   1.4998912E-03,   1.4016505E-03
     +,   1.3182571E-03,   1.2471608E-03,   1.1861486E-03
     +,   1.1334115E-03,   1.0875416E-03,   1.0474926E-03
     +,   1.0125116E-03,   9.8208210E-04,   9.5584767E-04
     +,   9.3356235E-04,   9.1502949E-04,   9.0007676E-04
     +,   8.8852434E-04,   8.8017201E-04,   8.7478972E-04
     +,   8.7211508E-04,   8.7185681E-04,   8.7369396E-04
     +,   8.7728427E-04,   8.8226795E-04,   8.8827196E-04
     +,   8.9491805E-04,   9.0182805E-04,   9.0862886E-04
     +,   9.1496075E-04,   9.2048320E-04,   9.2488155E-04
     +,   9.2787237E-04,   9.2921039E-04,   9.2869496E-04
     +,   9.2617143E-04,   9.2153728E-04,   9.1474201E-04
     +,   9.0578682E-04,   8.9472521E-04,   8.8165852E-04
     +,   8.6672971E-04,   8.5012091E-04,   8.3204219E-04
     +,   8.1272807E-04,   7.9242513E-04,   7.7138463E-04
     +,   7.4985740E-04,   7.2808366E-04,   7.0628751E-04
     +,   6.8467035E-04,   6.6341145E-04,   6.4266054E-04
     +,   6.2253809E-04,   6.0313760E-04,   5.8452424E-04
     +,   5.6673749E-04,   5.4979295E-04,   5.3368817E-04
     +,   5.1840459E-04,   5.0390972E-04,   4.9016165E-04
     +,   4.7711382E-04,   4.6471649E-04,   4.5291788E-04
     +,   4.4166864E-04,   4.3092261E-04,   4.2063752E-04
     +,   4.1077562E-04,   4.0130538E-04,   3.9220019E-04
     +,   3.8343880E-04,   3.7500390E-04,   3.6688373E-04
     +,   3.5906941E-04,   3.5155471E-04,   3.4433519E-04
     +,   3.3740827E-04,   3.3077147E-04,   3.2442209E-04
     +,   3.1835641E-04,   3.1256990E-04,   3.0705589E-04
     +,   3.0180538E-04,   2.9680747E-04,   2.9204891E-04
     +,   2.8751357E-04,   2.8318301E-04,   2.7903687E-04
     +,   2.7505279E-04,   2.7120652E-04,   2.6747241E-04
     +,   2.6382442E-04,   2.6023557E-04,   2.5667934E-04
     +,   2.5312879E-04,   2.4955880E-04,   2.4594498E-04
     +,   2.4226456E-04,   2.3849701E-04,   2.3462428E-04
     +,   2.3063041E-04,   2.2650242E-04,   2.2223027E-04
     +,   2.1780710E-04,   2.1322863E-04,   2.0849385E-04
     +,   2.0360468E-04,   1.9856564E-04,   1.9338424E-04
     +,   1.8806987E-04,   1.8263477E-04,   1.7709227E-04
     +,   1.7145829E-04,   1.6574914E-04,   1.5998310E-04
     +,   1.5417830E-04,   1.4835414E-04,   1.4252961E-04
     +,   1.3672361E-04,   1.3095523E-04,   1.2524221E-04
     +,   1.1960223E-04,   1.1405123E-04,   1.0860489E-04
     +,   1.0327671E-04,   9.8079639E-05,   9.3024493E-05
     +,   8.8121305E-05,   8.3377920E-05,   7.8801335E-05
     +,   7.4396543E-05,   7.0167647E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz80 = Yx/0.167363636363636
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.7857550E-05,   2.8509601E-05
     +,   2.9174971E-05,   2.9853973E-05,   3.0546900E-05
     +,   3.1254029E-05,   3.1975629E-05,   3.2711941E-05
     +,   3.3463166E-05,   3.4229528E-05,   3.5011188E-05
     +,   3.5808276E-05,   3.6620891E-05,   3.7449117E-05
     +,   3.8292979E-05,   3.9152488E-05,   4.0027589E-05
     +,   4.0918207E-05,   4.1824242E-05,   4.2745509E-05
     +,   4.3681834E-05,   4.4632983E-05,   4.5598674E-05
     +,   4.6578654E-05,   4.7572532E-05,   4.8580019E-05
     +,   4.9600723E-05,   5.0634251E-05,   5.1680225E-05
     +,   5.2738240E-05,   5.3807918E-05,   5.4888904E-05
     +,   5.5980832E-05,   5.7083394E-05,   5.8196350E-05
     +,   5.9319478E-05,   6.0452643E-05,   6.1595783E-05
     +,   6.2748986E-05,   6.3912303E-05,   6.5086082E-05
     +,   6.6270673E-05,   6.7466630E-05,   6.8674613E-05
     +,   6.9895505E-05,   7.1130315E-05,   7.2380230E-05
     +,   7.3646668E-05,   7.4931231E-05,   7.6235679E-05
     +,   7.7562036E-05,   7.8912482E-05,   8.0289450E-05
     +,   8.1695609E-05,   8.3133702E-05,   8.4606865E-05
     +,   8.6118329E-05,   8.7671571E-05,   8.9270281E-05
     +,   9.0918402E-05,   9.2620052E-05,   9.4379662E-05
     +,   9.6201817E-05,   9.8091485E-05,   1.0005400E-04
     +,   1.0209482E-04,   1.0422007E-04,   1.0643605E-04
     +,   1.0874987E-04,   1.1116883E-04,   1.1370133E-04
     +,   1.1635607E-04,   1.1914299E-04,   1.2207264E-04
     +,   1.2515690E-04,   1.2840889E-04,   1.3184294E-04
     +,   1.3547491E-04,   1.3932268E-04,   1.4340623E-04
     +,   1.4774731E-04,   1.5237091E-04,   1.5730444E-04
     +,   1.6257928E-04,   1.6822996E-04,   1.7429618E-04
     +,   1.8082181E-04,   1.8785713E-04,   1.9545792E-04
     +,   2.0368764E-04,   2.1261780E-04,   2.2232777E-04
     +,   2.3290665E-04,   2.4445396E-04,   2.5708057E-04
     +,   2.7090762E-04,   2.8606961E-04,   3.0271112E-04
     +,   3.2099095E-04,   3.4107646E-04,   3.6314785E-04
     +,   3.8739093E-04,   4.1400018E-04,   4.4317017E-04
     +,   4.7509736E-04,   5.0997525E-04,   5.4799044E-04
     +,   5.8932393E-04,   6.3415972E-04,   6.8269519E-04
     +,   7.3515502E-04,   7.9183263E-04,   8.5311913E-04
     +,   9.1957243E-04,   9.9197135E-04,   1.0714228E-03
     +,   1.1594524E-03,   1.2581587E-03,   1.3703315E-03
     +,   1.4995832E-03,   1.6503528E-03,   1.8277150E-03
     +,   2.0369233E-03,   2.2826791E-03,   2.5681893E-03
     +,   2.8943287E-03,   3.2594304E-03,   3.6598896E-03
     +,   4.0920153E-03,   4.5544971E-03,   5.0510503E-03
     +,   5.5917129E-03,   6.1923200E-03,   6.8710931E-03
     +,   7.6433253E-03,   8.5148187E-03,   9.4765984E-03
     +,   1.0503942E-02,   1.1562536E-02,   1.2621636E-02
     +,   1.3669436E-02,   1.4720879E-02,   1.5808525E-02
     +,   1.6957441E-02,   1.8158900E-02,   1.9363992E-02
     +,   2.0504942E-02,   2.1531057E-02,   2.2432508E-02
     +,   2.3230635E-02,   2.3935677E-02,   2.4498172E-02
     +,   2.4796020E-02,   2.4685152E-02,   2.4089899E-02
     +,   2.3066407E-02,   2.1783134E-02,   2.0433446E-02
     +,   1.9148756E-02,   1.7965408E-02,   1.6847609E-02
     +,   1.5733767E-02,   1.4574777E-02,   1.3351657E-02
     +,   1.2076000E-02,   1.0780347E-02,   9.5057366E-03
     +,   8.2912687E-03,   7.1685128E-03,   6.1598527E-03
     +,   5.2782372E-03,   4.5270803E-03,   3.9012537E-03
     +,   3.3897273E-03,   2.9791738E-03,   2.6568044E-03
     +,   2.4117364E-03,   2.2347549E-03,   2.1173167E-03
     +,   2.0507472E-03,   2.0259651E-03,   2.0337270E-03
     +,   2.0650849E-03,   2.1118694E-03,   2.1669921E-03
     +,   2.2246151E-03,   2.2801491E-03,   2.3301737E-03
     +,   2.3723149E-03,   2.4050749E-03,   2.4276755E-03
     +,   2.4398894E-03,   2.4418756E-03,   2.4340535E-03
     +,   2.4169888E-03,   2.3913123E-03,   2.3576776E-03
     +,   2.3167492E-03,   2.2691984E-03,   2.2157347E-03
     +,   2.1571217E-03,   2.0942104E-03,   2.0279249E-03
     +,   1.9592738E-03,   1.8893258E-03,   1.8191665E-03
     +,   1.7498607E-03,   1.6824102E-03,   1.6177034E-03
     +,   1.5564713E-03,   1.4992688E-03,   1.4464557E-03
     +,   1.3981949E-03,   1.3544537E-03,   1.3150321E-03
     +,   1.2795937E-03,   1.2476956E-03,   1.2188276E-03
     +,   1.1924512E-03,   1.1680365E-03,   1.1450889E-03
     +,   1.1231747E-03,   1.1019410E-03,   1.0811195E-03
     +,   1.0605323E-03,   1.0400823E-03,   1.0197491E-03
     +,   9.9957047E-04,   9.7962609E-04,   9.6002198E-04
     +,   9.4087352E-04,   9.2229055E-04,   9.0436451E-04
     +,   8.8715926E-04,   8.7070727E-04,   8.5500610E-04
     +,   8.4001903E-04,   8.2567951E-04,   8.1189704E-04
     +,   7.9856097E-04,   7.8555034E-04,   7.7274122E-04
     +,   7.6001446E-04,   7.4725819E-04,   7.3437690E-04
     +,   7.2129321E-04,   7.0795108E-04,   6.9431541E-04
     +,   6.8037258E-04,   6.6613068E-04,   6.5161486E-04
     +,   6.3686457E-04,   6.2193320E-04,   6.0688250E-04
     +,   5.9177884E-04,   5.7668966E-04,   5.6168367E-04
     +,   5.4682518E-04,   5.3217146E-04,   5.1777327E-04
     +,   5.0367269E-04,   4.8990286E-04,   4.7648608E-04
     +,   4.6343484E-04,   4.5075410E-04,   4.3843858E-04
     +,   4.2647598E-04,   4.1484775E-04,   4.0353046E-04
     +,   3.9249554E-04,   3.8171207E-04,   3.7114814E-04
     +,   3.6077155E-04,   3.5054953E-04,   3.4045181E-04
     +,   3.3045080E-04,   3.2052089E-04,   3.1064142E-04
     +,   3.0079426E-04,   2.9096680E-04,   2.8114926E-04
     +,   2.7133766E-04,   2.6153080E-04,   2.5173265E-04
     +,   2.4194966E-04,   2.3219275E-04,   2.2247480E-04
     +,   2.1281137E-04,   2.0322078E-04,   1.9372175E-04
     +,   1.8433527E-04,   1.7508169E-04,   1.6598294E-04
     +,   1.5705929E-04,   1.4833176E-04,   1.3981917E-04
     +,   1.3154019E-04,   1.2351091E-04,   1.1574676E-04
     +,   1.0826024E-04,   1.0106277E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz85 = Yx/0.191068181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.6314647E-05,   2.7089418E-05
     +,   2.7869339E-05,   2.8653534E-05,   2.9441113E-05
     +,   3.0231149E-05,   3.1022708E-05,   3.1814812E-05
     +,   3.2606491E-05,   3.3396762E-05,   3.4184632E-05
     +,   3.4969078E-05,   3.5749101E-05,   3.6523699E-05
     +,   3.7291862E-05,   3.8052611E-05,   3.8804952E-05
     +,   3.9547926E-05,   4.0280607E-05,   4.1002062E-05
     +,   4.1711421E-05,   4.2407817E-05,   4.3090440E-05
     +,   4.3758544E-05,   4.4411372E-05,   4.5048284E-05
     +,   4.5668654E-05,   4.6271933E-05,   4.6857651E-05
     +,   4.7425365E-05,   4.7974769E-05,   4.8505608E-05
     +,   4.9017715E-05,   4.9511022E-05,   4.9985563E-05
     +,   5.0441464E-05,   5.0878978E-05,   5.1298455E-05
     +,   5.1700426E-05,   5.2085452E-05,   5.2454310E-05
     +,   5.2807918E-05,   5.3147291E-05,   5.3473643E-05
     +,   5.3788317E-05,   5.4092885E-05,   5.4389013E-05
     +,   5.4678600E-05,   5.4963712E-05,   5.5246597E-05
     +,   5.5529727E-05,   5.5815737E-05,   5.6107463E-05
     +,   5.6407989E-05,   5.6720535E-05,   5.7048575E-05
     +,   5.7395784E-05,   5.7766014E-05,   5.8163350E-05
     +,   5.8592046E-05,   5.9056572E-05,   5.9561600E-05
     +,   6.0111968E-05,   6.0712700E-05,   6.1369064E-05
     +,   6.2086379E-05,   6.2870306E-05,   6.3726497E-05
     +,   6.4660948E-05,   6.5679698E-05,   6.6789042E-05
     +,   6.7995315E-05,   6.9305192E-05,   7.0725349E-05
     +,   7.2262716E-05,   7.3924391E-05,   7.5717595E-05
     +,   7.7649558E-05,   7.9727812E-05,   8.1960017E-05
     +,   8.4353669E-05,   8.6916625E-05,   8.9656402E-05
     +,   9.2580864E-05,   9.5697389E-05,   9.9013727E-05
     +,   1.0253692E-04,   1.0627445E-04,   1.1023307E-04
     +,   1.1441985E-04,   1.1884182E-04,   1.2350589E-04
     +,   1.2841936E-04,   1.3359060E-04,   1.3902932E-04
     +,   1.4474674E-04,   1.5075777E-04,   1.5708075E-04
     +,   1.6374061E-04,   1.7076898E-04,   1.7820836E-04
     +,   1.8611281E-04,   1.9455282E-04,   2.0361689E-04
     +,   2.1341618E-04,   2.2408785E-04,   2.3579702E-04
     +,   2.4874008E-04,   2.6314717E-04,   2.7928143E-04
     +,   2.9743640E-04,   3.1793508E-04,   3.4111962E-04
     +,   3.6734692E-04,   3.9697142E-04,   4.3033683E-04
     +,   4.6775179E-04,   5.0948089E-04,   5.5571477E-04
     +,   6.0656242E-04,   6.6203030E-04,   7.2200492E-04
     +,   7.8624813E-04,   8.5440016E-04,   9.2598266E-04
     +,   1.0004102E-03,   1.0770381E-03,   1.1551903E-03
     +,   1.2342450E-03,   1.3137005E-03,   1.3933060E-03
     +,   1.4731700E-03,   1.5539243E-03,   1.6368509E-03
     +,   1.7240153E-03,   1.8183225E-03,   1.9234635E-03
     +,   2.0437227E-03,   2.1836008E-03,   2.3472409E-03
     +,   2.5377271E-03,   2.7564180E-03,   3.0025414E-03
     +,   3.2732754E-03,   3.5645352E-03,   3.8726295E-03
     +,   4.1964552E-03,   4.5398590E-03,   4.9136495E-03
     +,   5.3366772E-03,   5.8356137E-03,   6.4428779E-03
     +,   7.1922196E-03,   8.1114341E-03,   9.2131775E-03
     +,   1.0487583E-02,   1.1901662E-02,   1.3406762E-02
     +,   1.4948328E-02,   1.6470097E-02,   1.7910603E-02
     +,   1.9197663E-02,   2.0250414E-02,   2.0992229E-02
     +,   2.1368703E-02,   2.1359937E-02,   2.0978680E-02
     +,   2.0257151E-02,   1.9236097E-02,   1.7967764E-02
     +,   1.6527116E-02,   1.5014407E-02,   1.3543507E-02
     +,   1.2222878E-02,   1.1138752E-02,   1.0343144E-02
     +,   9.8477947E-03,   9.6259909E-03,   9.6237250E-03
     +,   9.7757634E-03,   1.0018634E-02,   1.0295333E-02
     +,   1.0554303E-02,   1.0748981E-02,   1.0842638E-02
     +,   1.0817008E-02,   1.0678077E-02,   1.0453482E-02
     +,   1.0181212E-02,   9.8955417E-03,   9.6176062E-03
     +,   9.3542766E-03,   9.1033326E-03,   8.8595068E-03
     +,   8.6171906E-03,   8.3697401E-03,   8.1078177E-03
     +,   7.8195687E-03,   7.4935346E-03,   7.1228682E-03
     +,   6.7085815E-03,   6.2601417E-03,   5.7934648E-03
     +,   5.3273705E-03,   4.8799133E-03,   4.4655227E-03
     +,   4.0936582E-03,   3.7686774E-03,   3.4905560E-03
     +,   3.2559987E-03,   3.0596717E-03,   2.8952737E-03
     +,   2.7563602E-03,   2.6369374E-03,   2.5318416E-03
     +,   2.4369482E-03,   2.3491746E-03,   2.2663886E-03
     +,   2.1872434E-03,   2.1109872E-03,   2.0372386E-03
     +,   1.9658422E-03,   1.8967561E-03,   1.8299763E-03
     +,   1.7655093E-03,   1.7033675E-03,   1.6435740E-03
     +,   1.5861647E-03,   1.5311752E-03,   1.4786370E-03
     +,   1.4285634E-03,   1.3809331E-03,   1.3356756E-03
     +,   1.2926735E-03,   1.2517696E-03,   1.2127688E-03
     +,   1.1754624E-03,   1.1396442E-03,   1.1051234E-03
     +,   1.0717388E-03,   1.0393660E-03,   1.0079236E-03
     +,   9.7736856E-04,   9.4768486E-04,   9.1887923E-04
     +,   8.9096907E-04,   8.6397136E-04,   8.3788927E-04
     +,   8.1270927E-04,   7.8839605E-04,   7.6488883E-04
     +,   7.4210326E-04,   7.1993819E-04,   6.9827936E-04
     +,   6.7700323E-04,   6.5598864E-04,   6.3512230E-04
     +,   6.1430567E-04,   5.9345696E-04,   5.7251687E-04
     +,   5.5145286E-04,   5.3025648E-04,   5.0894264E-04
     +,   4.8754847E-04,   4.6613187E-04,   4.4476474E-04
     +,   4.2352983E-04,   4.0251896E-04,   3.8182622E-04
     +,   3.6154443E-04,   3.4176148E-04,   3.2255970E-04
     +,   3.0401212E-04,   2.8617945E-04,   2.6911020E-04
     +,   2.5284238E-04,   2.3739913E-04,   2.2279372E-04
     +,   2.0902618E-04,   1.9608841E-04,   1.8396169E-04
     +,   1.7262169E-04,   1.6203626E-04,   1.5217016E-04
     +,   1.4298366E-04,   1.3443595E-04,   1.2648461E-04
     +,   1.1908694E-04,   1.1220195E-04,   1.0578900E-04
     +,   9.9810124E-05,   9.4228853E-05,   8.9011875E-05
     +,   8.4127758E-05,   7.9548372E-05,   7.5247532E-05
     +,   7.1202121E-05,   6.7390851E-05,   6.3795138E-05
     +,   6.0397993E-05,   5.7184654E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz90 = Yx/0.191068181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3498448E-05,   1.3681659E-05
     +,   1.3863741E-05,   1.4044701E-05,   1.4224564E-05
     +,   1.4403359E-05,   1.4581125E-05,   1.4757903E-05
     +,   1.4933750E-05,   1.5108735E-05,   1.5282923E-05
     +,   1.5456391E-05,   1.5629228E-05,   1.5801528E-05
     +,   1.5973386E-05,   1.6144906E-05,   1.6316204E-05
     +,   1.6487393E-05,   1.6658587E-05,   1.6829923E-05
     +,   1.7001517E-05,   1.7173508E-05,   1.7346021E-05
     +,   1.7519202E-05,   1.7693179E-05,   1.7868091E-05
     +,   1.8044075E-05,   1.8221272E-05,   1.8399824E-05
     +,   1.8579860E-05,   1.8761528E-05,   1.8944969E-05
     +,   1.9130324E-05,   1.9317738E-05,   1.9507364E-05
     +,   1.9699357E-05,   1.9893880E-05,   2.0091111E-05
     +,   2.0291243E-05,   2.0494477E-05,   2.0701060E-05
     +,   2.0911244E-05,   2.1125335E-05,   2.1343674E-05
     +,   2.1566657E-05,   2.1794749E-05,   2.2028486E-05
     +,   2.2268494E-05,   2.2515507E-05,   2.2770375E-05
     +,   2.3034097E-05,   2.3307828E-05,   2.3592902E-05
     +,   2.3890885E-05,   2.4203542E-05,   2.4532945E-05
     +,   2.4881438E-05,   2.5251687E-05,   2.5646748E-05
     +,   2.6070047E-05,   2.6525457E-05,   2.7017322E-05
     +,   2.7550463E-05,   2.8130264E-05,   2.8762694E-05
     +,   2.9454241E-05,   3.0212104E-05,   3.1044030E-05
     +,   3.1958505E-05,   3.2964563E-05,   3.4071989E-05
     +,   3.5291087E-05,   3.6632897E-05,   3.8108858E-05
     +,   3.9731058E-05,   4.1512048E-05,   4.3464635E-05
     +,   4.5601872E-05,   4.7937116E-05,   5.0483817E-05
     +,   5.3255088E-05,   5.6264176E-05,   5.9523554E-05
     +,   6.3045656E-05,   6.6841800E-05,   7.0922972E-05
     +,   7.5298725E-05,   7.9978112E-05,   8.4968437E-05
     +,   9.0276211E-05,   9.5906740E-05,   1.0186363E-04
     +,   1.0814914E-04,   1.1476467E-04,   1.2171062E-04
     +,   1.2898551E-04,   1.3658809E-04,   1.4451549E-04
     +,   1.5276554E-04,   1.6133476E-04,   1.7022119E-04
     +,   1.7942234E-04,   1.8893763E-04,   1.9876676E-04
     +,   2.0891202E-04,   2.1937734E-04,   2.3016855E-04
     +,   2.4129353E-04,   2.5276368E-04,   2.6459264E-04
     +,   2.7679568E-04,   2.8939158E-04,   3.0239957E-04
     +,   3.1584181E-04,   3.2973976E-04,   3.4411647E-04
     +,   3.5899301E-04,   3.7439106E-04,   3.9032922E-04
     +,   4.0682591E-04,   4.2389860E-04,   4.4156410E-04
     +,   4.5984119E-04,   4.7875463E-04,   4.9833889E-04
     +,   5.1863963E-04,   5.3972617E-04,   5.6168949E-04
     +,   5.8465684E-04,   6.0879026E-04,   6.3429517E-04
     +,   6.6141912E-04,   6.9045508E-04,   7.2172901E-04
     +,   7.5559883E-04,   7.9243741E-04,   8.3261402E-04
     +,   8.7647612E-04,   9.2433422E-04,   9.7643805E-04
     +,   1.0329554E-03,   1.0939585E-03,   1.1594224E-03
     +,   1.2292070E-03,   1.3030499E-03,   1.3805743E-03
     +,   1.4612810E-03,   1.5445368E-03,   1.6295755E-03
     +,   1.7154972E-03,   1.8012648E-03,   1.8856982E-03
     +,   1.9675111E-03,   2.0453501E-03,   2.1178622E-03
     +,   2.1837950E-03,   2.2421298E-03,   2.2922484E-03
     +,   2.3340927E-03,   2.3683181E-03,   2.3964134E-03
     +,   2.4207169E-03,   2.4443318E-03,   2.4708854E-03
     +,   2.5041790E-03,   2.5477272E-03,   2.6042920E-03
     +,   2.6755298E-03,   2.7618485E-03,   2.8625657E-03
     +,   2.9763936E-03,   3.1022220E-03,   3.2401602E-03
     +,   3.3927090E-03,   3.5659585E-03,   3.7705668E-03
     +,   4.0218933E-03,   4.3384517E-03,   4.7381171E-03
     +,   5.2325637E-03,   5.8219088E-03,   6.4929058E-03
     +,   7.2237845E-03,   7.9969671E-03,   8.8173142E-03
     +,   9.7284429E-03,   1.0812203E-02,   1.2157592E-02
     +,   1.3803831E-02,   1.5691966E-02,   1.7664818E-02
     +,   1.9517910E-02,   2.1068135E-02,   2.2209249E-02
     +,   2.2936409E-02,   2.3320055E-02,   2.3433652E-02
     +,   2.3302861E-02,   2.2931391E-02,   2.2355419E-02
     +,   2.1641698E-02,   2.0837175E-02,   1.9942021E-02
     +,   1.8930852E-02,   1.7790370E-02,   1.6544679E-02
     +,   1.5256210E-02,   1.3999186E-02,   1.2821804E-02
     +,   1.1729937E-02,   1.0705487E-02,   9.7364020E-03
     +,   8.8285701E-03,   7.9961084E-03,   7.2477222E-03
     +,   6.5829111E-03,   5.9963986E-03,   5.4823062E-03
     +,   5.0342637E-03,   4.6436461E-03,   4.2992374E-03
     +,   3.9891959E-03,   3.7036557E-03,   3.4362215E-03
     +,   3.1839516E-03,   2.9463267E-03,   2.7239660E-03
     +,   2.5176350E-03,   2.3277318E-03,   2.1541954E-03
     +,   1.9966066E-03,   1.8543371E-03,   1.7266605E-03
     +,   1.6128506E-03,   1.5122151E-03,   1.4240680E-03
     +,   1.3477172E-03,   1.2824276E-03,   1.2273755E-03
     +,   1.1816142E-03,   1.1440647E-03,   1.1135240E-03
     +,   1.0886893E-03,   1.0682025E-03,   1.0507089E-03
     +,   1.0349130E-03,   1.0196342E-03,   1.0038465E-03
     +,   9.8671333E-04,   9.6760399E-04,   9.4609585E-04
     +,   9.2196779E-04,   8.9518609E-04,   8.6588005E-04
     +,   8.3430961E-04,   8.0084056E-04,   7.6591218E-04
     +,   7.3000719E-04,   6.9361966E-04,   6.5723393E-04
     +,   6.2130456E-04,   5.8623834E-04,   5.5238011E-04
     +,   5.2000710E-04,   4.8933015E-04,   4.6048700E-04
     +,   4.3355103E-04,   4.0853902E-04,   3.8541667E-04
     +,   3.6410740E-04,   3.4450309E-04,   3.2647487E-04
     +,   3.0987980E-04,   2.9456778E-04,   2.8038913E-04
     +,   2.6720102E-04,   2.5486792E-04,   2.4326783E-04
     +,   2.3229115E-04,   2.2184360E-04,   2.1184425E-04
     +,   2.0222705E-04,   1.9293776E-04,   1.8393516E-04
     +,   1.7518690E-04,   1.6667096E-04,   1.5837212E-04
     +,   1.5028114E-04,   1.4239473E-04,   1.3471241E-04
     +,   1.2723744E-04,   1.1997410E-04,   1.1292897E-04
     +,   1.0610813E-04,   9.9518831E-05,   9.3166978E-05
     +,   8.7058768E-05,   8.1198596E-05,   7.5590702E-05
     +,   7.0237264E-05,   6.5140033E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ttz95 = Yx/0.176590909090909
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7538729E-05,   1.8374709E-05
     +,   1.9225541E-05,   2.0089681E-05,   2.0965481E-05
     +,   2.1851181E-05,   2.2744916E-05,   2.3644716E-05
     +,   2.4548510E-05,   2.5454183E-05,   2.6359503E-05
     +,   2.7262184E-05,   2.8159891E-05,   2.9050232E-05
     +,   2.9930801E-05,   3.0799158E-05,   3.1652857E-05
     +,   3.2489465E-05,   3.3306562E-05,   3.4101766E-05
     +,   3.4872737E-05,   3.5617195E-05,   3.6332931E-05
     +,   3.7017857E-05,   3.7669921E-05,   3.8287242E-05
     +,   3.8868031E-05,   3.9410646E-05,   3.9913582E-05
     +,   4.0375497E-05,   4.0795203E-05,   4.1171694E-05
     +,   4.1504118E-05,   4.1791827E-05,   4.2034353E-05
     +,   4.2231397E-05,   4.2382875E-05,   4.2488864E-05
     +,   4.2549651E-05,   4.2565684E-05,   4.2537613E-05
     +,   4.2466250E-05,   4.2352574E-05,   4.2197735E-05
     +,   4.2003030E-05,   4.1769890E-05,   4.1499905E-05
     +,   4.1194762E-05,   4.0856277E-05,   4.0486357E-05
     +,   4.0086998E-05,   3.9660266E-05,   3.9208320E-05
     +,   3.8733298E-05,   3.8237464E-05,   3.7723021E-05
     +,   3.7192240E-05,   3.6647369E-05,   3.6090638E-05
     +,   3.5524263E-05,   3.4950412E-05,   3.4371216E-05
     +,   3.3788769E-05,   3.3205062E-05,   3.2622011E-05
     +,   3.2041517E-05,   3.1465301E-05,   3.0895084E-05
     +,   3.0332414E-05,   2.9778806E-05,   2.9235605E-05
     +,   2.8704118E-05,   2.8185466E-05,   2.7680753E-05
     +,   2.7190907E-05,   2.6716747E-05,   2.6259027E-05
     +,   2.5818397E-05,   2.5395357E-05,   2.4990330E-05
     +,   2.4603662E-05,   2.4235576E-05,   2.3886234E-05
     +,   2.3555674E-05,   2.3243900E-05,   2.2950793E-05
     +,   2.2676197E-05,   2.2419854E-05,   2.2181470E-05
     +,   2.1960681E-05,   2.1757052E-05,   2.1570115E-05
     +,   2.1399361E-05,   2.1244217E-05,   2.1104077E-05
     +,   2.0978308E-05,   2.0866235E-05,   2.0767158E-05
     +,   2.0680352E-05,   2.0605074E-05,   2.0540552E-05
     +,   2.0486003E-05,   2.0440631E-05,   2.0403630E-05
     +,   2.0374180E-05,   2.0351457E-05,   2.0334639E-05
     +,   2.0322896E-05,   2.0315398E-05,   2.0311323E-05
     +,   2.0309848E-05,   2.0310170E-05,   2.0311481E-05
     +,   2.0313002E-05,   2.0313952E-05,   2.0313591E-05
     +,   2.0311190E-05,   2.0306059E-05,   2.0297543E-05
     +,   2.0285033E-05,   2.0267982E-05,   2.0245914E-05
     +,   2.0218438E-05,   2.0185280E-05,   2.0146306E-05
     +,   2.0101557E-05,   2.0051282E-05,   1.9996000E-05
     +,   1.9936550E-05,   1.9874171E-05,   1.9810546E-05
     +,   1.9747944E-05,   1.9689245E-05,   1.9638113E-05
     +,   1.9599029E-05,   1.9577432E-05,   1.9579804E-05
     +,   1.9613750E-05,   1.9688041E-05,   1.9812689E-05
     +,   1.9998904E-05,   2.0259089E-05,   2.0606771E-05
     +,   2.1056496E-05,   2.1623626E-05,   2.2324251E-05
     +,   2.3174978E-05,   2.4192665E-05,   2.5394280E-05
     +,   2.6796866E-05,   2.8417409E-05,   3.0272753E-05
     +,   3.2379754E-05,   3.4755703E-05,   3.7418584E-05
     +,   4.0387353E-05,   4.3682616E-05,   4.7327503E-05
     +,   5.1348092E-05,   5.5773387E-05,   6.0636274E-05
     +,   6.5972927E-05,   7.1821596E-05,   7.8221216E-05
     +,   8.5209751E-05,   9.2820774E-05,   1.0108000E-04
     +,   1.1000285E-04,   1.1959393E-04,   1.2984831E-04
     +,   1.4075691E-04,   1.5231939E-04,   1.6456477E-04
     +,   1.7757926E-04,   1.9154050E-04,   2.0676164E-04
     +,   2.2373321E-04,   2.4315937E-04,   2.6598299E-04
     +,   2.9338943E-04,   3.2677644E-04,   3.6768476E-04
     +,   4.1769107E-04,   4.7826723E-04,   5.5060524E-04
     +,   6.3542760E-04,   7.3281460E-04,   8.4207399E-04
     +,   9.6165150E-04,   1.0891120E-03,   1.2212379E-03
     +,   1.3541771E-03,   1.4836597E-03,   1.6052742E-03
     +,   1.7147632E-03,   1.8082806E-03,   1.8826127E-03
     +,   1.9353569E-03,   1.9650194E-03,   1.9710392E-03
     +,   1.9537567E-03,   1.9143417E-03,   1.8546684E-03
     +,   1.7771778E-03,   1.6847384E-03,   1.5804708E-03
     +,   1.4676017E-03,   1.3493263E-03,   1.2286748E-03
     +,   1.1083937E-03,   9.9087530E-04,   8.7811332E-04
     +,   7.7167311E-04,   6.7268993E-04,   5.8190251E-04
     +,   4.9970171E-04,   4.2617161E-04,   3.6114006E-04
     +,   3.0423718E-04,   2.5494955E-04,   2.1265441E-04
     +,   1.7666658E-04,   1.4627626E-04,   1.2077625E-04
     +,   9.9486380E-05,   8.1775426E-05,   6.7075496E-05
     +,   5.4887918E-05,   4.4785011E-05,   3.6408463E-05
     +,   2.9463510E-05,   2.3709843E-05,   1.8952143E-05
     +,   1.5031508E-05,   1.1817581E-05,   9.2010341E-06
     +,   7.0889314E-06,   5.4011030E-06,   4.0674940E-06
     +,   3.0266290E-06,   2.2248128E-06,   1.6155892E-06
     +,   1.1592089E-06,   8.2219486E-07,   5.7689141E-07
     +,   4.0089469E-07,   2.7639101E-07,   1.8949824E-07
     +,   1.2962138E-07,   8.8837460E-08,   6.1327960E-08
     +,   4.2906649E-08,   3.0618480E-08,   2.2414190E-08
     +,   1.6897753E-08,   1.3134772E-08,   1.0509996E-08
     +,   8.6240268E-09,   7.2208990E-09,   6.1383538E-09
     +,   5.2742242E-09,   4.5641690E-09,   3.9673416E-09
     +,   3.4573713E-09,   3.0167768E-09,   2.6333962E-09
     +,   2.2983802E-09,   2.0049853E-09,   1.7477960E-09
     +,   1.5223075E-09,   1.3246735E-09,   1.1515757E-09
     +,   1.0000998E-09,   8.6766666E-10,   7.5199602E-10
     +,   6.5107825E-10,   5.6311911E-10,   4.8654186E-10
     +,   4.1994211E-10,   3.6208572E-10,   3.1187541E-10
     +,   2.6835120E-10,   2.3066113E-10,   1.9806069E-10
     +,   1.6989078E-10,   1.4557736E-10,   1.2461446E-10
     +,   1.0655921E-10,   9.1026124E-11,   7.7676476E-11
     +,   6.6216393E-11,   5.6388307E-11,   4.7969583E-11
     +,   4.0765238E-11,   3.4607300E-11,   2.9348923E-11
     +,   2.4863943E-11,   2.1042420E-11,   1.7789914E-11
     +,   1.5024499E-11,   1.2675907E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz100 = Yx/0.0126
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4658771E-07,   3.8788414E-07
     +,   4.3341640E-07,   4.8353019E-07,   5.3858867E-07
     +,   5.9897252E-07,   6.6507823E-07,   7.3731957E-07
     +,   8.1612274E-07,   9.0193265E-07,   9.9520264E-07
     +,   1.0963986E-06,   1.2059950E-06,   1.3244747E-06
     +,   1.4523241E-06,   1.5900331E-06,   1.7380901E-06
     +,   1.8969816E-06,   2.0671855E-06,   2.2491720E-06
     +,   2.4433950E-06,   2.6502930E-06,   2.8702777E-06
     +,   3.1037521E-06,   3.3510607E-06,   3.6125443E-06
     +,   3.8884855E-06,   4.1791322E-06,   4.4846852E-06
     +,   4.8052934E-06,   5.1410534E-06,   5.4920019E-06
     +,   5.8581177E-06,   6.2393101E-06,   6.6354269E-06
     +,   7.0462443E-06,   7.4714658E-06,   7.9107213E-06
     +,   8.3635905E-06,   8.8295328E-06,   9.3079843E-06
     +,   9.7982802E-06,   1.0299696E-05,   1.0811434E-05
     +,   1.1332638E-05,   1.1862384E-05,   1.2399697E-05
     +,   1.2943546E-05,   1.3492854E-05,   1.4046504E-05
     +,   1.4603338E-05,   1.5162181E-05,   1.5721813E-05
     +,   1.6281048E-05,   1.6838625E-05,   1.7393344E-05
     +,   1.7943979E-05,   1.8489331E-05,   1.9028217E-05
     +,   1.9559488E-05,   2.0082029E-05,   2.0594773E-05
     +,   2.1096674E-05,   2.1586771E-05,   2.2064165E-05
     +,   2.2527967E-05,   2.2977418E-05,   2.3411754E-05
     +,   2.3830349E-05,   2.4232582E-05,   2.4617953E-05
     +,   2.4985975E-05,   2.5336285E-05,   2.5668516E-05
     +,   2.5982419E-05,   2.6277779E-05,   2.6554419E-05
     +,   2.6812206E-05,   2.7051081E-05,   2.7270997E-05
     +,   2.7471930E-05,   2.7653905E-05,   2.7816943E-05
     +,   2.7961099E-05,   2.8086417E-05,   2.8192968E-05
     +,   2.8280796E-05,   2.8349963E-05,   2.8400513E-05
     +,   2.8432485E-05,   2.8445897E-05,   2.8440763E-05
     +,   2.8417080E-05,   2.8374827E-05,   2.8313976E-05
     +,   2.8234483E-05,   2.8136295E-05,   2.8019365E-05
     +,   2.7883621E-05,   2.7729020E-05,   2.7555503E-05
     +,   2.7363038E-05,   2.7151591E-05,   2.6921180E-05
     +,   2.6671825E-05,   2.6403588E-05,   2.6116564E-05
     +,   2.5810923E-05,   2.5486841E-05,   2.5144558E-05
     +,   2.4784404E-05,   2.4406716E-05,   2.4011957E-05
     +,   2.3600591E-05,   2.3173208E-05,   2.2730412E-05
     +,   2.2272930E-05,   2.1801494E-05,   2.1316966E-05
     +,   2.0820215E-05,   2.0312180E-05,   1.9793877E-05
     +,   1.9266376E-05,   1.8730758E-05,   1.8188141E-05
     +,   1.7639724E-05,   1.7086670E-05,   1.6530221E-05
     +,   1.5971566E-05,   1.5411970E-05,   1.4852611E-05
     +,   1.4294743E-05,   1.3739517E-05,   1.3188141E-05
     +,   1.2641728E-05,   1.2101356E-05,   1.1568101E-05
     +,   1.1042976E-05,   1.0526911E-05,   1.0020776E-05
     +,   9.5254154E-06,   9.0415997E-06,   8.5699985E-06
     +,   8.1112203E-06,   7.6658362E-06,   7.2343041E-06
     +,   6.8170098E-06,   6.4142914E-06,   6.0264197E-06
     +,   5.6535664E-06,   5.2958344E-06,   4.9532900E-06
     +,   4.6259324E-06,   4.3136797E-06,   4.0163955E-06
     +,   3.7339130E-06,   3.4660136E-06,   3.2124183E-06
     +,   2.9728074E-06,   2.7468504E-06,   2.5341626E-06
     +,   2.3343316E-06,   2.1469352E-06,   1.9715337E-06
     +,   1.8076566E-06,   1.6548314E-06,   1.5125912E-06
     +,   1.3804871E-06,   1.2581098E-06,   1.1451775E-06
     +,   1.0417041E-06,   9.4832905E-07,   8.6699123E-07
     +,   8.0223458E-07,   7.6356565E-07,   7.6948368E-07
     +,   8.5405208E-07,   1.0768971E-06,   1.5374624E-06
     +,   2.3939795E-06,   3.8866992E-06,   6.3637549E-06
     +,   1.0307504E-05,   1.6359267E-05,   2.5340863E-05
     +,   3.8274076E-05,   5.6404031E-05,   8.1232931E-05
     +,   1.1456045E-04,   1.5851414E-04,   2.1555088E-04
     +,   2.8836034E-04,   3.7962137E-04,   4.9159845E-04
     +,   6.2561192E-04,   7.8146794E-04,   9.5701247E-04
     +,   1.1480103E-03,   1.3484370E-03,   1.5511357E-03
     +,   1.7487024E-03,   1.9343731E-03,   2.1025953E-03
     +,   2.2490658E-03,   2.3702525E-03,   2.4626595E-03
     +,   2.5221710E-03,   2.5439798E-03,   2.5233703E-03
     +,   2.4572122E-03,   2.3456672E-03,   2.1933771E-03
     +,   2.0095126E-03,   1.8065056E-03,   1.5978860E-03
     +,   1.3959474E-03,   1.2099459E-03,   1.0453071E-03
     +,   9.0386911E-04,   7.8477472E-04,   6.8552303E-04
     +,   6.0291274E-04,   5.3365494E-04,   4.7469276E-04
     +,   4.2334918E-04,   3.7741230E-04,   3.3519324E-04
     +,   2.9555615E-04,   2.5790141E-04,   2.2209284E-04
     +,   1.8833268E-04,   1.5700475E-04,   1.2852566E-04
     +,   1.0323335E-04,   8.1320322E-05,   6.2805084E-05
     +,   4.7546706E-05,   3.5279172E-05,   2.5652951E-05
     +,   1.8277349E-05,   1.2757722E-05,   8.7226008E-06
     +,   5.8405822E-06,   3.8292492E-06,   2.4576905E-06
     +,   1.5439045E-06,   9.4912184E-07,   5.7089039E-07
     +,   3.3592164E-07,   1.9334448E-07,   1.0883572E-07
     +,   5.9909823E-08,   3.2245826E-08,   1.6969379E-08
     +,   8.7302912E-09,   4.3905581E-09,   2.1583402E-09
     +,   1.0371038E-09,   4.8709281E-10,   2.2361515E-10
     +,   1.0036323E-10,   4.4057116E-11,   1.8931402E-11
     +,   7.9766497E-12,   3.3074943E-12,   1.3592612E-12
     +,   5.6135326E-13,   2.3885814E-13,   1.0879419E-13
     +,   5.5331973E-14,   3.2122823E-14,   2.0975041E-14
     +,   1.4837554E-14,   1.0974139E-14,   8.2925212E-15
     +,   6.3233089E-15,   4.8366924E-15,   3.7011096E-15
     +,   2.8299608E-15,   2.1611546E-15,   1.6479795E-15
     +,   1.2547334E-15,   9.5381204E-16,   7.2391999E-16
     +,   5.4855712E-16,   4.1501629E-16,   3.1348520E-16
     +,   2.3641349E-16,   1.7800784E-16,   1.3381669E-16
     +,   1.0043683E-16,   7.5262583E-17,   5.6308983E-17
     +,   4.2061006E-17,   3.1368522E-17,   2.3356629E-17
     +,   1.7363628E-17,   1.2887638E-17,   9.5503147E-18
     +,   7.0658818E-18,   5.2194729E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz104 = Yx/0.0126
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.4786832E-05,   1.4909556E-05
     +,   1.5034406E-05,   1.5161530E-05,   1.5291072E-05
     +,   1.5423175E-05,   1.5557969E-05,   1.5695587E-05
     +,   1.5836136E-05,   1.5979740E-05,   1.6126496E-05
     +,   1.6276492E-05,   1.6429816E-05,   1.6586535E-05
     +,   1.6746710E-05,   1.6910386E-05,   1.7077600E-05
     +,   1.7248369E-05,   1.7422704E-05,   1.7600596E-05
     +,   1.7782022E-05,   1.7966948E-05,   1.8155311E-05
     +,   1.8347066E-05,   1.8542103E-05,   1.8740340E-05
     +,   1.8941651E-05,   1.9145909E-05,   1.9352959E-05
     +,   1.9562644E-05,   1.9774776E-05,   1.9989158E-05
     +,   2.0205574E-05,   2.0423804E-05,   2.0643600E-05
     +,   2.0864692E-05,   2.1086822E-05,   2.1309694E-05
     +,   2.1533013E-05,   2.1756456E-05,   2.1979704E-05
     +,   2.2202415E-05,   2.2424247E-05,   2.2644836E-05
     +,   2.2863816E-05,   2.3080818E-05,   2.3295452E-05
     +,   2.3507329E-05,   2.3716060E-05,   2.3921242E-05
     +,   2.4122473E-05,   2.4319355E-05,   2.4511473E-05
     +,   2.4698435E-05,   2.4879826E-05,   2.5055251E-05
     +,   2.5224308E-05,   2.5386606E-05,   2.5541754E-05
     +,   2.5689373E-05,   2.5829089E-05,   2.5960542E-05
     +,   2.6083364E-05,   2.6197225E-05,   2.6301790E-05
     +,   2.6396738E-05,   2.6481768E-05,   2.6556589E-05
     +,   2.6620928E-05,   2.6674528E-05,   2.6717151E-05
     +,   2.6748574E-05,   2.6768594E-05,   2.6777032E-05
     +,   2.6773720E-05,   2.6758520E-05,   2.6731312E-05
     +,   2.6691992E-05,   2.6640484E-05,   2.6576734E-05
     +,   2.6500713E-05,   2.6412401E-05,   2.6311815E-05
     +,   2.6198990E-05,   2.6073983E-05,   2.5936870E-05
     +,   2.5787764E-05,   2.5626774E-05,   2.5454059E-05
     +,   2.5269788E-05,   2.5074141E-05,   2.4867337E-05
     +,   2.4649617E-05,   2.4421230E-05,   2.4182440E-05
     +,   2.3933560E-05,   2.3674900E-05,   2.3406812E-05
     +,   2.3129636E-05,   2.2843771E-05,   2.2549617E-05
     +,   2.2247612E-05,   2.1938195E-05,   2.1621874E-05
     +,   2.1299147E-05,   2.0970550E-05,   2.0636673E-05
     +,   2.0298146E-05,   1.9955625E-05,   1.9609806E-05
     +,   1.9261481E-05,   1.8911449E-05,   1.8560635E-05
     +,   1.8209974E-05,   1.7860551E-05,   1.7513479E-05
     +,   1.7170032E-05,   1.6831533E-05,   1.6499480E-05
     +,   1.6175458E-05,   1.5861180E-05,   1.5558535E-05
     +,   1.5269541E-05,   1.4996351E-05,   1.4741267E-05
     +,   1.4506761E-05,   1.4295407E-05,   1.4109949E-05
     +,   1.3953209E-05,   1.3828132E-05,   1.3737712E-05
     +,   1.3684997E-05,   1.3673032E-05,   1.3704823E-05
     +,   1.3783289E-05,   1.3911216E-05,   1.4091179E-05
     +,   1.4325487E-05,   1.4616131E-05,   1.4964717E-05
     +,   1.5372352E-05,   1.5839609E-05,   1.6366475E-05
     +,   1.6952292E-05,   1.7595610E-05,   1.8294262E-05
     +,   1.9045287E-05,   1.9844838E-05,   2.0688218E-05
     +,   2.1569937E-05,   2.2483688E-05,   2.3422333E-05
     +,   2.4378021E-05,   2.5342313E-05,   2.6306250E-05
     +,   2.7260421E-05,   2.8195165E-05,   2.9100811E-05
     +,   2.9967838E-05,   3.0787014E-05,   3.1549844E-05
     +,   3.2248794E-05,   3.2877600E-05,   3.3431694E-05
     +,   3.3908760E-05,   3.4309207E-05,   3.4636767E-05
     +,   3.4899280E-05,   3.5109613E-05,   3.5286575E-05
     +,   3.5456193E-05,   3.5653036E-05,   3.5921883E-05
     +,   3.6319576E-05,   3.6916954E-05,   3.7801416E-05
     +,   3.9079281E-05,   4.0878484E-05,   4.3351232E-05
     +,   4.6676847E-05,   5.1064126E-05,   5.6752713E-05
     +,   6.4014108E-05,   7.3151808E-05,   8.4499094E-05
     +,   9.8413853E-05,   1.1527180E-04,   1.3545810E-04
     +,   1.5935328E-04,   1.8731374E-04,   2.1965643E-04
     +,   2.5663449E-04,   2.9840937E-04,   3.4502670E-04
     +,   3.9639487E-04,   4.5226040E-04,   5.1218504E-04
     +,   5.7553814E-04,   6.4149738E-04,   7.0905249E-04
     +,   7.7701814E-04,   8.4406917E-04,   9.0878393E-04
     +,   9.6969161E-04,   1.0253238E-03,   1.0742877E-03
     +,   1.1153234E-03,   1.1473598E-03,   1.1695711E-03
     +,   1.1814191E-03,   1.1826759E-03,   1.1734369E-03
     +,   1.1541159E-03,   1.1254204E-03,   1.0883139E-03
     +,   1.0439702E-03,   9.9371176E-04,   9.3894301E-04
     +,   8.8108855E-04,   8.2153844E-04,   7.6158252E-04
     +,   7.0237205E-04,   6.4489053E-04,   5.8992975E-04
     +,   5.3807849E-04,   4.8973004E-04,   4.4509859E-04
     +,   4.0423742E-04,   3.6706257E-04,   3.3338618E-04
     +,   3.0294823E-04,   2.7544270E-04,   2.5054222E-04
     +,   2.2792173E-04,   2.0727771E-04,   1.8833597E-04
     +,   1.7086128E-04,   1.5466192E-04,   1.3958756E-04
     +,   1.2552548E-04,   1.1239629E-04,   1.0014862E-04
     +,   8.8751047E-05,   7.8184901E-05,   6.8439076E-05
     +,   5.9505375E-05,   5.1373736E-05,   4.4028835E-05
     +,   3.7448994E-05,   3.1605934E-05,   2.6463526E-05
     +,   2.1979287E-05,   1.8105791E-05,   1.4791741E-05
     +,   1.1983412E-05,   9.6264857E-06,   7.6675933E-06
     +,   6.0553166E-06,   4.7411154E-06,   3.6802062E-06
     +,   2.8320676E-06,   2.1605731E-06,   1.6340206E-06
     +,   1.2250655E-06,   9.1049804E-07,   6.7082675E-07
     +,   4.8994644E-07,   3.5473172E-07,   2.5460901E-07
     +,   1.8116424E-07,   1.2779165E-07,   8.9368548E-08
     +,   6.1965117E-08,   4.2600785E-08,   2.9042594E-08
     +,   1.9636973E-08,   1.3170808E-08,   8.7656762E-09
     +,   5.7910374E-09,   3.8000141E-09,   2.4786087E-09
     +,   1.6088938E-09,   1.0409174E-09,   6.7272021E-10
     +,   4.3556539E-10,   2.8364341E-10,   1.8668422E-10
     +,   1.2489521E-10,   8.5458640E-11,   6.0140948E-11
     +,   4.3706653E-11,   3.2849595E-11,   2.5500276E-11
     +,   2.0369475E-11,   1.6659013E-11,   1.3874916E-11
     +,   1.1711656E-11,   9.9786264E-12,   8.5557204E-12
     +,   7.3653982E-12,   6.3563291E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz106 = Yx/0.0091304347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2732531E-05,   1.2780727E-05
     +,   1.2825509E-05,   1.2867051E-05,   1.2905549E-05
     +,   1.2941214E-05,   1.2974271E-05,   1.3004960E-05
     +,   1.3033537E-05,   1.3060269E-05,   1.3085444E-05
     +,   1.3109353E-05,   1.3132307E-05,   1.3154628E-05
     +,   1.3176648E-05,   1.3198707E-05,   1.3221160E-05
     +,   1.3244367E-05,   1.3268694E-05,   1.3294517E-05
     +,   1.3322216E-05,   1.3352173E-05,   1.3384779E-05
     +,   1.3420419E-05,   1.3459487E-05,   1.3502370E-05
     +,   1.3549457E-05,   1.3601128E-05,   1.3657764E-05
     +,   1.3719738E-05,   1.3787416E-05,   1.3861151E-05
     +,   1.3941288E-05,   1.4028162E-05,   1.4122092E-05
     +,   1.4223378E-05,   1.4332313E-05,   1.4449163E-05
     +,   1.4574181E-05,   1.4707592E-05,   1.4849608E-05
     +,   1.5000410E-05,   1.5160156E-05,   1.5328980E-05
     +,   1.5506988E-05,   1.5694253E-05,   1.5890826E-05
     +,   1.6096725E-05,   1.6311935E-05,   1.6536409E-05
     +,   1.6770071E-05,   1.7012802E-05,   1.7264460E-05
     +,   1.7524870E-05,   1.7793805E-05,   1.8071021E-05
     +,   1.8356244E-05,   1.8649134E-05,   1.8949348E-05
     +,   1.9256495E-05,   1.9570150E-05,   1.9889862E-05
     +,   2.0215130E-05,   2.0545433E-05,   2.0880238E-05
     +,   2.1218937E-05,   2.1560943E-05,   2.1905589E-05
     +,   2.2252238E-05,   2.2600178E-05,   2.2948720E-05
     +,   2.3297103E-05,   2.3644609E-05,   2.3990442E-05
     +,   2.4333829E-05,   2.4673995E-05,   2.5010126E-05
     +,   2.5341402E-05,   2.5667023E-05,   2.5986188E-05
     +,   2.6298065E-05,   2.6601876E-05,   2.6896796E-05
     +,   2.7182075E-05,   2.7456930E-05,   2.7720629E-05
     +,   2.7972439E-05,   2.8211685E-05,   2.8437697E-05
     +,   2.8649858E-05,   2.8847602E-05,   2.9030383E-05
     +,   2.9197727E-05,   2.9349210E-05,   2.9484483E-05
     +,   2.9603238E-05,   2.9705274E-05,   2.9790439E-05
     +,   2.9858684E-05,   2.9910039E-05,   2.9944646E-05
     +,   2.9962723E-05,   2.9964622E-05,   2.9950790E-05
     +,   2.9921790E-05,   2.9878311E-05,   2.9821171E-05
     +,   2.9751303E-05,   2.9669785E-05,   2.9577803E-05
     +,   2.9476694E-05,   2.9367910E-05,   2.9253042E-05
     +,   2.9133775E-05,   2.9011944E-05,   2.8889457E-05
     +,   2.8768338E-05,   2.8650684E-05,   2.8538663E-05
     +,   2.8434490E-05,   2.8340412E-05,   2.8258686E-05
     +,   2.8191567E-05,   2.8141274E-05,   2.8109946E-05
     +,   2.8099661E-05,   2.8112372E-05,   2.8149905E-05
     +,   2.8213934E-05,   2.8305936E-05,   2.8427221E-05
     +,   2.8578872E-05,   2.8761780E-05,   2.8976601E-05
     +,   2.9223813E-05,   2.9503697E-05,   2.9816367E-05
     +,   3.0161797E-05,   3.0539908E-05,   3.0950592E-05
     +,   3.1393753E-05,   3.1869404E-05,   3.2377760E-05
     +,   3.2919343E-05,   3.3494958E-05,   3.4105906E-05
     +,   3.4754037E-05,   3.5441768E-05,   3.6172176E-05
     +,   3.6949103E-05,   3.7777179E-05,   3.8661714E-05
     +,   3.9608796E-05,   4.0625269E-05,   4.1718624E-05
     +,   4.2896794E-05,   4.4168111E-05,   4.5541175E-05
     +,   4.7024634E-05,   4.8626709E-05,   5.0355353E-05
     +,   5.2217758E-05,   5.4219981E-05,   5.6366818E-05
     +,   5.8661743E-05,   6.1106635E-05,   6.3701540E-05
     +,   6.6444874E-05,   6.9333888E-05,   7.2364928E-05
     +,   7.5533833E-05,   7.8837162E-05,   8.2273553E-05
     +,   8.5845131E-05,   8.9558882E-05,   9.3429509E-05
     +,   9.7481367E-05,   1.0175058E-04,   1.0628779E-04
     +,   1.1116060E-04,   1.1645565E-04,   1.2227983E-04
     +,   1.2876162E-04,   1.3605207E-04,   1.4432406E-04
     +,   1.5377039E-04,   1.6460188E-04,   1.7704448E-04
     +,   1.9133458E-04,   2.0771159E-04,   2.2641355E-04
     +,   2.4766862E-04,   2.7168370E-04,   2.9863536E-04
     +,   3.2866024E-04,   3.6184158E-04,   3.9819386E-04
     +,   4.3765132E-04,   4.8005799E-04,   5.2515394E-04
     +,   5.7256315E-04,   6.2178884E-04,   6.7221536E-04
     +,   7.2310894E-04,   7.7362149E-04,   8.2281750E-04
     +,   8.6969248E-04,   9.1320009E-04,   9.5229264E-04
     +,   9.8596257E-04,   1.0132826E-03,   1.0334461E-03
     +,   1.0458091E-03,   1.0499239E-03,   1.0455622E-03
     +,   1.0327311E-03,   1.0116767E-03,   9.8287524E-04
     +,   9.4701129E-04,   9.0495334E-04,   8.5770688E-04
     +,   8.0637372E-04,   7.5210887E-04,   6.9606968E-04
     +,   6.3936826E-04,   5.8303599E-04,   5.2799610E-04
     +,   4.7503604E-04,   4.2479031E-04,   3.7773850E-04
     +,   3.3421093E-04,   2.9439444E-04,   2.5834481E-04
     +,   2.2600846E-04,   1.9724584E-04,   1.7184659E-04
     +,   1.4955355E-04,   1.3008284E-04,   1.1313874E-04
     +,   9.8426135E-05,   8.5662912E-05,   7.4587922E-05
     +,   6.4964894E-05,   5.6584449E-05,   4.9265433E-05
     +,   4.2854215E-05,   3.7221998E-05,   3.2261778E-05
     +,   2.7885644E-05,   2.4021951E-05,   2.0611420E-05
     +,   1.7604874E-05,   1.4961014E-05,   1.2644218E-05
     +,   1.0622894E-05,   8.8685219E-06,   7.3549631E-06
     +,   6.0577613E-06,   4.9538103E-06,   4.0213258E-06
     +,   3.2398711E-06,   2.5903166E-06,   2.0548769E-06
     +,   1.6172457E-06,   1.2626709E-06,   9.7789291E-07
     +,   7.5118589E-07,   5.7231921E-07,   4.3246186E-07
     +,   3.2408292E-07,   2.4084940E-07,   1.7750435E-07
     +,   1.2973071E-07,   9.4023591E-08,   6.7574433E-08
     +,   4.8160029E-08,   3.4036230E-08,   2.3853902E-08
     +,   1.6578198E-08,   1.1426047E-08,   7.8098115E-09
     +,   5.2942433E-09,   3.5596459E-09,   2.3741265E-09
     +,   1.5708831E-09,   1.0313878E-09,   6.7212103E-10
     +,   4.3488499E-10,   2.7953481E-10,   1.7861829E-10
     +,   1.1357432E-10,   7.1955948E-11,   4.5507872E-11
     +,   2.8799194E-11,   1.8295062E-11,   1.1712633E-11
     +,   7.5927433E-12,   5.0095193E-12,   3.3810658E-12
     +,   2.3440152E-12,   1.6733069E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz108 = Yx/0.00882608695652174
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.4032235E-30,   1.1392463E-29
     +,   2.3903520E-29,   4.9909379E-29,   1.0370073E-28
     +,   2.1441624E-28,   4.4117532E-28,   9.0332537E-28
     +,   1.8405533E-27,   3.7319446E-27,   7.5301141E-27
     +,   1.5119726E-26,   3.0210929E-26,   6.0070612E-26
     +,   1.1886100E-25,   2.3404150E-25,   4.5858950E-25
     +,   8.9419671E-25,   1.7350814E-24,   3.3503053E-24
     +,   6.4376398E-24,   1.2309679E-23,   2.3422839E-23
     +,   4.4352531E-23,   8.3573483E-23,   1.5671106E-22
     +,   2.9242097E-22,   5.4299414E-22,   1.0033625E-21
     +,   1.8450157E-21,   3.3761235E-21,   6.1477473E-21
     +,   1.1140162E-20,   2.0088293E-20,   3.6047410E-20
     +,   6.4369896E-20,   1.1438463E-19,   2.0226869E-19
     +,   3.5593639E-19,   6.2328695E-19,   1.0861354E-18
     +,   1.8834727E-18,   3.2502050E-18,   5.5813594E-18
     +,   9.5378094E-18,   1.6219349E-17,   2.7447065E-17
     +,   4.6220752E-17,   7.7456001E-17,   1.2916727E-16
     +,   2.1435130E-16,   3.5397896E-16,   5.8170559E-16
     +,   9.5129116E-16,   1.5480850E-15,   2.5070161E-15
     +,   4.0401405E-15,   6.4790960E-15,   1.0339771E-14
     +,   1.6420425E-14,   2.5949847E-14,   4.0810044E-14
     +,   6.3866115E-14,   9.9460553E-14,   1.5414040E-13
     +,   2.3771314E-13,   3.6481568E-13,   5.5714184E-13
     +,   8.4672189E-13,   1.2805264E-12,   1.9271696E-12
     +,   2.8861789E-12,   4.3014030E-12,   6.3792339E-12
     +,   9.4146531E-12,   1.3826877E-11,   2.0207920E-11
     +,   2.9389456E-11,   4.2534209E-11,   6.1258908E-11
     +,   8.7795375E-11,   1.2521521E-10,   1.7771164E-10
     +,   2.5099028E-10,   3.5275305E-10,   4.9336391E-10
     +,   6.8665201E-10,   9.5101738E-10,   1.3107304E-09
     +,   1.7976948E-09,   2.4535844E-09,   3.3324474E-09
     +,   4.5040096E-09,   6.0577743E-09,   8.1079055E-09
     +,   1.0798860E-08,   1.4312949E-08,   1.8877893E-08
     +,   2.4777641E-08,   3.2362369E-08,   4.2063181E-08
     +,   5.4404840E-08,   7.0025287E-08,   8.9690374E-08
     +,   1.1431809E-07,   1.4499908E-07,   1.8301766E-07
     +,   2.2987685E-07,   2.8732620E-07,   3.5738483E-07
     +,   4.4235571E-07,   5.4486361E-07,   6.6785020E-07
     +,   8.1461161E-07,   9.8877410E-07,   1.1943291E-06
     +,   1.4355758E-06,   1.7171506E-06,   2.0439300E-06
     +,   2.4210367E-06,   2.8537556E-06,   3.3474175E-06
     +,   3.9073147E-06,   4.5386300E-06,   5.2462742E-06
     +,   6.0346606E-06,   6.9077132E-06,   7.8684961E-06
     +,   8.9192563E-06,   1.0061007E-05,   1.1293634E-05
     +,   1.2615432E-05,   1.4023286E-05,   1.5512209E-05
     +,   1.7075572E-05,   1.8704925E-05,   2.0389865E-05
     +,   2.2118171E-05,   2.3876015E-05,   2.5647991E-05
     +,   2.7417156E-05,   2.9165425E-05,   3.0873936E-05
     +,   3.2523265E-05,   3.4093639E-05,   3.5565616E-05
     +,   3.6920334E-05,   3.8139806E-05,   3.9207454E-05
     +,   4.0108524E-05,   4.0830306E-05,   4.1362451E-05
     +,   4.1697258E-05,   4.1829862E-05,   4.1758340E-05
     +,   4.1483709E-05,   4.1010000E-05,   4.0344079E-05
     +,   3.9495466E-05,   3.8476250E-05,   3.7300619E-05
     +,   3.5984591E-05,   3.4545759E-05,   3.3002834E-05
     +,   3.1375133E-05,   2.9682255E-05,   2.7943835E-05
     +,   2.6179054E-05,   2.4406208E-05,   2.2642533E-05
     +,   2.0904094E-05,   1.9205516E-05,   1.7559831E-05
     +,   1.5978680E-05,   1.4472745E-05,   1.3052028E-05
     +,   1.1727021E-05,   1.0510419E-05,   9.4194993E-06
     +,   8.4796820E-06,   7.7296181E-06,   7.2277676E-06
     +,   7.0602969E-06,   7.3500441E-06,   8.2655069E-06
     +,   1.0027899E-05,   1.2914081E-05,   1.7252993E-05
     +,   2.3412491E-05,   3.1774242E-05,   4.2699805E-05
     +,   5.6487363E-05,   7.3325347E-05,   9.3253853E-05
     +,   1.1614298E-04,   1.4169348E-04,   1.6946660E-04
     +,   1.9894862E-04,   2.2964220E-04,   2.6116712E-04
     +,   2.9335447E-04,   3.2631264E-04,   3.6043214E-04
     +,   3.9629810E-04,   4.3450145E-04,   4.7537949E-04
     +,   5.1872450E-04,   5.6356855E-04,   6.0816231E-04
     +,   6.5021962E-04,   6.8741525E-04,   7.1802200E-04
     +,   7.4147806E-04,   7.5865001E-04,   7.7163748E-04
     +,   7.8314391E-04,   7.9559232E-04,   8.1027742E-04
     +,   8.2683360E-04,   8.4318593E-04,   8.5599016E-04
     +,   8.6139789E-04,   8.5592328E-04,   8.3718292E-04
     +,   8.0433988E-04,   7.5820199E-04,   7.0100819E-04
     +,   6.3599157E-04,   5.6684174E-04,   4.9719337E-04
     +,   4.3021547E-04,   3.6833357E-04,   3.1310439E-04
     +,   2.6523651E-04,   2.2471113E-04,   1.9095397E-04
     +,   1.6304644E-04,   1.3992273E-04,   1.2053025E-04
     +,   1.0394481E-04,   8.9437628E-05,   7.6495344E-05
     +,   6.4802312E-05,   5.4200194E-05,   4.4638280E-05
     +,   3.6123558E-05,   2.8677645E-05,   2.2306567E-05
     +,   1.6985041E-05,   1.2652480E-05,   9.2164128E-06
     +,   6.5627628E-06,   4.5673496E-06,   3.1062750E-06
     +,   2.0642865E-06,   1.3403637E-06,   8.5033173E-07
     +,   5.2706474E-07,   3.1918131E-07,   1.8884160E-07
     +,   1.0915647E-07,   6.1645302E-08,   3.4012711E-08
     +,   1.8334250E-08,   9.6556985E-09,   4.9681423E-09
     +,   2.4973785E-09,   1.2264897E-09,   5.8849470E-10
     +,   2.7587424E-10,   1.2634492E-10,   5.6531890E-11
     +,   2.4713285E-11,   1.0554968E-11,   4.4041381E-12
     +,   1.7954184E-12,   7.1506906E-13,   2.7824788E-13
     +,   1.0577731E-13,   3.9287601E-14,   1.4255866E-14
     +,   5.0540059E-15,   1.7504630E-15,   5.9234544E-16
     +,   1.9582572E-16,   6.3251404E-17,   1.9959964E-17
     +,   6.1535078E-18,   1.8534996E-18,   5.4542387E-19
     +,   1.5681260E-19,   4.4045607E-20,   1.2087347E-20
     +,   3.2406666E-21,   8.4888623E-22,   2.1724162E-22
     +,   5.4320577E-23,   1.3270772E-23,   3.1682545E-24
     +,   7.3926330E-25,   1.6869215E-25
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz110 = Yx/0.00595
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.0255642E-06,   7.3087886E-06
     +,   7.5968351E-06,   7.8893863E-06,   8.1860971E-06
     +,   8.4865987E-06,   8.7905009E-06,   9.0973872E-06
     +,   9.4068173E-06,   9.7183411E-06,   1.0031472E-05
     +,   1.0345711E-05,   1.0660540E-05,   1.0975421E-05
     +,   1.1289801E-05,   1.1603115E-05,   1.1914781E-05
     +,   1.2224205E-05,   1.2530787E-05,   1.2833918E-05
     +,   1.3132981E-05,   1.3427355E-05,   1.3716416E-05
     +,   1.3999556E-05,   1.4276138E-05,   1.4545562E-05
     +,   1.4807218E-05,   1.5060506E-05,   1.5304840E-05
     +,   1.5539648E-05,   1.5764372E-05,   1.5978476E-05
     +,   1.6181441E-05,   1.6372769E-05,   1.6551992E-05
     +,   1.6718663E-05,   1.6872364E-05,   1.7012708E-05
     +,   1.7139344E-05,   1.7251945E-05,   1.7350223E-05
     +,   1.7433927E-05,   1.7502842E-05,   1.7556786E-05
     +,   1.7595623E-05,   1.7619250E-05,   1.7627604E-05
     +,   1.7620667E-05,   1.7598457E-05,   1.7561028E-05
     +,   1.7508479E-05,   1.7440947E-05,   1.7358610E-05
     +,   1.7261673E-05,   1.7150389E-05,   1.7025044E-05
     +,   1.6885957E-05,   1.6733477E-05,   1.6567992E-05
     +,   1.6389917E-05,   1.6199692E-05,   1.5997784E-05
     +,   1.5784695E-05,   1.5560938E-05,   1.5327039E-05
     +,   1.5083569E-05,   1.4831084E-05,   1.4570184E-05
     +,   1.4301450E-05,   1.4025507E-05,   1.3742948E-05
     +,   1.3454411E-05,   1.3160499E-05,   1.2861849E-05
     +,   1.2559076E-05,   1.2252783E-05,   1.1943592E-05
     +,   1.1632114E-05,   1.1318934E-05,   1.1004623E-05
     +,   1.0689771E-05,   1.0374909E-05,   1.0060598E-05
     +,   9.7473376E-06,   9.4356492E-06,   9.1259963E-06
     +,   8.8188599E-06,   8.5146576E-06,   8.2138286E-06
     +,   7.9167557E-06,   7.6237980E-06,   7.3353149E-06
     +,   7.0516344E-06,   6.7730457E-06,   6.4998121E-06
     +,   6.2321997E-06,   5.9704134E-06,   5.7146708E-06
     +,   5.4651305E-06,   5.2219616E-06,   4.9852774E-06
     +,   4.7551998E-06,   4.5317993E-06,   4.3151549E-06
     +,   4.1053040E-06,   3.9022648E-06,   3.7060493E-06
     +,   3.5166536E-06,   3.3340420E-06,   3.1581667E-06
     +,   2.9889791E-06,   2.8263967E-06,   2.6703442E-06
     +,   2.5207148E-06,   2.3774105E-06,   2.2403040E-06
     +,   2.1092778E-06,   1.9841882E-06,   1.8649012E-06
     +,   1.7512660E-06,   1.6431252E-06,   1.5403248E-06
     +,   1.4427062E-06,   1.3501028E-06,   1.2623447E-06
     +,   1.1792694E-06,   1.1007037E-06,   1.0264832E-06
     +,   9.5643520E-07,   8.9039634E-07,   8.2819639E-07
     +,   7.6967501E-07,   7.1466673E-07,   6.6301601E-07
     +,   6.1456461E-07,   5.6915860E-07,   5.2664984E-07
     +,   4.8689469E-07,   4.4975002E-07,   4.1507775E-07
     +,   3.8274612E-07,   3.5262772E-07,   3.2459761E-07
     +,   2.9853553E-07,   2.7432876E-07,   2.5186597E-07
     +,   2.3104134E-07,   2.1175468E-07,   1.9391031E-07
     +,   1.7741554E-07,   1.6218273E-07,   1.4812909E-07
     +,   1.3517644E-07,   1.2324944E-07,   1.1227711E-07
     +,   1.0219303E-07,   9.2934719E-08,   8.4442590E-08
     +,   7.6661102E-08,   6.9539077E-08,   6.3028658E-08
     +,   5.7086240E-08,   5.1673751E-08,   4.6759297E-08
     +,   4.2319034E-08,   3.8340964E-08,   3.4830695E-08
     +,   3.1819603E-08,   2.9377953E-08,   2.7634913E-08
     +,   2.6808333E-08,   2.7247772E-08,   2.9496849E-08
     +,   3.4382129E-08,   4.3135930E-08,   5.7566943E-08
     +,   8.0290015E-08,   1.1502915E-07,   1.6701443E-07
     +,   2.4349572E-07,   3.5438381E-07,   5.1303175E-07
     +,   7.3718604E-07,   1.0501263E-06,   1.4819561E-06
     +,   2.0710147E-06,   2.8654424E-06,   3.9248757E-06
     +,   5.3220701E-06,   7.1442591E-06,   9.4947254E-06
     +,   1.2493724E-05,   1.6278691E-05,   2.1004154E-05
     +,   2.6841135E-05,   3.3975168E-05,   4.2602911E-05
     +,   5.2928495E-05,   6.5159387E-05,   7.9500234E-05
     +,   9.6144977E-05,   1.1527001E-04,   1.3702772E-04
     +,   1.6153743E-04,   1.8887450E-04,   2.1906687E-04
     +,   2.5208551E-04,   2.8783496E-04,   3.2614896E-04
     +,   3.6678798E-04,   4.0943356E-04,   4.5368297E-04
     +,   4.9905159E-04,   5.4497836E-04,   5.9082778E-04
     +,   6.3589477E-04,   6.7941955E-04,   7.2060514E-04
     +,   7.5863407E-04,   7.9268689E-04,   8.2197553E-04
     +,   8.4576750E-04,   8.6341257E-04,   8.7437482E-04
     +,   8.7825907E-04,   8.7483221E-04,   8.6403941E-04
     +,   8.4601674E-04,   8.2109007E-04,   7.8976748E-04
     +,   7.5272669E-04,   7.1078830E-04,   6.6488207E-04
     +,   6.1601162E-04,   5.6522025E-04,   5.1354175E-04
     +,   4.6196615E-04,   4.1140884E-04,   3.6267954E-04
     +,   3.1645663E-04,   2.7327839E-04,   2.3354002E-04
     +,   1.9749226E-04,   1.6524835E-04,   1.3680114E-04
     +,   1.1204235E-04,   9.0780195E-05,   7.2759358E-05
     +,   5.7683133E-05,   4.5233002E-05,   3.5082001E-05
     +,   2.6909880E-05,   2.0413712E-05,   1.5314423E-05
     +,   1.1361245E-05,   8.3344357E-06,   6.0455864E-06
     +,   4.3361169E-06,   3.0749870E-06,   2.1559754E-06
     +,   1.4944864E-06,   1.0241824E-06,   6.9387232E-07
     +,   4.6470561E-07,   3.0765804E-07,   2.0134014E-07
     +,   1.3023964E-07,   8.3271829E-08,   5.2624447E-08
     +,   3.2869327E-08,   2.0290244E-08,   1.2378556E-08
     +,   7.4633233E-09,   4.4468718E-09,   2.6182820E-09
     +,   1.5234217E-09,   8.7586738E-10,   4.9759341E-10
     +,   2.7931985E-10,   1.5492628E-10,   8.4901856E-11
     +,   4.5971098E-11,   2.4592424E-11,   1.2997984E-11
     +,   6.7870501E-12,   3.5013017E-12,   1.7844590E-12
     +,   8.9846343E-13,   4.4692253E-13,   2.1963056E-13
     +,   1.0664140E-13,   5.1162941E-14,   2.4260193E-14
     +,   1.1373229E-14,   5.2753563E-15,   2.4240088E-15
     +,   1.1060574E-15,   5.0328628E-16,   2.3012347E-16
     +,   1.0709372E-16,   5.1741544E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz112 = Yx/0.00595
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   1.3368557E-38,   4.8937092E-38
     +,   1.7717967E-37,   6.3453386E-37,   2.2475593E-36
     +,   7.8746750E-36,   2.7287867E-35,   9.3534464E-35
     +,   3.1709970E-34,   1.0633555E-33,   3.5268464E-33
     +,   1.1569954E-32,   3.7543679E-32,   1.2049915E-31
     +,   3.8252067E-31,   1.2010684E-30,   3.7302457E-30
     +,   1.1458582E-29,   3.4816450E-29,   1.0463095E-28
     +,   3.1102315E-28,   9.1443741E-28,   2.6593085E-27
     +,   7.6491043E-27,   2.1762441E-26,   6.1239506E-26
     +,   1.7045027E-25,   4.6926584E-25,   1.2778471E-24
     +,   3.4416558E-24,   9.1684933E-24,   2.4159173E-23
     +,   6.2964366E-23,   1.6231654E-22,   4.1386417E-22
     +,   1.0437737E-21,   2.6036465E-21,   6.4241322E-21
     +,   1.5677339E-20,   3.7843129E-20,   9.0349791E-20
     +,   2.1335896E-19,   4.9836381E-19,   1.1513922E-18
     +,   2.6310572E-18,   5.9467119E-18,   1.3294677E-17
     +,   2.9397304E-17,   6.4296868E-17,   1.3909211E-16
     +,   2.9762231E-16,   6.2988509E-16,   1.3185802E-15
     +,   2.7301331E-15,   5.5913018E-15,   1.1325872E-14
     +,   2.2691977E-14,   4.4970128E-14,   8.8148774E-14
     +,   1.7089940E-13,   3.2772228E-13,   6.2161658E-13
     +,   1.1661914E-12,   2.1640547E-12,   3.9719144E-12
     +,   7.2107572E-12,   1.2947777E-11,   2.2996363E-11
     +,   4.0397796E-11,   7.0194933E-11,   1.2063923E-10
     +,   2.0507587E-10,   3.4481917E-10,   5.7347149E-10
     +,   9.4334263E-10,   1.5348769E-09,   2.4701938E-09
     +,   3.9322061E-09,   6.1913430E-09,   9.6424078E-09
     +,   1.4854121E-08,   2.2633955E-08,   3.4114244E-08
     +,   5.0860777E-08,   7.5006952E-08,   1.0941913E-07
     +,   1.5789604E-07,   2.2539788E-07,   3.1829887E-07
     +,   4.4466699E-07,   6.1456728E-07,   8.4035065E-07
     +,   1.1369051E-06,   1.5218767E-06,   2.0158475E-06
     +,   2.6423650E-06,   3.4277689E-06,   4.4010512E-06
     +,   5.5933701E-06,   7.0373126E-06,   8.7660655E-06
     +,   1.0812519E-05,   1.3207973E-05,   1.5980619E-05
     +,   1.9154186E-05,   2.2746706E-05,   2.6768945E-05
     +,   3.1222724E-05,   3.6099904E-05,   4.1381722E-05
     +,   4.7037815E-05,   5.3025225E-05,   5.9289549E-05
     +,   6.5765016E-05,   7.2375282E-05,   7.9035817E-05
     +,   8.5657266E-05,   9.2148774E-05,   9.8422199E-05
     +,   1.0439804E-04,   1.1001166E-04,   1.1521882E-04
     +,   1.2000083E-04,   1.2436882E-04,   1.2836636E-04
     +,   1.3206819E-04,   1.3557565E-04,   1.3900927E-04
     +,   1.4249644E-04,   1.4615575E-04,   1.5007936E-04
     +,   1.5431491E-04,   1.5884849E-04,   1.6359151E-04
     +,   1.6837526E-04,   1.7295536E-04,   1.7702751E-04
     +,   1.8025811E-04,   1.8233056E-04,   1.8300730E-04
     +,   1.8220331E-04,   1.8006613E-04,   1.7704778E-04
     +,   1.7394978E-04,   1.7191876E-04,   1.7237062E-04
     +,   1.7683802E-04,   1.8675940E-04,   2.0326604E-04
     +,   2.2706593E-04,   2.5854434E-04,   2.9815474E-04
     +,   3.4706795E-04,   4.0790124E-04,   4.8521315E-04
     +,   5.8540032E-04,   7.1564614E-04,   8.8167685E-04
     +,   1.0842310E-03,   1.3149524E-03,   1.5535705E-03
     +,   1.7688652E-03,   1.9249000E-03,   1.9912960E-03
     +,   1.9533304E-03,   1.8168453E-03,   1.6056421E-03
     +,   1.3531216E-03,   1.0924602E-03,   8.4941974E-04
     +,   6.3953258E-04,   4.6891809E-04,   3.3689843E-04
     +,   2.3895843E-04,   1.6907712E-04,   1.2118411E-04
     +,   8.9872854E-05,   7.0626025E-05,   5.9798869E-05
     +,   5.4534125E-05,   5.2677464E-05,   5.2688662E-05
     +,   5.3535030E-05,   5.4571676E-05,   5.5424720E-05
     +,   5.5894132E-05,   5.5884109E-05,   5.5359575E-05
     +,   5.4321536E-05,   5.2794392E-05,   5.0819188E-05
     +,   4.8449285E-05,   4.5747220E-05,   4.2781907E-05
     +,   3.9625487E-05,   3.6350244E-05,   3.3026059E-05
     +,   2.9718307E-05,   2.6485675E-05,   2.3378474E-05
     +,   2.0437954E-05,   1.7696151E-05,   1.5175335E-05
     +,   1.2888831E-05,   1.0841934E-05,   9.0327630E-06
     +,   7.4533664E-06,   6.0911575E-06,   4.9302039E-06
     +,   3.9523097E-06,   3.1380182E-06,   2.4675987E-06
     +,   1.9218307E-06,   1.4824163E-06,   1.1325229E-06
     +,   8.5691556E-07,   6.4217141E-07,   4.7662616E-07
     +,   3.5037021E-07,   2.5508797E-07,   1.8393976E-07
     +,   1.3136338E-07,   9.2917162E-08,   6.5093261E-08
     +,   4.5163642E-08,   3.1035945E-08,   2.1122915E-08
     +,   1.4238558E-08,   9.5058414E-09,   6.2854886E-09
     +,   4.1162314E-09,   2.6698375E-09,   1.7150679E-09
     +,   1.0911942E-09,   6.8759820E-10,   4.2913309E-10
     +,   2.6525301E-10,   1.6238796E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz113 = Yx/0.00733333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1909702E-05,   3.2223052E-05
     +,   3.2527983E-05,   3.2824064E-05,   3.3110864E-05
     +,   3.3387962E-05,   3.3654949E-05,   3.3911416E-05
     +,   3.4156976E-05,   3.4391254E-05,   3.4613880E-05
     +,   3.4824512E-05,   3.5022807E-05,   3.5208453E-05
     +,   3.5381148E-05,   3.5540612E-05,   3.5686586E-05
     +,   3.5818830E-05,   3.5937122E-05,   3.6041267E-05
     +,   3.6131096E-05,   3.6206457E-05,   3.6267214E-05
     +,   3.6313279E-05,   3.6344565E-05,   3.6361023E-05
     +,   3.6362631E-05,   3.6349375E-05,   3.6321297E-05
     +,   3.6278430E-05,   3.6220856E-05,   3.6148675E-05
     +,   3.6062003E-05,   3.5961002E-05,   3.5845842E-05
     +,   3.5716716E-05,   3.5573838E-05,   3.5417459E-05
     +,   3.5247835E-05,   3.5065252E-05,   3.4870016E-05
     +,   3.4662447E-05,   3.4442888E-05,   3.4211691E-05
     +,   3.3969231E-05,   3.3715900E-05,   3.3452096E-05
     +,   3.3178232E-05,   3.2894732E-05,   3.2602034E-05
     +,   3.2300584E-05,   3.1990821E-05,   3.1673218E-05
     +,   3.1348223E-05,   3.1016312E-05,   3.0677951E-05
     +,   3.0333602E-05,   2.9983743E-05,   2.9628838E-05
     +,   2.9269349E-05,   2.8905744E-05,   2.8538472E-05
     +,   2.8168004E-05,   2.7794769E-05,   2.7419195E-05
     +,   2.7041731E-05,   2.6662776E-05,   2.6282762E-05
     +,   2.5902058E-05,   2.5521074E-05,   2.5140165E-05
     +,   2.4759709E-05,   2.4380030E-05,   2.4001480E-05
     +,   2.3624372E-05,   2.3248987E-05,   2.2875634E-05
     +,   2.2504593E-05,   2.2136106E-05,   2.1770407E-05
     +,   2.1407741E-05,   2.1048294E-05,   2.0692283E-05
     +,   2.0339867E-05,   1.9991228E-05,   1.9646493E-05
     +,   1.9305817E-05,   1.8969295E-05,   1.8637054E-05
     +,   1.8309172E-05,   1.7985718E-05,   1.7666765E-05
     +,   1.7352371E-05,   1.7042570E-05,   1.6737378E-05
     +,   1.6436828E-05,   1.6140912E-05,   1.5849639E-05
     +,   1.5562980E-05,   1.5280933E-05,   1.5003448E-05
     +,   1.4730503E-05,   1.4462039E-05,   1.4198021E-05
     +,   1.3938383E-05,   1.3683054E-05,   1.3431977E-05
     +,   1.3185087E-05,   1.2942305E-05,   1.2703542E-05
     +,   1.2468734E-05,   1.2237782E-05,   1.2010621E-05
     +,   1.1787148E-05,   1.1567292E-05,   1.1350953E-05
     +,   1.1138061E-05,   1.0928513E-05,   1.0722239E-05
     +,   1.0519150E-05,   1.0319156E-05,   1.0122182E-05
     +,   9.9281588E-06,   9.7369984E-06,   9.5486239E-06
     +,   9.3629742E-06,   9.1799675E-06,   8.9995501E-06
     +,   8.8216466E-06,   8.6462060E-06,   8.4731610E-06
     +,   8.3024679E-06,   8.1340622E-06,   7.9679085E-06
     +,   7.8039529E-06,   7.6421511E-06,   7.4824661E-06
     +,   7.3248675E-06,   7.1693175E-06,   7.0157798E-06
     +,   6.8642316E-06,   6.7146507E-06,   6.5670129E-06
     +,   6.4212913E-06,   6.2774780E-06,   6.1355536E-06
     +,   5.9955000E-06,   5.8573141E-06,   5.7209909E-06
     +,   5.5865212E-06,   5.4539005E-06,   5.3231374E-06
     +,   5.1942429E-06,   5.0672288E-06,   4.9421142E-06
     +,   4.8189399E-06,   4.6977616E-06,   4.5786524E-06
     +,   4.4617136E-06,   4.3471009E-06,   4.2350180E-06
     +,   4.1257417E-06,   4.0196633E-06,   3.9173074E-06
     +,   3.8193743E-06,   3.7268060E-06,   3.6408514E-06
     +,   3.5631658E-06,   3.4959037E-06,   3.4418708E-06
     +,   3.4046964E-06,   3.3890242E-06,   3.4007637E-06
     +,   3.4473844E-06,   3.5382425E-06,   3.6849863E-06
     +,   3.9020133E-06,   4.2069578E-06,   4.6212599E-06
     +,   5.1708244E-06,   5.8866908E-06,   6.8056925E-06
     +,   7.9712108E-06,   9.4340230E-06,   1.1253003E-05
     +,   1.3495678E-05,   1.6238879E-05,   1.9569450E-05
     +,   2.3584478E-05,   2.8390927E-05,   3.4106244E-05
     +,   4.0857594E-05,   4.8780483E-05,   5.8017631E-05
     +,   6.8718007E-05,   8.1033984E-05,   9.5117619E-05
     +,   1.1111781E-04,   1.2917742E-04,   1.4942815E-04
     +,   1.7198409E-04,   1.9693741E-04,   2.2435450E-04
     +,   2.5426943E-04,   2.8667459E-04,   3.2152169E-04
     +,   3.5871414E-04,   3.9810024E-04,   4.3947244E-04
     +,   4.8256791E-04,   5.2706589E-04,   5.7258579E-04
     +,   6.1869225E-04,   6.6490384E-04,   7.1069598E-04
     +,   7.5550703E-04,   7.9875067E-04,   8.3983154E-04
     +,   8.7815395E-04,   9.1313367E-04,   9.4421773E-04
     +,   9.7089697E-04,   9.9271606E-04,   1.0092905E-03
     +,   1.0203166E-03,   1.0255816E-03,   1.0249678E-03
     +,   1.0184596E-03,   1.0061435E-03,   9.8820613E-04
     +,   9.6493011E-04,   9.3668868E-04,   9.0393098E-04
     +,   8.6717267E-04,   8.2698523E-04,   7.8397518E-04
     +,   7.3877070E-04,   6.9200923E-04,   6.4432091E-04
     +,   5.9630984E-04,   5.4854545E-04,   5.0155463E-04
     +,   4.5580984E-04,   4.1171955E-04,   3.6962735E-04
     +,   3.2981273E-04,   2.9248802E-04,   2.5779800E-04
     +,   2.2582676E-04,   1.9660532E-04,   1.7011145E-04
     +,   1.4627988E-04,   1.2501073E-04,   1.0617475E-04
     +,   8.9619411E-05,   7.5177064E-05,   6.2671759E-05
     +,   5.1923445E-05,   4.2752112E-05,   3.4982546E-05
     +,   2.8447837E-05,   2.2990911E-05,   1.8466004E-05
     +,   1.4740131E-05,   1.1693775E-05,   9.2201808E-06
     +,   7.2254466E-06,   5.6279523E-06,   4.3573505E-06
     +,   3.3535616E-06,   2.5658774E-06,   1.9519343E-06
     +,   1.4766033E-06,   1.1110012E-06,   8.3162371E-07
     +,   6.1952568E-07,   4.5951637E-07,   3.3956283E-07
     +,   2.5017712E-07,   1.8396427E-07,   1.3518775E-07
     +,   9.9446133E-08,   7.3378892E-08,   5.4446964E-08
     +,   4.0741430E-08,   3.0841584E-08,   2.3695417E-08
     +,   1.8530663E-08,   1.4784754E-08,   1.2049938E-08
     +,   1.0033415E-08,   8.5258103E-09,   7.3787354E-09
     +,   6.4873524E-09,   5.7782175E-09,   5.1999449E-09
     +,   4.7168403E-09,   4.3040767E-09,   3.9444532E-09
     +,   3.6259626E-09,   3.3402425E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz114 = Yx/0.0091304347826087
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0559209E-05,   1.1043566E-05
     +,   1.1544368E-05,   1.2061891E-05,   1.2596392E-05
     +,   1.3148123E-05,   1.3717307E-05,   1.4304147E-05
     +,   1.4908823E-05,   1.5531503E-05,   1.6172309E-05
     +,   1.6831336E-05,   1.7508644E-05,   1.8204253E-05
     +,   1.8918146E-05,   1.9650261E-05,   2.0400485E-05
     +,   2.1168655E-05,   2.1954549E-05,   2.2757902E-05
     +,   2.3578374E-05,   2.4415565E-05,   2.5268995E-05
     +,   2.6138176E-05,   2.7022439E-05,   2.7921147E-05
     +,   2.8833532E-05,   2.9758761E-05,   3.0695923E-05
     +,   3.1644020E-05,   3.2601991E-05,   3.3568675E-05
     +,   3.4542853E-05,   3.5523215E-05,   3.6508372E-05
     +,   3.7496877E-05,   3.8487189E-05,   3.9477705E-05
     +,   4.0466810E-05,   4.1452713E-05,   4.2433687E-05
     +,   4.3407894E-05,   4.4373453E-05,   4.5328474E-05
     +,   4.6271012E-05,   4.7199104E-05,   4.8110778E-05
     +,   4.9004051E-05,   4.9876940E-05,   5.0727485E-05
     +,   5.1553729E-05,   5.2353749E-05,   5.3125652E-05
     +,   5.3867625E-05,   5.4577846E-05,   5.5254633E-05
     +,   5.5896318E-05,   5.6501343E-05,   5.7068235E-05
     +,   5.7595600E-05,   5.8082176E-05,   5.8526810E-05
     +,   5.8928417E-05,   5.9286114E-05,   5.9599090E-05
     +,   5.9866674E-05,   6.0088347E-05,   6.0263705E-05
     +,   6.0392507E-05,   6.0474642E-05,   6.0510134E-05
     +,   6.0499151E-05,   6.0442009E-05,   6.0339156E-05
     +,   6.0191160E-05,   5.9998743E-05,   5.9762730E-05
     +,   5.9484089E-05,   5.9163900E-05,   5.8803325E-05
     +,   5.8403668E-05,   5.7966288E-05,   5.7492682E-05
     +,   5.6984365E-05,   5.6442983E-05,   5.5870194E-05
     +,   5.5267756E-05,   5.4637425E-05,   5.3981046E-05
     +,   5.3300450E-05,   5.2597476E-05,   5.1874013E-05
     +,   5.1131967E-05,   5.0373186E-05,   4.9599494E-05
     +,   4.8812781E-05,   4.8014801E-05,   4.7207366E-05
     +,   4.6392168E-05,   4.5570927E-05,   4.4745229E-05
     +,   4.3916698E-05,   4.3086784E-05,   4.2256986E-05
     +,   4.1428659E-05,   4.0603074E-05,   3.9781491E-05
     +,   3.8965092E-05,   3.8154933E-05,   3.7351987E-05
     +,   3.6557230E-05,   3.5771463E-05,   3.4995497E-05
     +,   3.4229990E-05,   3.3475601E-05,   3.2732834E-05
     +,   3.2002212E-05,   3.1284100E-05,   3.0578878E-05
     +,   2.9886809E-05,   2.9208079E-05,   2.8542887E-05
     +,   2.7891341E-05,   2.7253482E-05,   2.6629295E-05
     +,   2.6018779E-05,   2.5421819E-05,   2.4838333E-05
     +,   2.4268138E-05,   2.3711093E-05,   2.3166949E-05
     +,   2.2635517E-05,   2.2116523E-05,   2.1609741E-05
     +,   2.1114900E-05,   2.0631711E-05,   2.0159941E-05
     +,   1.9699357E-05,   1.9249723E-05,   1.8810842E-05
     +,   1.8382572E-05,   1.7964852E-05,   1.7557646E-05
     +,   1.7161025E-05,   1.6775210E-05,   1.6400521E-05
     +,   1.6037455E-05,   1.5686723E-05,   1.5349289E-05
     +,   1.5026361E-05,   1.4719472E-05,   1.4430557E-05
     +,   1.4161971E-05,   1.3916519E-05,   1.3697564E-05
     +,   1.3509061E-05,   1.3355635E-05,   1.3242606E-05
     +,   1.3176094E-05,   1.3163060E-05,   1.3211372E-05
     +,   1.3329883E-05,   1.3528486E-05,   1.3818183E-05
     +,   1.4211186E-05,   1.4720996E-05,   1.5362466E-05
     +,   1.6151895E-05,   1.7107199E-05,   1.8248000E-05
     +,   1.9595620E-05,   2.1173219E-05,   2.3005958E-05
     +,   2.5120948E-05,   2.7546928E-05,   3.0314553E-05
     +,   3.3455923E-05,   3.7003945E-05,   4.0991898E-05
     +,   4.5452918E-05,   5.0418887E-05,   5.5918874E-05
     +,   6.1978040E-05,   6.8616653E-05,   7.5848126E-05
     +,   8.3677085E-05,   9.2098155E-05,   1.0109547E-04
     +,   1.1064129E-04,   1.2069475E-04,   1.3120411E-04
     +,   1.4210727E-04,   1.5333325E-04,   1.6480651E-04
     +,   1.7645262E-04,   1.8820356E-04,   2.0000451E-04
     +,   2.1182331E-04,   2.2366059E-04,   2.3555919E-04
     +,   2.4761312E-04,   2.5997756E-04,   2.7287711E-04
     +,   2.8660955E-04,   3.0154607E-04,   3.1812952E-04
     +,   3.3686444E-04,   3.5829956E-04,   3.8300603E-04
     +,   4.1154961E-04,   4.4445397E-04,   4.8215836E-04
     +,   5.2497466E-04,   5.7304761E-04,   6.2631199E-04
     +,   6.8445341E-04,   7.4688619E-04,   8.1274612E-04
     +,   8.8089018E-04,   9.4990933E-04,   1.0181826E-03
     +,   1.0839244E-03,   1.1452521E-03,   1.2002736E-03
     +,   1.2471786E-03,   1.2843247E-03,   1.3103202E-03
     +,   1.3241010E-03,   1.3249920E-03,   1.3127365E-03
     +,   1.2875168E-03,   1.2499430E-03,   1.2010181E-03
     +,   1.1420841E-03,   1.0747608E-03,   1.0008508E-03
     +,   9.2226057E-04,   8.4091566E-04,   7.5867772E-04
     +,   6.7726616E-04,   5.9820549E-04,   5.2279048E-04
     +,   4.5205376E-04,   3.8675248E-04,   3.2738093E-04
     +,   2.7419033E-04,   2.2721241E-04,   1.8629082E-04
     +,   1.5112237E-04,   1.2129750E-04,   9.6329888E-05
     +,   7.5693257E-05,   5.8850364E-05,   4.5273988E-05
     +,   3.4463814E-05,   2.5959940E-05,   1.9350568E-05
     +,   1.4274668E-05,   1.0422106E-05,   7.5320245E-06
     +,   5.3890903E-06,   3.8183794E-06,   2.6800947E-06
     +,   1.8643976E-06,   1.2863555E-06,   8.8114410E-07
     +,   6.0007449E-07,   4.0710086E-07,   2.7588806E-07
     +,   1.8745401E-07,   1.2830991E-07,   8.8997751E-08
     +,   6.2967423E-08,   4.5739892E-08,   3.4292572E-08
     +,   2.6610843E-08,   2.1366350E-08,   1.7694477E-08
     +,   1.5037571E-08,   1.3040090E-08,   1.1476758E-08
     +,   1.0206007E-08,   9.1388497E-09,   8.2194251E-09
     +,   7.4121322E-09,   6.6940102E-09,   6.0496617E-09
     +,   5.4683502E-09,   4.9422604E-09,   4.4652726E-09
     +,   4.0324903E-09,   3.6396908E-09,   3.2832619E-09
     +,   2.9599247E-09,   2.6667737E-09,   2.4011262E-09
     +,   2.1605671E-09,   1.9428543E-09,   1.7459610E-09
     +,   1.5680042E-09,   1.4072818E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz115 = Yx/0.0105
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8592524E-07,   2.1151681E-07
     +,   2.4025852E-07,   2.7248342E-07,   3.0855259E-07
     +,   3.4885551E-07,   3.9381257E-07,   4.4387565E-07
     +,   4.9952786E-07,   5.6128914E-07,   6.2971105E-07
     +,   7.0538044E-07,   7.8892106E-07,   8.8099057E-07
     +,   9.8228304E-07,   1.0935282E-06,   1.2154889E-06
     +,   1.3489625E-06,   1.4947776E-06,   1.6537930E-06
     +,   1.8268950E-06,   2.0149946E-06,   2.2190209E-06
     +,   2.4399349E-06,   2.6786852E-06,   2.9362545E-06
     +,   3.2136152E-06,   3.5117359E-06,   3.8315807E-06
     +,   4.1740936E-06,   4.5401930E-06,   4.9307691E-06
     +,   5.3466651E-06,   5.7886791E-06,   6.2575464E-06
     +,   6.7539345E-06,   7.2784296E-06,   7.8315243E-06
     +,   8.4136418E-06,   9.0250369E-06,   9.6659087E-06
     +,   1.0336286E-05,   1.1036076E-05,   1.1765034E-05
     +,   1.2522753E-05,   1.3308676E-05,   1.4122060E-05
     +,   1.4962000E-05,   1.5827400E-05,   1.6716980E-05
     +,   1.7629272E-05,   1.8562621E-05,   1.9515166E-05
     +,   2.0484920E-05,   2.1469603E-05,   2.2466867E-05
     +,   2.3474122E-05,   2.4488641E-05,   2.5507530E-05
     +,   2.6527763E-05,   2.7546168E-05,   2.8559492E-05
     +,   2.9564313E-05,   3.0557199E-05,   3.1534666E-05
     +,   3.2493084E-05,   3.3428940E-05,   3.4338584E-05
     +,   3.5218509E-05,   3.6065147E-05,   3.6875113E-05
     +,   3.7644986E-05,   3.8371585E-05,   3.9051763E-05
     +,   3.9682596E-05,   4.0261340E-05,   4.0785420E-05
     +,   4.1252471E-05,   4.1660416E-05,   4.2007407E-05
     +,   4.2291842E-05,   4.2512431E-05,   4.2668144E-05
     +,   4.2758278E-05,   4.2782402E-05,   4.2740401E-05
     +,   4.2632491E-05,   4.2459145E-05,   4.2221185E-05
     +,   4.1919695E-05,   4.1556053E-05,   4.1131923E-05
     +,   4.0649236E-05,   4.0110153E-05,   3.9517057E-05
     +,   3.8872604E-05,   3.8179562E-05,   3.7440961E-05
     +,   3.6659905E-05,   3.5839708E-05,   3.4983703E-05
     +,   3.4095414E-05,   3.3178309E-05,   3.2236025E-05
     +,   3.1272109E-05,   3.0290112E-05,   2.9293622E-05
     +,   2.8286175E-05,   2.7271171E-05,   2.6251937E-05
     +,   2.5231780E-05,   2.4213763E-05,   2.3200946E-05
     +,   2.2196115E-05,   2.1202024E-05,   2.0221130E-05
     +,   1.9255849E-05,   1.8308292E-05,   1.7380497E-05
     +,   1.6474234E-05,   1.5591084E-05,   1.4732495E-05
     +,   1.3899733E-05,   1.3093822E-05,   1.2315610E-05
     +,   1.1565853E-05,   1.0845046E-05,   1.0153619E-05
     +,   9.4917714E-06,   8.8596526E-06,   8.2572078E-06
     +,   7.6843562E-06,   7.1408444E-06,   6.6264174E-06
     +,   6.1407031E-06,   5.6832932E-06,   5.2537875E-06
     +,   4.8517818E-06,   4.4768685E-06,   4.1286917E-06
     +,   3.8069950E-06,   3.5116173E-06,   3.2425207E-06
     +,   2.9998339E-06,   2.7839133E-06,   2.5953325E-06
     +,   2.4349486E-06,   2.3039477E-06,   2.2038753E-06
     +,   2.1366702E-06,   2.1047188E-06,   2.1108947E-06
     +,   2.1585872E-06,   2.2517415E-06,   2.3948944E-06
     +,   2.5931818E-06,   2.8523555E-06,   3.1788074E-06
     +,   3.5795574E-06,   4.0621803E-06,   4.6348478E-06
     +,   5.3062363E-06,   6.0853977E-06,   6.9816765E-06
     +,   8.0046420E-06,   9.1638813E-06,   1.0468716E-05
     +,   1.1928021E-05,   1.3550065E-05,   1.5342133E-05
     +,   1.7310089E-05,   1.9458073E-05,   2.1788295E-05
     +,   2.4300554E-05,   2.6991554E-05,   2.9855060E-05
     +,   3.2881308E-05,   3.6056550E-05,   3.9363040E-05
     +,   4.2779182E-05,   4.6279340E-05,   4.9833881E-05
     +,   5.3409782E-05,   5.6971461E-05,   6.0481412E-05
     +,   6.3901061E-05,   6.7192384E-05,   7.0319649E-05
     +,   7.3251089E-05,   7.5960568E-05,   7.8430458E-05
     +,   8.0653634E-05,   8.2635685E-05,   8.4397529E-05
     +,   8.5977867E-05,   8.7435212E-05,   8.8849847E-05
     +,   9.0325651E-05,   9.1991773E-05,   9.4003575E-05
     +,   9.6543379E-05,   9.9820834E-05,   1.0407317E-04
     +,   1.0956426E-04,   1.1658264E-04,   1.2544027E-04
     +,   1.3646869E-04,   1.5001293E-04,   1.6642516E-04
     +,   1.8605628E-04,   2.0924384E-04,   2.3629511E-04
     +,   2.6747037E-04,   3.0296444E-04,   3.4288241E-04
     +,   3.8721168E-04,   4.3579875E-04,   4.8832933E-04
     +,   5.4430537E-04,   6.0302368E-04,   6.6358107E-04
     +,   7.2487234E-04,   7.8560371E-04,   8.4432575E-04
     +,   8.9948316E-04,   9.4946846E-04,   9.9268812E-04
     +,   1.0276444E-03,   1.0530174E-03,   1.0677387E-03
     +,   1.0710598E-03,   1.0626081E-03,   1.0424190E-03
     +,   1.0109444E-03,   9.6904131E-04,   9.1792492E-04
     +,   8.5910718E-04,   7.9432112E-04,   7.2542601E-04
     +,   6.5430620E-04,   5.8278302E-04,   5.1253737E-04
     +,   4.4503799E-04,   3.8148899E-04,   3.2280761E-04
     +,   2.6962109E-04,   2.2227362E-04,   1.8085024E-04
     +,   1.4521871E-04,   1.1507612E-04,   8.9988513E-05
     +,   6.9439913E-05,   5.2873907E-05,   3.9726125E-05
     +,   2.9450935E-05,   2.1542506E-05,   1.5547590E-05
     +,   1.1071263E-05,   7.7783370E-06,   5.3916351E-06
     +,   3.6872025E-06,   2.4878063E-06,   1.6560307E-06
     +,   1.0875297E-06,   7.0459879E-07,   4.5035958E-07
     +,   2.8397616E-07,   1.7664875E-07,   1.0840446E-07
     +,   6.5626494E-08,   3.9191711E-08,   2.3088354E-08
     +,   1.3417702E-08,   7.6919306E-09,   4.3496140E-09
     +,   2.4262443E-09,   1.3349455E-09,   7.2451678E-10
     +,   3.8785225E-10,   2.0479929E-10,   1.0666255E-10
     +,   5.4793604E-11,   2.7762596E-11,   1.3874545E-11
     +,   6.8389044E-12,   3.3249428E-12,   1.5944422E-12
     +,   7.5415504E-13,   3.5186855E-13,   1.6194834E-13
     +,   7.3539075E-14,   3.2949829E-14,   1.4571638E-14
     +,   6.3623364E-15,   2.7442766E-15,   1.1701843E-15
     +,   4.9386642E-16,   2.0662400E-16,   8.5904712E-17
     +,   3.5606966E-17,   1.4781972E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz116 = Yx/0.00731818181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.4761931E-06,   5.8406313E-06
     +,   6.2222189E-06,   6.6211805E-06,   7.0376941E-06
     +,   7.4718823E-06,   7.9238198E-06,   8.3935201E-06
     +,   8.8809284E-06,   9.3859462E-06,   9.9083918E-06
     +,   1.0448008E-05,   1.1004474E-05,   1.1577387E-05
     +,   1.2166270E-05,   1.2770560E-05,   1.3389617E-05
     +,   1.4022718E-05,   1.4669056E-05,   1.5327738E-05
     +,   1.5997790E-05,   1.6678156E-05,   1.7367685E-05
     +,   1.8065197E-05,   1.8769346E-05,   1.9478806E-05
     +,   2.0192116E-05,   2.0907781E-05,   2.1624226E-05
     +,   2.2339827E-05,   2.3052908E-05,   2.3761746E-05
     +,   2.4464580E-05,   2.5159612E-05,   2.5845031E-05
     +,   2.6518996E-05,   2.7179660E-05,   2.7825172E-05
     +,   2.8453722E-05,   2.9063443E-05,   2.9652570E-05
     +,   3.0219328E-05,   3.0761988E-05,   3.1278883E-05
     +,   3.1768406E-05,   3.2229003E-05,   3.2659202E-05
     +,   3.3057622E-05,   3.3422966E-05,   3.3754040E-05
     +,   3.4049754E-05,   3.4309120E-05,   3.4531269E-05
     +,   3.4715471E-05,   3.4861092E-05,   3.4967637E-05
     +,   3.5034758E-05,   3.5062225E-05,   3.5049936E-05
     +,   3.4997935E-05,   3.4906403E-05,   3.4775647E-05
     +,   3.4606117E-05,   3.4398377E-05,   3.4153119E-05
     +,   3.3871180E-05,   3.3553475E-05,   3.3201082E-05
     +,   3.2815136E-05,   3.2396914E-05,   3.1947748E-05
     +,   3.1469102E-05,   3.0962467E-05,   3.0429455E-05
     +,   2.9871708E-05,   2.9290904E-05,   2.8688821E-05
     +,   2.8067258E-05,   2.7428014E-05,   2.6772901E-05
     +,   2.6103808E-05,   2.5422534E-05,   2.4730967E-05
     +,   2.4030884E-05,   2.3324141E-05,   2.2612463E-05
     +,   2.1897638E-05,   2.1181308E-05,   2.0465170E-05
     +,   1.9750789E-05,   1.9039673E-05,   1.8333314E-05
     +,   1.7633123E-05,   1.6940408E-05,   1.6256390E-05
     +,   1.5582280E-05,   1.4919128E-05,   1.4267979E-05
     +,   1.3629715E-05,   1.3005214E-05,   1.2395196E-05
     +,   1.1800371E-05,   1.1221290E-05,   1.0658503E-05
     +,   1.0112419E-05,   9.5833757E-06,   9.0716694E-06
     +,   8.5775246E-06,   8.1010594E-06,   7.6423312E-06
     +,   7.2013786E-06,   6.7781230E-06,   6.3724851E-06
     +,   5.9842810E-06,   5.6133304E-06,   5.2593591E-06
     +,   4.9220989E-06,   4.6011996E-06,   4.2963238E-06
     +,   4.0070713E-06,   3.7330174E-06,   3.4737366E-06
     +,   3.2287817E-06,   2.9976713E-06,   2.7799181E-06
     +,   2.5750426E-06,   2.3825344E-06,   2.2019042E-06
     +,   2.0326368E-06,   1.8742411E-06,   1.7262084E-06
     +,   1.5880551E-06,   1.4592860E-06,   1.3394314E-06
     +,   1.2280204E-06,   1.1245950E-06,   1.0287159E-06
     +,   9.3995999E-07,   8.5791316E-07,   7.8218005E-07
     +,   7.1239060E-07,   6.4819602E-07,   5.8926770E-07
     +,   5.3530601E-07,   4.8604926E-07,   4.4126833E-07
     +,   4.0078027E-07,   3.6445891E-07,   3.3224308E-07
     +,   3.0414964E-07,   2.8029240E-07,   2.6090586E-07
     +,   2.4636751E-07,   2.3722752E-07,   2.3424661E-07
     +,   2.3843589E-07,   2.5110225E-07,   2.7390081E-07
     +,   3.0889228E-07,   3.5859875E-07,   4.2607255E-07
     +,   5.1496062E-07,   6.2955849E-07,   7.7487300E-07
     +,   9.5668395E-07,   1.1815841E-06,   1.4569914E-06
     +,   1.7911658E-06,   2.1932269E-06,   2.6731175E-06
     +,   3.2415055E-06,   3.9097213E-06,   4.6897017E-06
     +,   5.5938285E-06,   6.6346561E-06,   7.8249113E-06
     +,   9.1772072E-06,   1.0703714E-05,   1.2415967E-05
     +,   1.4324720E-05,   1.6439590E-05,   1.8768596E-05
     +,   2.1317956E-05,   2.4091976E-05,   2.7092630E-05
     +,   3.0319075E-05,   3.3767647E-05,   3.7431982E-05
     +,   4.1302865E-05,   4.5368135E-05,   4.9613816E-05
     +,   5.4024640E-05,   5.8584792E-05,   6.3279687E-05
     +,   6.8098110E-05,   7.3034193E-05,   7.8089564E-05
     +,   8.3276442E-05,   8.8621091E-05,   9.4166644E-05
     +,   9.9976191E-05,   1.0613671E-04,   1.1276346E-04
     +,   1.2000412E-04,   1.2804290E-04,   1.3710774E-04
     +,   1.4747567E-04,   1.5947875E-04,   1.7351011E-04
     +,   1.9002942E-04,   2.0956309E-04,   2.3269923E-04
     +,   2.6007617E-04,   2.9236358E-04,   3.3022909E-04
     +,   3.7428975E-04,   4.2505743E-04,   4.8287460E-04
     +,   5.4783991E-04,   6.1972719E-04,   6.9793244E-04
     +,   7.8141887E-04,   8.6868467E-04,   9.5777621E-04
     +,   1.0463378E-03,   1.1316913E-03,   1.2109519E-03
     +,   1.2811895E-03,   1.3396061E-03,   1.3837100E-03
     +,   1.4114868E-03,   1.4215481E-03,   1.4132403E-03
     +,   1.3866912E-03,   1.3428157E-03,   1.2832503E-03
     +,   1.2102420E-03,   1.1265036E-03,   1.0350324E-03
     +,   9.3891443E-04,   8.4114989E-04,   7.4450002E-04
     +,   6.5135455E-04,   5.6363910E-04,   4.8277804E-04
     +,   4.0969704E-04,   3.4484782E-04,   2.8826392E-04
     +,   2.3964298E-04,   1.9843542E-04,   1.6391950E-04
     +,   1.3528536E-04,   1.1170171E-04,   9.2365248E-05
     +,   7.6536271E-05,   6.3562627E-05,   5.2890304E-05
     +,   4.4062122E-05,   3.6710735E-05,   3.0548243E-05
     +,   2.5353174E-05,   2.0956568E-05,   1.7229298E-05
     +,   1.4071746E-05,   1.1405381E-05,   9.1656275E-06
     +,   7.2975681E-06,   5.7530483E-06,   4.4886237E-06
     +,   3.4645877E-06,   2.6447010E-06,   1.9961274E-06
     +,   1.4893974E-06,   1.0984422E-06,   8.0063938E-07
     +,   5.7671610E-07,   4.1050274E-07,   2.8872719E-07
     +,   2.0065549E-07,   1.3778597E-07,   9.3482505E-08
     +,   6.2665904E-08,   4.1504173E-08,   2.7159365E-08
     +,   1.7559033E-08,   1.1216175E-08,   7.0785644E-09
     +,   4.4136037E-09,   2.7189542E-09,   1.6548429E-09
     +,   9.9511233E-10,   5.9119715E-10,   3.4701864E-10
     +,   2.0124162E-10,   1.1530360E-10,   6.5269797E-11
     +,   3.6504133E-11,   2.0170391E-11,   1.1011554E-11
     +,   5.9391589E-12,   3.1649182E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz117 = Yx/0.00882608695652174
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1364847E-05,   1.1692602E-05
     +,   1.2025440E-05,   1.2363383E-05,   1.2706458E-05
     +,   1.3054704E-05,   1.3408158E-05,   1.3766868E-05
     +,   1.4130876E-05,   1.4500250E-05,   1.4875041E-05
     +,   1.5255312E-05,   1.5641124E-05,   1.6032545E-05
     +,   1.6429645E-05,   1.6832486E-05,   1.7241135E-05
     +,   1.7655657E-05,   1.8076107E-05,   1.8502538E-05
     +,   1.8934999E-05,   1.9373529E-05,   1.9818142E-05
     +,   2.0268875E-05,   2.0725702E-05,   2.1188627E-05
     +,   2.1657606E-05,   2.2132586E-05,   2.2613489E-05
     +,   2.3100212E-05,   2.3592629E-05,   2.4090577E-05
     +,   2.4593874E-05,   2.5102290E-05,   2.5615580E-05
     +,   2.6133448E-05,   2.6655562E-05,   2.7181546E-05
     +,   2.7711023E-05,   2.8243496E-05,   2.8778510E-05
     +,   2.9315510E-05,   2.9853920E-05,   3.0393121E-05
     +,   3.0932431E-05,   3.1471147E-05,   3.2008516E-05
     +,   3.2543729E-05,   3.3075954E-05,   3.3604316E-05
     +,   3.4127894E-05,   3.4645738E-05,   3.5156849E-05
     +,   3.5660240E-05,   3.6154830E-05,   3.6639580E-05
     +,   3.7113386E-05,   3.7575148E-05,   3.8023736E-05
     +,   3.8458031E-05,   3.8876893E-05,   3.9279192E-05
     +,   3.9663788E-05,   4.0029568E-05,   4.0375442E-05
     +,   4.0700310E-05,   4.1003121E-05,   4.1282838E-05
     +,   4.1538478E-05,   4.1769072E-05,   4.1973730E-05
     +,   4.2151576E-05,   4.2301821E-05,   4.2423715E-05
     +,   4.2516574E-05,   4.2579792E-05,   4.2612824E-05
     +,   4.2615196E-05,   4.2586526E-05,   4.2526499E-05
     +,   4.2434895E-05,   4.2311560E-05,   4.2156444E-05
     +,   4.1969579E-05,   4.1751086E-05,   4.1501160E-05
     +,   4.1220115E-05,   4.0908308E-05,   4.0566232E-05
     +,   4.0194427E-05,   3.9793522E-05,   3.9364240E-05
     +,   3.8907390E-05,   3.8423819E-05,   3.7914466E-05
     +,   3.7380356E-05,   3.6822530E-05,   3.6242149E-05
     +,   3.5640362E-05,   3.5018438E-05,   3.4377605E-05
     +,   3.3719225E-05,   3.3044602E-05,   3.2355147E-05
     +,   3.1652242E-05,   3.0937277E-05,   3.0211697E-05
     +,   2.9476956E-05,   2.8734465E-05,   2.7985618E-05
     +,   2.7231879E-05,   2.6474600E-05,   2.5715211E-05
     +,   2.4955007E-05,   2.4195369E-05,   2.3437529E-05
     +,   2.2682792E-05,   2.1932323E-05,   2.1187325E-05
     +,   2.0448899E-05,   1.9718083E-05,   1.8995912E-05
     +,   1.8283374E-05,   1.7581338E-05,   1.6890628E-05
     +,   1.6212074E-05,   1.5546346E-05,   1.4894154E-05
     +,   1.4256057E-05,   1.3632633E-05,   1.3024318E-05
     +,   1.2431576E-05,   1.1854724E-05,   1.1294104E-05
     +,   1.0749941E-05,   1.0222409E-05,   9.7116654E-06
     +,   9.2178143E-06,   8.7408707E-06,   8.2808147E-06
     +,   7.8376070E-06,   7.4111695E-06,   7.0013493E-06
     +,   6.6079647E-06,   6.2308377E-06,   5.8697201E-06
     +,   5.5243395E-06,   5.1944230E-06,   4.8796765E-06
     +,   4.5797701E-06,   4.2943643E-06,   4.0231353E-06
     +,   3.7657614E-06,   3.5219123E-06,   3.2912815E-06
     +,   3.0736119E-06,   2.8686889E-06,   2.6763551E-06
     +,   2.4965407E-06,   2.3293087E-06,   2.1748572E-06
     +,   2.0335726E-06,   1.9060893E-06,   1.7933377E-06
     +,   1.6966002E-06,   1.6176027E-06,   1.5586088E-06
     +,   1.5225102E-06,   1.5129418E-06,   1.5344135E-06
     +,   1.5924433E-06,   1.6936957E-06,   1.8461453E-06
     +,   2.0592329E-06,   2.3439884E-06,   2.7132257E-06
     +,   3.1816696E-06,   3.7660438E-06,   4.4851836E-06
     +,   5.3601643E-06,   6.4143264E-06,   7.6732049E-06
     +,   9.1645325E-06,   1.0918296E-05,   1.2966580E-05
     +,   1.5343285E-05,   1.8084073E-05,   2.1226388E-05
     +,   2.4809213E-05,   2.8872497E-05,   3.3457774E-05
     +,   3.8607741E-05,   4.4365890E-05,   5.0776791E-05
     +,   5.7886540E-05,   6.5742657E-05,   7.4393545E-05
     +,   8.3889019E-05,   9.4281044E-05,   1.0562314E-04
     +,   1.1796941E-04,   1.3137447E-04,   1.4589385E-04
     +,   1.6158189E-04,   1.7848854E-04,   1.9666026E-04
     +,   2.1613609E-04,   2.3694315E-04,   2.5909406E-04
     +,   2.8258454E-04,   3.0738817E-04,   3.3344989E-04
     +,   3.6068365E-04,   3.8897025E-04,   4.1815254E-04
     +,   4.4803106E-04,   4.7836470E-04,   5.0887262E-04
     +,   5.3923484E-04,   5.6909159E-04,   5.9805613E-04
     +,   6.2571710E-04,   6.5164751E-04,   6.7541521E-04
     +,   6.9659745E-04,   7.1478961E-04,   7.2961778E-04
     +,   7.4075244E-04,   7.4791984E-04,   7.5091183E-04
     +,   7.4959325E-04,   7.4390910E-04,   7.3388807E-04
     +,   7.1964157E-04,   7.0136524E-04,   6.7932933E-04
     +,   6.5387407E-04,   6.2539987E-04,   5.9435616E-04
     +,   5.6122470E-04,   5.2650837E-04,   4.9071945E-04
     +,   4.5436362E-04,   4.1792481E-04,   3.8185675E-04
     +,   3.4657496E-04,   3.1244732E-04,   2.7978572E-04
     +,   2.4884604E-04,   2.1982907E-04,   1.9287562E-04
     +,   1.6807245E-04,   1.4545748E-04,   1.2502311E-04
     +,   1.0672107E-04,   9.0470348E-05,   7.6164855E-05
     +,   6.3678337E-05,   5.2870055E-05,   4.3591386E-05
     +,   3.5691268E-05,   2.9019644E-05,   2.3430621E-05
     +,   1.8785808E-05,   1.4956585E-05,   1.1824551E-05
     +,   9.2828150E-06,   7.2363105E-06,   5.6014137E-06
     +,   4.3054124E-06,   3.2859525E-06,   2.4902231E-06
     +,   1.8739031E-06,   1.4001718E-06,   1.0388053E-06
     +,   7.6526430E-07,   5.5976062E-07,   4.0654984E-07
     +,   2.9317980E-07,   2.0992810E-07,   1.4924917E-07
     +,   1.0535759E-07,   7.3844873E-08,   5.1390668E-08
     +,   3.5509526E-08,   2.4361917E-08,   1.6594994E-08
     +,   1.1223664E-08,   7.5369115E-09,   5.0250581E-09
     +,   3.3264986E-09,   2.1863489E-09,   1.4267495E-09
     +,   9.2439828E-10,   5.9465466E-10,   3.7979658E-10
     +,   2.4084082E-10,   1.5163097E-10,   9.4784597E-11
     +,   5.8825424E-11,   3.6248050E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz118 = Yx/0.007
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz1188(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8115325E-05,   1.8620714E-05
     +,   1.9135638E-05,   1.9660201E-05,   2.0194506E-05
     +,   2.0738653E-05,   2.1292750E-05,   2.1856886E-05
     +,   2.2431142E-05,   2.3015631E-05,   2.3610419E-05
     +,   2.4215580E-05,   2.4831177E-05,   2.5457268E-05
     +,   2.6093892E-05,   2.6741085E-05,   2.7398868E-05
     +,   2.8067238E-05,   2.8746184E-05,   2.9435667E-05
     +,   3.0135639E-05,   3.0846022E-05,   3.1566702E-05
     +,   3.2297594E-05,   3.3038486E-05,   3.3789245E-05
     +,   3.4549623E-05,   3.5319386E-05,   3.6098234E-05
     +,   3.6885845E-05,   3.7681857E-05,   3.8485850E-05
     +,   3.9297385E-05,   4.0115956E-05,   4.0941010E-05
     +,   4.1771960E-05,   4.2608153E-05,   4.3448883E-05
     +,   4.4293432E-05,   4.5140940E-05,   4.5990575E-05
     +,   4.6841440E-05,   4.7692527E-05,   4.8542835E-05
     +,   4.9391285E-05,   5.0236715E-05,   5.1077979E-05
     +,   5.1913801E-05,   5.2742929E-05,   5.3564007E-05
     +,   5.4375687E-05,   5.5176526E-05,   5.5965080E-05
     +,   5.6739904E-05,   5.7499423E-05,   5.8242149E-05
     +,   5.8966518E-05,   5.9670954E-05,   6.0353901E-05
     +,   6.1013765E-05,   6.1649000E-05,   6.2258048E-05
     +,   6.2839361E-05,   6.3391424E-05,   6.3912819E-05
     +,   6.4402047E-05,   6.4857799E-05,   6.5278684E-05
     +,   6.5663487E-05,   6.6011002E-05,   6.6320121E-05
     +,   6.6589855E-05,   6.6819252E-05,   6.7007481E-05
     +,   6.7153844E-05,   6.7257752E-05,   6.7318681E-05
     +,   6.7336296E-05,   6.7310364E-05,   6.7240777E-05
     +,   6.7127585E-05,   6.6970955E-05,   6.6771208E-05
     +,   6.6528795E-05,   6.6244349E-05,   6.5918583E-05
     +,   6.5552420E-05,   6.5146880E-05,   6.4703148E-05
     +,   6.4222535E-05,   6.3706466E-05,   6.3156527E-05
     +,   6.2574465E-05,   6.1962062E-05,   6.1321247E-05
     +,   6.0654096E-05,   5.9962724E-05,   5.9249403E-05
     +,   5.8516420E-05,   5.7766225E-05,   5.7001227E-05
     +,   5.6223998E-05,   5.5437085E-05,   5.4643133E-05
     +,   5.3844764E-05,   5.3044612E-05,   5.2245392E-05
     +,   5.1449770E-05,   5.0660394E-05,   4.9879865E-05
     +,   4.9110833E-05,   4.8355814E-05,   4.7617352E-05
     +,   4.6897825E-05,   4.6199657E-05,   4.5525074E-05
     +,   4.4876291E-05,   4.4255339E-05,   4.3664222E-05
     +,   4.3104748E-05,   4.2578591E-05,   4.2087326E-05
     +,   4.1632349E-05,   4.1214895E-05,   4.0835996E-05
     +,   4.0496558E-05,   4.0197254E-05,   3.9938583E-05
     +,   3.9720839E-05,   3.9544106E-05,   3.9408234E-05
     +,   3.9312890E-05,   3.9257484E-05,   3.9241211E-05
     +,   3.9263046E-05,   3.9321720E-05,   3.9415761E-05
     +,   3.9543444E-05,   3.9702842E-05,   3.9891831E-05
     +,   4.0108069E-05,   4.0348994E-05,   4.0611922E-05
     +,   4.0894000E-05,   4.1192190E-05,   4.1503394E-05
     +,   4.1824409E-05,   4.2151954E-05,   4.2482741E-05
     +,   4.2813474E-05,   4.3140950E-05,   4.3462023E-05
     +,   4.3773674E-05,   4.4073131E-05,   4.4357832E-05
     +,   4.4625540E-05,   4.4874330E-05,   4.5102741E-05
     +,   4.5309793E-05,   4.5495013E-05,   4.5658577E-05
     +,   4.5801287E-05,   4.5924688E-05,   4.6031077E-05
     +,   4.6123609E-05,   4.6206267E-05,   4.6283982E-05
     +,   4.6362595E-05,   4.6448928E-05,   4.6550787E-05
     +,   4.6676960E-05,   4.6837209E-05,   4.7042311E-05
     +,   4.7303998E-05,   4.7634949E-05,   4.8048791E-05
     +,   4.8560069E-05,   4.9184218E-05,   4.9937542E-05
     +,   5.0837276E-05,   5.1901592E-05,   5.3149513E-05
     +,   5.4601074E-05,   5.6277444E-05,   5.8200982E-05
     +,   6.0395265E-05,   6.2885250E-05,   6.5697670E-05
     +,   6.8861096E-05,   7.2405797E-05,   7.6364471E-05
     +,   8.0772246E-05,   8.5666339E-05,   9.1086542E-05
     +,   9.7075383E-05,   1.0367789E-04,   1.1094080E-04
     +,   1.1891253E-04,   1.2764317E-04,   1.3718331E-04
     +,   1.4758244E-04,   1.5888822E-04,   1.7114586E-04
     +,   1.8439602E-04,   1.9867145E-04,   2.1399777E-04
     +,   2.3039010E-04,   2.4784973E-04,   2.6636294E-04
     +,   2.8590008E-04,   3.0641252E-04,   3.2782959E-04
     +,   3.5005828E-04,   3.7298354E-04,   3.9646696E-04
     +,   4.2034456E-04,   4.4442929E-04,   4.6851419E-04
     +,   4.9237284E-04,   5.1575928E-04,   5.3841708E-04
     +,   5.6008063E-04,   5.8047887E-04,   5.9934141E-04
     +,   6.1640609E-04,   6.3142285E-04,   6.4415846E-04
     +,   6.5440388E-04,   6.6197949E-04,   6.6673954E-04
     +,   6.6857494E-04,   6.6741835E-04,   6.6324539E-04
     +,   6.5607554E-04,   6.4597372E-04,   6.3304720E-04
     +,   6.1744428E-04,   5.9935177E-04,   5.7899085E-04
     +,   5.5661052E-04,   5.3248269E-04,   5.0689798E-04
     +,   4.8015825E-04,   4.5256858E-04,   4.2443178E-04
     +,   3.9604562E-04,   3.6769468E-04,   3.3964386E-04
     +,   3.1213631E-04,   2.8539274E-04,   2.5960346E-04
     +,   2.3492977E-04,   2.1150454E-04,   1.8943074E-04
     +,   1.6878048E-04,   1.4959853E-04,   1.3190511E-04
     +,   1.1569684E-04,   1.0094852E-04,   8.7617351E-05
     +,   7.5646560E-05,   6.4967295E-05,   5.5500968E-05
     +,   4.7162874E-05,   3.9865263E-05,   3.3517968E-05
     +,   2.8031300E-05,   2.3317954E-05,   1.9293842E-05
     +,   1.5878983E-05,   1.2998592E-05,   1.0583752E-05
     +,   8.5714282E-06,   6.9044845E-06,   5.5318274E-06
     +,   4.4082790E-06,   3.4940085E-06,   2.7544695E-06
     +,   2.1597446E-06,   1.6843111E-06,   1.3064383E-06
     +,   1.0078779E-06,   7.7334010E-07,   5.9017771E-07
     +,   4.4795655E-07,   3.3817130E-07,   2.5391040E-07
     +,   1.8961050E-07,   1.4082840E-07,   1.0402923E-07
     +,   7.6430467E-08,   5.5849000E-08,   4.0589327E-08
     +,   2.9339187E-08,   2.1092854E-08,   1.5082286E-08
     +,   1.0726467E-08,   7.5875075E-09,   5.3383915E-09
     +,   3.7358472E-09,   2.6004905E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz1188 = Yx/0.00827272727272727
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3475237E-07,   1.5053703E-07
     +,   1.6796575E-07,   1.8718413E-07,   2.0834773E-07
     +,   2.3162241E-07,   2.5718452E-07,   2.8522152E-07
     +,   3.1593149E-07,   3.4952524E-07,   3.8622406E-07
     +,   4.2626129E-07,   4.6988220E-07,   5.1734412E-07
     +,   5.6891588E-07,   6.2487862E-07,   6.8552453E-07
     +,   7.5115770E-07,   8.2209277E-07,   8.9865574E-07
     +,   9.8118187E-07,   1.0700161E-06,   1.1655113E-06
     +,   1.2680334E-06,   1.3779455E-06,   1.4956275E-06
     +,   1.6214576E-06,   1.7558189E-06,   1.8990971E-06
     +,   2.0516795E-06,   2.2139518E-06,   2.3862979E-06
     +,   2.5690968E-06,   2.7627227E-06,   2.9675423E-06
     +,   3.1839104E-06,   3.4121729E-06,   3.6526551E-06
     +,   3.9056854E-06,   4.1715430E-06,   4.4505173E-06
     +,   4.7428571E-06,   5.0487934E-06,   5.3685289E-06
     +,   5.7022366E-06,   6.0500606E-06,   6.4121118E-06
     +,   6.7884639E-06,   7.1791587E-06,   7.5841963E-06
     +,   8.0035388E-06,   8.4371059E-06,   8.8847692E-06
     +,   9.3463859E-06,   9.8217151E-06,   1.0310522E-05
     +,   1.0812500E-05,   1.1327302E-05,   1.1854533E-05
     +,   1.2393753E-05,   1.2944472E-05,   1.3506170E-05
     +,   1.4078236E-05,   1.4660071E-05,   1.5251021E-05
     +,   1.5850343E-05,   1.6457319E-05,   1.7071132E-05
     +,   1.7690983E-05,   1.8315975E-05,   1.8945257E-05
     +,   1.9577856E-05,   2.0212861E-05,   2.0849257E-05
     +,   2.1486057E-05,   2.2122271E-05,   2.2756836E-05
     +,   2.3388693E-05,   2.4016803E-05,   2.4640136E-05
     +,   2.5257588E-05,   2.5868152E-05,   2.6470745E-05
     +,   2.7064378E-05,   2.7648002E-05,   2.8220664E-05
     +,   2.8781380E-05,   2.9329254E-05,   2.9863368E-05
     +,   3.0382900E-05,   3.0887069E-05,   3.1375122E-05
     +,   3.1846372E-05,   3.2300210E-05,   3.2736116E-05
     +,   3.3153585E-05,   3.3552253E-05,   3.3931785E-05
     +,   3.4291988E-05,   3.4632700E-05,   3.4953908E-05
     +,   3.5255653E-05,   3.5538113E-05,   3.5801520E-05
     +,   3.6046262E-05,   3.6272791E-05,   3.6481681E-05
     +,   3.6673599E-05,   3.6849309E-05,   3.7009700E-05
     +,   3.7155725E-05,   3.7288472E-05,   3.7409067E-05
     +,   3.7518770E-05,   3.7618891E-05,   3.7710841E-05
     +,   3.7796086E-05,   3.7876151E-05,   3.7952632E-05
     +,   3.8027167E-05,   3.8101429E-05,   3.8177132E-05
     +,   3.8256003E-05,   3.8339778E-05,   3.8430226E-05
     +,   3.8529070E-05,   3.8638042E-05,   3.8758830E-05
     +,   3.8893086E-05,   3.9042403E-05,   3.9208320E-05
     +,   3.9392271E-05,   3.9595630E-05,   3.9819621E-05
     +,   4.0065373E-05,   4.0333896E-05,   4.0626001E-05
     +,   4.0942366E-05,   4.1283474E-05,   4.1649666E-05
     +,   4.2041014E-05,   4.2457417E-05,   4.2898570E-05
     +,   4.3363969E-05,   4.3852837E-05,   4.4364253E-05
     +,   4.4897115E-05,   4.5450088E-05,   4.6021702E-05
     +,   4.6610410E-05,   4.7214558E-05,   4.7832436E-05
     +,   4.8462342E-05,   4.9102637E-05,   4.9751838E-05
     +,   5.0408540E-05,   5.1071598E-05,   5.1740160E-05
     +,   5.2413681E-05,   5.3091921E-05,   5.3775053E-05
     +,   5.4463639E-05,   5.5158551E-05,   5.5861005E-05
     +,   5.6572517E-05,   5.7294819E-05,   5.8029709E-05
     +,   5.8778980E-05,   5.9544309E-05,   6.0327133E-05
     +,   6.1128434E-05,   6.1948653E-05,   6.2787687E-05
     +,   6.3644729E-05,   6.4518215E-05,   6.5405999E-05
     +,   6.6305460E-05,   6.7213587E-05,   6.8127352E-05
     +,   6.9044203E-05,   6.9962451E-05,   7.0881717E-05
     +,   7.1803697E-05,   7.2732713E-05,   7.3676383E-05
     +,   7.4645955E-05,   7.5656928E-05,   7.6729215E-05
     +,   7.7887278E-05,   7.9159727E-05,   8.0578968E-05
     +,   8.2180348E-05,   8.4001047E-05,   8.6078668E-05
     +,   8.8450077E-05,   9.1149785E-05,   9.4208452E-05
     +,   9.7652177E-05,   1.0150232E-04,   1.0577589E-04
     +,   1.1048689E-04,   1.1564920E-04,   1.2128126E-04
     +,   1.2741133E-04,   1.3408356E-04,   1.4136703E-04
     +,   1.4936351E-04,   1.5821494E-04,   1.6811103E-04
     +,   1.7929502E-04,   1.9206567E-04,   2.0677404E-04
     +,   2.2381722E-04,   2.4362587E-04,   2.6664400E-04
     +,   2.9330020E-04,   3.2397517E-04,   3.5896519E-04
     +,   3.9843831E-04,   4.4238631E-04,   4.9059140E-04
     +,   5.4258772E-04,   5.9763348E-04,   6.5470452E-04
     +,   7.1250787E-04,   7.6950772E-04,   8.2397531E-04
     +,   8.7406626E-04,   9.1791543E-04,   9.5373782E-04
     +,   9.7993540E-04,   9.9520595E-04,   9.9863613E-04
     +,   9.8976807E-04,   9.6864271E-04,   9.3580619E-04
     +,   8.9228014E-04,   8.3950523E-04,   7.7925058E-04
     +,   7.1349985E-04,   6.4433552E-04,   5.7382486E-04
     +,   5.0390651E-04,   4.3629477E-04,   3.7241663E-04
     +,   3.1337558E-04,   2.5993263E-04,   2.1251342E-04
     +,   1.7124364E-04,   1.3599703E-04,   1.0644097E-04
     +,   8.2097802E-05,   6.2400082E-05,   4.6736935E-05
     +,   3.4493754E-05,   2.5084777E-05,   1.7974795E-05
     +,   1.2691069E-05,   8.8287834E-06,   6.0514581E-06
     +,   4.0867244E-06,   2.7192470E-06,   1.7826715E-06
     +,   1.1514237E-06,   7.3274487E-07,   4.5943059E-07
     +,   2.8381430E-07,   1.7274722E-07,   1.0360276E-07
     +,   6.1225201E-08,   3.5654431E-08,   2.0463485E-08
     +,   1.1577487E-08,   6.4584662E-09,   3.5538466E-09
     +,   1.9302855E-09,   1.0358994E-09,   5.5015092E-10
     +,   2.8983013E-10,   1.5202654E-10,   7.9831905E-11
     +,   4.2300247E-11,   2.2852600E-11,   1.2744892E-11
     +,   7.4262671E-12,   4.5590190E-12,   2.9534662E-12
     +,   2.0080936E-12,   1.4188264E-12,   1.0304266E-12
     +,   7.6199686E-13,   5.6971122E-13,   4.2858328E-13
     +,   3.2340149E-13,   2.4432016E-13,   1.8458058E-13
     +,   1.3936131E-13,   1.0511224E-13,   7.9182287E-14
     +,   5.9567063E-14,   4.4746389E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz120 = Yx/0.00731818181818182
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0871107E-09,   6.7061614E-09
     +,   8.8047907E-09,   1.1513520E-08,   1.4994885E-08
     +,   1.9450287E-08,   2.5128035E-08,   3.2332689E-08
     +,   4.1435779E-08,   5.2888879E-08,   6.7236840E-08
     +,   8.5134303E-08,   1.0736354E-07,   1.3485418E-07
     +,   1.6870474E-07,   2.1020603E-07,   2.6086630E-07
     +,   3.2243679E-07,   3.9694044E-07,   4.8669727E-07
     +,   5.9435365E-07,   7.2290760E-07,   8.7573045E-07
     +,   1.0566026E-06,   1.2697000E-06,   1.5196478E-06
     +,   1.8114928E-06,   2.1507176E-06,   2.5432294E-06
     +,   2.9953380E-06,   3.5137293E-06,   4.1054259E-06
     +,   4.7777385E-06,   5.5382029E-06,   6.3945163E-06
     +,   7.3544657E-06,   8.4258418E-06,   9.6163485E-06
     +,   1.0933621E-05,   1.2384921E-05,   1.3977383E-05
     +,   1.5717706E-05,   1.7612243E-05,   1.9666943E-05
     +,   2.1887357E-05,   2.4278655E-05,   2.6845639E-05
     +,   2.9592798E-05,   3.2524342E-05,   3.5644214E-05
     +,   3.8956136E-05,   4.2463595E-05,   4.6169709E-05
     +,   5.0077437E-05,   5.4188764E-05,   5.8505313E-05
     +,   6.3027408E-05,   6.7754016E-05,   7.2682291E-05
     +,   7.7807206E-05,   8.3121144E-05,   8.8613604E-05
     +,   9.4270530E-05,   1.0007493E-04,   1.0600648E-04
     +,   1.1204110E-04,   1.1815277E-04,   1.2431252E-04
     +,   1.3049082E-04,   1.3665704E-04,   1.4278194E-04
     +,   1.4883745E-04,   1.5479933E-04,   1.6064665E-04
     +,   1.6636455E-04,   1.7194446E-04,   1.7738515E-04
     +,   1.8269426E-04,   1.8789028E-04,   1.9300387E-04
     +,   1.9807971E-04,   2.0318007E-04,   2.0838626E-04
     +,   2.1380266E-04,   2.1955733E-04,   2.2580494E-04
     +,   2.3272446E-04,   2.4051846E-04,   2.4940562E-04
     +,   2.5961429E-04,   2.7137011E-04,   2.8488087E-04
     +,   3.0032001E-04,   3.1781042E-04,   3.3740536E-04
     +,   3.5907098E-04,   3.8267748E-04,   4.0798596E-04
     +,   4.3465395E-04,   4.6223463E-04,   4.9019977E-04
     +,   5.1795680E-04,   5.4488896E-04,   5.7038822E-04
     +,   5.9390877E-04,   6.1501219E-04,   6.3341926E-04
     +,   6.4905686E-04,   6.6210091E-04,   6.7300233E-04
     +,   6.8249286E-04,   6.9157052E-04,   7.0144096E-04
     +,   7.1342994E-04,   7.2885375E-04,   7.4886595E-04
     +,   7.7429309E-04,   8.0549734E-04,   8.4227417E-04
     +,   8.8383543E-04,   9.2886941E-04,   9.7567518E-04
     +,   1.0223638E-03,   1.0670770E-03,   1.1081792E-03
     +,   1.1443960E-03,   1.1748853E-03,   1.1992187E-03
     +,   1.2173165E-03,   1.2293323E-03,   1.2355356E-03
     +,   1.2362001E-03,   1.2315187E-03,   1.2215546E-03
     +,   1.2062225E-03,   1.1853131E-03,   1.1585562E-03
     +,   1.1257136E-03,   1.0866902E-03,   1.0416475E-03
     +,   9.9109451E-04,   9.3592505E-04,   8.7738427E-04
     +,   8.1698236E-04,   7.5635570E-04,   6.9708430E-04
     +,   6.4053672E-04,   5.8774848E-04,   5.3935166E-04
     +,   4.9556972E-04,   4.5627879E-04,   4.2110437E-04
     +,   3.8953268E-04,   3.6101526E-04,   3.3505750E-04
     +,   3.1127347E-04,   2.8940465E-04,   2.6931209E-04
     +,   2.5095188E-04,   2.3434123E-04,   2.1951873E-04
     +,   2.0651545E-04,   1.9533378E-04,   1.8593407E-04
     +,   1.7823130E-04,   1.7209904E-04,   1.6737795E-04
     +,   1.6388540E-04,   1.6142572E-04,   1.5980034E-04
     +,   1.5881583E-04,   1.5829007E-04,   1.5805654E-04
     +,   1.5796753E-04,   1.5789541E-04,   1.5773329E-04
     +,   1.5739445E-04,   1.5681150E-04,   1.5593502E-04
     +,   1.5473185E-04,   1.5318303E-04,   1.5128226E-04
     +,   1.4903377E-04,   1.4645020E-04,   1.4355096E-04
     +,   1.4036091E-04,   1.3690858E-04,   1.3322472E-04
     +,   1.2934125E-04,   1.2529088E-04,   1.2110543E-04
     +,   1.1681561E-04,   1.1245082E-04,   1.0803853E-04
     +,   1.0360373E-04,   9.9169010E-05,   9.4754883E-05
     +,   9.0379421E-05,   8.6058128E-05,   8.1804232E-05
     +,   7.7629258E-05,   7.3542848E-05,   6.9552727E-05
     +,   6.5665205E-05,   6.1885767E-05,   5.8218473E-05
     +,   5.4666591E-05,   5.1232946E-05,   4.7919835E-05
     +,   4.4728880E-05,   4.1661409E-05,   3.8718630E-05
     +,   3.5901521E-05,   3.3210585E-05,   3.0646104E-05
     +,   2.8208249E-05,   2.5896854E-05,   2.3711271E-05
     +,   2.1650498E-05,   1.9713318E-05,   1.7897888E-05
     +,   1.6201957E-05,   1.4622942E-05,   1.3157810E-05
     +,   1.1803016E-05,   1.0554642E-05,   9.4085099E-06
     +,   8.3601162E-06,   7.4046397E-06,   6.5370650E-06
     +,   5.7522925E-06,   5.0451258E-06,   4.4102894E-06
     +,   3.8425378E-06,   3.3367558E-06,   2.8878828E-06
     +,   2.4910271E-06,   2.1415112E-06,   1.8348718E-06
     +,   1.5668619E-06,   1.3334979E-06,   1.1310765E-06
     +,   9.5616303E-07,   8.0558209E-07,   6.7643055E-07
     +,   5.6607644E-07,   4.7213715E-07,   3.9246464E-07
     +,   3.2513978E-07,   2.6846195E-07,   2.2092054E-07
     +,   1.8118737E-07,   1.4810217E-07,   1.2065340E-07
     +,   9.7962527E-08,   7.9271942E-08,   6.3932376E-08
     +,   5.1388657E-08,   4.1167606E-08,   3.2868630E-08
     +,   2.6154618E-08,   2.0742357E-08,   1.6394839E-08
     +,   1.2914897E-08,   1.0139469E-08,   7.9336901E-09
     +,   6.1868075E-09,   4.8082942E-09,   3.7243533E-09
     +,   2.8750164E-09,   2.2118454E-09,   1.6958847E-09
     +,   1.2958850E-09,   9.8686836E-10,   7.4897982E-10
     +,   5.6650534E-10,   4.2702272E-10,   3.2078742E-10
     +,   2.4015584E-10,   1.7917783E-10,   1.3322350E-10
     +,   9.8716181E-11,   7.2894912E-11,   5.3643034E-11
     +,   3.9339285E-11,   2.8750330E-11,   2.0939068E-11
     +,   1.5197151E-11,   1.0991713E-11,   7.9223789E-12
     +,   5.6903657E-12,   4.0729421E-12,   2.9051429E-12
     +,   2.0649372E-12,   1.4626277E-12,   1.0323752E-12
     +,   7.2614918E-13,   5.0896602E-13,   3.5549485E-13
     +,   2.4742754E-13,   1.7161026E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz75 = Yx/0.0147777777777778
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7331537E-05,   1.7287985E-05
     +,   1.7223663E-05,   1.7138806E-05,   1.7033715E-05
     +,   1.6908773E-05,   1.6764423E-05,   1.6601185E-05
     +,   1.6419635E-05,   1.6220407E-05,   1.6004198E-05
     +,   1.5771757E-05,   1.5523879E-05,   1.5261407E-05
     +,   1.4985215E-05,   1.4696223E-05,   1.4395372E-05
     +,   1.4083635E-05,   1.3761998E-05,   1.3431468E-05
     +,   1.3093058E-05,   1.2747792E-05,   1.2396698E-05
     +,   1.2040783E-05,   1.1681080E-05,   1.1318582E-05
     +,   1.0954280E-05,   1.0589154E-05,   1.0224163E-05
     +,   9.8602413E-06,   9.4983125E-06,   9.1392676E-06
     +,   8.7839835E-06,   8.4333133E-06,   8.0880900E-06
     +,   7.7491322E-06,   7.4172403E-06,   7.0932101E-06
     +,   6.7778110E-06,   6.4718429E-06,   6.1760775E-06
     +,   5.8913147E-06,   5.6183658E-06,   5.3580684E-06
     +,   5.1112925E-06,   4.8789479E-06,   4.6619975E-06
     +,   4.4614644E-06,   4.2784391E-06,   4.1140938E-06
     +,   3.9696897E-06,   3.8465869E-06,   3.7462560E-06
     +,   3.6702777E-06,   3.6203712E-06,   3.5983787E-06
     +,   3.6062884E-06,   3.6462343E-06,   3.7205023E-06
     +,   3.8315311E-06,   3.9819174E-06,   4.1744179E-06
     +,   4.4119261E-06,   4.6974997E-06,   5.0343438E-06
     +,   5.4257530E-06,   5.8751857E-06,   6.3861303E-06
     +,   6.9622033E-06,   7.6069787E-06,   8.3241021E-06
     +,   9.1170714E-06,   9.9893696E-06,   1.0944193E-05
     +,   1.1984566E-05,   1.3113186E-05,   1.4332243E-05
     +,   1.5643387E-05,   1.7047698E-05,   1.8545496E-05
     +,   2.0136067E-05,   2.1817883E-05,   2.3588051E-05
     +,   2.5442649E-05,   2.7376151E-05,   2.9381790E-05
     +,   3.1451007E-05,   3.3573910E-05,   3.5738696E-05
     +,   3.7932186E-05,   4.0139650E-05,   4.2344800E-05
     +,   4.4530061E-05,   4.6677029E-05,   4.8766560E-05
     +,   5.0779072E-05,   5.2695432E-05,   5.4497159E-05
     +,   5.6167682E-05,   5.7692774E-05,   5.9062189E-05
     +,   6.0270540E-05,   6.1319210E-05,   6.2217812E-05
     +,   6.2986343E-05,   6.3657084E-05,   6.4276777E-05
     +,   6.4908651E-05,   6.5634369E-05,   6.6555469E-05
     +,   6.7794288E-05,   6.9494381E-05,   7.1819763E-05
     +,   7.4953859E-05,   7.9096702E-05,   8.4462867E-05
     +,   9.1277230E-05,   9.9773628E-05,   1.1019086E-04
     +,   1.2277416E-04,   1.3777650E-04,   1.5546153E-04
     +,   1.7611108E-04,   2.0003498E-04,   2.2757937E-04
     +,   2.5912895E-04,   2.9511360E-04,   3.3598777E-04
     +,   3.8221167E-04,   4.3419065E-04,   4.9221399E-04
     +,   5.5634580E-04,   6.2632968E-04,   7.0146378E-04
     +,   7.8052649E-04,   8.6172961E-04,   9.4274257E-04
     +,   1.0208142E-03,   1.0929859E-03,   1.1563660E-03
     +,   1.2084428E-03,   1.2473946E-03,   1.2723227E-03
     +,   1.2833597E-03,   1.2816379E-03,   1.2691065E-03
     +,   1.2482279E-03,   1.2216130E-03,   1.1916546E-03
     +,   1.1602228E-03,   1.1284774E-03,   1.0968203E-03
     +,   1.0649763E-03,   1.0321822E-03,   9.9744101E-04
     +,   9.5979049E-04,   9.1853249E-04,   8.7339105E-04
     +,   8.2458713E-04,   7.7282416E-04,   7.1918278E-04
     +,   6.6497672E-04,   6.1158719E-04,   5.6029932E-04
     +,   5.1216944E-04,   4.6795036E-04,   4.2806574E-04
     +,   3.9262624E-04,   3.6148197E-04,   3.3429923E-04
     +,   3.1063979E-04,   2.9002834E-04,   2.7200437E-04
     +,   2.5615815E-04,   2.4214727E-04,   2.2969474E-04
     +,   2.1858214E-04,   2.0863710E-04,   1.9971860E-04
     +,   1.9170433E-04,   1.8448262E-04,   1.7794700E-04
     +,   1.7199310E-04,   1.6651732E-04,   1.6141823E-04
     +,   1.5659814E-04,   1.5196446E-04,   1.4743129E-04
     +,   1.4292140E-04,   1.3836825E-04,   1.3371631E-04
     +,   1.2892253E-04,   1.2395732E-04,   1.1880435E-04
     +,   1.1346007E-04,   1.0793330E-04,   1.0224438E-04
     +,   9.6423406E-05,   9.0507943E-05,   8.4541411E-05
     +,   7.8571327E-05,   7.2646872E-05,   6.6816501E-05
     +,   6.1126528E-05,   5.5620258E-05,   5.0335606E-05
     +,   4.5304801E-05,   4.0554187E-05,   3.6103575E-05
     +,   3.1966003E-05,   2.8148368E-05,   2.4652072E-05
     +,   2.1473321E-05,   1.8603652E-05,   1.6030912E-05
     +,   1.3740139E-05,   1.1714115E-05,   9.9339259E-06
     +,   8.3797731E-06,   7.0316464E-06,   5.8694959E-06
     +,   4.8738029E-06,   4.0259424E-06,   3.3083229E-06
     +,   2.7045235E-06,   2.1994649E-06,   1.7794762E-06
     +,   1.4322592E-06,   1.1468408E-06,   9.1355429E-07
     +,   7.2396534E-07,   5.7076358E-07,   4.4765622E-07
     +,   3.4928306E-07,   2.7111855E-07,   2.0935505E-07
     +,   1.6082097E-07,   1.2289570E-07,   9.3425506E-08
     +,   7.0651431E-08,   5.3148902E-08,   3.9772658E-08
     +,   2.9606799E-08,   2.1923270E-08,   1.6147933E-08
     +,   1.1831101E-08,   8.6224290E-09,   6.2505814E-09
     +,   4.5070006E-09,   3.2324745E-09,   2.3059665E-09
     +,   1.6361803E-09,   1.1547007E-09,   8.1052809E-10
     +,   5.6586952E-10,   3.9292072E-10,   2.7135194E-10
     +,   1.8638117E-10,   1.2732154E-10,   8.6501251E-11
     +,   5.8447303E-11,   3.9276173E-11,   2.6248642E-11
     +,   1.7445660E-11,   1.1531329E-11,   7.5800356E-12
     +,   4.9551257E-12,   3.2212987E-12,   2.0825835E-12
     +,   1.3389415E-12,   8.5604456E-13,   5.4426640E-13
     +,   3.4411935E-13,   2.1636165E-13,   1.3527463E-13
     +,   8.4105859E-14,   5.1998997E-14,   3.1969300E-14
     +,   1.9544521E-14,   1.1881812E-14,   7.1827191E-15
     +,   4.3177407E-15,   2.5808852E-15,   1.5340465E-15
     +,   9.0666989E-16,   5.3286112E-16,   3.1140391E-16
     +,   1.8095452E-16,   1.0456014E-16,   6.0075130E-17
     +,   3.4321960E-17,   1.9497463E-17,   1.1013674E-17
     +,   6.1860317E-18,   3.4549219E-18,   1.9186163E-18
     +,   1.0594512E-18,   5.8170127E-19,   3.1758302E-19
     +,   1.7240053E-19,   9.3059357E-20
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz80 = Yx/0.0110833333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5486974E-05,   3.5406065E-05
     +,   3.5286230E-05,   3.5128582E-05,   3.4934405E-05
     +,   3.4705150E-05,   3.4442393E-05,   3.4147863E-05
     +,   3.3823417E-05,   3.3471013E-05,   3.3092725E-05
     +,   3.2690710E-05,   3.2267206E-05,   3.1824497E-05
     +,   3.1364947E-05,   3.0890937E-05,   3.0404863E-05
     +,   2.9909148E-05,   2.9406208E-05,   2.8898437E-05
     +,   2.8388213E-05,   2.7877864E-05,   2.7369688E-05
     +,   2.6865901E-05,   2.6368696E-05,   2.5880145E-05
     +,   2.5402276E-05,   2.4937022E-05,   2.4486229E-05
     +,   2.4051658E-05,   2.3634968E-05,   2.3237732E-05
     +,   2.2861417E-05,   2.2507409E-05,   2.2177001E-05
     +,   2.1871387E-05,   2.1591675E-05,   2.1338908E-05
     +,   2.1114023E-05,   2.0917912E-05,   2.0751373E-05
     +,   2.0615162E-05,   2.0509959E-05,   2.0436410E-05
     +,   2.0395108E-05,   2.0386604E-05,   2.0411424E-05
     +,   2.0470048E-05,   2.0562957E-05,   2.0690593E-05
     +,   2.0853393E-05,   2.1051779E-05,   2.1286167E-05
     +,   2.1556982E-05,   2.1864607E-05,   2.2209473E-05
     +,   2.2591985E-05,   2.3012552E-05,   2.3471579E-05
     +,   2.3969491E-05,   2.4506708E-05,   2.5083662E-05
     +,   2.5700756E-05,   2.6358448E-05,   2.7057222E-05
     +,   2.7797503E-05,   2.8579831E-05,   2.9404686E-05
     +,   3.0272691E-05,   3.1184409E-05,   3.2140586E-05
     +,   3.3141932E-05,   3.4189368E-05,   3.5283796E-05
     +,   3.6426354E-05,   3.7618312E-05,   3.8861031E-05
     +,   4.0156003E-05,   4.1504984E-05,   4.2909876E-05
     +,   4.4372584E-05,   4.5895336E-05,   4.7480225E-05
     +,   4.9129601E-05,   5.0845567E-05,   5.2630367E-05
     +,   5.4485838E-05,   5.6413803E-05,   5.8415484E-05
     +,   6.0491875E-05,   6.2643398E-05,   6.4869841E-05
     +,   6.7170258E-05,   6.9543239E-05,   7.1986760E-05
     +,   7.4497962E-05,   7.7073848E-05,   7.9710800E-05
     +,   8.2405510E-05,   8.5154512E-05,   8.7955232E-05
     +,   9.0805595E-05,   9.3705188E-05,   9.6654774E-05
     +,   9.9657329E-05,   1.0271796E-04,   1.0584389E-04
     +,   1.0904453E-04,   1.1233157E-04,   1.1571833E-04
     +,   1.1921873E-04,   1.2284717E-04,   1.2661648E-04
     +,   1.3053737E-04,   1.3461587E-04,   1.3885263E-04
     +,   1.4324002E-04,   1.4776162E-04,   1.5238962E-04
     +,   1.5708490E-04,   1.6179623E-04,   1.6646049E-04
     +,   1.7100478E-04,   1.7534956E-04,   1.7941276E-04
     +,   1.8311555E-04,   1.8639068E-04,   1.8919038E-04
     +,   1.9149762E-04,   1.9333583E-04,   1.9478145E-04
     +,   1.9597377E-04,   1.9712577E-04,   1.9853258E-04
     +,   2.0057907E-04,   2.0374444E-04,   2.0860528E-04
     +,   2.1583519E-04,   2.2620267E-04,   2.4056449E-04
     +,   2.5985250E-04,   2.8505415E-04,   3.1718600E-04
     +,   3.5725161E-04,   4.0618127E-04,   4.6476975E-04
     +,   5.3359056E-04,   6.1289896E-04,   7.0254283E-04
     +,   8.0188736E-04,   9.0975140E-04,   1.0243695E-03
     +,   1.1434180E-03,   1.2640816E-03,   1.3831547E-03
     +,   1.4971804E-03,   1.6026325E-03,   1.6961071E-03
     +,   1.7744962E-03,   1.8351490E-03,   1.8760241E-03
     +,   1.8957842E-03,   1.8938616E-03,   1.8704893E-03
     +,   1.8266808E-03,   1.7641733E-03,   1.6853327E-03
     +,   1.5930242E-03,   1.4904377E-03,   1.3809104E-03
     +,   1.2677455E-03,   1.1540317E-03,   1.0424841E-03
     +,   9.3534624E-04,   8.3433994E-04,   7.4063666E-04
     +,   6.5490470E-04,   5.7738367E-04,   5.0796638E-04
     +,   4.4629053E-04,   3.9183343E-04,   3.4398906E-04
     +,   3.0212046E-04,   2.6559641E-04,   2.3381667E-04
     +,   2.0622587E-04,   1.8231322E-04,   1.6161158E-04
     +,   1.4369744E-04,   1.2819035E-04,   1.1474780E-04
     +,   1.0306592E-04,   9.2878698E-05,   8.3955092E-05
     +,   7.6096316E-05,   6.9133726E-05,   6.2925857E-05
     +,   5.7354489E-05,   5.2321084E-05,   4.7744245E-05
     +,   4.3557331E-05,   3.9705890E-05,   3.6145611E-05
     +,   3.2841141E-05,   2.9765024E-05,   2.6895905E-05
     +,   2.4217805E-05,   2.1719256E-05,   1.9392102E-05
     +,   1.7230454E-05,   1.5229984E-05,   1.3387328E-05
     +,   1.1699262E-05,   1.0162125E-05,   8.7715935E-06
     +,   7.5225548E-06,   6.4088890E-06,   5.4234447E-06
     +,   4.5582333E-06,   3.8046628E-06,   3.1535744E-06
     +,   2.5955660E-06,   2.1212288E-06,   1.7213079E-06
     +,   1.3868560E-06,   1.1094166E-06,   8.8113967E-07
     +,   6.9483320E-07,   5.4399521E-07,   4.2284572E-07
     +,   3.2631951E-07,   2.5002331E-07,   1.9019095E-07
     +,   1.4363700E-07,   1.0770040E-07,   8.0175084E-08
     +,   5.9255310E-08,   4.3479673E-08,   3.1675263E-08
     +,   2.2910028E-08,   1.6451228E-08,   1.1728531E-08
     +,   8.3017051E-09,   5.8339986E-09,   4.0704000E-09
     +,   2.8195950E-09,   1.9392041E-09,   1.3241759E-09
     +,   8.9774616E-10,   6.0431682E-10,   4.0390757E-10
     +,   2.6804736E-10,   1.7663426E-10,   1.1558463E-10
     +,   7.5111820E-11,   4.8476789E-11,   3.1076742E-11
     +,   1.9792097E-11,   1.2525534E-11,   7.8791513E-12
     +,   4.9287367E-12,   3.0678348E-12,   1.9015844E-12
     +,   1.1750776E-12,   7.2503266E-13,   4.4756847E-13
     +,   2.7714999E-13,   1.7273681E-13,   1.0880148E-13
     +,   6.9574873E-14,   4.5382900E-14,   3.0326199E-14
     +,   2.0823992E-14,   1.4711707E-14,   1.0684513E-14
     +,   7.9563423E-15,   6.0518882E-15,   4.6823977E-15
     +,   3.6701307E-15,   2.9040923E-15,   2.3131803E-15
     +,   1.8506774E-15,   1.4847681E-15,   1.1931329E-15
     +,   9.5952242E-16,   7.7181250E-16,   6.2070267E-16
     +,   4.9894380E-16,   4.0081472E-16,   3.2173636E-16
     +,   2.5804531E-16,   2.0677654E-16,   1.6554133E-16
     +,   1.3240255E-16,   1.0579694E-16,   8.4454882E-17
     +,   6.7352758E-17,   5.3660768E-17,   4.2710617E-17
     +,   3.3961343E-17,   2.6977989E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz85 = Yx/0.0137307692307692
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5814065E-07,   5.1337315E-07
     +,   5.7430856E-07,   6.4141227E-07,   7.1517252E-07
     +,   7.9610174E-07,   8.8473365E-07,   9.8162445E-07
     +,   1.0873492E-06,   1.2025076E-06,   1.3277112E-06
     +,   1.4635920E-06,   1.6107946E-06,   1.7699763E-06
     +,   1.9418055E-06,   2.1269577E-06,   2.3261134E-06
     +,   2.5399565E-06,   2.7691683E-06,   3.0144274E-06
     +,   3.2764065E-06,   3.5557675E-06,   3.8531534E-06
     +,   4.1692115E-06,   4.5045335E-06,   4.8597244E-06
     +,   5.2353430E-06,   5.6319236E-06,   6.0499669E-06
     +,   6.4899427E-06,   6.9522798E-06,   7.4373702E-06
     +,   7.9455613E-06,   8.4771591E-06,   9.0324193E-06
     +,   9.6115573E-06,   1.0214730E-05,   1.0842035E-05
     +,   1.1493566E-05,   1.2169278E-05,   1.2869155E-05
     +,   1.3593070E-05,   1.4340857E-05,   1.5112280E-05
     +,   1.5907050E-05,   1.6724807E-05,   1.7565120E-05
     +,   1.8427489E-05,   1.9311350E-05,   2.0216046E-05
     +,   2.1140848E-05,   2.2084940E-05,   2.3047403E-05
     +,   2.4027286E-05,   2.5023424E-05,   2.6034666E-05
     +,   2.7059685E-05,   2.8097062E-05,   2.9145256E-05
     +,   3.0202609E-05,   3.1267333E-05,   3.2337535E-05
     +,   3.3411125E-05,   3.4485969E-05,   3.5559799E-05
     +,   3.6630132E-05,   3.7694481E-05,   3.8750124E-05
     +,   3.9794359E-05,   4.0824245E-05,   4.1836905E-05
     +,   4.2829244E-05,   4.3798264E-05,   4.4740791E-05
     +,   4.5653753E-05,   4.6534096E-05,   4.7378737E-05
     +,   4.8184713E-05,   4.8949212E-05,   4.9669576E-05
     +,   5.0343289E-05,   5.0968145E-05,   5.1542142E-05
     +,   5.2063679E-05,   5.2531457E-05,   5.2944655E-05
     +,   5.3302843E-05,   5.3606134E-05,   5.3855128E-05
     +,   5.4051008E-05,   5.4195563E-05,   5.4291133E-05
     +,   5.4340730E-05,   5.4347962E-05,   5.4317090E-05
     +,   5.4253014E-05,   5.4161235E-05,   5.4047909E-05
     +,   5.3919772E-05,   5.3784217E-05,   5.3649248E-05
     +,   5.3523545E-05,   5.3416486E-05,   5.3338197E-05
     +,   5.3299707E-05,   5.3313019E-05,   5.3391264E-05
     +,   5.3548851E-05,   5.3801723E-05,   5.4167482E-05
     +,   5.4665510E-05,   5.5317236E-05,   5.6146015E-05
     +,   5.7177262E-05,   5.8438087E-05,   5.9957165E-05
     +,   6.1763858E-05,   6.3887856E-05,   6.6357621E-05
     +,   6.9199559E-05,   7.2436400E-05,   7.6085104E-05
     +,   8.0155267E-05,   8.4647370E-05,   8.9550813E-05
     +,   9.4841576E-05,   1.0048202E-04,   1.0641861E-04
     +,   1.1258307E-04,   1.1889142E-04,   1.2524689E-04
     +,   1.3154090E-04,   1.3765802E-04,   1.4347925E-04
     +,   1.4888887E-04,   1.5378068E-04,   1.5806471E-04
     +,   1.6167536E-04,   1.6457915E-04,   1.6678109E-04
     +,   1.6833023E-04,   1.6932354E-04,   1.6990704E-04
     +,   1.7027404E-04,   1.7066005E-04,   1.7133534E-04
     +,   1.7259455E-04,   1.7474518E-04,   1.7809562E-04
     +,   1.8294559E-04,   1.8958015E-04,   1.9826973E-04
     +,   2.0928041E-04,   2.2289908E-04,   2.3947282E-04
     +,   2.5946627E-04,   2.8353475E-04,   3.1260424E-04
     +,   3.4793661E-04,   3.9114960E-04,   4.4417940E-04
     +,   5.0913583E-04,   5.8804388E-04,   6.8249548E-04
     +,   7.9324754E-04,   9.1982045E-04,   1.0601783E-03
     +,   1.2105826E-03,   1.3656585E-03,   1.5186530E-03
     +,   1.6618770E-03,   1.7873088E-03,   1.8872708E-03
     +,   1.9550996E-03,   1.9857953E-03,   1.9765801E-03
     +,   1.9272752E-03,   1.8404508E-03,   1.7212798E-03
     +,   1.5770574E-03,   1.4164589E-03,   1.2486372E-03
     +,   1.0822698E-03,   9.2474319E-04,   7.8161951E-04
     +,   6.5642252E-04,   5.5070885E-04,   4.6437376E-04
     +,   3.9610191E-04,   3.4382660E-04,   3.0511554E-04
     +,   2.7747641E-04,   2.5854763E-04,   2.4619559E-04
     +,   2.3855429E-04,   2.3403071E-04,   2.3129405E-04
     +,   2.2926087E-04,   2.2708136E-04,   2.2412537E-04
     +,   2.1996677E-04,   2.1436356E-04,   2.0723385E-04
     +,   1.9862827E-04,   1.8870167E-04,   1.7768168E-04
     +,   1.6584143E-04,   1.5347534E-04,   1.4087767E-04
     +,   1.2832484E-04,   1.1606424E-04,   1.0430718E-04
     +,   9.3223469E-05,   8.2939798E-05,   7.3541567E-05
     +,   6.5076565E-05,   5.7558504E-05,   5.0971699E-05
     +,   4.5277215E-05,   4.0418767E-05,   3.6326899E-05
     +,   3.2924418E-05,   3.0130766E-05,   2.7865182E-05
     +,   2.6049436E-05,   2.4610135E-05,   2.3480203E-05
     +,   2.2599568E-05,   2.1915539E-05,   2.1382824E-05
     +,   2.0963234E-05,   2.0625082E-05,   2.0342539E-05
     +,   2.0094918E-05,   1.9866000E-05,   1.9643257E-05
     +,   1.9417272E-05,   1.9181160E-05,   1.8930075E-05
     +,   1.8660767E-05,   1.8371264E-05,   1.8060593E-05
     +,   1.7728546E-05,   1.7375472E-05,   1.7002165E-05
     +,   1.6609769E-05,   1.6199669E-05,   1.5773407E-05
     +,   1.5332647E-05,   1.4879182E-05,   1.4414813E-05
     +,   1.3941357E-05,   1.3460683E-05,   1.2974625E-05
     +,   1.2484971E-05,   1.1993459E-05,   1.1501805E-05
     +,   1.1011654E-05,   1.0524552E-05,   1.0041960E-05
     +,   9.5652786E-06,   9.0958201E-06,   8.6347654E-06
     +,   8.1831913E-06,   7.7421237E-06,   7.3124320E-06
     +,   6.8948875E-06,   6.4901801E-06,   6.0989018E-06
     +,   5.7215125E-06,   5.3583790E-06,   5.0098006E-06
     +,   4.6759815E-06,   4.3570190E-06,   4.0529330E-06
     +,   3.7636985E-06,   3.4891816E-06,   3.2292207E-06
     +,   2.9835621E-06,   2.7519334E-06,   2.5339848E-06
     +,   2.3293544E-06,   2.1376193E-06,   1.9583517E-06
     +,   1.7910760E-06,   1.6353214E-06,   1.4905844E-06
     +,   1.3563536E-06,   1.2321262E-06,   1.1173784E-06
     +,   1.0116055E-06,   9.1429206E-07,   8.2494410E-07
     +,   7.4306547E-07,   6.6818291E-07,   5.9982790E-07
     +,   5.3755599E-07,   4.8093182E-07,   4.2954565E-07
     +,   3.8299919E-07,   3.4091980E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz90 = Yx/0.01204
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.2965206E-07,   4.8925415E-07
     +,   5.5611685E-07,   6.3097457E-07,   7.1461625E-07
     +,   8.0788556E-07,   9.1168283E-07,   1.0269636E-06
     +,   1.1547385E-06,   1.2960810E-06,   1.4521124E-06
     +,   1.6240100E-06,   1.8130016E-06,   2.0203643E-06
     +,   2.2474180E-06,   2.4955227E-06,   2.7660733E-06
     +,   3.0604924E-06,   3.3802241E-06,   3.7267255E-06
     +,   4.1014591E-06,   4.5058832E-06,   4.9414339E-06
     +,   5.4095522E-06,   5.9115914E-06,   6.4489086E-06
     +,   7.0227757E-06,   7.6343986E-06,   8.2849019E-06
     +,   8.9753157E-06,   9.7065686E-06,   1.0479471E-05
     +,   1.1294710E-05,   1.2152841E-05,   1.3054279E-05
     +,   1.3999292E-05,   1.4987993E-05,   1.6020333E-05
     +,   1.7096168E-05,   1.8215080E-05,   1.9376625E-05
     +,   2.0580133E-05,   2.1824821E-05,   2.3109751E-05
     +,   2.4433875E-05,   2.5796016E-05,   2.7194897E-05
     +,   2.8629143E-05,   3.0097286E-05,   3.1597792E-05
     +,   3.3129061E-05,   3.4689438E-05,   3.6277186E-05
     +,   3.7890641E-05,   3.9527913E-05,   4.1187253E-05
     +,   4.2866766E-05,   4.4564549E-05,   4.6278623E-05
     +,   4.8006961E-05,   4.9747425E-05,   5.1497838E-05
     +,   5.3255742E-05,   5.5018707E-05,   5.6784116E-05
     +,   5.8548962E-05,   6.0310264E-05,   6.2064537E-05
     +,   6.3808227E-05,   6.5537279E-05,   6.7247507E-05
     +,   6.8934183E-05,   7.0592410E-05,   7.2216746E-05
     +,   7.3801537E-05,   7.5340809E-05,   7.6828117E-05
     +,   7.8256766E-05,   7.9619866E-05,   8.0910315E-05
     +,   8.2120736E-05,   8.3243809E-05,   8.4272047E-05
     +,   8.5198153E-05,   8.6014858E-05,   8.6715198E-05
     +,   8.7292487E-05,   8.7740496E-05,   8.8053450E-05
     +,   8.8226239E-05,   8.8254419E-05,   8.8134308E-05
     +,   8.7863118E-05,   8.7438973E-05,   8.6860950E-05
     +,   8.6129228E-05,   8.5244988E-05,   8.4210631E-05
     +,   8.3029496E-05,   8.1706254E-05,   8.0246478E-05
     +,   7.8657009E-05,   7.6945544E-05,   7.5120966E-05
     +,   7.3192976E-05,   7.1172064E-05,   6.9069683E-05
     +,   6.6897970E-05,   6.4669541E-05,   6.2397514E-05
     +,   6.0095623E-05,   5.7777597E-05,   5.5457655E-05
     +,   5.3149772E-05,   5.0868181E-05,   4.8626644E-05
     +,   4.6438916E-05,   4.4318072E-05,   4.2276915E-05
     +,   4.0327388E-05,   3.8480652E-05,   3.6747089E-05
     +,   3.5136040E-05,   3.3655575E-05,   3.2312520E-05
     +,   3.1112446E-05,   3.0059276E-05,   2.9155504E-05
     +,   2.8401850E-05,   2.7797412E-05,   2.7339443E-05
     +,   2.7023483E-05,   2.6843241E-05,   2.6790716E-05
     +,   2.6856198E-05,   2.7028411E-05,   2.7294607E-05
     +,   2.7640730E-05,   2.8051631E-05,   2.8511298E-05
     +,   2.9003066E-05,   2.9509927E-05,   3.0014902E-05
     +,   3.0501364E-05,   3.0953426E-05,   3.1356587E-05
     +,   3.1698375E-05,   3.1969306E-05,   3.2164364E-05
     +,   3.2284999E-05,   3.2342203E-05,   3.2360746E-05
     +,   3.2385244E-05,   3.2488315E-05,   3.2781245E-05
     +,   3.3427419E-05,   3.4658282E-05,   3.6791920E-05
     +,   4.0252628E-05,   4.5589848E-05,   5.3495354E-05
     +,   6.4814230E-05,   8.0545135E-05,   1.0182785E-04
     +,   1.2991452E-04,   1.6611803E-04,   2.1173575E-04
     +,   2.6795774E-04,   3.3576626E-04,   4.1582878E-04
     +,   5.0840114E-04,   6.1327004E-04,   7.2973984E-04
     +,   8.5664570E-04,   9.9238346E-04,   1.1349813E-03
     +,   1.2821087E-03,   1.4310392E-03,   1.5785921E-03
     +,   1.7210576E-03,   1.8541469E-03,   1.9730534E-03
     +,   2.0726898E-03,   2.1481048E-03,   2.1950004E-03
     +,   2.2103090E-03,   2.1926807E-03,   2.1427558E-03
     +,   2.0631659E-03,   1.9582626E-03,   1.8336078E-03
     +,   1.6953746E-03,   1.5497671E-03,   1.4025290E-03
     +,   1.2586050E-03,   1.1219801E-03,   9.9564332E-04
     +,   8.8160974E-04,   7.8098511E-04,   6.9406501E-04
     +,   6.2044058E-04,   5.5911113E-04,   5.0862442E-04
     +,   4.6724500E-04,   4.3312638E-04,   4.0446475E-04
     +,   3.7963627E-04,   3.5728942E-04,   3.3638775E-04
     +,   3.1621070E-04,   2.9632298E-04,   2.7652361E-04
     +,   2.5678423E-04,   2.3718918E-04,   2.1788765E-04
     +,   1.9905697E-04,   1.8087513E-04,   1.6350325E-04
     +,   1.4707819E-04,   1.3171011E-04,   1.1747827E-04
     +,   1.0443357E-04,   9.2600632E-05,   8.1978731E-05
     +,   7.2543509E-05,   6.4250475E-05,   5.7038469E-05
     +,   5.0832263E-05,   4.5545730E-05,   4.1086118E-05
     +,   3.7357600E-05,   3.4264180E-05,   3.1712356E-05
     +,   2.9613731E-05,   2.7886961E-05,   2.6458552E-05
     +,   2.5263837E-05,   2.4247212E-05,   2.3361927E-05
     +,   2.2569513E-05,   2.1839202E-05,   2.1147087E-05
     +,   2.0475181E-05,   1.9810472E-05,   1.9144072E-05
     +,   1.8470486E-05,   1.7786837E-05,   1.7092232E-05
     +,   1.6387270E-05,   1.5673701E-05,   1.4953938E-05
     +,   1.4230884E-05,   1.3507731E-05,   1.2787784E-05
     +,   1.2074275E-05,   1.1370326E-05,   1.0678929E-05
     +,   1.0002852E-05,   9.3445597E-06,   8.7062335E-06
     +,   8.0898180E-06,   7.4969548E-06,   6.9289472E-06
     +,   6.3868160E-06,   5.8713617E-06,   5.3830604E-06
     +,   4.9221430E-06,   4.4886424E-06,   4.0823752E-06
     +,   3.7029411E-06,   3.3497704E-06,   3.0221715E-06
     +,   2.7193207E-06,   2.4402682E-06,   2.1839824E-06
     +,   1.9493868E-06,   1.7353261E-06,   1.5406416E-06
     +,   1.3641317E-06,   1.2046156E-06,   1.0609010E-06
     +,   9.3183445E-07,   8.1627519E-07,   7.1313588E-07
     +,   6.2135780E-07,   5.3994449E-07,   4.6794221E-07
     +,   4.0445403E-07,   3.4864553E-07,   2.9973160E-07
     +,   2.5699177E-07,   2.1975531E-07,   1.8741206E-07
     +,   1.5940030E-07,   1.3521324E-07,   1.1438855E-07
     +,   9.6512579E-08,   8.1211780E-08,   6.8154151E-08
     +,   5.7042541E-08,   4.7615018E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ttz95 = Yx/0.014
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz100(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4360946E-05,   3.5119509E-05
     +,   3.5888657E-05,   3.6668636E-05,   3.7459668E-05
     +,   3.8262016E-05,   3.9075909E-05,   3.9901584E-05
     +,   4.0739265E-05,   4.1589195E-05,   4.2451567E-05
     +,   4.3326578E-05,   4.4214405E-05,   4.5115201E-05
     +,   4.6029101E-05,   4.6956207E-05,   4.7896603E-05
     +,   4.8850332E-05,   4.9817394E-05,   5.0797771E-05
     +,   5.1791405E-05,   5.2798183E-05,   5.3817970E-05
     +,   5.4850603E-05,   5.5895791E-05,   5.6953326E-05
     +,   5.8022833E-05,   5.9103990E-05,   6.0196358E-05
     +,   6.1299499E-05,   6.2412910E-05,   6.3536041E-05
     +,   6.4668318E-05,   6.5809108E-05,   6.6957749E-05
     +,   6.8113528E-05,   6.9275746E-05,   7.0443573E-05
     +,   7.1616283E-05,   7.2792944E-05,   7.3972784E-05
     +,   7.5154894E-05,   7.6338350E-05,   7.7522258E-05
     +,   7.8705685E-05,   7.9887664E-05,   8.1067235E-05
     +,   8.2243452E-05,   8.3415332E-05,   8.4581952E-05
     +,   8.5742329E-05,   8.6895518E-05,   8.8040608E-05
     +,   8.9176727E-05,   9.0302914E-05,   9.1418413E-05
     +,   9.2522445E-05,   9.3614202E-05,   9.4693052E-05
     +,   9.5758362E-05,   9.6809621E-05,   9.7846409E-05
     +,   9.8868295E-05,   9.9875113E-05,   1.0086683E-04
     +,   1.0184335E-04,   1.0280502E-04,   1.0375211E-04
     +,   1.0468524E-04,   1.0560511E-04,   1.0651274E-04
     +,   1.0740925E-04,   1.0829621E-04,   1.0917518E-04
     +,   1.1004819E-04,   1.1091752E-04,   1.1178565E-04
     +,   1.1265536E-04,   1.1352984E-04,   1.1441248E-04
     +,   1.1530698E-04,   1.1621736E-04,   1.1714785E-04
     +,   1.1810311E-04,   1.1908783E-04,   1.2010712E-04
     +,   1.2116615E-04,   1.2227042E-04,   1.2342537E-04
     +,   1.2463672E-04,   1.2591018E-04,   1.2725142E-04
     +,   1.2866608E-04,   1.3015979E-04,   1.3173808E-04
     +,   1.3340602E-04,   1.3516878E-04,   1.3703087E-04
     +,   1.3899682E-04,   1.4107049E-04,   1.4325556E-04
     +,   1.4555496E-04,   1.4797154E-04,   1.5050726E-04
     +,   1.5316396E-04,   1.5594313E-04,   1.5884546E-04
     +,   1.6187150E-04,   1.6502157E-04,   1.6829598E-04
     +,   1.7169441E-04,   1.7521736E-04,   1.7886457E-04
     +,   1.8263707E-04,   1.8653544E-04,   1.9056164E-04
     +,   1.9471759E-04,   1.9900688E-04,   2.0343333E-04
     +,   2.0800238E-04,   2.1272054E-04,   2.1759537E-04
     +,   2.2263535E-04,   2.2785050E-04,   2.3325188E-04
     +,   2.3885058E-04,   2.4465920E-04,   2.5068960E-04
     +,   2.5695440E-04,   2.6346455E-04,   2.7023116E-04
     +,   2.7726244E-04,   2.8456541E-04,   2.9214329E-04
     +,   2.9999690E-04,   3.0812301E-04,   3.1651361E-04
     +,   3.2515579E-04,   3.3403243E-04,   3.4312092E-04
     +,   3.5239317E-04,   3.6181638E-04,   3.7135356E-04
     +,   3.8096384E-04,   3.9060335E-04,   4.0022618E-04
     +,   4.0978738E-04,   4.1924173E-04,   4.2854788E-04
     +,   4.3766981E-04,   4.4657895E-04,   4.5525623E-04
     +,   4.6369448E-04,   4.7190185E-04,   4.7990342E-04
     +,   4.8774370E-04,   4.9548963E-04,   5.0323288E-04
     +,   5.1109237E-04,   5.1921559E-04,   5.2778370E-04
     +,   5.3701148E-04,   5.4715114E-04,   5.5849331E-04
     +,   5.7137088E-04,   5.8615889E-04,   6.0327270E-04
     +,   6.2316837E-04,   6.4633763E-04,   6.7330193E-04
     +,   7.0460234E-04,   7.4078963E-04,   7.8242086E-04
     +,   8.3004986E-04,   8.8422513E-04,   9.4550854E-04
     +,   1.0144938E-03,   1.0918382E-03,   1.1783141E-03
     +,   1.2748830E-03,   1.3827640E-03,   1.5035134E-03
     +,   1.6391145E-03,   1.7920462E-03,   1.9653055E-03
     +,   2.1623219E-03,   2.3868082E-03,   2.6424816E-03
     +,   2.9326710E-03,   3.2599317E-03,   3.6258884E-03
     +,   4.0314505E-03,   4.4778283E-03,   4.9687042E-03
     +,   5.5132471E-03,   6.1284639E-03,   6.8383059E-03
     +,   7.6679490E-03,   8.6357910E-03,   9.7506130E-03
     +,   1.1019111E-02,   1.2457071E-02,   1.4087069E-02
     +,   1.5916862E-02,   1.7919188E-02,   2.0037943E-02
     +,   2.2214640E-02,   2.4412071E-02,   2.6628958E-02
     +,   2.8894272E-02,   3.1193083E-02,   3.3336028E-02
     +,   3.4959406E-02,   3.5812665E-02,   3.6094047E-02
     +,   3.6353000E-02,   3.6950491E-02,   3.7713777E-02
     +,   3.8201623E-02,   3.8161300E-02,   3.7637297E-02
     +,   3.6775485E-02,   3.5623401E-02,   3.4109022E-02
     +,   3.2218356E-02,   3.0129135E-02,   2.8078357E-02
     +,   2.6163626E-02,   2.4355775E-02,   2.2628002E-02
     +,   2.0991087E-02,   1.9451430E-02,   1.8002000E-02
     +,   1.6643992E-02,   1.5387225E-02,   1.4229592E-02
     +,   1.3151752E-02,   1.2133305E-02,   1.1169191E-02
     +,   1.0270114E-02,   9.4505735E-03,   8.7171467E-03
     +,   8.0643427E-03,   7.4780746E-03,   6.9425455E-03
     +,   6.4465585E-03,   5.9866528E-03,   5.5665215E-03
     +,   5.1934794E-03,   4.8739756E-03,   4.6099639E-03
     +,   4.3975678E-03,   4.2278706E-03,   4.0890630E-03
     +,   3.9689108E-03,   3.8567560E-03,   3.7446439E-03
     +,   3.6275985E-03,   3.5032814E-03,   3.3713512E-03
     +,   3.2327045E-03,   3.0888310E-03,   2.9413067E-03
     +,   2.7915312E-03,   2.6406574E-03,   2.4896096E-03
     +,   2.3392250E-03,   2.1903876E-03,   2.0441157E-03
     +,   1.9015702E-03,   1.7640244E-03,   1.6327730E-03
     +,   1.5090053E-03,   1.3936854E-03,   1.2874712E-03
     +,   1.1906784E-03,   1.1032535E-03,   1.0248362E-03
     +,   9.5479749E-04,   8.9233660E-04,   8.3654048E-04
     +,   7.8647269E-04,   7.4121892E-04,   6.9994119E-04
     +,   6.6189613E-04,   6.2645739E-04,   5.9311133E-04
     +,   5.6145468E-04,   5.3118664E-04,   5.0208747E-04
     +,   4.7401222E-04,   4.4686772E-04,   4.2060754E-04
     +,   3.9521241E-04,   3.7068778E-04,   3.4704842E-04
     +,   3.2431952E-04,   3.0252474E-04,   2.8168847E-04
     +,   2.6182868E-04,   2.4295945E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz100 = Yx/0.30263829787234
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz104(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.8370754E-05,   9.1359594E-05
     +,   9.4345211E-05,   9.7321026E-05,   1.0028028E-04
     +,   1.0321627E-04,   1.0612215E-04,   1.0899115E-04
     +,   1.1181640E-04,   1.1459135E-04,   1.1730940E-04
     +,   1.1996408E-04,   1.2254926E-04,   1.2505896E-04
     +,   1.2748745E-04,   1.2982938E-04,   1.3207969E-04
     +,   1.3423373E-04,   1.3628724E-04,   1.3823644E-04
     +,   1.4007793E-04,   1.4180888E-04,   1.4342688E-04
     +,   1.4493021E-04,   1.4631744E-04,   1.4758797E-04
     +,   1.4874153E-04,   1.4977853E-04,   1.5069988E-04
     +,   1.5150709E-04,   1.5220215E-04,   1.5278770E-04
     +,   1.5326685E-04,   1.5364311E-04,   1.5392057E-04
     +,   1.5410379E-04,   1.5419775E-04,   1.5420777E-04
     +,   1.5413959E-04,   1.5399930E-04,   1.5379318E-04
     +,   1.5352787E-04,   1.5321017E-04,   1.5284707E-04
     +,   1.5244562E-04,   1.5201312E-04,   1.5155664E-04
     +,   1.5108354E-04,   1.5060096E-04,   1.5011591E-04
     +,   1.4963538E-04,   1.4916611E-04,   1.4871459E-04
     +,   1.4828716E-04,   1.4788970E-04,   1.4752788E-04
     +,   1.4720697E-04,   1.4693178E-04,   1.4670678E-04
     +,   1.4653594E-04,   1.4642265E-04,   1.4636996E-04
     +,   1.4638031E-04,   1.4645561E-04,   1.4659735E-04
     +,   1.4680624E-04,   1.4708270E-04,   1.4742636E-04
     +,   1.4783650E-04,   1.4831175E-04,   1.4885032E-04
     +,   1.4944977E-04,   1.5010736E-04,   1.5081967E-04
     +,   1.5158308E-04,   1.5239343E-04,   1.5324613E-04
     +,   1.5413636E-04,   1.5505892E-04,   1.5600848E-04
     +,   1.5697935E-04,   1.5796570E-04,   1.5896153E-04
     +,   1.5996088E-04,   1.6095757E-04,   1.6194557E-04
     +,   1.6291873E-04,   1.6387108E-04,   1.6479683E-04
     +,   1.6569028E-04,   1.6654590E-04,   1.6735858E-04
     +,   1.6812318E-04,   1.6883526E-04,   1.6949032E-04
     +,   1.7008463E-04,   1.7061451E-04,   1.7107693E-04
     +,   1.7146912E-04,   1.7178881E-04,   1.7203426E-04
     +,   1.7220408E-04,   1.7229737E-04,   1.7231371E-04
     +,   1.7225313E-04,   1.7211610E-04,   1.7190346E-04
     +,   1.7161667E-04,   1.7125739E-04,   1.7082770E-04
     +,   1.7033024E-04,   1.6976777E-04,   1.6914352E-04
     +,   1.6846102E-04,   1.6772404E-04,   1.6693663E-04
     +,   1.6610319E-04,   1.6522805E-04,   1.6431609E-04
     +,   1.6337214E-04,   1.6240124E-04,   1.6140858E-04
     +,   1.6039953E-04,   1.5937953E-04,   1.5835396E-04
     +,   1.5732866E-04,   1.5630914E-04,   1.5530144E-04
     +,   1.5431126E-04,   1.5334469E-04,   1.5240781E-04
     +,   1.5150700E-04,   1.5064843E-04,   1.4983883E-04
     +,   1.4908488E-04,   1.4839365E-04,   1.4777237E-04
     +,   1.4722884E-04,   1.4677097E-04,   1.4640721E-04
     +,   1.4614672E-04,   1.4599909E-04,   1.4597470E-04
     +,   1.4608476E-04,   1.4634138E-04,   1.4675778E-04
     +,   1.4734834E-04,   1.4812883E-04,   1.4911650E-04
     +,   1.5033039E-04,   1.5179149E-04,   1.5352291E-04
     +,   1.5555002E-04,   1.5790103E-04,   1.6060720E-04
     +,   1.6370307E-04,   1.6722638E-04,   1.7121955E-04
     +,   1.7572922E-04,   1.8080635E-04,   1.8650756E-04
     +,   1.9289505E-04,   2.0003680E-04,   2.0800652E-04
     +,   2.1688522E-04,   2.2676072E-04,   2.3772746E-04
     +,   2.4988709E-04,   2.6334950E-04,   2.7823358E-04
     +,   2.9466624E-04,   3.1278483E-04,   3.3274054E-04
     +,   3.5469930E-04,   3.7884383E-04,   4.0538100E-04
     +,   4.3454531E-04,   4.6660149E-04,   5.0185079E-04
     +,   5.4063555E-04,   5.8333896E-04,   6.3037866E-04
     +,   6.8219914E-04,   7.3925970E-04,   8.0200593E-04
     +,   8.7083428E-04,   9.4604999E-04,   1.0278274E-03
     +,   1.1161541E-03,   1.2107743E-03,   1.3111691E-03
     +,   1.4165333E-03,   1.5257801E-03,   1.6376053E-03
     +,   1.7505968E-03,   1.8633974E-03,   1.9749138E-03
     +,   2.0846033E-03,   2.1927794E-03,   2.3008964E-03
     +,   2.4117704E-03,   2.5296852E-03,   2.6603187E-03
     +,   2.8104701E-03,   2.9876125E-03,   3.1994882E-03
     +,   3.4538405E-03,   3.7585604E-03,   4.1225459E-03
     +,   4.5572096E-03,   5.0781593E-03,   5.7059461E-03
     +,   6.4643887E-03,   7.3752464E-03,   8.4495535E-03
     +,   9.6791033E-03,   1.1033499E-02,   1.2467047E-02
     +,   1.3934047E-02,   1.5405742E-02,   1.6885107E-02
     +,   1.8422274E-02,   2.0129671E-02,   2.2168484E-02
     +,   2.4663549E-02,   2.7572889E-02,   3.0643962E-02
     +,   3.3560935E-02,   3.6166254E-02,   3.8507093E-02
     +,   4.0673174E-02,   4.2656764E-02,   4.4350695E-02
     +,   4.5564651E-02,   4.6055458E-02,   4.5687359E-02
     +,   4.4577632E-02,   4.2980410E-02,   4.1039020E-02
     +,   3.8734935E-02,   3.6080975E-02,   3.3271819E-02
     +,   3.0568916E-02,   2.8068870E-02,   2.5665173E-02
     +,   2.3236936E-02,   2.0808613E-02,   1.8518779E-02
     +,   1.6492737E-02,   1.4772181E-02,   1.3333924E-02
     +,   1.2136300E-02,   1.1141114E-02,   1.0309853E-02
     +,   9.5975408E-03,   8.9579010E-03,   8.3556781E-03
     +,   7.7749845E-03,   7.2184280E-03,   6.6990848E-03
     +,   6.2310034E-03,   5.8226441E-03,   5.4743895E-03
     +,   5.1793461E-03,   4.9257497E-03,   4.6997070E-03
     +,   4.4877250E-03,   4.2785816E-03,   4.0643676E-03
     +,   3.8407762E-03,   3.6067928E-03,   3.3640240E-03
     +,   3.1157767E-03,   2.8662097E-03,   2.6196497E-03
     +,   2.3801012E-03,   2.1509109E-03,   1.9346894E-03
     +,   1.7332409E-03,   1.5476776E-03,   1.3784643E-03
     +,   1.2255727E-03,   1.0885395E-03,   9.6660171E-04
     +,   8.5875241E-04,   7.6384691E-04,   6.8064628E-04
     +,   6.0789078E-04,   5.4435275E-04,   4.8885861E-04
     +,   4.4033342E-04,   3.9780271E-04,   3.6041261E-04
     +,   3.2741905E-04,   2.9819118E-04,   2.7219413E-04
     +,   2.4898365E-04,   2.2818704E-04,   2.0949698E-04
     +,   1.9265417E-04,   1.7744230E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz104 = Yx/0.307854166666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz106(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5442215E-05,   4.7660295E-05
     +,   4.9998496E-05,   5.2459927E-05,   5.5047192E-05
     +,   5.7762427E-05,   6.0607214E-05,   6.3582396E-05
     +,   6.6688131E-05,   6.9923961E-05,   7.3288349E-05
     +,   7.6779041E-05,   8.0392740E-05,   8.4125240E-05
     +,   8.7971304E-05,   9.1924616E-05,   9.5977819E-05
     +,   1.0012255E-04,   1.0434922E-04,   1.0864743E-04
     +,   1.1300558E-04,   1.1741116E-04,   1.2185071E-04
     +,   1.2631017E-04,   1.3077421E-04,   1.3522738E-04
     +,   1.3965341E-04,   1.4403554E-04,   1.4835686E-04
     +,   1.5260017E-04,   1.5674836E-04,   1.6078433E-04
     +,   1.6469136E-04,   1.6845313E-04,   1.7205389E-04
     +,   1.7547872E-04,   1.7871351E-04,   1.8174520E-04
     +,   1.8456216E-04,   1.8715359E-04,   1.8951055E-04
     +,   1.9162531E-04,   1.9349177E-04,   1.9510566E-04
     +,   1.9646413E-04,   1.9756623E-04,   1.9841263E-04
     +,   1.9900574E-04,   1.9934961E-04,   1.9944992E-04
     +,   1.9931384E-04,   1.9895012E-04,   1.9836862E-04
     +,   1.9758064E-04,   1.9659862E-04,   1.9543571E-04
     +,   1.9410603E-04,   1.9262446E-04,   1.9100618E-04
     +,   1.8926698E-04,   1.8742245E-04,   1.8548868E-04
     +,   1.8348134E-04,   1.8141598E-04,   1.7930774E-04
     +,   1.7717133E-04,   1.7502074E-04,   1.7286938E-04
     +,   1.7072984E-04,   1.6861393E-04,   1.6653229E-04
     +,   1.6449505E-04,   1.6251091E-04,   1.6058797E-04
     +,   1.5873311E-04,   1.5695223E-04,   1.5525047E-04
     +,   1.5363193E-04,   1.5209980E-04,   1.5065640E-04
     +,   1.4930345E-04,   1.4804170E-04,   1.4687146E-04
     +,   1.4579226E-04,   1.4480331E-04,   1.4390309E-04
     +,   1.4308991E-04,   1.4236152E-04,   1.4171559E-04
     +,   1.4114933E-04,   1.4065996E-04,   1.4024448E-04
     +,   1.3989974E-04,   1.3962264E-04,   1.3940995E-04
     +,   1.3925845E-04,   1.3916501E-04,   1.3912644E-04
     +,   1.3913965E-04,   1.3920158E-04,   1.3930928E-04
     +,   1.3945976E-04,   1.3965018E-04,   1.3987778E-04
     +,   1.4013985E-04,   1.4043368E-04,   1.4075670E-04
     +,   1.4110639E-04,   1.4148022E-04,   1.4187582E-04
     +,   1.4229078E-04,   1.4272286E-04,   1.4316976E-04
     +,   1.4362935E-04,   1.4409961E-04,   1.4457852E-04
     +,   1.4506419E-04,   1.4555498E-04,   1.4604921E-04
     +,   1.4654550E-04,   1.4704256E-04,   1.4753942E-04
     +,   1.4803519E-04,   1.4852939E-04,   1.4902170E-04
     +,   1.4951210E-04,   1.5000098E-04,   1.5048905E-04
     +,   1.5097728E-04,   1.5146716E-04,   1.5196059E-04
     +,   1.5245976E-04,   1.5296749E-04,   1.5348691E-04
     +,   1.5402169E-04,   1.5457603E-04,   1.5515462E-04
     +,   1.5576252E-04,   1.5640573E-04,   1.5709025E-04
     +,   1.5782319E-04,   1.5861182E-04,   1.5946437E-04
     +,   1.6038955E-04,   1.6139667E-04,   1.6249590E-04
     +,   1.6369803E-04,   1.6501470E-04,   1.6645814E-04
     +,   1.6804179E-04,   1.6977968E-04,   1.7168700E-04
     +,   1.7377970E-04,   1.7607512E-04,   1.7859157E-04
     +,   1.8134867E-04,   1.8436743E-04,   1.8767061E-04
     +,   1.9128283E-04,   1.9523039E-04,   1.9954263E-04
     +,   2.0425156E-04,   2.0939250E-04,   2.1500466E-04
     +,   2.2113250E-04,   2.2782608E-04,   2.3514134E-04
     +,   2.4314159E-04,   2.5189921E-04,   2.6149556E-04
     +,   2.7202134E-04,   2.8357789E-04,   2.9627761E-04
     +,   3.1024401E-04,   3.2560868E-04,   3.4251370E-04
     +,   3.6110816E-04,   3.8154382E-04,   4.0397423E-04
     +,   4.2855035E-04,   4.5541703E-04,   4.8470497E-04
     +,   5.1652634E-04,   5.5097317E-04,   5.8810797E-04
     +,   6.2795868E-04,   6.7051436E-04,   7.1572792E-04
     +,   7.6351123E-04,   8.1373443E-04,   8.6624012E-04
     +,   9.2085119E-04,   9.7738206E-04,   1.0356654E-03
     +,   1.0955813E-03,   1.1570884E-03,   1.2202471E-03
     +,   1.2852600E-03,   1.3524996E-03,   1.4225240E-03
     +,   1.4960817E-03,   1.5741140E-03,   1.6577544E-03
     +,   1.7483194E-03,   1.8472919E-03,   1.9563541E-03
     +,   2.0773923E-03,   2.2125295E-03,   2.3641675E-03
     +,   2.5350698E-03,   2.7284755E-03,   2.9483119E-03
     +,   3.1995536E-03,   3.4886340E-03,   3.8237227E-03
     +,   4.2144335E-03,   4.6706581E-03,   5.2003665E-03
     +,   5.8068316E-03,   6.4865560E-03,   7.2296439E-03
     +,   8.0235656E-03,   8.8604353E-03,   9.7466279E-03
     +,   1.0711304E-02,   1.1807491E-02,   1.3098494E-02
     +,   1.4628625E-02,   1.6393233E-02,   1.8336376E-02
     +,   2.0392025E-02,   2.2545457E-02,   2.4854798E-02
     +,   2.7394025E-02,   3.0146280E-02,   3.2934532E-02
     +,   3.5449885E-02,   3.7387270E-02,   3.8651448E-02
     +,   3.9484840E-02,   4.0297322E-02,   4.1257463E-02
     +,   4.2103842E-02,   4.2437721E-02,   4.2100545E-02
     +,   4.1196864E-02,   3.9876882E-02,   3.8199048E-02
     +,   3.6141247E-02,   3.3693101E-02,   3.0960167E-02
     +,   2.8181536E-02,   2.5622804E-02,   2.3441363E-02
     +,   2.1638656E-02,   2.0108460E-02,   1.8720966E-02
     +,   1.7386725E-02,   1.6075233E-02,   1.4794637E-02
     +,   1.3561353E-02,   1.2383772E-02,   1.1263509E-02
     +,   1.0203141E-02,   9.2102392E-03,   8.2952585E-03
     +,   7.4671879E-03,   6.7302398E-03,   6.0828580E-03
     +,   5.5186776E-03,   5.0283163E-03,   4.6011130E-03
     +,   4.2262957E-03,   3.8937961E-03,   3.5947266E-03
     +,   3.3216337E-03,   3.0685482E-03,   2.8310565E-03
     +,   2.6061314E-03,   2.3920096E-03,   2.1878644E-03
     +,   1.9935772E-03,   1.8094040E-03,   1.6357951E-03
     +,   1.4731752E-03,   1.3218762E-03,   1.1820500E-03
     +,   1.0536666E-03,   9.3653437E-04,   8.3029538E-04
     +,   7.3448266E-04,   6.4852473E-04,   5.7179492E-04
     +,   5.0361810E-04,   4.4331027E-04,   3.9017867E-04
     +,   3.4355131E-04,   3.0277221E-04,   2.6722060E-04
     +,   2.3630512E-04,   2.0947620E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz106 = Yx/0.303333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz108(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3235414E-05,   4.4413668E-05
     +,   4.5605553E-05,   4.6810233E-05,   4.8026788E-05
     +,   4.9254300E-05,   5.0491872E-05,   5.1738538E-05
     +,   5.2993284E-05,   5.4255215E-05,   5.5523356E-05
     +,   5.6796755E-05,   5.8074460E-05,   5.9355563E-05
     +,   6.0639202E-05,   6.1924547E-05,   6.3210784E-05
     +,   6.4497202E-05,   6.5783148E-05,   6.7068067E-05
     +,   6.8351444E-05,   6.9632937E-05,   7.0912196E-05
     +,   7.2189177E-05,   7.3463787E-05,   7.4736243E-05
     +,   7.6006756E-05,   7.7275879E-05,   7.8544232E-05
     +,   7.9812628E-05,   8.1082209E-05,   8.2354149E-05
     +,   8.3630046E-05,   8.4911582E-05,   8.6200816E-05
     +,   8.7499975E-05,   8.8811568E-05,   9.0138412E-05
     +,   9.1483635E-05,   9.2850467E-05,   9.4242620E-05
     +,   9.5664014E-05,   9.7118806E-05,   9.8611432E-05
     +,   1.0014665E-04,   1.0172932E-04,   1.0336463E-04
     +,   1.0505789E-04,   1.0681459E-04,   1.0864043E-04
     +,   1.1054102E-04,   1.1252220E-04,   1.1458962E-04
     +,   1.1674911E-04,   1.1900606E-04,   1.2136598E-04
     +,   1.2383395E-04,   1.2641473E-04,   1.2911262E-04
     +,   1.3193161E-04,   1.3487489E-04,   1.3794522E-04
     +,   1.4114428E-04,   1.4447322E-04,   1.4793231E-04
     +,   1.5152041E-04,   1.5523584E-04,   1.5907537E-04
     +,   1.6303490E-04,   1.6710875E-04,   1.7129029E-04
     +,   1.7557127E-04,   1.7994254E-04,   1.8439307E-04
     +,   1.8891098E-04,   1.9348327E-04,   1.9809515E-04
     +,   2.0273098E-04,   2.0737428E-04,   2.1200749E-04
     +,   2.1661201E-04,   2.2116906E-04,   2.2565879E-04
     +,   2.3006160E-04,   2.3435710E-04,   2.3852556E-04
     +,   2.4254675E-04,   2.4640176E-04,   2.5007143E-04
     +,   2.5353814E-04,   2.5678481E-04,   2.5979584E-04
     +,   2.6255683E-04,   2.6505525E-04,   2.6727997E-04
     +,   2.6922184E-04,   2.7087360E-04,   2.7223019E-04
     +,   2.7328840E-04,   2.7404728E-04,   2.7450811E-04
     +,   2.7467415E-04,   2.7455078E-04,   2.7414548E-04
     +,   2.7346759E-04,   2.7252827E-04,   2.7134042E-04
     +,   2.6991850E-04,   2.6827844E-04,   2.6643689E-04
     +,   2.6441214E-04,   2.6222301E-04,   2.5988894E-04
     +,   2.5743002E-04,   2.5486655E-04,   2.5221866E-04
     +,   2.4950673E-04,   2.4675063E-04,   2.4397028E-04
     +,   2.4118453E-04,   2.3841199E-04,   2.3567042E-04
     +,   2.3297696E-04,   2.3034766E-04,   2.2779772E-04
     +,   2.2534162E-04,   2.2299269E-04,   2.2076347E-04
     +,   2.1866562E-04,   2.1670973E-04,   2.1490578E-04
     +,   2.1326280E-04,   2.1178932E-04,   2.1049283E-04
     +,   2.0938032E-04,   2.0845828E-04,   2.0773272E-04
     +,   2.0720896E-04,   2.0689201E-04,   2.0678653E-04
     +,   2.0689683E-04,   2.0722681E-04,   2.0778045E-04
     +,   2.0856112E-04,   2.0957226E-04,   2.1081706E-04
     +,   2.1229907E-04,   2.1402116E-04,   2.1598701E-04
     +,   2.1819978E-04,   2.2066355E-04,   2.2338238E-04
     +,   2.2636073E-04,   2.2960412E-04,   2.3311879E-04
     +,   2.3691179E-04,   2.4099128E-04,   2.4536700E-04
     +,   2.5005045E-04,   2.5505453E-04,   2.6039410E-04
     +,   2.6608646E-04,   2.7215108E-04,   2.7860940E-04
     +,   2.8548564E-04,   2.9280683E-04,   3.0060179E-04
     +,   3.0890128E-04,   3.1773915E-04,   3.2715080E-04
     +,   3.3717294E-04,   3.4784246E-04,   3.5919872E-04
     +,   3.7128071E-04,   3.8412565E-04,   3.9777160E-04
     +,   4.1225454E-04,   4.2760803E-04,   4.4386214E-04
     +,   4.6104487E-04,   4.7917999E-04,   4.9828511E-04
     +,   5.1837263E-04,   5.3944974E-04,   5.6151662E-04
     +,   5.8456475E-04,   6.0857803E-04,   6.3353230E-04
     +,   6.5939699E-04,   6.8613113E-04,   7.1369059E-04
     +,   7.4202911E-04,   7.7109778E-04,   8.0085453E-04
     +,   8.3127321E-04,   8.6234784E-04,   8.9410384E-04
     +,   9.2661142E-04,   9.6000108E-04,   9.9448022E-04
     +,   1.0303431E-03,   1.0679942E-03,   1.1079668E-03
     +,   1.1509372E-03,   1.1977358E-03,   1.2493684E-03
     +,   1.3070236E-03,   1.3720652E-03,   1.4460370E-03
     +,   1.5306376E-03,   1.6276938E-03,   1.7390925E-03
     +,   1.8667189E-03,   2.0123813E-03,   2.1777051E-03
     +,   2.3640199E-03,   2.5722459E-03,   2.8028016E-03
     +,   3.0554931E-03,   3.3294759E-03,   3.6234853E-03
     +,   3.9362912E-03,   4.2676013E-03,   4.6193083E-03
     +,   4.9968129E-03,   5.4099737E-03,   5.8734566E-03
     +,   6.4065461E-03,   7.0325853E-03,   7.7772480E-03
     +,   8.6643239E-03,   9.7080711E-03,   1.0904650E-02
     +,   1.2229582E-02,   1.3648596E-02,   1.5139865E-02
     +,   1.6709276E-02,   1.8378172E-02,   2.0144833E-02
     +,   2.1959847E-02,   2.3758249E-02,   2.5534282E-02
     +,   2.7380684E-02,   2.9456463E-02,   3.1948145E-02
     +,   3.5040446E-02,   3.8760982E-02,   4.2708956E-02
     +,   4.6050616E-02,   4.8019696E-02,   4.8461325E-02
     +,   4.7796264E-02,   4.6514809E-02,   4.4830490E-02
     +,   4.2743426E-02,   4.0252529E-02,   3.7464391E-02
     +,   3.4568671E-02,   3.1757299E-02,   2.9176094E-02
     +,   2.6930554E-02,   2.5078133E-02,   2.3588818E-02
     +,   2.2340050E-02,   2.1174975E-02,   1.9966386E-02
     +,   1.8639477E-02,   1.7169565E-02,   1.5581830E-02
     +,   1.3948435E-02,   1.2367619E-02,   1.0929245E-02
     +,   9.6860621E-03,   8.6450707E-03,   7.7786180E-03
     +,   7.0443051E-03,   6.4022094E-03,   5.8241142E-03
     +,   5.2940594E-03,   4.8045390E-03,   4.3518310E-03
     +,   3.9331918E-03,   3.5457332E-03,   3.1866860E-03
     +,   2.8536997E-03,   2.5451968E-03,   2.2602268E-03
     +,   1.9982764E-03,   1.7590313E-03,   1.5421067E-03
     +,   1.3469699E-03,   1.1728283E-03,   1.0186619E-03
     +,   8.8319875E-04,   7.6500047E-04,   6.6248042E-04
     +,   5.7400099E-04,   4.9790926E-04,   4.3262029E-04
     +,   3.7664329E-04,   3.2863265E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz108 = Yx/0.317625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz110(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.2783707E-05,   8.5005806E-05
     +,   8.7213004E-05,   8.9402129E-05,   9.1570066E-05
     +,   9.3713832E-05,   9.5830481E-05,   9.7917291E-05
     +,   9.9971527E-05,   1.0199077E-04,   1.0397266E-04
     +,   1.0591491E-04,   1.0781552E-04,   1.0967252E-04
     +,   1.1148425E-04,   1.1324910E-04,   1.1496563E-04
     +,   1.1663259E-04,   1.1824894E-04,   1.1981367E-04
     +,   1.2132598E-04,   1.2278519E-04,   1.2419076E-04
     +,   1.2554236E-04,   1.2683954E-04,   1.2808222E-04
     +,   1.2927028E-04,   1.3040364E-04,   1.3148245E-04
     +,   1.3250682E-04,   1.3347693E-04,   1.3439305E-04
     +,   1.3525551E-04,   1.3606461E-04,   1.3682076E-04
     +,   1.3752439E-04,   1.3817595E-04,   1.3877590E-04
     +,   1.3932472E-04,   1.3982304E-04,   1.4027134E-04
     +,   1.4067026E-04,   1.4102047E-04,   1.4132263E-04
     +,   1.4157748E-04,   1.4178584E-04,   1.4194855E-04
     +,   1.4206661E-04,   1.4214100E-04,   1.4217287E-04
     +,   1.4216348E-04,   1.4211414E-04,   1.4202637E-04
     +,   1.4190179E-04,   1.4174220E-04,   1.4154946E-04
     +,   1.4132581E-04,   1.4107350E-04,   1.4079493E-04
     +,   1.4049289E-04,   1.4017014E-04,   1.3982991E-04
     +,   1.3947547E-04,   1.3911027E-04,   1.3873811E-04
     +,   1.3836293E-04,   1.3798884E-04,   1.3762033E-04
     +,   1.3726184E-04,   1.3691821E-04,   1.3659438E-04
     +,   1.3629546E-04,   1.3602671E-04,   1.3579360E-04
     +,   1.3560157E-04,   1.3545628E-04,   1.3536349E-04
     +,   1.3532888E-04,   1.3535822E-04,   1.3545730E-04
     +,   1.3563178E-04,   1.3588730E-04,   1.3622944E-04
     +,   1.3666350E-04,   1.3719460E-04,   1.3782771E-04
     +,   1.3856747E-04,   1.3941820E-04,   1.4038384E-04
     +,   1.4146794E-04,   1.4267364E-04,   1.4400345E-04
     +,   1.4545939E-04,   1.4704299E-04,   1.4875511E-04
     +,   1.5059579E-04,   1.5256472E-04,   1.5466040E-04
     +,   1.5688114E-04,   1.5922388E-04,   1.6168524E-04
     +,   1.6426072E-04,   1.6694526E-04,   1.6973271E-04
     +,   1.7261624E-04,   1.7558856E-04,   1.7864100E-04
     +,   1.8176436E-04,   1.8494883E-04,   1.8818412E-04
     +,   1.9145876E-04,   1.9476115E-04,   1.9807892E-04
     +,   2.0139954E-04,   2.0470966E-04,   2.0799620E-04
     +,   2.1124523E-04,   2.1444344E-04,   2.1757677E-04
     +,   2.2063157E-04,   2.2359473E-04,   2.2645268E-04
     +,   2.2919252E-04,   2.3180200E-04,   2.3426946E-04
     +,   2.3658352E-04,   2.3873402E-04,   2.4071134E-04
     +,   2.4250710E-04,   2.4411367E-04,   2.4552501E-04
     +,   2.4673581E-04,   2.4774217E-04,   2.4854176E-04
     +,   2.4913362E-04,   2.4951811E-04,   2.4969733E-04
     +,   2.4967454E-04,   2.4945513E-04,   2.4904573E-04
     +,   2.4845483E-04,   2.4769263E-04,   2.4677077E-04
     +,   2.4570260E-04,   2.4450320E-04,   2.4318940E-04
     +,   2.4177904E-04,   2.4029217E-04,   2.3874981E-04
     +,   2.3717448E-04,   2.3559001E-04,   2.3402125E-04
     +,   2.3249436E-04,   2.3103599E-04,   2.2967358E-04
     +,   2.2843534E-04,   2.2734940E-04,   2.2644424E-04
     +,   2.2574808E-04,   2.2528852E-04,   2.2509287E-04
     +,   2.2518712E-04,   2.2559610E-04,   2.2634314E-04
     +,   2.2744980E-04,   2.2893546E-04,   2.3081731E-04
     +,   2.3310989E-04,   2.3582506E-04,   2.3897199E-04
     +,   2.4255714E-04,   2.4658337E-04,   2.5105142E-04
     +,   2.5595922E-04,   2.6130170E-04,   2.6707229E-04
     +,   2.7326227E-04,   2.7986159E-04,   2.8685920E-04
     +,   2.9424444E-04,   3.0200690E-04,   3.1013755E-04
     +,   3.1862909E-04,   3.2747758E-04,   3.3668298E-04
     +,   3.4624949E-04,   3.5618624E-04,   3.6650957E-04
     +,   3.7724240E-04,   3.8841419E-04,   4.0006329E-04
     +,   4.1223670E-04,   4.2498924E-04,   4.3838489E-04
     +,   4.5249707E-04,   4.6740903E-04,   4.8321282E-04
     +,   5.0000986E-04,   5.1791302E-04,   5.3704588E-04
     +,   5.5754179E-04,   5.7954813E-04,   6.0322613E-04
     +,   6.2875333E-04,   6.5632223E-04,   6.8614603E-04
     +,   7.1846007E-04,   7.5351889E-04,   7.9159997E-04
     +,   8.3300588E-04,   8.7805995E-04,   9.2710124E-04
     +,   9.8047929E-04,   1.0385514E-03,   1.1016669E-03
     +,   1.1701506E-03,   1.2442967E-03,   1.3243660E-03
     +,   1.4105946E-03,   1.5032229E-03,   1.6025893E-03
     +,   1.7092602E-03,   1.8242137E-03,   1.9491001E-03
     +,   2.0865309E-03,   2.2403421E-03,   2.4157653E-03
     +,   2.6194698E-03,   2.8594048E-03,   3.1444333E-03
     +,   3.4838510E-03,   3.8869870E-03,   4.3630716E-03
     +,   4.9213669E-03,   5.5712834E-03,   6.3221282E-03
     +,   7.1815569E-03,   8.1530595E-03,   9.2338240E-03
     +,   1.0414623E-02,   1.1681714E-02,   1.3018955E-02
     +,   1.4410424E-02,   1.5848620E-02,   1.7352663E-02
     +,   1.8983467E-02,   2.0826101E-02,   2.2928184E-02
     +,   2.5240134E-02,   2.7625658E-02,   2.9945990E-02
     +,   3.2144129E-02,   3.4277894E-02,   3.6507804E-02
     +,   3.9018277E-02,   4.1823000E-02,   4.4563394E-02
     +,   4.6575006E-02,   4.7298986E-02,   4.6682965E-02
     +,   4.5160994E-02,   4.3278594E-02,   4.1372769E-02
     +,   3.9508384E-02,   3.7562847E-02,   3.5359204E-02
     +,   3.2830838E-02,   3.0105446E-02,   2.7413080E-02
     +,   2.4923699E-02,   2.2687934E-02,   2.0690093E-02
     +,   1.8903546E-02,   1.7296474E-02,   1.5824031E-02
     +,   1.4438001E-02,   1.3104821E-02,   1.1814611E-02
     +,   1.0576066E-02,   9.4053615E-03,   8.3157141E-03
     +,   7.3132589E-03,   6.3977139E-03,   5.5660675E-03
     +,   4.8151282E-03,   4.1427570E-03,   3.5471981E-03
     +,   3.0262652E-03,   2.5766292E-03,   2.1934372E-03
     +,   1.8705269E-03,   1.6007257E-03,   1.3764448E-03
     +,   1.1901414E-03,   1.0348175E-03,   9.0427272E-04
     +,   7.9330738E-04,   6.9771573E-04,   6.1425718E-04
     +,   5.4051238E-04,   4.7475993E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz110 = Yx/0.3049375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz112(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1652198E-05,   4.2712276E-05
     +,   4.3794556E-05,   4.4899567E-05,   4.6027901E-05
     +,   4.7180154E-05,   4.8356898E-05,   4.9558785E-05
     +,   5.0786395E-05,   5.2040457E-05,   5.3321612E-05
     +,   5.4630556E-05,   5.5967983E-05,   5.7334648E-05
     +,   5.8731268E-05,   6.0158636E-05,   6.1617568E-05
     +,   6.3108841E-05,   6.4633321E-05,   6.6191904E-05
     +,   6.7785462E-05,   6.9414957E-05,   7.1081333E-05
     +,   7.2785660E-05,   7.4528907E-05,   7.6312193E-05
     +,   7.8136640E-05,   8.0003410E-05,   8.1913706E-05
     +,   8.3868741E-05,   8.5869789E-05,   8.7918204E-05
     +,   9.0015288E-05,   9.2162416E-05,   9.4360970E-05
     +,   9.6612333E-05,   9.8917881E-05,   1.0127900E-04
     +,   1.0369713E-04,   1.0617346E-04,   1.0870936E-04
     +,   1.1130597E-04,   1.1396437E-04,   1.1668559E-04
     +,   1.1947040E-04,   1.2231954E-04,   1.2523338E-04
     +,   1.2821230E-04,   1.3125618E-04,   1.3436476E-04
     +,   1.3753750E-04,   1.4077342E-04,   1.4407113E-04
     +,   1.4742912E-04,   1.5084510E-04,   1.5431657E-04
     +,   1.5784048E-04,   1.6141334E-04,   1.6503103E-04
     +,   1.6868908E-04,   1.7238245E-04,   1.7610572E-04
     +,   1.7985252E-04,   1.8361653E-04,   1.8739089E-04
     +,   1.9116790E-04,   1.9493990E-04,   1.9869862E-04
     +,   2.0243549E-04,   2.0614159E-04,   2.0980819E-04
     +,   2.1342587E-04,   2.1698559E-04,   2.2047800E-04
     +,   2.2389395E-04,   2.2722468E-04,   2.3046108E-04
     +,   2.3359488E-04,   2.3661788E-04,   2.3952285E-04
     +,   2.4230247E-04,   2.4495058E-04,   2.4746128E-04
     +,   2.4982973E-04,   2.5205174E-04,   2.5412426E-04
     +,   2.5604473E-04,   2.5781183E-04,   2.5942476E-04
     +,   2.6088426E-04,   2.6219158E-04,   2.6334907E-04
     +,   2.6435978E-04,   2.6522789E-04,   2.6595820E-04
     +,   2.6655637E-04,   2.6702875E-04,   2.6738230E-04
     +,   2.6762448E-04,   2.6776304E-04,   2.6780678E-04
     +,   2.6776397E-04,   2.6764345E-04,   2.6745425E-04
     +,   2.6720515E-04,   2.6690518E-04,   2.6656271E-04
     +,   2.6618646E-04,   2.6578433E-04,   2.6536410E-04
     +,   2.6493307E-04,   2.6449791E-04,   2.6406482E-04
     +,   2.6363961E-04,   2.6322703E-04,   2.6283166E-04
     +,   2.6245721E-04,   2.6210674E-04,   2.6178287E-04
     +,   2.6148724E-04,   2.6122123E-04,   2.6098566E-04
     +,   2.6078059E-04,   2.6060568E-04,   2.6045999E-04
     +,   2.6034249E-04,   2.6025146E-04,   2.6018487E-04
     +,   2.6014057E-04,   2.6011595E-04,   2.6010835E-04
     +,   2.6011464E-04,   2.6013187E-04,   2.6015687E-04
     +,   2.6018618E-04,   2.6021656E-04,   2.6024456E-04
     +,   2.6026685E-04,   2.6027995E-04,   2.6028039E-04
     +,   2.6026493E-04,   2.6023030E-04,   2.6017317E-04
     +,   2.6009040E-04,   2.5997893E-04,   2.5983580E-04
     +,   2.5965821E-04,   2.5944327E-04,   2.5918859E-04
     +,   2.5889179E-04,   2.5855072E-04,   2.5816305E-04
     +,   2.5772749E-04,   2.5724227E-04,   2.5670635E-04
     +,   2.5611892E-04,   2.5547945E-04,   2.5478788E-04
     +,   2.5404469E-04,   2.5325050E-04,   2.5240678E-04
     +,   2.5151551E-04,   2.5057912E-04,   2.4960065E-04
     +,   2.4858405E-04,   2.4753375E-04,   2.4645511E-04
     +,   2.4535408E-04,   2.4423783E-04,   2.4311396E-04
     +,   2.4199145E-04,   2.4088030E-04,   2.3979125E-04
     +,   2.3873648E-04,   2.3772946E-04,   2.3678517E-04
     +,   2.3591986E-04,   2.3515148E-04,   2.3450023E-04
     +,   2.3398752E-04,   2.3363798E-04,   2.3347816E-04
     +,   2.3353787E-04,   2.3384995E-04,   2.3445110E-04
     +,   2.3538247E-04,   2.3668977E-04,   2.3842449E-04
     +,   2.4064466E-04,   2.4341523E-04,   2.4680974E-04
     +,   2.5091087E-04,   2.5581167E-04,   2.6161608E-04
     +,   2.6844061E-04,   2.7641476E-04,   2.8568105E-04
     +,   2.9639495E-04,   3.0872534E-04,   3.2285324E-04
     +,   3.3896789E-04,   3.5726500E-04,   3.7794496E-04
     +,   4.0120626E-04,   4.2723806E-04,   4.5621928E-04
     +,   4.8830960E-04,   5.2364240E-04,   5.6232017E-04
     +,   6.0441549E-04,   6.4996531E-04,   6.9897127E-04
     +,   7.5140293E-04,   8.0721010E-04,   8.6632796E-04
     +,   9.2868210E-04,   9.9420652E-04,   1.0628591E-03
     +,   1.1346260E-03,   1.2095316E-03,   1.2876549E-03
     +,   1.3691426E-03,   1.4542132E-03,   1.5431810E-03
     +,   1.6364920E-03,   1.7347523E-03,   1.8387666E-03
     +,   1.9495803E-03,   2.0685422E-03,   2.1973245E-03
     +,   2.3379449E-03,   2.4928011E-03,   2.6647027E-03
     +,   2.8569314E-03,   3.0733030E-03,   3.3183231E-03
     +,   3.5972702E-03,   3.9161840E-03,   4.2816130E-03
     +,   4.7000437E-03,   5.1769088E-03,   5.7154489E-03
     +,   6.3161165E-03,   6.9772587E-03,   7.6972810E-03
     +,   8.4778229E-03,   9.3259402E-03,   1.0253371E-02
     +,   1.1272528E-02,   1.2392518E-02,   1.3620530E-02
     +,   1.4969642E-02,   1.6468840E-02,   1.8166874E-02
     +,   2.0119844E-02,   2.2353763E-02,   2.4812847E-02
     +,   2.7344437E-02,   2.9778313E-02,   3.2072101E-02
     +,   3.4379397E-02,   3.6925837E-02,   3.9764624E-02
     +,   4.2645369E-02,   4.5171347E-02,   4.7122944E-02
     +,   4.8559219E-02,   4.9512390E-02,   4.9668584E-02
     +,   4.8550241E-02,   4.6041258E-02,   4.2586189E-02
     +,   3.8845930E-02,   3.5277735E-02,   3.2031786E-02
     +,   2.9081821E-02,   2.6350271E-02,   2.3771865E-02
     +,   2.1326406E-02,   1.9043315E-02,   1.6968999E-02
     +,   1.5125646E-02,   1.3492935E-02,   1.2021245E-02
     +,   1.0658420E-02,   9.3719661E-03,   8.1551792E-03
     +,   7.0202909E-03,   5.9857867E-03,   5.0655194E-03
     +,   4.2640418E-03,   3.5767294E-03,   2.9931772E-03
     +,   2.5005746E-03,   2.0863398E-03,   1.7391688E-03
     +,   1.4493566E-03,   1.2084848E-03,   1.0091872E-03
     +,   8.4485731E-04,   7.0960220E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz112 = Yx/0.302458333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz113(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4662949E-05,   4.6226236E-05
     +,   4.7842095E-05,   4.9513310E-05,   5.1242758E-05
     +,   5.3033455E-05,   5.4888471E-05,   5.6810968E-05
     +,   5.8804108E-05,   6.0871123E-05,   6.3015192E-05
     +,   6.5239466E-05,   6.7546942E-05,   6.9940616E-05
     +,   7.2423209E-05,   7.4997304E-05,   7.7665209E-05
     +,   8.0428945E-05,   8.3290186E-05,   8.6250249E-05
     +,   8.9309920E-05,   9.2469651E-05,   9.5729214E-05
     +,   9.9088043E-05,   1.0254463E-04,   1.0609713E-04
     +,   1.0974285E-04,   1.1347845E-04,   1.1729987E-04
     +,   1.2120223E-04,   1.2517997E-04,   1.2922674E-04
     +,   1.3333544E-04,   1.3749815E-04,   1.4170633E-04
     +,   1.4595063E-04,   1.5022104E-04,   1.5450687E-04
     +,   1.5879712E-04,   1.6307971E-04,   1.6734269E-04
     +,   1.7157327E-04,   1.7575854E-04,   1.7988529E-04
     +,   1.8394009E-04,   1.8790949E-04,   1.9178008E-04
     +,   1.9553847E-04,   1.9917158E-04,   2.0266658E-04
     +,   2.0601097E-04,   2.0919285E-04,   2.1220082E-04
     +,   2.1502418E-04,   2.1765284E-04,   2.2007778E-04
     +,   2.2229066E-04,   2.2428425E-04,   2.2605207E-04
     +,   2.2758887E-04,   2.2889057E-04,   2.2995414E-04
     +,   2.3077754E-04,   2.3136016E-04,   2.3170239E-04
     +,   2.3180590E-04,   2.3167334E-04,   2.3130873E-04
     +,   2.3071705E-04,   2.2990441E-04,   2.2887804E-04
     +,   2.2764591E-04,   2.2621729E-04,   2.2460234E-04
     +,   2.2281177E-04,   2.2085724E-04,   2.1875119E-04
     +,   2.1650670E-04,   2.1413747E-04,   2.1165746E-04
     +,   2.0908153E-04,   2.0642451E-04,   2.0370199E-04
     +,   2.0092927E-04,   1.9812229E-04,   1.9529685E-04
     +,   1.9246887E-04,   1.8965403E-04,   1.8686839E-04
     +,   1.8412725E-04,   1.8144592E-04,   1.7883955E-04
     +,   1.7632276E-04,   1.7390955E-04,   1.7161353E-04
     +,   1.6944777E-04,   1.6742457E-04,   1.6555548E-04
     +,   1.6385135E-04,   1.6232202E-04,   1.6097636E-04
     +,   1.5982242E-04,   1.5886690E-04,   1.5811565E-04
     +,   1.5757316E-04,   1.5724264E-04,   1.5712618E-04
     +,   1.5722448E-04,   1.5753675E-04,   1.5806111E-04
     +,   1.5879398E-04,   1.5973070E-04,   1.6086502E-04
     +,   1.6218935E-04,   1.6369480E-04,   1.6537130E-04
     +,   1.6720734E-04,   1.6919042E-04,   1.7130673E-04
     +,   1.7354166E-04,   1.7587979E-04,   1.7830469E-04
     +,   1.8079924E-04,   1.8334601E-04,   1.8592710E-04
     +,   1.8852424E-04,   1.9111944E-04,   1.9369429E-04
     +,   1.9623099E-04,   1.9871187E-04,   2.0112004E-04
     +,   2.0343911E-04,   2.0565369E-04,   2.0774920E-04
     +,   2.0971225E-04,   2.1153092E-04,   2.1319422E-04
     +,   2.1469276E-04,   2.1601877E-04,   2.1716606E-04
     +,   2.1812995E-04,   2.1890752E-04,   2.1949761E-04
     +,   2.1990048E-04,   2.2011870E-04,   2.2015587E-04
     +,   2.2001742E-04,   2.1971084E-04,   2.1924447E-04
     +,   2.1862869E-04,   2.1787501E-04,   2.1699653E-04
     +,   2.1600764E-04,   2.1492373E-04,   2.1376146E-04
     +,   2.1253870E-04,   2.1127434E-04,   2.0998817E-04
     +,   2.0870073E-04,   2.0743381E-04,   2.0620992E-04
     +,   2.0505197E-04,   2.0398409E-04,   2.0303096E-04
     +,   2.0221763E-04,   2.0157003E-04,   2.0111444E-04
     +,   2.0087756E-04,   2.0088642E-04,   2.0116814E-04
     +,   2.0174988E-04,   2.0265878E-04,   2.0392156E-04
     +,   2.0556449E-04,   2.0761292E-04,   2.1009173E-04
     +,   2.1302445E-04,   2.1643330E-04,   2.2033910E-04
     +,   2.2476155E-04,   2.2971907E-04,   2.3522841E-04
     +,   2.4130530E-04,   2.4796525E-04,   2.5522371E-04
     +,   2.6309633E-04,   2.7159983E-04,   2.8075403E-04
     +,   2.9058207E-04,   3.0111065E-04,   3.1237281E-04
     +,   3.2440847E-04,   3.3726462E-04,   3.5099621E-04
     +,   3.6566850E-04,   3.8135529E-04,   3.9813804E-04
     +,   4.1610582E-04,   4.3535509E-04,   4.5598496E-04
     +,   4.7809505E-04,   5.0178118E-04,   5.2713352E-04
     +,   5.5423024E-04,   5.8312924E-04,   6.1386923E-04
     +,   6.4646156E-04,   6.8088353E-04,   7.1707676E-04
     +,   7.5494783E-04,   7.9436402E-04,   8.3515333E-04
     +,   8.7711174E-04,   9.2001288E-04,   9.6361688E-04
     +,   1.0076845E-03,   1.0520002E-03,   1.0964011E-03
     +,   1.1408074E-03,   1.1852501E-03,   1.2299233E-03
     +,   1.2752168E-03,   1.3217548E-03,   1.3704327E-03
     +,   1.4224420E-03,   1.4792862E-03,   1.5427602E-03
     +,   1.6149259E-03,   1.6980569E-03,   1.7945463E-03
     +,   1.9067778E-03,   2.0369927E-03,   2.1871305E-03
     +,   2.3586561E-03,   2.5523680E-03,   2.7682655E-03
     +,   3.0054003E-03,   3.2617697E-03,   3.5343680E-03
     +,   3.8194929E-03,   4.1134409E-03,   4.4137323E-03
     +,   4.7209221E-03,   5.0405390E-03,   5.3843656E-03
     +,   5.7701208E-03,   6.2187370E-03,   6.7493371E-03
     +,   7.3731509E-03,   8.0887740E-03,   8.8820821E-03
     +,   9.7325100E-03,   1.0625296E-02,   1.1565418E-02
     +,   1.2585615E-02,   1.3741269E-02,   1.5091167E-02
     +,   1.6672401E-02,   1.8485552E-02,   2.0507574E-02
     +,   2.2734294E-02,   2.5220022E-02,   2.8060751E-02
     +,   3.1307619E-02,   3.4878522E-02,   3.8546462E-02
     +,   4.1995633E-02,   4.4901185E-02,   4.7022749E-02
     +,   4.8310999E-02,   4.8949938E-02,   4.9212053E-02
     +,   4.9171213E-02,   4.8587307E-02,   4.7155421E-02
     +,   4.4826753E-02,   4.1832488E-02,   3.8490977E-02
     +,   3.5074025E-02,   3.1776529E-02,   2.8703114E-02
     +,   2.5873262E-02,   2.3256047E-02,   2.0803861E-02
     +,   1.8465718E-02,   1.6202843E-02,   1.4010474E-02
     +,   1.1925511E-02,   1.0006669E-02,   8.3029754E-03
     +,   6.8354453E-03,   5.5975900E-03,   4.5672166E-03
     +,   3.7170411E-03,   3.0206149E-03,   2.4536524E-03
     +,   1.9942038E-03,   1.6225313E-03,   1.3214973E-03
     +,   1.0767678E-03,   8.7692979E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz113 = Yx/0.304723404255319
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz114(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.5631051E-05,   8.8196284E-05
     +,   9.0745569E-05,   9.3273535E-05,   9.5774849E-05
     +,   9.8244236E-05,   1.0067649E-04,   1.0306665E-04
     +,   1.0540976E-04,   1.0770129E-04,   1.0993685E-04
     +,   1.1211234E-04,   1.1422394E-04,   1.1626827E-04
     +,   1.1824231E-04,   1.2014330E-04,   1.2196909E-04
     +,   1.2371792E-04,   1.2538844E-04,   1.2697984E-04
     +,   1.2849181E-04,   1.2992443E-04,   1.3127836E-04
     +,   1.3255484E-04,   1.3375538E-04,   1.3488214E-04
     +,   1.3593775E-04,   1.3692520E-04,   1.3784792E-04
     +,   1.3870976E-04,   1.3951499E-04,   1.4026812E-04
     +,   1.4097408E-04,   1.4163788E-04,   1.4226495E-04
     +,   1.4286079E-04,   1.4343110E-04,   1.4398155E-04
     +,   1.4451800E-04,   1.4504617E-04,   1.4557183E-04
     +,   1.4610063E-04,   1.4663795E-04,   1.4718914E-04
     +,   1.4775930E-04,   1.4835312E-04,   1.4897513E-04
     +,   1.4962944E-04,   1.5031980E-04,   1.5104940E-04
     +,   1.5182134E-04,   1.5263788E-04,   1.5350107E-04
     +,   1.5441229E-04,   1.5537259E-04,   1.5638233E-04
     +,   1.5744167E-04,   1.5854997E-04,   1.5970616E-04
     +,   1.6090886E-04,   1.6215607E-04,   1.6344541E-04
     +,   1.6477404E-04,   1.6613885E-04,   1.6753636E-04
     +,   1.6896254E-04,   1.7041342E-04,   1.7188446E-04
     +,   1.7337114E-04,   1.7486862E-04,   1.7637202E-04
     +,   1.7787630E-04,   1.7937638E-04,   1.8086721E-04
     +,   1.8234372E-04,   1.8380096E-04,   1.8523398E-04
     +,   1.8663796E-04,   1.8800836E-04,   1.8934075E-04
     +,   1.9063086E-04,   1.9187479E-04,   1.9306874E-04
     +,   1.9420947E-04,   1.9529359E-04,   1.9631835E-04
     +,   1.9728114E-04,   1.9817983E-04,   1.9901236E-04
     +,   1.9977732E-04,   2.0047311E-04,   2.0109894E-04
     +,   2.0165398E-04,   2.0213785E-04,   2.0255028E-04
     +,   2.0289130E-04,   2.0316141E-04,   2.0336088E-04
     +,   2.0349059E-04,   2.0355135E-04,   2.0354424E-04
     +,   2.0347052E-04,   2.0333148E-04,   2.0312851E-04
     +,   2.0286339E-04,   2.0253743E-04,   2.0215256E-04
     +,   2.0171056E-04,   2.0121312E-04,   2.0066208E-04
     +,   2.0005947E-04,   1.9940702E-04,   1.9870675E-04
     +,   1.9796070E-04,   1.9717070E-04,   1.9633860E-04
     +,   1.9546671E-04,   1.9455679E-04,   1.9361101E-04
     +,   1.9263136E-04,   1.9161995E-04,   1.9057890E-04
     +,   1.8951041E-04,   1.8841666E-04,   1.8729985E-04
     +,   1.8616245E-04,   1.8500666E-04,   1.8383494E-04
     +,   1.8264992E-04,   1.8145407E-04,   1.8025005E-04
     +,   1.7904061E-04,   1.7782849E-04,   1.7661665E-04
     +,   1.7540794E-04,   1.7420534E-04,   1.7301200E-04
     +,   1.7183102E-04,   1.7066571E-04,   1.6951926E-04
     +,   1.6839501E-04,   1.6729640E-04,   1.6622688E-04
     +,   1.6518994E-04,   1.6418936E-04,   1.6322863E-04
     +,   1.6231161E-04,   1.6144228E-04,   1.6062474E-04
     +,   1.5986318E-04,   1.5916197E-04,   1.5852589E-04
     +,   1.5796004E-04,   1.5746988E-04,   1.5706116E-04
     +,   1.5674044E-04,   1.5651491E-04,   1.5639230E-04
     +,   1.5638150E-04,   1.5649231E-04,   1.5673564E-04
     +,   1.5712388E-04,   1.5767076E-04,   1.5839160E-04
     +,   1.5930360E-04,   1.6042564E-04,   1.6177889E-04
     +,   1.6338631E-04,   1.6527316E-04,   1.6746683E-04
     +,   1.6999691E-04,   1.7289468E-04,   1.7619363E-04
     +,   1.7992895E-04,   1.8413654E-04,   1.8885372E-04
     +,   1.9411815E-04,   1.9996701E-04,   2.0643641E-04
     +,   2.1356135E-04,   2.2137423E-04,   2.2990392E-04
     +,   2.3917467E-04,   2.4920632E-04,   2.6001269E-04
     +,   2.7160041E-04,   2.8396805E-04,   2.9710738E-04
     +,   3.1100141E-04,   3.2562343E-04,   3.4093895E-04
     +,   3.5690627E-04,   3.7347412E-04,   3.9058502E-04
     +,   4.0817662E-04,   4.2618267E-04,   4.4453351E-04
     +,   4.6315891E-04,   4.8199197E-04,   5.0096901E-04
     +,   5.2003242E-04,   5.3913292E-04,   5.5823370E-04
     +,   5.7731068E-04,   5.9635489E-04,   6.1537570E-04
     +,   6.3440343E-04,   6.5348740E-04,   6.7270105E-04
     +,   6.9214468E-04,   7.1194413E-04,   7.3225237E-04
     +,   7.5325405E-04,   7.7516364E-04,   7.9822977E-04
     +,   8.2273263E-04,   8.4898557E-04,   8.7733747E-04
     +,   9.0816908E-04,   9.4188546E-04,   9.7892061E-04
     +,   1.0197238E-03,   1.0647507E-03,   1.1144521E-03
     +,   1.1692641E-03,   1.2295891E-03,   1.2957803E-03
     +,   1.3681306E-03,   1.4468764E-03,   1.5321993E-03
     +,   1.6242513E-03,   1.7232015E-03,   1.8293263E-03
     +,   1.9430976E-03,   2.0652891E-03,   2.1971234E-03
     +,   2.3403806E-03,   2.4974779E-03,   2.6715167E-03
     +,   2.8662586E-03,   3.0859655E-03,   3.3350582E-03
     +,   3.6176052E-03,   3.9365757E-03,   4.2929160E-03
     +,   4.6845954E-03,   5.1060547E-03,   5.5485070E-03
     +,   6.0013579E-03,   6.4552100E-03,   6.9060936E-03
     +,   7.3596318E-03,   7.8333886E-03,   8.3556175E-03
     +,   8.9600990E-03,   9.6791005E-03,   1.0538868E-02
     +,   1.1561153E-02,   1.2769920E-02,   1.4198114E-02
     +,   1.5887139E-02,   1.7872905E-02,   2.0154778E-02
     +,   2.2658730E-02,   2.5233785E-02,   2.7720444E-02
     +,   3.0058254E-02,   3.2322984E-02,   3.4632307E-02
     +,   3.7020136E-02,   3.9423600E-02,   4.1753933E-02
     +,   4.3906949E-02,   4.5707233E-02,   4.6942841E-02
     +,   4.7520623E-02,   4.7520552E-02,   4.7006894E-02
     +,   4.5839451E-02,   4.3789413E-02,   4.0830847E-02
     +,   3.7238315E-02,   3.3416357E-02,   2.9701579E-02
     +,   2.6295587E-02,   2.3288352E-02,   2.0684332E-02
     +,   1.8419186E-02,   1.6384916E-02,   1.4470664E-02
     +,   1.2604991E-02,   1.0775579E-02,   9.0199551E-03
     +,   7.3964559E-03,   5.9560915E-03,   4.7262465E-03
     +,   3.7093747E-03,   2.8893750E-03,   2.2404692E-03
     +,   1.7337613E-03,   1.3415772E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz114 = Yx/0.296829787234043
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz115(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.0302129E-05,   6.2098639E-05
     +,   6.3941217E-05,   6.5830711E-05,   6.7767840E-05
     +,   6.9753325E-05,   7.1787734E-05,   7.3871604E-05
     +,   7.6005286E-05,   7.8189158E-05,   8.0423335E-05
     +,   8.2707811E-05,   8.5042484E-05,   8.7427041E-05
     +,   8.9861009E-05,   9.2343646E-05,   9.4874122E-05
     +,   9.7451302E-05,   1.0007388E-04,   1.0274027E-04
     +,   1.0544867E-04,   1.0819703E-04,   1.1098291E-04
     +,   1.1380389E-04,   1.1665696E-04,   1.1953905E-04
     +,   1.2244677E-04,   1.2537635E-04,   1.2832394E-04
     +,   1.3128525E-04,   1.3425587E-04,   1.3723107E-04
     +,   1.4020586E-04,   1.4317513E-04,   1.4613353E-04
     +,   1.4907548E-04,   1.5199529E-04,   1.5488702E-04
     +,   1.5774493E-04,   1.6056269E-04,   1.6333436E-04
     +,   1.6605381E-04,   1.6871480E-04,   1.7131130E-04
     +,   1.7383727E-04,   1.7628667E-04,   1.7865389E-04
     +,   1.8093319E-04,   1.8311913E-04,   1.8520659E-04
     +,   1.8719063E-04,   1.8906676E-04,   1.9083067E-04
     +,   1.9247863E-04,   1.9400699E-04,   1.9541301E-04
     +,   1.9669396E-04,   1.9784796E-04,   1.9887340E-04
     +,   1.9976938E-04,   2.0053542E-04,   2.0117183E-04
     +,   2.0167923E-04,   2.0205916E-04,   2.0231356E-04
     +,   2.0244514E-04,   2.0245714E-04,   2.0235349E-04
     +,   2.0213875E-04,   2.0181829E-04,   2.0139781E-04
     +,   2.0088391E-04,   2.0028379E-04,   1.9960520E-04
     +,   1.9885656E-04,   1.9804687E-04,   1.9718580E-04
     +,   1.9628360E-04,   1.9535089E-04,   1.9439917E-04
     +,   1.9344020E-04,   1.9248623E-04,   1.9155009E-04
     +,   1.9064508E-04,   1.8978464E-04,   1.8898275E-04
     +,   1.8825363E-04,   1.8761164E-04,   1.8707142E-04
     +,   1.8664754E-04,   1.8635466E-04,   1.8620725E-04
     +,   1.8621971E-04,   1.8640594E-04,   1.8677965E-04
     +,   1.8735370E-04,   1.8814048E-04,   1.8915134E-04
     +,   1.9039673E-04,   1.9188601E-04,   1.9362706E-04
     +,   1.9562630E-04,   1.9788858E-04,   2.0041691E-04
     +,   2.0321216E-04,   2.0627344E-04,   2.0959727E-04
     +,   2.1317790E-04,   2.1700695E-04,   2.2107390E-04
     +,   2.2536499E-04,   2.2986441E-04,   2.3455307E-04
     +,   2.3940974E-04,   2.4441013E-04,   2.4952801E-04
     +,   2.5473419E-04,   2.5999791E-04,   2.6528572E-04
     +,   2.7056300E-04,   2.7579378E-04,   2.8094050E-04
     +,   2.8596463E-04,   2.9082794E-04,   2.9549177E-04
     +,   2.9991756E-04,   3.0406815E-04,   3.0790674E-04
     +,   3.1139888E-04,   3.1451153E-04,   3.1721470E-04
     +,   3.1948055E-04,   3.2128475E-04,   3.2260612E-04
     +,   3.2342735E-04,   3.2373509E-04,   3.2351978E-04
     +,   3.2277650E-04,   3.2150431E-04,   3.1970689E-04
     +,   3.1739165E-04,   3.1457117E-04,   3.1126116E-04
     +,   3.0748156E-04,   3.0325635E-04,   2.9861220E-04
     +,   2.9357924E-04,   2.8819044E-04,   2.8248102E-04
     +,   2.7648825E-04,   2.7025049E-04,   2.6380806E-04
     +,   2.5720181E-04,   2.5047301E-04,   2.4366230E-04
     +,   2.3681109E-04,   2.2995959E-04,   2.2314691E-04
     +,   2.1641083E-04,   2.0978830E-04,   2.0331380E-04
     +,   1.9702020E-04,   1.9093868E-04,   1.8509809E-04
     +,   1.7952535E-04,   1.7424481E-04,   1.6927934E-04
     +,   1.6464954E-04,   1.6037410E-04,   1.5646973E-04
     +,   1.5295189E-04,   1.4983444E-04,   1.4712985E-04
     +,   1.4484950E-04,   1.4300419E-04,   1.4160376E-04
     +,   1.4065762E-04,   1.4017506E-04,   1.4016518E-04
     +,   1.4063710E-04,   1.4160018E-04,   1.4306397E-04
     +,   1.4503839E-04,   1.4753373E-04,   1.5056082E-04
     +,   1.5413076E-04,   1.5825462E-04,   1.6294447E-04
     +,   1.6821212E-04,   1.7406930E-04,   1.8052821E-04
     +,   1.8760127E-04,   1.9530037E-04,   2.0363757E-04
     +,   2.1262550E-04,   2.2227748E-04,   2.3260691E-04
     +,   2.4362827E-04,   2.5535806E-04,   2.6781525E-04
     +,   2.8102030E-04,   2.9499730E-04,   3.0977471E-04
     +,   3.2538586E-04,   3.4186704E-04,   3.5926164E-04
     +,   3.7761824E-04,   3.9698923E-04,   4.1743158E-04
     +,   4.3900710E-04,   4.6178061E-04,   4.8581621E-04
     +,   5.1117688E-04,   5.3792488E-04,   5.6611840E-04
     +,   5.9580751E-04,   6.2703562E-04,   6.5984158E-04
     +,   6.9425913E-04,   7.3031854E-04,   7.6805719E-04
     +,   8.0752751E-04,   8.4880728E-04,   8.9201645E-04
     +,   9.3734381E-04,   9.8507002E-04,   1.0355953E-03
     +,   1.0894723E-03,   1.1474548E-03,   1.2105244E-03
     +,   1.2799223E-03,   1.3571822E-03,   1.4441393E-03
     +,   1.5429137E-03,   1.6558443E-03,   1.7854052E-03
     +,   1.9340401E-03,   2.1039413E-03,   2.2967895E-03
     +,   2.5135088E-03,   2.7540117E-03,   3.0170295E-03
     +,   3.3001062E-03,   3.5997729E-03,   3.9118486E-03
     +,   4.2318567E-03,   4.5554745E-03,   4.8789200E-03
     +,   5.1991297E-03,   5.5138031E-03,   5.8216066E-03
     +,   6.1226180E-03,   6.4194840E-03,   6.7194016E-03
     +,   7.0367153E-03,   7.3950500E-03,   7.8276768E-03
     +,   8.3746575E-03,   9.0766829E-03,   9.9673076E-03
     +,   1.1066031E-02,   1.2374667E-02,   1.3876340E-02
     +,   1.5537255E-02,   1.7312821E-02,   1.9162256E-02
     +,   2.1068862E-02,   2.3054294E-02,   2.5173040E-02
     +,   2.7486755E-02,   3.0039886E-02,   3.2854285E-02
     +,   3.5918944E-02,   3.9139498E-02,   4.2290885E-02
     +,   4.5075718E-02,   4.7264308E-02,   4.8737880E-02
     +,   4.9394783E-02,   4.9127597E-02,   4.7979768E-02
     +,   4.6249744E-02,   4.4332780E-02,   4.2444102E-02
     +,   4.0501364E-02,   3.8241506E-02,   3.5436586E-02
     +,   3.2050002E-02,   2.8256994E-02,   2.4348414E-02
     +,   2.0599676E-02,   1.7181735E-02,   1.4150702E-02
     +,   1.1493050E-02,   9.1797709E-03,   7.1925325E-03
     +,   5.5226502E-03,   4.1581187E-03,   3.0756355E-03
     +,   2.2401607E-03,   1.6103461E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz115 = Yx/0.298468085106383
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz116(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1622231E-05,   6.3852945E-05
     +,   6.6159664E-05,   6.8543544E-05,   7.1005692E-05
     +,   7.3547038E-05,   7.6168457E-05,   7.8870558E-05
     +,   8.1653896E-05,   8.4518921E-05,   8.7465814E-05
     +,   9.0494606E-05,   9.3605195E-05,   9.6797303E-05
     +,   1.0007042E-04,   1.0342382E-04,   1.0685664E-04
     +,   1.1036774E-04,   1.1395586E-04,   1.1761946E-04
     +,   1.2135672E-04,   1.2516568E-04,   1.2904407E-04
     +,   1.3298960E-04,   1.3699933E-04,   1.4107044E-04
     +,   1.4519977E-04,   1.4938378E-04,   1.5361872E-04
     +,   1.5790068E-04,   1.6222536E-04,   1.6658827E-04
     +,   1.7098468E-04,   1.7540947E-04,   1.7985742E-04
     +,   1.8432282E-04,   1.8879992E-04,   1.9328260E-04
     +,   1.9776469E-04,   2.0223932E-04,   2.0669997E-04
     +,   2.1113937E-04,   2.1555042E-04,   2.1992561E-04
     +,   2.2425740E-04,   2.2853803E-04,   2.3275957E-04
     +,   2.3691411E-04,   2.4099348E-04,   2.4498973E-04
     +,   2.4889462E-04,   2.5270012E-04,   2.5639823E-04
     +,   2.5998097E-04,   2.6344054E-04,   2.6676958E-04
     +,   2.6996038E-04,   2.7300610E-04,   2.7589995E-04
     +,   2.7863533E-04,   2.8120636E-04,   2.8360749E-04
     +,   2.8583340E-04,   2.8787990E-04,   2.8974263E-04
     +,   2.9141852E-04,   2.9290435E-04,   2.9419819E-04
     +,   2.9529867E-04,   2.9620470E-04,   2.9691632E-04
     +,   2.9743413E-04,   2.9775925E-04,   2.9789380E-04
     +,   2.9784045E-04,   2.9760241E-04,   2.9718372E-04
     +,   2.9658905E-04,   2.9582353E-04,   2.9489290E-04
     +,   2.9380340E-04,   2.9256183E-04,   2.9117541E-04
     +,   2.8965154E-04,   2.8799826E-04,   2.8622357E-04
     +,   2.8433595E-04,   2.8234377E-04,   2.8025571E-04
     +,   2.7808058E-04,   2.7582678E-04,   2.7350298E-04
     +,   2.7111775E-04,   2.6867937E-04,   2.6619565E-04
     +,   2.6367482E-04,   2.6112419E-04,   2.5855118E-04
     +,   2.5596243E-04,   2.5336465E-04,   2.5076378E-04
     +,   2.4816560E-04,   2.4557521E-04,   2.4299772E-04
     +,   2.4043731E-04,   2.3789777E-04,   2.3538298E-04
     +,   2.3289585E-04,   2.3043914E-04,   2.2801507E-04
     +,   2.2562574E-04,   2.2327263E-04,   2.2095720E-04
     +,   2.1868027E-04,   2.1644279E-04,   2.1424518E-04
     +,   2.1208778E-04,   2.0997075E-04,   2.0789422E-04
     +,   2.0585803E-04,   2.0386199E-04,   2.0190602E-04
     +,   1.9998998E-04,   1.9811364E-04,   1.9627686E-04
     +,   1.9447971E-04,   1.9272212E-04,   1.9100450E-04
     +,   1.8932699E-04,   1.8769030E-04,   1.8609497E-04
     +,   1.8454192E-04,   1.8303232E-04,   1.8156751E-04
     +,   1.8014897E-04,   1.7877843E-04,   1.7745809E-04
     +,   1.7619009E-04,   1.7497700E-04,   1.7382136E-04
     +,   1.7272632E-04,   1.7169492E-04,   1.7073056E-04
     +,   1.6983661E-04,   1.6901684E-04,   1.6827502E-04
     +,   1.6761504E-04,   1.6704085E-04,   1.6655665E-04
     +,   1.6616624E-04,   1.6587377E-04,   1.6568316E-04
     +,   1.6559838E-04,   1.6562307E-04,   1.6576082E-04
     +,   1.6601504E-04,   1.6638874E-04,   1.6688478E-04
     +,   1.6750564E-04,   1.6825336E-04,   1.6912962E-04
     +,   1.7013573E-04,   1.7127248E-04,   1.7254001E-04
     +,   1.7393818E-04,   1.7546630E-04,   1.7712291E-04
     +,   1.7890627E-04,   1.8081392E-04,   1.8284316E-04
     +,   1.8499057E-04,   1.8725224E-04,   1.8962400E-04
     +,   1.9210145E-04,   1.9467977E-04,   1.9735380E-04
     +,   2.0011877E-04,   2.0296950E-04,   2.0590099E-04
     +,   2.0890875E-04,   2.1198866E-04,   2.1513723E-04
     +,   2.1835142E-04,   2.2162948E-04,   2.2497097E-04
     +,   2.2837630E-04,   2.3184781E-04,   2.3538961E-04
     +,   2.3900808E-04,   2.4271161E-04,   2.4651148E-04
     +,   2.5042222E-04,   2.5446119E-04,   2.5864958E-04
     +,   2.6301297E-04,   2.6758178E-04,   2.7239101E-04
     +,   2.7748151E-04,   2.8290058E-04,   2.8870261E-04
     +,   2.9494934E-04,   3.0171085E-04,   3.0906626E-04
     +,   3.1710503E-04,   3.2592597E-04,   3.3563975E-04
     +,   3.4636850E-04,   3.5824539E-04,   3.7141528E-04
     +,   3.8603498E-04,   4.0227230E-04,   4.2030370E-04
     +,   4.4031363E-04,   4.6249319E-04,   4.8703770E-04
     +,   5.1414082E-04,   5.4399279E-04,   5.7677919E-04
     +,   6.1267457E-04,   6.5183704E-04,   6.9441070E-04
     +,   7.4052159E-04,   7.9027319E-04,   8.4374862E-04
     +,   9.0101798E-04,   9.6213445E-04,   1.0271365E-03
     +,   1.0960515E-03,   1.1689031E-03,   1.2457108E-03
     +,   1.3264782E-03,   1.4111990E-03,   1.4998607E-03
     +,   1.5924316E-03,   1.6888536E-03,   1.7890583E-03
     +,   1.8929639E-03,   2.0004776E-03,   2.1115264E-03
     +,   2.2260977E-03,   2.3442947E-03,   2.4664239E-03
     +,   2.5931427E-03,   2.7256506E-03,   2.8659073E-03
     +,   3.0168144E-03,   3.1823667E-03,   3.3675891E-03
     +,   3.5782079E-03,   3.8199415E-03,   4.0975539E-03
     +,   4.4137118E-03,   4.7679734E-03,   5.1563852E-03
     +,   5.5719428E-03,   6.0060043E-03,   6.4505790E-03
     +,   6.9010099E-03,   7.3584546E-03,   7.8313565E-03
     +,   8.3353575E-03,   8.8913785E-03,   9.5223682E-03
     +,   1.0250423E-02,   1.1096810E-02,   1.2087023E-02
     +,   1.3256892E-02,   1.4652286E-02,   1.6314583E-02
     +,   1.8255398E-02,   2.0439191E-02,   2.2796260E-02
     +,   2.5266705E-02,   2.7843058E-02,   3.0574854E-02
     +,   3.3537369E-02,   3.6794398E-02,   4.0358994E-02
     +,   4.4133089E-02,   4.7853410E-02,   5.1136289E-02
     +,   5.3633153E-02,   5.5165123E-02,   5.5707142E-02
     +,   5.5281952E-02,   5.3909022E-02,   5.1637564E-02
     +,   4.8559189E-02,   4.4767555E-02,   4.0343307E-02
     +,   3.5409443E-02,   3.0185897E-02,   2.4971757E-02
     +,   2.0066319E-02,   1.5698794E-02,   1.1996814E-02
     +,   8.9921141E-03,   6.6416170E-03,   4.8569683E-03
     +,   3.5318502E-03,   2.5631795E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz116 = Yx/0.303829787234043
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz117(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2826956E-04,   1.3338143E-04
     +,   1.3854852E-04,   1.4375873E-04,   1.4899932E-04
     +,   1.5425686E-04,   1.5951754E-04,   1.6476690E-04
     +,   1.6999019E-04,   1.7517246E-04,   1.8029859E-04
     +,   1.8535317E-04,   1.9032112E-04,   1.9518730E-04
     +,   1.9993690E-04,   2.0455560E-04,   2.0902939E-04
     +,   2.1334512E-04,   2.1748996E-04,   2.2145228E-04
     +,   2.2522123E-04,   2.2878716E-04,   2.3214101E-04
     +,   2.3527544E-04,   2.3818402E-04,   2.4086195E-04
     +,   2.4330539E-04,   2.4551206E-04,   2.4748108E-04
     +,   2.4921284E-04,   2.5070916E-04,   2.5197331E-04
     +,   2.5300967E-04,   2.5382428E-04,   2.5442382E-04
     +,   2.5481661E-04,   2.5501192E-04,   2.5501984E-04
     +,   2.5485147E-04,   2.5451870E-04,   2.5403395E-04
     +,   2.5341040E-04,   2.5266153E-04,   2.5180110E-04
     +,   2.5084324E-04,   2.4980213E-04,   2.4869182E-04
     +,   2.4752619E-04,   2.4631916E-04,   2.4508414E-04
     +,   2.4383407E-04,   2.4258155E-04,   2.4133836E-04
     +,   2.4011584E-04,   2.3892472E-04,   2.3777495E-04
     +,   2.3667542E-04,   2.3563449E-04,   2.3465992E-04
     +,   2.3375831E-04,   2.3293565E-04,   2.3219718E-04
     +,   2.3154721E-04,   2.3098962E-04,   2.3052740E-04
     +,   2.3016313E-04,   2.2989837E-04,   2.2973477E-04
     +,   2.2967295E-04,   2.2971361E-04,   2.2985660E-04
     +,   2.3010198E-04,   2.3044925E-04,   2.3089779E-04
     +,   2.3144692E-04,   2.3209595E-04,   2.3284399E-04
     +,   2.3369014E-04,   2.3463384E-04,   2.3567422E-04
     +,   2.3681065E-04,   2.3804278E-04,   2.3936981E-04
     +,   2.4079171E-04,   2.4230783E-04,   2.4391832E-04
     +,   2.4562259E-04,   2.4742071E-04,   2.4931223E-04
     +,   2.5129667E-04,   2.5337364E-04,   2.5554240E-04
     +,   2.5780188E-04,   2.6015064E-04,   2.6258721E-04
     +,   2.6510921E-04,   2.6771409E-04,   2.7039836E-04
     +,   2.7315845E-04,   2.7598962E-04,   2.7888655E-04
     +,   2.8184312E-04,   2.8485261E-04,   2.8790708E-04
     +,   2.9099811E-04,   2.9411630E-04,   2.9725145E-04
     +,   3.0039216E-04,   3.0352664E-04,   3.0664229E-04
     +,   3.0972570E-04,   3.1276266E-04,   3.1573849E-04
     +,   3.1863825E-04,   3.2144613E-04,   3.2414639E-04
     +,   3.2672289E-04,   3.2915958E-04,   3.3144013E-04
     +,   3.3354896E-04,   3.3547019E-04,   3.3718906E-04
     +,   3.3869079E-04,   3.3996167E-04,   3.4098895E-04
     +,   3.4176063E-04,   3.4226596E-04,   3.4249571E-04
     +,   3.4244152E-04,   3.4209678E-04,   3.4145667E-04
     +,   3.4051720E-04,   3.3927723E-04,   3.3773622E-04
     +,   3.3589627E-04,   3.3376037E-04,   3.3133442E-04
     +,   3.2862509E-04,   3.2564145E-04,   3.2239355E-04
     +,   3.1889370E-04,   3.1515546E-04,   3.1119410E-04
     +,   3.0702568E-04,   3.0266808E-04,   2.9814002E-04
     +,   2.9346099E-04,   2.8865167E-04,   2.8373348E-04
     +,   2.7872802E-04,   2.7365738E-04,   2.6854419E-04
     +,   2.6341112E-04,   2.5828049E-04,   2.5317463E-04
     +,   2.4811557E-04,   2.4312528E-04,   2.3822456E-04
     +,   2.3343373E-04,   2.2877291E-04,   2.2426080E-04
     +,   2.1991550E-04,   2.1575399E-04,   2.1179266E-04
     +,   2.0804653E-04,   2.0452958E-04,   2.0125526E-04
     +,   1.9823558E-04,   1.9548180E-04,   1.9300413E-04
     +,   1.9081194E-04,   1.8891401E-04,   1.8731822E-04
     +,   1.8603189E-04,   1.8506187E-04,   1.8441462E-04
     +,   1.8409625E-04,   1.8411278E-04,   1.8447039E-04
     +,   1.8517495E-04,   1.8623323E-04,   1.8765194E-04
     +,   1.8943829E-04,   1.9160075E-04,   1.9414810E-04
     +,   1.9709041E-04,   2.0043865E-04,   2.0420512E-04
     +,   2.0840373E-04,   2.1304921E-04,   2.1815863E-04
     +,   2.2375061E-04,   2.2984474E-04,   2.3646325E-04
     +,   2.4363000E-04,   2.5137136E-04,   2.5971475E-04
     +,   2.6869020E-04,   2.7832986E-04,   2.8866826E-04
     +,   2.9974140E-04,   3.1158698E-04,   3.2424516E-04
     +,   3.3775804E-04,   3.5216744E-04,   3.6751811E-04
     +,   3.8385432E-04,   4.0122052E-04,   4.1966030E-04
     +,   4.3921723E-04,   4.5993461E-04,   4.8185277E-04
     +,   5.0501066E-04,   5.2944926E-04,   5.5520912E-04
     +,   5.8233406E-04,   6.1087223E-04,   6.4088416E-04
     +,   6.7244447E-04,   7.0564618E-04,   7.4061059E-04
     +,   7.7749364E-04,   8.1648829E-04,   8.5783162E-04
     +,   9.0181222E-04,   9.4876869E-04,   9.9908805E-04
     +,   1.0531973E-03,   1.1115620E-03,   1.1746754E-03
     +,   1.2430308E-03,   1.3171197E-03,   1.3974191E-03
     +,   1.4843792E-03,   1.5784112E-03,   1.6799096E-03
     +,   1.7892554E-03,   1.9068320E-03,   2.0330476E-03
     +,   2.1683706E-03,   2.3133492E-03,   2.4686174E-03
     +,   2.6349088E-03,   2.8130822E-03,   3.0041102E-03
     +,   3.2090724E-03,   3.4291258E-03,   3.6654519E-03
     +,   3.9191069E-03,   4.1907262E-03,   4.4801999E-03
     +,   4.7861971E-03,   5.1056850E-03,   5.4337108E-03
     +,   5.7635042E-03,   6.0872394E-03,   6.3973945E-03
     +,   6.6888379E-03,   6.9612670E-03,   7.2214925E-03
     +,   7.4849846E-03,   7.7761654E-03,   8.1268065E-03
     +,   8.5723046E-03,   9.1460226E-03,   9.8725678E-03
     +,   1.0761496E-02,   1.1803386E-02,   1.2970181E-02
     +,   1.4221292E-02,   1.5516343E-02,   1.6835922E-02
     +,   1.8208764E-02,   1.9735821E-02,   2.1591293E-02
     +,   2.3979599E-02,   2.7048878E-02,   3.0795110E-02
     +,   3.5021909E-02,   3.9396800E-02,   4.3591656E-02
     +,   4.7414038E-02,   5.0822493E-02,   5.3788774E-02
     +,   5.6121211E-02,   5.7426896E-02,   5.7281956E-02
     +,   5.5481467E-02,   5.2178841E-02,   4.7826562E-02
     +,   4.2974319E-02,   3.8053732E-02,   3.3273995E-02
     +,   2.8664086E-02,   2.4202138E-02,   1.9922299E-02
     +,   1.5939608E-02,   1.2399512E-02,   9.4103590E-03
     +,   7.0039085E-03,   5.1405523E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz117 = Yx/0.303531914893617
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz118(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1348694E-04,   1.1716768E-04
     +,   1.2086577E-04,   1.2457503E-04,   1.2828944E-04
     +,   1.3200272E-04,   1.3570869E-04,   1.3940102E-04
     +,   1.4307356E-04,   1.4672018E-04,   1.5033493E-04
     +,   1.5391200E-04,   1.5744564E-04,   1.6093062E-04
     +,   1.6436176E-04,   1.6773431E-04,   1.7104390E-04
     +,   1.7428647E-04,   1.7745848E-04,   1.8055685E-04
     +,   1.8357889E-04,   1.8652253E-04,   1.8938609E-04
     +,   1.9216862E-04,   1.9486937E-04,   1.9748868E-04
     +,   2.0002696E-04,   2.0248542E-04,   2.0486579E-04
     +,   2.0717015E-04,   2.0940138E-04,   2.1156255E-04
     +,   2.1365727E-04,   2.1568980E-04,   2.1766446E-04
     +,   2.1958591E-04,   2.2145927E-04,   2.2328993E-04
     +,   2.2508320E-04,   2.2684458E-04,   2.2857983E-04
     +,   2.3029446E-04,   2.3199400E-04,   2.3368398E-04
     +,   2.3536952E-04,   2.3705553E-04,   2.3874675E-04
     +,   2.4044748E-04,   2.4216140E-04,   2.4389205E-04
     +,   2.4564230E-04,   2.4741425E-04,   2.4920967E-04
     +,   2.5102973E-04,   2.5287471E-04,   2.5474443E-04
     +,   2.5663796E-04,   2.5855363E-04,   2.6048918E-04
     +,   2.6244175E-04,   2.6440763E-04,   2.6638273E-04
     +,   2.6836211E-04,   2.7034065E-04,   2.7231273E-04
     +,   2.7427179E-04,   2.7621153E-04,   2.7812485E-04
     +,   2.8000490E-04,   2.8184423E-04,   2.8363566E-04
     +,   2.8537161E-04,   2.8704506E-04,   2.8864868E-04
     +,   2.9017573E-04,   2.9161960E-04,   2.9297412E-04
     +,   2.9423326E-04,   2.9539200E-04,   2.9644574E-04
     +,   2.9739019E-04,   2.9822206E-04,   2.9893860E-04
     +,   2.9953799E-04,   3.0001902E-04,   3.0038113E-04
     +,   3.0062482E-04,   3.0075139E-04,   3.0076248E-04
     +,   3.0066102E-04,   3.0045034E-04,   3.0013444E-04
     +,   2.9971823E-04,   2.9920702E-04,   2.9860676E-04
     +,   2.9792386E-04,   2.9716507E-04,   2.9633768E-04
     +,   2.9544893E-04,   2.9450684E-04,   2.9351885E-04
     +,   2.9249326E-04,   2.9143752E-04,   2.9035987E-04
     +,   2.8926745E-04,   2.8816811E-04,   2.8706866E-04
     +,   2.8597625E-04,   2.8489708E-04,   2.8383706E-04
     +,   2.8280201E-04,   2.8179665E-04,   2.8082565E-04
     +,   2.7989276E-04,   2.7900166E-04,   2.7815488E-04
     +,   2.7735479E-04,   2.7660292E-04,   2.7590062E-04
     +,   2.7524857E-04,   2.7464682E-04,   2.7409504E-04
     +,   2.7359262E-04,   2.7313843E-04,   2.7273118E-04
     +,   2.7236907E-04,   2.7205035E-04,   2.7177291E-04
     +,   2.7153469E-04,   2.7133329E-04,   2.7116667E-04
     +,   2.7103265E-04,   2.7092919E-04,   2.7085427E-04
     +,   2.7080637E-04,   2.7078390E-04,   2.7078562E-04
     +,   2.7081111E-04,   2.7085948E-04,   2.7093073E-04
     +,   2.7102526E-04,   2.7114374E-04,   2.7128714E-04
     +,   2.7145733E-04,   2.7165603E-04,   2.7188595E-04
     +,   2.7214989E-04,   2.7245106E-04,   2.7279308E-04
     +,   2.7318022E-04,   2.7361658E-04,   2.7410709E-04
     +,   2.7465640E-04,   2.7526997E-04,   2.7595318E-04
     +,   2.7671145E-04,   2.7755054E-04,   2.7847601E-04
     +,   2.7949430E-04,   2.8061063E-04,   2.8183119E-04
     +,   2.8316179E-04,   2.8460802E-04,   2.8617555E-04
     +,   2.8787000E-04,   2.8969694E-04,   2.9166200E-04
     +,   2.9377022E-04,   2.9602696E-04,   2.9843795E-04
     +,   3.0100837E-04,   3.0374361E-04,   3.0664960E-04
     +,   3.0973222E-04,   3.1299793E-04,   3.1645360E-04
     +,   3.2010654E-04,   3.2396489E-04,   3.2803722E-04
     +,   3.3233355E-04,   3.3686499E-04,   3.4164317E-04
     +,   3.4668148E-04,   3.5199471E-04,   3.5759894E-04
     +,   3.6351214E-04,   3.6975282E-04,   3.7634224E-04
     +,   3.8330283E-04,   3.9065783E-04,   3.9843287E-04
     +,   4.0665394E-04,   4.1534842E-04,   4.2454345E-04
     +,   4.3426742E-04,   4.4454852E-04,   4.5541377E-04
     +,   4.6688830E-04,   4.7899684E-04,   4.9176143E-04
     +,   5.0519983E-04,   5.1932607E-04,   5.3415116E-04
     +,   5.4968003E-04,   5.6591054E-04,   5.8283744E-04
     +,   6.0044794E-04,   6.1872223E-04,   6.3763495E-04
     +,   6.5715751E-04,   6.7725580E-04,   6.9789297E-04
     +,   7.1903004E-04,   7.4063247E-04,   7.6266751E-04
     +,   7.8510877E-04,   8.0793793E-04,   8.3115057E-04
     +,   8.5475738E-04,   8.7878265E-04,   9.0327172E-04
     +,   9.2829135E-04,   9.5392822E-04,   9.8028954E-04
     +,   1.0075080E-03,   1.0357400E-03,   1.0651646E-03
     +,   1.0959869E-03,   1.1284470E-03,   1.1628207E-03
     +,   1.1994282E-03,   1.2386418E-03,   1.2809085E-03
     +,   1.3267532E-03,   1.3767958E-03,   1.4317658E-03
     +,   1.4925181E-03,   1.5600200E-03,   1.6353637E-03
     +,   1.7197469E-03,   1.8144450E-03,   1.9207647E-03
     +,   2.0399881E-03,   2.1733290E-03,   2.3218617E-03
     +,   2.4864748E-03,   2.6678503E-03,   2.8664721E-03
     +,   3.0826728E-03,   3.3166101E-03,   3.5683657E-03
     +,   3.8379212E-03,   4.1251378E-03,   4.4297869E-03
     +,   4.7516795E-03,   5.0909375E-03,   5.4484890E-03
     +,   5.8268383E-03,   6.2309410E-03,   6.6687847E-03
     +,   7.1512950E-03,   7.6910630E-03,   8.2995407E-03
     +,   8.9828884E-03,   9.7374758E-03,   1.0547319E-02
     +,   1.1385112E-02,   1.2218201E-02,   1.3018420E-02
     +,   1.3772300E-02,   1.4487442E-02,   1.5193425E-02
     +,   1.5939988E-02,   1.6795285E-02,   1.7842500E-02
     +,   1.9166330E-02,   2.0823613E-02,   2.2808792E-02
     +,   2.5047399E-02,   2.7438875E-02,   2.9931471E-02
     +,   3.2564197E-02,   3.5427909E-02,   3.8564879E-02
     +,   4.1886449E-02,   4.5167420E-02,   4.8106711E-02
     +,   5.0397575E-02,   5.1778529E-02,   5.2063953E-02
     +,   5.1151022E-02,   4.9000118E-02,   4.5627519E-02
     +,   4.1145869E-02,   3.5829086E-02,   3.0113578E-02
     +,   2.4498837E-02,   1.9399034E-02,   1.5049228E-02
     +,   1.1502671E-02,   8.6940704E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz118 = Yx/0.291617021276596
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz1188(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9451864E-05,   8.1713937E-05
     +,   8.4034829E-05,   8.6417363E-05,   8.8864341E-05
     +,   9.1378861E-05,   9.3963914E-05,   9.6622622E-05
     +,   9.9358076E-05,   1.0217345E-04,   1.0507185E-04
     +,   1.0805619E-04,   1.1112946E-04,   1.1429439E-04
     +,   1.1755364E-04,   1.2090957E-04,   1.2436428E-04
     +,   1.2791959E-04,   1.3157690E-04,   1.3533732E-04
     +,   1.3920141E-04,   1.4316928E-04,   1.4724043E-04
     +,   1.5141402E-04,   1.5568810E-04,   1.6006056E-04
     +,   1.6452835E-04,   1.6908767E-04,   1.7373395E-04
     +,   1.7846192E-04,   1.8326547E-04,   1.8813761E-04
     +,   1.9307065E-04,   1.9805611E-04,   2.0308458E-04
     +,   2.0814591E-04,   2.1322948E-04,   2.1832340E-04
     +,   2.2341599E-04,   2.2849377E-04,   2.3354412E-04
     +,   2.3855292E-04,   2.4350613E-04,   2.4838926E-04
     +,   2.5318767E-04,   2.5788674E-04,   2.6247173E-04
     +,   2.6692808E-04,   2.7124147E-04,   2.7539779E-04
     +,   2.7938356E-04,   2.8318577E-04,   2.8679223E-04
     +,   2.9019132E-04,   2.9337232E-04,   2.9632580E-04
     +,   2.9904311E-04,   3.0151691E-04,   3.0374064E-04
     +,   3.0570989E-04,   3.0742071E-04,   3.0887104E-04
     +,   3.1006016E-04,   3.1098846E-04,   3.1165822E-04
     +,   3.1207275E-04,   3.1223713E-04,   3.1215735E-04
     +,   3.1184102E-04,   3.1129699E-04,   3.1053505E-04
     +,   3.0956656E-04,   3.0840348E-04,   3.0705892E-04
     +,   3.0554665E-04,   3.0388127E-04,   3.0207820E-04
     +,   3.0015301E-04,   2.9812186E-04,   2.9600121E-04
     +,   2.9380736E-04,   2.9155711E-04,   2.8926699E-04
     +,   2.8695323E-04,   2.8463185E-04,   2.8231854E-04
     +,   2.8002853E-04,   2.7777633E-04,   2.7557614E-04
     +,   2.7344094E-04,   2.7138327E-04,   2.6941500E-04
     +,   2.6754680E-04,   2.6578849E-04,   2.6414904E-04
     +,   2.6263646E-04,   2.6125769E-04,   2.6001866E-04
     +,   2.5892432E-04,   2.5797877E-04,   2.5718482E-04
     +,   2.5654471E-04,   2.5605937E-04,   2.5572896E-04
     +,   2.5555288E-04,   2.5552924E-04,   2.5565564E-04
     +,   2.5592893E-04,   2.5634494E-04,   2.5689905E-04
     +,   2.5758549E-04,   2.5839850E-04,   2.5933108E-04
     +,   2.6037605E-04,   2.6152551E-04,   2.6277124E-04
     +,   2.6410440E-04,   2.6551593E-04,   2.6699639E-04
     +,   2.6853586E-04,   2.7012438E-04,   2.7175184E-04
     +,   2.7340764E-04,   2.7508137E-04,   2.7676264E-04
     +,   2.7844080E-04,   2.8010548E-04,   2.8174638E-04
     +,   2.8335335E-04,   2.8491649E-04,   2.8642645E-04
     +,   2.8787393E-04,   2.8925022E-04,   2.9054709E-04
     +,   2.9175708E-04,   2.9287313E-04,   2.9388885E-04
     +,   2.9479884E-04,   2.9559850E-04,   2.9628407E-04
     +,   2.9685258E-04,   2.9730226E-04,   2.9763227E-04
     +,   2.9784290E-04,   2.9793548E-04,   2.9791248E-04
     +,   2.9777753E-04,   2.9753562E-04,   2.9719234E-04
     +,   2.9675511E-04,   2.9623203E-04,   2.9563237E-04
     +,   2.9496683E-04,   2.9424662E-04,   2.9348425E-04
     +,   2.9269309E-04,   2.9188741E-04,   2.9108208E-04
     +,   2.9029255E-04,   2.8953541E-04,   2.8882717E-04
     +,   2.8818473E-04,   2.8762556E-04,   2.8716712E-04
     +,   2.8682663E-04,   2.8662151E-04,   2.8656903E-04
     +,   2.8668551E-04,   2.8698749E-04,   2.8749049E-04
     +,   2.8820953E-04,   2.8915875E-04,   2.9035119E-04
     +,   2.9179963E-04,   2.9351495E-04,   2.9550801E-04
     +,   2.9778766E-04,   3.0036256E-04,   3.0323974E-04
     +,   3.0642617E-04,   3.0992710E-04,   3.1374808E-04
     +,   3.1789322E-04,   3.2236736E-04,   3.2717493E-04
     +,   3.3232069E-04,   3.3780979E-04,   3.4364828E-04
     +,   3.4984393E-04,   3.5640530E-04,   3.6334348E-04
     +,   3.7067183E-04,   3.7840579E-04,   3.8656368E-04
     +,   3.9516657E-04,   4.0423987E-04,   4.1381086E-04
     +,   4.2390986E-04,   4.3457048E-04,   4.4582953E-04
     +,   4.5772505E-04,   4.7029569E-04,   4.8358258E-04
     +,   4.9762585E-04,   5.1246327E-04,   5.2813138E-04
     +,   5.4466317E-04,   5.6208583E-04,   5.8042043E-04
     +,   5.9968274E-04,   6.1988138E-04,   6.4101606E-04
     +,   6.6308002E-04,   6.8606314E-04,   7.0995191E-04
     +,   7.3473144E-04,   7.6039130E-04,   7.8693510E-04
     +,   8.1438257E-04,   8.4277801E-04,   8.7220344E-04
     +,   9.0278656E-04,   9.3471049E-04,   9.6822629E-04
     +,   1.0036628E-03,   1.0414361E-03,   1.0820499E-03
     +,   1.1260989E-03,   1.1742668E-03,   1.2273117E-03
     +,   1.2860425E-03,   1.3512888E-03,   1.4238711E-03
     +,   1.5045453E-03,   1.5939485E-03,   1.6925622E-03
     +,   1.8006653E-03,   1.9182957E-03,   2.0452552E-03
     +,   2.1811549E-03,   2.3254754E-03,   2.4776799E-03
     +,   2.6373831E-03,   2.8045468E-03,   2.9796837E-03
     +,   3.1639859E-03,   3.3594538E-03,   3.5688654E-03
     +,   3.7955889E-03,   4.0431544E-03,   4.3147728E-03
     +,   4.6126191E-03,   4.9371314E-03,   5.2864794E-03
     +,   5.6563551E-03,   6.0402006E-03,   6.4299428E-03
     +,   6.8173357E-03,   7.1955733E-03,   7.5608259E-03
     +,   7.9134461E-03,   8.2583483E-03,   8.6046224E-03
     +,   8.9641875E-03,   9.3499422E-03,   9.7743254E-03
     +,   1.0248666E-02,   1.0784471E-02,   1.1396469E-02
     +,   1.2106088E-02,   1.2941665E-02,   1.3932300E-02
     +,   1.5095341E-02,   1.6423112E-02,   1.7880075E-02
     +,   1.9417703E-02,   2.1003503E-02,   2.2642715E-02
     +,   2.4372254E-02,   2.6221791E-02,   2.8174058E-02
     +,   3.0167568E-02,   3.2157078E-02,   3.4186441E-02
     +,   3.6397494E-02,   3.8938187E-02,   4.1820973E-02
     +,   4.4827472E-02,   4.7529839E-02,   4.9416699E-02
     +,   5.0046761E-02,   4.9162593E-02,   4.6734206E-02
     +,   4.2944964E-02,   3.8141791E-02,   3.2760870E-02
     +,   2.7244473E-02,   2.1967137E-02,   1.7195201E-02
     +,   1.3080781E-02,   9.6823489E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz1188 = Yx/0.286702127659574
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz120(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0809556E-04,   1.1180084E-04
     +,   1.1562125E-04,   1.1955892E-04,   1.2361576E-04
     +,   1.2779332E-04,   1.3209309E-04,   1.3651590E-04
     +,   1.4106238E-04,   1.4573298E-04,   1.5052727E-04
     +,   1.5544477E-04,   1.6048411E-04,   1.6564380E-04
     +,   1.7092146E-04,   1.7631418E-04,   1.8181869E-04
     +,   1.8743089E-04,   1.9314588E-04,   1.9895844E-04
     +,   2.0486244E-04,   2.1085120E-04,   2.1691719E-04
     +,   2.2305260E-04,   2.2924831E-04,   2.3549504E-04
     +,   2.4178292E-04,   2.4810099E-04,   2.5443832E-04
     +,   2.6078295E-04,   2.6712276E-04,   2.7344481E-04
     +,   2.7973627E-04,   2.8598370E-04,   2.9217330E-04
     +,   2.9829115E-04,   3.0432345E-04,   3.1025615E-04
     +,   3.1607540E-04,   3.2176726E-04,   3.2731821E-04
     +,   3.3271487E-04,   3.3794474E-04,   3.4299510E-04
     +,   3.4785454E-04,   3.5251200E-04,   3.5695705E-04
     +,   3.6118022E-04,   3.6517342E-04,   3.6892883E-04
     +,   3.7244015E-04,   3.7570225E-04,   3.7871097E-04
     +,   3.8146341E-04,   3.8395805E-04,   3.8619459E-04
     +,   3.8817400E-04,   3.8989828E-04,   3.9137129E-04
     +,   3.9259758E-04,   3.9358326E-04,   3.9433522E-04
     +,   3.9486194E-04,   3.9517262E-04,   3.9527749E-04
     +,   3.9518726E-04,   3.9491427E-04,   3.9447052E-04
     +,   3.9386953E-04,   3.9312438E-04,   3.9224877E-04
     +,   3.9125688E-04,   3.9016252E-04,   3.8897956E-04
     +,   3.8772164E-04,   3.8640201E-04,   3.8503367E-04
     +,   3.8362885E-04,   3.8219921E-04,   3.8075558E-04
     +,   3.7930807E-04,   3.7786542E-04,   3.7643616E-04
     +,   3.7502707E-04,   3.7364438E-04,   3.7229253E-04
     +,   3.7097541E-04,   3.6969563E-04,   3.6845487E-04
     +,   3.6725309E-04,   3.6608955E-04,   3.6496294E-04
     +,   3.6387061E-04,   3.6280931E-04,   3.6177435E-04
     +,   3.6076133E-04,   3.5976464E-04,   3.5877837E-04
     +,   3.5779594E-04,   3.5681119E-04,   3.5581746E-04
     +,   3.5480782E-04,   3.5377571E-04,   3.5271482E-04
     +,   3.5161889E-04,   3.5048201E-04,   3.4929896E-04
     +,   3.4806505E-04,   3.4677630E-04,   3.4542871E-04
     +,   3.4402011E-04,   3.4254824E-04,   3.4101200E-04
     +,   3.3941076E-04,   3.3774544E-04,   3.3601699E-04
     +,   3.3422737E-04,   3.3237954E-04,   3.3047708E-04
     +,   3.2852415E-04,   3.2652551E-04,   3.2448652E-04
     +,   3.2241343E-04,   3.2031233E-04,   3.1818988E-04
     +,   3.1605331E-04,   3.1390961E-04,   3.1176646E-04
     +,   3.0963100E-04,   3.0751104E-04,   3.0541373E-04
     +,   3.0334646E-04,   3.0131641E-04,   2.9933042E-04
     +,   2.9739531E-04,   2.9551735E-04,   2.9370282E-04
     +,   2.9195749E-04,   2.9028684E-04,   2.8869606E-04
     +,   2.8719034E-04,   2.8577453E-04,   2.8445281E-04
     +,   2.8322992E-04,   2.8211006E-04,   2.8109751E-04
     +,   2.8019649E-04,   2.7941141E-04,   2.7874671E-04
     +,   2.7820730E-04,   2.7779795E-04,   2.7752420E-04
     +,   2.7739169E-04,   2.7740671E-04,   2.7757580E-04
     +,   2.7790634E-04,   2.7840625E-04,   2.7908341E-04
     +,   2.7994727E-04,   2.8100680E-04,   2.8227214E-04
     +,   2.8375373E-04,   2.8546230E-04,   2.8740865E-04
     +,   2.8960433E-04,   2.9206063E-04,   2.9478880E-04
     +,   2.9779974E-04,   3.0110468E-04,   3.0471379E-04
     +,   3.0863678E-04,   3.1288265E-04,   3.1745914E-04
     +,   3.2237405E-04,   3.2763302E-04,   3.3324066E-04
     +,   3.3920107E-04,   3.4551613E-04,   3.5218694E-04
     +,   3.5921313E-04,   3.6659418E-04,   3.7432733E-04
     +,   3.8241004E-04,   3.9083851E-04,   3.9961003E-04
     +,   4.0872034E-04,   4.1816646E-04,   4.2794688E-04
     +,   4.3806163E-04,   4.4851119E-04,   4.5930021E-04
     +,   4.7043586E-04,   4.8192884E-04,   4.9379404E-04
     +,   5.0605187E-04,   5.1872805E-04,   5.3185452E-04
     +,   5.4546999E-04,   5.5962132E-04,   5.7436322E-04
     +,   5.8975874E-04,   6.0588046E-04,   6.2281050E-04
     +,   6.4064167E-04,   6.5947470E-04,   6.7942124E-04
     +,   7.0060132E-04,   7.2314317E-04,   7.4717909E-04
     +,   7.7284989E-04,   8.0029521E-04,   8.2965521E-04
     +,   8.6106354E-04,   8.9464878E-04,   9.3052932E-04
     +,   9.6880563E-04,   1.0095611E-03,   1.0528624E-03
     +,   1.0987567E-03,   1.1472673E-03,   1.1984023E-03
     +,   1.2521568E-03,   1.3085121E-03,   1.3674395E-03
     +,   1.4289202E-03,   1.4929351E-03,   1.5594757E-03
     +,   1.6285459E-03,   1.7001777E-03,   1.7744228E-03
     +,   1.8513636E-03,   1.9311198E-03,   2.0138635E-03
     +,   2.0998358E-03,   2.1893478E-03,   2.2828269E-03
     +,   2.3808233E-03,   2.4840329E-03,   2.5933019E-03
     +,   2.7096362E-03,   2.8341620E-03,   2.9680666E-03
     +,   3.1125019E-03,   3.2684905E-03,   3.4367724E-03
     +,   3.6176695E-03,   3.8110043E-03,   4.0160981E-03
     +,   4.2318567E-03,   4.4570086E-03,   4.6905172E-03
     +,   4.9320632E-03,   5.1825298E-03,   5.4444540E-03
     +,   5.7221847E-03,   6.0216282E-03,   6.3494970E-03
     +,   6.7120888E-03,   7.1138158E-03,   7.5556161E-03
     +,   8.0339042E-03,   8.5404050E-03,   9.0633212E-03
     +,   9.5896702E-03,   1.0108544E-02,   1.0614866E-02
     +,   1.1112150E-02,   1.1613866E-02,   1.2142775E-02
     +,   1.2728327E-02,   1.3402890E-02,   1.4197766E-02
     +,   1.5140176E-02,   1.6250120E-02,   1.7536510E-02
     +,   1.8991588E-02,   2.0585956E-02,   2.2267077E-02
     +,   2.3966750E-02,   2.5616802E-02,   2.7170489E-02
     +,   2.8618395E-02,   2.9992701E-02,   3.1353101E-02
     +,   3.2758959E-02,   3.4234546E-02,   3.5741314E-02
     +,   3.7168521E-02,   3.8347520E-02,   3.9083924E-02
     +,   3.9194893E-02,   3.8538553E-02,   3.7034083E-02
     +,   3.4675788E-02,   3.1544503E-02,   2.7811399E-02
     +,   2.3724927E-02,   1.9574244E-02,   1.5638541E-02
     +,   1.2136000E-02,   9.1937706E-03
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz120 = Yx/0.270170212765957
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz75(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3107120E-05,   4.4822224E-05
     +,   4.6649053E-05,   4.8598242E-05,   5.0681283E-05
     +,   5.2910513E-05,   5.5299148E-05,   5.7861405E-05
     +,   6.0612350E-05,   6.3568106E-05,   6.6745619E-05
     +,   7.0162874E-05,   7.3838666E-05,   7.7792720E-05
     +,   8.2045583E-05,   8.6618478E-05,   9.1533315E-05
     +,   9.6812626E-05,   1.0247925E-04,   1.0855625E-04
     +,   1.1506682E-04,   1.2203395E-04,   1.2948018E-04
     +,   1.3742792E-04,   1.4589775E-04,   1.5490994E-04
     +,   1.6448284E-04,   1.7463314E-04,   1.8537536E-04
     +,   1.9672175E-04,   2.0868183E-04,   2.2126242E-04
     +,   2.3446718E-04,   2.4829662E-04,   2.6274798E-04
     +,   2.7781515E-04,   2.9348899E-04,   3.0975725E-04
     +,   3.2660572E-04,   3.4401639E-04,   3.6197130E-04
     +,   3.8045074E-04,   3.9943520E-04,   4.1890636E-04
     +,   4.3884848E-04,   4.5925038E-04,   4.8010709E-04
     +,   5.0142250E-04,   5.2321272E-04,   5.4550823E-04
     +,   5.6835910E-04,   5.9183931E-04,   6.1605003E-04
     +,   6.4112915E-04,   6.6725042E-04,   6.9463527E-04
     +,   7.2355272E-04,   7.5432414E-04,   7.8732613E-04
     +,   8.2298694E-04,   8.6178270E-04,   9.0422819E-04
     +,   9.5086248E-04,   1.0022381E-03,   1.0588991E-03
     +,   1.1213580E-03,   1.1900911E-03,   1.2655156E-03
     +,   1.3480000E-03,   1.4378633E-03,   1.5354264E-03
     +,   1.6410435E-03,   1.7552207E-03,   1.8787156E-03
     +,   2.0127352E-03,   2.1591368E-03,   2.3206675E-03
     +,   2.5012025E-03,   2.7059482E-03,   2.9414978E-03
     +,   3.2156426E-03,   3.5370423E-03,   3.9144391E-03
     +,   4.3559098E-03,   4.8679379E-03,   5.4550567E-03
     +,   6.1197756E-03,   6.8634781E-03,   7.6874769E-03
     +,   8.5945604E-03,   9.5902411E-03,   1.0683637E-02
     +,   1.1888024E-02,   1.3219824E-02,   1.4694404E-02
     +,   1.6317869E-02,   1.8078601E-02,   1.9943774E-02
     +,   2.1867499E-02,   2.3805413E-02,   2.5726283E-02
     +,   2.7609618E-02,   2.9436061E-02,   3.1178506E-02
     +,   3.2797184E-02,   3.4229115E-02,   3.5376325E-02
     +,   3.6118317E-02,   3.6362454E-02,   3.6099646E-02
     +,   3.5407465E-02,   3.4386251E-02,   3.3089068E-02
     +,   3.1514872E-02,   2.9666383E-02,   2.7604438E-02
     +,   2.5446141E-02,   2.3317723E-02,   2.1312408E-02
     +,   1.9477164E-02,   1.7822215E-02,   1.6333427E-02
     +,   1.4982222E-02,   1.3737826E-02,   1.2580710E-02
     +,   1.1510277E-02,   1.0541433E-02,   9.6929185E-03
     +,   8.9746425E-03,   8.3811060E-03,   7.8922864E-03
     +,   7.4802143E-03,   7.1165781E-03,   6.7786626E-03
     +,   6.4518852E-03,   6.1296471E-03,   5.8113681E-03
     +,   5.5000125E-03,   5.1998328E-03,   4.9147932E-03
     +,   4.6477192E-03,   4.3999543E-03,   4.1715144E-03
     +,   3.9614365E-03,   3.7682371E-03,   3.5902730E-03
     +,   3.4260314E-03,   3.2742501E-03,   3.1339407E-03
     +,   3.0042850E-03,   2.8845507E-03,   2.7739790E-03
     +,   2.6717088E-03,   2.5767486E-03,   2.4879794E-03
     +,   2.4042272E-03,   2.3243143E-03,   2.2471303E-03
     +,   2.1717106E-03,   2.0972888E-03,   2.0233153E-03
     +,   1.9494765E-03,   1.8756785E-03,   1.8020245E-03
     +,   1.7287739E-03,   1.6562964E-03,   1.5850450E-03
     +,   1.5155069E-03,   1.4481654E-03,   1.3834811E-03
     +,   1.3218729E-03,   1.2637017E-03,   1.2092588E-03
     +,   1.1587667E-03,   1.1123827E-03,   1.0701959E-03
     +,   1.0322320E-03,   9.9846651E-04,   9.6882315E-04
     +,   9.4318372E-04,   9.2139241E-04,   9.0326811E-04
     +,   8.8860502E-04,   8.7718113E-04,   8.6876150E-04
     +,   8.6310779E-04,   8.5997680E-04,   8.5913041E-04
     +,   8.6033490E-04,   8.6336350E-04,   8.6800184E-04
     +,   8.7404688E-04,   8.8130770E-04,   8.8960712E-04
     +,   8.9878094E-04,   9.0867805E-04,   9.1915944E-04
     +,   9.3009672E-04,   9.4137143E-04,   9.5287751E-04
     +,   9.6451293E-04,   9.7618403E-04,   9.8780461E-04
     +,   9.9929352E-04,   1.0105741E-03,   1.0215733E-03
     +,   1.0322251E-03,   1.0424646E-03,   1.0522306E-03
     +,   1.0614671E-03,   1.0701220E-03,   1.0781446E-03
     +,   1.0854899E-03,   1.0921168E-03,   1.0979864E-03
     +,   1.1030654E-03,   1.1073225E-03,   1.1107319E-03
     +,   1.1132711E-03,   1.1149212E-03,   1.1156673E-03
     +,   1.1154971E-03,   1.1144041E-03,   1.1123860E-03
     +,   1.1094416E-03,   1.1055770E-03,   1.1008021E-03
     +,   1.0951307E-03,   1.0885813E-03,   1.0811788E-03
     +,   1.0729516E-03,   1.0639339E-03,   1.0541665E-03
     +,   1.0436912E-03,   1.0325589E-03,   1.0208215E-03
     +,   1.0085371E-03,   9.9576428E-04,   9.8256685E-04
     +,   9.6900843E-04,   9.5515314E-04,   9.4106520E-04
     +,   9.2680822E-04,   9.1244222E-04,   8.9802523E-04
     +,   8.8360975E-04,   8.6924568E-04,   8.5497467E-04
     +,   8.4083370E-04,   8.2685426E-04,   8.1305986E-04
     +,   7.9946703E-04,   7.8608724E-04,   7.7292556E-04
     +,   7.5997890E-04,   7.4724038E-04,   7.3469745E-04
     +,   7.2233501E-04,   7.1013212E-04,   6.9806585E-04
     +,   6.8611035E-04,   6.7424058E-04,   6.6242914E-04
     +,   6.5064809E-04,   6.3887279E-04,   6.2707742E-04
     +,   6.1523874E-04,   6.0333632E-04,   5.9135241E-04
     +,   5.7927164E-04,   5.6708138E-04,   5.5477384E-04
     +,   5.4234412E-04,   5.2979036E-04,   5.1711360E-04
     +,   5.0432020E-04,   4.9141760E-04,   4.7841750E-04
     +,   4.6533364E-04,   4.5218386E-04,   4.3898550E-04
     +,   4.2576095E-04,   4.1253143E-04,   3.9932167E-04
     +,   3.8615533E-04,   3.7305907E-04,   3.6005760E-04
     +,   3.4717598E-04,   3.3444044E-04,   3.2187472E-04
     +,   3.0950358E-04,   2.9734784E-04,   2.8542979E-04
     +,   2.7376818E-04,   2.6238139E-04,   2.5128471E-04
     +,   2.4049265E-04,   2.3001652E-04,   2.1986685E-04
     +,   2.1005077E-04,   2.0057466E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz75 = Yx/0.29131914893617
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz80(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.2149709E-05,   6.3988933E-05
     +,   6.5835193E-05,   6.7686989E-05,   6.9542963E-05
     +,   7.1401788E-05,   7.3262272E-05,   7.5123404E-05
     +,   7.6984237E-05,   7.8844110E-05,   8.0702412E-05
     +,   8.2558843E-05,   8.4413237E-05,   8.6265696E-05
     +,   8.8116576E-05,   8.9966488E-05,   9.1816357E-05
     +,   9.3667397E-05,   9.5521224E-05,   9.7379656E-05
     +,   9.9245059E-05,   1.0112012E-04,   1.0300796E-04
     +,   1.0491225E-04,   1.0683704E-04,   1.0878704E-04
     +,   1.1076747E-04,   1.1278417E-04,   1.1484358E-04
     +,   1.1695299E-04,   1.1912031E-04,   1.2135426E-04
     +,   1.2366443E-04,   1.2606128E-04,   1.2855612E-04
     +,   1.3116121E-04,   1.3388992E-04,   1.3675631E-04
     +,   1.3977576E-04,   1.4296429E-04,   1.4633908E-04
     +,   1.4991809E-04,   1.5372002E-04,   1.5776444E-04
     +,   1.6207132E-04,   1.6666112E-04,   1.7155461E-04
     +,   1.7677246E-04,   1.8233508E-04,   1.8826264E-04
     +,   1.9457418E-04,   2.0128774E-04,   2.0841988E-04
     +,   2.1598556E-04,   2.2399671E-04,   2.3246354E-04
     +,   2.4139274E-04,   2.5078762E-04,   2.6064771E-04
     +,   2.7096851E-04,   2.8174120E-04,   2.9295273E-04
     +,   3.0458477E-04,   3.1661565E-04,   3.2902035E-04
     +,   3.4176902E-04,   3.5483198E-04,   3.6817757E-04
     +,   3.8177773E-04,   3.9560755E-04,   4.0965163E-04
     +,   4.2390564E-04,   4.3838291E-04,   4.5311695E-04
     +,   4.6817042E-04,   4.8363823E-04,   4.9965293E-04
     +,   5.1638903E-04,   5.3406932E-04,   5.5296568E-04
     +,   5.7339866E-04,   5.9573958E-04,   6.2040420E-04
     +,   6.4785255E-04,   6.7858107E-04,   7.1312609E-04
     +,   7.5206067E-04,   7.9601584E-04,   8.4569695E-04
     +,   9.0193417E-04,   9.6573762E-04,   1.0383679E-03
     +,   1.1214147E-03,   1.2168771E-03,   1.3272136E-03
     +,   1.4553359E-03,   1.6045962E-03,   1.7786430E-03
     +,   1.9812959E-03,   2.2162904E-03,   2.4871321E-03
     +,   2.7969060E-03,   3.1483278E-03,   3.5438247E-03
     +,   3.9858534E-03,   4.4770869E-03,   5.0204070E-03
     +,   5.6187506E-03,   6.2750978E-03,   6.9930749E-03
     +,   7.7786087E-03,   8.6424612E-03,   9.6012261E-03
     +,   1.0675524E-02,   1.1884294E-02,   1.3238943E-02
     +,   1.4741102E-02,   1.6387224E-02,   1.8174665E-02
     +,   2.0101596E-02,   2.2153568E-02,   2.4281608E-02
     +,   2.6390666E-02,   2.8355947E-02,   3.0061888E-02
     +,   3.1431686E-02,   3.2419924E-02,   3.2980755E-02
     +,   3.3057600E-02,   3.2613453E-02,   3.1671949E-02
     +,   3.0331554E-02,   2.8744530E-02,   2.7077986E-02
     +,   2.5467828E-02,   2.3978673E-02,   2.2595081E-02
     +,   2.1258993E-02,   1.9931428E-02,   1.8630011E-02
     +,   1.7414844E-02,   1.6341163E-02,   1.5421508E-02
     +,   1.4623301E-02,   1.3894466E-02,   1.3192910E-02
     +,   1.2500913E-02,   1.1822176E-02,   1.1170378E-02
     +,   1.0558590E-02,   9.9943280E-03,   9.4785467E-03
     +,   9.0063438E-03,   8.5679349E-03,   8.1499983E-03
     +,   7.7375961E-03,   7.3167621E-03,   6.8772598E-03
     +,   6.4147711E-03,   5.9318314E-03,   5.4370887E-03
     +,   4.9433899E-03,   4.4652279E-03,   4.0161256E-03
     +,   3.6067076E-03,   3.2437069E-03,   2.9298600E-03
     +,   2.6644273E-03,   2.4440694E-03,   2.2638643E-03
     +,   2.1182008E-03,   2.0014241E-03,   1.9082850E-03
     +,   1.8341903E-03,   1.7752942E-03,   1.7284673E-03
     +,   1.6912344E-03,   1.6616744E-03,   1.6383042E-03
     +,   1.6199868E-03,   1.6058366E-03,   1.5951487E-03
     +,   1.5873420E-03,   1.5819047E-03,   1.5783746E-03
     +,   1.5763188E-03,   1.5753101E-03,   1.5749403E-03
     +,   1.5748165E-03,   1.5745607E-03,   1.5738279E-03
     +,   1.5723052E-03,   1.5697179E-03,   1.5658428E-03
     +,   1.5604974E-03,   1.5535530E-03,   1.5449269E-03
     +,   1.5345837E-03,   1.5225279E-03,   1.5087981E-03
     +,   1.4934655E-03,   1.4766238E-03,   1.4583824E-03
     +,   1.4388631E-03,   1.4181919E-03,   1.3964974E-03
     +,   1.3739042E-03,   1.3505336E-03,   1.3265007E-03
     +,   1.3019140E-03,   1.2768774E-03,   1.2514907E-03
     +,   1.2258510E-03,   1.2000568E-03,   1.1742036E-03
     +,   1.1483945E-03,   1.1227331E-03,   1.0973287E-03
     +,   1.0722922E-03,   1.0477413E-03,   1.0237927E-03
     +,   1.0005631E-03,   9.7816973E-04,   9.5672422E-04
     +,   9.3633140E-04,   9.1708620E-04,   8.9907320E-04
     +,   8.8236365E-04,   8.6701300E-04,   8.5305754E-04
     +,   8.4051944E-04,   8.2939881E-04,   8.1967731E-04
     +,   8.1131671E-04,   8.0426084E-04,   7.9843373E-04
     +,   7.9374237E-04,   7.9007784E-04,   7.8731723E-04
     +,   7.8532437E-04,   7.8395265E-04,   7.8304816E-04
     +,   7.8245072E-04,   7.8199810E-04,   7.8152778E-04
     +,   7.8088028E-04,   7.7990146E-04,   7.7844528E-04
     +,   7.7637809E-04,   7.7357737E-04,   7.6993683E-04
     +,   7.6536677E-04,   7.5979636E-04,   7.5317279E-04
     +,   7.4546365E-04,   7.3665468E-04,   7.2675146E-04
     +,   7.1577798E-04,   7.0377416E-04,   6.9079502E-04
     +,   6.7690900E-04,   6.6219724E-04,   6.4674753E-04
     +,   6.3065410E-04,   6.1401777E-04,   5.9693912E-04
     +,   5.7951891E-04,   5.6185678E-04,   5.4404815E-04
     +,   5.2618288E-04,   5.0834380E-04,   4.9060752E-04
     +,   4.7304310E-04,   4.5570964E-04,   4.3865832E-04
     +,   4.2193348E-04,   4.0556950E-04,   3.8959557E-04
     +,   3.7403146E-04,   3.5889359E-04,   3.4419060E-04
     +,   3.2992859E-04,   3.1610767E-04,   3.0272704E-04
     +,   2.8978154E-04,   2.7726556E-04,   2.6517152E-04
     +,   2.5349061E-04,   2.4221481E-04,   2.3133427E-04
     +,   2.2084093E-04,   2.1072515E-04,   2.0097909E-04
     +,   1.9159399E-04,   1.8256260E-04,   1.7387679E-04
     +,   1.6552981E-04,   1.5751402E-04,   1.4982292E-04
     +,   1.4244922E-04,   1.3538628E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz80 = Yx/0.265106382978723
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz85(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.4584533E-05,   4.6118133E-05
     +,   4.7722511E-05,   4.9402322E-05,   5.1162457E-05
     +,   5.3007916E-05,   5.4943928E-05,   5.6975787E-05
     +,   5.9108912E-05,   6.1348925E-05,   6.3701264E-05
     +,   6.6171553E-05,   6.8765250E-05,   7.1487775E-05
     +,   7.4344345E-05,   7.7340061E-05,   8.0479636E-05
     +,   8.3767547E-05,   8.7207845E-05,   9.0804067E-05
     +,   9.4559262E-05,   9.8475866E-05,   1.0255555E-04
     +,   1.0679953E-04,   1.1120769E-04,   1.1577951E-04
     +,   1.2051332E-04,   1.2540646E-04,   1.3045521E-04
     +,   1.3565483E-04,   1.4099937E-04,   1.4648179E-04
     +,   1.5209388E-04,   1.5782616E-04,   1.6366818E-04
     +,   1.6960813E-04,   1.7563325E-04,   1.8172951E-04
     +,   1.8788229E-04,   1.9407530E-04,   2.0029233E-04
     +,   2.0651560E-04,   2.1272709E-04,   2.1890808E-04
     +,   2.2503961E-04,   2.3110225E-04,   2.3707654E-04
     +,   2.4294318E-04,   2.4868271E-04,   2.5427632E-04
     +,   2.5970556E-04,   2.6495266E-04,   2.7000046E-04
     +,   2.7483323E-04,   2.7943568E-04,   2.8379424E-04
     +,   2.8789646E-04,   2.9173124E-04,   2.9528927E-04
     +,   2.9856255E-04,   3.0154502E-04,   3.0423224E-04
     +,   3.0662134E-04,   3.0871172E-04,   3.1050411E-04
     +,   3.1200110E-04,   3.1320757E-04,   3.1412940E-04
     +,   3.1477481E-04,   3.1515359E-04,   3.1527755E-04
     +,   3.1515997E-04,   3.1481619E-04,   3.1426339E-04
     +,   3.1352096E-04,   3.1261035E-04,   3.1155552E-04
     +,   3.1038298E-04,   3.0912209E-04,   3.0780555E-04
     +,   3.0646933E-04,   3.0515384E-04,   3.0390342E-04
     +,   3.0276721E-04,   3.0179918E-04,   3.0105902E-04
     +,   3.0061201E-04,   3.0052970E-04,   3.0089039E-04
     +,   3.0177928E-04,   3.0329003E-04,   3.0552538E-04
     +,   3.0859892E-04,   3.1263786E-04,   3.1778519E-04
     +,   3.2420404E-04,   3.3208248E-04,   3.4163706E-04
     +,   3.5312041E-04,   3.6682305E-04,   3.8308094E-04
     +,   4.0227320E-04,   4.2482698E-04,   4.5120908E-04
     +,   4.8192640E-04,   5.1751733E-04,   5.5854570E-04
     +,   6.0560205E-04,   6.5931829E-04,   7.2039251E-04
     +,   7.8962604E-04,   8.6800649E-04,   9.5676945E-04
     +,   1.0575068E-03,   1.1722122E-03,   1.3033311E-03
     +,   1.4536866E-03,   1.6263752E-03,   1.8244984E-03
     +,   2.0509132E-03,   2.3079382E-03,   2.5971979E-03
     +,   2.9197445E-03,   3.2766045E-03,   3.6696745E-03
     +,   4.1028331E-03,   4.5829243E-03,   5.1196199E-03
     +,   5.7239630E-03,   6.4048683E-03,   7.1650557E-03
     +,   7.9975901E-03,   8.8865235E-03,   9.8127956E-03
     +,   1.0765801E-02,   1.1754915E-02,   1.2812625E-02
     +,   1.3982101E-02,   1.5290773E-02,   1.6725821E-02
     +,   1.8232640E-02,   1.9745070E-02,   2.1227999E-02
     +,   2.2697899E-02,   2.4201620E-02,   2.5771344E-02
     +,   2.7394054E-02,   2.9013308E-02,   3.0543081E-02
     +,   3.1865031E-02,   3.2822505E-02,   3.3256073E-02
     +,   3.3085383E-02,   3.2367013E-02,   3.1255893E-02
     +,   2.9895699E-02,   2.8342549E-02,   2.6586996E-02
     +,   2.4635883E-02,   2.2566356E-02,   2.0510709E-02
     +,   1.8598340E-02,   1.6902784E-02,   1.5424706E-02
     +,   1.4111754E-02,   1.2897790E-02,   1.1737674E-02
     +,   1.0622082E-02,   9.5713846E-03,   8.6182971E-03
     +,   7.7907788E-03,   7.1020881E-03,   6.5491027E-03
     +,   6.1163497E-03,   5.7820752E-03,   5.5236518E-03
     +,   5.3212130E-03,   5.1592155E-03,   5.0264117E-03
     +,   4.9150800E-03,   4.8200106E-03,   4.7375676E-03
     +,   4.6649892E-03,   4.5999871E-03,   4.5404714E-03
     +,   4.4844998E-03,   4.4301869E-03,   4.3757395E-03
     +,   4.3193926E-03,   4.2594643E-03,   4.1943137E-03
     +,   4.1224142E-03,   4.0424247E-03,   3.9533069E-03
     +,   3.8544196E-03,   3.7456453E-03,   3.6274570E-03
     +,   3.5009477E-03,   3.3677570E-03,   3.2299939E-03
     +,   3.0900834E-03,   2.9505999E-03,   2.8140671E-03
     +,   2.6828190E-03,   2.5588928E-03,   2.4439143E-03
     +,   2.3390986E-03,   2.2452476E-03,   2.1627815E-03
     +,   2.0917926E-03,   2.0321175E-03,   1.9833934E-03
     +,   1.9451062E-03,   1.9166338E-03,   1.8972730E-03
     +,   1.8862543E-03,   1.8827437E-03,   1.8858409E-03
     +,   1.8945850E-03,   1.9079318E-03,   1.9247641E-03
     +,   1.9438933E-03,   1.9640694E-03,   1.9839974E-03
     +,   2.0023673E-03,   2.0178906E-03,   2.0293335E-03
     +,   2.0355682E-03,   2.0356101E-03,   2.0286643E-03
     +,   2.0141597E-03,   1.9917756E-03,   1.9614534E-03
     +,   1.9234027E-03,   1.8780910E-03,   1.8262200E-03
     +,   1.7686823E-03,   1.7065330E-03,   1.6409283E-03
     +,   1.5730732E-03,   1.5041691E-03,   1.4353723E-03
     +,   1.3677486E-03,   1.3022296E-03,   1.2396008E-03
     +,   1.1804823E-03,   1.1253305E-03,   1.0744252E-03
     +,   1.0278971E-03,   9.8574255E-04,   9.4783690E-04
     +,   9.1396132E-04,   8.8383025E-04,   8.5710775E-04
     +,   8.3342922E-04,   8.1242004E-04,   7.9371053E-04
     +,   7.7694684E-04,   7.6179829E-04,   7.4796187E-04
     +,   7.3516916E-04,   7.2318281E-04,   7.1179774E-04
     +,   7.0083846E-04,   6.9015764E-04,   6.7963236E-04
     +,   6.6916004E-04,   6.5865699E-04,   6.4805528E-04
     +,   6.3729833E-04,   6.2634074E-04,   6.1514636E-04
     +,   6.0368649E-04,   5.9193803E-04,   5.7988364E-04
     +,   5.6751189E-04,   5.5481493E-04,   5.4179080E-04
     +,   5.2844075E-04,   5.1477179E-04,   5.0079345E-04
     +,   4.8652268E-04,   4.7197731E-04,   4.5718229E-04
     +,   4.4216414E-04,   4.2695520E-04,   4.1158960E-04
     +,   3.9610433E-04,   3.8054097E-04,   3.6494012E-04
     +,   3.4934658E-04,   3.3380371E-04,   3.1835731E-04
     +,   3.0305100E-04,   2.8792961E-04,   2.7303441E-04
     +,   2.5840721E-04,   2.4408550E-04,   2.3010609E-04
     +,   2.1650102E-04,   2.0330075E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz85 = Yx/0.268234042553191
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz90(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.0713491E-05,   3.1827880E-05
     +,   3.2983196E-05,   3.4180372E-05,   3.5420315E-05
     +,   3.6703816E-05,   3.8031576E-05,   3.9404233E-05
     +,   4.0822237E-05,   4.2286043E-05,   4.3795884E-05
     +,   4.5351895E-05,   4.6954083E-05,   4.8602287E-05
     +,   5.0296247E-05,   5.2035517E-05,   5.3819520E-05
     +,   5.5647572E-05,   5.7518802E-05,   5.9432252E-05
     +,   6.1386825E-05,   6.3381311E-05,   6.5414410E-05
     +,   6.7484812E-05,   6.9590998E-05,   7.1731607E-05
     +,   7.3905096E-05,   7.6110009E-05,   7.8344936E-05
     +,   8.0608501E-05,   8.2899431E-05,   8.5216583E-05
     +,   8.7559005E-05,   8.9925881E-05,   9.2316564E-05
     +,   9.4730756E-05,   9.7168340E-05,   9.9629462E-05
     +,   1.0211475E-04,   1.0462485E-04,   1.0716099E-04
     +,   1.0972461E-04,   1.1231749E-04,   1.1494171E-04
     +,   1.1759967E-04,   1.2029405E-04,   1.2302773E-04
     +,   1.2580382E-04,   1.2862556E-04,   1.3149629E-04
     +,   1.3441936E-04,   1.3739814E-04,   1.4043575E-04
     +,   1.4353530E-04,   1.4669928E-04,   1.4993019E-04
     +,   1.5322964E-04,   1.5659904E-04,   1.6003878E-04
     +,   1.6354870E-04,   1.6712771E-04,   1.7077381E-04
     +,   1.7448381E-04,   1.7825376E-04,   1.8207857E-04
     +,   1.8595155E-04,   1.8986556E-04,   1.9381171E-04
     +,   1.9778042E-04,   2.0176063E-04,   2.0574071E-04
     +,   2.0970765E-04,   2.1364821E-04,   2.1754793E-04
     +,   2.2139226E-04,   2.2516637E-04,   2.2885509E-04
     +,   2.3244330E-04,   2.3591667E-04,   2.3926143E-04
     +,   2.4246430E-04,   2.4551380E-04,   2.4839942E-04
     +,   2.5111259E-04,   2.5364698E-04,   2.5599849E-04
     +,   2.5816553E-04,   2.6014968E-04,   2.6195581E-04
     +,   2.6359214E-04,   2.6507108E-04,   2.6640884E-04
     +,   2.6762651E-04,   2.6875004E-04,   2.6981079E-04
     +,   2.7084583E-04,   2.7189890E-04,   2.7302085E-04
     +,   2.7427054E-04,   2.7571566E-04,   2.7743401E-04
     +,   2.7951476E-04,   2.8206015E-04,   2.8518593E-04
     +,   2.8902531E-04,   2.9372907E-04,   2.9946846E-04
     +,   3.0643668E-04,   3.1485275E-04,   3.2496211E-04
     +,   3.3703938E-04,   3.5139197E-04,   3.6835924E-04
     +,   3.8831763E-04,   4.1167776E-04,   4.3888827E-04
     +,   4.7042809E-04,   5.0680758E-04,   5.4855272E-04
     +,   5.9619662E-04,   6.5025943E-04,   7.1121607E-04
     +,   7.7946781E-04,   8.5530878E-04,   9.3888404E-04
     +,   1.0301414E-03,   1.1288211E-03,   1.2344118E-03
     +,   1.3461824E-03,   1.4631852E-03,   1.5843569E-03
     +,   1.7085944E-03,   1.8349446E-03,   1.9627616E-03
     +,   2.0919531E-03,   2.2231848E-03,   2.3580778E-03
     +,   2.4993340E-03,   2.6508081E-03,   2.8174231E-03
     +,   3.0049484E-03,   3.2196681E-03,   3.4679049E-03
     +,   3.7553723E-03,   4.0864144E-03,   4.4633774E-03
     +,   4.8861033E-03,   5.3519225E-03,   5.8564702E-03
     +,   6.3954652E-03,   6.9673122E-03,   7.5762635E-03
     +,   8.2353698E-03,   8.9682154E-03,   9.8080672E-03
     +,   1.0793786E-02,   1.1962142E-02,   1.3336398E-02
     +,   1.4912681E-02,   1.6650613E-02,   1.8479584E-02
     +,   2.0325087E-02,   2.2138014E-02,   2.3892665E-02
     +,   2.5537565E-02,   2.6940499E-02,   2.7900884E-02
     +,   2.8249538E-02,   2.7962457E-02,   2.7189733E-02
     +,   2.6174342E-02,   2.5129037E-02,   2.4156684E-02
     +,   2.3249831E-02,   2.2344308E-02,   2.1381436E-02
     +,   2.0351304E-02,   1.9307114E-02,   1.8346293E-02
     +,   1.7564682E-02,   1.7011240E-02,   1.6671509E-02
     +,   1.6485373E-02,   1.6378278E-02,   1.6284531E-02
     +,   1.6156320E-02,   1.5962519E-02,   1.5682891E-02
     +,   1.5302272E-02,   1.4809299E-02,   1.4200521E-02
     +,   1.3487194E-02,   1.2698030E-02,   1.1874356E-02
     +,   1.1058932E-02,   1.0284689E-02,   9.5690768E-03
     +,   8.9158770E-03,   8.3220145E-03,   7.7846069E-03
     +,   7.3046619E-03,   6.8863779E-03,   6.5339850E-03
     +,   6.2484746E-03,   6.0258252E-03,   5.8570351E-03
     +,   5.7296855E-03,   5.6299320E-03,   5.5443575E-03
     +,   5.4613049E-03,   5.3716907E-03,   5.2693225E-03
     +,   5.1508290E-03,   5.0153472E-03,   4.8641274E-03
     +,   4.6999338E-03,   4.5265285E-03,   4.3480652E-03
     +,   4.1686315E-03,   3.9918358E-03,   3.8205017E-03
     +,   3.6565179E-03,   3.5008283E-03,   3.3534984E-03
     +,   3.2139104E-03,   3.0809890E-03,   2.9534576E-03
     +,   2.8300541E-03,   2.7096886E-03,   2.5915650E-03
     +,   2.4752531E-03,   2.3606638E-03,   2.2480288E-03
     +,   2.1378242E-03,   2.0307270E-03,   1.9275033E-03
     +,   1.8289598E-03,   1.7358818E-03,   1.6489766E-03
     +,   1.5688286E-03,   1.4958748E-03,   1.4303811E-03
     +,   1.3724328E-03,   1.3219229E-03,   1.2785591E-03
     +,   1.2418869E-03,   1.2112970E-03,   1.1860605E-03
     +,   1.1653542E-03,   1.1483042E-03,   1.1340115E-03
     +,   1.1215887E-03,   1.1101899E-03,   1.0990375E-03
     +,   1.0874384E-03,   1.0748021E-03,   1.0606495E-03
     +,   1.0446148E-03,   1.0264472E-03,   1.0060027E-03
     +,   9.8324043E-04,   9.5820968E-04,   9.3103648E-04
     +,   9.0190989E-04,   8.7107404E-04,   8.3880400E-04
     +,   8.0540171E-04,   7.7117915E-04,   7.3644979E-04
     +,   7.0151611E-04,   6.6666270E-04,   6.3215394E-04
     +,   5.9822656E-04,   5.6508475E-04,   5.3290173E-04
     +,   5.0182187E-04,   4.7195435E-04,   4.4338440E-04
     +,   4.1616589E-04,   3.9033240E-04,   3.6589388E-04
     +,   3.4284539E-04,   3.2116394E-04,   3.0081772E-04
     +,   2.8176294E-04,   2.6395102E-04,   2.4732703E-04
     +,   2.3183266E-04,   2.1740951E-04,   2.0399665E-04
     +,   1.9153529E-04,   1.7996604E-04,   1.6923265E-04
     +,   1.5927925E-04,   1.5005357E-04,   1.4150448E-04
     +,   1.3358428E-04,   1.2624664E-04,   1.1944868E-04
     +,   1.1314884E-04,   1.0730876E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz90 = Yx/0.267936170212766
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ttz95(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.3113596E-05,   3.3815391E-05
     +,   3.4512566E-05,   3.5204423E-05,   3.5890323E-05
     +,   3.6569647E-05,   3.7241873E-05,   3.7906510E-05
     +,   3.8563139E-05,   3.9211489E-05,   3.9851340E-05
     +,   4.0482599E-05,   4.1105293E-05,   4.1719613E-05
     +,   4.2325908E-05,   4.2924657E-05,   4.3516600E-05
     +,   4.4102650E-05,   4.4683922E-05,   4.5261822E-05
     +,   4.5837995E-05,   4.6414374E-05,   4.6993187E-05
     +,   4.7577021E-05,   4.8168720E-05,   4.8771548E-05
     +,   4.9389109E-05,   5.0025388E-05,   5.0684761E-05
     +,   5.1371993E-05,   5.2092255E-05,   5.2851134E-05
     +,   5.3654589E-05,   5.4508950E-05,   5.5420980E-05
     +,   5.6397723E-05,   5.7446563E-05,   5.8575173E-05
     +,   5.9791546E-05,   6.1103667E-05,   6.2519859E-05
     +,   6.4048414E-05,   6.5697583E-05,   6.7475579E-05
     +,   6.9390422E-05,   7.1449795E-05,   7.3661053E-05
     +,   7.6030985E-05,   7.8565819E-05,   8.1271013E-05
     +,   8.4151172E-05,   8.7209948E-05,   9.0449837E-05
     +,   9.3872346E-05,   9.7477241E-05,   1.0126340E-04
     +,   1.0522784E-04,   1.0936616E-04,   1.1367226E-04
     +,   1.1813844E-04,   1.2275530E-04,   1.2751184E-04
     +,   1.3239497E-04,   1.3739057E-04,   1.4248291E-04
     +,   1.4765417E-04,   1.5288607E-04,   1.5815845E-04
     +,   1.6345071E-04,   1.6874081E-04,   1.7400675E-04
     +,   1.7922564E-04,   1.8437482E-04,   1.8943139E-04
     +,   1.9437318E-04,   1.9917857E-04,   2.0382667E-04
     +,   2.0829774E-04,   2.1257375E-04,   2.1663844E-04
     +,   2.2047675E-04,   2.2407649E-04,   2.2742714E-04
     +,   2.3052124E-04,   2.3335320E-04,   2.3592076E-04
     +,   2.3822390E-04,   2.4026571E-04,   2.4205190E-04
     +,   2.4359104E-04,   2.4489441E-04,   2.4597606E-04
     +,   2.4685229E-04,   2.4754225E-04,   2.4806708E-04
     +,   2.4845023E-04,   2.4871717E-04,   2.4889500E-04
     +,   2.4901275E-04,   2.4910062E-04,   2.4919020E-04
     +,   2.4931403E-04,   2.4950574E-04,   2.4979931E-04
     +,   2.5022958E-04,   2.5083154E-04,   2.5164016E-04
     +,   2.5269049E-04,   2.5401724E-04,   2.5565483E-04
     +,   2.5763660E-04,   2.5999537E-04,   2.6276283E-04
     +,   2.6596899E-04,   2.6964274E-04,   2.7381085E-04
     +,   2.7849805E-04,   2.8372731E-04,   2.8951833E-04
     +,   2.9588907E-04,   3.0285481E-04,   3.1042733E-04
     +,   3.1861663E-04,   3.2742973E-04,   3.3687279E-04
     +,   3.4694851E-04,   3.5766108E-04,   3.6901369E-04
     +,   3.8101315E-04,   3.9366994E-04,   4.0700356E-04
     +,   4.2104447E-04,   4.3584162E-04,   4.5146703E-04
     +,   4.6802603E-04,   4.8566525E-04,   5.0458411E-04
     +,   5.2504579E-04,   5.4739130E-04,   5.7205028E-04
     +,   5.9954886E-04,   6.3051749E-04,   6.6569541E-04
     +,   7.0592522E-04,   7.5213623E-04,   8.0533209E-04
     +,   8.6655741E-04,   9.3685609E-04,   1.0172250E-03
     +,   1.1085653E-03,   1.2116233E-03,   1.3269233E-03
     +,   1.4547140E-03,   1.5949291E-03,   1.7471474E-03
     +,   1.9105508E-03,   2.0839327E-03,   2.2657239E-03
     +,   2.4540224E-03,   2.6466483E-03,   2.8412705E-03
     +,   3.0355218E-03,   3.2271631E-03,   3.4142907E-03
     +,   3.5955990E-03,   3.7706473E-03,   3.9401338E-03
     +,   4.1061826E-03,   4.2725285E-03,   4.4445544E-03
     +,   4.6291454E-03,   4.8345500E-03,   5.0704903E-03
     +,   5.3489385E-03,   5.6857290E-03,   6.1027030E-03
     +,   6.6286675E-03,   7.2968602E-03,   8.1372224E-03
     +,   9.1648037E-03,   1.0370085E-02,   1.1719520E-02
     +,   1.3170404E-02,   1.4693035E-02,   1.6284300E-02
     +,   1.7961185E-02,   1.9738734E-02,   2.1613827E-02
     +,   2.3570230E-02,   2.5592016E-02,   2.7650995E-02
     +,   2.9664805E-02,   3.1486791E-02,   3.2974616E-02
     +,   3.4075182E-02,   3.4812018E-02,   3.5187963E-02
     +,   3.5139233E-02,   3.4593694E-02,   3.3551078E-02
     +,   3.2125741E-02,   3.0555790E-02,   2.9147960E-02
     +,   2.8114481E-02,   2.7388416E-02,   2.6614869E-02
     +,   2.5391959E-02,   2.3573888E-02,   2.1367548E-02
     +,   1.9163223E-02,   1.7282782E-02,   1.5846061E-02
     +,   1.4796196E-02,   1.3998955E-02,   1.3327313E-02
     +,   1.2701130E-02,   1.2089202E-02,   1.1491727E-02
     +,   1.0918215E-02,   1.0372868E-02,   9.8510152E-03
     +,   9.3435617E-03,   8.8425865E-03,   8.3442796E-03
     +,   7.8491420E-03,   7.3612165E-03,   6.8871561E-03
     +,   6.4352173E-03,   6.0137012E-03,   5.6291427E-03
     +,   5.2847355E-03,   4.9796328E-03,   4.7094417E-03
     +,   4.4676880E-03,   4.2475360E-03,   4.0431879E-03
     +,   3.8507089E-03,   3.6680938E-03,   3.4948536E-03
     +,   3.3313734E-03,   3.1783090E-03,   3.0361630E-03
     +,   2.9050773E-03,   2.7847707E-03,   2.6746367E-03
     +,   2.5738692E-03,   2.4815700E-03,   2.3968297E-03
     +,   2.3187895E-03,   2.2466776E-03,   2.1797952E-03
     +,   2.1175218E-03,   2.0593088E-03,   2.0046574E-03
     +,   1.9531036E-03,   1.9042068E-03,   1.8575378E-03
     +,   1.8126764E-03,   1.7691926E-03,   1.7266683E-03
     +,   1.6846958E-03,   1.6428943E-03,   1.6009188E-03
     +,   1.5584772E-03,   1.5153460E-03,   1.4713699E-03
     +,   1.4264653E-03,   1.3806272E-03,   1.3339138E-03
     +,   1.2864349E-03,   1.2383452E-03,   1.1898293E-03
     +,   1.1410881E-03,   1.0923237E-03,   1.0437344E-03
     +,   9.9550944E-04,   9.4781612E-04,   9.0080936E-04
     +,   8.5461925E-04,   8.0936379E-04,   7.6513941E-04
     +,   7.2203483E-04,   6.8012218E-04,   6.3947006E-04
     +,   6.0013385E-04,   5.6216825E-04,   5.2561762E-04
     +,   4.9052073E-04,   4.5691355E-04,   4.2482070E-04
     +,   3.9426281E-04,   3.6524897E-04,   3.3778296E-04
     +,   3.1185616E-04,   2.8745446E-04,   2.6455132E-04
     +,   2.4311530E-04,   2.2310426E-04,   2.0447209E-04
     +,   1.8716454E-04,   1.7112489E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ttz95 = Yx/0.29236170212766
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_haonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0129034E-10,   7.9264190E-10
     +,   1.2423821E-09,   1.9302933E-09,   2.9728993E-09
     +,   4.5386583E-09,   6.8685386E-09,   1.0303634E-08
     +,   1.5321582E-08,   2.2584434E-08,   3.2999282E-08
     +,   4.7795773E-08,   6.8622079E-08,   9.7662607E-08
     +,   1.3777868E-07,   1.9267512E-07,   2.6709071E-07
     +,   3.6701309E-07,   4.9991257E-07,   6.7498786E-07
     +,   9.0341575E-07,   1.1985854E-06,   1.5762976E-06
     +,   2.0549476E-06,   2.6555178E-06,   3.4016471E-06
     +,   4.3193559E-06,   5.4367351E-06,   6.7833971E-06
     +,   8.3896866E-06,   1.0285701E-05,   1.2500051E-05
     +,   1.5058420E-05,   1.7981940E-05,   2.1285479E-05
     +,   2.4975832E-05,   2.9049999E-05,   3.3493539E-05
     +,   3.8279624E-05,   4.3367279E-05,   4.8702070E-05
     +,   5.4215383E-05,   5.9825681E-05,   6.5439934E-05
     +,   7.0955881E-05,   7.6264878E-05,   8.1255333E-05
     +,   8.5816537E-05,   8.9842681E-05,   9.3237031E-05
     +,   9.5915806E-05,   9.7811702E-05,   9.8876793E-05
     +,   9.9084784E-05,   9.8432181E-05,   9.6938689E-05
     +,   9.4646610E-05,   9.1619288E-05,   8.7938730E-05
     +,   8.3702580E-05,   7.9020676E-05,   7.4011194E-05
     +,   6.8797155E-05,   6.3502070E-05,   5.8246893E-05
     +,   5.3147589E-05,   4.8311500E-05,   4.3836812E-05
     +,   3.9809955E-05,   3.6306013E-05,   3.3387303E-05
     +,   3.1104217E-05,   2.9494673E-05,   2.8584947E-05
     +,   2.8389539E-05,   2.8911581E-05,   3.0142777E-05
     +,   3.2063228E-05,   3.4641405E-05,   3.7833855E-05
     +,   4.1584546E-05,   4.5825582E-05,   5.0476359E-05
     +,   5.5445256E-05,   6.0629405E-05,   6.5917578E-05
     +,   7.1190967E-05,   7.6327240E-05,   8.1202350E-05
     +,   8.5695276E-05,   8.9691268E-05,   9.3085415E-05
     +,   9.5786687E-05,   9.7721408E-05,   9.8835619E-05
     +,   9.9097066E-05,   9.8496610E-05,   9.7048272E-05
     +,   9.4788382E-05,   9.1774091E-05,   8.8080473E-05
     +,   8.3797910E-05,   7.9027479E-05,   7.3878058E-05
     +,   6.8461086E-05,   6.2887077E-05,   5.7262354E-05
     +,   5.1685456E-05,   4.6244229E-05,   4.1014275E-05
     +,   3.6058198E-05,   3.1423959E-05,   2.7146223E-05
     +,   2.3245853E-05,   1.9732113E-05,   1.6603088E-05
     +,   1.3848296E-05,   1.1449614E-05,   9.3837798E-06
     +,   7.6235010E-06,   6.1392839E-06,   4.9008408E-06
     +,   3.8780768E-06,   3.0419490E-06,   2.3652317E-06
     +,   1.8230074E-06,   1.3928020E-06,   1.0548331E-06
     +,   7.9188789E-07,   5.8930141E-07,   4.3470698E-07
     +,   3.1787013E-07,   2.3040310E-07,   1.6554672E-07
     +,   1.1790794E-07,   8.3243464E-08,   5.8256859E-08
     +,   4.0414601E-08,   2.7791970E-08,   1.8944579E-08
     +,   1.2800891E-08,   8.5741370E-09,   5.6928560E-09
     +,   3.7467456E-09,   2.4444049E-09,   1.5808204E-09
     +,   1.0133869E-09,   6.4395750E-10,   4.0563491E-10
     +,   2.5328148E-10,   1.5676697E-10,   9.6182215E-11
     +,   5.8496749E-11,   3.5266193E-11,   2.1075020E-11
     +,   1.2484381E-11,   7.3309908E-12,   4.2672563E-12
     +,   2.4621589E-12,   1.4082550E-12,   7.9842860E-13
     +,   4.4871672E-13,   2.4997577E-13,   1.3804553E-13
     +,   7.5567726E-14,   4.1004353E-14,   2.2055395E-14
     +,   1.1759737E-14,   6.2154113E-15,   3.2562934E-15
     +,   1.6910867E-15,   8.7057660E-16,   4.4426132E-16
     +,   2.2472409E-16,   1.1268370E-16,   5.6009346E-17
     +,   2.7595688E-17,   1.3477545E-17,   6.5250004E-18
     +,   3.1314105E-18,   1.4896322E-18,   7.0243490E-19
     +,   3.2834790E-19,   1.5214359E-19,   6.9879436E-20
     +,   3.1815205E-20,   1.4358959E-20,   6.4239283E-21
     +,   2.8487529E-21,   1.2523096E-21,   5.4570540E-22
     +,   2.3571166E-22,   1.0092416E-22,   4.2836151E-23
     +,   1.8022512E-23,   7.5161681E-24,   3.1072099E-24
     +,   1.2733395E-24,   5.1725822E-25,   2.0828050E-25
     +,   8.3134137E-26,   3.2893592E-26,   1.2901332E-26
     +,   5.0157101E-27,   1.9330131E-27,   7.3845677E-28
     +,   2.7963728E-28,   1.0496664E-28,   3.9058178E-29
     +,   1.4406626E-29,   5.2673300E-30,   1.9089964E-30
     +,   6.8584472E-31,   2.4424993E-31,   8.6222270E-32
     +,   3.0171067E-32,   1.0465774E-32,   3.5986536E-33
     +,   1.2265399E-33,   4.1440928E-34,   1.3879279E-34
     +,   4.6076268E-35,   1.5162843E-35,   4.9463721E-36
     +,   1.5994936E-36,   5.1268968E-37,   1.6289694E-37
     +,   5.1307092E-38,   1.6018858E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_haonly_eez_mass = Yx/0.00123725
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_haonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.1259808E-07,   9.4884894E-07
     +,   1.2542324E-06,   1.6458398E-06,   2.1440062E-06
     +,   2.7726351E-06,   3.5594958E-06,   4.5364136E-06
     +,   5.7393668E-06,   7.2085099E-06,   8.9878477E-06
     +,   1.1124862E-05,   1.3669799E-05,   1.6674710E-05
     +,   2.0192176E-05,   2.4273737E-05,   2.8968014E-05
     +,   3.4318597E-05,   4.0361658E-05,   4.7123449E-05
     +,   5.4617754E-05,   6.2843341E-05,   7.1781506E-05
     +,   8.1394748E-05,   9.1623551E-05,   1.0238764E-04
     +,   1.1358388E-04,   1.2508777E-04,   1.3675456E-04
     +,   1.4842190E-04,   1.5991284E-04,   1.7104020E-04
     +,   1.8161134E-04,   1.9143349E-04,   2.0031977E-04
     +,   2.0809499E-04,   2.1460137E-04,   2.1970402E-04
     +,   2.2329610E-04,   2.2530185E-04,   2.2568043E-04
     +,   2.2442697E-04,   2.2157330E-04,   2.1718703E-04
     +,   2.1136952E-04,   2.0425270E-04,   1.9599496E-04
     +,   1.8677641E-04,   1.7679356E-04,   1.6625364E-04
     +,   1.5536931E-04,   1.4435321E-04,   1.3341333E-04
     +,   1.2274782E-04,   1.1254347E-04,   1.0297044E-04
     +,   9.4182025E-05,   8.6312619E-05,   7.9477060E-05
     +,   7.3770563E-05,   6.9268790E-05,   6.6028384E-05
     +,   6.4087624E-05,   6.3466563E-05,   6.4167900E-05
     +,   6.6176974E-05,   6.9462112E-05,   7.3973992E-05
     +,   7.9646386E-05,   8.6394663E-05,   9.4117204E-05
     +,   1.0269372E-04,   1.1198770E-04,   1.2184494E-04
     +,   1.3209727E-04,   1.4256351E-04,   1.5305182E-04
     +,   1.6336344E-04,   1.7329761E-04,   1.8265532E-04
     +,   1.9124323E-04,   1.9888084E-04,   2.0540318E-04
     +,   2.1066754E-04,   2.1455603E-04,   2.1698046E-04
     +,   2.1788402E-04,   2.1724343E-04,   2.1506938E-04
     +,   2.1140580E-04,   2.0632803E-04,   1.9994040E-04
     +,   1.9237252E-04,   1.8377397E-04,   1.7430985E-04
     +,   1.6415637E-04,   1.5349330E-04,   1.4250120E-04
     +,   1.3135381E-04,   1.2021653E-04,   1.0923967E-04
     +,   9.8558427E-05,   8.8287990E-05,   7.8524798E-05
     +,   6.9343849E-05,   6.0799917E-05,   5.2928994E-05
     +,   4.5749057E-05,   3.9261464E-05,   3.3453711E-05
     +,   2.8302200E-05,   2.3773297E-05,   1.9826990E-05
     +,   1.6417889E-05,   1.3498211E-05,   1.1018642E-05
     +,   8.9305577E-06,   7.1865729E-06,   5.7420107E-06
     +,   4.5551410E-06,   3.5878327E-06,   2.8058093E-06
     +,   2.1786275E-06,   1.6795935E-06,   1.2856329E-06
     +,   9.7707868E-07,   7.3728239E-07,   5.5237990E-07
     +,   4.1089754E-07,   3.0347942E-07,   2.2254416E-07
     +,   1.6203290E-07,   1.1713365E-07,   8.4073676E-08
     +,   5.9914889E-08,   4.2393577E-08,   2.9782466E-08
     +,   2.0774129E-08,   1.4387337E-08,   9.8930153E-09
     +,   6.7541697E-09,   4.5784314E-09,   3.0814653E-09
     +,   2.0591508E-09,   1.3662188E-09,   9.0001234E-10
     +,   5.8866234E-10,   3.8227804E-10,   2.4648772E-10
     +,   1.5779968E-10,   1.0030128E-10,   6.3299838E-11
     +,   3.9664421E-11,   2.4677147E-11,   1.5243291E-11
     +,   9.3488351E-12,   5.6929604E-12,   3.4420396E-12
     +,   2.0662434E-12,   1.2315460E-12,   7.2881149E-13
     +,   4.2822066E-13,   2.4981371E-13,   1.4469998E-13
     +,   8.3217768E-14,   4.7517268E-14,   2.6939102E-14
     +,   1.5164131E-14,   8.4751643E-15,   4.7029090E-15
     +,   2.5910776E-15,   1.4174203E-15,   7.6986232E-16
     +,   4.1515827E-16,   2.2228942E-16,   1.1817351E-16
     +,   6.2374586E-17,   3.2688226E-17,   1.7009027E-17
     +,   8.7874846E-18,   4.5074933E-18,   2.2956295E-18
     +,   1.1608416E-18,   5.8282670E-19,   2.9053134E-19
     +,   1.4379436E-19,   7.0663649E-20,   3.4478542E-20
     +,   1.6702589E-20,   8.0338851E-21,   3.8367589E-21
     +,   1.8192274E-21,   8.5645919E-22,   4.0034232E-22
     +,   1.8580258E-22,   8.5616475E-23,   3.9170424E-23
     +,   1.7793763E-23,   8.0254796E-24,   3.5938475E-24
     +,   1.5978717E-24,   7.0539848E-25,   3.0918666E-25
     +,   1.3455270E-25,   5.8139462E-26,   2.4942783E-26
     +,   1.0624396E-26,   4.4932157E-27,   1.8867694E-27
     +,   7.8664247E-28,   3.2562403E-28,   1.3383020E-28
     +,   5.4613337E-29,   2.2127907E-29,   8.9014834E-30
     +,   3.5553427E-30,   1.4099674E-30,   5.5517987E-31
     +,   2.1704034E-31,   8.4247251E-32,   3.2468814E-32
     +,   1.2423934E-32,   4.7200929E-33,   1.7805215E-33
     +,   6.6687209E-34,   2.4797999E-34,   9.1556557E-35
     +,   3.3563773E-35,   1.2216517E-35,   4.4147515E-36
     +,   1.5840188E-36,   5.6431697E-37,   1.9961100E-37
     +,   7.0101060E-38,   2.4444248E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_haonly_qq_mass = Yx/0.003051125
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_haonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9843986E-19,   1.5479359E-18
     +,   2.9802267E-18,   5.6981482E-18,   1.0819437E-17
     +,   2.0401498E-17,   3.8203674E-17,   7.1045458E-17
     +,   1.3120429E-16,   2.4063089E-16,   4.3827028E-16
     +,   7.9271871E-16,   1.4239105E-15,   2.5399943E-15
     +,   4.4995521E-15,   7.9157550E-15,   1.3829383E-14
     +,   2.3993750E-14,   4.1341056E-14,   7.0737809E-14
     +,   1.2020104E-13,   2.0283899E-13,   3.3992099E-13
     +,   5.6571620E-13,   9.3497183E-13,   1.5345788E-12
     +,   2.5013052E-12,   4.0488437E-12,   6.5085199E-12
     +,   1.0390128E-11,   1.6471992E-11,   2.5933394E-11
     +,   4.0547066E-11,   6.2957480E-11,   9.7078463E-11
     +,   1.4865739E-10,   2.2606730E-10,   3.4140912E-10
     +,   5.1204296E-10,   7.6264201E-10,   1.1280481E-09
     +,   1.6570079E-09,   2.4171929E-09,   3.5017866E-09
     +,   5.0380100E-09,   7.1981465E-09,   1.0213529E-08
     +,   1.4392130E-08,   2.0140483E-08,   2.7990543E-08
     +,   3.8632358E-08,   5.2953073E-08,   7.2082692E-08
     +,   9.7449394E-08,   1.3083691E-07,   1.7445885E-07
     +,   2.3103048E-07,   3.0385206E-07,   3.9689544E-07
     +,   5.1489229E-07,   6.6341903E-07,   8.4898272E-07
     +,   1.0790733E-06,   1.3622457E-06,   1.7081436E-06
     +,   2.1274591E-06,   2.6319842E-06,   3.2344228E-06
     +,   3.9484044E-06,   4.7881458E-06,   5.7684188E-06
     +,   6.9040452E-06,   8.2098313E-06,   9.6998965E-06
     +,   1.1387557E-05,   1.3284805E-05,   1.5401749E-05
     +,   1.7746272E-05,   2.0323852E-05,   2.3137105E-05
     +,   2.6185215E-05,   2.9464438E-05,   3.2967222E-05
     +,   3.6683083E-05,   4.0597821E-05,   4.4694716E-05
     +,   4.8953800E-05,   5.3353320E-05,   5.7869012E-05
     +,   6.2475556E-05,   6.7146539E-05,   7.1854585E-05
     +,   7.6571894E-05,   8.1270940E-05,   8.5924192E-05
     +,   9.0503825E-05,   9.4982781E-05,   9.9333462E-05
     +,   1.0352882E-04,   1.0754106E-04,   1.1134273E-04
     +,   1.1490547E-04,   1.1820106E-04,   1.2120060E-04
     +,   1.2387551E-04,   1.2619742E-04,   1.2813865E-04
     +,   1.2967276E-04,   1.3077547E-04,   1.3142519E-04
     +,   1.3160358E-04,   1.3129665E-04,   1.3049522E-04
     +,   1.2919557E-04,   1.2740005E-04,   1.2511725E-04
     +,   1.2236249E-04,   1.1915734E-04,   1.1553020E-04
     +,   1.1151518E-04,   1.0715185E-04,   1.0248498E-04
     +,   9.7563374E-05,   9.2438677E-05,   8.7164612E-05
     +,   8.1796512E-05,   7.6389028E-05,   7.0996488E-05
     +,   6.5670494E-05,   6.0460414E-05,   5.5411150E-05
     +,   5.0563860E-05,   4.5954090E-05,   4.1612591E-05
     +,   3.7564114E-05,   3.3827717E-05,   3.0417139E-05
     +,   2.7340682E-05,   2.4601368E-05,   2.2197626E-05
     +,   2.0123927E-05,   1.8371118E-05,   1.6926933E-05
     +,   1.5776748E-05,   1.4904193E-05,   1.4291501E-05
     +,   1.3920106E-05,   1.3771089E-05,   1.3825463E-05
     +,   1.4064501E-05,   1.4469962E-05,   1.5024210E-05
     +,   1.5710315E-05,   1.6512147E-05,   1.7414362E-05
     +,   1.8402285E-05,   1.9461910E-05,   2.0579915E-05
     +,   2.1743521E-05,   2.2940303E-05,   2.4158346E-05
     +,   2.5386087E-05,   2.6612197E-05,   2.7825628E-05
     +,   2.9015717E-05,   3.0172083E-05,   3.1284606E-05
     +,   3.2343545E-05,   3.3339671E-05,   3.4264252E-05
     +,   3.5109049E-05,   3.5866506E-05,   3.6529829E-05
     +,   3.7093036E-05,   3.7550944E-05,   3.7899375E-05
     +,   3.8135120E-05,   3.8255967E-05,   3.8260790E-05
     +,   3.8149527E-05,   3.7923161E-05,   3.7583730E-05
     +,   3.7134309E-05,   3.6578909E-05,   3.5922436E-05
     +,   3.5170669E-05,   3.4330144E-05,   3.3408003E-05
     +,   3.2411917E-05,   3.1350122E-05,   3.0231069E-05
     +,   2.9063443E-05,   2.7856107E-05,   2.6617923E-05
     +,   2.5357576E-05,   2.4083543E-05,   2.2804092E-05
     +,   2.1527112E-05,   2.0259960E-05,   1.9009483E-05
     +,   1.7782049E-05,   1.6583415E-05,   1.5418640E-05
     +,   1.4292125E-05,   1.3207739E-05,   1.2168583E-05
     +,   1.1177126E-05,   1.0235286E-05,   9.3443887E-06
     +,   8.5051443E-06,   7.7177519E-06,   6.9819980E-06
     +,   6.2972340E-06,   5.6623921E-06,   5.0760755E-06
     +,   4.5366587E-06,   4.0422724E-06,   3.5908295E-06
     +,   3.1801089E-06,   2.8078302E-06,   2.4716076E-06
     +,   2.1690330E-06,   1.8977216E-06,   1.6553150E-06
     +,   1.4394896E-06,   1.2479993E-06,   1.0786976E-06
     +,   9.2953792E-07,   7.9857227E-07,   6.8397316E-07
     +,   5.8404129E-07,   4.9719881E-07,   4.2198448E-07
     +,   3.5705932E-07,   3.0120788E-07,   2.5332159E-07
     +,   2.1240041E-07,   1.7754903E-07,   1.4796649E-07
     +,   1.2293870E-07,   1.0183354E-07,   8.4095525E-08
     +,   6.9236833E-08,   5.6830533E-08,   4.6505338E-08
     +,   3.7940573E-08,   3.0859411E-08,   2.5023672E-08
     +,   2.0229800E-08,   1.6304774E-08,   1.3101411E-08
     +,   1.0495362E-08,   8.3821838E-09,   6.6741981E-09
     +,   5.2981202E-09,   4.1929571E-09,   3.3082526E-09
     +,   2.6023192E-09,   2.0408062E-09,   1.5955854E-09
     +,   1.2437041E-09,   9.6649222E-10,   7.4878781E-10
     +,   5.7835686E-10,   4.4536530E-10,   3.4191369E-10
     +,   2.6169344E-10,   1.9968635E-10,   1.5191078E-10
     +,   1.1521471E-10,   8.7117043E-11,   6.5671656E-11
     +,   4.9355655E-11,   3.6980734E-11,   2.7624221E-11
     +,   2.0572558E-11,   1.5274337E-11,   1.1306283E-11
     +,   8.3436019E-12,   6.1386248E-12,   4.5026027E-12
     +,   3.2926134E-12,   2.4004516E-12,   1.7447393E-12
     +,   1.2642761E-12,   9.1335316E-13,   6.5783099E-13
     +,   4.7235252E-13,   3.3814414E-13,   2.4133091E-13
     +,   1.7171515E-13,   1.2180888E-13,   8.6145744E-14
     +,   6.0738510E-14,   4.2695204E-14,   2.9920433E-14
     +,   2.0904648E-14,   1.4561015E-14,   1.0111740E-14
     +,   7.0005778E-15,   4.8320045E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_haonly_ww_mass = Yx/0.001624
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_haonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5768591E-07,   4.1900745E-07
     +,   4.8965535E-07,   5.7083264E-07,   6.6386127E-07
     +,   7.7018808E-07,   8.9139047E-07,   1.0291810E-06
     +,   1.1854083E-06,   1.3620698E-06,   1.5612984E-06
     +,   1.7853710E-06,   2.0367042E-06,   2.3178509E-06
     +,   2.6314906E-06,   2.9804244E-06,   3.3675599E-06
     +,   3.7958998E-06,   4.2685201E-06,   4.7885533E-06
     +,   5.3591639E-06,   5.9835156E-06,   6.6647417E-06
     +,   7.4059553E-06,   8.2100969E-06,   9.0800577E-06
     +,   1.0018493E-05,   1.1027872E-05,   1.2110378E-05
     +,   1.3267901E-05,   1.4501960E-05,   1.5813686E-05
     +,   1.7203751E-05,   1.8672332E-05,   2.0219079E-05
     +,   2.1843058E-05,   2.3542729E-05,   2.5315881E-05
     +,   2.7159762E-05,   2.9070703E-05,   3.1044572E-05
     +,   3.3076391E-05,   3.5160534E-05,   3.7290654E-05
     +,   3.9459763E-05,   4.1660191E-05,   4.3883709E-05
     +,   4.6121491E-05,   4.8364218E-05,   5.0602132E-05
     +,   5.2825078E-05,   5.5022643E-05,   5.7184141E-05
     +,   5.9298894E-05,   6.1355982E-05,   6.3344763E-05
     +,   6.5254622E-05,   6.7075249E-05,   6.8796697E-05
     +,   7.0409464E-05,   7.1904600E-05,   7.3273812E-05
     +,   7.4509422E-05,   7.5604708E-05,   7.6553726E-05
     +,   7.7351404E-05,   7.7993740E-05,   7.8477664E-05
     +,   7.8801175E-05,   7.8963349E-05,   7.8964287E-05
     +,   7.8805169E-05,   7.8488200E-05,   7.8016652E-05
     +,   7.7394732E-05,   7.6627584E-05,   7.5721262E-05
     +,   7.4682663E-05,   7.3519390E-05,   7.2239694E-05
     +,   7.0852562E-05,   6.9367285E-05,   6.7793801E-05
     +,   6.6142202E-05,   6.4422973E-05,   6.2646606E-05
     +,   6.0823833E-05,   5.8965168E-05,   5.7081223E-05
     +,   5.5182292E-05,   5.3278360E-05,   5.1379240E-05
     +,   4.9494323E-05,   4.7632435E-05,   4.5801888E-05
     +,   4.4010605E-05,   4.2265707E-05,   4.0573883E-05
     +,   3.8940965E-05,   3.7372312E-05,   3.5872403E-05
     +,   3.4445220E-05,   3.3093867E-05,   3.1820942E-05
     +,   3.0628238E-05,   2.9516925E-05,   2.8487595E-05
     +,   2.7540262E-05,   2.6674294E-05,   2.5888541E-05
     +,   2.5181440E-05,   2.4550907E-05,   2.3994520E-05
     +,   2.3509438E-05,   2.3092583E-05,   2.2740573E-05
     +,   2.2449849E-05,   2.2216673E-05,   2.2037222E-05
     +,   2.1907597E-05,   2.1823882E-05,   2.1782202E-05
     +,   2.1778742E-05,   2.1809803E-05,   2.1871831E-05
     +,   2.1961438E-05,   2.2075461E-05,   2.2210959E-05
     +,   2.2365248E-05,   2.2535905E-05,   2.2720818E-05
     +,   2.2918137E-05,   2.3126349E-05,   2.3344204E-05
     +,   2.3570785E-05,   2.3805451E-05,   2.4047849E-05
     +,   2.4297880E-05,   2.4555713E-05,   2.4821762E-05
     +,   2.5096615E-05,   2.5381067E-05,   2.5676063E-05
     +,   2.5982694E-05,   2.6302114E-05,   2.6635578E-05
     +,   2.6984373E-05,   2.7349775E-05,   2.7733009E-05
     +,   2.8135300E-05,   2.8557755E-05,   2.9001358E-05
     +,   2.9466930E-05,   2.9955168E-05,   3.0466565E-05
     +,   3.1001378E-05,   3.1559637E-05,   3.2141150E-05
     +,   3.2745476E-05,   3.3371860E-05,   3.4019326E-05
     +,   3.4686629E-05,   3.5372221E-05,   3.6074278E-05
     +,   3.6790767E-05,   3.7519407E-05,   3.8257636E-05
     +,   3.9002673E-05,   3.9751591E-05,   4.0501265E-05
     +,   4.1248379E-05,   4.1989497E-05,   4.2721087E-05
     +,   4.3439573E-05,   4.4141216E-05,   4.4822355E-05
     +,   4.5479315E-05,   4.6108395E-05,   4.6705980E-05
     +,   4.7268546E-05,   4.7792710E-05,   4.8275160E-05
     +,   4.8712776E-05,   4.9102626E-05,   4.9441998E-05
     +,   4.9728351E-05,   4.9959435E-05,   5.0133229E-05
     +,   5.0248000E-05,   5.0302282E-05,   5.0294915E-05
     +,   5.0225011E-05,   5.0092003E-05,   4.9895636E-05
     +,   4.9635943E-05,   4.9313250E-05,   4.8928214E-05
     +,   4.8481772E-05,   4.7975147E-05,   4.7409798E-05
     +,   4.6787496E-05,   4.6110283E-05,   4.5380370E-05
     +,   4.4600176E-05,   4.3772427E-05,   4.2899937E-05
     +,   4.1985670E-05,   4.1032810E-05,   4.0044641E-05
     +,   3.9024508E-05,   3.7975817E-05,   3.6902100E-05
     +,   3.5806934E-05,   3.4693821E-05,   3.3566273E-05
     +,   3.2427848E-05,   3.1282034E-05,   3.0132200E-05
     +,   2.8981629E-05,   2.7833605E-05,   2.6691201E-05
     +,   2.5557343E-05,   2.4434901E-05,   2.3326586E-05
     +,   2.2234870E-05,   2.1162059E-05,   2.0110359E-05
     +,   1.9081774E-05,   1.8078066E-05,   1.7100805E-05
     +,   1.6151440E-05,   1.5231224E-05,   1.4341167E-05
     +,   1.3482097E-05,   1.2654747E-05,   1.1859594E-05
     +,   1.1096947E-05,   1.0367015E-05,   9.6698459E-06
     +,   9.0053018E-06,   8.3731147E-06,   7.7729355E-06
     +,   7.2042972E-06,   6.6665957E-06,   6.1591331E-06
     +,   5.6811659E-06,   5.2318746E-06,   4.8103461E-06
     +,   4.4156204E-06,   4.0467307E-06,   3.7026373E-06
     +,   3.3822810E-06,   3.0846043E-06,   2.8085383E-06
     +,   2.5529926E-06,   2.3168827E-06,   2.0991522E-06
     +,   1.8987558E-06,   1.7146548E-06,   1.5458381E-06
     +,   1.3913320E-06,   1.2501933E-06,   1.1215037E-06
     +,   1.0043799E-06,   8.9798897E-07,   8.0152478E-07
     +,   7.1422113E-07,   6.3535828E-07,   5.6425483E-07
     +,   5.0026426E-07,   4.4278028E-07,   3.9123918E-07
     +,   3.4511351E-07,   3.0390942E-07,   2.6716896E-07
     +,   2.3447160E-07,   2.0542412E-07,   1.7966879E-07
     +,   1.5687310E-07,   1.3673569E-07,   1.1897836E-07
     +,   1.0334972E-07,   8.9619249E-08,   7.7579351E-08
     +,   6.7040844E-08,   5.7834072E-08,   4.9805351E-08
     +,   4.2816730E-08,   3.6745082E-08,   3.1479470E-08
     +,   2.6921699E-08,   2.2983603E-08,   1.9587459E-08
     +,   1.6663925E-08,   1.4152048E-08,   1.1997700E-08
     +,   1.0153557E-08,   8.5777501E-09,   7.2338220E-09
     +,   6.0897034E-09,   5.1175522E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_haonly_zz_mass = Yx/0.001995
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_asha_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.7168471E-21,   1.6828183E-20
     +,   3.2292149E-20,   6.1594512E-20,   1.1678066E-19
     +,   2.2008159E-19,   4.1226894E-19,   7.6764744E-19
     +,   1.4207684E-18,   2.6138072E-18,   4.7797879E-18
     +,   8.6881452E-18,   1.5697570E-17,   2.8191847E-17
     +,   5.0327018E-17,   8.9302631E-17,   1.5751204E-16
     +,   2.7615270E-16,   4.8125342E-16,   8.3365269E-16
     +,   1.4354387E-15,   2.4568167E-15,   4.1797154E-15
     +,   7.0683328E-15,   1.1881492E-14,   1.9852651E-14
     +,   3.2973068E-14,   5.4436710E-14,   8.9334173E-14
     +,   1.4572646E-13,   2.3629438E-13,   3.8085919E-13
     +,   6.1020172E-13,   9.7180662E-13,   1.5384587E-12
     +,   2.4209872E-12,   3.7870592E-12,   5.8885869E-12
     +,   9.1018963E-12,   1.3984711E-11,   2.1359258E-11
     +,   3.2428699E-11,   4.8942385E-11,   7.3426869E-11
     +,   1.0950686E-10,   1.6234779E-10,   2.3926133E-10
     +,   3.5052800E-10,   5.1050347E-10,   7.3910039E-10
     +,   1.0637528E-09,   1.5219932E-09,   2.1648119E-09
     +,   3.0610758E-09,   4.3029686E-09,   6.0132983E-09
     +,   8.3542950E-09,   1.1538844E-08,   1.5844357E-08
     +,   2.1629745E-08,   2.9355919E-08,   3.9610903E-08
     +,   5.3138116E-08,   7.0872673E-08,   9.3981313E-08
     +,   1.2390561E-07,   1.6241994E-07,   2.1168208E-07
     +,   2.7430730E-07,   3.5342455E-07,   4.5276670E-07
     +,   5.7672440E-07,   7.3044919E-07,   9.1989364E-07
     +,   1.1519124E-06,   1.4343107E-06,   1.7758665E-06
     +,   2.1863641E-06,   2.6766227E-06,   3.2584524E-06
     +,   3.9445167E-06,   4.7483613E-06,   5.6840763E-06
     +,   6.7662950E-06,   8.0096843E-06,   9.4289135E-06
     +,   1.1037941E-05,   1.2849975E-05,   1.4876574E-05
     +,   1.7127539E-05,   1.9610261E-05,   2.2328979E-05
     +,   2.5284402E-05,   2.8473440E-05,   3.1888612E-05
     +,   3.5517325E-05,   3.9342442E-05,   4.3341206E-05
     +,   4.7486246E-05,   5.1744755E-05,   5.6079905E-05
     +,   6.0450267E-05,   6.4811677E-05,   6.9116941E-05
     +,   7.3317860E-05,   7.7365934E-05,   8.1213293E-05
     +,   8.4814244E-05,   8.8126770E-05,   9.1113412E-05
     +,   9.3742128E-05,   9.5987809E-05,   9.7832402E-05
     +,   9.9265962E-05,   1.0028634E-04,   1.0089958E-04
     +,   1.0111923E-04,   1.0096597E-04,   1.0046655E-04
     +,   9.9652818E-05,   9.8560347E-05,   9.7227152E-05
     +,   9.5692318E-05,   9.3994342E-05,   9.2169939E-05
     +,   9.0253059E-05,   8.8273497E-05,   8.6256536E-05
     +,   8.4222163E-05,   8.2185230E-05,   8.0155121E-05
     +,   7.8136742E-05,   7.6130571E-05,   7.4134128E-05
     +,   7.2142509E-05,   7.0149756E-05,   6.8150250E-05
     +,   6.6139663E-05,   6.4116022E-05,   6.2080813E-05
     +,   6.0039889E-05,   5.8003981E-05,   5.5988876E-05
     +,   5.4015702E-05,   5.2110903E-05,   5.0305491E-05
     +,   4.8634571E-05,   4.7136593E-05,   4.5852226E-05
     +,   4.4823053E-05,   4.4090502E-05,   4.3694512E-05
     +,   4.3672157E-05,   4.4056378E-05,   4.4874843E-05
     +,   4.6148787E-05,   4.7892081E-05,   5.0110553E-05
     +,   5.2801472E-05,   5.5952769E-05,   5.9543483E-05
     +,   6.3543586E-05,   6.7913970E-05,   7.2607087E-05
     +,   7.7568016E-05,   8.2734987E-05,   8.8039989E-05
     +,   9.3410235E-05,   9.8769677E-05,   1.0403999E-04
     +,   1.0914159E-04,   1.1399531E-04,   1.1852427E-04
     +,   1.2265476E-04,   1.2631739E-04,   1.2944921E-04
     +,   1.3199438E-04,   1.3390543E-04,   1.3514438E-04
     +,   1.3568367E-04,   1.3550681E-04,   1.3460869E-04
     +,   1.3299602E-04,   1.3068708E-04,   1.2771148E-04
     +,   1.2410962E-04,   1.1993184E-04,   1.1523689E-04
     +,   1.1009076E-04,   1.0456566E-04,   9.8737226E-05
     +,   9.2683324E-05,   8.6482542E-05,   8.0212099E-05
     +,   7.3945717E-05,   6.7752553E-05,   6.1696221E-05
     +,   5.5833389E-05,   5.0212555E-05,   4.4873992E-05
     +,   3.9849798E-05,   3.5163572E-05,   3.0830393E-05
     +,   2.6857697E-05,   2.3246264E-05,   1.9990261E-05
     +,   1.7078552E-05,   1.4495811E-05,   1.2223215E-05
     +,   1.0239253E-05,   8.5207876E-06,   7.0439160E-06
     +,   5.7845104E-06,   4.7187518E-06,   3.8237195E-06
     +,   3.0777926E-06,   2.4608455E-06,   1.9543934E-06
     +,   1.5417470E-06,   1.2080613E-06,   9.4022374E-07
     +,   7.2682644E-07,   5.5806731E-07,   4.2559583E-07
     +,   3.2237028E-07,   2.4252179E-07,   1.8121089E-07
     +,   1.3447925E-07,   9.9118672E-08,   7.2556489E-08
     +,   5.2749403E-08,   3.8087315E-08,   2.7312142E-08
     +,   1.9450713E-08,   1.3757044E-08,   9.6630917E-09
     +,   6.7406054E-09,   4.6695585E-09,   3.2125373E-09
     +,   2.1948630E-09,   1.4891712E-09,   1.0033702E-09
     +,   6.7136702E-10,   4.4609999E-10,   2.9435310E-10
     +,   1.9287354E-10,   1.2550065E-10,   8.1092577E-11
     +,   5.2031691E-11,   3.3152502E-11,   2.0975766E-11
     +,   1.3178421E-11,   8.2215857E-12,   5.0933173E-12
     +,   3.1332027E-12,   1.9138554E-12,   1.1608303E-12
     +,   6.9915119E-13,   4.1812780E-13,   2.4829609E-13
     +,   1.4640726E-13,   8.5721747E-14,   4.9836325E-14
     +,   2.8768634E-14,   1.6490068E-14,   9.3853038E-15
     +,   5.3037989E-15,   2.9760744E-15,   1.6581603E-15
     +,   9.1733340E-16,   5.0388794E-16,   2.7482394E-16
     +,   1.4883233E-16,   8.0029956E-17,   4.2727717E-17
     +,   2.2650918E-17,   1.1922348E-17,   6.2309634E-18
     +,   3.2333059E-18,   1.6659266E-18,   8.5223643E-19
     +,   4.3289360E-19,   2.1832129E-19,   1.0932638E-19
     +,   5.4355990E-20,   2.6833831E-20,   1.3152917E-20
     +,   6.4010584E-21,   3.0931044E-21,   1.4839818E-21
     +,   7.0692484E-22,   3.3435659E-22,   1.5701936E-22
     +,   7.3213221E-23,   3.3894835E-23,   1.5579971E-23
     +,   7.1106644E-24,   3.2221124E-24,   1.4497155E-24
     +,   6.4760437E-25,   2.8724196E-25
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_asha_eez_mass = Yx/0.002121
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_asha_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   1.7949812E-38,   1.8582806E-37,   1.8577216E-36
     +,   1.7933344E-35,   1.6717319E-34,   1.5048155E-33
     +,   1.3080308E-32,   1.0979196E-31,   8.8986944E-31
     +,   6.9650850E-30,   5.2640071E-29,   3.8417967E-28
     +,   2.7075114E-27,   1.8425780E-26,   1.2108660E-25
     +,   7.6839169E-25,   4.7085506E-24,   2.7861731E-23
     +,   1.5920080E-22,   8.7841633E-22,   4.6802812E-21
     +,   2.4080184E-20,   1.1963701E-19,   5.7395271E-19
     +,   2.6590478E-18,   1.1895157E-17,   5.1385872E-17
     +,   2.1435504E-16,   8.6345543E-16,   3.3586330E-15
     +,   1.2615438E-14,   4.5757255E-14,   1.6026633E-13
     +,   5.4203132E-13,   1.7702019E-12,   5.5828480E-12
     +,   1.7001582E-11,   4.9998269E-11,   1.4197844E-10
     +,   3.8933287E-10,   1.0309159E-09,   2.6360609E-09
     +,   6.5086523E-09,   1.5518737E-08,   3.5729446E-08
     +,   7.9435353E-08,   1.7054110E-07,   3.5355814E-07
     +,   7.0778151E-07,   1.3682162E-06,   2.5540919E-06
     +,   4.6039054E-06,   8.0138507E-06,   1.3469930E-05
     +,   2.1863185E-05,   3.4266654E-05,   5.1862433E-05
     +,   7.5795841E-05,   1.0696950E-04,   1.4577627E-04
     +,   1.9183652E-04,   2.4377921E-04,   2.9914346E-04
     +,   3.5446938E-04,   4.0560158E-04,   4.4817574E-04
     +,   4.7822448E-04,   4.9280154E-04,   4.9046765E-04
     +,   4.7155647E-04,   4.3815011E-04,   3.9377451E-04
     +,   3.4290494E-04,   2.9036755E-04,   2.4079926E-04
     +,   1.9821129E-04,   1.6574070E-04,   1.4555709E-04
     +,   1.3886897E-04,   1.4597582E-04,   1.6630691E-04
     +,   1.9841868E-04,   2.3998482E-04,   2.8780726E-04
     +,   3.3794084E-04,   3.8593693E-04,   4.2725939E-04
     +,   4.5778201E-04,   4.7432826E-04,   4.7510254E-04
     +,   4.5994512E-04,   4.3032467E-04,   3.8908131E-04
     +,   3.3996315E-04,   2.8705527E-04,   2.3422664E-04
     +,   1.8469238E-04,   1.4073314E-04,   1.0363014E-04
     +,   7.3741037E-05,   5.0707888E-05,   3.3695669E-05
     +,   2.1637981E-05,   1.3427364E-05,   8.0521140E-06
     +,   4.6662431E-06,   2.6130926E-06,   1.4140985E-06
     +,   7.3952305E-07,   3.7373343E-07,   1.8251578E-07
     +,   8.6134378E-08,   3.9282686E-08,   1.7312665E-08
     +,   7.3731536E-09,   3.0345393E-09,   1.2068987E-09
     +,   4.6384541E-10,   1.7227170E-10,   6.1830964E-11
     +,   2.1445540E-11,   7.1877144E-12,   2.3279924E-12
     +,   7.2866133E-13,   2.2039884E-13,   6.4419004E-14
     +,   1.8195188E-14,   4.9665417E-15,   1.3100570E-15
     +,   3.3392265E-16,   8.2254397E-17,   1.9579843E-17
     +,   4.5037978E-18,   1.0011184E-18,   2.1505503E-19
     +,   4.4643144E-20,   8.9551833E-21,   1.7359223E-21
     +,   3.2519861E-22,   5.8871680E-23,   1.0298533E-23
     +,   1.7409397E-24,   2.8441751E-25,   4.4901935E-26
     +,   6.8499627E-27,   1.0098859E-27,   1.4387902E-28
     +,   1.9807615E-29,   2.6351358E-30,   3.3880098E-31
     +,   4.2094209E-32,   5.0536629E-33,   5.8631316E-34
     +,   6.5738867E-35,   7.1228013E-36,   7.4573701E-37
     +,   7.5450124E-38,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_asha_qq_mass = Yx/0.003051125
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_asha_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.9829813E-17,   1.2402334E-16
     +,   2.1896117E-16,   3.8426624E-16,   6.7034881E-16
     +,   1.1624438E-15,   2.0037661E-15,   3.4334197E-15
     +,   5.8480040E-15,   9.9014230E-15,   1.6664567E-14
     +,   2.7880269E-14,   4.6366766E-14,   7.6652389E-14
     +,   1.2596571E-13,   2.0577337E-13,   3.3414471E-13
     +,   5.3937529E-13,   8.6548320E-13,   1.3805043E-12
     +,   2.1889168E-12,   3.4501076E-12,   5.4056291E-12
     +,   8.4193893E-12,   1.3035355E-11,   2.0062379E-11
     +,   3.0694312E-11,   4.6681950E-11,   7.0575830E-11
     +,   1.0606679E-10,   1.5846011E-10,   2.3532992E-10
     +,   3.4741776E-10,   5.0985272E-10,   7.4379847E-10
     +,   1.0786578E-09,   1.5550008E-09,   2.2283995E-09
     +,   3.1745284E-09,   4.4955102E-09,   6.3284800E-09
     +,   8.8560093E-09,   1.2319549E-08,   1.7036101E-08
     +,   2.3418714E-08,   3.2001793E-08,   4.3471339E-08
     +,   5.8701453E-08,   7.8797463E-08,   1.0514595E-07
     +,   1.3947286E-07,   1.8390928E-07,   2.4106404E-07
     +,   3.1410988E-07,   4.0685887E-07,   5.2387168E-07
     +,   6.7053776E-07,   8.5317771E-07,   1.0791318E-06
     +,   1.3568416E-06,   1.6959189E-06,   2.1071985E-06
     +,   2.6027226E-06,   3.1957914E-06,   3.9008837E-06
     +,   4.7334756E-06,   5.7100528E-06,   6.8476775E-06
     +,   8.1639710E-06,   9.6764834E-06,   1.1402639E-05
     +,   1.3358901E-05,   1.5560729E-05,   1.8021552E-05
     +,   2.0752723E-05,   2.3762805E-05,   2.7056843E-05
     +,   3.0636074E-05,   3.4497782E-05,   3.8634789E-05
     +,   4.3034848E-05,   4.7681500E-05,   5.2552961E-05
     +,   5.7623507E-05,   6.2862469E-05,   6.8235960E-05
     +,   7.3705938E-05,   7.9232195E-05,   8.4771425E-05
     +,   9.0279209E-05,   9.5709853E-05,   1.0101674E-04
     +,   1.0615314E-04,   1.1107298E-04,   1.1573101E-04
     +,   1.2008274E-04,   1.2408584E-04,   1.2769968E-04
     +,   1.3088679E-04,   1.3361276E-04,   1.3584785E-04
     +,   1.3756758E-04,   1.3875435E-04,   1.3939882E-04
     +,   1.3950170E-04,   1.3907562E-04,   1.3814696E-04
     +,   1.3675795E-04,   1.3496813E-04,   1.3285576E-04
     +,   1.3051902E-04,   1.2807579E-04,   1.2566343E-04
     +,   1.2343671E-04,   1.2156564E-04,   1.2023076E-04
     +,   1.1961847E-04,   1.1991399E-04,   1.2129389E-04
     +,   1.2391746E-04,   1.2791766E-04,   1.3339137E-04
     +,   1.4039034E-04,   1.4891381E-04,   1.5890176E-04
     +,   1.7022940E-04,   1.8270835E-04,   1.9608531E-04
     +,   2.1005089E-04,   2.2424532E-04,   2.3827479E-04
     +,   2.5172348E-04,   2.6417538E-04,   2.7523030E-04
     +,   2.8452664E-04,   2.9175883E-04,   2.9669298E-04
     +,   2.9918121E-04,   2.9916977E-04,   2.9670200E-04
     +,   2.9191660E-04,   2.8504038E-04,   2.7637533E-04
     +,   2.6628232E-04,   2.5516318E-04,   2.4343772E-04
     +,   2.3152377E-04,   2.1981797E-04,   2.0867767E-04
     +,   1.9840595E-04,   1.8924223E-04,   1.8135698E-04
     +,   1.7484927E-04,   1.6974883E-04,   1.6602261E-04
     +,   1.6358300E-04,   1.6229799E-04,   1.6200219E-04
     +,   1.6250891E-04,   1.6362044E-04,   1.6513845E-04
     +,   1.6687255E-04,   1.6864650E-04,   1.7030393E-04
     +,   1.7171141E-04,   1.7276061E-04,   1.7336823E-04
     +,   1.7347588E-04,   1.7304861E-04,   1.7207253E-04
     +,   1.7055267E-04,   1.6851047E-04,   1.6598077E-04
     +,   1.6300924E-04,   1.5965046E-04,   1.5596476E-04
     +,   1.5201648E-04,   1.4787234E-04,   1.4359942E-04
     +,   1.3926327E-04,   1.3492697E-04,   1.3064996E-04
     +,   1.2648692E-04,   1.2248654E-04,   1.1869096E-04
     +,   1.1513559E-04,   1.1184829E-04,   1.0884900E-04
     +,   1.0614974E-04,   1.0375505E-04,   1.0166154E-04
     +,   9.9858647E-05,   9.8329161E-05,   9.7049735E-05
     +,   9.5991556E-05,   9.5121373E-05,   9.4402429E-05
     +,   9.3795359E-05,   9.3259325E-05,   9.2752984E-05
     +,   9.2235627E-05,   9.1668146E-05,   9.1013892E-05
     +,   9.0239562E-05,   8.9316018E-05,   8.8218723E-05
     +,   8.6928245E-05,   8.5430634E-05,   8.3717525E-05
     +,   8.1786027E-05,   7.9638565E-05,   7.7282792E-05
     +,   7.4731026E-05,   7.1999581E-05,   6.9108239E-05
     +,   6.6079861E-05,   6.2939442E-05,   5.9713253E-05
     +,   5.6428311E-05,   5.3112049E-05,   4.9791059E-05
     +,   4.6490877E-05,   4.3235719E-05,   4.0047853E-05
     +,   3.6947120E-05,   3.3950895E-05,   3.1074167E-05
     +,   2.8329247E-05,   2.5725616E-05,   2.3270206E-05
     +,   2.0967662E-05,   1.8820327E-05,   1.6828328E-05
     +,   1.4989952E-05,   1.3302051E-05,   1.1759919E-05
     +,   1.0357747E-05,   9.0889134E-06,   7.9461088E-06
     +,   6.9214748E-06,   6.0068805E-06,   5.1941347E-06
     +,   4.4750559E-06,   3.8415496E-06,   3.2857763E-06
     +,   2.8002528E-06,   2.3778666E-06,   2.0119001E-06
     +,   1.6960975E-06,   1.4247003E-06,   1.1923937E-06
     +,   9.9433612E-07,   8.2615617E-07,   6.8391830E-07
     +,   5.6409408E-07,   4.6354802E-07,   3.7951565E-07
     +,   3.0956551E-07,   2.5156649E-07,   2.0366653E-07
     +,   1.6426591E-07,   1.3198716E-07,   1.0564781E-07
     +,   8.4240718E-08,   6.6913628E-08,   5.2945147E-08
     +,   4.1729702E-08,   3.2761708E-08,   2.5620366E-08
     +,   1.9956785E-08,   1.5483554E-08,   1.1965240E-08
     +,   9.2095727E-09,   7.0601525E-09,   5.3905693E-09
     +,   4.0992303E-09,   3.1045784E-09,   2.3417408E-09
     +,   1.7591206E-09,   1.3160637E-09,   9.8054875E-10
     +,   7.2757078E-10,   5.3762994E-10,   3.9563719E-10
     +,   2.8993713E-10,   2.1159682E-10,   1.5378146E-10
     +,   1.1129660E-10,   8.0213704E-11,   5.7569317E-11
     +,   4.1144987E-11,   2.9282892E-11,   2.0753432E-11
     +,   1.4646454E-11,   1.0293177E-11,   7.2032749E-12
     +,   5.0197403E-12,   3.4833098E-12,   2.4069776E-12
     +,   1.6561848E-12,   1.1347814E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_asha_ww_mass = Yx/0.004872
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_asha_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0635641E-15,   3.2990720E-15
     +,   5.2485516E-15,   8.3092568E-15,   1.3090598E-14
     +,   2.0522605E-14,   3.2017076E-14,   4.9705652E-14
     +,   7.6789994E-14,   1.1805482E-13,   1.8060949E-13
     +,   2.7496446E-13,   4.1657381E-13,   6.2804162E-13
     +,   9.4225008E-13,   1.4067838E-12,   2.0901271E-12
     +,   3.0903197E-12,   4.5469678E-12,   6.6577815E-12
     +,   9.7012641E-12,   1.4067608E-11,   2.0300418E-11
     +,   2.9153679E-11,   4.1665577E-11,   5.9260992E-11
     +,   8.3881645E-11,   1.1816176E-10,   1.6565371E-10
     +,   2.3112393E-10,   3.2093123E-10,   4.4351453E-10
     +,   6.1001082E-10,   8.3503804E-10,   1.1376792E-09
     +,   1.5427123E-09,   2.0821296E-09,   2.7970051E-09
     +,   3.7398551E-09,   4.9772715E-09,   6.5935306E-09
     +,   8.6944070E-09,   1.1412123E-08,   1.4910976E-08
     +,   1.9394019E-08,   2.5110868E-08,   3.2366600E-08
     +,   4.1532118E-08,   5.3055768E-08,   6.7476698E-08
     +,   8.5439375E-08,   1.0771013E-07,   1.3519448E-07
     +,   1.6895936E-07,   2.1024782E-07,   2.6051001E-07
     +,   3.2141952E-07,   3.9490121E-07,   4.8315610E-07
     +,   5.8868659E-07,   7.1432231E-07,   8.6324900E-07
     +,   1.0390185E-06,   1.2455977E-06,   1.4873813E-06
     +,   1.7691865E-06,   2.0963298E-06,   2.4745711E-06
     +,   2.9102150E-06,   3.4100256E-06,   3.9813485E-06
     +,   4.6319878E-06,   5.3703561E-06,   6.2052995E-06
     +,   7.1462464E-06,   8.2031174E-06,   9.3862163E-06
     +,   1.0706207E-05,   1.2174123E-05,   1.3801190E-05
     +,   1.5598480E-05,   1.7577087E-05,   1.9747411E-05
     +,   2.2119353E-05,   2.4701381E-05,   2.7500731E-05
     +,   3.0522246E-05,   3.3768600E-05,   3.7238970E-05
     +,   4.0929182E-05,   4.4830958E-05,   4.8931088E-05
     +,   5.3211334E-05,   5.7648398E-05,   6.2213585E-05
     +,   6.6872330E-05,   7.1585608E-05,   7.6309101E-05
     +,   8.0995233E-05,   8.5592837E-05,   9.0049500E-05
     +,   9.4311661E-05,   9.8327284E-05,   1.0204617E-04
     +,   1.0542238E-04,   1.0841524E-04,   1.1099043E-04
     +,   1.1312132E-04,   1.1478992E-04,   1.1598707E-04
     +,   1.1671257E-04,   1.1697532E-04,   1.1679241E-04
     +,   1.1618855E-04,   1.1519484E-04,   1.1384743E-04
     +,   1.1218619E-04,   1.1025292E-04,   1.0809028E-04
     +,   1.0573990E-04,   1.0324123E-04,   1.0063074E-04
     +,   9.7940821E-05,   9.5199131E-05,   9.2428301E-05
     +,   8.9646288E-05,   8.6865861E-05,   8.4095773E-05
     +,   8.1340702E-05,   7.8602701E-05,   7.5881573E-05
     +,   7.3176852E-05,   7.0488873E-05,   6.7821748E-05
     +,   6.5186228E-05,   6.2604748E-05,   6.0118538E-05
     +,   5.7796944E-05,   5.5749824E-05,   5.4143115E-05
     +,   5.3216445E-05,   5.3300551E-05,   5.4831926E-05
     +,   5.8360059E-05,   6.4540887E-05,   7.4112548E-05
     +,   8.7846980E-05,   1.0647418E-04,   1.3058312E-04
     +,   1.6050879E-04,   1.9621561E-04,   2.3720290E-04
     +,   2.8246784E-04,   3.3055901E-04,   3.7973866E-04
     +,   4.2827043E-04,   4.7481016E-04,   5.1881350E-04
     +,   5.6082290E-04,   6.0251943E-04,   6.4654509E-04
     +,   6.9626013E-04,   7.5575639E-04,   8.3026744E-04
     +,   9.2658313E-04,   1.0525070E-03,   1.2145141E-03
     +,   1.4139703E-03,   1.6440259E-03,   1.8899253E-03
     +,   2.1337389E-03,   2.3609370E-03,   2.5636721E-03
     +,   2.7375573E-03,   2.8747297E-03,   2.9609655E-03
     +,   2.9821554E-03,   2.9364221E-03,   2.8403532E-03
     +,   2.7211066E-03,   2.5990470E-03,   2.4752740E-03
     +,   2.3344615E-03,   2.1599350E-03,   1.9482113E-03
     +,   1.7127818E-03,   1.4769890E-03,   1.2633321E-03
     +,   1.0862150E-03,   9.5017982E-04,   8.5179374E-04
     +,   7.8283151E-04,   7.3324179E-04,   6.9347228E-04
     +,   6.5601856E-04,   6.1613007E-04,   5.7174516E-04
     +,   5.2291027E-04,   4.7099267E-04,   4.1794433E-04
     +,   3.6574178E-04,   3.1603209E-04,   2.6997470E-04
     +,   2.2823972E-04,   1.9109668E-04,   1.5852346E-04
     +,   1.3031978E-04,   1.0618768E-04,   8.5776890E-05
     +,   6.8709916E-05,   5.4598670E-05,   4.3056953E-05
     +,   3.3710836E-05,   2.6209736E-05,   2.0236543E-05
     +,   1.5513466E-05,   1.1803151E-05,   8.9069836E-06
     +,   6.6615462E-06,   4.9337982E-06,   3.6156200E-06
     +,   2.6195460E-06,   1.8749680E-06,   1.3249595E-06
     +,   9.2383380E-07,   6.3524476E-07,   4.3058387E-07
     +,   2.8759658E-07,   1.8922108E-07,   1.2259795E-07
     +,   7.8202284E-08,   4.9100748E-08,   3.0338761E-08
     +,   1.8444466E-08,   1.1031663E-08,   6.4901982E-09
     +,   3.7554364E-09,   2.1370379E-09,   1.1958740E-09
     +,   6.5802408E-10,   3.5599620E-10,   1.8935804E-10
     +,   9.9025871E-11,   5.0911522E-11,   2.5731512E-11
     +,   1.2784831E-11,   6.2446567E-12,   2.9984073E-12
     +,   1.4152213E-12,   6.5664336E-13,   2.9949589E-13
     +,   1.3427511E-13,   5.9177083E-14,   2.5637497E-14
     +,   1.0918139E-14,   4.5704704E-15,   1.8807200E-15
     +,   7.6077000E-16,   3.0250802E-16,   1.1823972E-16
     +,   4.5430893E-17,   1.7160150E-17,   6.3719336E-18
     +,   2.3259837E-18,   8.3480773E-19,   2.9461263E-19
     +,   1.0225166E-19,   3.4914838E-20,   1.1736581E-20
     +,   3.8876269E-21,   1.2711021E-21,   4.1147126E-22
     +,   1.3255130E-22,   4.2847523E-23,   1.4079839E-23
     +,   4.7899366E-24,   1.7228227E-24,   6.6663420E-25
     +,   2.7899456E-25,   1.2514819E-25,   5.9090520E-26
     +,   2.8824580E-26,   1.4314744E-26,   7.1677289E-27
     +,   3.5975154E-27,   1.8039571E-27,   9.0211185E-28
     +,   4.4944801E-28,   2.2299089E-28,   1.1014200E-28
     +,   5.4155122E-29,   2.6503468E-29,   1.2910572E-29
     +,   6.2595740E-30,   3.0207444E-30,   1.4508866E-30
     +,   6.9362132E-31,   3.3003546E-31,   1.5630319E-31
     +,   7.3675102E-32,   3.4565749E-32
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_asha_zz_mass = Yx/0.0173315625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_ashz_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9479463E-08,   4.6179348E-08
     +,   5.3913084E-08,   6.2821819E-08,   7.3062857E-08
     +,   8.4811120E-08,   9.8260493E-08,   1.1362519E-07
     +,   1.3114131E-07,   1.5106893E-07,   1.7369241E-07
     +,   1.9932250E-07,   2.2829784E-07,   2.6098598E-07
     +,   2.9778471E-07,   3.3912318E-07,   3.8546281E-07
     +,   4.3729798E-07,   4.9515637E-07,   5.5959913E-07
     +,   6.3122138E-07,   7.1065068E-07,   7.9854578E-07
     +,   8.9560183E-07,   1.0025325E-06,   1.1200892E-06
     +,   1.2490407E-06,   1.3901785E-06,   1.5443098E-06
     +,   1.7122542E-06,   1.8948372E-06,   2.0928856E-06
     +,   2.3072198E-06,   2.5386471E-06,   2.7879541E-06
     +,   3.0558972E-06,   3.3431959E-06,   3.6505153E-06
     +,   3.9784845E-06,   4.3276277E-06,   4.6984278E-06
     +,   5.0912590E-06,   5.5063992E-06,   5.9440167E-06
     +,   6.4041628E-06,   6.8867544E-06,   7.3915703E-06
     +,   7.9182419E-06,   8.4662406E-06,   9.0348803E-06
     +,   9.6233034E-06,   1.0230474E-05,   1.0855176E-05
     +,   1.1496049E-05,   1.2151491E-05,   1.2819787E-05
     +,   1.3499011E-05,   1.4187082E-05,   1.4881749E-05
     +,   1.5580625E-05,   1.6281170E-05,   1.6980741E-05
     +,   1.7676528E-05,   1.8365690E-05,   1.9045310E-05
     +,   1.9712345E-05,   2.0363808E-05,   2.0996613E-05
     +,   2.1607773E-05,   2.2194246E-05,   2.2753147E-05
     +,   2.3281582E-05,   2.3776849E-05,   2.4236306E-05
     +,   2.4657524E-05,   2.5038245E-05,   2.5376399E-05
     +,   2.5670137E-05,   2.5917876E-05,   2.6118285E-05
     +,   2.6270305E-05,   2.6373185E-05,   2.6426469E-05
     +,   2.6430029E-05,   2.6384063E-05,   2.6289103E-05
     +,   2.6146041E-05,   2.5956111E-05,   2.5720918E-05
     +,   2.5442419E-05,   2.5122934E-05,   2.4765181E-05
     +,   2.4372261E-05,   2.3947629E-05,   2.3495135E-05
     +,   2.3019058E-05,   2.2524022E-05,   2.2015109E-05
     +,   2.1497752E-05,   2.0977854E-05,   2.0461650E-05
     +,   1.9955867E-05,   1.9467547E-05,   1.9004177E-05
     +,   1.8573579E-05,   1.8183904E-05,   1.7843644E-05
     +,   1.7561542E-05,   1.7346531E-05,   1.7207696E-05
     +,   1.7154194E-05,   1.7195158E-05,   1.7339593E-05
     +,   1.7596287E-05,   1.7973649E-05,   1.8479650E-05
     +,   1.9121586E-05,   1.9906072E-05,   2.0838726E-05
     +,   2.1924201E-05,   2.3165981E-05,   2.4566145E-05
     +,   2.6125310E-05,   2.7842612E-05,   2.9715535E-05
     +,   3.1739615E-05,   3.3908804E-05,   3.6214897E-05
     +,   3.8648093E-05,   4.1196374E-05,   4.3846212E-05
     +,   4.6581943E-05,   4.9386588E-05,   5.2241347E-05
     +,   5.5126351E-05,   5.8020709E-05,   6.0902610E-05
     +,   6.3749845E-05,   6.6540422E-05,   6.9252812E-05
     +,   7.1866241E-05,   7.4361451E-05,   7.6721284E-05
     +,   7.8931167E-05,   8.0979291E-05,   8.2857579E-05
     +,   8.4561849E-05,   8.6092070E-05,   8.7452630E-05
     +,   8.8652552E-05,   8.9705318E-05,   9.0628564E-05
     +,   9.1443835E-05,   9.2175927E-05,   9.2852293E-05
     +,   9.3501971E-05,   9.4154755E-05,   9.4840158E-05
     +,   9.5586161E-05,   9.6418124E-05,   9.7357814E-05
     +,   9.8422301E-05,   9.9623110E-05,   1.0096552E-04
     +,   1.0244822E-04,   1.0406299E-04,   1.0579466E-04
     +,   1.0762140E-04,   1.0951543E-04,   1.1144369E-04
     +,   1.1336860E-04,   1.1524939E-04,   1.1704340E-04
     +,   1.1870729E-04,   1.2019817E-04,   1.2147528E-04
     +,   1.2250082E-04,   1.2324110E-04,   1.2366746E-04
     +,   1.2375695E-04,   1.2349266E-04,   1.2286413E-04
     +,   1.2186728E-04,   1.2050419E-04,   1.1878280E-04
     +,   1.1671647E-04,   1.1432337E-04,   1.1162549E-04
     +,   1.0864814E-04,   1.0541933E-04,   1.0196862E-04
     +,   9.8326513E-05,   9.4524192E-05,   9.0592657E-05
     +,   8.6561995E-05,   8.2461222E-05,   7.8318277E-05
     +,   7.4159463E-05,   7.0009140E-05,   6.5889799E-05
     +,   6.1822335E-05,   5.7825790E-05,   5.3917076E-05
     +,   5.0111332E-05,   4.6422323E-05,   4.2861706E-05
     +,   3.9439550E-05,   3.6164536E-05,   3.3043762E-05
     +,   3.0082596E-05,   2.7284952E-05,   2.4653486E-05
     +,   2.2189426E-05,   1.9892497E-05,   1.7761149E-05
     +,   1.5792788E-05,   1.3983663E-05,   1.2328884E-05
     +,   1.0822677E-05,   9.4586285E-06,   8.2295237E-06
     +,   7.1276418E-06,   6.1449582E-06,   5.2731825E-06
     +,   4.5038519E-06,   3.8285111E-06,   3.2388737E-06
     +,   2.7268518E-06,   2.2846205E-06,   1.9047328E-06
     +,   1.5801946E-06,   1.3044701E-06,   1.0714958E-06
     +,   8.7572209E-07,   7.1212781E-07,   5.7617427E-07
     +,   4.6381325E-07,   3.7146819E-07,   2.9599633E-07
     +,   2.3465383E-07,   1.8507080E-07,   1.4521603E-07
     +,   1.1335953E-07,   8.8035911E-08,   6.8016462E-08
     +,   5.2278139E-08,   3.9974214E-08,   3.0407911E-08
     +,   2.3010934E-08,   1.7323227E-08,   1.2973733E-08
     +,   9.6657642E-09,   7.1638451E-09,   5.2819833E-09
     +,   3.8742196E-09,   2.8268421E-09,   2.0518853E-09
     +,   1.4816396E-09,   1.0643021E-09,   7.6052670E-10
     +,   5.4062443E-10,   3.8230782E-10,   2.6894378E-10
     +,   1.8820644E-10,   1.3102179E-10,   9.0736509E-11
     +,   6.2509400E-11,   4.2838840E-11,   2.9205513E-11
     +,   1.9807111E-11,   1.3362899E-11,   8.9682897E-12
     +,   5.9875997E-12,   3.9767135E-12,   2.6273543E-12
     +,   1.7268231E-12,   1.1290142E-12,   7.3432054E-13
     +,   4.7510916E-13,   3.0579941E-13,   1.9579485E-13
     +,   1.2471000E-13,   7.9017393E-14,   4.9805646E-14
     +,   3.1228892E-14,   1.9479112E-14,   1.2086776E-14
     +,   7.4605874E-15,   4.5811121E-15,   2.7982727E-15
     +,   1.7003709E-15,   1.0278236E-15,   6.1805723E-16
     +,   3.6970971E-16,   2.2000247E-16,   1.3023134E-16
     +,   7.6690145E-17,   4.4924490E-17,   2.6179590E-17
     +,   1.5176228E-17,   8.7518538E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_ashz_eez_mass = Yx/0.002121
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_ashz_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   2.4704071E-38
     +,   7.8191100E-37,   2.2917308E-35,   6.2199557E-34
     +,   1.5632503E-32,   3.6381635E-31,   7.8407625E-30
     +,   1.5647688E-28,   2.8917422E-27,   4.9486271E-26
     +,   7.8420091E-25,   1.1507669E-23,   1.5636817E-22
     +,   1.9677048E-21,   2.2927455E-20,   2.4739103E-19
     +,   2.4719027E-18,   2.2871536E-17,   1.9596347E-16
     +,   1.5547951E-15,   1.1423245E-14,   7.7718153E-14
     +,   4.8963356E-13,   2.8565266E-12,   1.5431989E-11
     +,   7.7201023E-11,   3.5763631E-10,   1.5341467E-09
     +,   6.0943850E-09,   2.2417671E-08,   7.6362134E-08
     +,   2.4086998E-07,   7.0356555E-07,   1.9030216E-06
     +,   4.7665026E-06,   1.1055369E-05,   2.3744815E-05
     +,   4.7224923E-05,   8.6974534E-05,   1.4833319E-04
     +,   2.3425823E-04,   3.4259039E-04,   4.6394867E-04
     +,   5.8182393E-04,   6.7568646E-04,   7.2672323E-04
     +,   7.2403642E-04,   6.6867023E-04,   5.7356729E-04
     +,   4.5959253E-04,   3.4964128E-04,   2.6340672E-04
     +,   2.1440613E-04,   2.0927736E-04,   2.4815410E-04
     +,   3.2490666E-04,   4.2711143E-04,   5.3661206E-04
     +,   6.3192390E-04,   6.9269486E-04,   7.0512359E-04
     +,   6.6601933E-04,   5.8356422E-04,   4.7428088E-04
     +,   3.5753066E-04,   2.4998374E-04,   1.6211870E-04
     +,   9.7517928E-05,   5.4407694E-05,   2.8154669E-05
     +,   1.3513681E-05,   6.0160173E-06,   2.4841622E-06
     +,   9.5139478E-07,   3.3797059E-07,   1.1135376E-07
     +,   3.4030684E-08,   9.6458894E-09,   2.5360354E-09
     +,   6.1843319E-10,   1.3987263E-10,   2.9342306E-11
     +,   5.7095600E-12,   1.0304692E-12,   1.7249075E-13
     +,   2.6782150E-14,   3.8567528E-15,   5.1516877E-16
     +,   6.3822033E-17,   7.3340654E-18,   7.8164846E-19
     +,   7.7273901E-20,   7.0850726E-21,   6.0258098E-22
     +,   4.7534414E-23,   3.4776767E-24,   2.3598996E-25
     +,   1.4854482E-26,   8.6725078E-28,   4.6958614E-29
     +,   2.3585978E-30,   1.0986750E-31,   4.7473651E-33
     +,   1.9024622E-34,   7.0720578E-36,   2.4381048E-37
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_ashz_qq_mass = Yx/0.003051125
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_ashz_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0131738E-05,   2.0903941E-05
     +,   2.1687079E-05,   2.2480204E-05,   2.3282302E-05
     +,   2.4092302E-05,   2.4909097E-05,   2.5731533E-05
     +,   2.6558399E-05,   2.7388511E-05,   2.8220607E-05
     +,   2.9053432E-05,   2.9885730E-05,   3.0716230E-05
     +,   3.1543699E-05,   3.2366908E-05,   3.3184679E-05
     +,   3.3995864E-05,   3.4799385E-05,   3.5594225E-05
     +,   3.6379457E-05,   3.7154230E-05,   3.7917795E-05
     +,   3.8669572E-05,   3.9409002E-05,   4.0135739E-05
     +,   4.0849554E-05,   4.1550356E-05,   4.2238200E-05
     +,   4.2913318E-05,   4.3576085E-05,   4.4227021E-05
     +,   4.4866822E-05,   4.5496334E-05,   4.6116547E-05
     +,   4.6728572E-05,   4.7333677E-05,   4.7933212E-05
     +,   4.8528684E-05,   4.9121609E-05,   4.9713635E-05
     +,   5.0306440E-05,   5.0901726E-05,   5.1501207E-05
     +,   5.2106578E-05,   5.2719493E-05,   5.3341551E-05
     +,   5.3974280E-05,   5.4619075E-05,   5.5277225E-05
     +,   5.5949866E-05,   5.6637957E-05,   5.7342277E-05
     +,   5.8063459E-05,   5.8801845E-05,   5.9557631E-05
     +,   6.0330756E-05,   6.1120954E-05,   6.1927720E-05
     +,   6.2750361E-05,   6.3587955E-05,   6.4439402E-05
     +,   6.5303400E-05,   6.6178494E-05,   6.7063149E-05
     +,   6.7955603E-05,   6.8854140E-05,   6.9756847E-05
     +,   7.0661903E-05,   7.1567396E-05,   7.2471543E-05
     +,   7.3372496E-05,   7.4268661E-05,   7.5158416E-05
     +,   7.6040378E-05,   7.6913333E-05,   7.7776247E-05
     +,   7.8628254E-05,   7.9468758E-05,   8.0297446E-05
     +,   8.1114144E-05,   8.1918988E-05,   8.2712257E-05
     +,   8.3494597E-05,   8.4266700E-05,   8.5029533E-05
     +,   8.5784173E-05,   8.6531887E-05,   8.7273955E-05
     +,   8.8011744E-05,   8.8746703E-05,   8.9480156E-05
     +,   9.0213420E-05,   9.0947688E-05,   9.1684109E-05
     +,   9.2423536E-05,   9.3166695E-05,   9.3914059E-05
     +,   9.4665920E-05,   9.5422183E-05,   9.6182637E-05
     +,   9.6946664E-05,   9.7713506E-05,   9.8482102E-05
     +,   9.9251192E-05,   1.0001932E-04,   1.0078488E-04
     +,   1.0154612E-04,   1.0230129E-04,   1.0304858E-04
     +,   1.0378621E-04,   1.0451249E-04,   1.0522586E-04
     +,   1.0592496E-04,   1.0660860E-04,   1.0727593E-04
     +,   1.0792626E-04,   1.0855934E-04,   1.0917509E-04
     +,   1.0977386E-04,   1.1035623E-04,   1.1092308E-04
     +,   1.1147551E-04,   1.1201479E-04,   1.1254242E-04
     +,   1.1305993E-04,   1.1356886E-04,   1.1407070E-04
     +,   1.1456691E-04,   1.1505854E-04,   1.1554664E-04
     +,   1.1603170E-04,   1.1651397E-04,   1.1699319E-04
     +,   1.1746863E-04,   1.1793907E-04,   1.1840275E-04
     +,   1.1885740E-04,   1.1930012E-04,   1.1972778E-04
     +,   1.2013655E-04,   1.2052232E-04,   1.2088064E-04
     +,   1.2120683E-04,   1.2149604E-04,   1.2174330E-04
     +,   1.2194367E-04,   1.2209233E-04,   1.2218469E-04
     +,   1.2221643E-04,   1.2218357E-04,   1.2208267E-04
     +,   1.2191069E-04,   1.2166528E-04,   1.2134463E-04
     +,   1.2094756E-04,   1.2047365E-04,   1.1992303E-04
     +,   1.1929653E-04,   1.1859564E-04,   1.1782231E-04
     +,   1.1697919E-04,   1.1606925E-04,   1.1509608E-04
     +,   1.1406351E-04,   1.1297563E-04,   1.1183685E-04
     +,   1.1065168E-04,   1.0942472E-04,   1.0816057E-04
     +,   1.0686384E-04,   1.0553916E-04,   1.0419083E-04
     +,   1.0282307E-04,   1.0144007E-04,   1.0004565E-04
     +,   9.8643388E-05,   9.7236836E-05,   9.5829258E-05
     +,   9.4423718E-05,   9.3023016E-05,   9.1629940E-05
     +,   9.0247057E-05,   8.8876834E-05,   8.7521577E-05
     +,   8.6183580E-05,   8.4865154E-05,   8.3568375E-05
     +,   8.2295359E-05,   8.1048260E-05,   7.9829173E-05
     +,   7.8640041E-05,   7.7482982E-05,   7.6359938E-05
     +,   7.5272794E-05,   7.4223346E-05,   7.3213334E-05
     +,   7.2244402E-05,   7.1317911E-05,   7.0435104E-05
     +,   6.9597059E-05,   6.8804635E-05,   6.8058340E-05
     +,   6.7358429E-05,   6.6704946E-05,   6.6097542E-05
     +,   6.5535540E-05,   6.5017994E-05,   6.4543601E-05
     +,   6.4110704E-05,   6.3717343E-05,   6.3361236E-05
     +,   6.3039864E-05,   6.2750347E-05,   6.2489606E-05
     +,   6.2254338E-05,   6.2041050E-05,   6.1846069E-05
     +,   6.1665611E-05,   6.1495819E-05,   6.1332772E-05
     +,   6.1172519E-05,   6.1011142E-05,   6.0844814E-05
     +,   6.0669758E-05,   6.0482322E-05,   6.0279050E-05
     +,   6.0056635E-05,   5.9812002E-05,   5.9542272E-05
     +,   5.9244860E-05,   5.8917438E-05,   5.8557940E-05
     +,   5.8164595E-05,   5.7735968E-05,   5.7270874E-05
     +,   5.6768444E-05,   5.6228106E-05,   5.5649627E-05
     +,   5.5032990E-05,   5.4378474E-05,   5.3686632E-05
     +,   5.2958294E-05,   5.2194478E-05,   5.1396390E-05
     +,   5.0565504E-05,   4.9703478E-05,   4.8812064E-05
     +,   4.7893169E-05,   4.6948884E-05,   4.5981331E-05
     +,   4.4992703E-05,   4.3985317E-05,   4.2961543E-05
     +,   4.1923697E-05,   4.0874125E-05,   3.9815197E-05
     +,   3.8749309E-05,   3.7678703E-05,   3.6605608E-05
     +,   3.5532234E-05,   3.4460740E-05,   3.3393131E-05
     +,   3.2331314E-05,   3.1277210E-05,   3.0232542E-05
     +,   2.9198916E-05,   2.8177908E-05,   2.7170974E-05
     +,   2.6179399E-05,   2.5204350E-05,   2.4246947E-05
     +,   2.3308197E-05,   2.2388942E-05,   2.1489906E-05
     +,   2.0611815E-05,   1.9755164E-05,   1.8920466E-05
     +,   1.8108041E-05,   1.7318225E-05,   1.6551163E-05
     +,   1.5807032E-05,   1.5085828E-05,   1.4387587E-05
     +,   1.3712177E-05,   1.3059512E-05,   1.2429379E-05
     +,   1.1821525E-05,   1.1235711E-05,   1.0671583E-05
     +,   1.0128826E-05,   9.6070280E-06,   9.1058164E-06
     +,   8.6247319E-06,   8.1633598E-06,   7.7212053E-06
     +,   7.2978251E-06,   6.8927066E-06,   6.5053832E-06
     +,   6.1353294E-06,   5.7820703E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_ashz_ww_mass = Yx/0.004872
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_ashz_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1877974E-07,   3.5627627E-07
     +,   3.9764245E-07,   4.4321675E-07,   4.9336057E-07
     +,   5.4846083E-07,   6.0893018E-07,   6.7520818E-07
     +,   7.4776199E-07,   8.2709221E-07,   9.1372630E-07
     +,   1.0082249E-06,   1.1111823E-06,   1.2232273E-06
     +,   1.3450225E-06,   1.4772683E-06,   1.6207010E-06
     +,   1.7760949E-06,   1.9442618E-06,   2.1260516E-06
     +,   2.3223531E-06,   2.5340912E-06,   2.7622248E-06
     +,   3.0077642E-06,   3.2717262E-06,   3.5551896E-06
     +,   3.8592457E-06,   4.1850180E-06,   4.5336556E-06
     +,   4.9063265E-06,   5.3042163E-06,   5.7285238E-06
     +,   6.1804517E-06,   6.6612079E-06,   7.1719946E-06
     +,   7.7140012E-06,   8.2884053E-06,   8.8963488E-06
     +,   9.5389814E-06,   1.0217350E-05,   1.0932526E-05
     +,   1.1685493E-05,   1.2477187E-05,   1.3308482E-05
     +,   1.4180184E-05,   1.5093023E-05,   1.6047656E-05
     +,   1.7044649E-05,   1.8084487E-05,   1.9167561E-05
     +,   2.0294159E-05,   2.1464479E-05,   2.2678587E-05
     +,   2.3936524E-05,   2.5238076E-05,   2.6583048E-05
     +,   2.7971055E-05,   2.9401577E-05,   3.0873980E-05
     +,   3.2387466E-05,   3.3941080E-05,   3.5533725E-05
     +,   3.7163998E-05,   3.8830436E-05,   4.0531377E-05
     +,   4.2264721E-05,   4.4028347E-05,   4.5819630E-05
     +,   4.7635865E-05,   4.9473794E-05,   5.1330058E-05
     +,   5.3200682E-05,   5.5081546E-05,   5.6967907E-05
     +,   5.8854795E-05,   6.0736820E-05,   6.2608044E-05
     +,   6.4462154E-05,   6.6292523E-05,   6.8092166E-05
     +,   6.9853573E-05,   7.1569149E-05,   7.3230811E-05
     +,   7.4830488E-05,   7.6359727E-05,   7.7810211E-05
     +,   7.9173442E-05,   8.0441161E-05,   8.1605132E-05
     +,   8.2657520E-05,   8.3590792E-05,   8.4397871E-05
     +,   8.5072228E-05,   8.5608059E-05,   8.6000313E-05
     +,   8.6244727E-05,   8.6338077E-05,   8.6278145E-05
     +,   8.6063868E-05,   8.5695414E-05,   8.5174273E-05
     +,   8.4503437E-05,   8.3687301E-05,   8.2732098E-05
     +,   8.1645783E-05,   8.0438200E-05,   7.9121477E-05
     +,   7.7710043E-05,   7.6220851E-05,   7.4673553E-05
     +,   7.3090981E-05,   7.1498987E-05,   6.9927031E-05
     +,   6.8407986E-05,   6.6978610E-05,   6.5679189E-05
     +,   6.4553991E-05,   6.3650870E-05,   6.3021573E-05
     +,   6.2721607E-05,   6.2810679E-05,   6.3353204E-05
     +,   6.4419241E-05,   6.6086031E-05,   6.8440007E-05
     +,   7.1578783E-05,   7.5614320E-05,   8.0674239E-05
     +,   8.6904372E-05,   9.4467076E-05,   1.0354009E-04
     +,   1.1430850E-04,   1.2695731E-04,   1.4165483E-04
     +,   1.5853837E-04,   1.7769437E-04,   1.9913813E-04
     +,   2.2279898E-04,   2.4851298E-04,   2.7602253E-04
     +,   3.0498824E-04,   3.3501771E-04,   3.6571117E-04
     +,   3.9671190E-04,   4.2776144E-04,   4.5875914E-04
     +,   4.8979867E-04,   5.2117498E-04,   5.5336184E-04
     +,   5.8695010E-04,   6.2254415E-04,   6.6064135E-04
     +,   7.0151902E-04,   7.4515166E-04,   7.9118006E-04
     +,   8.3894492E-04,   8.8759081E-04,   9.3620591E-04
     +,   9.8395697E-04,   1.0301828E-03,   1.0744239E-03
     +,   1.1163631E-03,   1.1556997E-03,   1.1920116E-03
     +,   1.2246417E-03,   1.2526537E-03,   1.2748882E-03
     +,   1.2901095E-03,   1.2972252E-03,   1.2955037E-03
     +,   1.2847744E-03,   1.2655345E-03,   1.2389583E-03
     +,   1.2067900E-03,   1.1711556E-03,   1.1343112E-03
     +,   1.0984071E-03,   1.0653052E-03,   1.0364803E-03
     +,   1.0130055E-03,   9.9560816E-04,   9.8472729E-04
     +,   9.8053133E-04,   9.8287046E-04,   9.9117798E-04
     +,   1.0043529E-03,   1.0206960E-03,   1.0379459E-03
     +,   1.0534384E-03,   1.0643796E-03,   1.0681890E-03
     +,   1.0628344E-03,   1.0471040E-03,   1.0207631E-03
     +,   9.8455837E-04,   9.4010029E-04,   8.8962913E-04
     +,   8.3571998E-04,   7.8095915E-04,   7.2766491E-04
     +,   6.7767105E-04,   6.3219172E-04,   5.9178483E-04
     +,   5.5641175E-04,   5.2556273E-04,   4.9841439E-04
     +,   4.7400765E-04,   4.5140536E-04,   4.2981037E-04
     +,   4.0863792E-04,   3.8754460E-04,   3.6641397E-04
     +,   3.4531514E-04,   3.2444193E-04,   3.0405357E-04
     +,   2.8442065E-04,   2.6578092E-04,   2.4831021E-04
     +,   2.3211047E-04,   2.1721110E-04,   2.0357504E-04
     +,   1.9111506E-04,   1.7971215E-04,   1.6923112E-04
     +,   1.5953452E-04,   1.5049467E-04,   1.4200127E-04
     +,   1.3396467E-04,   1.2631583E-04,   1.1900574E-04
     +,   1.1200264E-04,   1.0528816E-04,   9.8852950E-05
     +,   9.2693765E-05,   8.6811015E-05,   8.1205282E-05
     +,   7.5876349E-05,   7.0822483E-05,   6.6039640E-05
     +,   6.1521008E-05,   5.7257737E-05,   5.3239579E-05
     +,   4.9455030E-05,   4.5891742E-05,   4.2537213E-05
     +,   3.9379483E-05,   3.6407146E-05,   3.3609420E-05
     +,   3.0976506E-05,   2.8499830E-05,   2.6171519E-05
     +,   2.3984592E-05,   2.1932963E-05,   2.0011150E-05
     +,   1.8214025E-05,   1.6536822E-05,   1.4975107E-05
     +,   1.3524562E-05,   1.2180812E-05,   1.0939476E-05
     +,   9.7961974E-06,   8.7465278E-06,   7.7858585E-06
     +,   6.9095177E-06,   6.1128499E-06,   5.3910803E-06
     +,   4.7394278E-06,   4.1531862E-06,   3.6276940E-06
     +,   3.1583406E-06,   2.7406447E-06,   2.3702962E-06
     +,   2.0431507E-06,   1.7552311E-06,   1.5027708E-06
     +,   1.2822463E-06,   1.0903295E-06,   9.2395015E-07
     +,   7.8024601E-07,   6.5660618E-07,   5.5062662E-07
     +,   4.6013719E-07,   3.8316375E-07,   3.1794244E-07
     +,   2.6288706E-07,   2.1659460E-07,   1.7781827E-07
     +,   1.4546185E-07,   1.1856805E-07,   9.6299260E-08
     +,   7.7932405E-08,   6.2841174E-08,   5.0489977E-08
     +,   4.0419636E-08,   3.2241140E-08,   2.5624242E-08
     +,   2.0291729E-08,   1.6010583E-08,   1.2586942E-08
     +,   9.8594075E-09,   7.6949398E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_ashz_zz_mass = Yx/0.0173315625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_hzonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9426741E-05,   3.9925868E-05
     +,   4.0387400E-05,   4.0809766E-05,   4.1191506E-05
     +,   4.1531293E-05,   4.1827949E-05,   4.2080417E-05
     +,   4.2287800E-05,   4.2449396E-05,   4.2564647E-05
     +,   4.2633201E-05,   4.2654901E-05,   4.2629796E-05
     +,   4.2558146E-05,   4.2440446E-05,   4.2277436E-05
     +,   4.2070096E-05,   4.1819665E-05,   4.1527659E-05
     +,   4.1195879E-05,   4.0826428E-05,   4.0421706E-05
     +,   3.9984428E-05,   3.9517701E-05,   3.9024922E-05
     +,   3.8509887E-05,   3.7976773E-05,   3.7430145E-05
     +,   3.6874997E-05,   3.6316746E-05,   3.5761215E-05
     +,   3.5214725E-05,   3.4684017E-05,   3.4176297E-05
     +,   3.3699227E-05,   3.3260927E-05,   3.2869953E-05
     +,   3.2535270E-05,   3.2266260E-05,   3.2072636E-05
     +,   3.1964431E-05,   3.1951946E-05,   3.2045657E-05
     +,   3.2256135E-05,   3.2593998E-05,   3.3069751E-05
     +,   3.3693694E-05,   3.4475819E-05,   3.5425634E-05
     +,   3.6552035E-05,   3.7863163E-05,   3.9366190E-05
     +,   4.1067309E-05,   4.2971293E-05,   4.5081677E-05
     +,   4.7400335E-05,   4.9927472E-05,   5.2661442E-05
     +,   5.5598644E-05,   5.8733502E-05,   6.2058360E-05
     +,   6.5563188E-05,   6.9236150E-05,   7.3063289E-05
     +,   7.7028264E-05,   8.1113256E-05,   8.5298227E-05
     +,   8.9562003E-05,   9.3881485E-05,   9.8233060E-05
     +,   1.0259161E-04,   1.0693217E-04,   1.1122890E-04
     +,   1.1545663E-04,   1.1959064E-04,   1.2360683E-04
     +,   1.2748239E-04,   1.3119633E-04,   1.3472959E-04
     +,   1.3806493E-04,   1.4118815E-04,   1.4408729E-04
     +,   1.4675359E-04,   1.4918114E-04,   1.5136726E-04
     +,   1.5331217E-04,   1.5501938E-04,   1.5649512E-04
     +,   1.5774847E-04,   1.5879107E-04,   1.5963671E-04
     +,   1.6030118E-04,   1.6080179E-04,   1.6115700E-04
     +,   1.6138605E-04,   1.6150837E-04,   1.6154340E-04
     +,   1.6150986E-04,   1.6142556E-04,   1.6130695E-04
     +,   1.6116876E-04,   1.6102358E-04,   1.6088186E-04
     +,   1.6075143E-04,   1.6063753E-04,   1.6054272E-04
     +,   1.6046679E-04,   1.6040693E-04,   1.6035764E-04
     +,   1.6031126E-04,   1.6025772E-04,   1.6018529E-04
     +,   1.6008064E-04,   1.5992914E-04,   1.5971546E-04
     +,   1.5942380E-04,   1.5903826E-04,   1.5854341E-04
     +,   1.5792434E-04,   1.5716733E-04,   1.5626011E-04
     +,   1.5519196E-04,   1.5395411E-04,   1.5253984E-04
     +,   1.5094485E-04,   1.4916688E-04,   1.4720633E-04
     +,   1.4506569E-04,   1.4275004E-04,   1.4026626E-04
     +,   1.3762373E-04,   1.3483316E-04,   1.3190741E-04
     +,   1.2886040E-04,   1.2570716E-04,   1.2246380E-04
     +,   1.1914709E-04,   1.1577387E-04,   1.1236111E-04
     +,   1.0892576E-04,   1.0548445E-04,   1.0205292E-04
     +,   9.8646153E-05,   9.5278461E-05,   9.1962836E-05
     +,   8.8711036E-05,   8.5533764E-05,   8.2440471E-05
     +,   7.9439014E-05,   7.6536002E-05,   7.3736912E-05
     +,   7.1045986E-05,   6.8466070E-05,   6.5998946E-05
     +,   6.3645501E-05,   6.1405706E-05,   5.9278555E-05
     +,   5.7262292E-05,   5.5354762E-05,   5.3553071E-05
     +,   5.1853902E-05,   5.0253726E-05,   4.8748741E-05
     +,   4.7334874E-05,   4.6007975E-05,   4.4763914E-05
     +,   4.3598619E-05,   4.2507956E-05,   4.1487914E-05
     +,   4.0534735E-05,   3.9644761E-05,   3.8814491E-05
     +,   3.8040602E-05,   3.7320071E-05,   3.6649977E-05
     +,   3.6027632E-05,   3.5450579E-05,   3.4916542E-05
     +,   3.4423399E-05,   3.3969187E-05,   3.3552140E-05
     +,   3.3170636E-05,   3.2823133E-05,   3.2508222E-05
     +,   3.2224605E-05,   3.1971067E-05,   3.1746436E-05
     +,   3.1549604E-05,   3.1379532E-05,   3.1235173E-05
     +,   3.1115531E-05,   3.1019594E-05,   3.0946379E-05
     +,   3.0894880E-05,   3.0864088E-05,   3.0852971E-05
     +,   3.0860483E-05,   3.0885545E-05,   3.0927069E-05
     +,   3.0983934E-05,   3.1054969E-05,   3.1139018E-05
     +,   3.1234871E-05,   3.1341318E-05,   3.1457112E-05
     +,   3.1580996E-05,   3.1711705E-05,   3.1847962E-05
     +,   3.1988486E-05,   3.2132000E-05,   3.2277239E-05
     +,   3.2422930E-05,   3.2567830E-05,   3.2710712E-05
     +,   3.2850377E-05,   3.2985645E-05,   3.3115379E-05
     +,   3.3238462E-05,   3.3353826E-05,   3.3460459E-05
     +,   3.3557364E-05,   3.3643624E-05,   3.3718337E-05
     +,   3.3780678E-05,   3.3829874E-05,   3.3865199E-05
     +,   3.3885975E-05,   3.3891589E-05,   3.3881493E-05
     +,   3.3855169E-05,   3.3812183E-05,   3.3752145E-05
     +,   3.3674711E-05,   3.3579614E-05,   3.3466618E-05
     +,   3.3335557E-05,   3.3186312E-05,   3.3018812E-05
     +,   3.2833053E-05,   3.2629050E-05,   3.2406901E-05
     +,   3.2166739E-05,   3.1908730E-05,   3.1633092E-05
     +,   3.1340096E-05,   3.1030064E-05,   3.0703330E-05
     +,   3.0360272E-05,   3.0001343E-05,   2.9626997E-05
     +,   2.9237712E-05,   2.8834042E-05,   2.8416554E-05
     +,   2.7985838E-05,   2.7542497E-05,   2.7087197E-05
     +,   2.6620619E-05,   2.6143445E-05,   2.5656382E-05
     +,   2.5160170E-05,   2.4655581E-05,   2.4143359E-05
     +,   2.3624258E-05,   2.3099094E-05,   2.2568644E-05
     +,   2.2033681E-05,   2.1495016E-05,   2.0953461E-05
     +,   2.0409791E-05,   1.9864772E-05,   1.9319201E-05
     +,   1.8773857E-05,   1.8229484E-05,   1.7686802E-05
     +,   1.7146571E-05,   1.6609456E-05,   1.6076179E-05
     +,   1.5547364E-05,   1.5023687E-05,   1.4505723E-05
     +,   1.3994088E-05,   1.3489310E-05,   1.2991940E-05
     +,   1.2502445E-05,   1.2021323E-05,   1.1548985E-05
     +,   1.1085818E-05,   1.0632218E-05,   1.0188487E-05
     +,   9.7549510E-06,   9.3318486E-06,   8.9194400E-06
     +,   8.5178954E-06,   8.1274084E-06,   7.7480881E-06
     +,   7.3800629E-06,   7.0233814E-06,   6.6781104E-06
     +,   6.3442417E-06,   6.0217853E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_hzonly_eez_mass = Yx/0.00470155
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_hzonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0245478E-04,   1.0646853E-04
     +,   1.1051643E-04,   1.1459127E-04,   1.1868554E-04
     +,   1.2279159E-04,   1.2690155E-04,   1.3100739E-04
     +,   1.3510096E-04,   1.3917424E-04,   1.4321896E-04
     +,   1.4722698E-04,   1.5119016E-04,   1.5510057E-04
     +,   1.5895031E-04,   1.6273178E-04,   1.6643753E-04
     +,   1.7006043E-04,   1.7359359E-04,   1.7703048E-04
     +,   1.8036496E-04,   1.8359131E-04,   1.8670406E-04
     +,   1.8969846E-04,   1.9256990E-04,   1.9531448E-04
     +,   1.9792863E-04,   2.0040937E-04,   2.0275406E-04
     +,   2.0496066E-04,   2.0702755E-04,   2.0895366E-04
     +,   2.1073817E-04,   2.1238087E-04,   2.1388193E-04
     +,   2.1524183E-04,   2.1646153E-04,   2.1754215E-04
     +,   2.1848538E-04,   2.1929294E-04,   2.1996698E-04
     +,   2.2050973E-04,   2.2092370E-04,   2.2121157E-04
     +,   2.2137605E-04,   2.2142001E-04,   2.2134645E-04
     +,   2.2115832E-04,   2.2085867E-04,   2.2045050E-04
     +,   2.1993689E-04,   2.1932073E-04,   2.1860513E-04
     +,   2.1779287E-04,   2.1688690E-04,   2.1588994E-04
     +,   2.1480481E-04,   2.1363418E-04,   2.1238071E-04
     +,   2.1104704E-04,   2.0963576E-04,   2.0814943E-04
     +,   2.0659073E-04,   2.0496221E-04,   2.0326646E-04
     +,   2.0150632E-04,   1.9968447E-04,   1.9780394E-04
     +,   1.9586760E-04,   1.9387876E-04,   1.9184059E-04
     +,   1.8975674E-04,   1.8763077E-04,   1.8546671E-04
     +,   1.8326870E-04,   1.8104092E-04,   1.7878808E-04
     +,   1.7651514E-04,   1.7422705E-04,   1.7192907E-04
     +,   1.6962689E-04,   1.6732616E-04,   1.6503295E-04
     +,   1.6275331E-04,   1.6049368E-04,   1.5826037E-04
     +,   1.5606004E-04,   1.5389922E-04,   1.5178470E-04
     +,   1.4972301E-04,   1.4772074E-04,   1.4578443E-04
     +,   1.4392055E-04,   1.4213521E-04,   1.4043426E-04
     +,   1.3882354E-04,   1.3730826E-04,   1.3589348E-04
     +,   1.3458369E-04,   1.3338306E-04,   1.3229504E-04
     +,   1.3132277E-04,   1.3046867E-04,   1.2973466E-04
     +,   1.2912194E-04,   1.2863101E-04,   1.2826188E-04
     +,   1.2801375E-04,   1.2788520E-04,   1.2787404E-04
     +,   1.2797747E-04,   1.2819207E-04,   1.2851371E-04
     +,   1.2893767E-04,   1.2945860E-04,   1.3007066E-04
     +,   1.3076747E-04,   1.3154217E-04,   1.3238749E-04
     +,   1.3329583E-04,   1.3425923E-04,   1.3526948E-04
     +,   1.3631825E-04,   1.3739704E-04,   1.3849730E-04
     +,   1.3961046E-04,   1.4072809E-04,   1.4184180E-04
     +,   1.4294351E-04,   1.4402528E-04,   1.4507958E-04
     +,   1.4609922E-04,   1.4707744E-04,   1.4800791E-04
     +,   1.4888489E-04,   1.4970313E-04,   1.5045799E-04
     +,   1.5114545E-04,   1.5176207E-04,   1.5230516E-04
     +,   1.5277261E-04,   1.5316301E-04,   1.5347563E-04
     +,   1.5371037E-04,   1.5386779E-04,   1.5394916E-04
     +,   1.5395619E-04,   1.5389136E-04,   1.5375756E-04
     +,   1.5355830E-04,   1.5329749E-04,   1.5297956E-04
     +,   1.5260931E-04,   1.5219179E-04,   1.5173244E-04
     +,   1.5123696E-04,   1.5071120E-04,   1.5016114E-04
     +,   1.4959283E-04,   1.4901247E-04,   1.4842612E-04
     +,   1.4783975E-04,   1.4725937E-04,   1.4669067E-04
     +,   1.4613924E-04,   1.4561029E-04,   1.4510885E-04
     +,   1.4463956E-04,   1.4420679E-04,   1.4381435E-04
     +,   1.4346576E-04,   1.4316404E-04,   1.4291173E-04
     +,   1.4271095E-04,   1.4256329E-04,   1.4246983E-04
     +,   1.4243116E-04,   1.4244733E-04,   1.4251797E-04
     +,   1.4264211E-04,   1.4281840E-04,   1.4304493E-04
     +,   1.4331940E-04,   1.4363906E-04,   1.4400070E-04
     +,   1.4440084E-04,   1.4483549E-04,   1.4530044E-04
     +,   1.4579119E-04,   1.4630292E-04,   1.4683059E-04
     +,   1.4736901E-04,   1.4791284E-04,   1.4845653E-04
     +,   1.4899453E-04,   1.4952123E-04,   1.5003102E-04
     +,   1.5051827E-04,   1.5097744E-04,   1.5140316E-04
     +,   1.5179005E-04,   1.5213297E-04,   1.5242700E-04
     +,   1.5266740E-04,   1.5284968E-04,   1.5296960E-04
     +,   1.5302327E-04,   1.5300704E-04,   1.5291765E-04
     +,   1.5275212E-04,   1.5250793E-04,   1.5218277E-04
     +,   1.5177482E-04,   1.5128260E-04,   1.5070502E-04
     +,   1.5004132E-04,   1.4929120E-04,   1.4845464E-04
     +,   1.4753203E-04,   1.4652412E-04,   1.4543197E-04
     +,   1.4425698E-04,   1.4300089E-04,   1.4166576E-04
     +,   1.4025389E-04,   1.3876778E-04,   1.3721031E-04
     +,   1.3558459E-04,   1.3389385E-04,   1.3214143E-04
     +,   1.3033100E-04,   1.2846642E-04,   1.2655149E-04
     +,   1.2459012E-04,   1.2258647E-04,   1.2054462E-04
     +,   1.1846863E-04,   1.1636277E-04,   1.1423127E-04
     +,   1.1207820E-04,   1.0990763E-04,   1.0772368E-04
     +,   1.0553039E-04,   1.0333163E-04,   1.0113114E-04
     +,   9.8932658E-05,   9.6739837E-05,   9.4556082E-05
     +,   9.2384573E-05,   9.0228619E-05,   8.8091118E-05
     +,   8.5974832E-05,   8.3882493E-05,   8.1816601E-05
     +,   7.9779398E-05,   7.7772929E-05,   7.5799187E-05
     +,   7.3859977E-05,   7.1956812E-05,   7.0090988E-05
     +,   6.8263784E-05,   6.6476285E-05,   6.4729276E-05
     +,   6.3023399E-05,   6.1359278E-05,   5.9737224E-05
     +,   5.8157406E-05,   5.6619945E-05,   5.5124823E-05
     +,   5.3671782E-05,   5.2260461E-05,   5.0890478E-05
     +,   4.9561313E-05,   4.8272304E-05,   4.7022655E-05
     +,   4.5811637E-05,   4.4638291E-05,   4.3501725E-05
     +,   4.2400854E-05,   4.1334697E-05,   4.0302068E-05
     +,   3.9301900E-05,   3.8332972E-05,   3.7394148E-05
     +,   3.6484184E-05,   3.5601937E-05,   3.4746176E-05
     +,   3.3915680E-05,   3.3109318E-05,   3.2325876E-05
     +,   3.1564268E-05,   3.0823321E-05,   3.0102005E-05
     +,   2.9399222E-05,   2.8713999E-05,   2.8045319E-05
     +,   2.7392298E-05,   2.6754002E-05,   2.6129626E-05
     +,   2.5518340E-05,   2.4919436E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_hzonly_qq_mass = Yx/0.0102984
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_hzonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.3782678E-05,   7.6040764E-05
     +,   7.8303477E-05,   8.0570520E-05,   8.2842133E-05
     +,   8.5119311E-05,   8.7403714E-05,   8.9697860E-05
     +,   9.2005044E-05,   9.4329684E-05,   9.6676966E-05
     +,   9.9053286E-05,   1.0146596E-04,   1.0392348E-04
     +,   1.0643545E-04,   1.0901241E-04,   1.1166604E-04
     +,   1.1440895E-04,   1.1725462E-04,   1.2021733E-04
     +,   1.2331204E-04,   1.2655412E-04,   1.2995942E-04
     +,   1.3354390E-04,   1.3732338E-04,   1.4131369E-04
     +,   1.4553008E-04,   1.4998739E-04,   1.5469956E-04
     +,   1.5967996E-04,   1.6494071E-04,   1.7049315E-04
     +,   1.7634747E-04,   1.8251293E-04,   1.8899771E-04
     +,   1.9580915E-04,   2.0295363E-04,   2.1043666E-04
     +,   2.1826355E-04,   2.2643807E-04,   2.3496407E-04
     +,   2.4384414E-04,   2.5308004E-04,   2.6267246E-04
     +,   2.7262059E-04,   2.8292165E-04,   2.9357112E-04
     +,   3.0456146E-04,   3.1588209E-04,   3.2751937E-04
     +,   3.3945590E-04,   3.5167063E-04,   3.6413866E-04
     +,   3.7683296E-04,   3.8972253E-04,   4.0277673E-04
     +,   4.1596364E-04,   4.2925336E-04,   4.4261984E-04
     +,   4.5604233E-04,   4.6950887E-04,   4.8301727E-04
     +,   4.9657834E-04,   5.1021762E-04,   5.2397780E-04
     +,   5.3791743E-04,   5.5211427E-04,   5.6666275E-04
     +,   5.8167410E-04,   5.9727149E-04,   6.1359088E-04
     +,   6.3077093E-04,   6.4895285E-04,   6.6826900E-04
     +,   6.8883965E-04,   7.1076484E-04,   7.3411403E-04
     +,   7.5892109E-04,   7.8517850E-04,   8.1283180E-04
     +,   8.4177282E-04,   8.7184442E-04,   9.0283429E-04
     +,   9.3448639E-04,   9.6649840E-04,   9.9853985E-04
     +,   1.0302529E-03,   1.0612753E-03,   1.0912439E-03
     +,   1.1198147E-03,   1.1466744E-03,   1.1715466E-03
     +,   1.1942062E-03,   1.2144847E-03,   1.2322712E-03
     +,   1.2475121E-03,   1.2602085E-03,   1.2704130E-03
     +,   1.2782179E-03,   1.2837494E-03,   1.2871580E-03
     +,   1.2886102E-03,   1.2882818E-03,   1.2863516E-03
     +,   1.2829945E-03,   1.2783838E-03,   1.2726857E-03
     +,   1.2660607E-03,   1.2586636E-03,   1.2506386E-03
     +,   1.2421283E-03,   1.2332647E-03,   1.2241709E-03
     +,   1.2149581E-03,   1.2057242E-03,   1.1965513E-03
     +,   1.1875017E-03,   1.1786176E-03,   1.1699207E-03
     +,   1.1614127E-03,   1.1530735E-03,   1.1448677E-03
     +,   1.1367431E-03,   1.1286348E-03,   1.1204684E-03
     +,   1.1121643E-03,   1.1036419E-03,   1.0948187E-03
     +,   1.0856164E-03,   1.0759642E-03,   1.0658003E-03
     +,   1.0550767E-03,   1.0437568E-03,   1.0318247E-03
     +,   1.0192816E-03,   1.0061471E-03,   9.9246367E-04
     +,   9.7829185E-04,   9.6371042E-04,   9.4881182E-04
     +,   9.3370187E-04,   9.1849203E-04,   9.0329704E-04
     +,   8.8822702E-04,   8.7338861E-04,   8.5887243E-04
     +,   8.4475684E-04,   8.3110225E-04,   8.1795064E-04
     +,   8.0532418E-04,   7.9322734E-04,   7.8164943E-04
     +,   7.7056489E-04,   7.5993827E-04,   7.4972684E-04
     +,   7.3988398E-04,   7.3036272E-04,   7.2111801E-04
     +,   7.1210985E-04,   7.0330559E-04,   6.9468137E-04
     +,   6.8622065E-04,   6.7791954E-04,   6.6978304E-04
     +,   6.6182582E-04,   6.5407099E-04,   6.4655201E-04
     +,   6.3930824E-04,   6.3238549E-04,   6.2583381E-04
     +,   6.1970763E-04,   6.1406189E-04,   6.0895068E-04
     +,   6.0442608E-04,   6.0053589E-04,   5.9732056E-04
     +,   5.9481215E-04,   5.9303269E-04,   5.9199153E-04
     +,   5.9168605E-04,   5.9209840E-04,   5.9319910E-04
     +,   5.9494399E-04,   5.9727766E-04,   6.0013577E-04
     +,   6.0344551E-04,   6.0713058E-04,   6.1111292E-04
     +,   6.1531772E-04,   6.1967532E-04,   6.2412547E-04
     +,   6.2861963E-04,   6.3312246E-04,   6.3761300E-04
     +,   6.4208690E-04,   6.4655289E-04,   6.5103348E-04
     +,   6.5556058E-04,   6.6017359E-04,   6.6491513E-04
     +,   6.6982507E-04,   6.7493838E-04,   6.8027864E-04
     +,   6.8585557E-04,   6.9165922E-04,   6.9765979E-04
     +,   7.0380472E-04,   7.1001705E-04,   7.1619824E-04
     +,   7.2222785E-04,   7.2796823E-04,   7.3326670E-04
     +,   7.3796138E-04,   7.4188644E-04,   7.4487680E-04
     +,   7.4677507E-04,   7.4743619E-04,   7.4673234E-04
     +,   7.4455887E-04,   7.4083603E-04,   7.3551253E-04
     +,   7.2856736E-04,   7.2000921E-04,   7.0987822E-04
     +,   6.9824123E-04,   6.8519206E-04,   6.7084661E-04
     +,   6.5534137E-04,   6.3882640E-04,   6.2146212E-04
     +,   6.0341560E-04,   5.8485701E-04,   5.6595192E-04
     +,   5.4686051E-04,   5.2773498E-04,   5.0871418E-04
     +,   4.8992253E-04,   4.7147024E-04,   4.5345046E-04
     +,   4.3593894E-04,   4.1899335E-04,   4.0265729E-04
     +,   3.8695772E-04,   3.7190752E-04,   3.5750589E-04
     +,   3.4374275E-04,   3.3059812E-04,   3.1804375E-04
     +,   3.0604601E-04,   2.9456822E-04,   2.8357003E-04
     +,   2.7301014E-04,   2.6284836E-04,   2.5304567E-04
     +,   2.4356489E-04,   2.3437175E-04,   2.2543594E-04
     +,   2.1673132E-04,   2.0823511E-04,   1.9992859E-04
     +,   1.9179792E-04,   1.8383289E-04,   1.7602631E-04
     +,   1.6837442E-04,   1.6087694E-04,   1.5353525E-04
     +,   1.4635276E-04,   1.3933473E-04,   1.3248768E-04
     +,   1.2581809E-04,   1.1933297E-04,   1.1303956E-04
     +,   1.0694479E-04,   1.0105450E-04,   9.5373813E-05
     +,   8.9907408E-05,   8.4658175E-05,   7.9628575E-05
     +,   7.4819189E-05,   7.0230104E-05,   6.5859684E-05
     +,   6.1705752E-05,   5.7764628E-05,   5.4032276E-05
     +,   5.0503346E-05,   4.7172263E-05,   4.4032586E-05
     +,   4.1077365E-05,   3.8299640E-05,   3.5691806E-05
     +,   3.3246411E-05,   3.0955649E-05,   2.8811968E-05
     +,   2.6807613E-05,   2.4935209E-05,   2.3187285E-05
     +,   2.1556809E-05,   2.0036758E-05,   1.8620563E-05
     +,   1.7301745E-05,   1.6074267E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_hzonly_ww_mass = Yx/0.0399233333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A200N_tt_hzonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8130267E-05,   3.8879192E-05
     +,   3.9629402E-05,   4.0381699E-05,   4.1137024E-05
     +,   4.1896445E-05,   4.2661137E-05,   4.3432388E-05
     +,   4.4211607E-05,   4.5000350E-05,   4.5800229E-05
     +,   4.6612979E-05,   4.7440455E-05,   4.8284546E-05
     +,   4.9147286E-05,   5.0030736E-05,   5.0937058E-05
     +,   5.1868403E-05,   5.2827036E-05,   5.3815187E-05
     +,   5.4835116E-05,   5.5889064E-05,   5.6979283E-05
     +,   5.8107962E-05,   5.9277179E-05,   6.0489048E-05
     +,   6.1745493E-05,   6.3048370E-05,   6.4399377E-05
     +,   6.5800014E-05,   6.7251705E-05,   6.8755668E-05
     +,   7.0312803E-05,   7.1923918E-05,   7.3589516E-05
     +,   7.5309828E-05,   7.7084915E-05,   7.8914425E-05
     +,   8.0797945E-05,   8.2734521E-05,   8.4723135E-05
     +,   8.6762397E-05,   8.8850604E-05,   9.0985872E-05
     +,   9.3166032E-05,   9.5388597E-05,   9.7650940E-05
     +,   9.9950143E-05,   1.0228320E-04,   1.0464677E-04
     +,   1.0703747E-04,   1.0945170E-04,   1.1188574E-04
     +,   1.1433586E-04,   1.1679798E-04,   1.1926825E-04
     +,   1.2174252E-04,   1.2421675E-04,   1.2668662E-04
     +,   1.2914800E-04,   1.3159652E-04,   1.3402799E-04
     +,   1.3643781E-04,   1.3882168E-04,   1.4117517E-04
     +,   1.4349367E-04,   1.4577263E-04,   1.4800738E-04
     +,   1.5019324E-04,   1.5232548E-04,   1.5439941E-04
     +,   1.5641017E-04,   1.5835308E-04,   1.6022340E-04
     +,   1.6201650E-04,   1.6372796E-04,   1.6535340E-04
     +,   1.6688863E-04,   1.6832988E-04,   1.6967366E-04
     +,   1.7091667E-04,   1.7205639E-04,   1.7309033E-04
     +,   1.7401697E-04,   1.7483502E-04,   1.7554392E-04
     +,   1.7614361E-04,   1.7663470E-04,   1.7701840E-04
     +,   1.7729640E-04,   1.7747104E-04,   1.7754524E-04
     +,   1.7752219E-04,   1.7740582E-04,   1.7720030E-04
     +,   1.7691049E-04,   1.7654165E-04,   1.7609980E-04
     +,   1.7559133E-04,   1.7502396E-04,   1.7440617E-04
     +,   1.7374806E-04,   1.7306161E-04,   1.7236080E-04
     +,   1.7166260E-04,   1.7098714E-04,   1.7035859E-04
     +,   1.6980573E-04,   1.6936244E-04,   1.6906849E-04
     +,   1.6896993E-04,   1.6911948E-04,   1.6957679E-04
     +,   1.7040820E-04,   1.7168642E-04,   1.7348991E-04
     +,   1.7590138E-04,   1.7900650E-04,   1.8289118E-04
     +,   1.8763948E-04,   1.9333050E-04,   2.0003435E-04
     +,   2.0780896E-04,   2.1669647E-04,   2.2671997E-04
     +,   2.3787902E-04,   2.5014923E-04,   2.6347864E-04
     +,   2.7779024E-04,   2.9297968E-04,   3.0892296E-04
     +,   3.2547535E-04,   3.4248346E-04,   3.5978842E-04
     +,   3.7723809E-04,   3.9469599E-04,   4.1205043E-04
     +,   4.2922579E-04,   4.4619286E-04,   4.6297538E-04
     +,   4.7965714E-04,   4.9638579E-04,   5.1337742E-04
     +,   5.3091615E-04,   5.4934953E-04,   5.6909164E-04
     +,   5.9061596E-04,   6.1445049E-04,   6.4117200E-04
     +,   6.7140302E-04,   7.0579868E-04,   7.4502855E-04
     +,   7.8975508E-04,   8.4059912E-04,   8.9808676E-04
     +,   9.6257759E-04,   1.0341870E-03,   1.1126987E-03
     +,   1.1974764E-03,   1.2873784E-03,   1.3807403E-03
     +,   1.4753821E-03,   1.5686859E-03,   1.6577569E-03
     +,   1.7396521E-03,   1.8116492E-03,   1.8715236E-03
     +,   1.9178250E-03,   1.9500569E-03,   1.9687607E-03
     +,   1.9754563E-03,   1.9724618E-03,   1.9625977E-03
     +,   1.9488273E-03,   1.9338982E-03,   1.9200369E-03
     +,   1.9087524E-03,   1.9007743E-03,   1.8961142E-03
     +,   1.8942342E-03,   1.8942653E-03,   1.8952176E-03
     +,   1.8961546E-03,   1.8962811E-03,   1.8949544E-03
     +,   1.8916376E-03,   1.8858158E-03,   1.8769321E-03
     +,   1.8643308E-03,   1.8472795E-03,   1.8250140E-03
     +,   1.7968214E-03,   1.7621394E-03,   1.7206430E-03
     +,   1.6723041E-03,   1.6174240E-03,   1.5566334E-03
     +,   1.4908630E-03,   1.4212736E-03,   1.3491933E-03
     +,   1.2760384E-03,   1.2032234E-03,   1.1320725E-03
     +,   1.0637513E-03,   9.9921355E-04,   9.3914947E-04
     +,   8.8398129E-04,   8.3387148E-04,   7.8875083E-04
     +,   7.4836088E-04,   7.1231363E-04,   6.8014982E-04
     +,   6.5138761E-04,   6.2556547E-04,   6.0227141E-04
     +,   5.8116094E-04,   5.6195864E-04,   5.4445199E-04
     +,   5.2847806E-04,   5.1391002E-04,   5.0063926E-04
     +,   4.8856146E-04,   4.7756804E-04,   4.6753837E-04
     +,   4.5833783E-04,   4.4981888E-04,   4.4182627E-04
     +,   4.3420139E-04,   4.2678785E-04,   4.1943882E-04
     +,   4.1202185E-04,   4.0442377E-04,   3.9655267E-04
     +,   3.8834070E-04,   3.7974500E-04,   3.7074561E-04
     +,   3.6134527E-04,   3.5156720E-04,   3.4145196E-04
     +,   3.3105316E-04,   3.2043495E-04,   3.0966924E-04
     +,   2.9883112E-04,   2.8799524E-04,   2.7723296E-04
     +,   2.6661169E-04,   2.5619063E-04,   2.4601992E-04
     +,   2.3613952E-04,   2.2657985E-04,   2.1736034E-04
     +,   2.0849038E-04,   1.9997098E-04,   1.9179514E-04
     +,   1.8394915E-04,   1.7641365E-04,   1.6916677E-04
     +,   1.6218398E-04,   1.5543970E-04,   1.4890864E-04
     +,   1.4256737E-04,   1.3639453E-04,   1.3037126E-04
     +,   1.2448187E-04,   1.1871459E-04,   1.1306065E-04
     +,   1.0751458E-04,   1.0207434E-04,   9.6740703E-05
     +,   9.1516420E-05,   8.6406260E-05,   8.1416736E-05
     +,   7.6555436E-05,   7.1830131E-05,   6.7248882E-05
     +,   6.2819956E-05,   5.8550537E-05,   5.4447653E-05
     +,   5.0516821E-05,   4.6762947E-05,   4.3189255E-05
     +,   3.9798175E-05,   3.6590409E-05,   3.3565822E-05
     +,   3.0722684E-05,   2.8058537E-05,   2.5569612E-05
     +,   2.3251261E-05,   2.1098254E-05,   1.9104406E-05
     +,   1.7263266E-05,   1.5567690E-05,   1.4010462E-05
     +,   1.2583956E-05,   1.1280626E-05,   1.0092736E-05
     +,   9.0127787E-06,   8.0332202E-06,   7.1468589E-06
     +,   6.3466023E-06,   5.6257404E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A200N_tt_hzonly_zz_mass = Yx/0.032585
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_haonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1480557E-22,   4.8070351E-22
     +,   1.9626857E-21,   7.8142387E-21,   3.0337634E-20
     +,   1.1485130E-19,   4.2398701E-19,   1.5262623E-18
     +,   5.3574214E-18,   1.8338052E-17,   6.1208335E-17
     +,   1.9921806E-16,   6.3227616E-16,   1.9567969E-15
     +,   5.9053363E-15,   1.7378182E-14,   4.9868231E-14
     +,   1.3954183E-13,   3.8075502E-13,   1.0130853E-12
     +,   2.6284953E-12,   6.6501158E-12,   1.6406099E-11
     +,   3.9468831E-11,   9.2587257E-11,   2.1179451E-10
     +,   4.7243165E-10,   1.0275980E-09,   2.1795536E-09
     +,   4.5078870E-09,   9.0915604E-09,   1.7879866E-08
     +,   3.4288689E-08,   6.4120599E-08,   1.1692432E-07
     +,   2.0790857E-07,   3.6049622E-07,   6.0951731E-07
     +,   1.0049392E-06,   1.6156525E-06,   2.5329214E-06
     +,   3.8722105E-06,   5.7724737E-06,   8.3913974E-06
     +,   1.1895472E-05,   1.6444252E-05,   2.2169044E-05
     +,   2.9147750E-05,   3.7378952E-05,   4.6759957E-05
     +,   5.7074136E-05,   6.7993067E-05,   7.9097394E-05
     +,   8.9918605E-05,   9.9995399E-05,   1.0894446E-04
     +,   1.1652576E-04,   1.2269572E-04,   1.2763111E-04
     +,   1.3171458E-04,   1.3547925E-04,   1.3951761E-04
     +,   1.4437007E-04,   1.5041622E-04,   1.5779080E-04
     +,   1.6634462E-04,   1.7566254E-04,   1.8512814E-04
     +,   1.9402622E-04,   2.0164890E-04,   2.0738966E-04
     +,   2.1079827E-04,   2.1160001E-04,   2.0968138E-04
     +,   2.0506252E-04,   1.9787207E-04,   1.8833790E-04
     +,   1.7679273E-04,   1.6368528E-04,   1.4958554E-04
     +,   1.3517005E-04,   1.2117620E-04,   1.0833939E-04
     +,   9.7311633E-05,   8.8590874E-05,   8.2463135E-05
     +,   7.8978570E-05,   7.7955236E-05,   7.9013204E-05
     +,   8.1626735E-05,   8.5186766E-05,   8.9062909E-05
     +,   9.2659575E-05,   9.5461146E-05,   9.7063676E-05
     +,   9.7193719E-05,   9.5714866E-05,   9.2623108E-05
     +,   8.8032037E-05,   8.2151972E-05,   7.5262018E-05
     +,   6.7682311E-05,   5.9743368E-05,   5.1761879E-05
     +,   4.4017725E-05,   3.6739733E-05,   3.0097839E-05
     +,   2.4200697E-05,   1.9098994E-05,   1.4793775E-05
     +,   1.1247100E-05,   8.3924233E-06,   6.1464975E-06
     +,   4.4182752E-06,   3.1172515E-06,   2.1586134E-06
     +,   1.4671440E-06,   9.7870986E-07,   6.4081144E-07
     +,   4.1180925E-07,   2.5974344E-07,   1.6079859E-07
     +,   9.7704806E-08,   5.8269226E-08,   3.4107043E-08
     +,   1.9595031E-08,   1.1049148E-08,   6.1151839E-09
     +,   3.3217760E-09,   1.7710463E-09,   9.2676394E-10
     +,   4.7600013E-10,   2.3995195E-10,   1.1872457E-10
     +,   5.7656220E-11,   2.7480901E-11,   1.2855974E-11
     +,   5.9030844E-12,   2.6603680E-12,   1.1767478E-12
     +,   5.1087297E-13,   2.1769264E-13,   9.1046860E-14
     +,   3.7373326E-14,   1.5057796E-14,   5.9545620E-15
     +,   2.3110779E-15,   8.8037592E-16,   3.2917267E-16
     +,   1.2080105E-16,   4.3510236E-17,   1.5381610E-17
     +,   5.3372195E-18,   1.8176856E-18,   6.0757000E-19
     +,   1.9932467E-19,   6.4184873E-20,   2.0285850E-20
     +,   6.2925390E-21,   1.9158757E-21,   5.7252460E-22
     +,   1.6791710E-22,   4.8337711E-23,   1.3657858E-23
     +,   3.7876332E-24,   1.0309174E-24,   2.7540394E-25
     +,   7.2214626E-26,   1.8585201E-26,   4.6944342E-27
     +,   1.1638171E-27,   2.8320106E-28,   6.7638732E-29
     +,   1.5855014E-29,   3.6479156E-30,   8.2378719E-31
     +,   1.8257834E-31,   3.9717071E-32,   8.4803505E-33
     +,   1.7772119E-33,   3.6553884E-34,   7.3792691E-35
     +,   1.4622055E-35,   2.8437557E-36,   5.4280244E-37
     +,   1.0169041E-37,   1.8699510E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_haonly_eez_mass = Yx/0.00165433333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_haonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DATA LBOUND, UBOUND / 50., 120./
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
C There is only one MC event; what else can we do?
      Yx = 1.0
      END IF
      A202N_tt_haonly_qq_mass = Yx/0.002877
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_haonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3870794E-07,   2.8131473E-07
     +,   3.3059717E-07,   3.8742422E-07,   4.5274663E-07
     +,   5.2760026E-07,   6.1310624E-07,   7.1047253E-07
     +,   8.2099223E-07,   9.4604712E-07,   1.0870956E-06
     +,   1.2456719E-06,   1.4233799E-06,   1.6218810E-06
     +,   1.8428859E-06,   2.0881375E-06,   2.3593975E-06
     +,   2.6584248E-06,   2.9869591E-06,   3.3466913E-06
     +,   3.7392440E-06,   4.1661415E-06,   4.6287701E-06
     +,   5.1283919E-06,   5.6660219E-06,   6.2425115E-06
     +,   6.8584241E-06,   7.5140465E-06,   8.2093529E-06
     +,   8.9439709E-06,   9.7171678E-06,   1.0527817E-05
     +,   1.1374392E-05,   1.2254952E-05,   1.3167140E-05
     +,   1.4108180E-05,   1.5074898E-05,   1.6063723E-05
     +,   1.7070788E-05,   1.8091803E-05,   1.9122335E-05
     +,   2.0157673E-05,   2.1192998E-05,   2.2223436E-05
     +,   2.3244154E-05,   2.4250459E-05,   2.5237912E-05
     +,   2.6202430E-05,   2.7140419E-05,   2.8048898E-05
     +,   2.8925611E-05,   2.9769169E-05,   3.0579147E-05
     +,   3.1356263E-05,   3.2102336E-05,   3.2820561E-05
     +,   3.3515425E-05,   3.4192843E-05,   3.4860146E-05
     +,   3.5526096E-05,   3.6200832E-05,   3.6895843E-05
     +,   3.7623759E-05,   3.8398353E-05,   3.9234295E-05
     +,   4.0146835E-05,   4.1151761E-05,   4.2264859E-05
     +,   4.3501877E-05,   4.4877885E-05,   4.6407218E-05
     +,   4.8102804E-05,   4.9976134E-05,   5.2036517E-05
     +,   5.4291097E-05,   5.6744408E-05,   5.9397931E-05
     +,   6.2249965E-05,   6.5295651E-05,   6.8526759E-05
     +,   7.1931216E-05,   7.5493946E-05,   7.9196056E-05
     +,   8.3015919E-05,   8.6928521E-05,   9.0906673E-05
     +,   9.4920440E-05,   9.8938508E-05,   1.0292767E-04
     +,   1.0685424E-04,   1.1068409E-04,   1.1438293E-04
     +,   1.1791709E-04,   1.2125424E-04,   1.2436353E-04
     +,   1.2721583E-04,   1.2978457E-04,   1.3204552E-04
     +,   1.3397766E-04,   1.3556278E-04,   1.3678608E-04
     +,   1.3763597E-04,   1.3810431E-04,   1.3818630E-04
     +,   1.3788047E-04,   1.3718859E-04,   1.3611563E-04
     +,   1.3466961E-04,   1.3286127E-04,   1.3070414E-04
     +,   1.2821438E-04,   1.2541022E-04,   1.2231234E-04
     +,   1.1894300E-04,   1.1532647E-04,   1.1148809E-04
     +,   1.0745486E-04,   1.0325421E-04,   9.8914847E-05
     +,   9.4465409E-05,   8.9934685E-05,   8.5351639E-05
     +,   8.0744743E-05,   7.6141499E-05,   7.1568378E-05
     +,   6.7051107E-05,   6.2613261E-05,   5.8277328E-05
     +,   5.4063305E-05,   4.9989649E-05,   4.6072113E-05
     +,   4.2324671E-05,   3.8758448E-05,   3.5382698E-05
     +,   3.2204003E-05,   2.9226705E-05,   2.6453177E-05
     +,   2.3883733E-05,   2.1516618E-05,   1.9348405E-05
     +,   1.7374279E-05,   1.5588099E-05,   1.3982482E-05
     +,   1.2549166E-05,   1.1279331E-05,   1.0163508E-05
     +,   9.1919301E-06,   8.3547493E-06,   7.6421093E-06
     +,   7.0442338E-06,   6.5516224E-06,   6.1551541E-06
     +,   5.8461255E-06,   5.6162921E-06,   5.4579482E-06
     +,   5.3639487E-06,   5.3277035E-06,   5.3431754E-06
     +,   5.4048865E-06,   5.5078795E-06,   5.6477015E-06
     +,   5.8203741E-06,   6.0223406E-06,   6.2504355E-06
     +,   6.5018612E-06,   6.7741439E-06,   7.0650658E-06
     +,   7.3726515E-06,   7.6951492E-06,   8.0309883E-06
     +,   8.3787181E-06,   8.7370090E-06,   9.1046486E-06
     +,   9.4805036E-06,   9.8634528E-06,   1.0252465E-05
     +,   1.0646525E-05,   1.1044621E-05,   1.1445743E-05
     +,   1.1848912E-05,   1.2253146E-05,   1.2657431E-05
     +,   1.3060744E-05,   1.3462083E-05,   1.3860430E-05
     +,   1.4254741E-05,   1.4643957E-05,   1.5027048E-05
     +,   1.5402975E-05,   1.5770671E-05,   1.6129110E-05
     +,   1.6477272E-05,   1.6814129E-05,   1.7138673E-05
     +,   1.7449947E-05,   1.7747006E-05,   1.8028933E-05
     +,   1.8294835E-05,   1.8543889E-05,   1.8775310E-05
     +,   1.8988350E-05,   1.9182311E-05,   1.9356570E-05
     +,   1.9510564E-05,   1.9643772E-05,   1.9755758E-05
     +,   1.9846155E-05,   1.9914656E-05,   1.9961029E-05
     +,   1.9985126E-05,   1.9986861E-05,   1.9966228E-05
     +,   1.9923300E-05,   1.9858218E-05,   1.9771196E-05
     +,   1.9662530E-05,   1.9532587E-05,   1.9381789E-05
     +,   1.9210625E-05,   1.9019679E-05,   1.8809556E-05
     +,   1.8580935E-05,   1.8334553E-05,   1.8071200E-05
     +,   1.7791703E-05,   1.7496915E-05,   1.7187762E-05
     +,   1.6865184E-05,   1.6530144E-05,   1.6183621E-05
     +,   1.5826630E-05,   1.5460206E-05,   1.5085369E-05
     +,   1.4703137E-05,   1.4314565E-05,   1.3920670E-05
     +,   1.3522453E-05,   1.3120927E-05,   1.2717091E-05
     +,   1.2311893E-05,   1.1906256E-05,   1.1501096E-05
     +,   1.1097307E-05,   1.0695713E-05,   1.0297103E-05
     +,   9.9022573E-06,   9.5119076E-06,   9.1267220E-06
     +,   8.7473236E-06,   8.3743280E-06,   8.0082646E-06
     +,   7.6496244E-06,   7.2988669E-06,   6.9564117E-06
     +,   6.6226057E-06,   6.2977520E-06,   5.9821318E-06
     +,   5.6759804E-06,   5.3794706E-06,   5.0927370E-06
     +,   4.8158913E-06,   4.5490074E-06,   4.2921051E-06
     +,   4.0451723E-06,   3.8081878E-06,   3.5810751E-06
     +,   3.3637320E-06,   3.1560442E-06,   2.9578728E-06
     +,   2.7690423E-06,   2.5893610E-06,   2.4186293E-06
     +,   2.2566326E-06,   2.1031292E-06,   1.9578706E-06
     +,   1.8206093E-06,   1.6910727E-06,   1.5689990E-06
     +,   1.4541044E-06,   1.3461192E-06,   1.2447553E-06
     +,   1.1497390E-06,   1.0607849E-06,   9.7762074E-07
     +,   8.9996570E-07,   8.2755417E-07,   7.6011725E-07
     +,   6.9739292E-07,   6.3913006E-07,   5.8507771E-07
     +,   5.3499895E-07,   4.8865775E-07,   4.4583234E-07
     +,   4.0630385E-07,   3.6986680E-07,   3.3631960E-07
     +,   3.0547383E-07,   2.7714592E-07,   2.5116429E-07
     +,   2.2736303E-07,   2.0558754E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_haonly_ww_mass = Yx/0.0020964
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_haonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8214847E-05,   2.9517605E-05
     +,   3.0852745E-05,   3.2219494E-05,   3.3616914E-05
     +,   3.5043882E-05,   3.6499088E-05,   3.7981019E-05
     +,   3.9487899E-05,   4.1017815E-05,   4.2568503E-05
     +,   4.4137498E-05,   4.5722030E-05,   4.7319096E-05
     +,   4.8925380E-05,   5.0537317E-05,   5.2151030E-05
     +,   5.3762404E-05,   5.5367058E-05,   5.6960329E-05
     +,   5.8537364E-05,   6.0093069E-05,   6.1622137E-05
     +,   6.3119216E-05,   6.4578642E-05,   6.5994820E-05
     +,   6.7362023E-05,   6.8674482E-05,   6.9926522E-05
     +,   7.1112474E-05,   7.2226823E-05,   7.3264200E-05
     +,   7.4219424E-05,   7.5087621E-05,   7.5864147E-05
     +,   7.6544748E-05,   7.7125515E-05,   7.7602970E-05
     +,   7.7974117E-05,   7.8236386E-05,   7.8387748E-05
     +,   7.8426710E-05,   7.8352299E-05,   7.8164121E-05
     +,   7.7862365E-05,   7.7447738E-05,   7.6921548E-05
     +,   7.6285636E-05,   7.5542397E-05,   7.4694726E-05
     +,   7.3746029E-05,   7.2700168E-05,   7.1561444E-05
     +,   7.0334521E-05,   6.9024529E-05,   6.7636793E-05
     +,   6.6176952E-05,   6.4650943E-05,   6.3064821E-05
     +,   6.1424806E-05,   5.9737242E-05,   5.8008467E-05
     +,   5.6244968E-05,   5.4453052E-05,   5.2638967E-05
     +,   5.0809031E-05,   4.8969185E-05,   4.7125439E-05
     +,   4.5283377E-05,   4.3448592E-05,   4.1626194E-05
     +,   3.9821261E-05,   3.8038386E-05,   3.6282046E-05
     +,   3.4556302E-05,   3.2864882E-05,   3.1211308E-05
     +,   2.9598796E-05,   2.8030143E-05,   2.6507851E-05
     +,   2.5034260E-05,   2.3611232E-05,   2.2240529E-05
     +,   2.0923469E-05,   1.9661284E-05,   1.8454801E-05
     +,   1.7304774E-05,   1.6211603E-05,   1.5175639E-05
     +,   1.4196941E-05,   1.3275424E-05,   1.2410927E-05
     +,   1.1603146E-05,   1.0851626E-05,   1.0155825E-05
     +,   9.5151918E-06,   8.9290388E-06,   8.3967016E-06
     +,   7.9174279E-06,   7.4904974E-06,   7.1151385E-06
     +,   6.7906344E-06,   6.5162353E-06,   6.2912563E-06
     +,   6.1150145E-06,   5.9868685E-06,   5.9062272E-06
     +,   5.8725382E-06,   5.8852879E-06,   5.9440140E-06
     +,   6.0482885E-06,   6.1977389E-06,   6.3920088E-06
     +,   6.6307966E-06,   6.9137950E-06,   7.2407493E-06
     +,   7.6113729E-06,   8.0254240E-06,   8.4825933E-06
     +,   8.9825935E-06,   9.5251053E-06,   1.0109723E-05
     +,   1.0735983E-05,   1.1403383E-05,   1.2111343E-05
     +,   1.2859111E-05,   1.3645919E-05,   1.4470781E-05
     +,   1.5332671E-05,   1.6230319E-05,   1.7162401E-05
     +,   1.8127334E-05,   1.9123459E-05,   2.0148826E-05
     +,   2.1201404E-05,   2.2278973E-05,   2.3379065E-05
     +,   2.4499019E-05,   2.5636065E-05,   2.6787260E-05
     +,   2.7949414E-05,   2.9119159E-05,   3.0293078E-05
     +,   3.1467585E-05,   3.2638873E-05,   3.3803124E-05
     +,   3.4956447E-05,   3.6094771E-05,   3.7213995E-05
     +,   3.8310060E-05,   3.9378883E-05,   4.0416340E-05
     +,   4.1418334E-05,   4.2380925E-05,   4.3300231E-05
     +,   4.4172437E-05,   4.4993885E-05,   4.5761110E-05
     +,   4.6470861E-05,   4.7120018E-05,   4.7705755E-05
     +,   4.8225509E-05,   4.8676939E-05,   4.9058021E-05
     +,   4.9367060E-05,   4.9602637E-05,   4.9763687E-05
     +,   4.9849470E-05,   4.9859602E-05,   4.9794035E-05
     +,   4.9653048E-05,   4.9437298E-05,   4.9147755E-05
     +,   4.8785711E-05,   4.8352827E-05,   4.7851008E-05
     +,   4.7282487E-05,   4.6649773E-05,   4.5955654E-05
     +,   4.5203116E-05,   4.4395354E-05,   4.3535809E-05
     +,   4.2628089E-05,   4.1675910E-05,   4.0683084E-05
     +,   3.9653587E-05,   3.8591461E-05,   3.7500740E-05
     +,   3.6385452E-05,   3.5249741E-05,   3.4097593E-05
     +,   3.2932967E-05,   3.1759784E-05,   3.0581890E-05
     +,   2.9402945E-05,   2.8226448E-05,   2.7055848E-05
     +,   2.5894416E-05,   2.4745181E-05,   2.3610972E-05
     +,   2.2494507E-05,   2.1398291E-05,   2.0324556E-05
     +,   1.9275316E-05,   1.8252482E-05,   1.7257647E-05
     +,   1.6292195E-05,   1.5357362E-05,   1.4454184E-05
     +,   1.3583433E-05,   1.2745697E-05,   1.1941435E-05
     +,   1.1170928E-05,   1.0434243E-05,   9.7312877E-06
     +,   9.0618842E-06,   8.4257063E-06,   7.8222711E-06
     +,   7.2509833E-06,   6.7112064E-06,   6.2021572E-06
     +,   5.7229822E-06,   5.2727869E-06,   4.8506249E-06
     +,   4.4554681E-06,   4.0862615E-06,   3.7419420E-06
     +,   3.4214277E-06,   3.1236029E-06,   2.8473512E-06
     +,   2.5915772E-06,   2.3551934E-06,   2.1371100E-06
     +,   1.9362599E-06,   1.7516188E-06,   1.5821704E-06
     +,   1.4269315E-06,   1.2849628E-06,   1.1553591E-06
     +,   1.0372440E-06,   9.2978138E-07,   8.3218157E-07
     +,   7.4369393E-07,   6.6360190E-07,   5.9123028E-07
     +,   5.2594794E-07,   4.6716210E-07,   4.1431386E-07
     +,   3.6688226E-07,   3.2438635E-07,   2.8637507E-07
     +,   2.5243114E-07,   2.2217104E-07,   1.9524073E-07
     +,   1.7131285E-07,   1.5008739E-07,   1.3129103E-07
     +,   1.1467380E-07,   1.0000683E-07,   8.7082228E-08
     +,   7.5712180E-08,   6.5726432E-08,   5.6970581E-08
     +,   4.9305488E-08,   4.2606704E-08,   3.6761783E-08
     +,   3.1670069E-08,   2.7241899E-08,   2.3397188E-08
     +,   2.0064375E-08,   1.7179925E-08,   1.4687648E-08
     +,   1.2537799E-08,   1.0686262E-08,   9.0941752E-09
     +,   7.7274915E-09,   6.5561196E-09,   5.5538316E-09
     +,   4.6975503E-09,   3.9672341E-09,   3.3453134E-09
     +,   2.8165879E-09,   2.3677849E-09,   1.9874615E-09
     +,   1.6656642E-09,   1.3938409E-09,   1.1645935E-09
     +,   9.7155461E-10,   8.0927753E-10,   6.7306893E-10
     +,   5.5893190E-10,   4.6343654E-10,   3.8367057E-10
     +,   3.1714539E-10,   2.6175503E-10,   2.1570672E-10
     +,   1.7748804E-10,   1.4581615E-10,   1.1961329E-10
     +,   9.7968009E-11,   8.0117253E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_haonly_zz_mass = Yx/0.001995
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_asha_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9154278E-08,   2.3861427E-08
     +,   2.9628550E-08,   3.6669814E-08,   4.5236934E-08
     +,   5.5624295E-08,   6.8174991E-08,   8.3286743E-08
     +,   1.0141859E-07,   1.2309920E-07,   1.4893237E-07
     +,   1.7960662E-07,   2.1590202E-07,   2.5869949E-07
     +,   3.0898801E-07,   3.6787296E-07,   4.3658451E-07
     +,   5.1648306E-07,   6.0906780E-07,   7.1597975E-07
     +,   8.3900864E-07,   9.8009309E-07,   1.1413201E-06
     +,   1.3249382E-06,   1.5333221E-06,   1.7690088E-06
     +,   2.0346558E-06,   2.3330447E-06,   2.6670646E-06
     +,   3.0396943E-06,   3.4539828E-06,   3.9130250E-06
     +,   4.4199328E-06,   4.9778118E-06,   5.5897212E-06
     +,   6.2586446E-06,   6.9874509E-06,   7.7788427E-06
     +,   8.6353839E-06,   9.5593041E-06,   1.0552659E-05
     +,   1.1617124E-05,   1.2754040E-05,   1.3964338E-05
     +,   1.5248513E-05,   1.6606600E-05,   1.8038108E-05
     +,   1.9542033E-05,   2.1116792E-05,   2.2760243E-05
     +,   2.4469620E-05,   2.6241585E-05,   2.8072142E-05
     +,   2.9956816E-05,   3.1890340E-05,   3.3867072E-05
     +,   3.5880730E-05,   3.7924539E-05,   3.9991279E-05
     +,   4.2073323E-05,   4.4162705E-05,   4.6251240E-05
     +,   4.8330414E-05,   5.0391784E-05,   5.2426927E-05
     +,   5.4427295E-05,   5.6384830E-05,   5.8291498E-05
     +,   6.0139944E-05,   6.1923056E-05,   6.3634587E-05
     +,   6.5268716E-05,   6.6820641E-05,   6.8286143E-05
     +,   6.9662055E-05,   7.0946102E-05,   7.2136871E-05
     +,   7.3233881E-05,   7.4237651E-05,   7.5149605E-05
     +,   7.5971897E-05,   7.6707649E-05,   7.7360542E-05
     +,   7.7935103E-05,   7.8436315E-05,   7.8869743E-05
     +,   7.9241334E-05,   7.9557438E-05,   7.9824640E-05
     +,   8.0049758E-05,   8.0239741E-05,   8.0401594E-05
     +,   8.0542341E-05,   8.0668979E-05,   8.0788326E-05
     +,   8.0907077E-05,   8.1031649E-05,   8.1168109E-05
     +,   8.1322120E-05,   8.1498787E-05,   8.1702616E-05
     +,   8.1937280E-05,   8.2205624E-05,   8.2509454E-05
     +,   8.2849372E-05,   8.3224768E-05,   8.3633546E-05
     +,   8.4072155E-05,   8.4535452E-05,   8.5016734E-05
     +,   8.5507614E-05,   8.5998166E-05,   8.6477019E-05
     +,   8.6931410E-05,   8.7347478E-05,   8.7710439E-05
     +,   8.8004934E-05,   8.8215289E-05,   8.8325891E-05
     +,   8.8321642E-05,   8.8188201E-05,   8.7912609E-05
     +,   8.7483364E-05,   8.6891101E-05,   8.6128617E-05
     +,   8.5191394E-05,   8.4077612E-05,   8.2788480E-05
     +,   8.1328035E-05,   7.9703590E-05,   7.7925128E-05
     +,   7.6005716E-05,   7.3960728E-05,   7.1808121E-05
     +,   6.9567694E-05,   6.7260800E-05,   6.4910178E-05
     +,   6.2539366E-05,   6.0172064E-05,   5.7831905E-05
     +,   5.5542132E-05,   5.3325053E-05,   5.1201554E-05
     +,   4.9190850E-05,   4.7310466E-05,   4.5575529E-05
     +,   4.3998858E-05,   4.2590855E-05,   4.1359399E-05
     +,   4.0309616E-05,   3.9444123E-05,   3.8763104E-05
     +,   3.8264294E-05,   3.7943140E-05,   3.7793059E-05
     +,   3.7805556E-05,   3.7970465E-05,   3.8276172E-05
     +,   3.8709866E-05,   3.9257706E-05,   3.9905150E-05
     +,   4.0637158E-05,   4.1438321E-05,   4.2293144E-05
     +,   4.3186246E-05,   4.4102573E-05,   4.5027402E-05
     +,   4.5946606E-05,   4.6846788E-05,   4.7715374E-05
     +,   4.8540624E-05,   4.9311748E-05,   5.0019036E-05
     +,   5.0653842E-05,   5.1208539E-05,   5.1676630E-05
     +,   5.2052739E-05,   5.2332511E-05,   5.2512689E-05
     +,   5.2591025E-05,   5.2566247E-05,   5.2438041E-05
     +,   5.2206953E-05,   5.1874336E-05,   5.1442323E-05
     +,   5.0913721E-05,   5.0292001E-05,   4.9581133E-05
     +,   4.8785576E-05,   4.7910278E-05,   4.6960471E-05
     +,   4.5941648E-05,   4.4859615E-05,   4.3720331E-05
     +,   4.2529806E-05,   4.1294101E-05,   4.0019360E-05
     +,   3.8711700E-05,   3.7377089E-05,   3.6021353E-05
     +,   3.4650289E-05,   3.3269491E-05,   3.1884279E-05
     +,   3.0499743E-05,   2.9120856E-05,   2.7752199E-05
     +,   2.6398080E-05,   2.5062591E-05,   2.3749542E-05
     +,   2.2462342E-05,   2.1204096E-05,   1.9977684E-05
     +,   1.8785660E-05,   1.7630213E-05,   1.6513199E-05
     +,   1.5436270E-05,   1.4400768E-05,   1.3407682E-05
     +,   1.2457731E-05,   1.1551459E-05,   1.0689066E-05
     +,   9.8705132E-06,   9.0956046E-06,   8.3639170E-06
     +,   7.6747892E-06,   7.0273927E-06,   6.4207825E-06
     +,   5.8538635E-06,   5.3253848E-06,   4.8339930E-06
     +,   4.3782738E-06,   3.9567440E-06,   3.5678279E-06
     +,   3.2099217E-06,   2.8814254E-06,   2.5806939E-06
     +,   2.3060861E-06,   2.0559928E-06,   1.8288250E-06
     +,   1.6230108E-06,   1.4370233E-06,   1.2693966E-06
     +,   1.1187175E-06,   9.8362079E-07,   8.6280858E-07
     +,   7.5505608E-07,   6.5920614E-07,   5.7416412E-07
     +,   4.9890627E-07,   4.3248568E-07,   3.7401585E-07
     +,   3.2267815E-07,   2.7772217E-07,   2.3845857E-07
     +,   2.0425539E-07,   1.7453718E-07,   1.4878428E-07
     +,   1.2652646E-07,   1.0733905E-07,   9.0841105E-08
     +,   7.6693141E-08,   6.4592371E-08,   5.4269204E-08
     +,   4.5485148E-08,   3.8030652E-08,   3.1720688E-08
     +,   2.6393247E-08,   2.1907162E-08,   1.8139481E-08
     +,   1.4983232E-08,   1.2345962E-08,   1.0148113E-08
     +,   8.3212557E-09,   6.8066321E-09,   5.5540852E-09
     +,   4.5210076E-09,   3.6710777E-09,   2.9736758E-09
     +,   2.4028612E-09,   1.9368886E-09,   1.5574563E-09
     +,   1.2493010E-09,   9.9966091E-10,   7.9795565E-10
     +,   6.3538774E-10,   5.0470611E-10,   3.9992165E-10
     +,   3.1611486E-10,   2.4926067E-10,   1.9606330E-10
     +,   1.5384310E-10,   1.2041840E-10,   9.4025704E-11
     +,   7.3237465E-11,   5.6906084E-11,   4.4107926E-11
     +,   3.4104709E-11,   2.6305321E-11,   2.0240080E-11
     +,   1.5535049E-11,   1.1894678E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_asha_eez_mass = Yx/0.00231606666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_asha_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   3.5247370E-38,   4.7005999E-37
     +,   6.0026062E-36,   7.3400031E-35,   8.5946719E-34
     +,   9.6359776E-33,   1.0344804E-31,   1.0635268E-30
     +,   1.0468992E-29,   9.8686859E-29,   8.9072902E-28
     +,   7.6988649E-27,   6.3714933E-26,   5.0495065E-25
     +,   3.8317017E-24,   2.7843852E-23,   1.9373154E-22
     +,   1.2907328E-21,   8.2350039E-21,   5.0310033E-20
     +,   2.9429564E-19,   1.6484585E-18,   8.8421836E-18
     +,   4.5413268E-17,   2.2335338E-16,   1.0518243E-15
     +,   4.7432977E-15,   2.0481385E-14,   8.4688400E-14
     +,   3.3529939E-13,   1.2712294E-12,   4.6148870E-12
     +,   1.6042171E-11,   5.3400673E-11,   1.7021316E-10
     +,   5.1950200E-10,   1.5182616E-09,   4.2489794E-09
     +,   1.1386028E-08,   2.9217141E-08,   7.1788357E-08
     +,   1.6890671E-07,   3.8053278E-07,   8.2094181E-07
     +,   1.6958453E-06,   3.3545475E-06,   6.3538396E-06
     +,   1.1524002E-05,   2.0014397E-05,   3.3284738E-05
     +,   5.3003529E-05,   8.0821905E-05,   1.1801120E-04
     +,   1.6499717E-04,   2.2090146E-04,   2.8319241E-04
     +,   3.4764313E-04,   4.0864968E-04,   4.5998517E-04
     +,   4.9581548E-04,   5.1180978E-04,   5.0602132E-04
     +,   4.7933462E-04,   4.3533879E-04,   3.7969588E-04
     +,   3.1917752E-04,   2.6063621E-04,   2.1016311E-04
     +,   1.7255764E-04,   1.5109665E-04,   1.4753404E-04
     +,   1.6215182E-04,   1.9377512E-04,   2.3972681E-04
     +,   2.9578697E-04,   3.5632614E-04,   4.1469754E-04
     +,   4.6398444E-04,   4.9797166E-04,   5.1216083E-04
     +,   5.0456898E-04,   4.7606335E-04,   4.3013084E-04
     +,   3.7214524E-04,   3.0831614E-04,   2.4459482E-04
     +,   1.8580597E-04,   1.3515771E-04,   9.4142735E-05
     +,   6.2790125E-05,   4.0101393E-05,   2.4524397E-05
     +,   1.4361562E-05,   8.0530681E-06,   4.3239852E-06
     +,   2.2232093E-06,   1.0945640E-06,   5.1600688E-07
     +,   2.3293424E-07,   1.0069014E-07,   4.1677804E-08
     +,   1.6518646E-08,   6.2693282E-09,   2.2784110E-09
     +,   7.9285412E-10,   2.6419031E-10,   8.4298762E-11
     +,   2.5756668E-11,   7.5353820E-12,   2.1109800E-12
     +,   5.6629853E-13,   1.4546938E-13,   3.5780139E-14
     +,   8.4270537E-15,   1.9006159E-15,   4.1046666E-16
     +,   8.4879577E-17,   1.6807991E-17,   3.1870651E-18
     +,   5.7863905E-19,   1.0059805E-19,   1.6747803E-20
     +,   2.6698761E-21,   4.0753304E-22,   5.9565909E-23
     +,   8.3372776E-24,   1.1174180E-24,   1.4339772E-25
     +,   1.7620994E-26,   2.0735606E-27,   2.3364937E-28
     +,   2.5208347E-29,   2.6044969E-30,   2.5766970E-31
     +,   2.4408325E-32,   2.2139657E-33,   1.9231223E-34
     +,   1.5995809E-35,   1.2738912E-36,   9.7146036E-38
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_asha_qq_mass = Yx/0.002877
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_asha_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.8670095E-16,   8.0962967E-16
     +,   1.3399132E-15,   2.2061325E-15,   3.6136924E-15
     +,   5.8889174E-15,   9.5473979E-15,   1.5399188E-14
     +,   2.4710020E-14,   3.9447138E-14,   6.2650277E-14
     +,   9.8990660E-14,   1.5560750E-13,   2.4334910E-13
     +,   3.7861175E-13,   5.8603355E-13,   9.0243351E-13
     +,   1.3825194E-12,   2.1071294E-12,   3.1950352E-12
     +,   4.8197427E-12,   7.2332852E-12,   1.0799609E-11
     +,   1.6041696E-11,   2.3705555E-11,   3.4851070E-11
     +,   5.0973743E-11,   7.4171974E-11,   1.0737340E-10
     +,   1.5463829E-10,   2.2156485E-10,   3.1582653E-10
     +,   4.4787749E-10,   6.3187866E-10,   8.8689350E-10
     +,   1.2384334E-09,   1.7204335E-09,   2.3777402E-09
     +,   3.2693357E-09,   4.4721302E-09,   6.0860481E-09
     +,   8.2398959E-09,   1.1098706E-08,   1.4872655E-08
     +,   1.9827628E-08,   2.6297801E-08,   3.4700459E-08
     +,   4.5553190E-08,   5.9493782E-08,   7.7302666E-08
     +,   9.9928386E-08,   1.2851577E-07,   1.6443606E-07
     +,   2.0932359E-07,   2.6510341E-07,   3.3403856E-07
     +,   4.1875830E-07,   5.2229927E-07,   6.4814020E-07
     +,   8.0023392E-07,   9.8303440E-07,   1.2015223E-06
     +,   1.4611988E-06,   1.7681209E-06,   2.1288797E-06
     +,   2.5505371E-06,   3.0406727E-06,   3.6072211E-06
     +,   4.2585266E-06,   5.0031085E-06,   5.8497299E-06
     +,   6.8070785E-06,   7.8838648E-06,   9.0884214E-06
     +,   1.0428799E-05,   1.1912527E-05,   1.3546345E-05
     +,   1.5336131E-05,   1.7286909E-05,   1.9402603E-05
     +,   2.1685704E-05,   2.4137664E-05,   2.6758202E-05
     +,   2.9545885E-05,   3.2497355E-05,   3.5608027E-05
     +,   3.8871254E-05,   4.2279138E-05,   4.5821609E-05
     +,   4.9487211E-05,   5.3262738E-05,   5.7133100E-05
     +,   6.1081504E-05,   6.5089931E-05,   6.9139038E-05
     +,   7.3208023E-05,   7.7275909E-05,   8.1321072E-05
     +,   8.5322856E-05,   8.9261230E-05,   9.3118870E-05
     +,   9.6881042E-05,   1.0053768E-04,   1.0408364E-04
     +,   1.0752059E-04,   1.1085775E-04,   1.1411260E-04
     +,   1.1731188E-04,   1.2049211E-04,   1.2369960E-04
     +,   1.2698965E-04,   1.3042631E-04,   1.3408040E-04
     +,   1.3802813E-04,   1.4234771E-04,   1.4711711E-04
     +,   1.5240967E-04,   1.5829109E-04,   1.6481418E-04
     +,   1.7201592E-04,   1.7991339E-04,   1.8849976E-04
     +,   1.9774235E-04,   2.0758215E-04,   2.1793325E-04
     +,   2.2868332E-04,   2.3969897E-04,   2.5082775E-04
     +,   2.6190633E-04,   2.7276418E-04,   2.8323336E-04
     +,   2.9315212E-04,   3.0237366E-04,   3.1076759E-04
     +,   3.1822574E-04,   3.2466155E-04,   3.3000929E-04
     +,   3.3422204E-04,   3.3726901E-04,   3.3913064E-04
     +,   3.3979540E-04,   3.3925683E-04,   3.3751255E-04
     +,   3.3456369E-04,   3.3041803E-04,   3.2509246E-04
     +,   3.1861826E-04,   3.1104637E-04,   3.0245192E-04
     +,   2.9293686E-04,   2.8263198E-04,   2.7169706E-04
     +,   2.6031662E-04,   2.4869334E-04,   2.3704088E-04
     +,   2.2557538E-04,   2.1450462E-04,   2.0401758E-04
     +,   1.9427684E-04,   1.8541254E-04,   1.7751601E-04
     +,   1.7063887E-04,   1.6479424E-04,   1.5995886E-04
     +,   1.5607786E-04,   1.5307151E-04,   1.5084223E-04
     +,   1.4928133E-04,   1.4827597E-04,   1.4771504E-04
     +,   1.4749428E-04,   1.4751974E-04,   1.4771022E-04
     +,   1.4799862E-04,   1.4833211E-04,   1.4867169E-04
     +,   1.4899111E-04,   1.4927515E-04,   1.4951837E-04
     +,   1.4972303E-04,   1.4989784E-04,   1.5005603E-04
     +,   1.5021440E-04,   1.5039188E-04,   1.5060851E-04
     +,   1.5088459E-04,   1.5123960E-04,   1.5169158E-04
     +,   1.5225633E-04,   1.5294660E-04,   1.5377153E-04
     +,   1.5473607E-04,   1.5584045E-04,   1.5707948E-04
     +,   1.5844266E-04,   1.5991369E-04,   1.6147047E-04
     +,   1.6308497E-04,   1.6472394E-04,   1.6634892E-04
     +,   1.6791675E-04,   1.6938050E-04,   1.7069031E-04
     +,   1.7179450E-04,   1.7264036E-04,   1.7317579E-04
     +,   1.7335053E-04,   1.7311744E-04,   1.7243397E-04
     +,   1.7126344E-04,   1.6957619E-04,   1.6735074E-04
     +,   1.6457473E-04,   1.6124531E-04,   1.5736949E-04
     +,   1.5296464E-04,   1.4805794E-04,   1.4268560E-04
     +,   1.3689227E-04,   1.3073048E-04,   1.2425844E-04
     +,   1.1753893E-04,   1.1063823E-04,   1.0362422E-04
     +,   9.6564239E-05,   8.9523957E-05,   8.2566512E-05
     +,   7.5750737E-05,   6.9129637E-05,   6.2750085E-05
     +,   5.6652520E-05,   5.0870171E-05,   4.5428562E-05
     +,   4.0345953E-05,   3.5634119E-05,   3.1297714E-05
     +,   2.7335436E-05,   2.3740884E-05,   2.0502972E-05
     +,   1.7606542E-05,   1.5033392E-05,   1.2763174E-05
     +,   1.0773909E-05,   9.0425401E-06,   7.5457092E-06
     +,   6.2603272E-06,   5.1638931E-06,   4.2347860E-06
     +,   3.4526313E-06,   2.7985520E-06,   2.2551335E-06
     +,   1.8065832E-06,   1.4387601E-06,   1.1391000E-06
     +,   8.9654111E-07,   7.0146484E-07,   5.4559121E-07
     +,   4.2184683E-07,   3.2423549E-07,   2.4772925E-07
     +,   1.8815051E-07,   1.4205149E-07,   1.0660845E-07
     +,   7.9530892E-08,   5.8977228E-08,   4.3474127E-08
     +,   3.1854320E-08,   2.3200611E-08,   1.6796816E-08
     +,   1.2087725E-08,   8.6466150E-09,   6.1480119E-09
     +,   4.3452437E-09,   3.0526592E-09,   2.1316775E-09
     +,   1.4796276E-09,   1.0208464E-09,   7.0009210E-10
     +,   4.7722698E-10,   3.2335573E-10,   2.1777612E-10
     +,   1.4578913E-10,   9.7009158E-11,   6.4163071E-11
     +,   4.2182223E-11,   2.7565011E-11,   1.7904622E-11
     +,   1.1559616E-11,   7.4183160E-12,   4.7319319E-12
     +,   3.0002353E-12,   1.8907887E-12,   1.1844445E-12
     +,   7.3749101E-13,   4.5643865E-13,   2.8078784E-13
     +,   1.7169507E-13,   1.0435352E-13,   6.3043558E-14
     +,   3.7856803E-14,   2.2595913E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_asha_ww_mass = Yx/0.00595499130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_asha_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0573624E-07,   5.5192169E-07
     +,   6.0147636E-07,   6.5455720E-07,   7.1132075E-07
     +,   7.7192072E-07,   8.3650809E-07,   9.0522929E-07
     +,   9.7822476E-07,   1.0556315E-06,   1.1375764E-06
     +,   1.2241785E-06,   1.3155468E-06,   1.4117808E-06
     +,   1.5129673E-06,   1.6191816E-06,   1.7304843E-06
     +,   1.8469229E-06,   1.9685301E-06,   2.0953230E-06
     +,   2.2273039E-06,   2.3644591E-06,   2.5067566E-06
     +,   2.6541597E-06,   2.8066006E-06,   2.9640144E-06
     +,   3.1263130E-06,   3.2934017E-06,   3.4651746E-06
     +,   3.6415199E-06,   3.8223179E-06,   4.0074506E-06
     +,   4.1967969E-06,   4.3902410E-06,   4.5876736E-06
     +,   4.7889966E-06,   4.9941264E-06,   5.2029986E-06
     +,   5.4155821E-06,   5.6318545E-06,   5.8518526E-06
     +,   6.0756397E-06,   6.3033312E-06,   6.5350955E-06
     +,   6.7711617E-06,   7.0118331E-06,   7.2574876E-06
     +,   7.5085950E-06,   7.7657205E-06,   8.0295413E-06
     +,   8.3008545E-06,   8.5805941E-06,   8.8698362E-06
     +,   9.1698375E-06,   9.4819979E-06,   9.8079454E-06
     +,   1.0149487E-05,   1.0508655E-05,   1.0887710E-05
     +,   1.1289154E-05,   1.1715722E-05,   1.2170410E-05
     +,   1.2656415E-05,   1.3177206E-05,   1.3736456E-05
     +,   1.4337968E-05,   1.4985766E-05,   1.5683883E-05
     +,   1.6436476E-05,   1.7247570E-05,   1.8121174E-05
     +,   1.9060970E-05,   2.0070449E-05,   2.1152538E-05
     +,   2.2309730E-05,   2.3543844E-05,   2.4855857E-05
     +,   2.6245829E-05,   2.7712889E-05,   2.9255101E-05
     +,   3.0869185E-05,   3.2550848E-05,   3.4294328E-05
     +,   3.6092853E-05,   3.7938200E-05,   3.9821261E-05
     +,   4.1731691E-05,   4.3658540E-05,   4.5589932E-05
     +,   4.7513775E-05,   4.9417838E-05,   5.1289855E-05
     +,   5.3118085E-05,   5.4891647E-05,   5.6600820E-05
     +,   5.8237179E-05,   5.9794333E-05,   6.1267805E-05
     +,   6.2655716E-05,   6.3958687E-05,   6.5180335E-05
     +,   6.6327120E-05,   6.7408742E-05,   6.8437854E-05
     +,   6.9430178E-05,   7.0404327E-05,   7.1381408E-05
     +,   7.2384857E-05,   7.3439936E-05,   7.4573240E-05
     +,   7.5812030E-05,   7.7183657E-05,   7.8714591E-05
     +,   8.0429971E-05,   8.2352359E-05,   8.4501276E-05
     +,   8.6891887E-05,   8.9534711E-05,   9.2434275E-05
     +,   9.5588905E-05,   9.8990000E-05,   1.0262132E-04
     +,   1.0645881E-04,   1.1047080E-04,   1.1461785E-04
     +,   1.1885256E-04,   1.2312103E-04,   1.2736260E-04
     +,   1.3151180E-04,   1.3549875E-04,   1.3925182E-04
     +,   1.4269844E-04,   1.4576870E-04,   1.4839706E-04
     +,   1.5052635E-04,   1.5211123E-04,   1.5312199E-04
     +,   1.5354958E-04,   1.5341010E-04,   1.5275030E-04
     +,   1.5165289E-04,   1.5024283E-04,   1.4869336E-04
     +,   1.4723276E-04,   1.4615066E-04,   1.4580233E-04
     +,   1.4661058E-04,   1.4906128E-04,   1.5369251E-04
     +,   1.6107745E-04,   1.7180371E-04,   1.8645487E-04
     +,   2.0560184E-04,   2.2980690E-04,   2.5962596E-04
     +,   2.9558173E-04,   3.3807830E-04,   3.8723001E-04
     +,   4.4263186E-04,   5.0318555E-04,   5.6721648E-04
     +,   6.3305843E-04,   7.0017314E-04,   7.7053299E-04
     +,   8.4961962E-04,   9.4632112E-04,   1.0714134E-03
     +,   1.2349699E-03,   1.4434456E-03,   1.6968511E-03
     +,   1.9859744E-03,   2.2902193E-03,   2.5782546E-03
     +,   2.8145595E-03,   2.9720794E-03,   3.0451657E-03
     +,   3.0532661E-03,   3.0307076E-03,   3.0079016E-03
     +,   2.9958996E-03,   2.9831000E-03,   2.9440934E-03
     +,   2.8538604E-03,   2.6995991E-03,   2.4856138E-03
     +,   2.2305858E-03,   1.9598051E-03,   1.6965655E-03
     +,   1.4565936E-03,   1.2470211E-03,   1.0687204E-03
     +,   9.1972435E-04,   7.9753046E-04,   6.9971307E-04
     +,   6.2351476E-04,   5.6540041E-04,   5.2107463E-04
     +,   4.8593900E-04,   4.5570717E-04,   4.2692607E-04
     +,   3.9727200E-04,   3.6561271E-04,   3.3186903E-04
     +,   2.9674504E-04,   2.6139553E-04,   2.2709288E-04
     +,   1.9497103E-04,   1.6586478E-04,   1.4024369E-04
     +,   1.1822869E-04,   9.9663725E-05,   8.4208536E-05
     +,   7.1427785E-05,   6.0865084E-05,   5.2095729E-05
     +,   4.4755954E-05,   3.8552134E-05,   3.3257562E-05
     +,   2.8702714E-05,   2.4762610E-05,   2.1343463E-05
     +,   1.8372972E-05,   1.5792966E-05,   1.3554290E-05
     +,   1.1613874E-05,   9.9334993E-06,   8.4792755E-06
     +,   7.2212351E-06,   6.1331275E-06,   5.1923125E-06
     +,   4.3794926E-06,   3.6782349E-06,   3.0745064E-06
     +,   2.5562947E-06,   2.1132585E-06,   1.7362852E-06
     +,   1.4172952E-06,   1.1490620E-06,   9.2505235E-07
     +,   7.3932972E-07,   5.8652370E-07,   4.6180185E-07
     +,   3.6083537E-07,   2.7977524E-07,   2.1524195E-07
     +,   1.6430339E-07,   1.2443941E-07,   9.3507730E-08
     +,   6.9711270E-08,   5.1561720E-08,   3.7836699E-08
     +,   2.7545621E-08,   1.9895195E-08,   1.4256203E-08
     +,   1.0134769E-08,   7.1478001E-09,   5.0013189E-09
     +,   3.4717940E-09,   2.3909854E-09,   1.6336047E-09
     +,   1.1073109E-09,   7.4464718E-10,   4.9680271E-10
     +,   3.2882430E-10,   2.1592482E-10,   1.4066744E-10
     +,   9.0914096E-11,   5.8293613E-11,   3.7082590E-11
     +,   2.3402981E-11,   1.4652725E-11,   9.1016075E-12
     +,   5.6088940E-12,   3.4291688E-12,   2.0799176E-12
     +,   1.2515911E-12,   7.4717820E-13,   4.4253311E-13
     +,   2.6002380E-13,   1.5157919E-13,   8.7662062E-14
     +,   5.0297186E-14,   2.8629903E-14,   1.6168016E-14
     +,   9.0581305E-15,   5.0347867E-15,   2.7763616E-15
     +,   1.5188481E-15,   8.2435645E-16,   4.4387338E-16
     +,   2.3711721E-16,   1.2566462E-16,   6.6072977E-17
     +,   3.4464934E-17,   1.7835887E-17,   9.1570374E-18
     +,   4.6642155E-18,   2.3569260E-18,   1.1816170E-18
     +,   5.8769854E-19,   2.8999965E-19
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_asha_zz_mass = Yx/0.0187409090909091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_ashz_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.2683280E-07,   4.9243147E-07
     +,   5.6670382E-07,   6.5056224E-07,   7.4497871E-07
     +,   8.5098327E-07,   9.6966244E-07,   1.1021544E-06
     +,   1.2496424E-06,   1.4133589E-06,   1.5945615E-06
     +,   1.7945364E-06,   2.0145858E-06,   2.2560134E-06
     +,   2.5201111E-06,   2.8081499E-06,   3.1213542E-06
     +,   3.4608947E-06,   3.8278599E-06,   4.2232432E-06
     +,   4.6479208E-06,   5.1026263E-06,   5.5879264E-06
     +,   6.1042415E-06,   6.6517241E-06,   7.2303669E-06
     +,   7.8398816E-06,   8.4797312E-06,   9.1490956E-06
     +,   9.8468718E-06,   1.0571652E-05,   1.1321724E-05
     +,   1.2095061E-05,   1.2889325E-05,   1.3701884E-05
     +,   1.4529805E-05,   1.5369880E-05,   1.6218632E-05
     +,   1.7072418E-05,   1.7927294E-05,   1.8779281E-05
     +,   1.9624216E-05,   2.0457912E-05,   2.1276188E-05
     +,   2.2074933E-05,   2.2850181E-05,   2.3598177E-05
     +,   2.4315483E-05,   2.4999028E-05,   2.5646235E-05
     +,   2.6255073E-05,   2.6824173E-05,   2.7352908E-05
     +,   2.7841514E-05,   2.8291084E-05,   2.8703782E-05
     +,   2.9082792E-05,   2.9432436E-05,   2.9758210E-05
     +,   3.0066807E-05,   3.0366127E-05,   3.0665266E-05
     +,   3.0974450E-05,   3.1305019E-05,   3.1669286E-05
     +,   3.2080403E-05,   3.2552234E-05,   3.3099084E-05
     +,   3.3735581E-05,   3.4476267E-05,   3.5335459E-05
     +,   3.6326786E-05,   3.7463018E-05,   3.8755501E-05
     +,   4.0214050E-05,   4.1846510E-05,   4.3658318E-05
     +,   4.5652265E-05,   4.7828384E-05,   5.0183651E-05
     +,   5.2711530E-05,   5.5402474E-05,   5.8243193E-05
     +,   6.1217441E-05,   6.4305437E-05,   6.7484762E-05
     +,   7.0729977E-05,   7.4013718E-05,   7.7306337E-05
     +,   8.0577112E-05,   8.3794526E-05,   8.6926564E-05
     +,   8.9941517E-05,   9.2808827E-05,   9.5499381E-05
     +,   9.7985889E-05,   1.0024389E-04,   1.0225166E-04
     +,   1.0399111E-04,   1.0544760E-04,   1.0661066E-04
     +,   1.0747375E-04,   1.0803461E-04,   1.0829507E-04
     +,   1.0826110E-04,   1.0794256E-04,   1.0735303E-04
     +,   1.0650958E-04,   1.0543232E-04,   1.0414411E-04
     +,   1.0267024E-04,   1.0103769E-04,   9.9275152E-05
     +,   9.7412019E-05,   9.5478426E-05,   9.3504263E-05
     +,   9.1519185E-05,   8.9551679E-05,   8.7629014E-05
     +,   8.5776497E-05,   8.4017141E-05,   8.2371494E-05
     +,   8.0857091E-05,   7.9488193E-05,   7.8275596E-05
     +,   7.7226607E-05,   7.6344717E-05,   7.5629810E-05
     +,   7.5078002E-05,   7.4682022E-05,   7.4431184E-05
     +,   7.4311894E-05,   7.4307762E-05,   7.4400195E-05
     +,   7.4568750E-05,   7.4791635E-05,   7.5046250E-05
     +,   7.5309610E-05,   7.5558964E-05,   7.5772274E-05
     +,   7.5928612E-05,   7.6008648E-05,   7.5994998E-05
     +,   7.5872566E-05,   7.5628777E-05,   7.5253796E-05
     +,   7.4740543E-05,   7.4084885E-05,   7.3285511E-05
     +,   7.2343901E-05,   7.1264069E-05,   7.0052585E-05
     +,   6.8718189E-05,   6.7271503E-05,   6.5724744E-05
     +,   6.4091560E-05,   6.2386629E-05,   6.0625171E-05
     +,   5.8822781E-05,   5.6995283E-05,   5.5158103E-05
     +,   5.3326185E-05,   5.1513867E-05,   4.9734546E-05
     +,   4.8000420E-05,   4.6322417E-05,   4.4710214E-05
     +,   4.3172055E-05,   4.1714567E-05,   4.0342893E-05
     +,   3.9060735E-05,   3.7870333E-05,   3.6772428E-05
     +,   3.5766403E-05,   3.4850509E-05,   3.4021752E-05
     +,   3.3276112E-05,   3.2608725E-05,   3.2013952E-05
     +,   3.1485481E-05,   3.1016520E-05,   3.0599938E-05
     +,   3.0228384E-05,   2.9894374E-05,   2.9590445E-05
     +,   2.9309283E-05,   2.9043800E-05,   2.8787201E-05
     +,   2.8533090E-05,   2.8275554E-05,   2.8009175E-05
     +,   2.7729084E-05,   2.7431022E-05,   2.7111337E-05
     +,   2.6766977E-05,   2.6395510E-05,   2.5995136E-05
     +,   2.5564643E-05,   2.5103369E-05,   2.4611179E-05
     +,   2.4088486E-05,   2.3536157E-05,   2.2955452E-05
     +,   2.2348002E-05,   2.1715827E-05,   2.1061171E-05
     +,   2.0386500E-05,   1.9694529E-05,   1.8988096E-05
     +,   1.8270108E-05,   1.7543507E-05,   1.6811311E-05
     +,   1.6076516E-05,   1.5342008E-05,   1.4610589E-05
     +,   1.3885006E-05,   1.3167859E-05,   1.2461548E-05
     +,   1.1768301E-05,   1.1090229E-05,   1.0429178E-05
     +,   9.7867933E-06,   9.1645552E-06,   8.5637375E-06
     +,   7.9853617E-06,   7.4302529E-06,   6.8990767E-06
     +,   6.3923012E-06,   5.9101894E-06,   5.4528273E-06
     +,   5.0201797E-06,   4.6120622E-06,   4.2281263E-06
     +,   3.8679104E-06,   3.5308799E-06,   3.2163707E-06
     +,   2.9236451E-06,   2.6519153E-06,   2.4003391E-06
     +,   2.1680146E-06,   1.9540105E-06,   1.7573886E-06
     +,   1.5772004E-06,   1.4124803E-06,   1.2622717E-06
     +,   1.1256404E-06,   1.0016696E-06,   8.8945893E-07
     +,   7.8813724E-07,   6.9687678E-07,   6.1487469E-07
     +,   5.4136717E-07,   4.7563483E-07,   4.1699764E-07
     +,   3.6481285E-07,   3.1847910E-07,   2.7743943E-07
     +,   2.4117588E-07,   2.0920676E-07,   1.8108912E-07
     +,   1.5641743E-07,   1.3482071E-07,   1.1595898E-07
     +,   9.9523675E-08,   8.5236820E-08,   7.2845751E-08
     +,   6.2123448E-08,   5.2866806E-08,   4.4894122E-08
     +,   3.8042799E-08,   3.2168376E-08,   2.7143297E-08
     +,   2.2854650E-08,   1.9202735E-08,   1.6099994E-08
     +,   1.3469976E-08,   1.1245590E-08,   9.3686356E-09
     +,   7.7883300E-09,   6.4608789E-09,   5.3482587E-09
     +,   4.4178647E-09,   3.6415477E-09,   2.9952898E-09
     +,   2.4584714E-09,   2.0135889E-09,   1.6457080E-09
     +,   1.3421735E-09,   1.0923039E-09,   8.8705748E-10
     +,   7.1885237E-10,   5.8130112E-10,   4.6907417E-10
     +,   3.7770764E-10,   3.0349340E-10,   2.4334135E-10
     +,   1.9469851E-10,   1.5544688E-10,   1.2384585E-10
     +,   9.8458589E-11,   7.8109873E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_ashz_eez_mass = Yx/0.00231606666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_ashz_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   5.4475601E-38,   5.3456891E-35,   3.8346918E-32
     +,   2.0104712E-29,   7.7055209E-27,   2.1593137E-24
     +,   4.4226415E-22,   6.6229637E-20,   7.2491181E-18
     +,   5.8011195E-16,   3.3931896E-14,   1.4510812E-12
     +,   4.5358012E-11,   1.0365570E-09,   1.7314926E-08
     +,   2.1143767E-07,   1.8875928E-06,   1.2318564E-05
     +,   5.8764850E-05,   2.0493215E-04,   5.2245514E-04
     +,   9.7367167E-04,   1.3266685E-03,   1.3227836E-03
     +,   9.7317813E-04,   5.6703785E-04,   3.9424858E-04
     +,   5.6104030E-04,   9.6506829E-04,   1.3188340E-03
     +,   1.3303753E-03,   9.8209514E-04,   5.3004193E-04
     +,   2.0912882E-04,   6.0318827E-05,   1.2717519E-05
     +,   1.9602289E-06,   2.2085776E-07,   1.8192065E-08
     +,   1.0953279E-09,   4.8214609E-11,   1.5513021E-12
     +,   3.6491901E-14,   6.2743844E-16,   7.8874161E-18
     +,   7.2482806E-20,   4.8685072E-22,   2.3904706E-24
     +,   8.5818113E-27,   2.2522052E-29,   4.3199873E-32
     +,   6.0573207E-35,   6.2101647E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_ashz_qq_mass = Yx/0.002877
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_ashz_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9697402E-05,   2.0611187E-05
     +,   2.1537166E-05,   2.2473307E-05,   2.3417451E-05
     +,   2.4367351E-05,   2.5320667E-05,   2.6274985E-05
     +,   2.7227819E-05,   2.8176681E-05,   2.9119046E-05
     +,   3.0052366E-05,   3.0974166E-05,   3.1881977E-05
     +,   3.2773456E-05,   3.3646324E-05,   3.4498447E-05
     +,   3.5327870E-05,   3.6132828E-05,   3.6911752E-05
     +,   3.7663369E-05,   3.8386657E-05,   3.9080915E-05
     +,   3.9745828E-05,   4.0381372E-05,   4.0988001E-05
     +,   4.1566527E-05,   4.2118245E-05,   4.2644893E-05
     +,   4.3148677E-05,   4.3632292E-05,   4.4098928E-05
     +,   4.4552253E-05,   4.4996414E-05,   4.5436049E-05
     +,   4.5876230E-05,   4.6322468E-05,   4.6780653E-05
     +,   4.7257079E-05,   4.7758265E-05,   4.8291073E-05
     +,   4.8862512E-05,   4.9479713E-05,   5.0149836E-05
     +,   5.0880066E-05,   5.1677409E-05,   5.2548661E-05
     +,   5.3500302E-05,   5.4538417E-05,   5.5668534E-05
     +,   5.6895584E-05,   5.8223755E-05,   5.9656417E-05
     +,   6.1196079E-05,   6.2844105E-05,   6.4600950E-05
     +,   6.6465785E-05,   6.8436646E-05,   7.0510258E-05
     +,   7.2682124E-05,   7.4946445E-05,   7.7296165E-05
     +,   7.9722813E-05,   8.2216931E-05,   8.4767918E-05
     +,   8.7363864E-05,   8.9992274E-05,   9.2639479E-05
     +,   9.5291478E-05,   9.7933451E-05,   1.0055061E-04
     +,   1.0312763E-04,   1.0564960E-04,   1.0810161E-04
     +,   1.1046944E-04,   1.1273952E-04,   1.1489904E-04
     +,   1.1693634E-04,   1.1884113E-04,   1.2060459E-04
     +,   1.2221928E-04,   1.2367981E-04,   1.2498224E-04
     +,   1.2612488E-04,   1.2710778E-04,   1.2793306E-04
     +,   1.2860465E-04,   1.2912847E-04,   1.2951213E-04
     +,   1.2976502E-04,   1.2989788E-04,   1.2992288E-04
     +,   1.2985330E-04,   1.2970326E-04,   1.2948751E-04
     +,   1.2922120E-04,   1.2891959E-04,   1.2859781E-04
     +,   1.2827042E-04,   1.2795150E-04,   1.2765401E-04
     +,   1.2738988E-04,   1.2716955E-04,   1.2700204E-04
     +,   1.2689461E-04,   1.2685277E-04,   1.2688007E-04
     +,   1.2697835E-04,   1.2714733E-04,   1.2738511E-04
     +,   1.2768776E-04,   1.2804987E-04,   1.2846454E-04
     +,   1.2892344E-04,   1.2941708E-04,   1.2993524E-04
     +,   1.3046690E-04,   1.3100063E-04,   1.3152487E-04
     +,   1.3202813E-04,   1.3249934E-04,   1.3292783E-04
     +,   1.3330385E-04,   1.3361852E-04,   1.3386428E-04
     +,   1.3403464E-04,   1.3412461E-04,   1.3413078E-04
     +,   1.3405099E-04,   1.3388488E-04,   1.3363347E-04
     +,   1.3329918E-04,   1.3288589E-04,   1.3239872E-04
     +,   1.3184387E-04,   1.3122847E-04,   1.3056055E-04
     +,   1.2984869E-04,   1.2910200E-04,   1.2832957E-04
     +,   1.2754084E-04,   1.2674509E-04,   1.2595106E-04
     +,   1.2516725E-04,   1.2440153E-04,   1.2366098E-04
     +,   1.2295188E-04,   1.2227960E-04,   1.2164858E-04
     +,   1.2106211E-04,   1.2052256E-04,   1.2003117E-04
     +,   1.1958827E-04,   1.1919308E-04,   1.1884389E-04
     +,   1.1853821E-04,   1.1827263E-04,   1.1804316E-04
     +,   1.1784497E-04,   1.1767294E-04,   1.1752133E-04
     +,   1.1738407E-04,   1.1725490E-04,   1.1712741E-04
     +,   1.1699508E-04,   1.1685138E-04,   1.1668987E-04
     +,   1.1650439E-04,   1.1628889E-04,   1.1603766E-04
     +,   1.1574533E-04,   1.1540703E-04,   1.1501824E-04
     +,   1.1457498E-04,   1.1407385E-04,   1.1351204E-04
     +,   1.1288729E-04,   1.1219802E-04,   1.1144336E-04
     +,   1.1062311E-04,   1.0973776E-04,   1.0878854E-04
     +,   1.0777749E-04,   1.0670730E-04,   1.0558136E-04
     +,   1.0440387E-04,   1.0317977E-04,   1.0191461E-04
     +,   1.0061452E-04,   9.9286386E-05,   9.7937584E-05
     +,   9.6575845E-05,   9.5209551E-05,   9.3847317E-05
     +,   9.2498020E-05,   9.1170616E-05,   8.9874295E-05
     +,   8.8618144E-05,   8.7411114E-05,   8.6261811E-05
     +,   8.5178617E-05,   8.4169500E-05,   8.3241706E-05
     +,   8.2401893E-05,   8.1656028E-05,   8.1009159E-05
     +,   8.0465463E-05,   8.0028134E-05,   7.9699363E-05
     +,   7.9480218E-05,   7.9370722E-05,   7.9369747E-05
     +,   7.9475059E-05,   7.9683326E-05,   7.9990161E-05
     +,   8.0390106E-05,   8.0876707E-05,   8.1442609E-05
     +,   8.2079634E-05,   8.2778752E-05,   8.3530336E-05
     +,   8.4324165E-05,   8.5149521E-05,   8.5995292E-05
     +,   8.6850174E-05,   8.7702734E-05,   8.8541427E-05
     +,   8.9354820E-05,   9.0131711E-05,   9.0861169E-05
     +,   9.1532624E-05,   9.2135990E-05,   9.2661816E-05
     +,   9.3101284E-05,   9.3446179E-05,   9.3689254E-05
     +,   9.3823968E-05,   9.3844632E-05,   9.3746552E-05
     +,   9.3525923E-05,   9.3179842E-05,   9.2706417E-05
     +,   9.2104645E-05,   9.1374459E-05,   9.0516645E-05
     +,   8.9532958E-05,   8.8425943E-05,   8.7198910E-05
     +,   8.5855892E-05,   8.4401712E-05,   8.2841718E-05
     +,   8.1181817E-05,   7.9428515E-05,   7.7588767E-05
     +,   7.5669792E-05,   7.3679104E-05,   7.1624585E-05
     +,   6.9514259E-05,   6.7356188E-05,   6.5158405E-05
     +,   6.2929117E-05,   6.0676415E-05,   5.8408161E-05
     +,   5.6132008E-05,   5.3855591E-05,   5.1586077E-05
     +,   4.9330309E-05,   4.7094953E-05,   4.4886270E-05
     +,   4.2710006E-05,   4.0571478E-05,   3.8475715E-05
     +,   3.6427307E-05,   3.4430228E-05,   3.2488031E-05
     +,   3.0603984E-05,   2.8780671E-05,   2.7020453E-05
     +,   2.5325055E-05,   2.3695988E-05,   2.2134149E-05
     +,   2.0640262E-05,   1.9214485E-05,   1.7856828E-05
     +,   1.6566803E-05,   1.5343796E-05,   1.4186797E-05
     +,   1.3094565E-05,   1.2065744E-05,   1.1098644E-05
     +,   1.0191538E-05,   9.3424342E-06,   8.5493284E-06
     +,   7.8100229E-06,   7.1223299E-06,   6.4839232E-06
     +,   5.8925229E-06,   5.3457475E-06,   4.8412912E-06
     +,   4.3767891E-06,   3.9499696E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_ashz_ww_mass = Yx/0.00595499130434783
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_ashz_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.6491105E-06,   4.6986106E-06
     +,   4.7482445E-06,   4.7982539E-06,   4.8489119E-06
     +,   4.9005266E-06,   4.9534433E-06,   5.0080462E-06
     +,   5.0647582E-06,   5.1240486E-06,   5.1864272E-06
     +,   5.2524529E-06,   5.3227341E-06,   5.3979247E-06
     +,   5.4787333E-06,   5.5659189E-06,   5.6602939E-06
     +,   5.7627230E-06,   5.8741234E-06,   5.9954668E-06
     +,   6.1277742E-06,   6.2721183E-06,   6.4296137E-06
     +,   6.6014341E-06,   6.7887727E-06,   6.9928810E-06
     +,   7.2150297E-06,   7.4565191E-06,   7.7186696E-06
     +,   8.0028103E-06,   8.3102768E-06,   8.6423970E-06
     +,   9.0004805E-06,   9.3858098E-06,   9.7996299E-06
     +,   1.0243128E-05,   1.0717427E-05,   1.1223565E-05
     +,   1.1762510E-05,   1.2335064E-05,   1.2941960E-05
     +,   1.3583760E-05,   1.4260865E-05,   1.4973513E-05
     +,   1.5721744E-05,   1.6505399E-05,   1.7324102E-05
     +,   1.8177241E-05,   1.9063969E-05,   1.9983194E-05
     +,   2.0933550E-05,   2.1913425E-05,   2.2920925E-05
     +,   2.3953964E-05,   2.5010071E-05,   2.6086658E-05
     +,   2.7180831E-05,   2.8289498E-05,   2.9409370E-05
     +,   3.0536998E-05,   3.1668795E-05,   3.2801090E-05
     +,   3.3930086E-05,   3.5052086E-05,   3.6163416E-05
     +,   3.7260404E-05,   3.8339687E-05,   3.9397986E-05
     +,   4.0432456E-05,   4.1440475E-05,   4.2420001E-05
     +,   4.3369357E-05,   4.4287553E-05,   4.5174151E-05
     +,   4.6029458E-05,   4.6854577E-05,   4.7651334E-05
     +,   4.8422397E-05,   4.9171387E-05,   4.9902796E-05
     +,   5.0621940E-05,   5.1335104E-05,   5.2049378E-05
     +,   5.2772717E-05,   5.3513784E-05,   5.4281994E-05
     +,   5.5087279E-05,   5.5940145E-05,   5.6851371E-05
     +,   5.7832018E-05,   5.8893209E-05,   6.0045906E-05
     +,   6.1300765E-05,   6.2667968E-05,   6.4157044E-05
     +,   6.5776374E-05,   6.7533416E-05,   6.9433954E-05
     +,   7.1482325E-05,   7.3680800E-05,   7.6029704E-05
     +,   7.8526813E-05,   8.1167738E-05,   8.3945117E-05
     +,   8.6849243E-05,   8.9867761E-05,   9.2985661E-05
     +,   9.6185620E-05,   9.9448655E-05,   1.0275441E-04
     +,   1.0608143E-04,   1.0940884E-04,   1.1271631E-04
     +,   1.1598613E-04,   1.1920332E-04,   1.2235813E-04
     +,   1.2544624E-04,   1.2847105E-04,   1.3144428E-04
     +,   1.3438787E-04,   1.3733501E-04,   1.4033094E-04
     +,   1.4343418E-04,   1.4671733E-04,   1.5026781E-04
     +,   1.5418771E-04,   1.5859491E-04,   1.6362222E-04
     +,   1.6941836E-04,   1.7614618E-04,   1.8398362E-04
     +,   1.9312059E-04,   2.0375878E-04,   2.1610594E-04
     +,   2.3037341E-04,   2.4676754E-04,   2.6547845E-04
     +,   2.8666772E-04,   3.1045257E-04,   3.3688670E-04
     +,   3.6593707E-04,   3.9746528E-04,   4.3121289E-04
     +,   4.6679081E-04,   5.0367572E-04,   5.4123235E-04
     +,   5.7874195E-04,   6.1544724E-04,   6.5061718E-04
     +,   6.8362261E-04,   7.1400526E-04,   7.4154173E-04
     +,   7.6629187E-04,   7.8861450E-04,   8.0914597E-04
     +,   8.2873832E-04,   8.4835902E-04,   8.6896529E-04
     +,   8.9135196E-04,   9.1600901E-04,   9.4299781E-04
     +,   9.7187702E-04,   1.0016810E-03,   1.0309862E-03
     +,   1.0580480E-03,   1.0810022E-03,   1.0981115E-03
     +,   1.1080180E-03,   1.1099679E-03,   1.1039593E-03
     +,   1.0907972E-03,   1.0720376E-03,   1.0498210E-03
     +,   1.0266334E-03,   1.0050270E-03,   9.8733313E-04
     +,   9.7542827E-04,   9.7056170E-04,   9.7327237E-04
     +,   9.8338211E-04,   1.0000683E-03,   1.0219759E-03
     +,   1.0473687E-03,   1.0742908E-03,   1.1007225E-03
     +,   1.1247187E-03,   1.1445353E-03,   1.1587245E-03
     +,   1.1661951E-03,   1.1662474E-03,   1.1585725E-03
     +,   1.1432272E-03,   1.1205868E-03,   1.0912879E-03
     +,   1.0561579E-03,   1.0161542E-03,   9.7230950E-04
     +,   9.2568778E-04,   8.7734085E-04,   8.2828640E-04
     +,   7.7948824E-04,   7.3183607E-04,   6.8612304E-04
     +,   6.4303353E-04,   6.0312724E-04,   5.6681992E-04
     +,   5.3437578E-04,   5.0590798E-04,   4.8138108E-04
     +,   4.6062181E-04,   4.4334328E-04,   4.2916960E-04
     +,   4.1766110E-04,   4.0834211E-04,   4.0072590E-04
     +,   3.9433592E-04,   3.8872237E-04,   3.8347224E-04
     +,   3.7821956E-04,   3.7264824E-04,   3.6649409E-04
     +,   3.5954485E-04,   3.5163999E-04,   3.4266891E-04
     +,   3.3256874E-04,   3.2132285E-04,   3.0895942E-04
     +,   2.9554771E-04,   2.8119376E-04,   2.6603622E-04
     +,   2.5024128E-04,   2.3399558E-04,   2.1749712E-04
     +,   2.0094881E-04,   1.8455202E-04,   1.6849622E-04
     +,   1.5295410E-04,   1.3807738E-04,   1.2399179E-04
     +,   1.1079419E-04,   9.8552649E-05,   8.7308043E-05
     +,   7.7074947E-05,   6.7843801E-05,   5.9585334E-05
     +,   5.2254734E-05,   4.5794914E-05,   4.0139934E-05
     +,   3.5219025E-05,   3.0959953E-05,   2.7290600E-05
     +,   2.4141465E-05,   2.1447348E-05,   1.9147976E-05
     +,   1.7188548E-05,   1.5520132E-05,   1.4099680E-05
     +,   1.2889658E-05,   1.1857583E-05,   1.0975660E-05
     +,   1.0220313E-05,   9.5715714E-06,   9.0125541E-06
     +,   8.5290658E-06,   8.1091939E-06,   7.7428649E-06
     +,   7.4215845E-06,   7.1381851E-06,   6.8865793E-06
     +,   6.6615712E-06,   6.4587234E-06,   6.2742629E-06
     +,   6.1049559E-06,   5.9480280E-06,   5.8011146E-06
     +,   5.6622225E-06,   5.5296482E-06,   5.4019788E-06
     +,   5.2780256E-06,   5.1568313E-06,   5.0376029E-06
     +,   4.9197283E-06,   4.8027196E-06,   4.6862247E-06
     +,   4.5699808E-06,   4.4538251E-06,   4.3376599E-06
     +,   4.2214465E-06,   4.1052062E-06,   3.9889856E-06
     +,   3.8728781E-06,   3.7569839E-06,   3.6414372E-06
     +,   3.5263699E-06,   3.4119359E-06,   3.2982789E-06
     +,   3.1855586E-06,   3.0739188E-06,   2.9635144E-06
     +,   2.8544825E-06,   2.7469664E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_ashz_zz_mass = Yx/0.0187409090909091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_hzonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9732154E-07,   4.6081462E-07
     +,   5.3316512E-07,   6.1539782E-07,   7.0862507E-07
     +,   8.1404926E-07,   9.3296745E-07,   1.0667736E-06
     +,   1.2169584E-06,   1.3851201E-06,   1.5729514E-06
     +,   1.7822514E-06,   2.0149187E-06,   2.2729530E-06
     +,   2.5584543E-06,   2.8736142E-06,   3.2207188E-06
     +,   3.6021372E-06,   4.0203163E-06,   4.4777739E-06
     +,   4.9770838E-06,   5.5208670E-06,   6.1117717E-06
     +,   6.7524934E-06,   7.4456566E-06,   8.1939334E-06
     +,   8.9999012E-06,   9.8660739E-06,   1.0794850E-05
     +,   1.1788486E-05,   1.2849053E-05,   1.3978413E-05
     +,   1.5178147E-05,   1.6449527E-05,   1.7793467E-05
     +,   1.9210467E-05,   2.0700561E-05,   2.2263237E-05
     +,   2.3897532E-05,   2.5601670E-05,   2.7373420E-05
     +,   2.9209748E-05,   3.1106920E-05,   3.3060453E-05
     +,   3.5065132E-05,   3.7114994E-05,   3.9203373E-05
     +,   4.1322892E-05,   4.3465610E-05,   4.5623048E-05
     +,   4.7786307E-05,   4.9946189E-05,   5.2093346E-05
     +,   5.4218621E-05,   5.6312783E-05,   5.8367368E-05
     +,   6.0374401E-05,   6.2326828E-05,   6.4218744E-05
     +,   6.6045621E-05,   6.7804453E-05,   6.9494105E-05
     +,   7.1115253E-05,   7.2670831E-05,   7.4165910E-05
     +,   7.5607692E-05,   7.7005745E-05,   7.8371646E-05
     +,   7.9719081E-05,   8.1063386E-05,   8.2421568E-05
     +,   8.3811588E-05,   8.5252315E-05,   8.6762673E-05
     +,   8.8361478E-05,   9.0066751E-05,   9.1894988E-05
     +,   9.3860719E-05,   9.5976051E-05,   9.8250173E-05
     +,   1.0068841E-04,   1.0329256E-04,   1.0605990E-04
     +,   1.0898360E-04,   1.1205204E-04,   1.1524952E-04
     +,   1.1855569E-04,   1.2194672E-04,   1.2539478E-04
     +,   1.2886951E-04,   1.3233820E-04,   1.3576646E-04
     +,   1.3911910E-04,   1.4236131E-04,   1.4545924E-04
     +,   1.4838041E-04,   1.5109548E-04,   1.5357780E-04
     +,   1.5580498E-04,   1.5775870E-04,   1.5942543E-04
     +,   1.6079629E-04,   1.6186746E-04,   1.6263971E-04
     +,   1.6311834E-04,   1.6331274E-04,   1.6323591E-04
     +,   1.6290386E-04,   1.6233501E-04,   1.6154948E-04
     +,   1.6056850E-04,   1.5941373E-04,   1.5810670E-04
     +,   1.5666822E-04,   1.5511822E-04,   1.5347493E-04
     +,   1.5175533E-04,   1.4997444E-04,   1.4814571E-04
     +,   1.4628096E-04,   1.4439043E-04,   1.4248332E-04
     +,   1.4056782E-04,   1.3865135E-04,   1.3674087E-04
     +,   1.3484342E-04,   1.3296580E-04,   1.3111535E-04
     +,   1.2929943E-04,   1.2752604E-04,   1.2580327E-04
     +,   1.2413962E-04,   1.2254347E-04,   1.2102331E-04
     +,   1.1958700E-04,   1.1824183E-04,   1.1699423E-04
     +,   1.1584937E-04,   1.1481101E-04,   1.1388117E-04
     +,   1.1306017E-04,   1.1234642E-04,   1.1173627E-04
     +,   1.1122421E-04,   1.1080292E-04,   1.1046330E-04
     +,   1.1019485E-04,   1.0998581E-04,   1.0982352E-04
     +,   1.0969471E-04,   1.0958584E-04,   1.0948355E-04
     +,   1.0937487E-04,   1.0924764E-04,   1.0909079E-04
     +,   1.0889456E-04,   1.0865086E-04,   1.0835320E-04
     +,   1.0799705E-04,   1.0757973E-04,   1.0710046E-04
     +,   1.0656034E-04,   1.0596216E-04,   1.0531034E-04
     +,   1.0461059E-04,   1.0386974E-04,   1.0309556E-04
     +,   1.0229637E-04,   1.0148073E-04,   1.0065718E-04
     +,   9.9834062E-05,   9.9019097E-05,   9.8219185E-05
     +,   9.7440236E-05,   9.6687028E-05,   9.5962954E-05
     +,   9.5270021E-05,   9.4608811E-05,   9.3978444E-05
     +,   9.3376650E-05,   9.2799761E-05,   9.2242983E-05
     +,   9.1700444E-05,   9.1165391E-05,   9.0630310E-05
     +,   9.0087276E-05,   8.9528141E-05,   8.8944551E-05
     +,   8.8328372E-05,   8.7671877E-05,   8.6967746E-05
     +,   8.6209380E-05,   8.5391017E-05,   8.4507868E-05
     +,   8.3556035E-05,   8.2532672E-05,   8.1436170E-05
     +,   8.0265869E-05,   7.9022291E-05,   7.7706762E-05
     +,   7.6321776E-05,   7.4870644E-05,   7.3357383E-05
     +,   7.1786650E-05,   7.0163827E-05,   6.8494526E-05
     +,   6.6784756E-05,   6.5040811E-05,   6.3269072E-05
     +,   6.1475846E-05,   5.9667345E-05,   5.7849706E-05
     +,   5.6028861E-05,   5.4210297E-05,   5.2399191E-05
     +,   5.0600436E-05,   4.8818507E-05,   4.7057361E-05
     +,   4.5320525E-05,   4.3611264E-05,   4.1932250E-05
     +,   4.0285766E-05,   3.8673825E-05,   3.7098078E-05
     +,   3.5559719E-05,   3.4059674E-05,   3.2598680E-05
     +,   3.1177242E-05,   2.9795545E-05,   2.8453605E-05
     +,   2.7151375E-05,   2.5888674E-05,   2.4665123E-05
     +,   2.3480286E-05,   2.2333759E-05,   2.1224978E-05
     +,   2.0153360E-05,   1.9118368E-05,   1.8119437E-05
     +,   1.7155955E-05,   1.6227294E-05,   1.5332898E-05
     +,   1.4472223E-05,   1.3644664E-05,   1.2849630E-05
     +,   1.2086598E-05,   1.1355033E-05,   1.0654358E-05
     +,   9.9839981E-06,   9.3434373E-06,   8.7320905E-06
     +,   8.1493590E-06,   7.5946755E-06,   7.0674496E-06
     +,   6.5670370E-06,   6.0927773E-06,   5.6440276E-06
     +,   5.2201085E-06,   4.8203005E-06,   4.4438630E-06
     +,   4.0900572E-06,   3.7581292E-06,   3.4472794E-06
     +,   3.1567022E-06,   2.8856036E-06,   2.6331541E-06
     +,   2.3985197E-06,   2.1808792E-06,   1.9794099E-06
     +,   1.7932794E-06,   1.6216633E-06,   1.4637579E-06
     +,   1.3187735E-06,   1.1859241E-06,   1.0644451E-06
     +,   9.5360343E-07,   8.5267482E-07,   7.6097382E-07
     +,   6.7782850E-07,   6.0260635E-07,   5.3469358E-07
     +,   4.7351588E-07,   4.1851993E-07,   3.6919107E-07
     +,   3.2503763E-07,   2.8560461E-07,   2.5046222E-07
     +,   2.1921056E-07,   1.9148062E-07,   1.6692717E-07
     +,   1.4523484E-07,   1.2611045E-07,   1.0928756E-07
     +,   9.4520203E-08,   8.1586137E-08,   7.0281402E-08
     +,   6.0422757E-08,   5.1843234E-08,   4.4393353E-08
     +,   3.7937994E-08,   3.2356702E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_hzonly_eez_mass = Yx/0.0044667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_hzonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0554520E-04,   1.0633361E-04
     +,   1.0705931E-04,   1.0772108E-04,   1.0831778E-04
     +,   1.0884845E-04,   1.0931221E-04,   1.0970836E-04
     +,   1.1003631E-04,   1.1029564E-04,   1.1048604E-04
     +,   1.1060738E-04,   1.1065967E-04,   1.1064304E-04
     +,   1.1055778E-04,   1.1040433E-04,   1.1018331E-04
     +,   1.0989541E-04,   1.0954149E-04,   1.0912259E-04
     +,   1.0863984E-04,   1.0809453E-04,   1.0748805E-04
     +,   1.0682193E-04,   1.0609782E-04,   1.0531749E-04
     +,   1.0448282E-04,   1.0359577E-04,   1.0265841E-04
     +,   1.0167291E-04,   1.0064154E-04,   9.9566591E-05
     +,   9.8450480E-05,   9.7295677E-05,   9.6104668E-05
     +,   9.4880044E-05,   9.3624381E-05,   9.2340357E-05
     +,   9.1030546E-05,   8.9697736E-05,   8.8344539E-05
     +,   8.6973669E-05,   8.5587781E-05,   8.4189589E-05
     +,   8.2781713E-05,   8.1366801E-05,   7.9947407E-05
     +,   7.8526115E-05,   7.7105396E-05,   7.5687734E-05
     +,   7.4275478E-05,   7.2870986E-05,   7.1476519E-05
     +,   7.0094204E-05,   6.8726215E-05,   6.7374538E-05
     +,   6.6041102E-05,   6.4727770E-05,   6.3436288E-05
     +,   6.2168328E-05,   6.0925457E-05,   5.9709102E-05
     +,   5.8520705E-05,   5.7361503E-05,   5.6232606E-05
     +,   5.5135166E-05,   5.4070082E-05,   5.3038293E-05
     +,   5.2040505E-05,   5.1077452E-05,   5.0149662E-05
     +,   4.9257680E-05,   4.8401853E-05,   4.7582547E-05
     +,   4.6799963E-05,   4.6054225E-05,   4.5345434E-05
     +,   4.4673608E-05,   4.4038654E-05,   4.3440414E-05
     +,   4.2878728E-05,   4.2353317E-05,   4.1863885E-05
     +,   4.1410069E-05,   4.0991483E-05,   4.0607672E-05
     +,   4.0258183E-05,   3.9942493E-05,   3.9660099E-05
     +,   3.9410439E-05,   3.9192939E-05,   3.9007038E-05
     +,   3.8852148E-05,   3.8727681E-05,   3.8633050E-05
     +,   3.8567665E-05,   3.8530969E-05,   3.8522383E-05
     +,   3.8541362E-05,   3.8587379E-05,   3.8659924E-05
     +,   3.8758513E-05,   3.8882703E-05,   3.9032035E-05
     +,   3.9206148E-05,   3.9404662E-05,   3.9627252E-05
     +,   3.9873619E-05,   4.0143525E-05,   4.0436767E-05
     +,   4.0753141E-05,   4.1092550E-05,   4.1454896E-05
     +,   4.1840132E-05,   4.2248255E-05,   4.2679309E-05
     +,   4.3133372E-05,   4.3610584E-05,   4.4111071E-05
     +,   4.4635060E-05,   4.5182813E-05,   4.5754594E-05
     +,   4.6350695E-05,   4.6971483E-05,   4.7617359E-05
     +,   4.8288694E-05,   4.8985963E-05,   4.9709593E-05
     +,   5.0460105E-05,   5.1237952E-05,   5.2043710E-05
     +,   5.2877840E-05,   5.3740932E-05,   5.4633489E-05
     +,   5.5556058E-05,   5.6509209E-05,   5.7493446E-05
     +,   5.8509238E-05,   5.9557125E-05,   6.0637598E-05
     +,   6.1751089E-05,   6.2897961E-05,   6.4078624E-05
     +,   6.5293476E-05,   6.6542700E-05,   6.7826586E-05
     +,   6.9145361E-05,   7.0499111E-05,   7.1887844E-05
     +,   7.3311588E-05,   7.4770316E-05,   7.6263837E-05
     +,   7.7791861E-05,   7.9354111E-05,   8.0950260E-05
     +,   8.2579762E-05,   8.4241990E-05,   8.5936343E-05
     +,   8.7662178E-05,   8.9418500E-05,   9.1204478E-05
     +,   9.3019131E-05,   9.4861411E-05,   9.6730022E-05
     +,   9.8623837E-05,   1.0054158E-04,   1.0248183E-04
     +,   1.0444309E-04,   1.0642394E-04,   1.0842292E-04
     +,   1.1043836E-04,   1.1246857E-04,   1.1451198E-04
     +,   1.1656700E-04,   1.1863177E-04,   1.2070472E-04
     +,   1.2278413E-04,   1.2486837E-04,   1.2695562E-04
     +,   1.2904433E-04,   1.3113294E-04,   1.3321982E-04
     +,   1.3530330E-04,   1.3738204E-04,   1.3945460E-04
     +,   1.4151956E-04,   1.4357544E-04,   1.4562115E-04
     +,   1.4765542E-04,   1.4967704E-04,   1.5168496E-04
     +,   1.5367819E-04,   1.5565567E-04,   1.5761644E-04
     +,   1.5955966E-04,   1.6148448E-04,   1.6339008E-04
     +,   1.6527560E-04,   1.6714030E-04,   1.6898345E-04
     +,   1.7080423E-04,   1.7260185E-04,   1.7437545E-04
     +,   1.7612436E-04,   1.7784748E-04,   1.7954400E-04
     +,   1.8121293E-04,   1.8285311E-04,   1.8446338E-04
     +,   1.8604247E-04,   1.8758910E-04,   1.8910173E-04
     +,   1.9057878E-04,   1.9201850E-04,   1.9341920E-04
     +,   1.9477880E-04,   1.9609521E-04,   1.9736623E-04
     +,   1.9858959E-04,   1.9976276E-04,   2.0088315E-04
     +,   2.0194815E-04,   2.0295494E-04,   2.0390055E-04
     +,   2.0478212E-04,   2.0559665E-04,   2.0634099E-04
     +,   2.0701207E-04,   2.0760672E-04,   2.0812187E-04
     +,   2.0855437E-04,   2.0890113E-04,   2.0915916E-04
     +,   2.0932552E-04,   2.0939735E-04,   2.0937198E-04
     +,   2.0924673E-04,   2.0901929E-04,   2.0868737E-04
     +,   2.0824892E-04,   2.0770216E-04,   2.0704544E-04
     +,   2.0627749E-04,   2.0539720E-04,   2.0440375E-04
     +,   2.0329667E-04,   2.0207577E-04,   2.0074114E-04
     +,   1.9929312E-04,   1.9773257E-04,   1.9606050E-04
     +,   1.9427820E-04,   1.9238738E-04,   1.9039014E-04
     +,   1.8828877E-04,   1.8608573E-04,   1.8378405E-04
     +,   1.8138695E-04,   1.7889784E-04,   1.7632035E-04
     +,   1.7365848E-04,   1.7091649E-04,   1.6809872E-04
     +,   1.6520955E-04,   1.6225394E-04,   1.5923665E-04
     +,   1.5616255E-04,   1.5303688E-04,   1.4986491E-04
     +,   1.4665173E-04,   1.4340256E-04,   1.4012279E-04
     +,   1.3681781E-04,   1.3349278E-04,   1.3015285E-04
     +,   1.2680335E-04,   1.2344918E-04,   1.2009553E-04
     +,   1.1674705E-04,   1.1340873E-04,   1.1008494E-04
     +,   1.0678037E-04,   1.0349905E-04,   1.0024531E-04
     +,   9.7022879E-05,   9.3835661E-05,   9.0687121E-05
     +,   8.7580440E-05,   8.4518935E-05,   8.1505306E-05
     +,   7.8542464E-05,   7.5632626E-05,   7.2778268E-05
     +,   6.9981230E-05,   6.7243534E-05,   6.4566600E-05
     +,   6.1952021E-05,   5.9400834E-05,   5.6914218E-05
     +,   5.4492841E-05,   5.2137497E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_hzonly_qq_mass = Yx/0.00872457894736842
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_hzonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.6942950E-05,   7.0062204E-05
     +,   7.3277341E-05,   7.6587967E-05,   7.9993551E-05
     +,   8.3493331E-05,   8.7086366E-05,   9.0771515E-05
     +,   9.4547591E-05,   9.8413526E-05,   1.0236819E-04
     +,   1.0641055E-04,   1.1054007E-04,   1.1475646E-04
     +,   1.1906005E-04,   1.2345175E-04,   1.2793348E-04
     +,   1.3250799E-04,   1.3717922E-04,   1.4195236E-04
     +,   1.4683402E-04,   1.5183228E-04,   1.5695678E-04
     +,   1.6221916E-04,   1.6763210E-04,   1.7321065E-04
     +,   1.7897111E-04,   1.8493134E-04,   1.9111086E-04
     +,   1.9753024E-04,   2.0421141E-04,   2.1117696E-04
     +,   2.1844996E-04,   2.2605414E-04,   2.3401337E-04
     +,   2.4235084E-04,   2.5108978E-04,   2.6025230E-04
     +,   2.6986049E-04,   2.7993429E-04,   2.9049325E-04
     +,   3.0155547E-04,   3.1313777E-04,   3.2525553E-04
     +,   3.3792303E-04,   3.5115314E-04,   3.6495738E-04
     +,   3.7934579E-04,   3.9432701E-04,   4.0990827E-04
     +,   4.2609425E-04,   4.4288769E-04,   4.6028872E-04
     +,   4.7829514E-04,   4.9689988E-04,   5.1609374E-04
     +,   5.3586316E-04,   5.5619003E-04,   5.7705236E-04
     +,   5.9842470E-04,   6.2027766E-04,   6.4258021E-04
     +,   6.6529692E-04,   6.8839319E-04,   7.1183452E-04
     +,   7.3558366E-04,   7.5960759E-04,   7.8387110E-04
     +,   8.0834446E-04,   8.3299435E-04,   8.5779279E-04
     +,   8.8270684E-04,   9.0770825E-04,   9.3276304E-04
     +,   9.5783849E-04,   9.8290038E-04,   1.0079127E-03
     +,   1.0328402E-03,   1.0576493E-03,   1.0823141E-03
     +,   1.1068091E-03,   1.1311218E-03,   1.1552452E-03
     +,   1.1791852E-03,   1.2029536E-03,   1.2265693E-03
     +,   1.2500499E-03,   1.2734119E-03,   1.2966577E-03
     +,   1.3197707E-03,   1.3427117E-03,   1.3654047E-03
     +,   1.3877394E-03,   1.4095695E-03,   1.4307150E-03
     +,   1.4509637E-03,   1.4700901E-03,   1.4878598E-03
     +,   1.5040513E-03,   1.5184652E-03,   1.5309470E-03
     +,   1.5413923E-03,   1.5497602E-03,   1.5560720E-03
     +,   1.5604163E-03,   1.5629273E-03,   1.5637849E-03
     +,   1.5631831E-03,   1.5613176E-03,   1.5583561E-03
     +,   1.5544249E-03,   1.5495812E-03,   1.5438137E-03
     +,   1.5370240E-03,   1.5290453E-03,   1.5196319E-03
     +,   1.5084966E-03,   1.4953170E-03,   1.4797702E-03
     +,   1.4615568E-03,   1.4404239E-03,   1.4161950E-03
     +,   1.3887853E-03,   1.3582116E-03,   1.3246007E-03
     +,   1.2881916E-03,   1.2493168E-03,   1.2084008E-03
     +,   1.1659286E-03,   1.1224353E-03,   1.0784701E-03
     +,   1.0345851E-03,   9.9129893E-04,   9.4909122E-04
     +,   9.0837304E-04,   8.6948590E-04,   8.3269092E-04
     +,   7.9816842E-04,   7.6601602E-04,   7.3625869E-04
     +,   7.0885936E-04,   6.8372674E-04,   6.6072942E-04
     +,   6.3970807E-04,   6.2049180E-04,   6.0290465E-04
     +,   5.8677804E-04,   5.7195988E-04,   5.5831834E-04
     +,   5.4574659E-04,   5.3416297E-04,   5.2351324E-04
     +,   5.1376608E-04,   5.0491106E-04,   4.9695390E-04
     +,   4.8991264E-04,   4.8381329E-04,   4.7868286E-04
     +,   4.7454727E-04,   4.7142766E-04,   4.6933454E-04
     +,   4.6826998E-04,   4.6822164E-04,   4.6916492E-04
     +,   4.7106209E-04,   4.7386286E-04,   4.7750564E-04
     +,   4.8191883E-04,   4.8702370E-04,   4.9273606E-04
     +,   4.9896806E-04,   5.0563097E-04,   5.1263795E-04
     +,   5.1990553E-04,   5.2735471E-04,   5.3491449E-04
     +,   5.4252171E-04,   5.5012142E-04,   5.5766961E-04
     +,   5.6513154E-04,   5.7248271E-04,   5.7970878E-04
     +,   5.8680243E-04,   5.9376616E-04,   6.0060975E-04
     +,   6.0734706E-04,   6.1399653E-04,   6.2058098E-04
     +,   6.2712363E-04,   6.3364790E-04,   6.4017682E-04
     +,   6.4673170E-04,   6.5332867E-04,   6.5998198E-04
     +,   6.6670048E-04,   6.7348924E-04,   6.8034662E-04
     +,   6.8726676E-04,   6.9423870E-04,   7.0124760E-04
     +,   7.0827332E-04,   7.1529171E-04,   7.2227715E-04
     +,   7.2920072E-04,   7.3603151E-04,   7.4273814E-04
     +,   7.4928894E-04,   7.5565302E-04,   7.6179951E-04
     +,   7.6770061E-04,   7.7332999E-04,   7.7866344E-04
     +,   7.8368024E-04,   7.8836147E-04,   7.9269253E-04
     +,   7.9666020E-04,   8.0025353E-04,   8.0346345E-04
     +,   8.0628291E-04,   8.0870430E-04,   8.1072049E-04
     +,   8.1232213E-04,   8.1349933E-04,   8.1423816E-04
     +,   8.1452297E-04,   8.1433327E-04,   8.1364549E-04
     +,   8.1243104E-04,   8.1065891E-04,   8.0829364E-04
     +,   8.0529752E-04,   8.0163201E-04,   7.9725741E-04
     +,   7.9213409E-04,   7.8622618E-04,   7.7950099E-04
     +,   7.7192957E-04,   7.6349155E-04,   7.5417280E-04
     +,   7.4396725E-04,   7.3287933E-04,   7.2092249E-04
     +,   7.0812099E-04,   6.9450750E-04,   6.8012410E-04
     +,   6.6502311E-04,   6.4926379E-04,   6.3291175E-04
     +,   6.1603833E-04,   5.9871958E-04,   5.8103440E-04
     +,   5.6306220E-04,   5.4488430E-04,   5.2658113E-04
     +,   5.0822995E-04,   4.8990466E-04,   4.7167757E-04
     +,   4.5361539E-04,   4.3577974E-04,   4.1822650E-04
     +,   4.0100716E-04,   3.8416730E-04,   3.6774628E-04
     +,   3.5177721E-04,   3.3628955E-04,   3.2130565E-04
     +,   3.0684329E-04,   2.9291573E-04,   2.7953231E-04
     +,   2.6669676E-04,   2.5440942E-04,   2.4266758E-04
     +,   2.3146544E-04,   2.2079340E-04,   2.1063970E-04
     +,   2.0099110E-04,   1.9183122E-04,   1.8314329E-04
     +,   1.7490816E-04,   1.6710667E-04,   1.5971792E-04
     +,   1.5272149E-04,   1.4609561E-04,   1.3981959E-04
     +,   1.3387184E-04,   1.2823204E-04,   1.2287970E-04
     +,   1.1779498E-04,   1.1295930E-04,   1.0835438E-04
     +,   1.0396336E-04,   9.9769823E-05,   9.5759038E-05
     +,   9.1916729E-05,   8.8230234E-05,   8.4687541E-05
     +,   8.1278158E-05,   7.7992183E-05,   7.4821161E-05
     +,   7.1757240E-05,   6.8793845E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_hzonly_ww_mass = Yx/0.0461396864864865
      RETURN
      END
      DOUBLE PRECISION FUNCTION A202N_tt_hzonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5828823E-05,   4.7444406E-05
     +,   4.9115639E-05,   5.0845480E-05,   5.2636944E-05
     +,   5.4493001E-05,   5.6416564E-05,   5.8410413E-05
     +,   6.0477138E-05,   6.2619205E-05,   6.4838641E-05
     +,   6.7137233E-05,   6.9516296E-05,   7.1976676E-05
     +,   7.4518670E-05,   7.7141958E-05,   7.9845580E-05
     +,   8.2627790E-05,   8.5486157E-05,   8.8417306E-05
     +,   9.1417132E-05,   9.4480587E-05,   9.7601631E-05
     +,   1.0077361E-04,   1.0398857E-04,   1.0723805E-04
     +,   1.1051252E-04,   1.1380172E-04,   1.1709469E-04
     +,   1.2037975E-04,   1.2364470E-04,   1.2687681E-04
     +,   1.3006311E-04,   1.3319023E-04,   1.3624485E-04
     +,   1.3921356E-04,   1.4208320E-04,   1.4484079E-04
     +,   1.4747411E-04,   1.4997117E-04,   1.5232111E-04
     +,   1.5451352E-04,   1.5653935E-04,   1.5839045E-04
     +,   1.6006004E-04,   1.6154254E-04,   1.6283375E-04
     +,   1.6393089E-04,   1.6483276E-04,   1.6553944E-04
     +,   1.6605263E-04,   1.6637558E-04,   1.6651268E-04
     +,   1.6646992E-04,   1.6625463E-04,   1.6587513E-04
     +,   1.6534106E-04,   1.6466304E-04,   1.6385260E-04
     +,   1.6292192E-04,   1.6188411E-04,   1.6075259E-04
     +,   1.5954133E-04,   1.5826453E-04,   1.5693648E-04
     +,   1.5557183E-04,   1.5418482E-04,   1.5278987E-04
     +,   1.5140101E-04,   1.5003212E-04,   1.4869664E-04
     +,   1.4740764E-04,   1.4617782E-04,   1.4501944E-04
     +,   1.4394413E-04,   1.4296321E-04,   1.4208729E-04
     +,   1.4132670E-04,   1.4069102E-04,   1.4018935E-04
     +,   1.3983026E-04,   1.3962161E-04,   1.3957068E-04
     +,   1.3968398E-04,   1.3996723E-04,   1.4042536E-04
     +,   1.4106210E-04,   1.4188033E-04,   1.4288131E-04
     +,   1.4406514E-04,   1.4543028E-04,   1.4697331E-04
     +,   1.4868884E-04,   1.5056945E-04,   1.5260543E-04
     +,   1.5478459E-04,   1.5709233E-04,   1.5951139E-04
     +,   1.6202216E-04,   1.6460227E-04,   1.6722760E-04
     +,   1.6987129E-04,   1.7250542E-04,   1.7510059E-04
     +,   1.7762686E-04,   1.8005438E-04,   1.8235431E-04
     +,   1.8449932E-04,   1.8646545E-04,   1.8823273E-04
     +,   1.8978653E-04,   1.9111911E-04,   1.9223108E-04
     +,   1.9313287E-04,   1.9384669E-04,   1.9440758E-04
     +,   1.9486589E-04,   1.9528822E-04,   1.9575920E-04
     +,   1.9638272E-04,   1.9728314E-04,   1.9860572E-04
     +,   2.0051611E-04,   2.0320035E-04,   2.0686271E-04
     +,   2.1172201E-04,   2.1800863E-04,   2.2595706E-04
     +,   2.3580005E-04,   2.4775730E-04,   2.6202813E-04
     +,   2.7877637E-04,   2.9812325E-04,   3.2013055E-04
     +,   3.4479675E-04,   3.7204751E-04,   4.0173091E-04
     +,   4.3362228E-04,   4.6743412E-04,   5.0283095E-04
     +,   5.3944823E-04,   5.7692430E-04,   6.1493414E-04
     +,   6.5322244E-04,   6.9163140E-04,   7.3013635E-04
     +,   7.6885638E-04,   8.0805569E-04,   8.4812829E-04
     +,   8.8956795E-04,   9.3290914E-04,   9.7865681E-04
     +,   1.0272044E-03,   1.0787559E-03,   1.1332453E-03
     +,   1.1902722E-03,   1.2490796E-03,   1.3085607E-03
     +,   1.3673073E-03,   1.4236937E-03,   1.4760229E-03
     +,   1.5226702E-03,   1.5622564E-03,   1.5937993E-03
     +,   1.6168605E-03,   1.6316135E-03,   1.6388714E-03
     +,   1.6400416E-03,   1.6370023E-03,   1.6319306E-03
     +,   1.6270811E-03,   1.6245545E-03,   1.6260721E-03
     +,   1.6328018E-03,   1.6452330E-03,   1.6631501E-03
     +,   1.6856682E-03,   1.7113549E-03,   1.7384002E-03
     +,   1.7648166E-03,   1.7886354E-03,   1.8080783E-03
     +,   1.8216805E-03,   1.8283639E-03,   1.8274531E-03
     +,   1.8186494E-03,   1.8019710E-03,   1.7776954E-03
     +,   1.7462915E-03,   1.7083678E-03,   1.6646468E-03
     +,   1.6159420E-03,   1.5631631E-03,   1.5073122E-03
     +,   1.4494692E-03,   1.3907839E-03,   1.3324427E-03
     +,   1.2756239E-03,   1.2214354E-03,   1.1708598E-03
     +,   1.1247030E-03,   1.0835408E-03,   1.0476891E-03
     +,   1.0171960E-03,   9.9185330E-04,   9.7121979E-04
     +,   9.5466583E-04,   9.4142987E-04,   9.3067111E-04
     +,   9.2152564E-04,   9.1315934E-04,   9.0480840E-04
     +,   8.9581212E-04,   8.8563509E-04,   8.7387906E-04
     +,   8.6028583E-04,   8.4473350E-04,   8.2722242E-04
     +,   8.0786063E-04,   7.8684447E-04,   7.6443329E-04
     +,   7.4092631E-04,   7.1664253E-04,   6.9189927E-04
     +,   6.6699018E-04,   6.4217468E-04,   6.1766873E-04
     +,   5.9363974E-04,   5.7020114E-04,   5.4742052E-04
     +,   5.2532315E-04,   5.0390116E-04,   4.8311907E-04
     +,   4.6292535E-04,   4.4326251E-04,   4.2407087E-04
     +,   4.0529628E-04,   3.8689628E-04,   3.6884044E-04
     +,   3.5111187E-04,   3.3370694E-04,   3.1663573E-04
     +,   2.9991911E-04,   2.8358455E-04,   2.6766519E-04
     +,   2.5219802E-04,   2.3722027E-04,   2.2276644E-04
     +,   2.0886757E-04,   1.9555124E-04,   1.8283793E-04
     +,   1.7074189E-04,   1.5927207E-04,   1.4843076E-04
     +,   1.3821389E-04,   1.2861186E-04,   1.1961116E-04
     +,   1.1119412E-04,   1.0333912E-04,   9.6022151E-05
     +,   8.9217705E-05,   8.2898943E-05,   7.7037912E-05
     +,   7.1606439E-05,   6.6577115E-05,   6.1922474E-05
     +,   5.7615973E-05,   5.3632320E-05,   4.9947401E-05
     +,   4.6538138E-05,   4.3382843E-05,   4.0461411E-05
     +,   3.7755119E-05,   3.5246419E-05,   3.2919099E-05
     +,   3.0758456E-05,   2.8750716E-05,   2.6883492E-05
     +,   2.5145227E-05,   2.3525590E-05,   2.2014947E-05
     +,   2.0604728E-05,   1.9286939E-05,   1.8054488E-05
     +,   1.6900769E-05,   1.5819929E-05,   1.4806542E-05
     +,   1.3855681E-05,   1.2962964E-05,   1.2124287E-05
     +,   1.1336027E-05,   1.0594784E-05,   9.8975570E-06
     +,   9.2415212E-06,   8.6241744E-06,   8.0431473E-06
     +,   7.4963482E-06,   6.9817775E-06,   6.4976580E-06
     +,   6.0422835E-06,   5.6141357E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A202N_tt_hzonly_zz_mass = Yx/0.0331062162162162
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   2.5225502E-38,   3.3926904E-37,   4.3668349E-36
     +,   5.3790323E-35,   6.3410739E-34,   7.1537934E-33
     +,   7.7237761E-32,   7.9807029E-31,   7.8917011E-30
     +,   7.4682110E-29,   6.7636681E-28,   5.8622523E-27
     +,   4.8625762E-26,   3.8599780E-25,   2.9322977E-24
     +,   2.1319529E-23,   1.4833276E-22,   9.8770636E-22
     +,   6.2941704E-21,   3.8385349E-20,   2.2403230E-19
     +,   1.2513406E-18,   6.6889212E-18,   3.4218070E-17
     +,   1.6752248E-16,   7.8488847E-16,   3.5193438E-15
     +,   1.5101942E-14,   6.2018716E-14,   2.4373673E-13
     +,   9.1675962E-13,   3.2998166E-12,   1.1367167E-11
     +,   3.7474163E-11,   1.1823044E-10,   3.5698111E-10
     +,   1.0315239E-09,   2.8525349E-09,   7.5491977E-09
     +,   1.9120018E-08,   4.6344084E-08,   1.0750242E-07
     +,   2.3864925E-07,   5.0701385E-07,   1.0308432E-06
     +,   2.0058274E-06,   3.7351074E-06,   6.6563380E-06
     +,   1.1352340E-05,   1.8529063E-05,   2.8942752E-05
     +,   4.3265725E-05,   6.1896528E-05,   8.4744017E-05
     +,   1.1103658E-04,   1.3923326E-04,   1.6708738E-04
     +,   1.9189624E-04,   2.1092290E-04,   2.2188690E-04
     +,   2.2342670E-04,   2.1539355E-04,   1.9890651E-04
     +,   1.7615654E-04,   1.5001523E-04,   1.2357511E-04
     +,   9.9720055E-05,   8.0827907E-05,   6.8621077E-05
     +,   6.4130945E-05,   6.7719666E-05,   7.9098616E-05
     +,   9.7312237E-05,   1.2071773E-04,   1.4700399E-04
     +,   1.7333259E-04,   1.9661471E-04,   2.1393094E-04
     +,   2.2299170E-04,   2.2254366E-04,   2.1259086E-04
     +,   1.9437019E-04,   1.7007766E-04,   1.4242603E-04
     +,   1.1414461E-04,   8.7547036E-05,   6.4260188E-05
     +,   4.5140408E-05,   3.0346022E-05,   1.9523695E-05
     +,   1.2020811E-05,   7.0832189E-06,   3.9942738E-06
     +,   2.1556166E-06,   1.1133051E-06,   5.5028062E-07
     +,   2.6029934E-07,   1.1783355E-07,   5.1048403E-08
     +,   2.1165363E-08,   8.3982306E-09,   3.1890013E-09
     +,   1.1589197E-09,   4.0304698E-10,   1.3414997E-10
     +,   4.2729542E-11,   1.3025663E-11,   3.7999061E-12
     +,   1.0609170E-12,   2.8345875E-13,   7.2482893E-14
     +,   1.7737778E-14,   4.1539411E-15,   9.3097825E-16
     +,   1.9969098E-16,   4.0991650E-17,   8.0524362E-18
     +,   1.5139143E-18,   2.7237582E-19,   4.6900643E-20
     +,   7.7282701E-21,   1.2187942E-21,   1.8393670E-22
     +,   2.6567523E-23,   3.6721917E-24,   4.8578695E-25
     +,   6.1501334E-26,   7.4509461E-27,   8.6388926E-28
     +,   9.5862639E-29,   1.0180336E-29,   1.0345698E-30
     +,   1.0061760E-31,   9.3657520E-33,   8.3431382E-34
     +,   7.1121007E-35,   5.8025326E-36,   4.5306307E-37
     +,   3.3851778E-38,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_eez_mass = Yx/0.0012495
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5137232E-16,   1.0281394E-15
     +,   2.9455054E-15,   8.2622236E-15,   2.2691620E-14
     +,   6.1019989E-14,   1.6066430E-13,   4.1420209E-13
     +,   1.0455560E-12,   2.5842969E-12,   6.2545277E-12
     +,   1.4821960E-11,   3.4393932E-11,   7.8148953E-11
     +,   1.7387344E-10,   3.7880429E-10,   8.0810897E-10
     +,   1.6881077E-09,   3.4530774E-09,   6.9165584E-09
     +,   1.3565999E-08,   2.6055016E-08,   4.9001017E-08
     +,   9.0241322E-08,   1.6273239E-07,   2.8735815E-07
     +,   4.9687588E-07,   8.4129107E-07,   1.3948178E-06
     +,   2.2644381E-06,   3.5997662E-06,   5.6034978E-06
     +,   8.5411366E-06,   1.2748098E-05,   1.8631679E-05
     +,   2.6664964E-05,   3.7369795E-05,   5.1286272E-05
     +,   6.8929563E-05,   9.0729409E-05,   1.1696749E-04
     +,   1.4770473E-04,   1.8272051E-04,   2.2146756E-04
     +,   2.6305515E-04,   3.0626947E-04,   3.4963392E-04
     +,   3.9150813E-04,   4.3021646E-04,   4.6419149E-04
     +,   4.9211230E-04,   5.1301956E-04,   5.2638870E-04
     +,   5.3215306E-04,   5.3067133E-04,   5.2265124E-04
     +,   5.0904130E-04,   4.9091119E-04,   4.6934080E-04
     +,   4.4533540E-04,   4.1977552E-04,   3.9340334E-04
     +,   3.6684226E-04,   3.4062896E-04,   3.1525595E-04
     +,   2.9120597E-04,   2.6895941E-04,   2.4899279E-04
     +,   2.3174511E-04,   2.1758296E-04,   2.0675208E-04
     +,   1.9934405E-04,   1.9527029E-04,   1.9426044E-04
     +,   1.9587795E-04,   1.9955584E-04,   2.0464427E-04
     +,   2.1046585E-04,   2.1637126E-04,   2.2178818E-04
     +,   2.2625893E-04,   2.2946583E-04,   2.3123948E-04
     +,   2.3155383E-04,   2.3050728E-04,   2.2829488E-04
     +,   2.2517424E-04,   2.2142878E-04,   2.1733386E-04
     +,   2.1312632E-04,   2.0898259E-04,   2.0500556E-04
     +,   2.0122020E-04,   1.9757808E-04,   1.9396980E-04
     +,   1.9024282E-04,   1.8622119E-04,   1.8172801E-04
     +,   1.7660396E-04,   1.7072502E-04,   1.6401324E-04
     +,   1.5644489E-04,   1.4805027E-04,   1.3891252E-04
     +,   1.2915833E-04,   1.1894850E-04,   1.0846693E-04
     +,   9.7907425E-05,   8.7461136E-05,   7.7306802E-05
     +,   6.7603280E-05,   5.8481121E-05,   5.0041537E-05
     +,   4.2352745E-05,   3.5452995E-05,   2.9351117E-05
     +,   2.4032028E-05,   1.9459701E-05,   1.5583379E-05
     +,   1.2341249E-05,   9.6654430E-06,   7.4860063E-06
     +,   5.7338539E-06,   4.3431614E-06,   3.2532939E-06
     +,   2.4099377E-06,   1.7654071E-06,   1.2789360E-06
     +,   9.1623752E-07,   6.4913087E-07,   4.5479041E-07
     +,   3.1510481E-07,   2.1590029E-07,   1.4629059E-07
     +,   9.8025666E-08,   6.4955593E-08,   4.2565027E-08
     +,   2.7583843E-08,   1.7677310E-08,   1.1202924E-08
     +,   7.0211024E-09,   4.3515715E-09,   2.6671443E-09
     +,   1.6165866E-09,   9.6898811E-10,   5.7437760E-10
     +,   3.3668904E-10,   1.9517275E-10,   1.1188647E-10
     +,   6.3430115E-11,   3.5560211E-11,   1.9714830E-11
     +,   1.0809101E-11,   5.8606544E-12,   3.1423358E-12
     +,   1.6661688E-12,   8.7368258E-13,   4.5305225E-13
     +,   2.3232382E-13,   1.1781686E-13,   5.9085630E-14
     +,   2.9302498E-14,   1.4370986E-14,   6.9701160E-15
     +,   3.3431186E-15,   1.5856727E-15,   7.4376269E-16
     +,   3.4500480E-16,   1.5826170E-16,   7.1791806E-17
     +,   3.2205784E-17,   1.4287714E-17,   6.2683259E-18
     +,   2.7194927E-18,   1.1668028E-18,   4.9506848E-19
     +,   2.0772112E-19,   8.6189977E-20,   3.5367435E-20
     +,   1.4351905E-20,   5.7591893E-21,   2.2854703E-21
     +,   8.9693419E-22,   3.4810183E-22,   1.3359736E-22
     +,   5.0704745E-23,   1.9031514E-23,   7.0640790E-24
     +,   2.5928972E-24,   9.4121184E-25,   3.3787046E-25
     +,   1.1993858E-25,   4.2104175E-26,   1.4617297E-26
     +,   5.0184122E-27,   1.7037722E-27,   5.7203047E-28
     +,   1.8993247E-28,   6.2364380E-29,   2.0249762E-29
     +,   6.5022306E-30,   2.0648196E-30,   6.4842695E-31
     +,   2.0136432E-31,   6.1841682E-32,   1.8781671E-32
     +,   5.6407430E-33,   1.6753063E-33,   4.9207484E-34
     +,   1.4293123E-34,   4.1054657E-35,   1.1661652E-35
     +,   3.2759465E-36,   9.1005847E-37,   2.5000248E-37
     +,   6.7917517E-38,   1.8247147E-38,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_qq_mass = Yx/0.00447084615384615
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0229163E-05,   2.0624493E-05
     +,   2.1014108E-05,   2.1399252E-05,   2.1781423E-05
     +,   2.2162385E-05,   2.2544160E-05,   2.2929036E-05
     +,   2.3319559E-05,   2.3718541E-05,   2.4129029E-05
     +,   2.4554307E-05,   2.4997893E-05,   2.5463498E-05
     +,   2.5955043E-05,   2.6476602E-05,   2.7032404E-05
     +,   2.7626793E-05,   2.8264216E-05,   2.8949173E-05
     +,   2.9686205E-05,   3.0479836E-05,   3.1334559E-05
     +,   3.2254829E-05,   3.3244898E-05,   3.4308960E-05
     +,   3.5450954E-05,   3.6674577E-05,   3.7983253E-05
     +,   3.9380066E-05,   4.0867701E-05,   4.2448413E-05
     +,   4.4123972E-05,   4.5895595E-05,   4.7763937E-05
     +,   4.9728962E-05,   5.1789975E-05,   5.3945510E-05
     +,   5.6193432E-05,   5.8530532E-05,   6.0953029E-05
     +,   6.3456071E-05,   6.6033943E-05,   6.8680019E-05
     +,   7.1386756E-05,   7.4145682E-05,   7.6947472E-05
     +,   7.9781938E-05,   8.2638122E-05,   8.5504325E-05
     +,   8.8368215E-05,   9.1216905E-05,   9.4037081E-05
     +,   9.6815260E-05,   9.9537479E-05,   1.0219009E-04
     +,   1.0475936E-04,   1.0723191E-04,   1.0959477E-04
     +,   1.1183559E-04,   1.1394276E-04,   1.1590560E-04
     +,   1.1771431E-04,   1.1936035E-04,   1.2083648E-04
     +,   1.2213649E-04,   1.2325590E-04,   1.2419127E-04
     +,   1.2494087E-04,   1.2550417E-04,   1.2588207E-04
     +,   1.2607682E-04,   1.2609176E-04,   1.2593143E-04
     +,   1.2560136E-04,   1.2510786E-04,   1.2445808E-04
     +,   1.2365969E-04,   1.2272077E-04,   1.2164972E-04
     +,   1.2045512E-04,   1.1914548E-04,   1.1772935E-04
     +,   1.1621486E-04,   1.1461013E-04,   1.1292264E-04
     +,   1.1115972E-04,   1.0932803E-04,   1.0743406E-04
     +,   1.0548357E-04,   1.0348200E-04,   1.0143449E-04
     +,   9.9345867E-05,   9.7220509E-05,   9.5062656E-05
     +,   9.2876478E-05,   9.0665897E-05,   8.8435052E-05
     +,   8.6187763E-05,   8.3928338E-05,   8.1660830E-05
     +,   7.9389756E-05,   7.7119512E-05,   7.4854921E-05
     +,   7.2600807E-05,   7.0362104E-05,   6.8143985E-05
     +,   6.5951695E-05,   6.3790394E-05,   6.1665123E-05
     +,   5.9581096E-05,   5.7543057E-05,   5.5555789E-05
     +,   5.3623498E-05,   5.1750310E-05,   4.9939648E-05
     +,   4.8194739E-05,   4.6518064E-05,   4.4911754E-05
     +,   4.3377262E-05,   4.1915398E-05,   4.0526545E-05
     +,   3.9210470E-05,   3.7966296E-05,   3.6792611E-05
     +,   3.5687615E-05,   3.4648911E-05,   3.3673801E-05
     +,   3.2759122E-05,   3.1901498E-05,   3.1097221E-05
     +,   3.0342466E-05,   2.9633209E-05,   2.8965433E-05
     +,   2.8335044E-05,   2.7737986E-05,   2.7170343E-05
     +,   2.6628320E-05,   2.6108268E-05,   2.5606752E-05
     +,   2.5120602E-05,   2.4646919E-05,   2.4183053E-05
     +,   2.3726654E-05,   2.3275710E-05,   2.2828493E-05
     +,   2.2383552E-05,   2.1939781E-05,   2.1496362E-05
     +,   2.1052716E-05,   2.0608531E-05,   2.0163761E-05
     +,   1.9718582E-05,   1.9273341E-05,   1.8828556E-05
     +,   1.8384941E-05,   1.7943323E-05,   1.7504624E-05
     +,   1.7069839E-05,   1.6640070E-05,   1.6216421E-05
     +,   1.5800020E-05,   1.5392030E-05,   1.4993580E-05
     +,   1.4605764E-05,   1.4229628E-05,   1.3866184E-05
     +,   1.3516384E-05,   1.3181075E-05,   1.2861025E-05
     +,   1.2556943E-05,   1.2269434E-05,   1.1998991E-05
     +,   1.1746016E-05,   1.1510836E-05,   1.1293652E-05
     +,   1.1094578E-05,   1.0913644E-05,   1.0750786E-05
     +,   1.0605850E-05,   1.0478598E-05,   1.0368720E-05
     +,   1.0275839E-05,   1.0199507E-05,   1.0139209E-05
     +,   1.0094386E-05,   1.0064427E-05,   1.0048678E-05
     +,   1.0046449E-05,   1.0057015E-05,   1.0079631E-05
     +,   1.0113529E-05,   1.0157925E-05,   1.0212023E-05
     +,   1.0275025E-05,   1.0346131E-05,   1.0424540E-05
     +,   1.0509452E-05,   1.0600086E-05,   1.0695670E-05
     +,   1.0795441E-05,   1.0898651E-05,   1.1004581E-05
     +,   1.1112527E-05,   1.1221802E-05,   1.1331751E-05
     +,   1.1441743E-05,   1.1551160E-05,   1.1659420E-05
     +,   1.1765967E-05,   1.1870273E-05,   1.1971833E-05
     +,   1.2070163E-05,   1.2164821E-05,   1.2255384E-05
     +,   1.2341453E-05,   1.2422657E-05,   1.2498653E-05
     +,   1.2569129E-05,   1.2633786E-05,   1.2692358E-05
     +,   1.2744606E-05,   1.2790311E-05,   1.2829276E-05
     +,   1.2861327E-05,   1.2886321E-05,   1.2904128E-05
     +,   1.2914641E-05,   1.2917780E-05,   1.2913480E-05
     +,   1.2901693E-05,   1.2882398E-05,   1.2855591E-05
     +,   1.2821283E-05,   1.2779507E-05,   1.2730308E-05
     +,   1.2673751E-05,   1.2609917E-05,   1.2538902E-05
     +,   1.2460819E-05,   1.2375787E-05,   1.2283949E-05
     +,   1.2185458E-05,   1.2080478E-05,   1.1969175E-05
     +,   1.1851744E-05,   1.1728380E-05,   1.1599290E-05
     +,   1.1464680E-05,   1.1324785E-05,   1.1179830E-05
     +,   1.1030048E-05,   1.0875681E-05,   1.0716991E-05
     +,   1.0554219E-05,   1.0387619E-05,   1.0217455E-05
     +,   1.0043998E-05,   9.8675009E-06,   9.6882268E-06
     +,   9.5064433E-06,   9.3224253E-06,   9.1364273E-06
     +,   8.9487085E-06,   8.7595408E-06,   8.5691736E-06
     +,   8.3778568E-06,   8.1858461E-06,   7.9933943E-06
     +,   7.8007342E-06,   7.6080987E-06,   7.4157210E-06
     +,   7.2238322E-06,   7.0326432E-06,   6.8423574E-06
     +,   6.6531916E-06,   6.4653268E-06,   6.2789641E-06
     +,   6.0942707E-06,   5.9114304E-06,   5.7305938E-06
     +,   5.5519263E-06,   5.3755634E-06,   5.2016535E-06
     +,   5.0303133E-06,   4.8616726E-06,   4.6958376E-06
     +,   4.5329039E-06,   4.3729765E-06,   4.2161291E-06
     +,   4.0624482E-06,   3.9119909E-06,   3.7648276E-06
     +,   3.6209985E-06,   3.4805580E-06,   3.3435319E-06
     +,   3.2099570E-06,   3.0798456E-06,   2.9532221E-06
     +,   2.8300831E-06,   2.7104390E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_ww_mass = Yx/0.0027576675
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_haonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7136794E-05,   1.7242492E-05
     +,   1.7344379E-05,   1.7442324E-05,   1.7536200E-05
     +,   1.7625929E-05,   1.7711429E-05,   1.7792669E-05
     +,   1.7869641E-05,   1.7942364E-05,   1.8010907E-05
     +,   1.8075365E-05,   1.8135881E-05,   1.8192641E-05
     +,   1.8245872E-05,   1.8295850E-05,   1.8342897E-05
     +,   1.8387382E-05,   1.8429728E-05,   1.8470399E-05
     +,   1.8509909E-05,   1.8548822E-05,   1.8587743E-05
     +,   1.8627332E-05,   1.8668276E-05,   1.8711313E-05
     +,   1.8757211E-05,   1.8806775E-05,   1.8860837E-05
     +,   1.8920258E-05,   1.8985926E-05,   1.9058729E-05
     +,   1.9139579E-05,   1.9229403E-05,   1.9329107E-05
     +,   1.9439620E-05,   1.9561856E-05,   1.9696701E-05
     +,   1.9845058E-05,   2.0007768E-05,   2.0185682E-05
     +,   2.0379601E-05,   2.0590298E-05,   2.0818512E-05
     +,   2.1064934E-05,   2.1330223E-05,   2.1614987E-05
     +,   2.1919799E-05,   2.2245167E-05,   2.2591557E-05
     +,   2.2959390E-05,   2.3349035E-05,   2.3760811E-05
     +,   2.4195011E-05,   2.4651818E-05,   2.5131441E-05
     +,   2.5633999E-05,   2.6159578E-05,   2.6708214E-05
     +,   2.7279910E-05,   2.7874623E-05,   2.8492273E-05
     +,   2.9132703E-05,   2.9795769E-05,   3.0481282E-05
     +,   3.1188956E-05,   3.1918546E-05,   3.2669675E-05
     +,   3.3442022E-05,   3.4235120E-05,   3.5048553E-05
     +,   3.5881760E-05,   3.6734233E-05,   3.7605289E-05
     +,   3.8494294E-05,   3.9400536E-05,   4.0323182E-05
     +,   4.1261323E-05,   4.2214055E-05,   4.3180378E-05
     +,   4.4159118E-05,   4.5149143E-05,   4.6149114E-05
     +,   4.7157690E-05,   4.8173340E-05,   4.9194536E-05
     +,   5.0219496E-05,   5.1246487E-05,   5.2273510E-05
     +,   5.3298543E-05,   5.4319469E-05,   5.5333945E-05
     +,   5.6339552E-05,   5.7333771E-05,   5.8314014E-05
     +,   5.9277445E-05,   6.0221257E-05,   6.1142433E-05
     +,   6.2037994E-05,   6.2904735E-05,   6.3739513E-05
     +,   6.4539054E-05,   6.5300119E-05,   6.6019405E-05
     +,   6.6693654E-05,   6.7319677E-05,   6.7894296E-05
     +,   6.8414447E-05,   6.8877249E-05,   6.9279966E-05
     +,   6.9620000E-05,   6.9895090E-05,   7.0103190E-05
     +,   7.0242560E-05,   7.0311857E-05,   7.0310052E-05
     +,   7.0236609E-05,   7.0091352E-05,   6.9874630E-05
     +,   6.9587280E-05,   6.9230620E-05,   6.8806519E-05
     +,   6.8317371E-05,   6.7766116E-05,   6.7156150E-05
     +,   6.6491521E-05,   6.5776621E-05,   6.5016458E-05
     +,   6.4216329E-05,   6.3382075E-05,   6.2519772E-05
     +,   6.1635881E-05,   6.0737020E-05,   5.9830090E-05
     +,   5.8921996E-05,   5.8019708E-05,   5.7130197E-05
     +,   5.6260353E-05,   5.5416785E-05,   5.4605873E-05
     +,   5.3833694E-05,   5.3105927E-05,   5.2427731E-05
     +,   5.1803723E-05,   5.1238007E-05,   5.0733965E-05
     +,   5.0294297E-05,   4.9921051E-05,   4.9615479E-05
     +,   4.9378068E-05,   4.9208527E-05,   4.9105816E-05
     +,   4.9068112E-05,   4.9092854E-05,   4.9176782E-05
     +,   4.9315935E-05,   4.9505710E-05,   4.9740938E-05
     +,   5.0015937E-05,   5.0324510E-05,   5.0660128E-05
     +,   5.1015908E-05,   5.1384734E-05,   5.1759307E-05
     +,   5.2132251E-05,   5.2496187E-05,   5.2843803E-05
     +,   5.3167914E-05,   5.3461565E-05,   5.3718100E-05
     +,   5.3931195E-05,   5.4094937E-05,   5.4203891E-05
     +,   5.4253142E-05,   5.4238302E-05,   5.4155611E-05
     +,   5.4001881E-05,   5.3774591E-05,   5.3471857E-05
     +,   5.3092455E-05,   5.2635798E-05,   5.2101939E-05
     +,   5.1491603E-05,   5.0806058E-05,   5.0047151E-05
     +,   4.9217306E-05,   4.8319485E-05,   4.7357040E-05
     +,   4.6333746E-05,   4.5253833E-05,   4.4121778E-05
     +,   4.2942327E-05,   4.1720486E-05,   4.0461488E-05
     +,   3.9170565E-05,   3.7853017E-05,   3.6514270E-05
     +,   3.5159715E-05,   3.3794575E-05,   3.2423970E-05
     +,   3.1052954E-05,   2.9686404E-05,   2.8328886E-05
     +,   2.6984728E-05,   2.5658121E-05,   2.4352847E-05
     +,   2.3072380E-05,   2.1819973E-05,   2.0598558E-05
     +,   1.9410660E-05,   1.8258479E-05,   1.7143979E-05
     +,   1.6068794E-05,   1.5034184E-05,   1.4041115E-05
     +,   1.3090326E-05,   1.2182283E-05,   1.1317140E-05
     +,   1.0494808E-05,   9.7150623E-06,   8.9773930E-06
     +,   8.2811084E-06,   7.6254018E-06,   7.0093138E-06
     +,   6.4317182E-06,   5.8913811E-06,   5.3870185E-06
     +,   4.9172641E-06,   4.4806643E-06,   4.0757245E-06
     +,   3.7009522E-06,   3.3548322E-06,   3.0358246E-06
     +,   2.7424007E-06,   2.4730755E-06,   2.2263616E-06
     +,   2.0008085E-06,   1.7950200E-06,   1.6076436E-06
     +,   1.4373618E-06,   1.2829145E-06,   1.1431076E-06
     +,   1.0168033E-06,   9.0291343E-07,   8.0041241E-07
     +,   7.0834108E-07,   6.2579852E-07,   5.5193624E-07
     +,   4.8596451E-07,   4.2715484E-07,   3.7482647E-07
     +,   3.2835052E-07,   2.8715078E-07,   2.5069727E-07
     +,   2.1850165E-07,   1.9011821E-07,   1.6514255E-07
     +,   1.4320641E-07,   1.2397459E-07,   1.0714388E-07
     +,   9.2441852E-08,   7.9623078E-08,   6.8466100E-08
     +,   5.8772901E-08,   5.0367131E-08,   4.3090676E-08
     +,   3.6803037E-08,   3.1379795E-08,   2.6710641E-08
     +,   2.2697817E-08,   1.9255125E-08,   1.6306970E-08
     +,   1.3786913E-08,   1.1636552E-08,   9.8048938E-09
     +,   8.2475804E-09,   6.9258035E-09,   5.8060112E-09
     +,   4.8589710E-09,   4.0595105E-09,   3.3857941E-09
     +,   2.8190923E-09,   2.3432272E-09,   1.9443716E-09
     +,   1.6106427E-09,   1.3319197E-09,   1.0995440E-09
     +,   9.0614855E-10,   7.4549222E-10,   6.1226257E-10
     +,   5.0198101E-10,   4.1085280E-10,   3.3569006E-10
     +,   2.7380317E-10,   2.2294132E-10,   1.8121245E-10
     +,   1.4704024E-10,   1.1910471E-10,   9.6309696E-11
     +,   7.7741605E-11,   6.2644667E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_haonly_zz_mass = Yx/0.00233882352941176
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.9032024E-13,   2.9780597E-13
     +,   4.6363472E-13,   7.1814527E-13,   1.1067302E-12
     +,   1.6969339E-12,   2.5886975E-12,   3.9290815E-12
     +,   5.9332227E-12,   8.9142652E-12,   1.3325176E-11
     +,   1.9817684E-11,   2.9324088E-11,   4.3170485E-11
     +,   6.3232586E-11,   9.2147893E-11,   1.3360435E-10
     +,   1.9272815E-10,   2.7660421E-10,   3.9496822E-10
     +,   5.6111699E-10,   7.9310852E-10,   1.1153121E-09
     +,   1.5604581E-09,   2.1721447E-09,   3.0082501E-09
     +,   4.1449932E-09,   5.6822165E-09,   7.7498887E-09
     +,   1.0516137E-08,   1.4197072E-08,   1.9068786E-08
     +,   2.5481693E-08,   3.3877651E-08,   4.4810271E-08
     +,   5.8968570E-08,   7.7204213E-08,   1.0056266E-07
     +,   1.3032040E-07,   1.6801958E-07,   2.1551817E-07
     +,   2.7503114E-07,   3.4918284E-07,   4.4105875E-07
     +,   5.5425767E-07,   6.9294379E-07,   8.6189550E-07
     +,   1.0665497E-06,   1.3130368E-06,   1.6082053E-06
     +,   1.9596318E-06,   2.3756118E-06,   2.8651209E-06
     +,   3.4378027E-06,   4.1037833E-06,   4.8736820E-06
     +,   5.7583575E-06,   6.7687643E-06,   7.9157253E-06
     +,   9.2096643E-06,   1.0660325E-05,   1.2276481E-05
     +,   1.4065461E-05,   1.6033047E-05,   1.8183029E-05
     +,   2.0516614E-05,   2.3032646E-05,   2.5726724E-05
     +,   2.8591645E-05,   3.1616561E-05,   3.4787667E-05
     +,   3.8087452E-05,   4.1495667E-05,   4.4988719E-05
     +,   4.8540795E-05,   5.2124007E-05,   5.5708744E-05
     +,   5.9264512E-05,   6.2760955E-05,   6.6168344E-05
     +,   6.9458074E-05,   7.2604176E-05,   7.5583259E-05
     +,   7.8375931E-05,   8.0966638E-05,   8.3344821E-05
     +,   8.5504420E-05,   8.7444765E-05,   8.9169756E-05
     +,   9.0688074E-05,   9.2012604E-05,   9.3159579E-05
     +,   9.4147959E-05,   9.4998606E-05,   9.5733129E-05
     +,   9.6372823E-05,   9.6937831E-05,   9.7445947E-05
     +,   9.7911943E-05,   9.8346638E-05,   9.8756507E-05
     +,   9.9143224E-05,   9.9503632E-05,   9.9829762E-05
     +,   1.0010935E-04,   1.0032626E-04,   1.0046132E-04
     +,   1.0049331E-04,   1.0040004E-04,   1.0015936E-04
     +,   9.9750505E-05,   9.9155041E-05,   9.8358098E-05
     +,   9.7349097E-05,   9.6122654E-05,   9.4678835E-05
     +,   9.3023831E-05,   9.1169539E-05,   8.9133850E-05
     +,   8.6939741E-05,   8.4614781E-05,   8.2190549E-05
     +,   7.9701371E-05,   7.7183176E-05,   7.4672447E-05
     +,   7.2205425E-05,   6.9816400E-05,   6.7537418E-05
     +,   6.5396787E-05,   6.3419080E-05,   6.1624043E-05
     +,   6.0026890E-05,   5.8637852E-05,   5.7462719E-05
     +,   5.6502926E-05,   5.5756271E-05,   5.5217639E-05
     +,   5.4879747E-05,   5.4733955E-05,   5.4771230E-05
     +,   5.4982975E-05,   5.5361685E-05,   5.5901695E-05
     +,   5.6599674E-05,   5.7454683E-05,   5.8468566E-05
     +,   5.9645648E-05,   6.0992279E-05,   6.2516439E-05
     +,   6.4226959E-05,   6.6132648E-05,   6.8241090E-05
     +,   7.0557719E-05,   7.3084826E-05,   7.5820448E-05
     +,   7.8757228E-05,   8.1881757E-05,   8.5174193E-05
     +,   8.8607747E-05,   9.2148279E-05,   9.5755080E-05
     +,   9.9381141E-05,   1.0297367E-04,   1.0647540E-04
     +,   1.0982605E-04,   1.1296367E-04,   1.1582598E-04
     +,   1.1835239E-04,   1.2048581E-04,   1.2217407E-04
     +,   1.2337149E-04,   1.2404025E-04,   1.2415176E-04
     +,   1.2368715E-04,   1.2263820E-04,   1.2100721E-04
     +,   1.1880719E-04,   1.1606135E-04,   1.1280255E-04
     +,   1.0907195E-04,   1.0491809E-04,   1.0039569E-04
     +,   9.5564086E-05,   9.0485271E-05,   8.5222629E-05
     +,   7.9839810E-05,   7.4399039E-05,   6.8959329E-05
     +,   6.3575870E-05,   5.8299534E-05,   5.3175143E-05
     +,   4.8241476E-05,   4.3531298E-05,   3.9070885E-05
     +,   3.4879806E-05,   3.0971543E-05,   2.7354063E-05
     +,   2.4029980E-05,   2.0996977E-05,   1.8248646E-05
     +,   1.5775302E-05,   1.3564409E-05,   1.1601094E-05
     +,   9.8689352E-06,   8.3506411E-06,   7.0282317E-06
     +,   5.8836495E-06,   4.8991910E-06,   4.0577188E-06
     +,   3.3428489E-06,   2.7392134E-06,   2.2326049E-06
     +,   1.8099939E-06,   1.4595475E-06,   1.1706616E-06
     +,   9.3393999E-07,   7.4111045E-07,   5.8495078E-07
     +,   4.5922289E-07,   3.5859227E-07,   2.7851380E-07
     +,   2.1515712E-07,   1.6532165E-07,   1.2634878E-07
     +,   9.6044843E-08,   7.2616068E-08,   5.4607131E-08
     +,   4.0843744E-08,   3.0384726E-08,   2.2481869E-08
     +,   1.6544680E-08,   1.2109769E-08,   8.8157250E-09
     +,   6.3829000E-09,   4.5964508E-09,   3.2920360E-09
     +,   2.3449704E-09,   1.6612784E-09,   1.1705307E-09
     +,   8.2026019E-10,   5.7166372E-10,   3.9623504E-10
     +,   2.7314354E-10,   1.8726110E-10,   1.2767760E-10
     +,   8.6575656E-11,   5.8383950E-11,   3.9156144E-11
     +,   2.6116090E-11,   1.7323138E-11,   1.1427402E-11
     +,   7.4965728E-12,   4.8907562E-12,   3.1731594E-12
     +,   2.0473913E-12,   1.3137014E-12,   8.3826538E-13
     +,   5.3193913E-13,   3.3568165E-13,   2.1065499E-13
     +,   1.3146144E-13,   8.1585407E-14,   5.0350705E-14
     +,   3.0900775E-14,   1.8858902E-14,   1.1445577E-14
     +,   6.9075651E-15,   4.1455622E-15,   2.4741112E-15
     +,   1.4683256E-15,   8.6653630E-16,   5.0852920E-16
     +,   2.9676795E-16,   1.7221940E-16,   9.9380589E-17
     +,   5.7028048E-17,   3.2540819E-17,   1.8464402E-17
     +,   1.0418186E-17,   5.8453735E-18,   3.2612282E-18
     +,   1.8093035E-18,   9.9813537E-19,   5.4755396E-19
     +,   2.9868246E-19,   1.6201318E-19,   8.7386210E-20
     +,   4.6867863E-20,   2.4995757E-20,   1.3255533E-20
     +,   6.9901083E-21,   3.6652971E-21,   1.9111245E-21
     +,   9.9084585E-22,   5.1083017E-22,   2.6186946E-22
     +,   1.3348848E-22,   6.7661168E-23,   3.4102391E-23
     +,   1.7090943E-23,   8.5172144E-24
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_eez_mass = Yx/0.002499
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   4.8660409E-38,   2.2095302E-37,   9.8848410E-37
     +,   4.3569730E-36,   1.8920919E-35,   8.0955263E-35
     +,   3.4126890E-34,   1.4173938E-33,   5.8000695E-33
     +,   2.3384136E-32,   9.2886294E-32,   3.6351925E-31
     +,   1.4016848E-30,   5.3249695E-30,   1.9930633E-29
     +,   7.3500245E-29,   2.6704456E-28,   9.5594399E-28
     +,   3.3715399E-27,   1.1715649E-26,   4.0110052E-26
     +,   1.3529514E-25,   4.4963321E-25,   1.4722449E-24
     +,   4.7494921E-24,   1.5095871E-23,   4.7273345E-23
     +,   1.4585454E-22,   4.4336941E-22,   1.3278592E-21
     +,   3.9183093E-21,   1.1391328E-20,   3.2629125E-20
     +,   9.2082825E-20,   2.5603481E-19,   7.0139860E-19
     +,   1.8931118E-18,   5.0342307E-18,   1.3189691E-17
     +,   3.4047217E-17,   8.6591272E-17,   2.1697620E-16
     +,   5.3566782E-16,   1.3029377E-15,   3.1224212E-15
     +,   7.3725417E-15,   1.7150437E-14,   3.9308390E-14
     +,   8.8764811E-14,   1.9748817E-13,   4.3290087E-13
     +,   9.3493128E-13,   1.9893737E-12,   4.1706400E-12
     +,   8.6144069E-12,   1.7530472E-11,   3.5149311E-11
     +,   6.9434541E-11,   1.3514170E-10,   2.5914276E-10
     +,   4.8960180E-10,   9.1134689E-10,   1.6713931E-09
     +,   3.0200236E-09,   5.3764473E-09,   9.4301376E-09
     +,   1.6296196E-08,   2.7746445E-08,   4.6545058E-08
     +,   7.6926817E-08,   1.2526439E-07,   2.0096928E-07
     +,   3.1766589E-07,   4.9472442E-07,   7.5909310E-07
     +,   1.1475673E-06,   1.7092312E-06,   2.5082702E-06
     +,   3.6265026E-06,   5.1659740E-06,   7.2503130E-06
     +,   1.0025519E-05,   1.3658618E-05,   1.8333778E-05
     +,   2.4245910E-05,   3.1591502E-05,   4.0555649E-05
     +,   5.1294919E-05,   6.3921339E-05,   7.8480145E-05
     +,   9.4934032E-05,   1.1314282E-04,   1.3285564E-04
     +,   1.5370092E-04,   1.7519461E-04,   1.9674757E-04
     +,   2.1769320E-04,   2.3731719E-04,   2.5489536E-04
     +,   2.6973954E-04,   2.8124292E-04,   2.8892068E-04
     +,   2.9244466E-04,   2.9166965E-04,   2.8664488E-04
     +,   2.7761256E-04,   2.6499419E-04,   2.4936226E-04
     +,   2.3140811E-04,   2.1189739E-04,   1.9163275E-04
     +,   1.7140969E-04,   1.5198375E-04,   1.3404443E-04
     +,   1.1819408E-04,   1.0493531E-04,   9.4667397E-05
     +,   8.7686632E-05,   8.4186438E-05,   8.4262057E-05
     +,   8.7911445E-05,   9.5035233E-05,   1.0543579E-04
     +,   1.1881251E-04,   1.3476226E-04,   1.5277641E-04
     +,   1.7224973E-04,   1.9249086E-04,   2.1274058E-04
     +,   2.3220120E-04,   2.5007260E-04,   2.6559085E-04
     +,   2.7806914E-04,   2.8693970E-04,   2.9178904E-04
     +,   2.9238258E-04,   2.8867944E-04,   2.8083305E-04
     +,   2.6917789E-04,   2.5420511E-04,   2.3652700E-04
     +,   2.1683336E-04,   1.9584723E-04,   1.7428309E-04
     +,   1.5280618E-04,   1.3199961E-04,   1.1234347E-04
     +,   9.4203788E-05,   7.7828197E-05,   6.3350672E-05
     +,   5.0805163E-05,   4.0143295E-05,   3.1250998E-05
     +,   2.3969362E-05,   1.8113153E-05,   1.3485941E-05
     +,   9.8926776E-06,   7.1496938E-06,   5.0910348E-06
     +,   3.5717003E-06,   2.4688204E-06,   1.6812965E-06
     +,   1.1280905E-06,   7.4575246E-07,   4.8572576E-07
     +,   3.1169270E-07,   1.9706695E-07,   1.2275713E-07
     +,   7.5338768E-08,   4.5554902E-08,   2.7139627E-08
     +,   1.5930100E-08,   9.2123660E-09,   5.2489031E-09
     +,   2.9465925E-09,   1.6297321E-09,   8.8807500E-10
     +,   4.7679150E-10,   2.5220936E-10,   1.3144369E-10
     +,   6.7492241E-11,   3.4144708E-11,   1.7019173E-11
     +,   8.3577355E-12,   4.0437415E-12,   1.9276815E-12
     +,   9.0538205E-13,   4.1895095E-13,   1.9100292E-13
     +,   8.5797011E-14,   3.7970956E-14,   1.6556326E-14
     +,   7.1124933E-15,   3.0104817E-15,   1.2554440E-15
     +,   5.1581035E-16,   2.0880531E-16,   8.3279565E-17
     +,   3.2724096E-17,   1.2668977E-17,   4.8325339E-18
     +,   1.8161623E-18,   6.7245508E-19,   2.4531220E-19
     +,   8.8172943E-20,   3.1224491E-20,   1.0893965E-20
     +,   3.7447436E-21,   1.2682901E-21,   4.2321615E-22
     +,   1.3913449E-22,   4.5067945E-23,   1.4382947E-23
     +,   4.5222572E-24,   1.4009033E-24,   4.2758559E-25
     +,   1.2858298E-25,   3.8095424E-26,   1.1120072E-26
     +,   3.1981918E-27,   9.0624768E-28,   2.5299767E-28
     +,   6.9587568E-29,   1.8858644E-29,   5.0354100E-30
     +,   1.3246051E-30,   3.4332337E-31,   8.7672665E-32
     +,   2.2057213E-32,   5.4673998E-33,   1.3353028E-33
     +,   3.2130995E-34,   7.6171207E-35,   1.7791111E-35
     +,   4.0943403E-36,   9.2833983E-37,   2.0737464E-37
     +,   4.5640437E-38,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_qq_mass = Yx/0.002807
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1947801E-10,   1.5763280E-10
     +,   2.0730125E-10,   2.7173977E-10,   3.5505962E-10
     +,   4.6242926E-10,   6.0032451E-10,   7.7682422E-10
     +,   1.0019697E-09,   1.2882024E-09,   1.6508602E-09
     +,   2.1087878E-09,   2.6850440E-09,   3.4077423E-09
     +,   4.3110000E-09,   5.4360827E-09,   6.8326713E-09
     +,   8.5603338E-09,   1.0690250E-08,   1.3307034E-08
     +,   1.6510912E-08,   2.0420082E-08,   2.5173215E-08
     +,   3.0932803E-08,   3.7887283E-08,   4.6255742E-08
     +,   5.6290411E-08,   6.8280990E-08,   8.2558579E-08
     +,   9.9499594E-08,   1.1953013E-07,   1.4313001E-07
     +,   1.7083688E-07,   2.0324985E-07,   2.4103306E-07
     +,   2.8491942E-07,   3.3571177E-07,   3.9428457E-07
     +,   4.6158979E-07,   5.3864454E-07,   6.2654561E-07
     +,   7.2645412E-07,   8.3959679E-07,   9.6725910E-07
     +,   1.1107793E-06,   1.2715369E-06,   1.4509452E-06
     +,   1.6504387E-06,   1.8714600E-06,   2.1154465E-06
     +,   2.3838188E-06,   2.6779658E-06,   2.9992275E-06
     +,   3.3489137E-06,   3.7282346E-06,   4.1383787E-06
     +,   4.5804513E-06,   5.0555109E-06,   5.5645805E-06
     +,   6.1086726E-06,   6.6888256E-06,   7.3061551E-06
     +,   7.9618585E-06,   8.6573773E-06,   9.3944254E-06
     +,   1.0174997E-05,   1.1001644E-05,   1.1877343E-05
     +,   1.2805846E-05,   1.3791537E-05,   1.4839746E-05
     +,   1.5956604E-05,   1.7149348E-05,   1.8426075E-05
     +,   1.9795987E-05,   2.1269274E-05,   2.2856879E-05
     +,   2.4570449E-05,   2.6422254E-05,   2.8424807E-05
     +,   3.0590338E-05,   3.2930860E-05,   3.5457146E-05
     +,   3.8178860E-05,   4.1103329E-05,   4.4235738E-05
     +,   4.7577767E-05,   5.1127929E-05,   5.4880136E-05
     +,   5.8824127E-05,   6.2944833E-05,   6.7221867E-05
     +,   7.1629773E-05,   7.6138487E-05,   8.0713362E-05
     +,   8.5315318E-05,   8.9902547E-05,   9.4430397E-05
     +,   9.8853612E-05,   1.0312640E-04,   1.0720513E-04
     +,   1.1104845E-04,   1.1461997E-04,   1.1788851E-04
     +,   1.2083028E-04,   1.2342934E-04,   1.2567843E-04
     +,   1.2757945E-04,   1.2914374E-04,   1.3039153E-04
     +,   1.3135131E-04,   1.3205899E-04,   1.3255642E-04
     +,   1.3289003E-04,   1.3310902E-04,   1.3326383E-04
     +,   1.3340460E-04,   1.3357952E-04,   1.3383404E-04
     +,   1.3420997E-04,   1.3474521E-04,   1.3547379E-04
     +,   1.3642636E-04,   1.3763092E-04,   1.3911385E-04
     +,   1.4090039E-04,   1.4301593E-04,   1.4548567E-04
     +,   1.4833517E-04,   1.5158874E-04,   1.5526880E-04
     +,   1.5939280E-04,   1.6397185E-04,   1.6900679E-04
     +,   1.7448669E-04,   1.8038640E-04,   1.8666525E-04
     +,   1.9326743E-04,   2.0012446E-04,   2.0715795E-04
     +,   2.1428434E-04,   2.2142091E-04,   2.2849343E-04
     +,   2.3544155E-04,   2.4222407E-04,   2.4882413E-04
     +,   2.5524964E-04,   2.6153214E-04,   2.6772253E-04
     +,   2.7388491E-04,   2.8008706E-04,   2.8638949E-04
     +,   2.9283657E-04,   2.9944716E-04,   3.0620827E-04
     +,   3.1307212E-04,   3.1995811E-04,   3.2675971E-04
     +,   3.3335539E-04,   3.3962232E-04,   3.4545429E-04
     +,   3.5077881E-04,   3.5557098E-04,   3.5986517E-04
     +,   3.6375999E-04,   3.6741339E-04,   3.7103207E-04
     +,   3.7485120E-04,   3.7910856E-04,   3.8401576E-04
     +,   3.8972771E-04,   3.9631789E-04,   4.0376052E-04
     +,   4.1192194E-04,   4.2056307E-04,   4.2935472E-04
     +,   4.3790092E-04,   4.4576701E-04,   4.5251317E-04
     +,   4.5772467E-04,   4.6103745E-04,   4.6215695E-04
     +,   4.6086957E-04,   4.5704652E-04,   4.5064063E-04
     +,   4.4168148E-04,   4.3026608E-04,   4.1655020E-04
     +,   4.0074016E-04,   3.8308781E-04,   3.6388109E-04
     +,   3.4343856E-04,   3.2210344E-04,   3.0023322E-04
     +,   2.7818716E-04,   2.5631537E-04,   2.3494748E-04
     +,   2.1437841E-04,   1.9485664E-04,   1.7657761E-04
     +,   1.5968026E-04,   1.4424510E-04,   1.3029604E-04
     +,   1.1780802E-04,   1.0671608E-04,   9.6922915E-05
     +,   8.8310291E-05,   8.0749131E-05,   7.4107265E-05
     +,   6.8255933E-05,   6.3075560E-05,   5.8459234E-05
     +,   5.4314129E-05,   5.0561550E-05,   4.7136728E-05
     +,   4.3987653E-05,   4.1073086E-05,   3.8360555E-05
     +,   3.5824760E-05,   3.3446155E-05,   3.1209060E-05
     +,   2.9100793E-05,   2.7110973E-05,   2.5230756E-05
     +,   2.3452332E-05,   2.1768803E-05,   2.0174164E-05
     +,   1.8663135E-05,   1.7231012E-05,   1.5873786E-05
     +,   1.4588168E-05,   1.3371475E-05,   1.2221464E-05
     +,   1.1136351E-05,   1.0114794E-05,   9.1555894E-06
     +,   8.2576626E-06,   7.4200238E-06,   6.6416151E-06
     +,   5.9211861E-06,   5.2572987E-06,   4.6483347E-06
     +,   4.0924197E-06,   3.5874036E-06,   3.1309107E-06
     +,   2.7203982E-06,   2.3531534E-06,   2.0263194E-06
     +,   1.7369654E-06,   1.4821595E-06,   1.2589526E-06
     +,   1.0644509E-06,   8.9586200E-07,   7.5050593E-07
     +,   6.2583450E-07,   5.1945938E-07,   4.2917213E-07
     +,   3.5293962E-07,   2.8890469E-07,   2.3539101E-07
     +,   1.9090122E-07,   1.5410387E-07,   1.2382297E-07
     +,   9.9030331E-08,   7.8835221E-08,   6.2467578E-08
     +,   4.9268291E-08,   3.8677808E-08,   3.0223283E-08
     +,   2.3507338E-08,   1.8198808E-08,   1.4023750E-08
     +,   1.0756493E-08,   8.2121892E-09,   6.2405823E-09
     +,   4.7203783E-09,   3.5539045E-09,   2.6633056E-09
     +,   1.9866115E-09,   1.4749972E-09,   1.0900494E-09
     +,   8.0184032E-10,   5.8709232E-10,   4.2786930E-10
     +,   3.1037917E-10,   2.2410977E-10,   1.6106821E-10
     +,   1.1522229E-10,   8.2044420E-11,   5.8148531E-11
     +,   4.1021801E-11,   2.8804997E-11,   2.0132921E-11
     +,   1.4006272E-11,   9.6989560E-12,   6.6850366E-12
     +,   4.5863764E-12,   3.1319292E-12,   2.1288314E-12
     +,   1.4402774E-12,   9.6992488E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_ww_mass = Yx/0.00694523666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_asha_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0431766E-07,   2.3121383E-07
     +,   2.6120009E-07,   2.9456695E-07,   3.3162371E-07
     +,   3.7269837E-07,   4.1813794E-07,   4.6830783E-07
     +,   5.2359053E-07,   5.8438883E-07,   6.5111948E-07
     +,   7.2421506E-07,   8.0412246E-07,   8.9130066E-07
     +,   9.8621899E-07,   1.0893539E-06,   1.2011877E-06
     +,   1.3222042E-06,   1.4528861E-06,   1.5937113E-06
     +,   1.7451484E-06,   1.9076522E-06,   2.0816585E-06
     +,   2.2675890E-06,   2.4658193E-06,   2.6767113E-06
     +,   2.9005771E-06,   3.1376869E-06,   3.3882620E-06
     +,   3.6524668E-06,   3.9304068E-06,   4.2221209E-06
     +,   4.5275783E-06,   4.8466741E-06,   5.1792222E-06
     +,   5.5249579E-06,   5.8835335E-06,   6.2545096E-06
     +,   6.6373855E-06,   7.0315396E-06,   7.4363129E-06
     +,   7.8509465E-06,   8.2746255E-06,   8.7064755E-06
     +,   9.1455868E-06,   9.5910136E-06,   1.0041811E-05
     +,   1.0497043E-05,   1.0955826E-05,   1.1417344E-05
     +,   1.1880899E-05,   1.2345939E-05,   1.2812109E-05
     +,   1.3279337E-05,   1.3747809E-05,   1.4218135E-05
     +,   1.4691343E-05,   1.5168980E-05,   1.5653202E-05
     +,   1.6146838E-05,   1.6653496E-05,   1.7177654E-05
     +,   1.7724709E-05,   1.8301160E-05,   1.8914639E-05
     +,   1.9573954E-05,   2.0289304E-05,   2.1072163E-05
     +,   2.1935544E-05,   2.2893812E-05,   2.3962917E-05
     +,   2.5160125E-05,   2.6504245E-05,   2.8015187E-05
     +,   2.9714092E-05,   3.1623043E-05,   3.3764587E-05
     +,   3.6161477E-05,   3.8836366E-05,   4.1811210E-05
     +,   4.5106277E-05,   4.8740156E-05,   5.2728130E-05
     +,   5.7082256E-05,   6.1809536E-05,   6.6912078E-05
     +,   7.2385024E-05,   7.8217097E-05,   8.4388492E-05
     +,   9.0871501E-05,   9.7629803E-05,   1.0461772E-04
     +,   1.1178080E-04,   1.1905679E-04,   1.2637592E-04
     +,   1.3366123E-04,   1.4083183E-04,   1.4780245E-04
     +,   1.5448742E-04,   1.6080096E-04,   1.6666102E-04
     +,   1.7198999E-04,   1.7671843E-04,   1.8078538E-04
     +,   1.8414161E-04,   1.8675011E-04,   1.8858703E-04
     +,   1.8964258E-04,   1.8992096E-04,   1.8943983E-04
     +,   1.8822955E-04,   1.8633160E-04,   1.8379765E-04
     +,   1.8068678E-04,   1.7706446E-04,   1.7299959E-04
     +,   1.6856329E-04,   1.6382601E-04,   1.5885696E-04
     +,   1.5372147E-04,   1.4848028E-04,   1.4318891E-04
     +,   1.3789686E-04,   1.3264680E-04,   1.2747504E-04
     +,   1.2241237E-04,   1.1748337E-04,   1.1270879E-04
     +,   1.0810534E-04,   1.0368827E-04,   9.9472127E-05
     +,   9.5473821E-05,   9.1713911E-05,   8.8220164E-05
     +,   8.5029409E-05,   8.2190789E-05,   7.9768062E-05
     +,   7.7841578E-05,   7.6508943E-05,   7.5885284E-05
     +,   7.6101438E-05,   7.7300443E-05,   7.9632875E-05
     +,   8.3250918E-05,   8.8301858E-05,   9.4923889E-05
     +,   1.0324430E-04,   1.1338202E-04,   1.2545691E-04
     +,   1.3960595E-04,   1.5600226E-04,   1.7487272E-04
     +,   1.9651462E-04,   2.2130625E-04,   2.4971314E-04
     +,   2.8230032E-04,   3.1977423E-04,   3.6306577E-04
     +,   4.1344849E-04,   4.7265788E-04,   5.4296199E-04
     +,   6.2705966E-04,   7.2773825E-04,   8.4730197E-04
     +,   9.8686724E-04,   1.1457136E-03,   1.3209445E-03
     +,   1.5076750E-03,   1.6997857E-03,   1.8910622E-03
     +,   2.0764137E-03,   2.2527012E-03,   2.4186787E-03
     +,   2.5737297E-03,   2.7157112E-03,   2.8387760E-03
     +,   2.9324389E-03,   2.9829973E-03,   2.9773768E-03
     +,   2.9080904E-03,   2.7771250E-03,   2.5967900E-03
     +,   2.3869779E-03,   2.1699229E-03,   1.9647551E-03
     +,   1.7838032E-03,   1.6315051E-03,   1.5055860E-03
     +,   1.3994944E-03,   1.3050439E-03,   1.2146375E-03
     +,   1.1228489E-03,   1.0272418E-03,   9.2838478E-04
     +,   8.2916161E-04,   7.3362287E-04,   6.4575282E-04
     +,   5.6848623E-04,   5.0322060E-04,   4.4984647E-04
     +,   4.0713054E-04,   3.7323750E-04,   3.4620837E-04
     +,   3.2429135E-04,   3.0609482E-04,   2.9059668E-04
     +,   2.7708075E-04,   2.6504695E-04,   2.5412894E-04
     +,   2.4403633E-04,   2.3452478E-04,   2.2538249E-04
     +,   2.1642722E-04,   2.0750715E-04,   1.9850401E-04
     +,   1.8933494E-04,   1.7995152E-04,   1.7033778E-04
     +,   1.6050786E-04,   1.5050276E-04,   1.4038390E-04
     +,   1.3022854E-04,   1.2012499E-04,   1.1016610E-04
     +,   1.0044361E-04,   9.1043941E-05,   8.2045277E-05
     +,   7.3513853E-05,   6.5501663E-05,   5.8046167E-05
     +,   5.1170766E-05,   4.4884891E-05,   3.9184877E-05
     +,   3.4056236E-05,   2.9475914E-05,   2.5413321E-05
     +,   2.1832888E-05,   1.8696093E-05,   1.5962805E-05
     +,   1.3592557E-05,   1.1545917E-05,   9.7854490E-06
     +,   8.2761671E-06,   6.9858429E-06,   5.8853470E-06
     +,   4.9487271E-06,   4.1530379E-06,   3.4781369E-06
     +,   2.9065311E-06,   2.4231622E-06,   2.0150273E-06
     +,   1.6709887E-06,   1.3815376E-06,   1.1385403E-06
     +,   9.3502990E-07,   7.6505137E-07,   6.2351887E-07
     +,   5.0607451E-07,   4.0897501E-07,   3.2901417E-07
     +,   2.6345057E-07,   2.0993704E-07,   1.6646503E-07
     +,   1.3132454E-07,   1.0306687E-07,   8.0463550E-08
     +,   6.2481007E-08,   4.8254559E-08,   3.7063650E-08
     +,   2.8310787E-08,   2.1504336E-08,   1.6242698E-08
     +,   1.2199420E-08,   9.1107184E-09,   6.7652737E-09
     +,   4.9950191E-09,   3.6668468E-09,   2.6764253E-09
     +,   1.9422748E-09,   1.4014083E-09,   1.0053217E-09
     +,   7.1703127E-10,   5.0845500E-10,   3.5847253E-10
     +,   2.5126795E-10,   1.7510764E-10,   1.2132612E-10
     +,   8.3575341E-11,   5.7238266E-11,   3.8973380E-11
     +,   2.6383624E-11,   1.7757155E-11,   1.1882171E-11
     +,   7.9047897E-12,   5.2284002E-12,   3.4380992E-12
     +,   2.2477690E-12,   1.4610191E-12,   9.4415686E-13
     +,   6.0660157E-13,   3.8747833E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_asha_zz_mass = Yx/0.0196390303030303
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4639777E-10,   4.5364026E-10
     +,   5.9224048E-10,   7.7079054E-10,   1.0000635E-09
     +,   1.2935195E-09,   1.6679149E-09,   2.1440341E-09
     +,   2.7475524E-09,   3.5101122E-09,   4.4705128E-09
     +,   5.6761773E-09,   7.1848518E-09,   9.0666132E-09
     +,   1.1406132E-08,   1.4305400E-08,   1.7886707E-08
     +,   2.2296232E-08,   2.7707966E-08,   3.4328203E-08
     +,   4.2400650E-08,   5.2211973E-08,   6.4097883E-08
     +,   7.8451116E-08,   9.5726421E-08,   1.1645218E-07
     +,   1.4123621E-07,   1.7077659E-07,   2.0587125E-07
     +,   2.4742849E-07,   2.9647674E-07,   3.5417713E-07
     +,   4.2183200E-07,   5.0089778E-07,   5.9299322E-07
     +,   6.9991108E-07,   8.2362362E-07,   9.6628901E-07
     +,   1.1302690E-06,   1.3181024E-06,   1.5325434E-06
     +,   1.7765276E-06,   2.0531807E-06,   2.3658019E-06
     +,   2.7178519E-06,   3.1129323E-06,   3.5547544E-06
     +,   4.0471155E-06,   4.5938564E-06,   5.1988200E-06
     +,   5.8657974E-06,   6.5984796E-06,   7.4003756E-06
     +,   8.2748156E-06,   9.2247301E-06,   1.0252770E-05
     +,   1.1361069E-05,   1.2551233E-05,   1.3824258E-05
     +,   1.5180432E-05,   1.6619273E-05,   1.8139477E-05
     +,   1.9738723E-05,   2.1413847E-05,   2.3160683E-05
     +,   2.4973833E-05,   2.6847067E-05,   2.8772844E-05
     +,   3.0742805E-05,   3.2747317E-05,   3.4776025E-05
     +,   3.6817422E-05,   3.8859449E-05,   4.0889099E-05
     +,   4.2893007E-05,   4.4857399E-05,   4.6768135E-05
     +,   4.8611055E-05,   5.0372255E-05,   5.2038165E-05
     +,   5.3595668E-05,   5.5032619E-05,   5.6337678E-05
     +,   5.7500907E-05,   5.8513597E-05,   5.9368787E-05
     +,   6.0061135E-05,   6.0587299E-05,   6.0945862E-05
     +,   6.1137544E-05,   6.1165178E-05,   6.1033741E-05
     +,   6.0750350E-05,   6.0324164E-05,   5.9766280E-05
     +,   5.9089645E-05,   5.8308789E-05,   5.7439702E-05
     +,   5.6499481E-05,   5.5506243E-05,   5.4478547E-05
     +,   5.3435429E-05,   5.2395757E-05,   5.1378225E-05
     +,   5.0400791E-05,   4.9480503E-05,   4.8633279E-05
     +,   4.7873629E-05,   4.7214395E-05,   4.6666668E-05
     +,   4.6239751E-05,   4.5940968E-05,   4.5775800E-05
     +,   4.5747882E-05,   4.5859146E-05,   4.6109992E-05
     +,   4.6499441E-05,   4.7025489E-05,   4.7685207E-05
     +,   4.8475140E-05,   4.9391587E-05,   5.0430717E-05
     +,   5.1588879E-05,   5.2862873E-05,   5.4249998E-05
     +,   5.5748049E-05,   5.7355570E-05,   5.9071492E-05
     +,   6.0895414E-05,   6.2826963E-05,   6.4866086E-05
     +,   6.7012195E-05,   6.9264497E-05,   7.1621034E-05
     +,   7.4078918E-05,   7.6633849E-05,   7.9279554E-05
     +,   8.2007915E-05,   8.4808766E-05,   8.7669912E-05
     +,   9.0576679E-05,   9.3512353E-05,   9.6458403E-05
     +,   9.9394667E-05,   1.0229923E-04,   1.0514942E-04
     +,   1.0792188E-04,   1.1059290E-04,   1.1313894E-04
     +,   1.1553722E-04,   1.1776605E-04,   1.1980488E-04
     +,   1.2163501E-04,   1.2323973E-04,   1.2460456E-04
     +,   1.2571717E-04,   1.2656774E-04,   1.2714895E-04
     +,   1.2745579E-04,   1.2748563E-04,   1.2723818E-04
     +,   1.2671520E-04,   1.2592057E-04,   1.2486010E-04
     +,   1.2354132E-04,   1.2197347E-04,   1.2016738E-04
     +,   1.1813545E-04,   1.1589131E-04,   1.1344995E-04
     +,   1.1082767E-04,   1.0804203E-04,   1.0511142E-04
     +,   1.0205519E-04,   9.8893834E-05,   9.5648204E-05
     +,   9.2339666E-05,   8.8990106E-05,   8.5621410E-05
     +,   8.2255159E-05,   7.8912431E-05,   7.5613840E-05
     +,   7.2378971E-05,   6.9225920E-05,   6.6171313E-05
     +,   6.3230153E-05,   6.0415477E-05,   5.7738005E-05
     +,   5.5206179E-05,   5.2826344E-05,   5.0602208E-05
     +,   4.8535116E-05,   4.6624249E-05,   4.4866596E-05
     +,   4.3256976E-05,   4.1788371E-05,   4.0452283E-05
     +,   3.9238806E-05,   3.8136859E-05,   3.7134563E-05
     +,   3.6219568E-05,   3.5379242E-05,   3.4600907E-05
     +,   3.3872129E-05,   3.3181019E-05,   3.2516276E-05
     +,   3.1867447E-05,   3.1225096E-05,   3.0580846E-05
     +,   2.9927451E-05,   2.9258848E-05,   2.8570237E-05
     +,   2.7858012E-05,   2.7119680E-05,   2.6353866E-05
     +,   2.5560264E-05,   2.4739518E-05,   2.3893064E-05
     +,   2.3023074E-05,   2.2132432E-05,   2.1224450E-05
     +,   2.0302838E-05,   1.9371666E-05,   1.8435190E-05
     +,   1.7497698E-05,   1.6563479E-05,   1.5636811E-05
     +,   1.4721815E-05,   1.3822348E-05,   1.2942002E-05
     +,   1.2084127E-05,   1.1251732E-05,   1.0447415E-05
     +,   9.6733984E-06,   8.9316081E-06,   8.2235129E-06
     +,   7.5502089E-06,   6.9124844E-06,   6.3107818E-06
     +,   5.7451812E-06,   5.2154719E-06,   4.7212134E-06
     +,   4.2617162E-06,   3.8360554E-06,   3.4431216E-06
     +,   3.0816877E-06,   2.7503927E-06,   2.4477617E-06
     +,   2.1722515E-06,   1.9222980E-06,   1.6962867E-06
     +,   1.4926019E-06,   1.3096542E-06,   1.1458794E-06
     +,   9.9974409E-07,   8.6977053E-07,   7.5455017E-07
     +,   6.5274196E-07,   5.6307022E-07,   4.8433895E-07
     +,   4.1543547E-07,   3.5532665E-07,   3.0305378E-07
     +,   2.5773721E-07,   2.1857701E-07,   1.8484158E-07
     +,   1.5586909E-07,   1.3106538E-07,   1.0989714E-07
     +,   9.1886577E-08,   7.6609624E-08,   6.3691573E-08
     +,   5.2802090E-08,   4.3650370E-08,   3.5982357E-08
     +,   2.9577528E-08,   2.4243695E-08,   1.9815566E-08
     +,   1.6150237E-08,   1.3125686E-08,   1.0637252E-08
     +,   8.5962304E-09,   6.9270949E-09,   5.5662843E-09
     +,   4.4600905E-09,   3.5636312E-09,   2.8392921E-09
     +,   2.2557505E-09,   1.7870783E-09,   1.4117579E-09
     +,   1.1121107E-09,   8.7357527E-10,   6.8426353E-10
     +,   5.3445470E-10,   4.1626472E-10,   3.2329009E-10
     +,   2.5037231E-10,   1.9335007E-10,   1.4889288E-10
     +,   1.1433195E-10,   8.7545221E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_eez_mass = Yx/0.002499
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.1125441E-29,   2.5139515E-28
     +,   8.7600712E-28,   3.0094042E-27,   1.0192341E-26
     +,   3.4032026E-26,   1.1202689E-25,   3.6356230E-25
     +,   1.1631864E-24,   3.6690067E-24,   1.1409544E-23
     +,   3.4979090E-23,   1.0572294E-22,   3.1503136E-22
     +,   9.2545900E-22,   2.6802855E-21,   7.6529199E-21
     +,   2.1542381E-20,   5.9783419E-20,   1.6356485E-19
     +,   4.4118391E-19,   1.1731986E-18,   3.0756412E-18
     +,   7.9494307E-18,   2.0255527E-17,   5.0883658E-17
     +,   1.2601850E-16,   3.0768824E-16,   7.4064413E-16
     +,   1.7576320E-15,   4.1121455E-15,   9.4848479E-15
     +,   2.1568102E-14,   4.8352130E-14,   1.0686606E-13
     +,   2.3285443E-13,   5.0020789E-13,   1.0593320E-12
     +,   2.2117995E-12,   4.5527102E-12,   9.2389048E-12
     +,   1.8483810E-11,   3.6457282E-11,   7.0892056E-11
     +,   1.3590397E-10,   2.5685457E-10,   4.7859056E-10
     +,   8.7914603E-10,   1.5921358E-09,   2.8426235E-09
     +,   5.0035682E-09,   8.6828287E-09,   1.4854562E-08
     +,   2.5054611E-08,   4.1660890E-08,   6.8295805E-08
     +,   1.1037758E-07,   1.7586873E-07,   2.7625953E-07
     +,   4.2782588E-07,   6.5318733E-07,   9.8317878E-07
     +,   1.4589564E-06,   2.1343885E-06,   3.0784418E-06
     +,   4.3772807E-06,   6.1362589E-06,   8.4804587E-06
     +,   1.1554748E-05,   1.5520949E-05,   2.0554238E-05
     +,   2.6834990E-05,   3.4540313E-05,   4.3829710E-05
     +,   5.4831758E-05,   6.7626963E-05,   8.2229657E-05
     +,   9.8572433E-05,   1.1649409E-04,   1.3572996E-04
     +,   1.5590743E-04,   1.7655556E-04,   1.9711339E-04
     +,   2.1695756E-04,   2.3542647E-04,   2.5186129E-04
     +,   2.6563986E-04,   2.7622038E-04,   2.8317381E-04
     +,   2.8621647E-04,   2.8522915E-04,   2.8026747E-04
     +,   2.7156057E-04,   2.5949680E-04,   2.4460049E-04
     +,   2.2750295E-04,   2.0890358E-04,   1.8953715E-04
     +,   1.7013401E-04,   1.5139414E-04,   1.3395710E-04
     +,   1.1838901E-04,   1.0516663E-04,   9.4676107E-05
     +,   8.7208762E-05,   8.2964543E-05,   8.2054532E-05
     +,   8.4502091E-05,   9.0243746E-05,   9.9128447E-05
     +,   1.1091376E-04,   1.2526585E-04,   1.4175574E-04
     +,   1.5986575E-04,   1.7899313E-04,   1.9846910E-04
     +,   2.1757513E-04,   2.3557578E-04,   2.5174694E-04
     +,   2.6541640E-04,   2.7599826E-04,   2.8302631E-04
     +,   2.8618291E-04,   2.8531795E-04,   2.8045615E-04
     +,   2.7179453E-04,   2.5968597E-04,   2.4461615E-04
     +,   2.2716762E-04,   2.0798534E-04,   1.8773292E-04
     +,   1.6705973E-04,   1.4656257E-04,   1.2676454E-04
     +,   1.0809211E-04,   9.0867587E-05,   7.5308672E-05
     +,   6.1532519E-05,   4.9566210E-05,   3.9362683E-05
     +,   3.0817999E-05,   2.3787499E-05,   1.8101491E-05
     +,   1.3579912E-05,   1.0043955E-05,   7.3237538E-06
     +,   5.2647679E-06,   3.7311740E-06,   2.6069811E-06
     +,   1.7957727E-06,   1.2194968E-06,   8.1645146E-07
     +,   5.3889886E-07,   3.5067518E-07,   2.2496654E-07
     +,   1.4228245E-07,   8.8718203E-08,   5.4537470E-08
     +,   3.3051531E-08,   1.9747681E-08,   1.1632213E-08
     +,   6.7549362E-09,   3.8672434E-09,   2.1827848E-09
     +,   1.2146224E-09,   6.6632150E-10,   3.6036926E-10
     +,   1.9215038E-10,   1.0100807E-10,   5.2345853E-11
     +,   2.6744214E-11,   1.3471248E-11,   6.6897213E-12
     +,   3.2750499E-12,   1.5807350E-12,   7.5217957E-13
     +,   3.5285433E-13,   1.6318830E-13,   7.4407142E-14
     +,   3.3447342E-14,   1.4822421E-14,   6.4758439E-15
     +,   2.7893780E-15,   1.1845104E-15,   4.9588300E-16
     +,   2.0466337E-16,   8.3279009E-17,   3.3408081E-17
     +,   1.3212213E-17,   5.1515055E-18,   1.9802158E-18
     +,   7.5041329E-19,   2.8035550E-19,   1.0326457E-19
     +,   3.7498521E-20,   1.3424120E-20,   4.7378143E-21
     +,   1.6485571E-21,   5.6552754E-22,   1.9125265E-22
     +,   6.3764895E-23,   2.0960078E-23,   6.7924490E-24
     +,   2.1700284E-24,   6.8350207E-25,   2.1224448E-25
     +,   6.4973851E-26,   1.9609190E-26,   5.8347115E-27
     +,   1.7115895E-27,   4.9497377E-28,   1.4111998E-28
     +,   3.9667389E-29,   1.0992569E-29,   3.0030809E-30
     +,   8.0882654E-31,   2.1477518E-31,   5.6225511E-32
     +,   1.4510639E-32,   3.6921422E-33,   9.2617035E-34
     +,   2.2903605E-34,   5.5839391E-35,   1.3422020E-35
     +,   3.1806482E-36,   7.4304306E-37,   1.7113263E-37
     +,   3.8859335E-38,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_qq_mass = Yx/0.002807
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.0055828E-08,   5.9337612E-08
     +,   7.0165640E-08,   8.2763627E-08,   9.7381360E-08
     +,   1.1429698E-07,   1.3381899E-07,   1.5628832E-07
     +,   1.8207984E-07,   2.1160585E-07,   2.4531559E-07
     +,   2.8369828E-07,   3.2728465E-07,   3.7664688E-07
     +,   4.3240092E-07,   4.9520617E-07,   5.6576613E-07
     +,   6.4482737E-07,   7.3318068E-07,   8.3165799E-07
     +,   9.4113221E-07,   1.0625153E-06,   1.1967531E-06
     +,   1.3448346E-06,   1.5077621E-06,   1.6865841E-06
     +,   1.8823606E-06,   2.0961756E-06,   2.3291275E-06
     +,   2.5823285E-06,   2.8568968E-06,   3.1539562E-06
     +,   3.4746329E-06,   3.8200501E-06,   4.1913299E-06
     +,   4.5895886E-06,   5.0159383E-06,   5.4714815E-06
     +,   5.9573499E-06,   6.4746259E-06,   7.0244578E-06
     +,   7.6079782E-06,   8.2263614E-06,   8.8808183E-06
     +,   9.5726282E-06,   1.0303145E-05,   1.1073828E-05
     +,   1.1886272E-05,   1.2742234E-05,   1.3643669E-05
     +,   1.4592782E-05,   1.5592061E-05,   1.6644311E-05
     +,   1.7752804E-05,   1.8921122E-05,   2.0153480E-05
     +,   2.1454573E-05,   2.2829721E-05,   2.4284891E-05
     +,   2.5826748E-05,   2.7462664E-05,   2.9200772E-05
     +,   3.1049807E-05,   3.3019322E-05,   3.5119516E-05
     +,   3.7360922E-05,   3.9754763E-05,   4.2312218E-05
     +,   4.5044853E-05,   4.7963746E-05,   5.1079915E-05
     +,   5.4403303E-05,   5.7943242E-05,   6.1707338E-05
     +,   6.5701846E-05,   6.9931120E-05,   7.4396972E-05
     +,   7.9098631E-05,   8.4032858E-05,   8.9193476E-05
     +,   9.4570722E-05,   1.0015237E-04,   1.0592237E-04
     +,   1.1186236E-04,   1.1795036E-04,   1.2416254E-04
     +,   1.3047189E-04,   1.3685024E-04,   1.4326697E-04
     +,   1.4969076E-04,   1.5608962E-04,   1.6243059E-04
     +,   1.6868058E-04,   1.7480720E-04,   1.8077857E-04
     +,   1.8656284E-04,   1.9212993E-04,   1.9744983E-04
     +,   2.0249444E-04,   2.0723591E-04,   2.1164828E-04
     +,   2.1570602E-04,   2.1938540E-04,   2.2266344E-04
     +,   2.2551896E-04,   2.2793253E-04,   2.2988635E-04
     +,   2.3136534E-04,   2.3235698E-04,   2.3285244E-04
     +,   2.3284655E-04,   2.3233880E-04,   2.3133364E-04
     +,   2.2984121E-04,   2.2787751E-04,   2.2546474E-04
     +,   2.2263190E-04,   2.1941376E-04,   2.1585189E-04
     +,   2.1199301E-04,   2.0788905E-04,   2.0359630E-04
     +,   1.9917420E-04,   1.9468399E-04,   1.9018759E-04
     +,   1.8574661E-04,   1.8142018E-04,   1.7726450E-04
     +,   1.7333055E-04,   1.6966404E-04,   1.6630332E-04
     +,   1.6327962E-04,   1.6061557E-04,   1.5832559E-04
     +,   1.5641545E-04,   1.5488236E-04,   1.5371590E-04
     +,   1.5289809E-04,   1.5240461E-04,   1.5220545E-04
     +,   1.5226648E-04,   1.5255013E-04,   1.5301711E-04
     +,   1.5362723E-04,   1.5434080E-04,   1.5511976E-04
     +,   1.5592862E-04,   1.5673549E-04,   1.5751271E-04
     +,   1.5823750E-04,   1.5889252E-04,   1.5946601E-04
     +,   1.5995190E-04,   1.6034997E-04,   1.6066538E-04
     +,   1.6090847E-04,   1.6109420E-04,   1.6124158E-04
     +,   1.6137310E-04,   1.6151360E-04,   1.6168962E-04
     +,   1.6192852E-04,   1.6225739E-04,   1.6270216E-04
     +,   1.6328674E-04,   1.6403220E-04,   1.6495583E-04
     +,   1.6607056E-04,   1.6738444E-04,   1.6890040E-04
     +,   1.7061562E-04,   1.7252180E-04,   1.7460529E-04
     +,   1.7684734E-04,   1.7922439E-04,   1.8170905E-04
     +,   1.8427076E-04,   1.8687631E-04,   1.8949101E-04
     +,   1.9208003E-04,   1.9460882E-04,   1.9704399E-04
     +,   1.9935431E-04,   2.0151171E-04,   2.0349138E-04
     +,   2.0527221E-04,   2.0683726E-04,   2.0817366E-04
     +,   2.0927258E-04,   2.1012887E-04,   2.1074059E-04
     +,   2.1110880E-04,   2.1123649E-04,   2.1112844E-04
     +,   2.1079030E-04,   2.1022794E-04,   2.0944710E-04
     +,   2.0845291E-04,   2.0724935E-04,   2.0583926E-04
     +,   2.0422415E-04,   2.0240434E-04,   2.0037901E-04
     +,   1.9814655E-04,   1.9570510E-04,   1.9305277E-04
     +,   1.9018816E-04,   1.8711116E-04,   1.8382317E-04
     +,   1.8032760E-04,   1.7663003E-04,   1.7273893E-04
     +,   1.6866569E-04,   1.6442437E-04,   1.6003172E-04
     +,   1.5550744E-04,   1.5087362E-04,   1.4615386E-04
     +,   1.4137333E-04,   1.3655850E-04,   1.3173583E-04
     +,   1.2693138E-04,   1.2217082E-04,   1.1747846E-04
     +,   1.1287642E-04,   1.0838456E-04,   1.0402044E-04
     +,   9.9798752E-05,   9.5730888E-05,   9.1825190E-05
     +,   8.8087239E-05,   8.4519648E-05,   8.1122074E-05
     +,   7.7891717E-05,   7.4823940E-05,   7.1911942E-05
     +,   6.9147492E-05,   6.6521381E-05,   6.4023690E-05
     +,   6.1643870E-05,   5.9371330E-05,   5.7195790E-05
     +,   5.5107357E-05,   5.3096661E-05,   5.1155042E-05
     +,   4.9274880E-05,   4.7449466E-05,   4.5672939E-05
     +,   4.3940407E-05,   4.2248070E-05,   4.0592859E-05
     +,   3.8972477E-05,   3.7385445E-05,   3.5830926E-05
     +,   3.4308494E-05,   3.2818149E-05,   3.1360327E-05
     +,   2.9935694E-05,   2.8545008E-05,   2.7189106E-05
     +,   2.5868958E-05,   2.4585510E-05,   2.3339555E-05
     +,   2.2131801E-05,   2.0962960E-05,   1.9833482E-05
     +,   1.8743685E-05,   1.7693814E-05,   1.6683940E-05
     +,   1.5713946E-05,   1.4783574E-05,   1.3892499E-05
     +,   1.3040277E-05,   1.2226295E-05,   1.1449861E-05
     +,   1.0710271E-05,   1.0006653E-05,   9.3381668E-06
     +,   8.7038352E-06,   8.1027256E-06,   7.5337966E-06
     +,   6.9960497E-06,   6.4884052E-06,   6.0098359E-06
     +,   5.5592413E-06,   5.1355842E-06,   4.7377825E-06
     +,   4.3647601E-06,   4.0154882E-06,   3.6889012E-06
     +,   3.3839890E-06,   3.0997162E-06,   2.8351044E-06
     +,   2.5891554E-06,   2.3609261E-06,   2.1494639E-06
     +,   1.9538659E-06,   1.7732307E-06,   1.6067023E-06
     +,   1.4534311E-06,   1.3126144E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_ww_mass = Yx/0.00694523666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_ashz_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.5103062E-06,   3.7048014E-06
     +,   3.9072243E-06,   4.1177309E-06,   4.3364748E-06
     +,   4.5636070E-06,   4.7992794E-06,   5.0436443E-06
     +,   5.2968503E-06,   5.5590654E-06,   5.8304518E-06
     +,   6.1111818E-06,   6.4014453E-06,   6.7014430E-06
     +,   7.0114020E-06,   7.3315746E-06,   7.6622446E-06
     +,   8.0037380E-06,   8.3564282E-06,   8.7207518E-06
     +,   9.0972062E-06,   9.4863835E-06,   9.8889568E-06
     +,   1.0305746E-05,   1.0737654E-05,   1.1185781E-05
     +,   1.1651381E-05,   1.2135910E-05,   1.2641044E-05
     +,   1.3168726E-05,   1.3721173E-05,   1.4300919E-05
     +,   1.4910844E-05,   1.5554200E-05,   1.6234653E-05
     +,   1.6956308E-05,   1.7723727E-05,   1.8541938E-05
     +,   1.9416537E-05,   2.0353524E-05,   2.1359512E-05
     +,   2.2441549E-05,   2.3607186E-05,   2.4864408E-05
     +,   2.6221574E-05,   2.7687380E-05,   2.9270735E-05
     +,   3.0980667E-05,   3.2826189E-05,   3.4816163E-05
     +,   3.6959096E-05,   3.9262995E-05,   4.1735097E-05
     +,   4.4381843E-05,   4.7208199E-05,   5.0218030E-05
     +,   5.3413380E-05,   5.6794390E-05,   6.0359154E-05
     +,   6.4103369E-05,   6.8020316E-05,   7.2100571E-05
     +,   7.6331722E-05,   8.0698817E-05,   8.5184096E-05
     +,   8.9766450E-05,   9.4422670E-05,   9.9126344E-05
     +,   1.0384934E-04,   1.0856080E-04,   1.1322879E-04
     +,   1.1781946E-04,   1.2229868E-04,   1.2663138E-04
     +,   1.3078313E-04,   1.3472023E-04,   1.3841006E-04
     +,   1.4182186E-04,   1.4492762E-04,   1.4770230E-04
     +,   1.5012402E-04,   1.5217527E-04,   1.5384245E-04
     +,   1.5511698E-04,   1.5599471E-04,   1.5647683E-04
     +,   1.5656929E-04,   1.5628319E-04,   1.5563433E-04
     +,   1.5464316E-04,   1.5333429E-04,   1.5173627E-04
     +,   1.4988107E-04,   1.4780342E-04,   1.4554027E-04
     +,   1.4313035E-04,   1.4061325E-04,   1.3802919E-04
     +,   1.3541777E-04,   1.3281812E-04,   1.3026754E-04
     +,   1.2780173E-04,   1.2545365E-04,   1.2325370E-04
     +,   1.2122900E-04,   1.1940336E-04,   1.1779724E-04
     +,   1.1642773E-04,   1.1530842E-04,   1.1445004E-04
     +,   1.1386064E-04,   1.1354602E-04,   1.1351054E-04
     +,   1.1375768E-04,   1.1429092E-04,   1.1511466E-04
     +,   1.1623502E-04,   1.1766090E-04,   1.1940464E-04
     +,   1.2148303E-04,   1.2391787E-04,   1.2673628E-04
     +,   1.2997090E-04,   1.3366019E-04,   1.3784801E-04
     +,   1.4258234E-04,   1.4791558E-04,   1.5390168E-04
     +,   1.6059639E-04,   1.6805374E-04,   1.7632564E-04
     +,   1.8545838E-04,   1.9549248E-04,   2.0645907E-04
     +,   2.1838101E-04,   2.3127157E-04,   2.4513525E-04
     +,   2.5997026E-04,   2.7577396E-04,   2.9254783E-04
     +,   3.1030321E-04,   3.2907006E-04,   3.4890635E-04
     +,   3.6990395E-04,   3.9218974E-04,   4.1593064E-04
     +,   4.4132557E-04,   4.6859213E-04,   4.9794890E-04
     +,   5.2959059E-04,   5.6365522E-04,   6.0018554E-04
     +,   6.3909363E-04,   6.8012968E-04,   7.2285242E-04
     +,   7.6661143E-04,   8.1054959E-04,   8.5362885E-04
     +,   8.9466741E-04,   9.3240291E-04,   9.6558098E-04
     +,   9.9305075E-04,   1.0138644E-03,   1.0273815E-03
     +,   1.0333526E-03,   1.0319802E-03,   1.0239470E-03
     +,   1.0104103E-03,   9.9294714E-04,   9.7346870E-04
     +,   9.5409126E-04,   9.3698333E-04,   9.2418940E-04
     +,   9.1745437E-04,   9.1806083E-04,   9.2669530E-04
     +,   9.4336609E-04,   9.6738630E-04,   9.9742482E-04
     +,   1.0316308E-03,   1.0678103E-03,   1.1036388E-03
     +,   1.1368807E-03,   1.1655964E-03,   1.1882903E-03
     +,   1.2040023E-03,   1.2123382E-03,   1.2134272E-03
     +,   1.2078350E-03,   1.1964383E-03,   1.1802859E-03
     +,   1.1604674E-03,   1.1379924E-03,   1.1137000E-03
     +,   1.0881969E-03,   1.0618308E-03,   1.0347010E-03
     +,   1.0066881E-03,   9.7751361E-04,   9.4681152E-04
     +,   9.1420911E-04,   8.7939942E-04,   8.4220205E-04
     +,   8.0260547E-04,   7.6079572E-04,   7.1714260E-04
     +,   6.7218003E-04,   6.2656705E-04,   5.8103574E-04
     +,   5.3633057E-04,   4.9316167E-04,   4.5216264E-04
     +,   4.1385664E-04,   3.7863370E-04,   3.4674749E-04
     +,   3.1832268E-04,   2.9336405E-04,   2.7177381E-04
     +,   2.5337539E-04,   2.3793474E-04,   2.2517800E-04
     +,   2.1480920E-04,   2.0652573E-04,   2.0002815E-04
     +,   1.9502823E-04,   1.9125569E-04,   1.8846185E-04
     +,   1.8642186E-04,   1.8493585E-04,   1.8382890E-04
     +,   1.8295091E-04,   1.8217487E-04,   1.8139512E-04
     +,   1.8052563E-04,   1.7949757E-04,   1.7825725E-04
     +,   1.7676405E-04,   1.7498856E-04,   1.7291104E-04
     +,   1.7051969E-04,   1.6780981E-04,   1.6478273E-04
     +,   1.6144539E-04,   1.5780922E-04,   1.5388978E-04
     +,   1.4970661E-04,   1.4528254E-04,   1.4064294E-04
     +,   1.3581529E-04,   1.3082940E-04,   1.2571573E-04
     +,   1.2050541E-04,   1.1522999E-04,   1.0992059E-04
     +,   1.0460721E-04,   9.9318429E-05,   9.4081573E-05
     +,   8.8921959E-05,   8.3862353E-05,   7.8923185E-05
     +,   7.4122661E-05,   6.9476519E-05,   6.4997650E-05
     +,   6.0696486E-05,   5.6581539E-05,   5.2658652E-05
     +,   4.8931593E-05,   4.5402474E-05,   4.2071610E-05
     +,   3.8937524E-05,   3.5997378E-05,   3.3247303E-05
     +,   3.0682349E-05,   2.8296523E-05,   2.6083091E-05
     +,   2.4034945E-05,   2.2144242E-05,   2.0403038E-05
     +,   1.8802932E-05,   1.7335597E-05,   1.5992471E-05
     +,   1.4765232E-05,   1.3645482E-05,   1.2625176E-05
     +,   1.1696363E-05,   1.0851505E-05,   1.0083298E-05
     +,   9.3848084E-06,   8.7495509E-06,   8.1713633E-06
     +,   7.6445658E-06,   7.1638387E-06,   6.7243382E-06
     +,   6.3215766E-06,   5.9515278E-06,   5.6105050E-06
     +,   5.2952391E-06,   5.0027779E-06,   4.7305330E-06
     +,   4.4761955E-06,   4.2377728E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_ashz_zz_mass = Yx/0.0196390303030303
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.7303266E-06,   8.6450109E-06
     +,   9.6456115E-06,   1.0737140E-05,   1.1924514E-05
     +,   1.3212469E-05,   1.4605514E-05,   1.6107846E-05
     +,   1.7723258E-05,   1.9455158E-05,   2.1306339E-05
     +,   2.3279012E-05,   2.5374698E-05,   2.7594158E-05
     +,   2.9937322E-05,   3.2403244E-05,   3.4990037E-05
     +,   3.7694845E-05,   4.0513805E-05,   4.3442062E-05
     +,   4.6473753E-05,   4.9602040E-05,   5.2819098E-05
     +,   5.6116434E-05,   5.9484410E-05,   6.2913052E-05
     +,   6.6391600E-05,   6.9908921E-05,   7.3453550E-05
     +,   7.7013894E-05,   8.0578400E-05,   8.4135674E-05
     +,   8.7674678E-05,   9.1184855E-05,   9.4656345E-05
     +,   9.8080018E-05,   1.0144769E-04,   1.0475203E-04
     +,   1.0798707E-04,   1.1114741E-04,   1.1422914E-04
     +,   1.1722920E-04,   1.2014554E-04,   1.2297687E-04
     +,   1.2572280E-04,   1.2838333E-04,   1.3095903E-04
     +,   1.3345061E-04,   1.3585882E-04,   1.3818424E-04
     +,   1.4042715E-04,   1.4258725E-04,   1.4466360E-04
     +,   1.4665459E-04,   1.4855758E-04,   1.5036916E-04
     +,   1.5208495E-04,   1.5369980E-04,   1.5520779E-04
     +,   1.5660236E-04,   1.5787655E-04,   1.5902318E-04
     +,   1.6003515E-04,   1.6090565E-04,   1.6162860E-04
     +,   1.6219860E-04,   1.6261167E-04,   1.6286525E-04
     +,   1.6295863E-04,   1.6289306E-04,   1.6267203E-04
     +,   1.6230148E-04,   1.6178984E-04,   1.6114816E-04
     +,   1.6039007E-04,   1.5953176E-04,   1.5859188E-04
     +,   1.5759133E-04,   1.5655317E-04,   1.5550188E-04
     +,   1.5446384E-04,   1.5346601E-04,   1.5253623E-04
     +,   1.5170219E-04,   1.5099134E-04,   1.5043007E-04
     +,   1.5004337E-04,   1.4985414E-04,   1.4988266E-04
     +,   1.5014621E-04,   1.5065836E-04,   1.5142887E-04
     +,   1.5246285E-04,   1.5376096E-04,   1.5531888E-04
     +,   1.5712724E-04,   1.5917183E-04,   1.6143330E-04
     +,   1.6388782E-04,   1.6650700E-04,   1.6925878E-04
     +,   1.7210757E-04,   1.7501522E-04,   1.7794145E-04
     +,   1.8084502E-04,   1.8368446E-04,   1.8641872E-04
     +,   1.8900819E-04,   1.9141583E-04,   1.9360773E-04
     +,   1.9555374E-04,   1.9722852E-04,   1.9861160E-04
     +,   1.9968832E-04,   2.0044965E-04,   2.0089257E-04
     +,   2.0101995E-04,   2.0084043E-04,   2.0036800E-04
     +,   1.9962157E-04,   1.9862432E-04,   1.9740315E-04
     +,   1.9598776E-04,   1.9440980E-04,   1.9270192E-04
     +,   1.9089722E-04,   1.8902789E-04,   1.8712481E-04
     +,   1.8521633E-04,   1.8332810E-04,   1.8148204E-04
     +,   1.7969610E-04,   1.7798376E-04,   1.7635418E-04
     +,   1.7481158E-04,   1.7335557E-04,   1.7198146E-04
     +,   1.7068046E-04,   1.6943987E-04,   1.6824376E-04
     +,   1.6707359E-04,   1.6590877E-04,   1.6472726E-04
     +,   1.6350613E-04,   1.6222268E-04,   1.6085466E-04
     +,   1.5938081E-04,   1.5778199E-04,   1.5604118E-04
     +,   1.5414406E-04,   1.5207921E-04,   1.4983880E-04
     +,   1.4741838E-04,   1.4481691E-04,   1.4203691E-04
     +,   1.3908447E-04,   1.3596907E-04,   1.3270292E-04
     +,   1.2930106E-04,   1.2578120E-04,   1.2216276E-04
     +,   1.1846679E-04,   1.1471575E-04,   1.1093284E-04
     +,   1.0714143E-04,   1.0336478E-04,   9.9626050E-05
     +,   9.5947471E-05,   9.2350048E-05,   8.8853398E-05
     +,   8.5475753E-05,   8.2233550E-05,   7.9141035E-05
     +,   7.6210497E-05,   7.3452342E-05,   7.0874623E-05
     +,   6.8483278E-05,   6.6282337E-05,   6.4273852E-05
     +,   6.2457788E-05,   6.0832459E-05,   5.9394541E-05
     +,   5.8139278E-05,   5.7060424E-05,   5.6150591E-05
     +,   5.5401433E-05,   5.4803717E-05,   5.4347431E-05
     +,   5.4022046E-05,   5.3816613E-05,   5.3719876E-05
     +,   5.3720429E-05,   5.3806838E-05,   5.3967702E-05
     +,   5.4191776E-05,   5.4468132E-05,   5.4786073E-05
     +,   5.5135344E-05,   5.5506131E-05,   5.5889133E-05
     +,   5.6275549E-05,   5.6657180E-05,   5.7026413E-05
     +,   5.7376248E-05,   5.7700308E-05,   5.7992827E-05
     +,   5.8248716E-05,   5.8463447E-05,   5.8633126E-05
     +,   5.8754489E-05,   5.8824808E-05,   5.8841921E-05
     +,   5.8804231E-05,   5.8710622E-05,   5.8560458E-05
     +,   5.8353573E-05,   5.8090238E-05,   5.7771089E-05
     +,   5.7397097E-05,   5.6969624E-05,   5.6490295E-05
     +,   5.5960976E-05,   5.5383771E-05,   5.4761083E-05
     +,   5.4095322E-05,   5.3389151E-05,   5.2645297E-05
     +,   5.1866653E-05,   5.1056082E-05,   5.0216480E-05
     +,   4.9350845E-05,   4.8462141E-05,   4.7553272E-05
     +,   4.6627061E-05,   4.5686407E-05,   4.4734035E-05
     +,   4.3772554E-05,   4.2804568E-05,   4.1832562E-05
     +,   4.0858838E-05,   3.9885599E-05,   3.8914957E-05
     +,   3.7948903E-05,   3.6989233E-05,   3.6037607E-05
     +,   3.5095600E-05,   3.4164656E-05,   3.3246044E-05
     +,   3.2340868E-05,   3.1450207E-05,   3.0574931E-05
     +,   2.9715782E-05,   2.8873450E-05,   2.8048500E-05
     +,   2.7241354E-05,   2.6452322E-05,   2.5681671E-05
     +,   2.4929595E-05,   2.4196139E-05,   2.3481292E-05
     +,   2.2785009E-05,   2.2107186E-05,   2.1447617E-05
     +,   2.0806056E-05,   2.0182260E-05,   1.9575895E-05
     +,   1.8986597E-05,   1.8414006E-05,   1.7857743E-05
     +,   1.7317372E-05,   1.6792439E-05,   1.6282518E-05
     +,   1.5787178E-05,   1.5305946E-05,   1.4838352E-05
     +,   1.4383973E-05,   1.3942335E-05,   1.3513022E-05
     +,   1.3095572E-05,   1.2689597E-05,   1.2294658E-05
     +,   1.1910383E-05,   1.1536368E-05,   1.1172271E-05
     +,   1.0817716E-05,   1.0472390E-05,   1.0135967E-05
     +,   9.8081327E-06,   9.4886263E-06,   9.1771572E-06
     +,   8.8734942E-06,   8.5773818E-06,   8.2886190E-06
     +,   8.0069822E-06,   7.7322993E-06,   7.4643740E-06
     +,   7.2030589E-06,   6.9481894E-06,   6.6996386E-06
     +,   6.4572623E-06,   6.2209560E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_eez_mass = Yx/0.00651913043478261
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0790701E-04,   1.1120624E-04
     +,   1.1454614E-04,   1.1792404E-04,   1.2133698E-04
     +,   1.2478181E-04,   1.2825518E-04,   1.3175351E-04
     +,   1.3527299E-04,   1.3880969E-04,   1.4235941E-04
     +,   1.4591770E-04,   1.4948001E-04,   1.5304152E-04
     +,   1.5659723E-04,   1.6014208E-04,   1.6367069E-04
     +,   1.6717761E-04,   1.7065729E-04,   1.7410402E-04
     +,   1.7751193E-04,   1.8087514E-04,   1.8418769E-04
     +,   1.8744371E-04,   1.9063696E-04,   1.9376150E-04
     +,   1.9681139E-04,   1.9978060E-04,   2.0266326E-04
     +,   2.0545363E-04,   2.0814601E-04,   2.1073493E-04
     +,   2.1321508E-04,   2.1558131E-04,   2.1782877E-04
     +,   2.1995284E-04,   2.2194914E-04,   2.2381364E-04
     +,   2.2554267E-04,   2.2713275E-04,   2.2858096E-04
     +,   2.2988468E-04,   2.3104169E-04,   2.3205006E-04
     +,   2.3290858E-04,   2.3361617E-04,   2.3417237E-04
     +,   2.3457703E-04,   2.3483059E-04,   2.3493380E-04
     +,   2.3488791E-04,   2.3469457E-04,   2.3435598E-04
     +,   2.3387448E-04,   2.3325307E-04,   2.3249502E-04
     +,   2.3160386E-04,   2.3058365E-04,   2.2943859E-04
     +,   2.2817330E-04,   2.2679254E-04,   2.2530142E-04
     +,   2.2370511E-04,   2.2200916E-04,   2.2021891E-04
     +,   2.1834022E-04,   2.1637871E-04,   2.1434024E-04
     +,   2.1223046E-04,   2.1005525E-04,   2.0782025E-04
     +,   2.0553113E-04,   2.0319334E-04,   2.0081237E-04
     +,   1.9839333E-04,   1.9594122E-04,   1.9346086E-04
     +,   1.9095700E-04,   1.8843386E-04,   1.8589545E-04
     +,   1.8334575E-04,   1.8078815E-04,   1.7822604E-04
     +,   1.7566222E-04,   1.7309951E-04,   1.7054015E-04
     +,   1.6798639E-04,   1.6543987E-04,   1.6290226E-04
     +,   1.6037474E-04,   1.5785825E-04,   1.5535360E-04
     +,   1.5286148E-04,   1.5038214E-04,   1.4791556E-04
     +,   1.4546195E-04,   1.4302089E-04,   1.4059231E-04
     +,   1.3817554E-04,   1.3577031E-04,   1.3337578E-04
     +,   1.3099150E-04,   1.2861661E-04,   1.2625064E-04
     +,   1.2389278E-04,   1.2154235E-04,   1.1919878E-04
     +,   1.1686159E-04,   1.1453027E-04,   1.1220430E-04
     +,   1.0988359E-04,   1.0756774E-04,   1.0525691E-04
     +,   1.0295093E-04,   1.0065018E-04,   9.8354780E-05
     +,   9.6065371E-05,   9.3782364E-05,   9.1506670E-05
     +,   8.9239060E-05,   8.6980450E-05,   8.4732055E-05
     +,   8.2495164E-05,   8.0271086E-05,   7.8061224E-05
     +,   7.5867312E-05,   7.3690862E-05,   7.1533774E-05
     +,   6.9397742E-05,   6.7284811E-05,   6.5196786E-05
     +,   6.3135827E-05,   6.1103841E-05,   5.9103026E-05
     +,   5.7135388E-05,   5.5202978E-05,   5.3307973E-05
     +,   5.1452505E-05,   4.9638580E-05,   4.7868220E-05
     +,   4.6143490E-05,   4.4466447E-05,   4.2838990E-05
     +,   4.1262960E-05,   3.9740331E-05,   3.8272872E-05
     +,   3.6862282E-05,   3.5510333E-05,   3.4218720E-05
     +,   3.2988988E-05,   3.1822648E-05,   3.0721258E-05
     +,   2.9686271E-05,   2.8719072E-05,   2.7820986E-05
     +,   2.6993350E-05,   2.6237482E-05,   2.5554593E-05
     +,   2.4945883E-05,   2.4412589E-05,   2.3955858E-05
     +,   2.3576838E-05,   2.3276705E-05,   2.3056597E-05
     +,   2.2917635E-05,   2.2860972E-05,   2.2887762E-05
     +,   2.2999136E-05,   2.3196286E-05,   2.3480394E-05
     +,   2.3852645E-05,   2.4314249E-05,   2.4866440E-05
     +,   2.5510506E-05,   2.6247661E-05,   2.7079228E-05
     +,   2.8006516E-05,   2.9030833E-05,   3.0153451E-05
     +,   3.1375723E-05,   3.2699027E-05,   3.4124634E-05
     +,   3.5653778E-05,   3.7287788E-05,   3.9027971E-05
     +,   4.0875453E-05,   4.2831351E-05,   4.4896788E-05
     +,   4.7072845E-05,   4.9360307E-05,   5.1760053E-05
     +,   5.4272881E-05,   5.6899284E-05,   5.9639595E-05
     +,   6.2494168E-05,   6.5463195E-05,   6.8546491E-05
     +,   7.1743612E-05,   7.5054159E-05,   7.8477446E-05
     +,   8.2012353E-05,   8.5657433E-05,   8.9411194E-05
     +,   9.3271919E-05,   9.7237076E-05,   1.0130428E-04
     +,   1.0547080E-04,   1.0973322E-04,   1.1408784E-04
     +,   1.1853077E-04,   1.2305782E-04,   1.2766410E-04
     +,   1.3234430E-04,   1.3709305E-04,   1.4190457E-04
     +,   1.4677239E-04,   1.5168964E-04,   1.5664937E-04
     +,   1.6164423E-04,   1.6666614E-04,   1.7170697E-04
     +,   1.7675839E-04,   1.8181141E-04,   1.8685657E-04
     +,   1.9188473E-04,   1.9688622E-04,   2.0185100E-04
     +,   2.0676870E-04,   2.1162916E-04,   2.1642209E-04
     +,   2.2113675E-04,   2.2576225E-04,   2.3028812E-04
     +,   2.3470372E-04,   2.3899815E-04,   2.4316100E-04
     +,   2.4718183E-04,   2.5105031E-04,   2.5475616E-04
     +,   2.5828966E-04,   2.6164143E-04,   2.6480202E-04
     +,   2.6776249E-04,   2.7051455E-04,   2.7305025E-04
     +,   2.7536199E-04,   2.7744271E-04,   2.7928612E-04
     +,   2.8088634E-04,   2.8223815E-04,   2.8333697E-04
     +,   2.8417894E-04,   2.8476084E-04,   2.8508026E-04
     +,   2.8513532E-04,   2.8492502E-04,   2.8444911E-04
     +,   2.8370810E-04,   2.8270326E-04,   2.8143643E-04
     +,   2.7991043E-04,   2.7812881E-04,   2.7609570E-04
     +,   2.7381588E-04,   2.7129523E-04,   2.6853982E-04
     +,   2.6555647E-04,   2.6235284E-04,   2.5893704E-04
     +,   2.5531769E-04,   2.5150369E-04,   2.4750488E-04
     +,   2.4333139E-04,   2.3899344E-04,   2.3450171E-04
     +,   2.2986754E-04,   2.2510189E-04,   2.2021655E-04
     +,   2.1522278E-04,   2.1013278E-04,   2.0495793E-04
     +,   1.9971041E-04,   1.9440161E-04,   1.8904360E-04
     +,   1.8364756E-04,   1.7822525E-04,   1.7278767E-04
     +,   1.6734558E-04,   1.6190998E-04,   1.5649087E-04
     +,   1.5109855E-04,   1.4574231E-04,   1.4043166E-04
     +,   1.3517504E-04,   1.2998111E-04,   1.2485738E-04
     +,   1.1981151E-04,   1.1485012E-04,   1.0997981E-04
     +,   1.0520616E-04,   1.0053480E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_qq_mass = Yx/0.01153
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9620571E-05,   8.2770224E-05
     +,   8.5990367E-05,   8.9279900E-05,   9.2637616E-05
     +,   9.6062075E-05,   9.9551820E-05,   1.0310524E-04
     +,   1.0672054E-04,   1.1039613E-04,   1.1413009E-04
     +,   1.1792054E-04,   1.2176577E-04,   1.2566410E-04
     +,   1.2961400E-04,   1.3361426E-04,   1.3766410E-04
     +,   1.4176323E-04,   1.4591207E-04,   1.5011185E-04
     +,   1.5436487E-04,   1.5867477E-04,   1.6304650E-04
     +,   1.6748723E-04,   1.7200540E-04,   1.7661251E-04
     +,   1.8132200E-04,   1.8615043E-04,   1.9111707E-04
     +,   1.9624463E-04,   2.0155883E-04,   2.0708887E-04
     +,   2.1286705E-04,   2.1892889E-04,   2.2531267E-04
     +,   2.3205898E-04,   2.3921036E-04,   2.4681003E-04
     +,   2.5490191E-04,   2.6352837E-04,   2.7273016E-04
     +,   2.8254426E-04,   2.9300270E-04,   3.0413075E-04
     +,   3.1594647E-04,   3.2845736E-04,   3.4166061E-04
     +,   3.5554136E-04,   3.7007101E-04,   3.8520768E-04
     +,   4.0089496E-04,   4.1706284E-04,   4.3362746E-04
     +,   4.5049397E-04,   4.6755499E-04,   4.8469732E-04
     +,   5.0180050E-04,   5.1874347E-04,   5.3540524E-04
     +,   5.5167166E-04,   5.6743802E-04,   5.8261328E-04
     +,   5.9712370E-04,   6.1091961E-04,   6.2397524E-04
     +,   6.3629303E-04,   6.4790616E-04,   6.5887748E-04
     +,   6.6930399E-04,   6.7931047E-04,   6.8905071E-04
     +,   6.9870404E-04,   7.0847012E-04,   7.1856368E-04
     +,   7.2920870E-04,   7.4063300E-04,   7.5305899E-04
     +,   7.6669746E-04,   7.8174239E-04,   7.9836283E-04
     +,   8.1669644E-04,   8.3684834E-04,   8.5888023E-04
     +,   8.8281714E-04,   9.0863433E-04,   9.3626766E-04
     +,   9.6560596E-04,   9.9649676E-04,   1.0287449E-03
     +,   1.0621173E-03,   1.0963514E-03,   1.1311482E-03
     +,   1.1661845E-03,   1.2011209E-03,   1.2356020E-03
     +,   1.2692629E-03,   1.3017452E-03,   1.3326923E-03
     +,   1.3617690E-03,   1.3886627E-03,   1.4130961E-03
     +,   1.4348306E-03,   1.4536778E-03,   1.4695013E-03
     +,   1.4822232E-03,   1.4918227E-03,   1.4983376E-03
     +,   1.5018600E-03,   1.5025297E-03,   1.5005274E-03
     +,   1.4960647E-03,   1.4893730E-03,   1.4806900E-03
     +,   1.4702537E-03,   1.4582864E-03,   1.4449873E-03
     +,   1.4305313E-03,   1.4150570E-03,   1.3986705E-03
     +,   1.3814470E-03,   1.3634325E-03,   1.3446503E-03
     +,   1.3251106E-03,   1.3048135E-03,   1.2837594E-03
     +,   1.2619571E-03,   1.2394245E-03,   1.2161989E-03
     +,   1.1923320E-03,   1.1678954E-03,   1.1429759E-03
     +,   1.1176732E-03,   1.0920957E-03,   1.0663588E-03
     +,   1.0405743E-03,   1.0148506E-03,   9.8928949E-04
     +,   9.6398249E-04,   9.3900680E-04,   9.1442815E-04
     +,   8.9030253E-04,   8.6667342E-04,   8.4357522E-04
     +,   8.2103699E-04,   7.9908525E-04,   7.7774224E-04
     +,   7.5703225E-04,   7.3698134E-04,   7.1761786E-04
     +,   6.9897325E-04,   6.8108062E-04,   6.6397712E-04
     +,   6.4770010E-04,   6.3228566E-04,   6.1776693E-04
     +,   6.0417457E-04,   5.9153314E-04,   5.7985832E-04
     +,   5.6915823E-04,   5.5943051E-04,   5.5066298E-04
     +,   5.4283126E-04,   5.3590100E-04,   5.2982755E-04
     +,   5.2455638E-04,   5.2002398E-04,   5.1616138E-04
     +,   5.1289285E-04,   5.1014102E-04,   5.0782604E-04
     +,   5.0586910E-04,   5.0419534E-04,   5.0273287E-04
     +,   5.0141790E-04,   5.0019356E-04,   4.9901364E-04
     +,   4.9784046E-04,   4.9664930E-04,   4.9542543E-04
     +,   4.9416604E-04,   4.9287907E-04,   4.9158290E-04
     +,   4.9030536E-04,   4.8908347E-04,   4.8795872E-04
     +,   4.8698057E-04,   4.8620044E-04,   4.8567299E-04
     +,   4.8545201E-04,   4.8559008E-04,   4.8613761E-04
     +,   4.8713962E-04,   4.8863614E-04,   4.9065973E-04
     +,   4.9323560E-04,   4.9638160E-04,   5.0010555E-04
     +,   5.0440797E-04,   5.0928089E-04,   5.1470776E-04
     +,   5.2066491E-04,   5.2712206E-04,   5.3404324E-04
     +,   5.4138748E-04,   5.4910954E-04,   5.5716094E-04
     +,   5.6549237E-04,   5.7405198E-04,   5.8278709E-04
     +,   5.9164618E-04,   6.0057786E-04,   6.0953118E-04
     +,   6.1845686E-04,   6.2730740E-04,   6.3603651E-04
     +,   6.4459996E-04,   6.5295451E-04,   6.6105928E-04
     +,   6.6887616E-04,   6.7636726E-04,   6.8349834E-04
     +,   6.9023744E-04,   6.9655466E-04,   7.0242310E-04
     +,   7.0782035E-04,   7.1272632E-04,   7.1712543E-04
     +,   7.2100549E-04,   7.2436035E-04,   7.2718656E-04
     +,   7.2948501E-04,   7.3126121E-04,   7.3252380E-04
     +,   7.3328428E-04,   7.3355692E-04,   7.3335669E-04
     +,   7.3270005E-04,   7.3160173E-04,   7.3007611E-04
     +,   7.2813494E-04,   7.2578515E-04,   7.2303199E-04
     +,   7.1987387E-04,   7.1630522E-04,   7.1231474E-04
     +,   7.0788595E-04,   7.0299720E-04,   6.9762353E-04
     +,   6.9173530E-04,   6.8530149E-04,   6.7828927E-04
     +,   6.7066634E-04,   6.6240173E-04,   6.5346825E-04
     +,   6.4384198E-04,   6.3350552E-04,   6.2244805E-04
     +,   6.1066786E-04,   5.9816951E-04,   5.8496837E-04
     +,   5.7108892E-04,   5.5656506E-04,   5.4143945E-04
     +,   5.2576262E-04,   5.0959474E-04,   4.9300073E-04
     +,   4.7605153E-04,   4.5882352E-04,   4.4139585E-04
     +,   4.2384863E-04,   4.0626191E-04,   3.8871626E-04
     +,   3.7128982E-04,   3.5405628E-04,   3.3708513E-04
     +,   3.2044217E-04,   3.0418474E-04,   2.8836640E-04
     +,   2.7303136E-04,   2.5821911E-04,   2.4395956E-04
     +,   2.3027780E-04,   2.1719038E-04,   2.0470873E-04
     +,   1.9283668E-04,   1.8157398E-04,   1.7091414E-04
     +,   1.6084632E-04,   1.5135658E-04,   1.4242664E-04
     +,   1.3403667E-04,   1.2616361E-04,   1.1878377E-04
     +,   1.1187176E-04,   1.0540218E-04,   9.9348763E-05
     +,   9.3686293E-05,   8.8389206E-05,   8.3433340E-05
     +,   7.8794939E-05,   7.4451869E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_ww_mass = Yx/0.0443876810810811
      RETURN
      END
      DOUBLE PRECISION FUNCTION A204_tt_hzonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.1076266E-05,   4.2819585E-05
     +,   4.4591579E-05,   4.6389290E-05,   4.8209597E-05
     +,   5.0049162E-05,   5.1904492E-05,   5.3771957E-05
     +,   5.5647721E-05,   5.7527941E-05,   5.9408587E-05
     +,   6.1285573E-05,   6.3154766E-05,   6.5011991E-05
     +,   6.6853063E-05,   6.8673842E-05,   7.0470225E-05
     +,   7.2238166E-05,   7.3973737E-05,   7.5673139E-05
     +,   7.7332697E-05,   7.8948986E-05,   8.0518672E-05
     +,   8.2038809E-05,   8.3506522E-05,   8.4919368E-05
     +,   8.6275126E-05,   8.7571869E-05,   8.8808061E-05
     +,   8.9982466E-05,   9.1094196E-05,   9.2142764E-05
     +,   9.3128023E-05,   9.4050250E-05,   9.4910043E-05
     +,   9.5708441E-05,   9.6446769E-05,   9.7126816E-05
     +,   9.7750715E-05,   9.8320881E-05,   9.8840181E-05
     +,   9.9311706E-05,   9.9738885E-05,   1.0012543E-04
     +,   1.0047540E-04,   1.0079291E-04,   1.0108249E-04
     +,   1.0134875E-04,   1.0159651E-04,   1.0183067E-04
     +,   1.0205628E-04,   1.0227844E-04,   1.0250233E-04
     +,   1.0273308E-04,   1.0297581E-04,   1.0323562E-04
     +,   1.0351746E-04,   1.0382622E-04,   1.0416653E-04
     +,   1.0454291E-04,   1.0495959E-04,   1.0542062E-04
     +,   1.0592960E-04,   1.0648993E-04,   1.0710464E-04
     +,   1.0777624E-04,   1.0850696E-04,   1.0929846E-04
     +,   1.1015204E-04,   1.1106837E-04,   1.1204772E-04
     +,   1.1308966E-04,   1.1419343E-04,   1.1535745E-04
     +,   1.1657979E-04,   1.1785787E-04,   1.1918854E-04
     +,   1.2056806E-04,   1.2199225E-04,   1.2345646E-04
     +,   1.2495540E-04,   1.2648362E-04,   1.2803503E-04
     +,   1.2960340E-04,   1.3118224E-04,   1.3276479E-04
     +,   1.3434436E-04,   1.3591423E-04,   1.3746764E-04
     +,   1.3899825E-04,   1.4049999E-04,   1.4196718E-04
     +,   1.4339463E-04,   1.4477802E-04,   1.4611383E-04
     +,   1.4739927E-04,   1.4863271E-04,   1.4981354E-04
     +,   1.5094264E-04,   1.5202189E-04,   1.5305483E-04
     +,   1.5404627E-04,   1.5500253E-04,   1.5593144E-04
     +,   1.5684233E-04,   1.5774601E-04,   1.5865461E-04
     +,   1.5958144E-04,   1.6054133E-04,   1.6154985E-04
     +,   1.6262350E-04,   1.6377959E-04,   1.6503579E-04
     +,   1.6641025E-04,   1.6792097E-04,   1.6958642E-04
     +,   1.7142437E-04,   1.7345320E-04,   1.7569063E-04
     +,   1.7815491E-04,   1.8086525E-04,   1.8384145E-04
     +,   1.8710531E-04,   1.9068182E-04,   1.9459963E-04
     +,   1.9889191E-04,   2.0359873E-04,   2.0876658E-04
     +,   2.1445105E-04,   2.2071617E-04,   2.2763625E-04
     +,   2.3529473E-04,   2.4378550E-04,   2.5321060E-04
     +,   2.6368082E-04,   2.7531449E-04,   2.8823430E-04
     +,   3.0256680E-04,   3.1844195E-04,   3.3599077E-04
     +,   3.5534211E-04,   3.7662286E-04,   3.9995735E-04
     +,   4.2546540E-04,   4.5325840E-04,   4.8344344E-04
     +,   5.1612133E-04,   5.5138214E-04,   5.8930845E-04
     +,   6.2997662E-04,   6.7345286E-04,   7.1978575E-04
     +,   7.6900452E-04,   8.2110782E-04,   8.7604451E-04
     +,   9.3369005E-04,   9.9382107E-04,   1.0560927E-03
     +,   1.1200065E-03,   1.1848888E-03,   1.2498958E-03
     +,   1.3140280E-03,   1.3761616E-03,   1.4351265E-03
     +,   1.4898013E-03,   1.5392199E-03,   1.5826833E-03
     +,   1.6198723E-03,   1.6509239E-03,   1.6764612E-03
     +,   1.6975625E-03,   1.7156774E-03,   1.7324791E-03
     +,   1.7496612E-03,   1.7687366E-03,   1.7908203E-03
     +,   1.8164740E-03,   1.8455944E-03,   1.8773985E-03
     +,   1.9104999E-03,   1.9430632E-03,   1.9729992E-03
     +,   1.9982248E-03,   2.0168920E-03,   2.0275812E-03
     +,   2.0294399E-03,   2.0222326E-03,   2.0063028E-03
     +,   1.9824789E-03,   1.9519099E-03,   1.9158785E-03
     +,   1.8756262E-03,   1.8322038E-03,   1.7863639E-03
     +,   1.7385242E-03,   1.6887797E-03,   1.6369839E-03
     +,   1.5828444E-03,   1.5260432E-03,   1.4663546E-03
     +,   1.4037446E-03,   1.3384271E-03,   1.2708850E-03
     +,   1.2018613E-03,   1.1323158E-03,   1.0633436E-03
     +,   9.9610165E-04,   9.3172787E-04,   8.7125931E-04
     +,   8.1556500E-04,   7.6530565E-04,   7.2090985E-04
     +,   6.8256218E-04,   6.5021269E-04,   6.2360876E-04
     +,   6.0232717E-04,   5.8581866E-04,   5.7344959E-04
     +,   5.6454801E-04,   5.5844290E-04,   5.5449340E-04
     +,   5.5211445E-04,   5.5079168E-04,   5.5008911E-04
     +,   5.4964889E-04,   5.4918788E-04,   5.4848858E-04
     +,   5.4738962E-04,   5.4577552E-04,   5.4356613E-04
     +,   5.4070767E-04,   5.3716637E-04,   5.3292175E-04
     +,   5.2796444E-04,   5.2229164E-04,   5.1590777E-04
     +,   5.0882157E-04,   5.0104730E-04,   4.9260433E-04
     +,   4.8351692E-04,   4.7381368E-04,   4.6352894E-04
     +,   4.5270153E-04,   4.4137382E-04,   4.2959207E-04
     +,   4.1740676E-04,   4.0487092E-04,   3.9203893E-04
     +,   3.7896665E-04,   3.6571195E-04,   3.5233126E-04
     +,   3.3888075E-04,   3.2541563E-04,   3.1198937E-04
     +,   2.9865187E-04,   2.8544970E-04,   2.7242702E-04
     +,   2.5962372E-04,   2.4707473E-04,   2.3481087E-04
     +,   2.2285947E-04,   2.1124347E-04,   1.9998111E-04
     +,   1.8908702E-04,   1.7857333E-04,   1.6844801E-04
     +,   1.5871620E-04,   1.4938149E-04,   1.4044509E-04
     +,   1.3190579E-04,   1.2376101E-04,   1.1600710E-04
     +,   1.0863939E-04,   1.0165153E-04,   9.5036346E-05
     +,   8.8786372E-05,   8.2892504E-05,   7.7345765E-05
     +,   7.2135619E-05,   6.7251560E-05,   6.2681924E-05
     +,   5.8415004E-05,   5.4438056E-05,   5.0738425E-05
     +,   4.7302667E-05,   4.4117554E-05,   4.1169380E-05
     +,   3.8444388E-05,   3.5929170E-05,   3.3610144E-05
     +,   3.1474272E-05,   2.9508534E-05,   2.7700637E-05
     +,   2.6038464E-05,   2.4510673E-05,   2.3106293E-05
     +,   2.1815127E-05,   2.0627424E-05,   1.9534218E-05
     +,   1.8527047E-05,   1.7598180E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A204_tt_hzonly_zz_mass = Yx/0.0331333333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3975457E-05,   2.4580433E-05
     +,   2.5176267E-05,   2.5761565E-05,   2.6334941E-05
     +,   2.6895006E-05,   2.7440379E-05,   2.7969703E-05
     +,   2.8481625E-05,   2.8974840E-05,   2.9448063E-05
     +,   2.9900042E-05,   3.0329567E-05,   3.0735497E-05
     +,   3.1116713E-05,   3.1472184E-05,   3.1800922E-05
     +,   3.2102020E-05,   3.2374639E-05,   3.2618009E-05
     +,   3.2831460E-05,   3.3014381E-05,   3.3166263E-05
     +,   3.3286695E-05,   3.3375338E-05,   3.3431952E-05
     +,   3.3456399E-05,   3.3448632E-05,   3.3408702E-05
     +,   3.3336746E-05,   3.3233013E-05,   3.3097836E-05
     +,   3.2931650E-05,   3.2734974E-05,   3.2508418E-05
     +,   3.2252683E-05,   3.1968550E-05,   3.1656888E-05
     +,   3.1318628E-05,   3.0954809E-05,   3.0566491E-05
     +,   3.0154835E-05,   2.9721055E-05,   2.9266417E-05
     +,   2.8792234E-05,   2.8299875E-05,   2.7790742E-05
     +,   2.7266273E-05,   2.6727934E-05,   2.6177220E-05
     +,   2.5615647E-05,   2.5044739E-05,   2.4466037E-05
     +,   2.3881055E-05,   2.3291368E-05,   2.2698483E-05
     +,   2.2103932E-05,   2.1509217E-05,   2.0915832E-05
     +,   2.0325240E-05,   1.9738887E-05,   1.9158166E-05
     +,   1.8584493E-05,   1.8019184E-05,   1.7463530E-05
     +,   1.6918826E-05,   1.6386264E-05,   1.5867048E-05
     +,   1.5362284E-05,   1.4873081E-05,   1.4400446E-05
     +,   1.3945397E-05,   1.3508838E-05,   1.3091682E-05
     +,   1.2694755E-05,   1.2318822E-05,   1.1964635E-05
     +,   1.1632881E-05,   1.1324184E-05,   1.1039112E-05
     +,   1.0778218E-05,   1.0541963E-05,   1.0330794E-05
     +,   1.0145081E-05,   9.9851677E-06,   9.8513301E-06
     +,   9.7438142E-06,   9.6628037E-06,   9.6084450E-06
     +,   9.5808327E-06,   9.5800115E-06,   9.6059885E-06
     +,   9.6587128E-06,   9.7380953E-06,   9.8439978E-06
     +,   9.9762265E-06,   1.0134557E-05,   1.0318694E-05
     +,   1.0528322E-05,   1.0763049E-05,   1.1022458E-05
     +,   1.1306055E-05,   1.1613332E-05,   1.1943692E-05
     +,   1.2296516E-05,   1.2671137E-05,   1.3066818E-05
     +,   1.3482758E-05,   1.3918143E-05,   1.4372101E-05
     +,   1.4843674E-05,   1.5331905E-05,   1.5835734E-05
     +,   1.6354114E-05,   1.6885877E-05,   1.7429888E-05
     +,   1.7984892E-05,   1.8549665E-05,   1.9122866E-05
     +,   1.9703173E-05,   2.0289233E-05,   2.0879617E-05
     +,   2.1472862E-05,   2.2067527E-05,   2.2662141E-05
     +,   2.3255167E-05,   2.3845108E-05,   2.4430401E-05
     +,   2.5009551E-05,   2.5580972E-05,   2.6143169E-05
     +,   2.6694584E-05,   2.7233727E-05,   2.7759083E-05
     +,   2.8269187E-05,   2.8762621E-05,   2.9237961E-05
     +,   2.9693827E-05,   3.0128915E-05,   3.0541963E-05
     +,   3.0931747E-05,   3.1297099E-05,   3.1636941E-05
     +,   3.1950269E-05,   3.2236105E-05,   3.2493597E-05
     +,   3.2721964E-05,   3.2920492E-05,   3.3088560E-05
     +,   3.3225642E-05,   3.3331311E-05,   3.3405213E-05
     +,   3.3447111E-05,   3.3456850E-05,   3.3434371E-05
     +,   3.3379722E-05,   3.3293032E-05,   3.3174543E-05
     +,   3.3024564E-05,   3.2843531E-05,   3.2631935E-05
     +,   3.2390373E-05,   3.2119518E-05,   3.1820146E-05
     +,   3.1493080E-05,   3.1139210E-05,   3.0759529E-05
     +,   3.0355093E-05,   2.9926981E-05,   2.9476336E-05
     +,   2.9004372E-05,   2.8512350E-05,   2.8001534E-05
     +,   2.7473228E-05,   2.6928807E-05,   2.6369609E-05
     +,   2.5796999E-05,   2.5212381E-05,   2.4617162E-05
     +,   2.4012712E-05,   2.3400398E-05,   2.2781611E-05
     +,   2.2157717E-05,   2.1530037E-05,   2.0899844E-05
     +,   2.0268448E-05,   1.9637102E-05,   1.9006995E-05
     +,   1.8379260E-05,   1.7755057E-05,   1.7135439E-05
     +,   1.6521404E-05,   1.5913938E-05,   1.5313975E-05
     +,   1.4722354E-05,   1.4139859E-05,   1.3567248E-05
     +,   1.3005237E-05,   1.2454425E-05,   1.1915369E-05
     +,   1.1388601E-05,   1.0874588E-05,   1.0373715E-05
     +,   9.8863102E-06,   9.4126899E-06,   8.9530777E-06
     +,   8.5076426E-06,   8.0765367E-06,   7.6598590E-06
     +,   7.2576404E-06,   6.8698678E-06,   6.4965120E-06
     +,   6.1375067E-06,   5.7927232E-06,   5.4619995E-06
     +,   5.1451680E-06,   4.8420288E-06,   4.5523338E-06
     +,   4.2758165E-06,   4.0122122E-06,   3.7612112E-06
     +,   3.5224891E-06,   3.2957228E-06,   3.0805738E-06
     +,   2.8766790E-06,   2.6836724E-06,   2.5011882E-06
     +,   2.3288599E-06,   2.1663031E-06,   2.0131367E-06
     +,   1.8689866E-06,   1.7334817E-06,   1.6062429E-06
     +,   1.4868986E-06,   1.3750905E-06,   1.2704581E-06
     +,   1.1726472E-06,   1.0813175E-06,   9.9613783E-07
     +,   9.1677873E-07,   8.4292236E-07,   7.7426478E-07
     +,   7.1051261E-07,   6.5137777E-07,   5.9658447E-07
     +,   5.4587076E-07,   4.9898580E-07,   4.5568581E-07
     +,   4.1573884E-07,   3.7892713E-07,   3.4504043E-07
     +,   3.1387899E-07,   2.8525486E-07,   2.5899081E-07
     +,   2.3491720E-07,   2.1287399E-07,   1.9271246E-07
     +,   1.7429190E-07,   1.5747938E-07,   1.4215026E-07
     +,   1.2818890E-07,   1.1548730E-07,   1.0394333E-07
     +,   9.3462319E-08,   8.3957048E-08,   7.5345362E-08
     +,   6.7551312E-08,   6.0504789E-08,   5.4141001E-08
     +,   4.8399603E-08,   4.3224986E-08,   3.8566210E-08
     +,   3.4376342E-08,   3.0611961E-08,   2.7233293E-08
     +,   2.4204152E-08,   2.1491013E-08,   1.9063593E-08
     +,   1.6893894E-08,   1.4956695E-08,   1.3228737E-08
     +,   1.1689131E-08,   1.0318658E-08,   9.1000798E-09
     +,   8.0175999E-09,   7.0570625E-09,   6.2055849E-09
     +,   5.4515388E-09,   4.7844924E-09,   4.1949790E-09
     +,   3.6745562E-09,   3.2155612E-09,   2.8111882E-09
     +,   2.4552753E-09,   2.1423525E-09,   1.8674922E-09
     +,   1.6263270E-09,   1.4149273E-09,   1.2298191E-09
     +,   1.0678863E-09,   9.2638192E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_eez_mass = Yx/0.0012565
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2781135E-04,   1.2689075E-04
     +,   1.2561884E-04,   1.2400738E-04,   1.2207108E-04
     +,   1.1982742E-04,   1.1729639E-04,   1.1450033E-04
     +,   1.1146365E-04,   1.0821231E-04,   1.0477394E-04
     +,   1.0117726E-04,   9.7451761E-05,   9.3627496E-05
     +,   8.9734778E-05,   8.5803789E-05,   8.1864462E-05
     +,   7.7946075E-05,   7.4077150E-05,   7.0285183E-05
     +,   6.6596484E-05,   6.3036030E-05,   5.9627393E-05
     +,   5.6392379E-05,   5.3351530E-05,   5.0523340E-05
     +,   4.7924816E-05,   4.5571152E-05,   4.3475840E-05
     +,   4.1650637E-05,   4.0105613E-05,   3.8849135E-05
     +,   3.7887927E-05,   3.7227081E-05,   3.6870053E-05
     +,   3.6818710E-05,   3.7073314E-05,   3.7632541E-05
     +,   3.8493479E-05,   3.9651546E-05,   4.1100615E-05
     +,   4.2832857E-05,   4.4838769E-05,   4.7107180E-05
     +,   4.9625167E-05,   5.2378105E-05,   5.5349639E-05
     +,   5.8521680E-05,   6.1874460E-05,   6.5386543E-05
     +,   6.9034941E-05,   7.2795134E-05,   7.6641183E-05
     +,   8.0546175E-05,   8.4481639E-05,   8.8418732E-05
     +,   9.2327646E-05,   9.6178264E-05,   9.9940255E-05
     +,   1.0358348E-04,   1.0707822E-04,   1.1039548E-04
     +,   1.1350715E-04,   1.1638671E-04,   1.1900928E-04
     +,   1.2135167E-04,   1.2339320E-04,   1.2511539E-04
     +,   1.2650269E-04,   1.2754227E-04,   1.2822443E-04
     +,   1.2854258E-04,   1.2849340E-04,   1.2807679E-04
     +,   1.2729595E-04,   1.2615715E-04,   1.2466990E-04
     +,   1.2284663E-04,   1.2070243E-04,   1.1825491E-04
     +,   1.1552417E-04,   1.1253203E-04,   1.0930235E-04
     +,   1.0586001E-04,   1.0223134E-04,   9.8443015E-05
     +,   9.4522540E-05,   9.0497015E-05,   8.6393804E-05
     +,   8.2239392E-05,   7.8059413E-05,   7.3878713E-05
     +,   6.9720903E-05,   6.5607775E-05,   6.1559556E-05
     +,   5.7595062E-05,   5.3730735E-05,   4.9981569E-05
     +,   4.6360125E-05,   4.2877458E-05,   3.9542214E-05
     +,   3.6361576E-05,   3.3340482E-05,   3.0482521E-05
     +,   2.7789361E-05,   2.5261170E-05,   2.2896911E-05
     +,   2.0694290E-05,   1.8649740E-05,   1.6758766E-05
     +,   1.5016251E-05,   1.3416150E-05,   1.1952114E-05
     +,   1.0617157E-05,   9.4042098E-06,   8.3058330E-06
     +,   7.3146634E-06,   6.4232122E-06,   5.6241997E-06
     +,   4.9104115E-06,   4.2748570E-06,   3.7108541E-06
     +,   3.2120108E-06,   2.7722256E-06,   2.3857592E-06
     +,   2.0472719E-06,   1.7517441E-06,   1.4945722E-06
     +,   1.2714795E-06,   1.0785808E-06,   9.1230982E-07
     +,   7.6945423E-07,   6.4709729E-07,   5.4263450E-07
     +,   4.5372656E-07,   3.7829162E-07,   3.1449062E-07
     +,   2.6069952E-07,   2.1548699E-07,   1.7760208E-07
     +,   1.4595646E-07,   1.1960528E-07,   9.7729561E-08
     +,   7.9624577E-08,   6.4687384E-08,   5.2401187E-08
     +,   4.2326096E-08,   3.4089727E-08,   2.7377318E-08
     +,   2.1923359E-08,   1.7505249E-08,   1.3937289E-08
     +,   1.1064708E-08,   8.7589083E-09,   6.9136319E-09
     +,   5.4413989E-09,   4.2703792E-09,   3.3417318E-09
     +,   2.6074825E-09,   2.0287270E-09,   1.5738895E-09
     +,   1.2175040E-09,   9.3910635E-10,   7.2228884E-10
     +,   5.5393229E-10,   4.2359088E-10,   3.2298722E-10
     +,   2.4557070E-10,   1.8617294E-10,   1.4073458E-10
     +,   1.0607996E-10,   7.9729626E-11,   5.9752210E-11
     +,   4.4651130E-11,   3.3270851E-11,   2.4719751E-11
     +,   1.8313379E-11,   1.3528251E-11,   9.9648007E-12
     +,   7.3188547E-12,   5.3599629E-12,   3.9140722E-12
     +,   2.8500284E-12,   2.0692777E-12,   1.4980688E-12
     +,   1.0814187E-12,   7.7841173E-13,   5.5869301E-13
     +,   3.9983465E-13,   2.8532577E-13,   2.0302558E-13
     +,   1.4404691E-13,   1.0190752E-13,   7.1888777E-14
     +,   5.0566762E-14,   3.5466100E-14,   2.4803332E-14
     +,   1.7296570E-14,   1.2027027E-14,   8.3387310E-15
     +,   5.7648880E-15,   3.9740740E-15,   2.7316666E-15
     +,   1.8722528E-15,   1.2795446E-15,   8.7195477E-16
     +,   5.9248404E-16,   4.0142728E-16,   2.7120155E-16
     +,   1.8269462E-16,   1.2271621E-16,   8.2191564E-17
     +,   5.4891500E-17,   3.6553912E-17,   2.4271972E-17
     +,   1.6070328E-17,   1.0609587E-17,   6.9842772E-18
     +,   4.5844302E-18,   3.0005791E-18,   1.9582765E-18
     +,   1.2743379E-18,   8.2688360E-19,   5.3500569E-19
     +,   3.4516086E-19,   2.2203714E-19,   1.4242313E-19
     +,   9.1093969E-20,   5.8096003E-20,   3.6944268E-20
     +,   2.3425765E-20,   1.4811462E-20,   9.3379103E-21
     +,   5.8700791E-21,   3.6795445E-21,   2.2997998E-21
     +,   1.4332773E-21,   8.9067228E-22,   5.5190143E-22
     +,   3.4099988E-22,   2.1008152E-22,   1.2905377E-22
     +,   7.9051354E-23,   4.8283144E-23,   2.9405210E-23
     +,   1.7856741E-23,   1.0812703E-23,   6.5285328E-24
     +,   3.9304091E-24,   2.3594861E-24,   1.4123575E-24
     +,   8.4296799E-25,   5.0168373E-25,   2.9771667E-25
     +,   1.7616668E-25,   1.0394103E-25,   6.1150174E-26
     +,   3.5872855E-26,   2.0983762E-26,   1.2238833E-26
     +,   7.1177741E-27,   4.1276939E-27,   2.3868038E-27
     +,   1.3761637E-27,   7.9118131E-28,   4.5355968E-28
     +,   2.5925798E-28,   1.4776696E-28,   8.3980482E-29
     +,   4.7591589E-29,   2.6891889E-29,   1.5151709E-29
     +,   8.5125442E-30,   4.7687523E-30,   2.6637345E-30
     +,   1.4836609E-30,   8.2397866E-31,   4.5630617E-31
     +,   2.5196352E-31,   1.3873142E-31,   7.6164552E-32
     +,   4.1695102E-32,   2.2759349E-32,   1.2387789E-32
     +,   6.7230585E-33,   3.6382641E-33,   1.9632203E-33
     +,   1.0563020E-33,   5.6671492E-34,   3.0316481E-34
     +,   1.6171502E-34,   8.6012758E-35,   4.5617644E-35
     +,   2.4123506E-35,   1.2720635E-35,   6.6882852E-36
     +,   3.5065354E-36,   1.8330848E-36,   9.5553004E-37
     +,   4.9664237E-37,   2.5739727E-37
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_qq_mass = Yx/0.002800525
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.1105398E-05,   2.1225942E-05
     +,   2.1341446E-05,   2.1451850E-05,   2.1557138E-05
     +,   2.1657323E-05,   2.1752472E-05,   2.1842696E-05
     +,   2.1928146E-05,   2.2009041E-05,   2.2085645E-05
     +,   2.2158280E-05,   2.2227323E-05,   2.2293221E-05
     +,   2.2356473E-05,   2.2417646E-05,   2.2477367E-05
     +,   2.2536327E-05,   2.2595281E-05,   2.2655040E-05
     +,   2.2716482E-05,   2.2780541E-05,   2.2848204E-05
     +,   2.2920523E-05,   2.2998582E-05,   2.3083530E-05
     +,   2.3176550E-05,   2.3278862E-05,   2.3391738E-05
     +,   2.3516452E-05,   2.3654320E-05,   2.3806675E-05
     +,   2.3974853E-05,   2.4160210E-05,   2.4364093E-05
     +,   2.4587844E-05,   2.4832796E-05,   2.5100253E-05
     +,   2.5391517E-05,   2.5707821E-05,   2.6050402E-05
     +,   2.6420421E-05,   2.6819002E-05,   2.7247204E-05
     +,   2.7706035E-05,   2.8196426E-05,   2.8719236E-05
     +,   2.9275239E-05,   2.9865143E-05,   3.0489547E-05
     +,   3.1148968E-05,   3.1843811E-05,   3.2574389E-05
     +,   3.3340930E-05,   3.4143486E-05,   3.4982077E-05
     +,   3.5856541E-05,   3.6766618E-05,   3.7711932E-05
     +,   3.8691960E-05,   3.9706047E-05,   4.0753443E-05
     +,   4.1833162E-05,   4.2944193E-05,   4.4085358E-05
     +,   4.5255256E-05,   4.6452449E-05,   4.7675247E-05
     +,   4.8921924E-05,   5.0190465E-05,   5.1478881E-05
     +,   5.2784850E-05,   5.4106084E-05,   5.5439970E-05
     +,   5.6783912E-05,   5.8135145E-05,   5.9490692E-05
     +,   6.0847473E-05,   6.2202344E-05,   6.3552085E-05
     +,   6.4893211E-05,   6.6222361E-05,   6.7535890E-05
     +,   6.8830268E-05,   7.0101756E-05,   7.1346738E-05
     +,   7.2561401E-05,   7.3742129E-05,   7.4885123E-05
     +,   7.5986769E-05,   7.7043500E-05,   7.8051737E-05
     +,   7.9008008E-05,   7.9909056E-05,   8.0751684E-05
     +,   8.1532882E-05,   8.2249826E-05,   8.2899831E-05
     +,   8.3480547E-05,   8.3989762E-05,   8.4425577E-05
     +,   8.4786334E-05,   8.5070693E-05,   8.5277585E-05
     +,   8.5406289E-05,   8.5456362E-05,   8.5427724E-05
     +,   8.5320607E-05,   8.5135602E-05,   8.4873609E-05
     +,   8.4535895E-05,   8.4124003E-05,   8.3639876E-05
     +,   8.3085695E-05,   8.2464001E-05,   8.1777573E-05
     +,   8.1029524E-05,   8.0223137E-05,   7.9362020E-05
     +,   7.8449913E-05,   7.7490768E-05,   7.6488701E-05
     +,   7.5448021E-05,   7.4373056E-05,   7.3268217E-05
     +,   7.2138064E-05,   7.0987066E-05,   6.9819798E-05
     +,   6.8640678E-05,   6.7454195E-05,   6.6264613E-05
     +,   6.5076281E-05,   6.3893145E-05,   6.2719242E-05
     +,   6.1558305E-05,   6.0413826E-05,   5.9289174E-05
     +,   5.8187507E-05,   5.7111629E-05,   5.6064120E-05
     +,   5.5047352E-05,   5.4063414E-05,   5.3114087E-05
     +,   5.2200856E-05,   5.1325031E-05,   5.0487561E-05
     +,   4.9689133E-05,   4.8930251E-05,   4.8211143E-05
     +,   4.7531750E-05,   4.6891830E-05,   4.6290923E-05
     +,   4.5728419E-05,   4.5203447E-05,   4.4715020E-05
     +,   4.4262000E-05,   4.3843145E-05,   4.3457057E-05
     +,   4.3102253E-05,   4.2777196E-05,   4.2480267E-05
     +,   4.2209787E-05,   4.1964082E-05,   4.1741434E-05
     +,   4.1540115E-05,   4.1358409E-05,   4.1194613E-05
     +,   4.1047057E-05,   4.0914092E-05,   4.0794093E-05
     +,   4.0685518E-05,   4.0586834E-05,   4.0496579E-05
     +,   4.0413335E-05,   4.0335734E-05,   4.0262472E-05
     +,   4.0192292E-05,   4.0124007E-05,   4.0056439E-05
     +,   3.9988507E-05,   3.9919130E-05,   3.9847320E-05
     +,   3.9772087E-05,   3.9692510E-05,   3.9607683E-05
     +,   3.9516755E-05,   3.9418886E-05,   3.9313280E-05
     +,   3.9199160E-05,   3.9075803E-05,   3.8942482E-05
     +,   3.8798513E-05,   3.8643240E-05,   3.8476042E-05
     +,   3.8296326E-05,   3.8103521E-05,   3.7897091E-05
     +,   3.7676557E-05,   3.7441463E-05,   3.7191385E-05
     +,   3.6925958E-05,   3.6644873E-05,   3.6347836E-05
     +,   3.6034624E-05,   3.5705089E-05,   3.5359106E-05
     +,   3.4996614E-05,   3.4617624E-05,   3.4222216E-05
     +,   3.3810516E-05,   3.3382694E-05,   3.2939020E-05
     +,   3.2479827E-05,   3.2005479E-05,   3.1516403E-05
     +,   3.1013114E-05,   3.0496185E-05,   2.9966212E-05
     +,   2.9423833E-05,   2.8869801E-05,   2.8304859E-05
     +,   2.7729780E-05,   2.7145419E-05,   2.6552669E-05
     +,   2.5952400E-05,   2.5345520E-05,   2.4732986E-05
     +,   2.4115778E-05,   2.3494831E-05,   2.2871105E-05
     +,   2.2245589E-05,   2.1619267E-05,   2.0993079E-05
     +,   2.0367948E-05,   1.9744848E-05,   1.9124664E-05
     +,   1.8508259E-05,   1.7896511E-05,   1.7290267E-05
     +,   1.6690301E-05,   1.6097352E-05,   1.5512158E-05
     +,   1.4935415E-05,   1.4367746E-05,   1.3809731E-05
     +,   1.3261935E-05,   1.2724885E-05,   1.2199031E-05
     +,   1.1684769E-05,   1.1182506E-05,   1.0692555E-05
     +,   1.0215188E-05,   9.7506581E-06,   9.2991804E-06
     +,   8.8608967E-06,   8.4359099E-06,   8.0243135E-06
     +,   7.6261626E-06,   7.2414473E-06,   6.8701261E-06
     +,   6.5121540E-06,   6.1674491E-06,   5.8358796E-06
     +,   5.5172914E-06,   5.2115315E-06,   4.9183968E-06
     +,   4.6376640E-06,   4.3691080E-06,   4.1124867E-06
     +,   3.8675248E-06,   3.6339350E-06,   3.4114337E-06
     +,   3.1997270E-06,   2.9984956E-06,   2.8074176E-06
     +,   2.6261825E-06,   2.4544511E-06,   2.2919069E-06
     +,   2.1382068E-06,   1.9930308E-06,   1.8560385E-06
     +,   1.7269114E-06,   1.6053148E-06,   1.4909352E-06
     +,   1.3834486E-06,   1.2825496E-06,   1.1879280E-06
     +,   1.0992819E-06,   1.0163241E-06,   9.3876457E-07
     +,   8.6633105E-07,   7.9874900E-07,   7.3576246E-07
     +,   6.7711545E-07,   6.2256817E-07,   5.7188259E-07
     +,   5.2483682E-07,   4.8121120E-07,   4.4080124E-07
     +,   4.0340569E-07,   3.6883782E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_ww_mass = Yx/0.00288910588235294
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_haonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.7696850E-05,   1.8873840E-05
     +,   2.0092211E-05,   2.1350184E-05,   2.2645700E-05
     +,   2.3976423E-05,   2.5339767E-05,   2.6732901E-05
     +,   2.8152741E-05,   2.9596093E-05,   3.1059521E-05
     +,   3.2539490E-05,   3.4032364E-05,   3.5534456E-05
     +,   3.7042064E-05,   3.8551530E-05,   4.0059265E-05
     +,   4.1561820E-05,   4.3055898E-05,   4.4538432E-05
     +,   4.6006615E-05,   4.7457925E-05,   4.8890146E-05
     +,   5.0301533E-05,   5.1690542E-05,   5.3056214E-05
     +,   5.4397879E-05,   5.5715322E-05,   5.7008736E-05
     +,   5.8278692E-05,   5.9526141E-05,   6.0752354E-05
     +,   6.1958919E-05,   6.3147629E-05,   6.4320506E-05
     +,   6.5479697E-05,   6.6627406E-05,   6.7765810E-05
     +,   6.8897098E-05,   7.0023169E-05,   7.1145820E-05
     +,   7.2266506E-05,   7.3386327E-05,   7.4505995E-05
     +,   7.5625700E-05,   7.6745142E-05,   7.7863493E-05
     +,   7.8979312E-05,   8.0090576E-05,   8.1194688E-05
     +,   8.2288461E-05,   8.3368133E-05,   8.4429434E-05
     +,   8.5467655E-05,   8.6477565E-05,   8.7453678E-05
     +,   8.8390210E-05,   8.9281144E-05,   9.0120389E-05
     +,   9.0901827E-05,   9.1619411E-05,   9.2267270E-05
     +,   9.2839735E-05,   9.3331560E-05,   9.3737894E-05
     +,   9.4054303E-05,   9.4277035E-05,   9.4402807E-05
     +,   9.4429095E-05,   9.4353985E-05,   9.4176285E-05
     +,   9.3895498E-05,   9.3511815E-05,   9.3026159E-05
     +,   9.2440037E-05,   9.1755552E-05,   9.0975445E-05
     +,   9.0103000E-05,   8.9141860E-05,   8.8096080E-05
     +,   8.6970118E-05,   8.5768574E-05,   8.4496387E-05
     +,   8.3158477E-05,   8.1759972E-05,   8.0305850E-05
     +,   7.8801240E-05,   7.7250988E-05,   7.5659969E-05
     +,   7.4032825E-05,   7.2373914E-05,   7.0687609E-05
     +,   6.8977941E-05,   6.7248737E-05,   6.5503533E-05
     +,   6.3745829E-05,   6.1978732E-05,   6.0205417E-05
     +,   5.8428599E-05,   5.6651181E-05,   5.4875654E-05
     +,   5.3104690E-05,   5.1340678E-05,   4.9586190E-05
     +,   4.7843616E-05,   4.6115383E-05,   4.4404020E-05
     +,   4.2712130E-05,   4.1042254E-05,   3.9397011E-05
     +,   3.7779235E-05,   3.6191643E-05,   3.4637236E-05
     +,   3.3118878E-05,   3.1639713E-05,   3.0202735E-05
     +,   2.8811193E-05,   2.7468199E-05,   2.6177051E-05
     +,   2.4940948E-05,   2.3763088E-05,   2.2646747E-05
     +,   2.1595155E-05,   2.0611444E-05,   1.9698684E-05
     +,   1.8859984E-05,   1.8098250E-05,   1.7416407E-05
     +,   1.6817175E-05,   1.6303256E-05,   1.5877140E-05
     +,   1.5541251E-05,   1.5297814E-05,   1.5148928E-05
     +,   1.5096505E-05,   1.5142271E-05,   1.5287771E-05
     +,   1.5534313E-05,   1.5882999E-05,   1.6334696E-05
     +,   1.6889982E-05,   1.7549148E-05,   1.8312217E-05
     +,   1.9178917E-05,   2.0148538E-05,   2.1220103E-05
     +,   2.2392254E-05,   2.3663173E-05,   2.5030591E-05
     +,   2.6491896E-05,   2.8044036E-05,   2.9683368E-05
     +,   3.1405772E-05,   3.3206750E-05,   3.5081310E-05
     +,   3.7023849E-05,   3.9028248E-05,   4.1088053E-05
     +,   4.3196349E-05,   4.5345532E-05,   4.7527818E-05
     +,   4.9734990E-05,   5.1958374E-05,   5.4188935E-05
     +,   5.6417513E-05,   5.8634749E-05,   6.0830953E-05
     +,   6.2996340E-05,   6.5121225E-05,   6.7195906E-05
     +,   6.9210699E-05,   7.1156013E-05,   7.3022667E-05
     +,   7.4801756E-05,   7.6484554E-05,   7.8062956E-05
     +,   7.9529360E-05,   8.0876591E-05,   8.2098100E-05
     +,   8.3188148E-05,   8.4141633E-05,   8.4954125E-05
     +,   8.5622087E-05,   8.6142711E-05,   8.6514097E-05
     +,   8.6735119E-05,   8.6805507E-05,   8.6725806E-05
     +,   8.6497428E-05,   8.6122549E-05,   8.5604108E-05
     +,   8.4945787E-05,   8.4151958E-05,   8.3227715E-05
     +,   8.2178645E-05,   8.1010861E-05,   7.9731064E-05
     +,   7.8346362E-05,   7.6864118E-05,   7.5292002E-05
     +,   7.3637988E-05,   7.1910210E-05,   7.0116825E-05
     +,   6.8265945E-05,   6.6365901E-05,   6.4424690E-05
     +,   6.2450214E-05,   6.0450297E-05,   5.8432517E-05
     +,   5.6404046E-05,   5.4371754E-05,   5.2342293E-05
     +,   5.0321934E-05,   4.8316437E-05,   4.6331155E-05
     +,   4.4371151E-05,   4.2441054E-05,   4.0544950E-05
     +,   3.8686492E-05,   3.6869103E-05,   3.5095603E-05
     +,   3.3368440E-05,   3.1689768E-05,   3.0061370E-05
     +,   2.8484594E-05,   2.6960433E-05,   2.5489699E-05
     +,   2.4072899E-05,   2.2710170E-05,   2.1401442E-05
     +,   2.0146483E-05,   1.8944871E-05,   1.7795926E-05
     +,   1.6698808E-05,   1.5652662E-05,   1.4656389E-05
     +,   1.3708802E-05,   1.2808693E-05,   1.1954769E-05
     +,   1.1145635E-05,   1.0379844E-05,   9.6559752E-06
     +,   8.9725736E-06,   8.3281311E-06,   7.7211316E-06
     +,   7.1501031E-06,   6.6135767E-06,   6.1100623E-06
     +,   5.6380877E-06,   5.1962520E-06,   4.7831309E-06
     +,   4.3973300E-06,   4.0375166E-06,   3.7023826E-06
     +,   3.3906356E-06,   3.1010188E-06,   2.8323341E-06
     +,   2.5834190E-06,   2.3531322E-06,   2.1403750E-06
     +,   1.9441011E-06,   1.7633042E-06,   1.5970047E-06
     +,   1.4442653E-06,   1.3042029E-06,   1.1759596E-06
     +,   1.0587185E-06,   9.5170873E-07,   8.5419748E-07
     +,   7.6548258E-07,   6.8490101E-07,   6.1183056E-07
     +,   5.4568460E-07,   4.8590596E-07,   4.3197232E-07
     +,   3.8339917E-07,   3.3972668E-07,   3.0053170E-07
     +,   2.6541494E-07,   2.3400982E-07,   2.0597228E-07
     +,   1.8098785E-07,   1.5876289E-07,   1.3902957E-07
     +,   1.2153941E-07,   1.0606686E-07,   9.2403766E-08
     +,   8.0360508E-08,   6.9765377E-08,   6.0460941E-08
     +,   5.2305651E-08,   4.5170619E-08,   3.8940165E-08
     +,   3.3509544E-08,   2.8785278E-08,   2.4682972E-08
     +,   2.1127684E-08,   1.8052118E-08,   1.5396742E-08
     +,   1.3108375E-08,   1.1140131E-08
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_haonly_zz_mass = Yx/0.00310578947368421
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1508123E-06,   1.3357155E-06
     +,   1.5457656E-06,   1.7835937E-06,   2.0519833E-06
     +,   2.3538564E-06,   2.6922601E-06,   3.0703497E-06
     +,   3.4913555E-06,   3.9585871E-06,   4.4753642E-06
     +,   5.0449953E-06,   5.6707536E-06,   6.3558091E-06
     +,   7.1032009E-06,   7.9157780E-06,   8.7961444E-06
     +,   9.7466145E-06,   1.0769146E-05,   1.1865291E-05
     +,   1.3036140E-05,   1.4282265E-05,   1.5603655E-05
     +,   1.6999771E-05,   1.8469273E-05,   2.0010286E-05
     +,   2.1620133E-05,   2.3295437E-05,   2.5032072E-05
     +,   2.6825175E-05,   2.8669159E-05,   3.0557730E-05
     +,   3.2483924E-05,   3.4440134E-05,   3.6418183E-05
     +,   3.8409369E-05,   4.0404557E-05,   4.2394186E-05
     +,   4.4368557E-05,   4.6317549E-05,   4.8231159E-05
     +,   5.0099268E-05,   5.1911862E-05,   5.3659165E-05
     +,   5.5331690E-05,   5.6920384E-05,   5.8416710E-05
     +,   5.9812770E-05,   6.1101404E-05,   6.2276296E-05
     +,   6.3332096E-05,   6.4264503E-05,   6.5070359E-05
     +,   6.5747779E-05,   6.6296183E-05,   6.6716391E-05
     +,   6.7010667E-05,   6.7182773E-05,   6.7237946E-05
     +,   6.7182897E-05,   6.7025714E-05,   6.6775807E-05
     +,   6.6443761E-05,   6.6041117E-05,   6.5580120E-05
     +,   6.5073567E-05,   6.4534353E-05,   6.3975269E-05
     +,   6.3408530E-05,   6.2845604E-05,   6.2296727E-05
     +,   6.1770821E-05,   6.1275161E-05,   6.0815408E-05
     +,   6.0395596E-05,   6.0018334E-05,   5.9685255E-05
     +,   5.9397553E-05,   5.9156679E-05,   5.8965379E-05
     +,   5.8828799E-05,   5.8755722E-05,   5.8759888E-05
     +,   5.8861409E-05,   5.9087979E-05,   5.9476104E-05
     +,   6.0071761E-05,   6.0931136E-05,   6.2120278E-05
     +,   6.3714753E-05,   6.5798340E-05,   6.8460839E-05
     +,   7.1795475E-05,   7.5895754E-05,   8.0851481E-05
     +,   8.6743748E-05,   9.3641487E-05,   1.0159535E-04
     +,   1.1063489E-04,   1.2076264E-04,   1.3195303E-04
     +,   1.4414750E-04,   1.5725616E-04,   1.7115432E-04
     +,   1.8568715E-04,   2.0067046E-04,   2.1589368E-04
     +,   2.3112560E-04,   2.4612102E-04,   2.6062626E-04
     +,   2.7438483E-04,   2.8714776E-04,   2.9867765E-04
     +,   3.0875919E-04,   3.1720279E-04,   3.2385378E-04
     +,   3.2859526E-04,   3.3135433E-04,   3.3210369E-04
     +,   3.3086320E-04,   3.2769996E-04,   3.2272510E-04
     +,   3.1609033E-04,   3.0798148E-04,   2.9861074E-04
     +,   2.8820930E-04,   2.7701620E-04,   2.6527085E-04
     +,   2.5320155E-04,   2.4102040E-04,   2.2891337E-04
     +,   2.1703861E-04,   2.0552069E-04,   1.9445257E-04
     +,   1.8389443E-04,   1.7387744E-04,   1.6440862E-04
     +,   1.5547508E-04,   1.4704884E-04,   1.3909279E-04
     +,   1.3156603E-04,   1.2442740E-04,   1.1763819E-04
     +,   1.1116487E-04,   1.0498086E-04,   9.9065488E-05
     +,   9.3404415E-05,   8.7988876E-05,   8.2814164E-05
     +,   7.7877899E-05,   7.3179166E-05,   6.8717673E-05
     +,   6.4492546E-05,   6.0501454E-05,   5.6740708E-05
     +,   5.3205389E-05,   4.9889226E-05,   4.6784669E-05
     +,   4.3883538E-05,   4.1177605E-05,   3.8658414E-05
     +,   3.6317793E-05,   3.4148237E-05,   3.2142780E-05
     +,   3.0294917E-05,   2.8598683E-05,   2.7048603E-05
     +,   2.5639445E-05,   2.4365938E-05,   2.3222732E-05
     +,   2.2204325E-05,   2.1304841E-05,   2.0517919E-05
     +,   1.9836762E-05,   1.9254185E-05,   1.8762539E-05
     +,   1.8353849E-05,   1.8019935E-05,   1.7752483E-05
     +,   1.7543156E-05,   1.7383723E-05,   1.7266184E-05
     +,   1.7182852E-05,   1.7126433E-05,   1.7090106E-05
     +,   1.7067568E-05,   1.7053082E-05,   1.7041477E-05
     +,   1.7028158E-05,   1.7009124E-05,   1.6980912E-05
     +,   1.6940596E-05,   1.6885759E-05,   1.6814447E-05
     +,   1.6725131E-05,   1.6616679E-05,   1.6488320E-05
     +,   1.6339598E-05,   1.6170339E-05,   1.5980615E-05
     +,   1.5770733E-05,   1.5541196E-05,   1.5292660E-05
     +,   1.5025928E-05,   1.4741948E-05,   1.4441747E-05
     +,   1.4126444E-05,   1.3797237E-05,   1.3455393E-05
     +,   1.3102194E-05,   1.2738951E-05,   1.2367019E-05
     +,   1.1987760E-05,   1.1602507E-05,   1.1212583E-05
     +,   1.0819316E-05,   1.0424005E-05,   1.0027888E-05
     +,   9.6321610E-06,   9.2380124E-06,   8.8465358E-06
     +,   8.4587673E-06,   8.0757109E-06,   7.6983015E-06
     +,   7.3273832E-06,   6.9637308E-06,   6.6080720E-06
     +,   6.2610638E-06,   5.9232671E-06,   5.5951718E-06
     +,   5.2772220E-06,   4.9697878E-06,   4.6731548E-06
     +,   4.3875425E-06,   4.1131375E-06,   3.8500370E-06
     +,   3.5982839E-06,   3.3578838E-06,   3.1287921E-06
     +,   2.9109015E-06,   2.7040642E-06,   2.5081085E-06
     +,   2.3228254E-06,   2.1479618E-06,   1.9832398E-06
     +,   1.8283677E-06,   1.6830337E-06,   1.5468992E-06
     +,   1.4196119E-06,   1.3008233E-06,   1.1901640E-06
     +,   1.0872608E-06,   9.9174611E-07,   9.0325068E-07
     +,   8.2140247E-07,   7.4583380E-07,   6.7618862E-07
     +,   6.1211756E-07,   5.5327564E-07,   4.9932879E-07
     +,   4.4995753E-07,   4.0485324E-07,   3.6371696E-07
     +,   3.2626295E-07,   2.9222224E-07,   2.6133563E-07
     +,   2.3335760E-07,   2.0805840E-07,   1.8522080E-07
     +,   1.6463963E-07,   1.4612235E-07,   1.2949087E-07
     +,   1.1457839E-07,   1.0122932E-07,   8.9299249E-08
     +,   7.8655837E-08,   6.9175464E-08,   6.0745613E-08
     +,   5.3261751E-08,   4.6629182E-08,   4.0760355E-08
     +,   3.5576232E-08,   3.1004127E-08,   2.6978705E-08
     +,   2.3440130E-08,   2.0334864E-08,   1.7614166E-08
     +,   1.5234235E-08,   1.3155915E-08,   1.1343813E-08
     +,   9.7665023E-09,   8.3956948E-09,   7.2063586E-09
     +,   6.1760823E-09,   5.2850888E-09,   4.5157376E-09
     +,   3.8525414E-09,   3.2817367E-09,   2.7912710E-09
     +,   2.3704891E-09,   2.0100899E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_eez_mass = Yx/0.0040208
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0631210E-20,   2.1015698E-20
     +,   4.1281825E-20,   8.0580303E-20,   1.5629804E-19
     +,   3.0125248E-19,   5.7698133E-19,   1.0981042E-18
     +,   2.0767103E-18,   3.9027117E-18,   7.2880353E-18
     +,   1.3524032E-17,   2.4937709E-17,   4.5694168E-17
     +,   8.3199222E-17,   1.5053352E-16,   2.7064574E-16
     +,   4.8353024E-16,   8.5842734E-16,   1.5143938E-15
     +,   2.6547935E-15,   4.6246597E-15,   8.0054066E-15
     +,   1.3770599E-14,   2.3538185E-14,   3.9981304E-14
     +,   6.7484077E-14,   1.1318993E-13,   1.8865812E-13
     +,   3.1246834E-13,   5.1428198E-13,   8.4112497E-13
     +,   1.3670564E-12,   2.2078916E-12,   3.5435524E-12
     +,   5.6515634E-12,   8.9571510E-12,   1.4107147E-11
     +,   2.2079477E-11,   3.4340562E-11,   5.3077012E-11
     +,   8.1523691E-11,   1.2443475E-10,   1.8874760E-10
     +,   2.8451563E-10,   4.2620357E-10,   6.3447975E-10
     +,   9.3866226E-10,   1.3800501E-09,   2.0164010E-09
     +,   2.9279104E-09,   4.2251465E-09,   6.0593810E-09
     +,   8.6363050E-09,   1.2233071E-08,   1.7221096E-08
     +,   2.4093801E-08,   3.3502175E-08,   4.6298645E-08
     +,   6.3590917E-08,   8.6807702E-08,   1.1777806E-07
     +,   1.5882243E-07,   2.1286796E-07,   2.8357550E-07
     +,   3.7547861E-07,   4.9416599E-07,   6.4644325E-07
     +,   8.4056518E-07,   1.0864135E-06,   1.3957755E-06
     +,   1.7825121E-06,   2.2628747E-06,   2.8556176E-06
     +,   3.5823043E-06,   4.4674457E-06,   5.5385394E-06
     +,   6.8261625E-06,   8.3640252E-06,   1.0188811E-05
     +,   1.2339722E-05,   1.4858542E-05,   1.7788570E-05
     +,   2.1174637E-05,   2.5061483E-05,   2.9493736E-05
     +,   3.4513752E-05,   4.0161536E-05,   4.6472134E-05
     +,   5.3475407E-05,   6.1194136E-05,   6.9642025E-05
     +,   7.8822675E-05,   8.8728957E-05,   9.9341436E-05
     +,   1.1062626E-04,   1.2253705E-04,   1.3501153E-04
     +,   1.4797477E-04,   1.6133618E-04,   1.7499369E-04
     +,   1.8883146E-04,   2.0272490E-04,   2.1653899E-04
     +,   2.3013356E-04,   2.4336437E-04,   2.5608487E-04
     +,   2.6814989E-04,   2.7941910E-04,   2.8975887E-04
     +,   2.9904392E-04,   3.0716229E-04,   3.1401464E-04
     +,   3.1951879E-04,   3.2360884E-04,   3.2623834E-04
     +,   3.2737950E-04,   3.2702446E-04,   3.2518481E-04
     +,   3.2189104E-04,   3.1719182E-04,   3.1115307E-04
     +,   3.0385633E-04,   2.9539669E-04,   2.8588102E-04
     +,   2.7542707E-04,   2.6415905E-04,   2.5220812E-04
     +,   2.3970722E-04,   2.2679205E-04,   2.1359557E-04
     +,   2.0024956E-04,   1.8687904E-04,   1.7360426E-04
     +,   1.6053607E-04,   1.4777592E-04,   1.3541592E-04
     +,   1.2353675E-04,   1.1220685E-04,   1.0148268E-04
     +,   9.1409624E-05,   8.2021252E-05,   7.3339339E-05
     +,   6.5375214E-05,   5.8131238E-05,   5.1600229E-05
     +,   4.5767429E-05,   4.0611867E-05,   3.6107060E-05
     +,   3.2221913E-05,   2.8922212E-05,   2.6171840E-05
     +,   2.3933386E-05,   2.2168913E-05,   2.0840946E-05
     +,   1.9913074E-05,   1.9350317E-05,   1.9119478E-05
     +,   1.9189487E-05,   1.9531497E-05,   2.0118938E-05
     +,   2.0927522E-05,   2.1935062E-05,   2.3121347E-05
     +,   2.4468052E-05,   2.5958470E-05,   2.7577184E-05
     +,   2.9309878E-05,   3.1143285E-05,   3.3064836E-05
     +,   3.5062370E-05,   3.7124031E-05,   3.9238283E-05
     +,   4.1393683E-05,   4.3578515E-05,   4.5781209E-05
     +,   4.7990052E-05,   5.0193019E-05,   5.2377953E-05
     +,   5.4532735E-05,   5.6645145E-05,   5.8702815E-05
     +,   6.0693474E-05,   6.2605119E-05,   6.4425978E-05
     +,   6.6144508E-05,   6.7749665E-05,   6.9231013E-05
     +,   7.0578826E-05,   7.1783958E-05,   7.2838309E-05
     +,   7.3734649E-05,   7.4466770E-05,   7.5029573E-05
     +,   7.5419121E-05,   7.5632692E-05,   7.5668766E-05
     +,   7.5527074E-05,   7.5208649E-05,   7.4715688E-05
     +,   7.4051648E-05,   7.3221199E-05,   7.2230046E-05
     +,   7.1084978E-05,   6.9793809E-05,   6.8365182E-05
     +,   6.6808512E-05,   6.5133958E-05,   6.3352323E-05
     +,   6.1474726E-05,   5.9512644E-05,   5.7477886E-05
     +,   5.5382414E-05,   5.3238025E-05,   5.1056420E-05
     +,   4.8849233E-05,   4.6627785E-05,   4.4402852E-05
     +,   4.2184718E-05,   3.9983352E-05,   3.7807873E-05
     +,   3.5666741E-05,   3.3567852E-05,   3.1518357E-05
     +,   2.9524503E-05,   2.7591776E-05,   2.5725018E-05
     +,   2.3928291E-05,   2.2204791E-05,   2.0556992E-05
     +,   1.8986782E-05,   1.7495380E-05,   1.6083271E-05
     +,   1.4750376E-05,   1.3496217E-05,   1.2319696E-05
     +,   1.1219298E-05,   1.0193196E-05,   9.2392193E-06
     +,   8.3548612E-06,   7.5373846E-06,   6.7839264E-06
     +,   6.0914690E-06,   5.4568491E-06,   4.8768493E-06
     +,   4.3482619E-06,   3.8678750E-06,   3.4324837E-06
     +,   3.0389367E-06,   2.6842040E-06,   2.3653120E-06
     +,   2.0794023E-06,   1.8237597E-06,   1.5957963E-06
     +,   1.3930486E-06,   1.2131997E-06,   1.0540888E-06
     +,   9.1369878E-07,   7.9014711E-07,   6.8169436E-07
     +,   5.8674635E-07,   5.0383966E-07,   4.3163141E-07
     +,   3.6890179E-07,   3.1454994E-07,   2.6757613E-07
     +,   2.2708161E-07,   1.9226283E-07,   1.6240156E-07
     +,   1.3685610E-07,   1.1505743E-07,   9.6503619E-08
     +,   8.0752223E-08,   6.7413126E-08,   5.6144930E-08
     +,   4.6650747E-08,   3.8670752E-08,   3.1980729E-08
     +,   2.6385802E-08,   2.1718719E-08,   1.7835047E-08
     +,   1.4611548E-08,   1.1942465E-08,   9.7380868E-09
     +,   7.9219040E-09,   6.4293539E-09,   5.2057558E-09
     +,   4.2051047E-09,   3.3888428E-09,   2.7245959E-09
     +,   2.1854196E-09,   1.7488125E-09,   1.3961563E-09
     +,   1.1119904E-09,   8.8358743E-10,   7.0044454E-10
     +,   5.5396254E-10,   4.3708182E-10,   3.4405467E-10
     +,   2.7018893E-10,   2.1168516E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_qq_mass = Yx/0.00370025833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0671791E-20,   3.9688000E-20
     +,   7.5729154E-20,   1.4361060E-19,   2.7066531E-19
     +,   5.0699146E-19,   9.4382507E-19,   1.7462312E-18
     +,   3.2109352E-18,   5.8679514E-18,   1.0657699E-17
     +,   1.9238107E-17,   3.4512970E-17,   6.1535408E-17
     +,   1.0904079E-16,   1.9203253E-16,   3.3611088E-16
     +,   5.8467196E-16,   1.0107951E-15,   1.7367442E-15
     +,   2.9657285E-15,   5.0332349E-15,   8.4894911E-15
     +,   1.4231329E-14,   2.3709619E-14,   3.9257927E-14
     +,   6.4603149E-14,   1.0565749E-13,   1.7173901E-13
     +,   2.7743433E-13,   4.4542305E-13,   7.1073399E-13
     +,   1.1271025E-12,   1.7764039E-12,   2.7825381E-12
     +,   4.3317407E-12,   6.7020196E-12,   1.0305475E-11
     +,   1.5749183E-11,   2.3920147E-11,   3.6107218E-11
     +,   5.4168427E-11,   8.0764458E-11,   1.1967845E-10
     +,   1.7625194E-10,   2.5797248E-10,   3.7526188E-10
     +,   5.4252158E-10,   7.7951035E-10,   1.1131362E-09
     +,   1.5797819E-09,   2.2282658E-09,   3.1236072E-09
     +,   4.3518376E-09,   6.0256728E-09,   8.2920684E-09
     +,   1.1340752E-08,   1.5414983E-08,   2.0824070E-08
     +,   2.7958256E-08,   3.7305789E-08,   4.9472799E-08
     +,   6.5204091E-08,   8.5409262E-08,   1.1118881E-07
     +,   1.4385864E-07,   1.8498511E-07,   2.3640516E-07
     +,   3.0026428E-07,   3.7902771E-07,   4.7551745E-07
     +,   5.9290431E-07,   7.3473956E-07,   9.0491892E-07
     +,   1.1076925E-06,   1.3476254E-06,   1.6295318E-06
     +,   1.9584184E-06,   2.3394321E-06,   2.7777560E-06
     +,   3.2784633E-06,   3.8465178E-06,   4.4865569E-06
     +,   5.2029709E-06,   5.9996978E-06,   6.8804452E-06
     +,   7.8485700E-06,   8.9075247E-06,   1.0060905E-05
     +,   1.1313165E-05,   1.2670153E-05,   1.4139780E-05
     +,   1.5733071E-05,   1.7465341E-05,   1.9357336E-05
     +,   2.1436230E-05,   2.3737295E-05,   2.6304329E-05
     +,   2.9191055E-05,   3.2460652E-05,   3.6186222E-05
     +,   4.0448831E-05,   4.5336481E-05,   5.0939994E-05
     +,   5.7350109E-05,   6.4652166E-05,   7.2919822E-05
     +,   8.2209095E-05,   9.2552727E-05,   1.0395366E-04
     +,   1.1637868E-04,   1.2975746E-04,   1.4397781E-04
     +,   1.5889002E-04,   1.7430680E-04,   1.9001386E-04
     +,   2.0577495E-04,   2.2134710E-04,   2.3648942E-04
     +,   2.5097921E-04,   2.6462277E-04,   2.7726474E-04
     +,   2.8879690E-04,   2.9916290E-04,   3.0835779E-04
     +,   3.1642438E-04,   3.2344912E-04,   3.2955129E-04
     +,   3.3487531E-04,   3.3957898E-04,   3.4382488E-04
     +,   3.4777075E-04,   3.5156336E-04,   3.5533158E-04
     +,   3.5918297E-04,   3.6320020E-04,   3.6743836E-04
     +,   3.7192323E-04,   3.7665071E-04,   3.8158652E-04
     +,   3.8666636E-04,   3.9179853E-04,   3.9686789E-04
     +,   4.0174075E-04,   4.0627152E-04,   4.1031183E-04
     +,   4.1371916E-04,   4.1636650E-04,   4.1815231E-04
     +,   4.1900872E-04,   4.1890881E-04,   4.1787009E-04
     +,   4.1595669E-04,   4.1327559E-04,   4.0997087E-04
     +,   4.0621316E-04,   4.0218647E-04,   3.9807247E-04
     +,   3.9403446E-04,   3.9020335E-04,   3.8666395E-04
     +,   3.8344640E-04,   3.8052266E-04,   3.7780721E-04
     +,   3.7516220E-04,   3.7240845E-04,   3.6933774E-04
     +,   3.6572944E-04,   3.6136448E-04,   3.5604296E-04
     +,   3.4959725E-04,   3.4190525E-04,   3.3289826E-04
     +,   3.2256820E-04,   3.1097082E-04,   2.9822369E-04
     +,   2.8450199E-04,   2.7003259E-04,   2.5508262E-04
     +,   2.3994609E-04,   2.2493069E-04,   2.1034462E-04
     +,   1.9648163E-04,   1.8360742E-04,   1.7195061E-04
     +,   1.6169525E-04,   1.5297526E-04,   1.4587201E-04
     +,   1.4041593E-04,   1.3659011E-04,   1.3433400E-04
     +,   1.3355025E-04,   1.3411134E-04,   1.3586588E-04
     +,   1.3864547E-04,   1.4227047E-04,   1.4655483E-04
     +,   1.5131080E-04,   1.5635289E-04,   1.6150120E-04
     +,   1.6658370E-04,   1.7143907E-04,   1.7591946E-04
     +,   1.7989197E-04,   1.8324045E-04,   1.8586760E-04
     +,   1.8769564E-04,   1.8866750E-04,   1.8874693E-04
     +,   1.8791856E-04,   1.8618694E-04,   1.8357561E-04
     +,   1.8012516E-04,   1.7589096E-04,   1.7094082E-04
     +,   1.6535251E-04,   1.5921102E-04,   1.5260515E-04
     +,   1.4562541E-04,   1.3836224E-04,   1.3090270E-04
     +,   1.2332933E-04,   1.1571929E-04,   1.0814295E-04
     +,   1.0066276E-04,   9.3333365E-05,   8.6202177E-05
     +,   7.9308957E-05,   7.2685776E-05,   6.6358043E-05
     +,   6.0345428E-05,   5.4661967E-05,   4.9316383E-05
     +,   4.4313027E-05,   3.9652907E-05,   3.5333160E-05
     +,   3.1348049E-05,   2.7689615E-05,   2.4347675E-05
     +,   2.1310008E-05,   1.8562901E-05,   1.6091577E-05
     +,   1.3880247E-05,   1.1912261E-05,   1.0170515E-05
     +,   8.6378041E-06,   7.2968828E-06,   6.1306232E-06
     +,   5.1223183E-06,   4.2559336E-06,   3.5160540E-06
     +,   2.8881329E-06,   2.3586078E-06,   1.9149174E-06
     +,   1.5455213E-06,   1.2399587E-06,   9.8885232E-07
     +,   7.8385284E-07,   6.1758749E-07,   4.8362222E-07
     +,   3.7640018E-07,   2.9115338E-07,   2.2382557E-07
     +,   1.7100204E-07,   1.2983647E-07,   9.7968368E-08
     +,   7.3461386E-08,   5.4741356E-08,   4.0537351E-08
     +,   2.9831192E-08,   2.1814907E-08,   1.5852804E-08
     +,   1.1448026E-08,   8.2152569E-09,   5.8582827E-09
     +,   4.1513282E-09,   2.9232163E-09,   2.0455035E-09
     +,   1.4223126E-09,   9.8277619E-10,   6.7478978E-10
     +,   4.6041235E-10,   3.1216169E-10,   2.1031808E-10
     +,   1.4080824E-10,   9.3679453E-11,   6.1932758E-11
     +,   4.0686593E-11,   2.6561239E-11,   1.7230602E-11
     +,   1.1107604E-11,   7.1153283E-12,   4.5293790E-12
     +,   2.8650916E-12,   1.8009787E-12,   1.1249548E-12
     +,   6.9828605E-13,   4.3071360E-13,   2.6400808E-13
     +,   1.6080681E-13,   9.7334101E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_ww_mass = Yx/0.007571865
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_asha_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0101741E-07,   1.1322726E-07
     +,   1.2672311E-07,   1.4161549E-07,   1.5802166E-07
     +,   1.7606530E-07,   1.9587655E-07,   2.1759236E-07
     +,   2.4135548E-07,   2.6731627E-07,   2.9562989E-07
     +,   3.2645804E-07,   3.5996752E-07,   3.9633093E-07
     +,   4.3572510E-07,   4.7833151E-07,   5.2433558E-07
     +,   5.7392589E-07,   6.2729328E-07,   6.8463157E-07
     +,   7.4613570E-07,   8.1200159E-07,   8.8242422E-07
     +,   9.5760299E-07,   1.0377287E-06,   1.1229989E-06
     +,   1.2136056E-06,   1.3097399E-06,   1.4115915E-06
     +,   1.5193485E-06,   1.6331981E-06,   1.7533263E-06
     +,   1.8799198E-06,   2.0131672E-06,   2.1532585E-06
     +,   2.3003888E-06,   2.4547596E-06,   2.6165776E-06
     +,   2.7860713E-06,   2.9634634E-06,   3.1490147E-06
     +,   3.3429926E-06,   3.5456910E-06,   3.7574312E-06
     +,   3.9785627E-06,   4.2094689E-06,   4.4505709E-06
     +,   4.7023254E-06,   4.9652326E-06,   5.2398341E-06
     +,   5.5267164E-06,   5.8265068E-06,   6.1398723E-06
     +,   6.4675410E-06,   6.8102395E-06,   7.1687650E-06
     +,   7.5439207E-06,   7.9365291E-06,   8.3474270E-06
     +,   8.7774461E-06,   9.2274031E-06,   9.6980993E-06
     +,   1.0190253E-05,   1.0704573E-05,   1.1241682E-05
     +,   1.1802066E-05,   1.2386167E-05,   1.2994223E-05
     +,   1.3626402E-05,   1.4282628E-05,   1.4962736E-05
     +,   1.5666277E-05,   1.6392700E-05,   1.7141147E-05
     +,   1.7910630E-05,   1.8699955E-05,   1.9507665E-05
     +,   2.0332129E-05,   2.1171585E-05,   2.2024129E-05
     +,   2.2887662E-05,   2.3760113E-05,   2.4639248E-05
     +,   2.5522984E-05,   2.6409170E-05,   2.7295919E-05
     +,   2.8181410E-05,   2.9064217E-05,   2.9943132E-05
     +,   3.0817460E-05,   3.1687003E-05,   3.2552067E-05
     +,   3.3413617E-05,   3.4273369E-05,   3.5133820E-05
     +,   3.5998204E-05,   3.6870719E-05,   3.7756352E-05
     +,   3.8661077E-05,   3.9591654E-05,   4.0555809E-05
     +,   4.1561932E-05,   4.2619278E-05,   4.3737578E-05
     +,   4.4927168E-05,   4.6198697E-05,   4.7562917E-05
     +,   4.9030466E-05,   5.0611809E-05,   5.2316889E-05
     +,   5.4154614E-05,   5.6133093E-05,   5.8258884E-05
     +,   6.0537244E-05,   6.2971507E-05,   6.5563589E-05
     +,   6.8313479E-05,   7.1220136E-05,   7.4281241E-05
     +,   7.7494602E-05,   8.0858859E-05,   8.4374406E-05
     +,   8.8045155E-05,   9.1880247E-05,   9.5895528E-05
     +,   1.0011471E-04,   1.0457126E-04,   1.0930805E-04
     +,   1.1437842E-04,   1.1984352E-04,   1.2577149E-04
     +,   1.3223232E-04,   1.3929485E-04,   1.4701911E-04
     +,   1.5545200E-04,   1.6462016E-04,   1.7452404E-04
     +,   1.8513417E-04,   1.9639006E-04,   2.0820016E-04
     +,   2.2044459E-04,   2.3298193E-04,   2.4565775E-04
     +,   2.5831303E-04,   2.7079121E-04,   2.8294881E-04
     +,   2.9466071E-04,   3.0582608E-04,   3.1637694E-04
     +,   3.2628982E-04,   3.3559997E-04,   3.4441944E-04
     +,   3.5295519E-04,   3.6152158E-04,   3.7053649E-04
     +,   3.8050045E-04,   3.9195924E-04,   4.0546103E-04
     +,   4.2152617E-04,   4.4065059E-04,   4.6338741E-04
     +,   4.9053255E-04,   5.2348699E-04,   5.6484673E-04
     +,   6.1920116E-04,   6.9388776E-04,   7.9913507E-04
     +,   9.4683288E-04,   1.1473801E-03,   1.4048822E-03
     +,   1.7121973E-03,   2.0482107E-03,   2.3794565E-03
     +,   2.6667267E-03,   2.8752610E-03,   2.9850053E-03
     +,   2.9961711E-03,   2.9270169E-03,   2.8045634E-03
     +,   2.6534980E-03,   2.4897640E-03,   2.3214573E-03
     +,   2.1537172E-03,   1.9919581E-03,   1.8407528E-03
     +,   1.7006068E-03,   1.5667401E-03,   1.4316811E-03
     +,   1.2898619E-03,   1.1409709E-03,   9.9019206E-04
     +,   8.4589899E-04,   7.1652839E-04,   6.0818490E-04
     +,   5.2363559E-04,   4.6249497E-04,   4.2205173E-04
     +,   3.9825824E-04,   3.8662308E-04,   3.8288324E-04
     +,   3.8342236E-04,   3.8545844E-04,   3.8705024E-04
     +,   3.8697885E-04,   3.8457176E-04,   3.7952513E-04
     +,   3.7175734E-04,   3.6131355E-04,   3.4831438E-04
     +,   3.3293790E-04,   3.1542027E-04,   2.9606262E-04
     +,   2.7523021E-04,   2.5334166E-04,   2.3085294E-04
     +,   2.0823459E-04,   1.8594417E-04,   1.6439985E-04
     +,   1.4396143E-04,   1.2491766E-04,   1.0747473E-04
     +,   9.1757276E-05,   7.7813958E-05,   6.5625085E-05
     +,   5.5114098E-05,   4.6162000E-05,   3.8621518E-05
     +,   3.2329110E-05,   2.7115999E-05,   2.2817858E-05
     +,   1.9281813E-05,   1.6370521E-05,   1.3964564E-05
     +,   1.1963382E-05,   1.0284778E-05,   8.8629076E-06
     +,   7.6464048E-06,   6.5960253E-06,   5.6821905E-06
     +,   4.8827492E-06,   4.1811450E-06,   3.5648914E-06
     +,   3.0242684E-06,   2.5513759E-06,   2.1395224E-06
     +,   1.7828042E-06,   1.4757946E-06,   1.2133830E-06
     +,   9.9072838E-07,   8.0326043E-07,   6.4664806E-07
     +,   5.1684793E-07,   4.1013530E-07,   3.2311189E-07
     +,   2.5271390E-07,   1.9622145E-07,   1.5125316E-07
     +,   1.1574566E-07,   8.7930957E-08,   6.6314875E-08
     +,   4.9649486E-08,   3.6902634E-08,   2.7229172E-08
     +,   1.9945315E-08,   1.4503944E-08,   1.0470438E-08
     +,   7.5036608E-09,   5.3384497E-09,   3.7704710E-09
     +,   2.6436870E-09,   1.8401497E-09,   1.2715397E-09
     +,   8.7225943E-10,   5.9401295E-10,   4.0158138E-10
     +,   2.6952005E-10,   1.7957107E-10,   1.1877392E-10
     +,   7.7989136E-11,   5.0837820E-11,   3.2897855E-11
     +,   2.1134290E-11,   1.3478302E-11,   8.5334170E-12
     +,   5.3633742E-12,   3.3465242E-12,   2.0729243E-12
     +,   1.2746750E-12,   7.7813878E-13,   4.7156365E-13
     +,   2.8370435E-13,   1.6944027E-13,   1.0046358E-13
     +,   5.9132651E-14,   3.4553140E-14,   2.0043493E-14
     +,   1.1542526E-14,   6.5986581E-15,   3.7449872E-15
     +,   2.1099474E-15,   1.1801424E-15
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_asha_zz_mass = Yx/0.0175800625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.4639818E-05,   2.5840105E-05
     +,   2.7085494E-05,   2.8377301E-05,   2.9716761E-05
     +,   3.1105006E-05,   3.2543030E-05,   3.4031687E-05
     +,   3.5571637E-05,   3.7163416E-05,   3.8807291E-05
     +,   4.0503339E-05,   4.2251431E-05,   4.4051187E-05
     +,   4.5902023E-05,   4.7803118E-05,   4.9753464E-05
     +,   5.1751809E-05,   5.3796743E-05,   5.5886634E-05
     +,   5.8019716E-05,   6.0194066E-05,   6.2407540E-05
     +,   6.4658023E-05,   6.6943030E-05,   6.9260153E-05
     +,   7.1606708E-05,   7.3979922E-05,   7.6376848E-05
     +,   7.8794321E-05,   8.1229024E-05,   8.3677369E-05
     +,   8.6135537E-05,   8.8599409E-05,   9.1064554E-05
     +,   9.3526236E-05,   9.5979391E-05,   9.8418524E-05
     +,   1.0083798E-04,   1.0323150E-04,   1.0559283E-04
     +,   1.0791523E-04,   1.1019182E-04,   1.1241559E-04
     +,   1.1457945E-04,   1.1667638E-04,   1.1869937E-04
     +,   1.2064167E-04,   1.2249687E-04,   1.2425898E-04
     +,   1.2592245E-04,   1.2748240E-04,   1.2893454E-04
     +,   1.3027550E-04,   1.3150241E-04,   1.3261347E-04
     +,   1.3360752E-04,   1.3448438E-04,   1.3524448E-04
     +,   1.3588909E-04,   1.3642009E-04,   1.3684000E-04
     +,   1.3715182E-04,   1.3735901E-04,   1.3746532E-04
     +,   1.3747472E-04,   1.3739146E-04,   1.3721967E-04
     +,   1.3696362E-04,   1.3662755E-04,   1.3621556E-04
     +,   1.3573171E-04,   1.3517986E-04,   1.3456393E-04
     +,   1.3388759E-04,   1.3315452E-04,   1.3236838E-04
     +,   1.3153291E-04,   1.3065178E-04,   1.2972875E-04
     +,   1.2876780E-04,   1.2777283E-04,   1.2674804E-04
     +,   1.2569757E-04,   1.2462585E-04,   1.2353715E-04
     +,   1.2243591E-04,   1.2132644E-04,   1.2021299E-04
     +,   1.1909963E-04,   1.1799012E-04,   1.1688804E-04
     +,   1.1579660E-04,   1.1471852E-04,   1.1365608E-04
     +,   1.1261119E-04,   1.1158509E-04,   1.1057877E-04
     +,   1.0959244E-04,   1.0862609E-04,   1.0767917E-04
     +,   1.0675078E-04,   1.0583967E-04,   1.0494437E-04
     +,   1.0406312E-04,   1.0319401E-04,   1.0233511E-04
     +,   1.0148440E-04,   1.0063979E-04,   9.9799232E-05
     +,   9.8960780E-05,   9.8122451E-05,   9.7282391E-05
     +,   9.6438758E-05,   9.5589814E-05,   9.4733747E-05
     +,   9.3868883E-05,   9.2993403E-05,   9.2105620E-05
     +,   9.1203670E-05,   9.0285648E-05,   8.9349647E-05
     +,   8.8393732E-05,   8.7415850E-05,   8.6413878E-05
     +,   8.5385866E-05,   8.4329731E-05,   8.3243598E-05
     +,   8.2125596E-05,   8.0974198E-05,   7.9787911E-05
     +,   7.8565703E-05,   7.7306730E-05,   7.6010678E-05
     +,   7.4677504E-05,   7.3307638E-05,   7.1902075E-05
     +,   7.0462265E-05,   6.8990114E-05,   6.7487927E-05
     +,   6.5958666E-05,   6.4405656E-05,   6.2832594E-05
     +,   6.1243481E-05,   5.9642814E-05,   5.8035195E-05
     +,   5.6425386E-05,   5.4818414E-05,   5.3219359E-05
     +,   5.1633204E-05,   5.0064868E-05,   4.8519250E-05
     +,   4.7001089E-05,   4.5514778E-05,   4.4064458E-05
     +,   4.2654035E-05,   4.1287098E-05,   3.9966759E-05
     +,   3.8695765E-05,   3.7476570E-05,   3.6311107E-05
     +,   3.5200908E-05,   3.4147175E-05,   3.3150725E-05
     +,   3.2211901E-05,   3.1330717E-05,   3.0506899E-05
     +,   2.9739835E-05,   2.9028566E-05,   2.8371878E-05
     +,   2.7768348E-05,   2.7216329E-05,   2.6713938E-05
     +,   2.6259142E-05,   2.5849791E-05,   2.5483585E-05
     +,   2.5158128E-05,   2.4870971E-05,   2.4619612E-05
     +,   2.4401492E-05,   2.4214047E-05,   2.4054718E-05
     +,   2.3920975E-05,   2.3810286E-05,   2.3720188E-05
     +,   2.3648263E-05,   2.3592163E-05,   2.3549615E-05
     +,   2.3518422E-05,   2.3496479E-05,   2.3481780E-05
     +,   2.3472414E-05,   2.3466580E-05,   2.3462580E-05
     +,   2.3458828E-05,   2.3453846E-05,   2.3446275E-05
     +,   2.3434855E-05,   2.3418452E-05,   2.3396031E-05
     +,   2.3366663E-05,   2.3329540E-05,   2.3283939E-05
     +,   2.3229246E-05,   2.3164934E-05,   2.3090581E-05
     +,   2.3005829E-05,   2.2910428E-05,   2.2804194E-05
     +,   2.2687012E-05,   2.2558834E-05,   2.2419681E-05
     +,   2.2269638E-05,   2.2108830E-05,   2.1937429E-05
     +,   2.1755654E-05,   2.1563779E-05,   2.1362081E-05
     +,   2.1150887E-05,   2.0930549E-05,   2.0701435E-05
     +,   2.0463924E-05,   2.0218420E-05,   1.9965351E-05
     +,   1.9705127E-05,   1.9438168E-05,   1.9164912E-05
     +,   1.8885799E-05,   1.8601251E-05,   1.8311684E-05
     +,   1.8017528E-05,   1.7719214E-05,   1.7417138E-05
     +,   1.7111694E-05,   1.6803291E-05,   1.6492306E-05
     +,   1.6179101E-05,   1.5864047E-05,   1.5547510E-05
     +,   1.5229818E-05,   1.4911290E-05,   1.4592260E-05
     +,   1.4273042E-05,   1.3953927E-05,   1.3635190E-05
     +,   1.3317122E-05,   1.2999996E-05,   1.2684062E-05
     +,   1.2369558E-05,   1.2056743E-05,   1.1745836E-05
     +,   1.1437047E-05,   1.1130601E-05,   1.0826711E-05
     +,   1.0525564E-05,   1.0227341E-05,   9.9322315E-06
     +,   9.6404174E-06,   9.3520566E-06,   9.0672993E-06
     +,   8.7863064E-06,   8.5092324E-06,   8.2362058E-06
     +,   7.9673473E-06,   7.7027980E-06,   7.4426657E-06
     +,   7.1870513E-06,   6.9360663E-06,   6.6898119E-06
     +,   6.4483661E-06,   6.2118029E-06,   5.9802019E-06
     +,   5.7536354E-06,   5.5321530E-06,   5.3157974E-06
     +,   5.1046241E-06,   4.8986553E-06,   4.6979303E-06
     +,   4.5024558E-06,   4.3122554E-06,   4.1273224E-06
     +,   3.9476654E-06,   3.7732616E-06,   3.6041058E-06
     +,   3.4401621E-06,   3.2814100E-06,   3.1278064E-06
     +,   2.9793016E-06,   2.8358550E-06,   2.6974008E-06
     +,   2.5638858E-06,   2.4352330E-06,   2.3113787E-06
     +,   2.1922372E-06,   2.0777327E-06,   1.9677727E-06
     +,   1.8622736E-06,   1.7611343E-06,   1.6642646E-06
     +,   1.5715578E-06,   1.4829182E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_eez_mass = Yx/0.0040208
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.3746833E-05,   6.4814594E-05
     +,   6.5863882E-05,   6.6893379E-05,   6.7901819E-05
     +,   6.8887930E-05,   6.9850495E-05,   7.0788265E-05
     +,   7.1700066E-05,   7.2584779E-05,   7.3441246E-05
     +,   7.4268406E-05,   7.5065189E-05,   7.5830612E-05
     +,   7.6563709E-05,   7.7263576E-05,   7.7929348E-05
     +,   7.8560224E-05,   7.9155434E-05,   7.9714308E-05
     +,   8.0236197E-05,   8.0720543E-05,   8.1166836E-05
     +,   8.1574653E-05,   8.1943603E-05,   8.2273415E-05
     +,   8.2563849E-05,   8.2814782E-05,   8.3026120E-05
     +,   8.3197890E-05,   8.3330175E-05,   8.3423140E-05
     +,   8.3477054E-05,   8.3492210E-05,   8.3469051E-05
     +,   8.3408078E-05,   8.3309824E-05,   8.3174993E-05
     +,   8.3004270E-05,   8.2798506E-05,   8.2558574E-05
     +,   8.2285427E-05,   8.1980113E-05,   8.1643739E-05
     +,   8.1277460E-05,   8.0882499E-05,   8.0460188E-05
     +,   8.0011851E-05,   7.9538877E-05,   7.9042744E-05
     +,   7.8524921E-05,   7.7986944E-05,   7.7430399E-05
     +,   7.6856806E-05,   7.6267861E-05,   7.5665121E-05
     +,   7.5050266E-05,   7.4424905E-05,   7.3790696E-05
     +,   7.3149255E-05,   7.2502211E-05,   7.1851144E-05
     +,   7.1197646E-05,   7.0543239E-05,   6.9889415E-05
     +,   6.9237642E-05,   6.8589281E-05,   6.7945730E-05
     +,   6.7308254E-05,   6.6678091E-05,   6.6056360E-05
     +,   6.5444190E-05,   6.4842534E-05,   6.4252366E-05
     +,   6.3674481E-05,   6.3109619E-05,   6.2558458E-05
     +,   6.2021601E-05,   6.1499493E-05,   6.0992490E-05
     +,   6.0500934E-05,   6.0024988E-05,   5.9564769E-05
     +,   5.9120288E-05,   5.8691476E-05,   5.8278147E-05
     +,   5.7880079E-05,   5.7496902E-05,   5.7128229E-05
     +,   5.6773555E-05,   5.6432316E-05,   5.6103891E-05
     +,   5.5787576E-05,   5.5482629E-05,   5.5188229E-05
     +,   5.4903536E-05,   5.4627646E-05,   5.4359636E-05
     +,   5.4098542E-05,   5.3843374E-05,   5.3593125E-05
     +,   5.3346790E-05,   5.3103326E-05,   5.2861735E-05
     +,   5.2620995E-05,   5.2380077E-05,   5.2138024E-05
     +,   5.1893865E-05,   5.1646661E-05,   5.1395506E-05
     +,   5.1139537E-05,   5.0877934E-05,   5.0609928E-05
     +,   5.0334791E-05,   5.0051862E-05,   4.9760518E-05
     +,   4.9460228E-05,   4.9150491E-05,   4.8830902E-05
     +,   4.8501104E-05,   4.8160797E-05,   4.7809786E-05
     +,   4.7447938E-05,   4.7075158E-05,   4.6691457E-05
     +,   4.6296900E-05,   4.5891622E-05,   4.5475848E-05
     +,   4.5049826E-05,   4.4613917E-05,   4.4168490E-05
     +,   4.3714041E-05,   4.3251061E-05,   4.2780142E-05
     +,   4.2301894E-05,   4.1816977E-05,   4.1326126E-05
     +,   4.0830102E-05,   4.0329684E-05,   3.9825696E-05
     +,   3.9318980E-05,   3.8810464E-05,   3.8301012E-05
     +,   3.7791528E-05,   3.7282967E-05,   3.6776259E-05
     +,   3.6272319E-05,   3.5772104E-05,   3.5276571E-05
     +,   3.4786630E-05,   3.4303172E-05,   3.3827124E-05
     +,   3.3359382E-05,   3.2900778E-05,   3.2452135E-05
     +,   3.2014279E-05,   3.1587995E-05,   3.1174008E-05
     +,   3.0773001E-05,   3.0385669E-05,   3.0012618E-05
     +,   2.9654422E-05,   2.9311628E-05,   2.8984743E-05
     +,   2.8674183E-05,   2.8380349E-05,   2.8103597E-05
     +,   2.7844228E-05,   2.7602484E-05,   2.7378554E-05
     +,   2.7172602E-05,   2.6984731E-05,   2.6814987E-05
     +,   2.6663361E-05,   2.6529822E-05,   2.6414264E-05
     +,   2.6316555E-05,   2.6236510E-05,   2.6173901E-05
     +,   2.6128455E-05,   2.6099864E-05,   2.6087773E-05
     +,   2.6091797E-05,   2.6111504E-05,   2.6146445E-05
     +,   2.6196120E-05,   2.6260008E-05,   2.6337553E-05
     +,   2.6428192E-05,   2.6531305E-05,   2.6646274E-05
     +,   2.6772457E-05,   2.6909182E-05,   2.7055765E-05
     +,   2.7211518E-05,   2.7375729E-05,   2.7547676E-05
     +,   2.7726626E-05,   2.7911852E-05,   2.8102613E-05
     +,   2.8298162E-05,   2.8497747E-05,   2.8700633E-05
     +,   2.8906081E-05,   2.9113335E-05,   2.9321674E-05
     +,   2.9530382E-05,   2.9738721E-05,   2.9945990E-05
     +,   3.0151494E-05,   3.0354546E-05,   3.0554485E-05
     +,   3.0750634E-05,   3.0942367E-05,   3.1129071E-05
     +,   3.1310126E-05,   3.1484946E-05,   3.1652977E-05
     +,   3.1813674E-05,   3.1966498E-05,   3.2110966E-05
     +,   3.2246600E-05,   3.2372933E-05,   3.2489541E-05
     +,   3.2596017E-05,   3.2691984E-05,   3.2777083E-05
     +,   3.2850978E-05,   3.2913365E-05,   3.2963977E-05
     +,   3.3002543E-05,   3.3028839E-05,   3.3042674E-05
     +,   3.3043856E-05,   3.3032251E-05,   3.3007716E-05
     +,   3.2970172E-05,   3.2919525E-05,   3.2855736E-05
     +,   3.2778786E-05,   3.2688658E-05,   3.2585383E-05
     +,   3.2469015E-05,   3.2339616E-05,   3.2197280E-05
     +,   3.2042110E-05,   3.1874257E-05,   3.1693871E-05
     +,   3.1501117E-05,   3.1296207E-05,   3.1079340E-05
     +,   3.0850744E-05,   3.0610681E-05,   3.0359406E-05
     +,   3.0097199E-05,   2.9824349E-05,   2.9541172E-05
     +,   2.9247996E-05,   2.8945145E-05,   2.8632949E-05
     +,   2.8311782E-05,   2.7982016E-05,   2.7644008E-05
     +,   2.7298134E-05,   2.6944803E-05,   2.6584397E-05
     +,   2.6217307E-05,   2.5843945E-05,   2.5464733E-05
     +,   2.5080062E-05,   2.4690340E-05,   2.4295985E-05
     +,   2.3897433E-05,   2.3495073E-05,   2.3089311E-05
     +,   2.2680579E-05,   2.2269258E-05,   2.1855774E-05
     +,   2.1440504E-05,   2.1023867E-05,   2.0606225E-05
     +,   2.0187987E-05,   1.9769503E-05,   1.9351166E-05
     +,   1.8933313E-05,   1.8516323E-05,   1.8100523E-05
     +,   1.7686243E-05,   1.7273829E-05,   1.6863572E-05
     +,   1.6455804E-05,   1.6050793E-05,   1.5648853E-05
     +,   1.5250228E-05,   1.4855206E-05,   1.4464014E-05
     +,   1.4076919E-05,   1.3694121E-05,   1.3315859E-05
     +,   1.2942317E-05,   1.2573709E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_qq_mass = Yx/0.00370025833333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.9391430E-06,   8.0438895E-06
     +,   8.1464568E-06,   8.2470342E-06,   8.3458726E-06
     +,   8.4432986E-06,   8.5397214E-06,   8.6356449E-06
     +,   8.7316712E-06,   8.8285242E-06,   8.9270561E-06
     +,   9.0282529E-06,   9.1332658E-06,   9.2434102E-06
     +,   9.3601857E-06,   9.4852958E-06,   9.6206541E-06
     +,   9.7684087E-06,   9.9309473E-06,   1.0110918E-05
     +,   1.0311241E-05,   1.0535106E-05,   1.0786001E-05
     +,   1.1067714E-05,   1.1384302E-05,   1.1740144E-05
     +,   1.2139892E-05,   1.2588479E-05,   1.3091089E-05
     +,   1.3653153E-05,   1.4280299E-05,   1.4978324E-05
     +,   1.5753149E-05,   1.6610769E-05,   1.7557188E-05
     +,   1.8598350E-05,   1.9740080E-05,   2.0987967E-05
     +,   2.2347382E-05,   2.3823159E-05,   2.5419802E-05
     +,   2.7141168E-05,   2.8990431E-05,   3.0970023E-05
     +,   3.3081527E-05,   3.5325593E-05,   3.7701859E-05
     +,   4.0208921E-05,   4.2844291E-05,   4.5604360E-05
     +,   4.8484380E-05,   5.1478561E-05,   5.4579970E-05
     +,   5.7780922E-05,   6.1072533E-05,   6.4445470E-05
     +,   6.7889647E-05,   7.1394563E-05,   7.4949450E-05
     +,   7.8543570E-05,   8.2166291E-05,   8.5807427E-05
     +,   8.9457179E-05,   9.3106799E-05,   9.6748576E-05
     +,   1.0037551E-04,   1.0398237E-04,   1.0756477E-04
     +,   1.1112018E-04,   1.1464702E-04,   1.1814536E-04
     +,   1.2161603E-04,   1.2506133E-04,   1.2848384E-04
     +,   1.3188686E-04,   1.3527398E-04,   1.3864831E-04
     +,   1.4201226E-04,   1.4536767E-04,   1.4871501E-04
     +,   1.5205273E-04,   1.5537786E-04,   1.5868471E-04
     +,   1.6196574E-04,   1.6521064E-04,   1.6840720E-04
     +,   1.7154048E-04,   1.7459407E-04,   1.7754953E-04
     +,   1.8038771E-04,   1.8308870E-04,   1.8563282E-04
     +,   1.8800086E-04,   1.9017563E-04,   1.9214203E-04
     +,   1.9388796E-04,   1.9540520E-04,   1.9668977E-04
     +,   1.9774280E-04,   1.9857052E-04,   1.9918491E-04
     +,   1.9960346E-04,   1.9984934E-04,   1.9995098E-04
     +,   1.9994155E-04,   1.9985868E-04,   1.9974328E-04
     +,   1.9963879E-04,   1.9959007E-04,   1.9964240E-04
     +,   1.9984011E-04,   2.0022545E-04,   2.0083736E-04
     +,   2.0171031E-04,   2.0287321E-04,   2.0434857E-04
     +,   2.0615141E-04,   2.0828896E-04,   2.1075987E-04
     +,   2.1355427E-04,   2.1665367E-04,   2.2003079E-04
     +,   2.2365029E-04,   2.2746959E-04,   2.3143931E-04
     +,   2.3550399E-04,   2.3960417E-04,   2.4367632E-04
     +,   2.4765564E-04,   2.5147595E-04,   2.5507249E-04
     +,   2.5838215E-04,   2.6134591E-04,   2.6390897E-04
     +,   2.6602304E-04,   2.6764674E-04,   2.6874631E-04
     +,   2.6929664E-04,   2.6928179E-04,   2.6869480E-04
     +,   2.6753813E-04,   2.6582327E-04,   2.6357031E-04
     +,   2.6080746E-04,   2.5757021E-04,   2.5390025E-04
     +,   2.4984451E-04,   2.4545417E-04,   2.4078343E-04
     +,   2.3588759E-04,   2.3082241E-04,   2.2564302E-04
     +,   2.2040264E-04,   2.1515087E-04,   2.0993348E-04
     +,   2.0479164E-04,   1.9976120E-04,   1.9487186E-04
     +,   1.9014701E-04,   1.8560431E-04,   1.8125480E-04
     +,   1.7710355E-04,   1.7315020E-04,   1.6938928E-04
     +,   1.6581037E-04,   1.6239936E-04,   1.5913897E-04
     +,   1.5600957E-04,   1.5298948E-04,   1.5005628E-04
     +,   1.4718737E-04,   1.4436072E-04,   1.4155502E-04
     +,   1.3875068E-04,   1.3593043E-04,   1.3307913E-04
     +,   1.3018440E-04,   1.2723703E-04,   1.2423068E-04
     +,   1.2116204E-04,   1.1803080E-04,   1.1483981E-04
     +,   1.1159461E-04,   1.0830316E-04,   1.0497572E-04
     +,   1.0162478E-04,   9.8264565E-05,   9.4910509E-05
     +,   9.1579095E-05,   8.8287939E-05,   8.5054788E-05
     +,   8.1897546E-05,   7.8834215E-05,   7.5882417E-05
     +,   7.3058902E-05,   7.0379632E-05,   6.7859728E-05
     +,   6.5513050E-05,   6.3351996E-05,   6.1387502E-05
     +,   5.9629099E-05,   5.8084683E-05,   5.6760375E-05
     +,   5.5660639E-05,   5.4788325E-05,   5.4144526E-05
     +,   5.3728661E-05,   5.3538617E-05,   5.3570628E-05
     +,   5.3819465E-05,   5.4278480E-05,   5.4939665E-05
     +,   5.5793731E-05,   5.6830264E-05,   5.8037815E-05
     +,   5.9403927E-05,   6.0915223E-05,   6.2557730E-05
     +,   6.4316846E-05,   6.6177214E-05,   6.8123321E-05
     +,   7.0139286E-05,   7.2208939E-05,   7.4316020E-05
     +,   7.6444390E-05,   7.8578065E-05,   8.0701095E-05
     +,   8.2797880E-05,   8.4853309E-05,   8.6852844E-05
     +,   8.8782312E-05,   9.0628222E-05,   9.2377923E-05
     +,   9.4019590E-05,   9.5542033E-05,   9.6935175E-05
     +,   9.8189841E-05,   9.9297788E-05,   1.0025183E-04
     +,   1.0104587E-04,   1.0167486E-04,   1.0213487E-04
     +,   1.0242296E-04,   1.0253735E-04,   1.0247731E-04
     +,   1.0224311E-04,   1.0183611E-04,   1.0125856E-04
     +,   1.0051372E-04,   9.9605721E-05,   9.8539509E-05
     +,   9.7320772E-05,   9.5956020E-05,   9.4452371E-05
     +,   9.2817507E-05,   9.1059541E-05,   8.9187160E-05
     +,   8.7209432E-05,   8.5135587E-05,   8.2975057E-05
     +,   8.0737547E-05,   7.8432873E-05,   7.6070697E-05
     +,   7.3660602E-05,   7.1212315E-05,   6.8735142E-05
     +,   6.6238135E-05,   6.3730258E-05,   6.1220133E-05
     +,   5.8715857E-05,   5.6225137E-05,   5.3755397E-05
     +,   5.1313611E-05,   4.8906131E-05,   4.6538789E-05
     +,   4.4217188E-05,   4.1946081E-05,   3.9730043E-05
     +,   3.7572812E-05,   3.5477948E-05,   3.3448217E-05
     +,   3.1486179E-05,   2.9593675E-05,   2.7772348E-05
     +,   2.6023166E-05,   2.4346940E-05,   2.2743909E-05
     +,   2.1213978E-05,   1.9756868E-05,   1.8371797E-05
     +,   1.7057890E-05,   1.5813845E-05,   1.4638304E-05
     +,   1.3529546E-05,   1.2485829E-05,   1.1505123E-05
     +,   1.0585400E-05,   9.7244065E-06,   8.9199248E-06
     +,   8.1695680E-06,   7.4710051E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_ww_mass = Yx/0.007571865
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_ashz_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.4744227E-07,   9.1525226E-07
     +,   9.8754708E-07,   1.0645582E-06,   1.1465280E-06
     +,   1.2337088E-06,   1.3263655E-06,   1.4247751E-06
     +,   1.5292285E-06,   1.6400361E-06,   1.7575205E-06
     +,   1.8820253E-06,   2.0139150E-06,   2.1535764E-06
     +,   2.3014218E-06,   2.4578928E-06,   2.6234613E-06
     +,   2.7986327E-06,   2.9839518E-06,   3.1800030E-06
     +,   3.3874160E-06,   3.6068695E-06,   3.8390936E-06
     +,   4.0848904E-06,   4.3450955E-06,   4.6206446E-06
     +,   4.9125251E-06,   5.2218038E-06,   5.5496330E-06
     +,   5.8972450E-06,   6.2659647E-06,   6.6572047E-06
     +,   7.0724777E-06,   7.5133798E-06,   7.9816191E-06
     +,   8.4789863E-06,   9.0073672E-06,   9.5687310E-06
     +,   1.0165160E-05,   1.0798748E-05,   1.1471722E-05
     +,   1.2186316E-05,   1.2944815E-05,   1.3749514E-05
     +,   1.4602704E-05,   1.5506657E-05,   1.6463579E-05
     +,   1.7475599E-05,   1.8544735E-05,   1.9672843E-05
     +,   2.0861606E-05,   2.2112490E-05,   2.3426677E-05
     +,   2.4805156E-05,   2.6248435E-05,   2.7756820E-05
     +,   2.9330151E-05,   3.0967880E-05,   3.2669050E-05
     +,   3.4432269E-05,   3.6255693E-05,   3.8137139E-05
     +,   4.0073839E-05,   4.2062835E-05,   4.4100834E-05
     +,   4.6184065E-05,   4.8308822E-05,   5.0470982E-05
     +,   5.2666630E-05,   5.4891621E-05,   5.7142239E-05
     +,   5.9414753E-05,   6.1706029E-05,   6.4013140E-05
     +,   6.6333938E-05,   6.8666952E-05,   7.1011280E-05
     +,   7.3366842E-05,   7.5734584E-05,   7.8116354E-05
     +,   8.0514605E-05,   8.2933067E-05,   8.5375868E-05
     +,   8.7848261E-05,   9.0355796E-05,   9.2904775E-05
     +,   9.5501520E-05,   9.8152799E-05,   1.0086490E-04
     +,   1.0364400E-04,   1.0649573E-04,   1.0942459E-04
     +,   1.1243396E-04,   1.1552600E-04,   1.1870116E-04
     +,   1.2195767E-04,   1.2529206E-04,   1.2869808E-04
     +,   1.3216742E-04,   1.3568868E-04,   1.3924828E-04
     +,   1.4282949E-04,   1.4641337E-04,   1.4997799E-04
     +,   1.5349935E-04,   1.5695138E-04,   1.6030586E-04
     +,   1.6353314E-04,   1.6660274E-04,   1.6948364E-04
     +,   1.7214447E-04,   1.7455507E-04,   1.7668614E-04
     +,   1.7851085E-04,   1.8000510E-04,   1.8114873E-04
     +,   1.8192612E-04,   1.8232742E-04,   1.8234931E-04
     +,   1.8199610E-04,   1.8128051E-04,   1.8022470E-04
     +,   1.7886104E-04,   1.7723281E-04,   1.7539474E-04
     +,   1.7341349E-04,   1.7136784E-04,   1.6934883E-04
     +,   1.6745918E-04,   1.6581347E-04,   1.6453690E-04
     +,   1.6376488E-04,   1.6364145E-04,   1.6431832E-04
     +,   1.6595269E-04,   1.6870498E-04,   1.7273606E-04
     +,   1.7820325E-04,   1.8525684E-04,   1.9403578E-04
     +,   2.0466256E-04,   2.1724033E-04,   2.3185395E-04
     +,   2.4857116E-04,   2.6744860E-04,   2.8854667E-04
     +,   3.1194513E-04,   3.3775912E-04,   3.6615704E-04
     +,   3.9737229E-04,   4.3169770E-04,   4.6946097E-04
     +,   5.1098282E-04,   5.5651338E-04,   6.0615153E-04
     +,   6.5975724E-04,   7.1688148E-04,   7.7672821E-04
     +,   8.3815044E-04,   8.9969748E-04,   9.5972122E-04
     +,   1.0165097E-03,   1.0684283E-03,   1.1140615E-03
     +,   1.1523141E-03,   1.1824623E-03,   1.2041505E-03
     +,   1.2173639E-03,   1.2223705E-03,   1.2196760E-03
     +,   1.2099907E-03,   1.1942274E-03,   1.1734978E-03
     +,   1.1491089E-03,   1.1225238E-03,   1.0952775E-03
     +,   1.0688483E-03,   1.0445092E-03,   1.0231725E-03
     +,   1.0052779E-03,   9.9074689E-04,   9.7901525E-04
     +,   9.6914207E-04,   9.5997693E-04,   9.5034344E-04
     +,   9.3922100E-04,   9.2587038E-04,   9.0990355E-04
     +,   8.9128193E-04,   8.7026623E-04,   8.4731798E-04
     +,   8.2299492E-04,   7.9785503E-04,   7.7238254E-04
     +,   7.4694667E-04,   7.2179607E-04,   6.9707638E-04
     +,   6.7286234E-04,   6.4918882E-04,   6.2608323E-04
     +,   6.0358376E-04,   5.8174488E-04,   5.6063122E-04
     +,   5.4030912E-04,   5.2083639E-04,   5.0224824E-04
     +,   4.8455372E-04,   4.6773680E-04,   4.5175833E-04
     +,   4.3656304E-04,   4.2208814E-04,   4.0827249E-04
     +,   3.9506122E-04,   3.8240795E-04,   3.7027744E-04
     +,   3.5864356E-04,   3.4748713E-04,   3.3679054E-04
     +,   3.2653511E-04,   3.1670002E-04,   3.0725743E-04
     +,   2.9817360E-04,   2.8940960E-04,   2.8092237E-04
     +,   2.7266631E-04,   2.6459646E-04,   2.5667151E-04
     +,   2.4885565E-04,   2.4111973E-04,   2.3344267E-04
     +,   2.2581262E-04,   2.1822572E-04,   2.1068497E-04
     +,   2.0319907E-04,   1.9578192E-04,   1.8844911E-04
     +,   1.8121702E-04,   1.7410224E-04,   1.6711954E-04
     +,   1.6028095E-04,   1.5359565E-04,   1.4707036E-04
     +,   1.4070893E-04,   1.3451226E-04,   1.2847938E-04
     +,   1.2260830E-04,   1.1689601E-04,   1.1133885E-04
     +,   1.0593313E-04,   1.0067626E-04,   9.5565629E-05
     +,   9.0599548E-05,   8.5777530E-05,   8.1099890E-05
     +,   7.6567434E-05,   7.2181632E-05,   6.7944711E-05
     +,   6.3859166E-05,   5.9927326E-05,   5.6151497E-05
     +,   5.2533924E-05,   4.9076487E-05,   4.5780271E-05
     +,   4.2645788E-05,   3.9673127E-05,   3.6861325E-05
     +,   3.4208664E-05,   3.1712854E-05,   2.9370822E-05
     +,   2.7178636E-05,   2.5131743E-05,   2.3225146E-05
     +,   2.1453334E-05,   1.9810272E-05,   1.8289595E-05
     +,   1.6884864E-05,   1.5589283E-05,   1.4396177E-05
     +,   1.3298703E-05,   1.2290249E-05,   1.1364208E-05
     +,   1.0514292E-05,   9.7343336E-06,   9.0185658E-06
     +,   8.3614204E-06,   7.7577542E-06,   7.2027055E-06
     +,   6.6917723E-06,   6.2208542E-06,   5.7861384E-06
     +,   5.3842100E-06,   5.0119288E-06,   4.6665177E-06
     +,   4.3454456E-06,   4.0465002E-06,   3.7676762E-06
     +,   3.5072401E-06,   3.2636285E-06,   3.0354995E-06
     +,   2.8216439E-06,   2.6210275E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_ashz_zz_mass = Yx/0.0175800625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  8.0130434E-05,   8.3235609E-05
     +,   8.6340093E-05,   8.9435882E-05,   9.2514871E-05
     +,   9.5568939E-05,   9.8590033E-05,   1.0157013E-04
     +,   1.0450140E-04,   1.0737641E-04,   1.1018782E-04
     +,   1.1292876E-04,   1.1559283E-04,   1.1817412E-04
     +,   1.2066730E-04,   1.2306763E-04,   1.2537112E-04
     +,   1.2757449E-04,   1.2967520E-04,   1.3167158E-04
     +,   1.3356280E-04,   1.3534883E-04,   1.3703055E-04
     +,   1.3860979E-04,   1.4008916E-04,   1.4147215E-04
     +,   1.4276315E-04,   1.4396726E-04,   1.4509042E-04
     +,   1.4613924E-04,   1.4712097E-04,   1.4804337E-04
     +,   1.4891478E-04,   1.4974388E-04,   1.5053959E-04
     +,   1.5131099E-04,   1.5206721E-04,   1.5281721E-04
     +,   1.5356990E-04,   1.5433348E-04,   1.5511591E-04
     +,   1.5592424E-04,   1.5676480E-04,   1.5764289E-04
     +,   1.5856270E-04,   1.5952709E-04,   1.6053759E-04
     +,   1.6159426E-04,   1.6269552E-04,   1.6383821E-04
     +,   1.6501741E-04,   1.6622660E-04,   1.6745761E-04
     +,   1.6870057E-04,   1.6994411E-04,   1.7117556E-04
     +,   1.7238084E-04,   1.7354487E-04,   1.7465175E-04
     +,   1.7568492E-04,   1.7662758E-04,   1.7746279E-04
     +,   1.7817387E-04,   1.7874483E-04,   1.7916046E-04
     +,   1.7940679E-04,   1.7947136E-04,   1.7934348E-04
     +,   1.7901437E-04,   1.7847776E-04,   1.7772958E-04
     +,   1.7676844E-04,   1.7559553E-04,   1.7421486E-04
     +,   1.7263305E-04,   1.7085923E-04,   1.6890536E-04
     +,   1.6678544E-04,   1.6451575E-04,   1.6211420E-04
     +,   1.5960059E-04,   1.5699571E-04,   1.5432143E-04
     +,   1.5159983E-04,   1.4885352E-04,   1.4610446E-04
     +,   1.4337452E-04,   1.4068407E-04,   1.3805267E-04
     +,   1.3549806E-04,   1.3303607E-04,   1.3068071E-04
     +,   1.2844376E-04,   1.2633455E-04,   1.2435985E-04
     +,   1.2252429E-04,   1.2082976E-04,   1.1927608E-04
     +,   1.1786052E-04,   1.1657838E-04,   1.1542295E-04
     +,   1.1438581E-04,   1.1345700E-04,   1.1262543E-04
     +,   1.1187883E-04,   1.1120432E-04,   1.1058846E-04
     +,   1.1001783E-04,   1.0947882E-04,   1.0895824E-04
     +,   1.0844348E-04,   1.0792249E-04,   1.0738429E-04
     +,   1.0681881E-04,   1.0621729E-04,   1.0557213E-04
     +,   1.0487709E-04,   1.0412739E-04,   1.0331949E-04
     +,   1.0245142E-04,   1.0152234E-04,   1.0053286E-04
     +,   9.9484787E-05,   9.8380980E-05,   9.7225304E-05
     +,   9.6022632E-05,   9.4778472E-05,   9.3499155E-05
     +,   9.2191302E-05,   9.0862144E-05,   8.9518966E-05
     +,   8.8169349E-05,   8.6820728E-05,   8.5480584E-05
     +,   8.4156083E-05,   8.2854036E-05,   8.1581005E-05
     +,   8.0343074E-05,   7.9145713E-05,   7.7993856E-05
     +,   7.6891942E-05,   7.5843695E-05,   7.4852178E-05
     +,   7.3919829E-05,   7.3048563E-05,   7.2239520E-05
     +,   7.1493305E-05,   7.0809976E-05,   7.0189075E-05
     +,   6.9629597E-05,   6.9130110E-05,   6.8688802E-05
     +,   6.8303489E-05,   6.7971690E-05,   6.7690642E-05
     +,   6.7457404E-05,   6.7268877E-05,   6.7121793E-05
     +,   6.7012828E-05,   6.6938665E-05,   6.6895889E-05
     +,   6.6881184E-05,   6.6891247E-05,   6.6922847E-05
     +,   6.6972854E-05,   6.7038265E-05,   6.7116183E-05
     +,   6.7203822E-05,   6.7298570E-05,   6.7397945E-05
     +,   6.7499575E-05,   6.7601279E-05,   6.7700988E-05
     +,   6.7796769E-05,   6.7886816E-05,   6.7969428E-05
     +,   6.8043068E-05,   6.8106245E-05,   6.8157613E-05
     +,   6.8195877E-05,   6.8219873E-05,   6.8228459E-05
     +,   6.8220601E-05,   6.8195317E-05,   6.8151690E-05
     +,   6.8088848E-05,   6.8005982E-05,   6.7902314E-05
     +,   6.7777131E-05,   6.7629779E-05,   6.7459616E-05
     +,   6.7266075E-05,   6.7048619E-05,   6.6806802E-05
     +,   6.6540168E-05,   6.6248358E-05,   6.5931083E-05
     +,   6.5588087E-05,   6.5219188E-05,   6.4824264E-05
     +,   6.4403277E-05,   6.3956264E-05,   6.3483312E-05
     +,   6.2984589E-05,   6.2460400E-05,   6.1911043E-05
     +,   6.1336897E-05,   6.0738494E-05,   6.0116421E-05
     +,   5.9471295E-05,   5.8803813E-05,   5.8114776E-05
     +,   5.7405061E-05,   5.6675577E-05,   5.5927267E-05
     +,   5.5161188E-05,   5.4378459E-05,   5.3580166E-05
     +,   5.2767460E-05,   5.1941577E-05,   5.1103740E-05
     +,   5.0255145E-05,   4.9397113E-05,   4.8530906E-05
     +,   4.7657792E-05,   4.6778998E-05,   4.5895827E-05
     +,   4.5009554E-05,   4.4121367E-05,   4.3232441E-05
     +,   4.2343989E-05,   4.1457170E-05,   4.0573061E-05
     +,   3.9692688E-05,   3.8817143E-05,   3.7947346E-05
     +,   3.7084206E-05,   3.6228619E-05,   3.5381436E-05
     +,   3.4543391E-05,   3.3715165E-05,   3.2897449E-05
     +,   3.2090869E-05,   3.1295949E-05,   3.0513154E-05
     +,   2.9742958E-05,   2.8985762E-05,   2.8241901E-05
     +,   2.7511622E-05,   2.6795218E-05,   2.6092870E-05
     +,   2.5404701E-05,   2.4730844E-05,   2.4071391E-05
     +,   2.3426350E-05,   2.2795701E-05,   2.2179420E-05
     +,   2.1577469E-05,   2.0989721E-05,   2.0416039E-05
     +,   1.9856290E-05,   1.9310322E-05,   1.8777926E-05
     +,   1.8258868E-05,   1.7752967E-05,   1.7259956E-05
     +,   1.6779572E-05,   1.6311564E-05,   1.5855680E-05
     +,   1.5411615E-05,   1.4979079E-05,   1.4557792E-05
     +,   1.4147477E-05,   1.3747826E-05,   1.3358531E-05
     +,   1.2979328E-05,   1.2609901E-05,   1.2249984E-05
     +,   1.1899272E-05,   1.1557509E-05,   1.1224399E-05
     +,   1.0899697E-05,   1.0583124E-05,   1.0274446E-05
     +,   9.9733988E-06,   9.6797658E-06,   9.3933086E-06
     +,   9.1138018E-06,   8.8410497E-06,   8.5748361E-06
     +,   8.3149871E-06,   8.0613008E-06,   7.8136200E-06
     +,   7.5717667E-06,   7.3355973E-06,   7.1049499E-06
     +,   6.8797008E-06,   6.6597049E-06,   6.4448523E-06
     +,   6.2350150E-06,   6.0300972E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_eez_mass = Yx/0.00633713043478261
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.7302174E-05,   1.0004684E-04
     +,   1.0279497E-04,   1.0554221E-04,   1.0828426E-04
     +,   1.1101660E-04,   1.1373473E-04,   1.1643408E-04
     +,   1.1911009E-04,   1.2175827E-04,   1.2437411E-04
     +,   1.2695318E-04,   1.2949112E-04,   1.3198380E-04
     +,   1.3442710E-04,   1.3681717E-04,   1.3915030E-04
     +,   1.4142309E-04,   1.4363232E-04,   1.4577509E-04
     +,   1.4784878E-04,   1.4985108E-04,   1.5178000E-04
     +,   1.5363398E-04,   1.5541169E-04,   1.5711236E-04
     +,   1.5873542E-04,   1.6028080E-04,   1.6174882E-04
     +,   1.6314012E-04,   1.6445582E-04,   1.6569738E-04
     +,   1.6686662E-04,   1.6796577E-04,   1.6899739E-04
     +,   1.6996435E-04,   1.7086988E-04,   1.7171749E-04
     +,   1.7251099E-04,   1.7325439E-04,   1.7395194E-04
     +,   1.7460815E-04,   1.7522759E-04,   1.7581506E-04
     +,   1.7637546E-04,   1.7691373E-04,   1.7743495E-04
     +,   1.7794417E-04,   1.7844648E-04,   1.7894690E-04
     +,   1.7945044E-04,   1.7996207E-04,   1.8048660E-04
     +,   1.8102876E-04,   1.8159318E-04,   1.8218427E-04
     +,   1.8280635E-04,   1.8346347E-04,   1.8415957E-04
     +,   1.8489822E-04,   1.8568296E-04,   1.8651698E-04
     +,   1.8740314E-04,   1.8834417E-04,   1.8934255E-04
     +,   1.9040026E-04,   1.9151915E-04,   1.9270070E-04
     +,   1.9394609E-04,   1.9525607E-04,   1.9663114E-04
     +,   1.9807130E-04,   1.9957630E-04,   2.0114535E-04
     +,   2.0277737E-04,   2.0447079E-04,   2.0622360E-04
     +,   2.0803318E-04,   2.0989665E-04,   2.1181065E-04
     +,   2.1377111E-04,   2.1577365E-04,   2.1781324E-04
     +,   2.1988453E-04,   2.2198145E-04,   2.2409766E-04
     +,   2.2622605E-04,   2.2835936E-04,   2.3048968E-04
     +,   2.3260871E-04,   2.3470786E-04,   2.3677811E-04
     +,   2.3881003E-04,   2.4079416E-04,   2.4272079E-04
     +,   2.4457989E-04,   2.4636151E-04,   2.4805564E-04
     +,   2.4965231E-04,   2.5114158E-04,   2.5251397E-04
     +,   2.5376002E-04,   2.5487086E-04,   2.5583766E-04
     +,   2.5665245E-04,   2.5730778E-04,   2.5779670E-04
     +,   2.5811300E-04,   2.5825118E-04,   2.5820674E-04
     +,   2.5797574E-04,   2.5755548E-04,   2.5694384E-04
     +,   2.5613976E-04,   2.5514330E-04,   2.5395516E-04
     +,   2.5257733E-04,   2.5101253E-04,   2.4926453E-04
     +,   2.4733783E-04,   2.4523796E-04,   2.4297113E-04
     +,   2.4054442E-04,   2.3796562E-04,   2.3524290E-04
     +,   2.3238556E-04,   2.2940250E-04,   2.2630420E-04
     +,   2.2310035E-04,   2.1980188E-04,   2.1641924E-04
     +,   2.1296335E-04,   2.0944493E-04,   2.0587504E-04
     +,   2.0226430E-04,   1.9862324E-04,   1.9496230E-04
     +,   1.9129174E-04,   1.8762120E-04,   1.8396012E-04
     +,   1.8031753E-04,   1.7670231E-04,   1.7312246E-04
     +,   1.6958558E-04,   1.6609924E-04,   1.6267005E-04
     +,   1.5930420E-04,   1.5600772E-04,   1.5278609E-04
     +,   1.4964414E-04,   1.4658636E-04,   1.4361696E-04
     +,   1.4073990E-04,   1.3795840E-04,   1.3527559E-04
     +,   1.3269442E-04,   1.3021748E-04,   1.2784713E-04
     +,   1.2558536E-04,   1.2343437E-04,   1.2139590E-04
     +,   1.1947162E-04,   1.1766312E-04,   1.1597198E-04
     +,   1.1439963E-04,   1.1294729E-04,   1.1161627E-04
     +,   1.1040791E-04,   1.0932326E-04,   1.0836339E-04
     +,   1.0752938E-04,   1.0682219E-04,   1.0624263E-04
     +,   1.0579151E-04,   1.0546952E-04,   1.0527715E-04
     +,   1.0521482E-04,   1.0528276E-04,   1.0548113E-04
     +,   1.0580982E-04,   1.0626857E-04,   1.0685687E-04
     +,   1.0757407E-04,   1.0841926E-04,   1.0939135E-04
     +,   1.1048898E-04,   1.1171051E-04,   1.1305421E-04
     +,   1.1451804E-04,   1.1609968E-04,   1.1779667E-04
     +,   1.1960647E-04,   1.2152609E-04,   1.2355241E-04
     +,   1.2568232E-04,   1.2791244E-04,   1.3023922E-04
     +,   1.3265890E-04,   1.3516781E-04,   1.3776218E-04
     +,   1.4043796E-04,   1.4319101E-04,   1.4601731E-04
     +,   1.4891285E-04,   1.5187320E-04,   1.5489421E-04
     +,   1.5797162E-04,   1.6110104E-04,   1.6427791E-04
     +,   1.6749784E-04,   1.7075641E-04,   1.7404890E-04
     +,   1.7737043E-04,   1.8071625E-04,   1.8408152E-04
     +,   1.8746099E-04,   1.9084928E-04,   1.9424097E-04
     +,   1.9763054E-04,   2.0101183E-04,   2.0437883E-04
     +,   2.0772516E-04,   2.1104414E-04,   2.1432868E-04
     +,   2.1757167E-04,   2.2076569E-04,   2.2390288E-04
     +,   2.2697507E-04,   2.2997404E-04,   2.3289134E-04
     +,   2.3571812E-04,   2.3844527E-04,   2.4106383E-04
     +,   2.4356454E-04,   2.4593808E-04,   2.4817500E-04
     +,   2.5026611E-04,   2.5220215E-04,   2.5397388E-04
     +,   2.5557252E-04,   2.5698938E-04,   2.5821614E-04
     +,   2.5924487E-04,   2.6006807E-04,   2.6067876E-04
     +,   2.6107067E-04,   2.6123802E-04,   2.6117571E-04
     +,   2.6087955E-04,   2.6034599E-04,   2.5957241E-04
     +,   2.5855695E-04,   2.5729882E-04,   2.5579805E-04
     +,   2.5405569E-04,   2.5207349E-04,   2.4985455E-04
     +,   2.4740264E-04,   2.4472253E-04,   2.4181981E-04
     +,   2.3870109E-04,   2.3537388E-04,   2.3184632E-04
     +,   2.2812719E-04,   2.2422645E-04,   2.2015421E-04
     +,   2.1592132E-04,   2.1153915E-04,   2.0701981E-04
     +,   2.0237532E-04,   1.9761802E-04,   1.9276080E-04
     +,   1.8781668E-04,   1.8279848E-04,   1.7771899E-04
     +,   1.7259145E-04,   1.6742820E-04,   1.6224218E-04
     +,   1.5704536E-04,   1.5185002E-04,   1.4666740E-04
     +,   1.4150902E-04,   1.3638526E-04,   1.3130660E-04
     +,   1.2628242E-04,   1.2132207E-04,   1.1643389E-04
     +,   1.1162562E-04,   1.0690478E-04,   1.0227769E-04
     +,   9.7750635E-05,   9.3328665E-05,   8.9016750E-05
     +,   8.4818712E-05,   8.0738289E-05,   7.6778109E-05
     +,   7.2940704E-05,   6.9227601E-05,   6.5640263E-05
     +,   6.2179191E-05,   5.8844827E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_qq_mass = Yx/0.01336895
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.8247894E-04,   1.9043939E-04
     +,   1.9843537E-04,   2.0643961E-04,   2.1442334E-04
     +,   2.2235692E-04,   2.3020993E-04,   2.3795155E-04
     +,   2.4555059E-04,   2.5297649E-04,   2.6019875E-04
     +,   2.6718789E-04,   2.7391614E-04,   2.8035665E-04
     +,   2.8648536E-04,   2.9228014E-04,   2.9772220E-04
     +,   3.0279544E-04,   3.0748770E-04,   3.1179038E-04
     +,   3.1569923E-04,   3.1921419E-04,   3.2233997E-04
     +,   3.2508580E-04,   3.2746591E-04,   3.2949931E-04
     +,   3.3120991E-04,   3.3262672E-04,   3.3378348E-04
     +,   3.3471832E-04,   3.3547444E-04,   3.3609907E-04
     +,   3.3664354E-04,   3.3716287E-04,   3.3771619E-04
     +,   3.3836495E-04,   3.3917392E-04,   3.4020978E-04
     +,   3.4154157E-04,   3.4323908E-04,   3.4537271E-04
     +,   3.4801321E-04,   3.5122992E-04,   3.5509054E-04
     +,   3.5965993E-04,   3.6499902E-04,   3.7116339E-04
     +,   3.7820256E-04,   3.8615734E-04,   3.9505959E-04
     +,   4.0493070E-04,   4.1577884E-04,   4.2759941E-04
     +,   4.4037285E-04,   4.5406280E-04,   4.6861806E-04
     +,   4.8396960E-04,   5.0003227E-04,   5.1670492E-04
     +,   5.3387188E-04,   5.5140536E-04,   5.6916714E-04
     +,   5.8701105E-04,   6.0479011E-04,   6.2235753E-04
     +,   6.3957111E-04,   6.5630145E-04,   6.7243271E-04
     +,   6.8787218E-04,   7.0255034E-04,   7.1642874E-04
     +,   7.2949968E-04,   7.4179308E-04,   7.5337384E-04
     +,   7.6434435E-04,   7.7484263E-04,   7.8503863E-04
     +,   7.9513324E-04,   8.0535002E-04,   8.1593049E-04
     +,   8.2712638E-04,   8.3919149E-04,   8.5237139E-04
     +,   8.6689816E-04,   8.8297518E-04,   9.0077537E-04
     +,   9.2042721E-04,   9.4200968E-04,   9.6554559E-04
     +,   9.9099765E-04,   1.0182644E-03,   1.0471799E-03
     +,   1.0775101E-03,   1.1089629E-03,   1.1411888E-03
     +,   1.1737861E-03,   1.2063143E-03,   1.2383015E-03
     +,   1.2692604E-03,   1.2986964E-03,   1.3261270E-03
     +,   1.3510921E-03,   1.3731731E-03,   1.3920000E-03
     +,   1.4072687E-03,   1.4187458E-03,   1.4262798E-03
     +,   1.4298025E-03,   1.4293351E-03,   1.4249826E-03
     +,   1.4169322E-03,   1.4054464E-03,   1.3908523E-03
     +,   1.3735306E-03,   1.3539072E-03,   1.3324320E-03
     +,   1.3095746E-03,   1.2858000E-03,   1.2615644E-03
     +,   1.2372998E-03,   1.2134005E-03,   1.1902197E-03
     +,   1.1680585E-03,   1.1471616E-03,   1.1277155E-03
     +,   1.1098443E-03,   1.0936140E-03,   1.0790335E-03
     +,   1.0660562E-03,   1.0545907E-03,   1.0445005E-03
     +,   1.0356167E-03,   1.0277416E-03,   1.0206623E-03
     +,   1.0141529E-03,   1.0079843E-03,   1.0019364E-03
     +,   9.9579676E-04,   9.8937424E-04,   9.8249933E-04
     +,   9.7503007E-04,   9.6685503E-04,   9.5789513E-04
     +,   9.4810250E-04,   9.3746273E-04,   9.2599151E-04
     +,   9.1373327E-04,   9.0075767E-04,   8.8715786E-04
     +,   8.7304384E-04,   8.5853925E-04,   8.4377942E-04
     +,   8.2890381E-04,   8.1405393E-04,   7.9936848E-04
     +,   7.8498165E-04,   7.7101967E-04,   7.5759547E-04
     +,   7.4481015E-04,   7.3275075E-04,   7.2148826E-04
     +,   7.1107724E-04,   7.0155517E-04,   6.9294625E-04
     +,   6.8525673E-04,   6.7847886E-04,   6.7259249E-04
     +,   6.6756504E-04,   6.6335290E-04,   6.5990462E-04
     +,   6.5716094E-04,   6.5505609E-04,   6.5352151E-04
     +,   6.5248564E-04,   6.5187475E-04,   6.5161678E-04
     +,   6.5164035E-04,   6.5187708E-04,   6.5226178E-04
     +,   6.5273361E-04,   6.5323734E-04,   6.5372331E-04
     +,   6.5414829E-04,   6.5447506E-04,   6.5467332E-04
     +,   6.5471925E-04,   6.5459526E-04,   6.5429072E-04
     +,   6.5380015E-04,   6.5312389E-04,   6.5226754E-04
     +,   6.5124128E-04,   6.5005949E-04,   6.4873917E-04
     +,   6.4730138E-04,   6.4577011E-04,   6.4417062E-04
     +,   6.4253144E-04,   6.4088183E-04,   6.3925207E-04
     +,   6.3767465E-04,   6.3618325E-04,   6.3481106E-04
     +,   6.3359260E-04,   6.3256262E-04,   6.3175563E-04
     +,   6.3120545E-04,   6.3094596E-04,   6.3100748E-04
     +,   6.3142000E-04,   6.3221017E-04,   6.3339958E-04
     +,   6.3500652E-04,   6.3704333E-04,   6.3951680E-04
     +,   6.4242602E-04,   6.4576248E-04,   6.4951001E-04
     +,   6.5364444E-04,   6.5813260E-04,   6.6293287E-04
     +,   6.6799711E-04,   6.7326875E-04,   6.7868491E-04
     +,   6.8417750E-04,   6.8967539E-04,   6.9510425E-04
     +,   7.0038781E-04,   7.0545159E-04,   7.1022351E-04
     +,   7.1463414E-04,   7.1861933E-04,   7.2212098E-04
     +,   7.2508916E-04,   7.2748063E-04,   7.2926230E-04
     +,   7.3040801E-04,   7.3090190E-04,   7.3073496E-04
     +,   7.2990765E-04,   7.2842604E-04,   7.2630279E-04
     +,   7.2355603E-04,   7.2020682E-04,   7.1627973E-04
     +,   7.1180117E-04,   7.0679688E-04,   7.0129277E-04
     +,   6.9531373E-04,   6.8888266E-04,   6.8201934E-04
     +,   6.7474099E-04,   6.6706259E-04,   6.5899559E-04
     +,   6.5054873E-04,   6.4172875E-04,   6.3253939E-04
     +,   6.2298420E-04,   6.1306520E-04,   6.0278305E-04
     +,   5.9213996E-04,   5.8113859E-04,   5.6978193E-04
     +,   5.5807515E-04,   5.4602628E-04,   5.3364434E-04
     +,   5.2094145E-04,   5.0793309E-04,   4.9463776E-04
     +,   4.8107569E-04,   4.6727055E-04,   4.5324882E-04
     +,   4.3904030E-04,   4.2467602E-04,   4.1018889E-04
     +,   3.9561509E-04,   3.8099050E-04,   3.6635384E-04
     +,   3.5174267E-04,   3.3719686E-04,   3.2275438E-04
     +,   3.0845450E-04,   2.9433364E-04,   2.8042935E-04
     +,   2.6677540E-04,   2.5340557E-04,   2.4035011E-04
     +,   2.2763679E-04,   2.1529217E-04,   2.0333781E-04
     +,   1.9179434E-04,   1.8067737E-04,   1.7000093E-04
     +,   1.5977441E-04,   1.5000533E-04,   1.4069694E-04
     +,   1.3185057E-04,   1.2346364E-04,   1.1553204E-04
     +,   1.0804807E-04,   1.0100289E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_ww_mass = Yx/0.0479515547368421
      RETURN
      END
      DOUBLE PRECISION FUNCTION A206_tt_hzonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.8023692E-05,   4.9675895E-05
     +,   5.1359188E-05,   5.3074054E-05,   5.4820986E-05
     +,   5.6600533E-05,   5.8413327E-05,   6.0259994E-05
     +,   6.2141153E-05,   6.4057567E-05,   6.6009830E-05
     +,   6.7998568E-05,   7.0024347E-05,   7.2087656E-05
     +,   7.4188880E-05,   7.6328266E-05,   7.8505931E-05
     +,   8.0721773E-05,   8.2975515E-05,   8.5266598E-05
     +,   8.7594228E-05,   8.9957291E-05,   9.2354312E-05
     +,   9.4783703E-05,   9.7243137E-05,   9.9730249E-05
     +,   1.0224211E-04,   1.0477538E-04,   1.0732639E-04
     +,   1.0989099E-04,   1.1246466E-04,   1.1504246E-04
     +,   1.1761903E-04,   1.2018869E-04,   1.2274542E-04
     +,   1.2528279E-04,   1.2779422E-04,   1.3027279E-04
     +,   1.3271146E-04,   1.3510288E-04,   1.3743980E-04
     +,   1.3971484E-04,   1.4192068E-04,   1.4404995E-04
     +,   1.4609555E-04,   1.4805063E-04,   1.4990856E-04
     +,   1.5166306E-04,   1.5330824E-04,   1.5483872E-04
     +,   1.5624975E-04,   1.5753704E-04,   1.5869708E-04
     +,   1.5972691E-04,   1.6062449E-04,   1.6138860E-04
     +,   1.6201872E-04,   1.6251532E-04,   1.6287967E-04
     +,   1.6311397E-04,   1.6322151E-04,   1.6320632E-04
     +,   1.6307342E-04,   1.6282886E-04,   1.6247947E-04
     +,   1.6203291E-04,   1.6149803E-04,   1.6088414E-04
     +,   1.6020155E-04,   1.5946123E-04,   1.5867484E-04
     +,   1.5785478E-04,   1.5701383E-04,   1.5616536E-04
     +,   1.5532313E-04,   1.5450112E-04,   1.5371357E-04
     +,   1.5297493E-04,   1.5229940E-04,   1.5170121E-04
     +,   1.5119434E-04,   1.5079220E-04,   1.5050793E-04
     +,   1.5035378E-04,   1.5034126E-04,   1.5048098E-04
     +,   1.5078233E-04,   1.5125365E-04,   1.5190172E-04
     +,   1.5273191E-04,   1.5374816E-04,   1.5495245E-04
     +,   1.5634511E-04,   1.5792470E-04,   1.5968787E-04
     +,   1.6162930E-04,   1.6374195E-04,   1.6601691E-04
     +,   1.6844351E-04,   1.7100947E-04,   1.7370100E-04
     +,   1.7650309E-04,   1.7939998E-04,   1.8237473E-04
     +,   1.8541045E-04,   1.8849046E-04,   1.9159808E-04
     +,   1.9471829E-04,   1.9783762E-04,   2.0094521E-04
     +,   2.0403294E-04,   2.0709720E-04,   2.1013850E-04
     +,   2.1316334E-04,   2.1618434E-04,   2.1922129E-04
     +,   2.2230165E-04,   2.2546115E-04,   2.2874396E-04
     +,   2.3220264E-04,   2.3589838E-04,   2.3989940E-04
     +,   2.4428027E-04,   2.4912073E-04,   2.5450316E-04
     +,   2.6050973E-04,   2.6722046E-04,   2.7470943E-04
     +,   2.8304229E-04,   2.9227248E-04,   3.0244025E-04
     +,   3.1356973E-04,   3.2566971E-04,   3.3873349E-04
     +,   3.5274337E-04,   3.6767541E-04,   3.8350391E-04
     +,   4.0021187E-04,   4.1780091E-04,   4.3630190E-04
     +,   4.5578266E-04,   4.7635700E-04,   4.9819337E-04
     +,   5.2151410E-04,   5.4658833E-04,   5.7372783E-04
     +,   6.0326629E-04,   6.3553476E-04,   6.7083194E-04
     +,   7.0939650E-04,   7.5136730E-04,   7.9675007E-04
     +,   8.4539416E-04,   8.9697441E-04,   9.5098780E-04
     +,   1.0067540E-03,   1.0634485E-03,   1.1201418E-03
     +,   1.1758474E-03,   1.2295772E-03,   1.2804137E-03
     +,   1.3275704E-03,   1.3704316E-03,   1.4086070E-03
     +,   1.4419467E-03,   1.4705467E-03,   1.4947259E-03
     +,   1.5149901E-03,   1.5319805E-03,   1.5464019E-03
     +,   1.5589562E-03,   1.5702697E-03,   1.5808361E-03
     +,   1.5909735E-03,   1.6008022E-03,   1.6102528E-03
     +,   1.6190961E-03,   1.6269914E-03,   1.6335539E-03
     +,   1.6384163E-03,   1.6412929E-03,   1.6420132E-03
     +,   1.6405367E-03,   1.6369384E-03,   1.6313703E-03
     +,   1.6240007E-03,   1.6149564E-03,   1.6042646E-03
     +,   1.5918213E-03,   1.5773912E-03,   1.5606242E-03
     +,   1.5411170E-03,   1.5184841E-03,   1.4924370E-03
     +,   1.4628473E-03,   1.4297988E-03,   1.3936098E-03
     +,   1.3548093E-03,   1.3140984E-03,   1.2722806E-03
     +,   1.2301845E-03,   1.1885853E-03,   1.1481325E-03
     +,   1.1093065E-03,   1.0723969E-03,   1.0374964E-03
     +,   1.0045271E-03,   9.7328296E-04,   9.4347156E-04
     +,   9.1476826E-04,   8.8686182E-04,   8.5949275E-04
     +,   8.3247904E-04,   8.0572936E-04,   7.7924220E-04
     +,   7.5309951E-04,   7.2744890E-04,   7.0247945E-04
     +,   6.7839731E-04,   6.5541046E-04,   6.3369848E-04
     +,   6.1340292E-04,   5.9461797E-04,   5.7738210E-04
     +,   5.6167960E-04,   5.4744334E-04,   5.3456466E-04
     +,   5.2290026E-04,   5.1228260E-04,   5.0253101E-04
     +,   4.9346237E-04,   4.8489889E-04,   4.7667496E-04
     +,   4.6864297E-04,   4.6067746E-04,   4.5267623E-04
     +,   4.4456069E-04,   4.3627611E-04,   4.2778917E-04
     +,   4.1908497E-04,   4.1016427E-04,   4.0104138E-04
     +,   3.9174024E-04,   3.8229077E-04,   3.7272673E-04
     +,   3.6308379E-04,   3.5339774E-04,   3.4370148E-04
     +,   3.3402466E-04,   3.2439432E-04,   3.1483234E-04
     +,   3.0535660E-04,   2.9598124E-04,   2.8671685E-04
     +,   2.7757039E-04,   2.6854622E-04,   2.5964726E-04
     +,   2.5087513E-04,   2.4223028E-04,   2.3371269E-04
     +,   2.2532314E-04,   2.1706302E-04,   2.0893363E-04
     +,   2.0093759E-04,   1.9307884E-04,   1.8536160E-04
     +,   1.7779088E-04,   1.7037296E-04,   1.6311429E-04
     +,   1.5602143E-04,   1.4910074E-04,   1.4235909E-04
     +,   1.3580275E-04,   1.2943716E-04,   1.2326712E-04
     +,   1.1729710E-04,   1.1153003E-04,   1.0596863E-04
     +,   1.0061390E-04,   9.5466581E-05,   9.0525922E-05
     +,   8.5790874E-05,   8.1259001E-05,   7.6927710E-05
     +,   7.2793198E-05,   6.8851637E-05,   6.5098320E-05
     +,   6.1528146E-05,   5.8136022E-05,   5.4916127E-05
     +,   5.1862902E-05,   4.8970189E-05,   4.6232122E-05
     +,   4.3642423E-05,   4.1195141E-05,   3.8883965E-05
     +,   3.6702968E-05,   3.4645986E-05,   3.2707179E-05
     +,   3.0880579E-05,   2.9160567E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A206_tt_hzonly_zz_mass = Yx/0.0327478918918919
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.6901237E-28,   1.5435930E-27
     +,   6.3347996E-27,   2.5506124E-26,   1.0075445E-25
     +,   3.9047562E-25,   1.4846764E-24,   5.5383392E-24
     +,   2.0268760E-23,   7.2777082E-23,   2.5637182E-22
     +,   8.8604503E-22,   3.0043549E-21,   9.9943944E-21
     +,   3.2618821E-20,   1.0444594E-19,   3.2811401E-19
     +,   1.0112639E-18,   3.0578530E-18,   9.0714367E-18
     +,   2.6402522E-17,   7.5391881E-17,   2.1120597E-16
     +,   5.8051160E-16,   1.5653497E-15,   4.1412127E-15
     +,   1.0748663E-14,   2.7370924E-14,   6.8380706E-14
     +,   1.6760520E-13,   4.0304218E-13,   9.5087664E-13
     +,   2.2009293E-12,   4.9980085E-12,   1.1135194E-11
     +,   2.4339298E-11,   5.2194860E-11,   1.0981231E-10
     +,   2.2667029E-10,   4.5902598E-10,   9.1199981E-10
     +,   1.7777096E-09,   3.3996703E-09,   6.3785537E-09
     +,   1.1741314E-08,   2.1204135E-08,   3.7569333E-08
     +,   6.5306487E-08,   1.1137510E-07,   1.8635009E-07
     +,   3.0590061E-07,   4.9265208E-07,   7.7840656E-07
     +,   1.2066698E-06,   1.8351587E-06,   2.7382387E-06
     +,   4.0084674E-06,   5.7569778E-06,   8.1118560E-06
     +,   1.1213866E-05,   1.5208968E-05,   2.0237438E-05
     +,   2.6419024E-05,   3.3836674E-05,   4.2517851E-05
     +,   5.2415697E-05,   6.3396285E-05,   7.5226926E-05
     +,   8.7578010E-05,   1.0002881E-04,   1.1209025E-04
     +,   1.2323140E-04,   1.3292000E-04,   1.4066177E-04
     +,   1.4604477E-04,   1.4877526E-04,   1.4870569E-04
     +,   1.4585063E-04,   1.4038694E-04,   1.3263989E-04
     +,   1.2305834E-04,   1.1217778E-04,   1.0058355E-04
     +,   8.8868845E-05,   7.7602897E-05,   6.7300112E-05
     +,   5.8403821E-05,   5.1272775E-05,   4.6179375E-05
     +,   4.3308606E-05,   4.2761425E-05,   4.4556957E-05
     +,   4.8632439E-05,   5.4842294E-05,   6.2955529E-05
     +,   7.2652852E-05,   8.3530198E-05,   9.5103584E-05
     +,   1.0682726E-04,   1.1811440E-04,   1.2837208E-04
     +,   1.3703590E-04,   1.4361249E-04,   1.4771473E-04
     +,   1.4909421E-04,   1.4765993E-04,   1.4348479E-04
     +,   1.3679736E-04,   1.2795874E-04,   1.1742942E-04
     +,   1.0572997E-04,   9.3396207E-05,   8.0941776E-05
     +,   6.8821522E-05,   5.7410056E-05,   4.6984926E-05
     +,   3.7726073E-05,   2.9718767E-05,   2.2968521E-05
     +,   1.7415858E-05,   1.2955735E-05,   9.4555817E-06
     +,   6.7706196E-06,   4.7563981E-06,   3.2781763E-06
     +,   2.2166703E-06,   1.4705287E-06,   9.5710891E-07
     +,   6.1115628E-07,   3.8287698E-07,   2.3532520E-07
     +,   1.4190390E-07,   8.3950283E-08,   4.8726722E-08
     +,   2.7747342E-08,   1.5501623E-08,   8.4965377E-09
     +,   4.5690363E-09,   2.4105549E-09,   1.2476977E-09
     +,   6.3359418E-10,   3.1566869E-10,   1.5429867E-10
     +,   7.3993214E-11,   3.4812934E-11,   1.6069398E-11
     +,   7.2770826E-12,   3.2331301E-12,   1.4093230E-12
     +,   6.0270902E-13,   2.5287295E-13,   1.0408909E-13
     +,   4.2036866E-14,   1.6655793E-14,   6.4743611E-15
     +,   2.4690892E-15,   9.2384804E-16,   3.3913553E-16
     +,   1.2213526E-16,   4.3155161E-17,   1.4960122E-17
     +,   5.0877994E-18,   1.6975973E-18,   5.5573152E-19
     +,   1.7848576E-19,   5.6238931E-20,   1.7385160E-20
     +,   5.2728673E-21,   1.5690067E-21,   4.5802880E-22
     +,   1.3118140E-22,   3.6861940E-23,   1.0162345E-23
     +,   2.7485251E-24,   7.2934870E-25,   1.8987984E-25
     +,   4.8496743E-26,   1.2152281E-26,   2.9876481E-27
     +,   7.2062771E-28,   1.7052214E-28,   3.9587869E-29
     +,   9.0171972E-30,   2.0150811E-30,   4.4177400E-31
     +,   9.5020204E-32,   2.0052407E-32,   4.1516774E-33
     +,   8.4327145E-34,   1.6805222E-34,   3.2857228E-35
     +,   6.3023752E-36,   1.1860076E-36,   2.1897966E-37
     +,   3.9666746E-38,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_eez_mass = Yx/0.00126175
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   3.9391391E-38,   5.2513068E-36
     +,   5.9891391E-34,   5.8437603E-32,   4.8780875E-30
     +,   3.4836902E-28,   2.1284347E-26,   1.1124672E-24
     +,   4.9750766E-23,   1.9032255E-21,   6.2292846E-20
     +,   1.7442898E-18,   4.1785939E-17,   8.5639356E-16
     +,   1.5015741E-14,   2.2524419E-13,   2.8906170E-12
     +,   3.1736516E-11,   2.9809819E-10,   2.3954703E-09
     +,   1.6468498E-08,   9.6860830E-08,   4.8737502E-07
     +,   2.0981261E-06,   7.7270115E-06,   2.4346293E-05
     +,   6.5627464E-05,   1.5134565E-04,   2.9859747E-04
     +,   5.0400570E-04,   7.2781951E-04,   8.9924474E-04
     +,   9.5085218E-04,   8.6152705E-04,   6.7263131E-04
     +,   4.6395449E-04,   3.1197237E-04,   2.6245162E-04
     +,   3.2542573E-04,   4.7860207E-04,   6.6975487E-04
     +,   8.2646485E-04,   8.8301336E-04,   8.1361306E-04
     +,   6.4597215E-04,   4.4184734E-04,   2.6036342E-04
     +,   1.3217340E-04,   5.7803958E-05,   2.1777369E-05
     +,   7.0683072E-06,   1.9763115E-06,   4.7605991E-07
     +,   9.8785698E-08,   1.7660245E-08,   2.7197007E-09
     +,   3.6084460E-10,   4.1241646E-11,   4.0609903E-12
     +,   3.4448990E-13,   2.5172806E-14,   1.5846513E-15
     +,   8.5945204E-17,   4.0156724E-18,   1.6162136E-19
     +,   5.6044350E-21,   1.6740354E-22,   4.3081741E-24
     +,   9.5503667E-26,   1.8240887E-27,   3.0009702E-29
     +,   4.2538597E-31,   5.1938715E-33,   5.4640536E-35
     +,   4.9520103E-37,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00,   0.0000000E+00
     +,   0.0000000E+00,   0.0000000E+00
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_qq_mass = Yx/0.002746625
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.8025045E-06,   3.0861277E-06
     +,   3.3929198E-06,   3.7241480E-06,   4.0810833E-06
     +,   4.4649933E-06,   4.8771308E-06,   5.3187305E-06
     +,   5.7909815E-06,   6.2950608E-06,   6.8320624E-06
     +,   7.4030258E-06,   8.0089148E-06,   8.6506043E-06
     +,   9.3288609E-06,   1.0044344E-05,   1.0797578E-05
     +,   1.1588956E-05,   1.2418707E-05,   1.3286900E-05
     +,   1.4193422E-05,   1.5137975E-05,   1.6120037E-05
     +,   1.7138947E-05,   1.8193708E-05,   1.9283210E-05
     +,   2.0406045E-05,   2.1560585E-05,   2.2744960E-05
     +,   2.3957056E-05,   2.5194524E-05,   2.6454778E-05
     +,   2.7734992E-05,   2.9032122E-05,   3.0342910E-05
     +,   3.1663894E-05,   3.2991433E-05,   3.4321682E-05
     +,   3.5650748E-05,   3.6974448E-05,   3.8288676E-05
     +,   3.9589122E-05,   4.0871491E-05,   4.2131465E-05
     +,   4.3364726E-05,   4.4567030E-05,   4.5734210E-05
     +,   4.6862217E-05,   4.7947175E-05,   4.8985381E-05
     +,   4.9973376E-05,   5.0907973E-05,   5.1786225E-05
     +,   5.2605610E-05,   5.3363852E-05,   5.4059135E-05
     +,   5.4690016E-05,   5.5255485E-05,   5.5754961E-05
     +,   5.6188328E-05,   5.6555909E-05,   5.6858527E-05
     +,   5.7097419E-05,   5.7274305E-05,   5.7391349E-05
     +,   5.7451110E-05,   5.7456578E-05,   5.7411104E-05
     +,   5.7318382E-05,   5.7182438E-05,   5.7007524E-05
     +,   5.6798166E-05,   5.6559027E-05,   5.6294950E-05
     +,   5.6010816E-05,   5.5711549E-05,   5.5402066E-05
     +,   5.5087217E-05,   5.4771692E-05,   5.4460015E-05
     +,   5.4156524E-05,   5.3865231E-05,   5.3589883E-05
     +,   5.3333835E-05,   5.3100095E-05,   5.2891228E-05
     +,   5.2709369E-05,   5.2556174E-05,   5.2432864E-05
     +,   5.2340136E-05,   5.2278221E-05,   5.2246869E-05
     +,   5.2245352E-05,   5.2272477E-05,   5.2326632E-05
     +,   5.2405765E-05,   5.2507454E-05,   5.2628919E-05
     +,   5.2767064E-05,   5.2918516E-05,   5.3079664E-05
     +,   5.3246717E-05,   5.3415719E-05,   5.3582633E-05
     +,   5.3743348E-05,   5.3893771E-05,   5.4029813E-05
     +,   5.4147476E-05,   5.4242872E-05,   5.4312288E-05
     +,   5.4352171E-05,   5.4359214E-05,   5.4330358E-05
     +,   5.4262811E-05,   5.4154079E-05,   5.4001983E-05
     +,   5.3804681E-05,   5.3560649E-05,   5.3268748E-05
     +,   5.2928124E-05,   5.2538308E-05,   5.2099160E-05
     +,   5.1610907E-05,   5.1074057E-05,   5.0489412E-05
     +,   4.9858161E-05,   4.9181661E-05,   4.8461628E-05
     +,   4.7699952E-05,   4.6898811E-05,   4.6060497E-05
     +,   4.5187586E-05,   4.4282719E-05,   4.3348755E-05
     +,   4.2388601E-05,   4.1405267E-05,   4.0401865E-05
     +,   3.9381586E-05,   3.8347578E-05,   3.7302998E-05
     +,   3.6251062E-05,   3.5194975E-05,   3.4137818E-05
     +,   3.3082619E-05,   3.2032465E-05,   3.0990217E-05
     +,   2.9958661E-05,   2.8940558E-05,   2.7938526E-05
     +,   2.6955006E-05,   2.5992305E-05,   2.5052654E-05
     +,   2.4138124E-05,   2.3250595E-05,   2.2391778E-05
     +,   2.1563279E-05,   2.0766558E-05,   2.0002844E-05
     +,   1.9273215E-05,   1.8578654E-05,   1.7919911E-05
     +,   1.7297583E-05,   1.6712158E-05,   1.6163960E-05
     +,   1.5653131E-05,   1.5179671E-05,   1.4743478E-05
     +,   1.4344309E-05,   1.3981768E-05,   1.3655348E-05
     +,   1.3364445E-05,   1.3108350E-05,   1.2886234E-05
     +,   1.2697185E-05,   1.2540227E-05,   1.2414280E-05
     +,   1.2318213E-05,   1.2250833E-05,   1.2210893E-05
     +,   1.2197102E-05,   1.2208124E-05,   1.2242600E-05
     +,   1.2299138E-05,   1.2376336E-05,   1.2472774E-05
     +,   1.2587027E-05,   1.2717663E-05,   1.2863256E-05
     +,   1.3022403E-05,   1.3193682E-05,   1.3375714E-05
     +,   1.3567138E-05,   1.3766602E-05,   1.3972779E-05
     +,   1.4184385E-05,   1.4400169E-05,   1.4618900E-05
     +,   1.4839377E-05,   1.5060456E-05,   1.5281023E-05
     +,   1.5500000E-05,   1.5716343E-05,   1.5929067E-05
     +,   1.6137221E-05,   1.6339887E-05,   1.6536209E-05
     +,   1.6725369E-05,   1.6906586E-05,   1.7079126E-05
     +,   1.7242302E-05,   1.7395485E-05,   1.7538070E-05
     +,   1.7669508E-05,   1.7789293E-05,   1.7896975E-05
     +,   1.7992134E-05,   1.8074403E-05,   1.8143455E-05
     +,   1.8199024E-05,   1.8240864E-05,   1.8268789E-05
     +,   1.8282655E-05,   1.8282357E-05,   1.8267829E-05
     +,   1.8239061E-05,   1.8196066E-05,   1.8138908E-05
     +,   1.8067689E-05,   1.7982544E-05,   1.7883642E-05
     +,   1.7771201E-05,   1.7645467E-05,   1.7506714E-05
     +,   1.7355245E-05,   1.7191409E-05,   1.7015567E-05
     +,   1.6828106E-05,   1.6629449E-05,   1.6420046E-05
     +,   1.6200349E-05,   1.5970838E-05,   1.5732016E-05
     +,   1.5484406E-05,   1.5228525E-05,   1.4964909E-05
     +,   1.4694116E-05,   1.4416708E-05,   1.4133242E-05
     +,   1.3844274E-05,   1.3550391E-05,   1.3252154E-05
     +,   1.2950119E-05,   1.2644855E-05,   1.2336934E-05
     +,   1.2026895E-05,   1.1715269E-05,   1.1402602E-05
     +,   1.1089421E-05,   1.0776226E-05,   1.0463499E-05
     +,   1.0151731E-05,   9.8413893E-06,   9.5329151E-06
     +,   9.2267192E-06,   8.9232362E-06,   8.6228356E-06
     +,   8.3258819E-06,   8.0327327E-06,   7.7437207E-06
     +,   7.4591426E-06,   7.1792720E-06,   6.9043817E-06
     +,   6.6347188E-06,   6.3704952E-06,   6.1118976E-06
     +,   5.8591186E-06,   5.6122994E-06,   5.3715908E-06
     +,   5.1370889E-06,   4.9089067E-06,   4.6871050E-06
     +,   4.4717558E-06,   4.2628853E-06,   4.0605296E-06
     +,   3.8646831E-06,   3.6753504E-06,   3.4924997E-06
     +,   3.3160882E-06,   3.1460772E-06,   2.9823925E-06
     +,   2.8249697E-06,   2.6737132E-06,   2.5285385E-06
     +,   2.3893310E-06,   2.2559877E-06,   2.1283799E-06
     +,   2.0063896E-06,   1.8898758E-06,   1.7787100E-06
     +,   1.6727415E-06,   1.5718330E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_ww_mass = Yx/0.00188956923076923
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_haonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.5125409E-05,   1.5500767E-05
     +,   1.5885646E-05,   1.6280359E-05,   1.6685301E-05
     +,   1.7100905E-05,   1.7527691E-05,   1.7966218E-05
     +,   1.8417109E-05,   1.8881074E-05,   1.9358846E-05
     +,   1.9851228E-05,   2.0359064E-05,   2.0883253E-05
     +,   2.1424716E-05,   2.1984411E-05,   2.2563323E-05
     +,   2.3162431E-05,   2.3782724E-05,   2.4425186E-05
     +,   2.5090767E-05,   2.5780386E-05,   2.6494896E-05
     +,   2.7235143E-05,   2.8001801E-05,   2.8795550E-05
     +,   2.9616904E-05,   3.0466281E-05,   3.1343963E-05
     +,   3.2250078E-05,   3.3184613E-05,   3.4147371E-05
     +,   3.5137989E-05,   3.6155921E-05,   3.7200429E-05
     +,   3.8270562E-05,   3.9365179E-05,   4.0482937E-05
     +,   4.1622345E-05,   4.2781590E-05,   4.3958818E-05
     +,   4.5151901E-05,   4.6358564E-05,   4.7576370E-05
     +,   4.8802744E-05,   5.0034982E-05,   5.1270254E-05
     +,   5.2505664E-05,   5.3738244E-05,   5.4964959E-05
     +,   5.6182758E-05,   5.7388595E-05,   5.8579415E-05
     +,   5.9752289E-05,   6.0904204E-05,   6.2032377E-05
     +,   6.3134059E-05,   6.4206637E-05,   6.5247594E-05
     +,   6.6254630E-05,   6.7225548E-05,   6.8158362E-05
     +,   6.9051181E-05,   6.9902388E-05,   7.0710492E-05
     +,   7.1474162E-05,   7.2192262E-05,   7.2863775E-05
     +,   7.3487885E-05,   7.4063850E-05,   7.4591131E-05
     +,   7.5069205E-05,   7.5497737E-05,   7.5876385E-05
     +,   7.6204960E-05,   7.6483266E-05,   7.6711163E-05
     +,   7.6888544E-05,   7.7015306E-05,   7.7091383E-05
     +,   7.7116703E-05,   7.7091179E-05,   7.7014767E-05
     +,   7.6887387E-05,   7.6709031E-05,   7.6479628E-05
     +,   7.6199212E-05,   7.5867858E-05,   7.5485637E-05
     +,   7.5052791E-05,   7.4569572E-05,   7.4036405E-05
     +,   7.3453841E-05,   7.2822586E-05,   7.2143470E-05
     +,   7.1417613E-05,   7.0646252E-05,   6.9830930E-05
     +,   6.8973372E-05,   6.8075584E-05,   6.7139765E-05
     +,   6.6168512E-05,   6.5164531E-05,   6.4130880E-05
     +,   6.3070860E-05,   6.1987928E-05,   6.0885886E-05
     +,   5.9768739E-05,   5.8640584E-05,   5.7505727E-05
     +,   5.6368681E-05,   5.5233959E-05,   5.4106251E-05
     +,   5.2990181E-05,   5.1890511E-05,   5.0811828E-05
     +,   4.9758786E-05,   4.8735816E-05,   4.7747322E-05
     +,   4.6797435E-05,   4.5890061E-05,   4.5028952E-05
     +,   4.4217519E-05,   4.3458862E-05,   4.2755710E-05
     +,   4.2110500E-05,   4.1525196E-05,   4.1001444E-05
     +,   4.0540384E-05,   4.0142793E-05,   3.9808951E-05
     +,   3.9538732E-05,   3.9331539E-05,   3.9186347E-05
     +,   3.9101702E-05,   3.9075698E-05,   3.9106046E-05
     +,   3.9190072E-05,   3.9324703E-05,   3.9506544E-05
     +,   3.9731880E-05,   3.9996667E-05,   4.0296651E-05
     +,   4.0627358E-05,   4.0984058E-05,   4.1361945E-05
     +,   4.1756070E-05,   4.2161366E-05,   4.2572774E-05
     +,   4.2985204E-05,   4.3393648E-05,   4.3793101E-05
     +,   4.4178698E-05,   4.4545726E-05,   4.4889650E-05
     +,   4.5206107E-05,   4.5490975E-05,   4.5740428E-05
     +,   4.5950885E-05,   4.6119079E-05,   4.6242065E-05
     +,   4.6317258E-05,   4.6342378E-05,   4.6315537E-05
     +,   4.6235193E-05,   4.6100187E-05,   4.5909710E-05
     +,   4.5663328E-05,   4.5360975E-05,   4.5002893E-05
     +,   4.4589706E-05,   4.4122356E-05,   4.3602078E-05
     +,   4.3030395E-05,   4.2409138E-05,   4.1740350E-05
     +,   4.1026306E-05,   4.0269504E-05,   3.9472674E-05
     +,   3.8638598E-05,   3.7770249E-05,   3.6870722E-05
     +,   3.5943202E-05,   3.4990902E-05,   3.4017045E-05
     +,   3.3024939E-05,   3.2017881E-05,   3.0999083E-05
     +,   2.9971696E-05,   2.8938912E-05,   2.7903738E-05
     +,   2.6869082E-05,   2.5837790E-05,   2.4812607E-05
     +,   2.3796058E-05,   2.2790526E-05,   2.1798309E-05
     +,   2.0821541E-05,   1.9862127E-05,   1.8921814E-05
     +,   1.8002234E-05,   1.7104852E-05,   1.6230906E-05
     +,   1.5381474E-05,   1.4557550E-05,   1.3759886E-05
     +,   1.2989091E-05,   1.2245675E-05,   1.1529999E-05
     +,   1.0842253E-05,   1.0182495E-05,   9.5507185E-06
     +,   8.9467949E-06,   8.3704599E-06,   7.8213579E-06
     +,   7.2990847E-06,   6.8031563E-06,   6.3329912E-06
     +,   5.8879450E-06,   5.4673701E-06,   5.0705280E-06
     +,   4.6966470E-06,   4.3449486E-06,   4.0146310E-06
     +,   3.7048487E-06,   3.4147504E-06,   3.1434952E-06
     +,   2.8902396E-06,   2.6541254E-06,   2.4343044E-06
     +,   2.2299537E-06,   2.0402604E-06,   1.8644196E-06
     +,   1.7016422E-06,   1.5511806E-06,   1.4122926E-06
     +,   1.2842620E-06,   1.1664079E-06,   1.0580744E-06
     +,   9.5862640E-07,   8.6745706E-07,   7.8399466E-07
     +,   7.0769391E-07,   6.3803327E-07,   5.7451871E-07
     +,   5.1668860E-07,   4.6410739E-07,   4.1636136E-07
     +,   3.7306305E-07,   3.3385373E-07,   2.9839373E-07
     +,   2.6636678E-07,   2.3748061E-07,   2.1146282E-07
     +,   1.8805945E-07,   1.6703548E-07,   1.4817515E-07
     +,   1.3127897E-07,   1.1616239E-07,   1.0265574E-07
     +,   9.0604360E-08,   7.9866226E-08,   7.0310861E-08
     +,   6.1819293E-08,   5.4283799E-08,   4.7605553E-08
     +,   4.1694928E-08,   3.6470979E-08,   3.1860392E-08
     +,   2.7796537E-08,   2.4219380E-08,   2.1075067E-08
     +,   1.8315070E-08,   1.5895681E-08,   1.3777727E-08
     +,   1.1926307E-08,   1.0310015E-08,   8.9010443E-09
     +,   7.6744007E-09,   6.6080563E-09,   5.6822826E-09
     +,   4.8797233E-09,   4.1849026E-09,   3.5842374E-09
     +,   3.0656517E-09,   2.6185947E-09,   2.2337223E-09
     +,   1.9028368E-09,   1.6187904E-09,   1.3752740E-09
     +,   1.1668154E-09,   9.8860575E-10,   8.3648100E-10
     +,   7.0679806E-10,   5.9640992E-10,   5.0257271E-10
     +,   4.2292325E-10,   3.5540820E-10,   2.9826380E-10
     +,   2.4996255E-10,   2.0919672E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_haonly_zz_mass = Yx/0.00252741176470588
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.0782264E-11,   1.2690046E-10
     +,   1.7660794E-10,   2.4470437E-10,   3.3756517E-10
     +,   4.6361512E-10,   6.3393230E-10,   8.6300200E-10
     +,   1.1696704E-09,   1.5783458E-09,   2.1204365E-09
     +,   2.8361715E-09,   3.7768060E-09,   5.0072742E-09
     +,   6.6094086E-09,   8.6857721E-09,   1.1364190E-08
     +,   1.4803147E-08,   1.9197909E-08,   2.4787864E-08
     +,   3.1864634E-08,   4.0781554E-08,   5.1963951E-08
     +,   6.5921860E-08,   8.3260453E-08,   1.0469740E-07
     +,   1.3107483E-07,   1.6337627E-07,   2.0274300E-07
     +,   2.5048999E-07,   3.0812225E-07,   3.7735069E-07
     +,   4.6010527E-07,   5.5854775E-07,   6.7508176E-07
     +,   8.1235669E-07,   9.7327006E-07,   1.1609604E-06
     +,   1.3788130E-06,   1.6304042E-06,   1.9195304E-06
     +,   2.2501292E-06,   2.6262592E-06,   3.0520500E-06
     +,   3.5316398E-06,   4.0691139E-06,   4.6684304E-06
     +,   5.3333515E-06,   6.0673574E-06,   6.8735721E-06
     +,   7.7546911E-06,   8.7128965E-06,   9.7498023E-06
     +,   1.0866456E-05,   1.2063140E-05,   1.3339580E-05
     +,   1.4694754E-05,   1.6126991E-05,   1.7633998E-05
     +,   1.9212912E-05,   2.0860378E-05,   2.2572662E-05
     +,   2.4345612E-05,   2.6175037E-05,   2.8056653E-05
     +,   2.9986018E-05,   3.1959080E-05,   3.3971734E-05
     +,   3.6020432E-05,   3.8101694E-05,   4.0212697E-05
     +,   4.2350723E-05,   4.4513723E-05,   4.6699755E-05
     +,   4.8907419E-05,   5.1135663E-05,   5.3383585E-05
     +,   5.5650617E-05,   5.7936602E-05,   6.0241713E-05
     +,   6.2566251E-05,   6.4911197E-05,   6.7277651E-05
     +,   6.9667440E-05,   7.2082519E-05,   7.4525517E-05
     +,   7.6999000E-05,   7.9505982E-05,   8.2048864E-05
     +,   8.4629850E-05,   8.7250148E-05,   8.9909321E-05
     +,   9.2604940E-05,   9.5332194E-05,   9.8083263E-05
     +,   1.0084651E-04,   1.0360687E-04,   1.0634494E-04
     +,   1.0903780E-04,   1.1165861E-04,   1.1417782E-04
     +,   1.1656345E-04,   1.1878268E-04,   1.2080264E-04
     +,   1.2259229E-04,   1.2412370E-04,   1.2537347E-04
     +,   1.2632426E-04,   1.2696593E-04,   1.2729643E-04
     +,   1.2732233E-04,   1.2705897E-04,   1.2653010E-04
     +,   1.2576711E-04,   1.2480804E-04,   1.2369581E-04
     +,   1.2247669E-04,   1.2119814E-04,   1.1990704E-04
     +,   1.1864751E-04,   1.1745923E-04,   1.1637608E-04
     +,   1.1542475E-04,   1.1462415E-04,   1.1398487E-04
     +,   1.1350955E-04,   1.1319314E-04,   1.1302392E-04
     +,   1.1298444E-04,   1.1305293E-04,   1.1320478E-04
     +,   1.1341377E-04,   1.1365372E-04,   1.1389946E-04
     +,   1.1412799E-04,   1.1431932E-04,   1.1445687E-04
     +,   1.1452791E-04,   1.1452349E-04,   1.1443830E-04
     +,   1.1427033E-04,   1.1402030E-04,   1.1369117E-04
     +,   1.1328734E-04,   1.1281421E-04,   1.1227742E-04
     +,   1.1168233E-04,   1.1103374E-04,   1.1033542E-04
     +,   1.0958990E-04,   1.0879841E-04,   1.0796090E-04
     +,   1.0707617E-04,   1.0614192E-04,   1.0515503E-04
     +,   1.0411193E-04,   1.0300876E-04,   1.0184162E-04
     +,   1.0060686E-04,   9.9301382E-05,   9.7922712E-05
     +,   9.6469121E-05,   9.4939889E-05,   9.3335279E-05
     +,   9.1656468E-05,   8.9905494E-05,   8.8085464E-05
     +,   8.6200329E-05,   8.4254563E-05,   8.2253289E-05
     +,   8.0202197E-05,   7.8107296E-05,   7.5974676E-05
     +,   7.3810450E-05,   7.1620852E-05,   6.9411755E-05
     +,   6.7188717E-05,   6.4957050E-05,   6.2721665E-05
     +,   6.0486818E-05,   5.8256348E-05,   5.6033718E-05
     +,   5.3821997E-05,   5.1623731E-05,   4.9441154E-05
     +,   4.7276480E-05,   4.5131776E-05,   4.3008928E-05
     +,   4.0909934E-05,   3.8837115E-05,   3.6792786E-05
     +,   3.4779543E-05,   3.2800359E-05,   3.0858482E-05
     +,   2.8957296E-05,   2.7100383E-05,   2.5291609E-05
     +,   2.3534889E-05,   2.1834012E-05,   2.0192663E-05
     +,   1.8614441E-05,   1.7102633E-05,   1.5660047E-05
     +,   1.4289049E-05,   1.2991622E-05,   1.1769056E-05
     +,   1.0622062E-05,   9.5508312E-06,   8.5549445E-06
     +,   7.6333417E-06,   6.7844321E-06,   6.0061820E-06
     +,   5.2961036E-06,   4.6512805E-06,   4.0684868E-06
     +,   3.5442895E-06,   3.0750650E-06,   2.6570403E-06
     +,   2.2863971E-06,   1.9593547E-06,   1.6721468E-06
     +,   1.4211154E-06,   1.2027513E-06,   1.0137078E-06
     +,   8.5081501E-07,   7.1111077E-07,   5.9186152E-07
     +,   4.9055075E-07,   4.0487862E-07,   3.3276569E-07
     +,   2.7234967E-07,   2.2196846E-07,   1.8014758E-07
     +,   1.4559110E-07,   1.1716973E-07,   9.3900276E-08
     +,   7.4935194E-08,   5.9549084E-08,   4.7123464E-08
     +,   3.7133784E-08,   2.9138505E-08,   2.2768504E-08
     +,   1.7716362E-08,   1.3727253E-08,   1.0591518E-08
     +,   8.1376923E-09,   6.2261156E-09,   4.7435318E-09
     +,   3.5987482E-09,   2.7187785E-09,   2.0453368E-09
     +,   1.5322169E-09,   1.1429950E-09,   8.4906604E-10
     +,   6.2806882E-10,   4.6263426E-10,   3.3934075E-10
     +,   2.4786054E-10,   1.8028021E-10,   1.3057268E-10
     +,   9.4172711E-11,   6.7634988E-11,   4.8371172E-11
     +,   3.4448083E-11,   2.4429651E-11,   1.7251960E-11
     +,   1.2131731E-11,   8.4952401E-12,   5.9238218E-12
     +,   4.1133650E-12,   2.8441758E-12,   1.9583207E-12
     +,   1.3427173E-12,   9.1675810E-13,   6.2328636E-13
     +,   4.2198287E-13,   2.8448852E-13,   1.9098929E-13
     +,   1.2767795E-13,   8.4995907E-14,   5.6343263E-14
     +,   3.7192990E-14,   2.4447932E-14,   1.6002883E-14
     +,   1.0430788E-14,   6.7703373E-15,   4.3759552E-15
     +,   2.8164191E-15,   1.8050816E-15,   1.1520131E-15
     +,   7.3213986E-16,   4.6333311E-16,   2.9198928E-16
     +,   1.8323248E-16,   1.1450223E-16,   7.1250261E-17
     +,   4.4150438E-17,   2.7242351E-17,   1.6739055E-17
     +,   1.0241829E-17,   6.2402232E-18
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_eez_mass = Yx/0.0028389375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1278260E-14,   9.3749159E-14
     +,   1.4281553E-13,   2.1663548E-13,   3.2721251E-13
     +,   4.9212614E-13,   7.3700269E-13,   1.0990258E-12
     +,   1.6318881E-12,   2.4128013E-12,   3.5522188E-12
     +,   5.2074378E-12,   7.6014039E-12,   1.1048683E-11
     +,   1.5990919E-11,   2.3045310E-11,   3.3070310E-11
     +,   4.7254131E-11,   6.7233850E-11,   9.5253902E-11
     +,   1.3437652E-10,   1.8876033E-10,   2.6402278E-10
     +,   3.6772588E-10,   5.0997379E-10,   7.0424017E-10
     +,   9.6836716E-10,   1.3258833E-09,   1.8076642E-09
     +,   2.4540097E-09,   3.3172800E-09,   4.4651256E-09
     +,   5.9845604E-09,   7.9868929E-09,   1.0613783E-08
     +,   1.4044584E-08,   1.8505267E-08,   2.4278750E-08
     +,   3.1718226E-08,   4.1260506E-08,   5.3445348E-08
     +,   6.8933851E-08,   8.8532616E-08,   1.1321965E-07
     +,   1.4417463E-07,   1.8281177E-07,   2.3081743E-07
     +,   2.9018963E-07,   3.6328277E-07,   4.5285339E-07
     +,   5.6210985E-07,   6.9476079E-07,   8.5506690E-07
     +,   1.0478999E-06,   1.2787624E-06,   1.5538725E-06
     +,   1.8801644E-06,   2.2653342E-06,   2.7178546E-06
     +,   3.2469738E-06,   3.8627077E-06,   4.5758097E-06
     +,   5.3976669E-06,   6.3403099E-06,   7.4162772E-06
     +,   8.6383534E-06,   1.0019657E-05,   1.1573134E-05
     +,   1.3311696E-05,   1.5247568E-05,   1.7392467E-05
     +,   1.9756819E-05,   2.2350016E-05,   2.5179486E-05
     +,   2.8250985E-05,   3.1568063E-05,   3.5131572E-05
     +,   3.8939619E-05,   4.2987591E-05,   4.7267877E-05
     +,   5.1769261E-05,   5.6477955E-05,   6.1376442E-05
     +,   6.6444874E-05,   7.1659990E-05,   7.6996716E-05
     +,   8.2427221E-05,   8.7922679E-05,   9.3452392E-05
     +,   9.8985511E-05,   1.0449111E-04,   1.0993840E-04
     +,   1.1529753E-04,   1.2054062E-04,   1.2564179E-04
     +,   1.3057707E-04,   1.3532587E-04,   1.3987003E-04
     +,   1.4419500E-04,   1.4828882E-04,   1.5214311E-04
     +,   1.5575168E-04,   1.5911137E-04,   1.6222059E-04
     +,   1.6507971E-04,   1.6769009E-04,   1.7005339E-04
     +,   1.7217136E-04,   1.7404523E-04,   1.7567516E-04
     +,   1.7705977E-04,   1.7819610E-04,   1.7907913E-04
     +,   1.7970195E-04,   1.8005571E-04,   1.8012991E-04
     +,   1.7991271E-04,   1.7939137E-04,   1.7855292E-04
     +,   1.7738463E-04,   1.7587483E-04,   1.7401358E-04
     +,   1.7179355E-04,   1.6921038E-04,   1.6626340E-04
     +,   1.6295658E-04,   1.5929813E-04,   1.5530174E-04
     +,   1.5098571E-04,   1.4637400E-04,   1.4149501E-04
     +,   1.3638235E-04,   1.3107329E-04,   1.2560935E-04
     +,   1.2003459E-04,   1.1439536E-04,   1.0873979E-04
     +,   1.0311673E-04,   9.7574455E-05,   9.2160299E-05
     +,   8.6920198E-05,   8.1897633E-05,   7.7132689E-05
     +,   7.2661845E-05,   6.8517998E-05,   6.4729196E-05
     +,   6.1318889E-05,   5.8306017E-05,   5.5704637E-05
     +,   5.3523829E-05,   5.1768086E-05,   5.0437528E-05
     +,   4.9527938E-05,   4.9031052E-05,   4.8934951E-05
     +,   4.9224356E-05,   4.9880891E-05,   5.0883449E-05
     +,   5.2208605E-05,   5.3830674E-05,   5.5722339E-05
     +,   5.7854770E-05,   6.0197817E-05,   6.2720319E-05
     +,   6.5390559E-05,   6.8176370E-05,   7.1045120E-05
     +,   7.3964220E-05,   7.6901415E-05,   7.9824902E-05
     +,   8.2703322E-05,   8.5506203E-05,   8.8204339E-05
     +,   9.0769827E-05,   9.3175993E-05,   9.5398216E-05
     +,   9.7413729E-05,   9.9201759E-05,   1.0074388E-04
     +,   1.0202420E-04,   1.0302941E-04,   1.0374881E-04
     +,   1.0417454E-04,   1.0430157E-04,   1.0412773E-04
     +,   1.0365366E-04,   1.0288283E-04,   1.0182141E-04
     +,   1.0047807E-04,   9.8864090E-05,   9.6992859E-05
     +,   9.4879804E-05,   9.2542301E-05,   8.9999310E-05
     +,   8.7270986E-05,   8.4378444E-05,   8.1343758E-05
     +,   7.8189551E-05,   7.4938347E-05,   7.1612645E-05
     +,   6.8234825E-05,   6.4826694E-05,   6.1409053E-05
     +,   5.8001711E-05,   5.4623644E-05,   5.1292180E-05
     +,   4.8023227E-05,   4.4831384E-05,   4.1729621E-05
     +,   3.8729104E-05,   3.5839323E-05,   3.3068376E-05
     +,   3.0422689E-05,   2.7906983E-05,   2.5524520E-05
     +,   2.3277304E-05,   2.1166050E-05,   1.9190111E-05
     +,   1.7347797E-05,   1.5636630E-05,   1.4053117E-05
     +,   1.2593055E-05,   1.1251750E-05,   1.0024004E-05
     +,   8.9041632E-06,   7.8863086E-06,   6.9644198E-06
     +,   6.1323713E-06,   5.3839699E-06,   4.7130866E-06
     +,   4.1137591E-06,   3.5801784E-06,   3.1067129E-06
     +,   2.6879804E-06,   2.3189098E-06,   1.9946742E-06
     +,   1.7107584E-06,   1.4629718E-06,   1.2474291E-06
     +,   1.0605381E-06,   8.9901181E-07,   7.5986151E-07
     +,   6.4037880E-07,   5.3810845E-07,   4.5084857E-07
     +,   3.7663648E-07,   3.1372355E-07,   2.6055665E-07
     +,   2.1576724E-07,   1.7815658E-07,   1.4667253E-07
     +,   1.2039926E-07,   9.8543715E-08,   8.0420683E-08
     +,   6.5439096E-08,   5.3092631E-08,   4.2949846E-08
     +,   3.4643584E-08,   2.7862161E-08,   2.2342592E-08
     +,   1.7864190E-08,   1.4241868E-08,   1.1320905E-08
     +,   8.9726866E-09,   7.0908421E-09,   5.5873208E-09
     +,   4.3897144E-09,   3.4387444E-09,   2.6859466E-09
     +,   2.0918252E-09,   1.6243541E-09,   1.2576695E-09
     +,   9.7092712E-10,   7.4737211E-10,   5.7360688E-10
     +,   4.3896078E-10,   3.3493788E-10,   2.5482239E-10
     +,   1.9330224E-10,   1.4620789E-10,   1.1026346E-10
     +,   8.2913704E-11,   6.2165377E-11,   4.6473433E-11
     +,   3.4640752E-11,   2.5745697E-11,   1.9078900E-11
     +,   1.4097029E-11,   1.0385717E-11,   7.6290814E-12
     +,   5.5878188E-12,   4.0807423E-12,   2.9714688E-12
     +,   2.1573882E-12,   1.5617854E-12,   1.1273025E-12
     +,   8.1132459E-13,   5.8220242E-13,   4.1657124E-13
     +,   2.9718751E-13,   2.1140095E-13
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_qq_mass = Yx/0.00332535
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.3211677E-17,   2.1721485E-17
     +,   3.5556613E-17,   5.7949594E-17,   9.4033157E-17
     +,   1.5191873E-16,   2.4436856E-16,   3.9136294E-16
     +,   6.2404311E-16,   9.9073643E-16,   1.5660531E-15
     +,   2.4646751E-15,   3.8620878E-15,   6.0254807E-15
     +,   9.3598962E-15,   1.4476398E-14,   2.2292647E-14
     +,   3.4180395E-14,   5.2180316E-14,   7.9314383E-14
     +,   1.2003700E-13,   1.8088230E-13,   2.7139166E-13
     +,   4.0543816E-13,   6.0307407E-13,   8.9319323E-13
     +,   1.3171897E-12,   1.9341102E-12,   2.8277723E-12
     +,   4.1166280E-12,   5.9672584E-12,   8.6128188E-12
     +,   1.2378158E-11,   1.7713679E-11,   2.5240931E-11
     +,   3.5813668E-11,   5.0598841E-11,   7.1183864E-11
     +,   9.9719587E-11,   1.3910079E-10,   1.9321435E-10
     +,   2.6724464E-10,   3.6807959E-10,   5.0482213E-10
     +,   6.8944905E-10,   9.3763675E-10,   1.2698089E-09
     +,   1.7124382E-09,   2.2996791E-09,   3.0753580E-09
     +,   4.0954635E-09,   5.4311373E-09,   7.1722961E-09
     +,   9.4322017E-09,   1.2352305E-08,   1.6109093E-08
     +,   2.0920897E-08,   2.7056846E-08,   3.4846703E-08
     +,   4.4692506E-08,   5.7081589E-08,   7.2601892E-08
     +,   9.1956949E-08,   1.1598706E-07,   1.4568842E-07
     +,   1.8223157E-07,   2.2699223E-07,   2.8156526E-07
     +,   3.4780271E-07,   4.2782341E-07,   5.2405619E-07
     +,   6.3924142E-07,   7.7647741E-07,   9.3920738E-07
     +,   1.1312609E-06,   1.3568515E-06,   1.6205555E-06
     +,   1.9273114E-06,   2.2824183E-06,   2.6914884E-06
     +,   3.1603493E-06,   3.6950794E-06,   4.3017981E-06
     +,   4.9867103E-06,   5.7558282E-06,   6.6150224E-06
     +,   7.5696662E-06,   8.6247064E-06,   9.7842394E-06
     +,   1.1051569E-05,   1.2428939E-05,   1.3917266E-05
     +,   1.5516052E-05,   1.7223361E-05,   1.9035619E-05
     +,   2.0947336E-05,   2.2951526E-05,   2.5039215E-05
     +,   2.7200058E-05,   2.9421934E-05,   3.1691765E-05
     +,   3.3995238E-05,   3.6317739E-05,   3.8644263E-05
     +,   4.0960429E-05,   4.3252829E-05,   4.5509496E-05
     +,   4.7720685E-05,   4.9879676E-05,   5.1983159E-05
     +,   5.4031618E-05,   5.6030211E-05,   5.7988553E-05
     +,   5.9921342E-05,   6.1847844E-05,   6.3792031E-05
     +,   6.5781620E-05,   6.7847781E-05,   7.0023583E-05
     +,   7.2343275E-05,   7.4840631E-05,   7.7547309E-05
     +,   8.0491285E-05,   8.3695595E-05,   8.7176762E-05
     +,   9.0943133E-05,   9.4994939E-05,   9.9322868E-05
     +,   1.0390919E-04,   1.0872726E-04,   1.1374388E-04
     +,   1.1891988E-04,   1.2421343E-04,   1.2958137E-04
     +,   1.3498298E-04,   1.4038233E-04,   1.4575018E-04
     +,   1.5106676E-04,   1.5632340E-04,   1.6152301E-04
     +,   1.6667983E-04,   1.7181867E-04,   1.7697357E-04
     +,   1.8218481E-04,   1.8749533E-04,   1.9294796E-04
     +,   1.9858102E-04,   2.0442420E-04,   2.1049508E-04
     +,   2.1679664E-04,   2.2331400E-04,   2.3001243E-04
     +,   2.3683652E-04,   2.4371083E-04,   2.5054009E-04
     +,   2.5721031E-04,   2.6359179E-04,   2.6954280E-04
     +,   2.7491304E-04,   2.7954782E-04,   2.8329459E-04
     +,   2.8600846E-04,   2.8755868E-04,   2.8783584E-04
     +,   2.8675917E-04,   2.8428331E-04,   2.8040507E-04
     +,   2.7516845E-04,   2.6866826E-04,   2.6105111E-04
     +,   2.5251505E-04,   2.4330491E-04,   2.3370354E-04
     +,   2.2402254E-04,   2.1458977E-04,   2.0573229E-04
     +,   1.9776123E-04,   1.9095637E-04,   1.8555000E-04
     +,   1.8171380E-04,   1.7954977E-04,   1.7908418E-04
     +,   1.8026547E-04,   1.8296731E-04,   1.8699588E-04
     +,   1.9209989E-04,   1.9798448E-04,   2.0432728E-04
     +,   2.1079459E-04,   2.1705691E-04,   2.2280563E-04
     +,   2.2776543E-04,   2.3170463E-04,   2.3444332E-04
     +,   2.3585770E-04,   2.3588105E-04,   2.3450205E-04
     +,   2.3176071E-04,   2.2774190E-04,   2.2256769E-04
     +,   2.1638897E-04,   2.0937689E-04,   2.0171324E-04
     +,   1.9358283E-04,   1.8516726E-04,   1.7663700E-04
     +,   1.6814747E-04,   1.5983568E-04,   1.5181747E-04
     +,   1.4418557E-04,   1.3700985E-04,   1.3033835E-04
     +,   1.2419821E-04,   1.1859708E-04,   1.1352589E-04
     +,   1.0896191E-04,   1.0487087E-04,   1.0120965E-04
     +,   9.7929144E-05,   9.4977084E-05,   9.2299597E-05
     +,   8.9843394E-05,   8.7557630E-05,   8.5394800E-05
     +,   8.3311672E-05,   8.1269958E-05,   7.9236874E-05
     +,   7.7185025E-05,   7.5092255E-05,   7.2941621E-05
     +,   7.0721071E-05,   6.8423178E-05,   6.6044391E-05
     +,   6.3584870E-05,   6.1048238E-05,   5.8440804E-05
     +,   5.5771314E-05,   5.3050735E-05,   5.0291805E-05
     +,   4.7508358E-05,   4.4715202E-05,   4.1927935E-05
     +,   3.9162351E-05,   3.6433990E-05,   3.3757900E-05
     +,   3.1148600E-05,   2.8619541E-05,   2.6182734E-05
     +,   2.3848734E-05,   2.1626687E-05,   1.9523792E-05
     +,   1.7545470E-05,   1.5695496E-05,   1.3975879E-05
     +,   1.2386852E-05,   1.0927122E-05,   9.5940950E-06
     +,   8.3839323E-06,   7.2916678E-06,   6.3114917E-06
     +,   5.4369998E-06,   4.6612854E-06,   3.9770871E-06
     +,   3.3770048E-06,   2.8536933E-06,   2.3998693E-06
     +,   2.0084829E-06,   1.6728245E-06,   1.3865514E-06
     +,   1.1437260E-06,   9.3886933E-07,   7.6698751E-07
     +,   6.2355468E-07,   5.0450012E-07,   4.0620580E-07
     +,   3.2548829E-07,   2.5955165E-07,   2.0597683E-07
     +,   1.6267228E-07,   1.2785476E-07,   1.0000515E-07
     +,   7.7846281E-08,   6.0305545E-08,   4.6493177E-08
     +,   3.5671931E-08,   2.7238221E-08,   2.0698668E-08
     +,   1.5653626E-08,   1.1781623E-08,   8.8248271E-09
     +,   6.5785031E-09,   4.8804583E-09,   3.6034304E-09
     +,   2.6478089E-09,   1.9363366E-09,   1.4092622E-09
     +,   1.0207721E-09,   7.3584155E-10,   5.2792021E-10
     +,   3.7694015E-10,   2.6785901E-10
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_ww_mass = Yx/0.00514682666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_asha_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.7418957E-14,   1.0090168E-13
     +,   1.5039440E-13,   2.2324446E-13,   3.3002453E-13
     +,   4.8587935E-13,   7.1240540E-13,   1.0402616E-12
     +,   1.5127704E-12,   2.1909046E-12,   3.1600274E-12
     +,   4.5391677E-12,   6.4935102E-12,   9.2512586E-12
     +,   1.3126246E-11,   1.8548087E-11,   2.6102166E-11
     +,   3.6582504E-11,   5.1061065E-11,   7.0978397E-11
     +,   9.8261344E-11,   1.3547534E-10,   1.8601866E-10
     +,   2.5437724E-10,   3.4643199E-10,   4.6987475E-10
     +,   6.3470162E-10,   8.5384666E-10,   1.1439690E-09
     +,   1.5264171E-09,   2.0284181E-09,   2.6845228E-09
     +,   3.5383687E-09,   4.6447917E-09,   6.0723537E-09
     +,   7.9063645E-09,   1.0252397E-08,   1.3240450E-08
     +,   1.7029997E-08,   2.1814975E-08,   2.7831064E-08
     +,   3.5362156E-08,   4.4748948E-08,   5.6397909E-08
     +,   7.0791437E-08,   8.8498687E-08,   1.1018765E-07
     +,   1.3663767E-07,   1.6875265E-07,   2.0757507E-07
     +,   2.5429952E-07,   3.1028682E-07,   3.7707645E-07
     +,   4.5640365E-07,   5.5019871E-07,   6.6061216E-07
     +,   7.9000671E-07,   9.4096794E-07,   1.1163005E-06
     +,   1.3190216E-06,   1.5523513E-06,   1.8196988E-06
     +,   2.1246135E-06,   2.4707949E-06,   2.8620359E-06
     +,   3.3021333E-06,   3.7949237E-06,   4.3441046E-06
     +,   4.9532969E-06,   5.6258204E-06,   6.3647799E-06
     +,   7.1727900E-06,   8.0520958E-06,   9.0042613E-06
     +,   1.0030290E-05,   1.1130453E-05,   1.2304155E-05
     +,   1.3549910E-05,   1.4865385E-05,   1.6247297E-05
     +,   1.7691233E-05,   1.9191984E-05,   2.0743182E-05
     +,   2.2337721E-05,   2.3967466E-05,   2.5623678E-05
     +,   2.7296792E-05,   2.8976929E-05,   3.0653642E-05
     +,   3.2316486E-05,   3.3955024E-05,   3.5558991E-05
     +,   3.7118549E-05,   3.8624701E-05,   4.0069397E-05
     +,   4.1445615E-05,   4.2747964E-05,   4.3972548E-05
     +,   4.5117555E-05,   4.6183104E-05,   4.7171794E-05
     +,   4.8088619E-05,   4.8941332E-05,   4.9740356E-05
     +,   5.0499111E-05,   5.1233888E-05,   5.1963842E-05
     +,   5.2710922E-05,   5.3499723E-05,   5.4357151E-05
     +,   5.5311913E-05,   5.6394154E-05,   5.7634479E-05
     +,   5.9063321E-05,   6.0709681E-05,   6.2600186E-05
     +,   6.4757398E-05,   6.7198918E-05,   6.9935450E-05
     +,   7.2969866E-05,   7.6295961E-05,   7.9897261E-05
     +,   8.3746607E-05,   8.7806548E-05,   9.2029790E-05
     +,   9.6360141E-05,   1.0073574E-04,   1.0509097E-04
     +,   1.0936145E-04,   1.1348716E-04,   1.1741834E-04
     +,   1.2111898E-04,   1.2457192E-04,   1.2778102E-04
     +,   1.3077367E-04,   1.3359991E-04,   1.3633043E-04
     +,   1.3905259E-04,   1.4186531E-04,   1.4487340E-04
     +,   1.4818263E-04,   1.5189742E-04,   1.5612187E-04
     +,   1.6096428E-04,   1.6654449E-04,   1.7300430E-04
     +,   1.8051465E-04,   1.8927718E-04,   1.9951681E-04
     +,   2.1146226E-04,   2.2531471E-04,   2.4121035E-04
     +,   2.5919368E-04,   2.7921936E-04,   3.0120392E-04
     +,   3.2514648E-04,   3.5132418E-04,   3.8052371E-04
     +,   4.1421872E-04,   4.5456190E-04,   5.0407840E-04
     +,   5.6503201E-04,   6.3868280E-04,   7.2489271E-04
     +,   8.2254369E-04,   9.3080633E-04,   1.0505407E-03
     +,   1.1844819E-03,   1.3351326E-03,   1.5008409E-03
     +,   1.6726427E-03,   1.8351481E-03,   1.9726809E-03
     +,   2.0779513E-03,   2.1578134E-03,   2.2314845E-03
     +,   2.3208747E-03,   2.4375075E-03,   2.5728839E-03
     +,   2.6979165E-03,   2.7728821E-03,   2.7638476E-03
     +,   2.6574822E-03,   2.4663636E-03,   2.2224118E-03
     +,   1.9629521E-03,   1.7175904E-03,   1.5021104E-03
     +,   1.3201038E-03,   1.1685314E-03,   1.0426729E-03
     +,   9.3844533E-04,   8.5251866E-04,   7.8174949E-04
     +,   7.2295731E-04,   6.7311415E-04,   6.2960584E-04
     +,   5.9034512E-04,   5.5377564E-04,   5.1886833E-04
     +,   4.8512567E-04,   4.5253336E-04,   4.2141741E-04
     +,   3.9222761E-04,   3.6532051E-04,   3.4080734E-04
     +,   3.1852152E-04,   2.9807957E-04,   2.7899194E-04
     +,   2.6077879E-04,   2.4305811E-04,   2.2559079E-04
     +,   2.0828340E-04,   1.9116416E-04,   1.7434702E-04
     +,   1.5799415E-04,   1.4228145E-04,   1.2737191E-04
     +,   1.1340054E-04,   1.0046680E-04,   8.8629116E-05
     +,   7.7908073E-05,   6.8291403E-05,   5.9739243E-05
     +,   5.2190222E-05,   4.5568930E-05,   3.9792070E-05
     +,   3.4773042E-05,   3.0425630E-05,   2.6667376E-05
     +,   2.3421670E-05,   2.0618536E-05,   1.8194994E-05
     +,   1.6095355E-05,   1.4271090E-05,   1.2680021E-05
     +,   1.1286037E-05,   1.0058598E-05,   8.9720725E-06
     +,   8.0051022E-06,   7.1401578E-06,   6.3630405E-06
     +,   5.6622980E-06,   5.0287217E-06,   4.4549474E-06
     +,   3.9351021E-06,   3.4644063E-06,   3.0388667E-06
     +,   2.6550751E-06,   2.3100583E-06,   2.0010648E-06
     +,   1.7255135E-06,   1.4809472E-06,   1.2649751E-06
     +,   1.0752458E-06,   9.0946622E-07,   7.6541977E-07
     +,   6.4096338E-07,   5.3403841E-07,   4.4269618E-07
     +,   3.6511415E-07,   2.9959827E-07,   2.4458581E-07
     +,   1.9865458E-07,   1.6052616E-07,   1.2905306E-07
     +,   1.0321964E-07,   8.2135379E-08,   6.5024125E-08
     +,   5.1214393E-08,   4.0130942E-08,   3.1285182E-08
     +,   2.4264686E-08,   1.8723352E-08,   1.4373447E-08
     +,   1.0977780E-08,   8.3413596E-09,   6.3057355E-09
     +,   4.7424531E-09,   3.5485137E-09,   2.6415521E-09
     +,   1.9563553E-09,   1.4414671E-09,   1.0566686E-09
     +,   7.7062046E-10,   5.5913896E-10,   4.0361819E-10
     +,   2.8986119E-10,   2.0710313E-10,   1.4721455E-10
     +,   1.0410999E-10,   7.3248997E-11,   5.1272861E-11
     +,   3.5706060E-11,   2.4738480E-11,   1.7051870E-11
     +,   1.1693602E-11,   7.9779638E-12,   5.4151909E-12
     +,   3.6568058E-12,   2.4567943E-12
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_asha_zz_mass = Yx/0.017332875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.2142251E-06,   2.4644187E-06
     +,   2.7363928E-06,   3.0311951E-06,   3.3498125E-06
     +,   3.6931654E-06,   4.0620789E-06,   4.4572753E-06
     +,   4.8793454E-06,   5.3287604E-06,   5.8058090E-06
     +,   6.3106118E-06,   6.8430945E-06,   7.4029763E-06
     +,   7.9897536E-06,   8.6026857E-06,   9.2407927E-06
     +,   9.9028339E-06,   1.0587321E-05,   1.1292499E-05
     +,   1.2016370E-05,   1.2756676E-05,   1.3510919E-05
     +,   1.4276428E-05,   1.5050246E-05,   1.5829331E-05
     +,   1.6610460E-05,   1.7390312E-05,   1.8165512E-05
     +,   1.8932689E-05,   1.9688508E-05,   2.0429756E-05
     +,   2.1153397E-05,   2.1856640E-05,   2.2537037E-05
     +,   2.3192539E-05,   2.3821594E-05,   2.4423216E-05
     +,   2.4997142E-05,   2.5543779E-05,   2.6064445E-05
     +,   2.6561363E-05,   2.7037730E-05,   2.7497836E-05
     +,   2.7947090E-05,   2.8392053E-05,   2.8840515E-05
     +,   2.9301440E-05,   2.9785000E-05,   3.0302515E-05
     +,   3.0866413E-05,   3.1490086E-05,   3.2187807E-05
     +,   3.2974553E-05,   3.3865756E-05,   3.4877157E-05
     +,   3.6024434E-05,   3.7322952E-05,   3.8787381E-05
     +,   4.0431361E-05,   4.2267060E-05,   4.4304830E-05
     +,   4.6552617E-05,   4.9015820E-05,   5.1696814E-05
     +,   5.4594217E-05,   5.7703252E-05,   6.1014711E-05
     +,   6.4515589E-05,   6.8188121E-05,   7.2010698E-05
     +,   7.5956996E-05,   7.9997328E-05,   8.4097861E-05
     +,   8.8222158E-05,   9.2331305E-05,   9.6384480E-05
     +,   1.0034008E-04,   1.0415685E-04,   1.0779468E-04
     +,   1.1121527E-04,   1.1438397E-04,   1.1726988E-04
     +,   1.1984758E-04,   1.2209723E-04,   1.2400580E-04
     +,   1.2556705E-04,   1.2678224E-04,   1.2765970E-04
     +,   1.2821515E-04,   1.2847080E-04,   1.2845494E-04
     +,   1.2820103E-04,   1.2774656E-04,   1.2713191E-04
     +,   1.2639895E-04,   1.2558980E-04,   1.2474529E-04
     +,   1.2390372E-04,   1.2309961E-04,   1.2236249E-04
     +,   1.2171629E-04,   1.2117832E-04,   1.2075908E-04
     +,   1.2046195E-04,   1.2028336E-04,   1.2021312E-04
     +,   1.2023500E-04,   1.2032746E-04,   1.2046471E-04
     +,   1.2061768E-04,   1.2075528E-04,   1.2084548E-04
     +,   1.2085658E-04,   1.2075833E-04,   1.2052281E-04
     +,   1.2012543E-04,   1.1954561E-04,   1.1876732E-04
     +,   1.1777942E-04,   1.1657577E-04,   1.1515534E-04
     +,   1.1352204E-04,   1.1168420E-04,   1.0965418E-04
     +,   1.0744812E-04,   1.0508482E-04,   1.0258563E-04
     +,   9.9973251E-05,   9.7271637E-05,   9.4504729E-05
     +,   9.1696595E-05,   8.8870169E-05,   8.6047548E-05
     +,   8.3248968E-05,   8.0492799E-05,   7.7795492E-05
     +,   7.5171287E-05,   7.2631876E-05,   7.0186703E-05
     +,   6.7843044E-05,   6.5605993E-05,   6.3478372E-05
     +,   6.1461149E-05,   5.9553709E-05,   5.7753703E-05
     +,   5.6057448E-05,   5.4460288E-05,   5.2956584E-05
     +,   5.1539984E-05,   5.0203602E-05,   4.8940397E-05
     +,   4.7743204E-05,   4.6604866E-05,   4.5518482E-05
     +,   4.4477572E-05,   4.3476146E-05,   4.2508756E-05
     +,   4.1570587E-05,   4.0657644E-05,   3.9766568E-05
     +,   3.8894759E-05,   3.8040394E-05,   3.7202364E-05
     +,   3.6380145E-05,   3.5573794E-05,   3.4783963E-05
     +,   3.4011719E-05,   3.3258399E-05,   3.2525611E-05
     +,   3.1815158E-05,   3.1128897E-05,   3.0468622E-05
     +,   2.9836010E-05,   2.9232637E-05,   2.8659766E-05
     +,   2.8118373E-05,   2.7609138E-05,   2.7132386E-05
     +,   2.6688007E-05,   2.6275537E-05,   2.5894142E-05
     +,   2.5542622E-05,   2.5219408E-05,   2.4922627E-05
     +,   2.4650126E-05,   2.4399524E-05,   2.4168214E-05
     +,   2.3953449E-05,   2.3752389E-05,   2.3562105E-05
     +,   2.3379671E-05,   2.3202174E-05,   2.3026792E-05
     +,   2.2850771E-05,   2.2671504E-05,   2.2486556E-05
     +,   2.2293681E-05,   2.2090828E-05,   2.1876171E-05
     +,   2.1648128E-05,   2.1405362E-05,   2.1146772E-05
     +,   2.0871503E-05,   2.0578958E-05,   2.0268764E-05
     +,   1.9940766E-05,   1.9595054E-05,   1.9231920E-05
     +,   1.8851822E-05,   1.8455405E-05,   1.8043474E-05
     +,   1.7617002E-05,   1.7177046E-05,   1.6724771E-05
     +,   1.6261460E-05,   1.5788473E-05,   1.5307192E-05
     +,   1.4819042E-05,   1.4325515E-05,   1.3828070E-05
     +,   1.3328160E-05,   1.2827251E-05,   1.2326794E-05
     +,   1.1828152E-05,   1.1332651E-05,   1.0841593E-05
     +,   1.0356212E-05,   9.8776391E-06,   9.4069383E-06
     +,   8.9451178E-06,   8.4931080E-06,   8.0517202E-06
     +,   7.6216838E-06,   7.2036819E-06,   6.7982701E-06
     +,   6.4059195E-06,   6.0270418E-06,   5.6619674E-06
     +,   5.3109211E-06,   4.9740561E-06,   4.6514747E-06
     +,   4.3432078E-06,   4.0492027E-06,   3.7693483E-06
     +,   3.5034984E-06,   3.2514527E-06,   3.0129488E-06
     +,   2.7876845E-06,   2.5753445E-06,   2.3755592E-06
     +,   2.1879323E-06,   2.0120578E-06,   1.8475110E-06
     +,   1.6938394E-06,   1.5505823E-06,   1.4172812E-06
     +,   1.2934728E-06,   1.1786829E-06,   1.0724426E-06
     +,   9.7429347E-07,   8.8378289E-07,   8.0046050E-07
     +,   7.2388815E-07,   6.5364685E-07,   5.8932295E-07
     +,   5.3051895E-07,   4.7685552E-07,   4.2796975E-07
     +,   3.8351109E-07,   3.4314678E-07,   3.0656332E-07
     +,   2.7346462E-07,   2.4356814E-07,   2.1660919E-07
     +,   1.9234166E-07,   1.7053245E-07,   1.5096657E-07
     +,   1.3344173E-07,   1.1777225E-07,   1.0378409E-07
     +,   9.1318633E-08,   8.0227728E-08,   7.0376920E-08
     +,   6.1641430E-08,   5.3908291E-08,   4.7073602E-08
     +,   4.1042686E-08,   3.5730125E-08,   3.1057766E-08
     +,   2.6955428E-08,   2.3359259E-08,   2.0212148E-08
     +,   1.7462348E-08,   1.5063746E-08,   1.2974786E-08
     +,   1.1158568E-08,   9.5819273E-09,   8.2155767E-09
     +,   7.0333139E-09,   6.0120464E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_eez_mass = Yx/0.0028389375
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.4273802E-05,   3.5291923E-05
     +,   3.6308582E-05,   3.7322032E-05,   3.8330501E-05
     +,   3.9332201E-05,   4.0325333E-05,   4.1308089E-05
     +,   4.2278669E-05,   4.3235301E-05,   4.4176220E-05
     +,   4.5099681E-05,   4.6003988E-05,   4.6887493E-05
     +,   4.7748588E-05,   4.8585745E-05,   4.9397499E-05
     +,   5.0182472E-05,   5.0939369E-05,   5.1666975E-05
     +,   5.2364201E-05,   5.3030064E-05,   5.3663680E-05
     +,   5.4264321E-05,   5.4831333E-05,   5.5364253E-05
     +,   5.5862722E-05,   5.6326546E-05,   5.6755631E-05
     +,   5.7150075E-05,   5.7510097E-05,   5.7836096E-05
     +,   5.8128575E-05,   5.8388217E-05,   5.8615838E-05
     +,   5.8812409E-05,   5.8979029E-05,   5.9116923E-05
     +,   5.9227463E-05,   5.9312133E-05,   5.9372553E-05
     +,   5.9410424E-05,   5.9427552E-05,   5.9425853E-05
     +,   5.9407314E-05,   5.9373979E-05,   5.9327966E-05
     +,   5.9271420E-05,   5.9206537E-05,   5.9135549E-05
     +,   5.9060651E-05,   5.8984075E-05,   5.8908015E-05
     +,   5.8834634E-05,   5.8766062E-05,   5.8704351E-05
     +,   5.8651491E-05,   5.8609392E-05,   5.8579859E-05
     +,   5.8564587E-05,   5.8565143E-05,   5.8582969E-05
     +,   5.8619378E-05,   5.8675494E-05,   5.8752310E-05
     +,   5.8850641E-05,   5.8971113E-05,   5.9114180E-05
     +,   5.9280123E-05,   5.9468988E-05,   5.9680689E-05
     +,   5.9914892E-05,   6.0171096E-05,   6.0448587E-05
     +,   6.0746483E-05,   6.1063729E-05,   6.1399041E-05
     +,   6.1750972E-05,   6.2117942E-05,   6.2498184E-05
     +,   6.2889791E-05,   6.3290710E-05,   6.3698746E-05
     +,   6.4111657E-05,   6.4527005E-05,   6.4942353E-05
     +,   6.5355125E-05,   6.5762753E-05,   6.6162582E-05
     +,   6.6551955E-05,   6.6928231E-05,   6.7288747E-05
     +,   6.7630863E-05,   6.7952024E-05,   6.8249727E-05
     +,   6.8521527E-05,   6.8765097E-05,   6.8978210E-05
     +,   6.9158756E-05,   6.9304791E-05,   6.9414513E-05
     +,   6.9486276E-05,   6.9518632E-05,   6.9510279E-05
     +,   6.9460162E-05,   6.9367401E-05,   6.9231333E-05
     +,   6.9051523E-05,   6.8827736E-05,   6.8559966E-05
     +,   6.8248431E-05,   6.7893590E-05,   6.7496105E-05
     +,   6.7056848E-05,   6.6576948E-05,   6.6057684E-05
     +,   6.5500601E-05,   6.4907370E-05,   6.4279942E-05
     +,   6.3620348E-05,   6.2930812E-05,   6.2213723E-05
     +,   6.1471655E-05,   6.0707232E-05,   5.9923179E-05
     +,   5.9122423E-05,   5.8307851E-05,   5.7482532E-05
     +,   5.6649467E-05,   5.5811797E-05,   5.4972592E-05
     +,   5.4135009E-05,   5.3302116E-05,   5.2477018E-05
     +,   5.1662748E-05,   5.0862232E-05,   5.0078401E-05
     +,   4.9314087E-05,   4.8571990E-05,   4.7854679E-05
     +,   4.7164660E-05,   4.6504294E-05,   4.5875768E-05
     +,   4.5281096E-05,   4.4722208E-05,   4.4200795E-05
     +,   4.3718377E-05,   4.3276337E-05,   4.2875858E-05
     +,   4.2517910E-05,   4.2203268E-05,   4.1932548E-05
     +,   4.1706167E-05,   4.1524316E-05,   4.1387022E-05
     +,   4.1294115E-05,   4.1245243E-05,   4.1239851E-05
     +,   4.1277217E-05,   4.1356452E-05,   4.1476487E-05
     +,   4.1636096E-05,   4.1833897E-05,   4.2068343E-05
     +,   4.2337757E-05,   4.2640368E-05,   4.2974225E-05
     +,   4.3337270E-05,   4.3727374E-05,   4.4142314E-05
     +,   4.4579738E-05,   4.5037239E-05,   4.5512359E-05
     +,   4.6002602E-05,   4.6505364E-05,   4.7018068E-05
     +,   4.7538109E-05,   4.8062841E-05,   4.8589602E-05
     +,   4.9115792E-05,   4.9638802E-05,   5.0156039E-05
     +,   5.0664938E-05,   5.1163002E-05,   5.1647803E-05
     +,   5.2116939E-05,   5.2568077E-05,   5.2998988E-05
     +,   5.3407530E-05,   5.3791609E-05,   5.4149292E-05
     +,   5.4478711E-05,   5.4778113E-05,   5.5045861E-05
     +,   5.5280430E-05,   5.5480457E-05,   5.5644658E-05
     +,   5.5771881E-05,   5.5861150E-05,   5.5911587E-05
     +,   5.5922446E-05,   5.5893124E-05,   5.5823170E-05
     +,   5.5712248E-05,   5.5560173E-05,   5.5366880E-05
     +,   5.5132419E-05,   5.4857006E-05,   5.4540978E-05
     +,   5.4184777E-05,   5.3788954E-05,   5.3354193E-05
     +,   5.2881311E-05,   5.2371201E-05,   5.1824831E-05
     +,   5.1243325E-05,   5.0627877E-05,   4.9979746E-05
     +,   4.9300252E-05,   4.8590860E-05,   4.7853016E-05
     +,   4.7088244E-05,   4.6298162E-05,   4.5484419E-05
     +,   4.4648670E-05,   4.3792588E-05,   4.2917931E-05
     +,   4.2026470E-05,   4.1119936E-05,   4.0200051E-05
     +,   3.9268609E-05,   3.8327398E-05,   3.7378100E-05
     +,   3.6422436E-05,   3.5462137E-05,   3.4498840E-05
     +,   3.3534150E-05,   3.2569675E-05,   3.1607000E-05
     +,   3.0647581E-05,   2.9692843E-05,   2.8744213E-05
     +,   2.7803038E-05,   2.6870573E-05,   2.5948000E-05
     +,   2.5036496E-05,   2.4137165E-05,   2.3250999E-05
     +,   2.2378907E-05,   2.1521832E-05,   2.0680547E-05
     +,   1.9855766E-05,   1.9048190E-05,   1.8258441E-05
     +,   1.7487029E-05,   1.6734399E-05,   1.6000975E-05
     +,   1.5287118E-05,   1.4593087E-05,   1.3919072E-05
     +,   1.3265256E-05,   1.2631763E-05,   1.2018614E-05
     +,   1.1425795E-05,   1.0853289E-05,   1.0300977E-05
     +,   9.7687052E-06,   9.2563050E-06,   8.7635781E-06
     +,   8.2902443E-06,   7.8360035E-06,   7.4005502E-06
     +,   6.9835519E-06,   6.5846230E-06,   6.2033587E-06
     +,   5.8393662E-06,   5.4921943E-06,   5.1614184E-06
     +,   4.8465590E-06,   4.5471679E-06,   4.2627503E-06
     +,   3.9928382E-06,   3.7369284E-06,   3.4945474E-06
     +,   3.2651878E-06,   3.0483761E-06,   2.8436175E-06
     +,   2.6504208E-06,   2.4683218E-06,   2.2968345E-06
     +,   2.1355065E-06,   1.9838692E-06,   1.8414861E-06
     +,   1.7079105E-06,   1.5827229E-06,   1.4654995E-06
     +,   1.3558440E-06,   1.2533568E-06,   1.1576653E-06
     +,   1.0683964E-06,   9.8520138E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_qq_mass = Yx/0.00332535
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.8949834E-06,   4.0540240E-06
     +,   4.2163015E-06,   4.3816913E-06,   4.5500592E-06
     +,   4.7212593E-06,   4.8951347E-06,   5.0715184E-06
     +,   5.2502292E-06,   5.4310854E-06,   5.6138883E-06
     +,   5.7984321E-06,   5.9845052E-06,   6.1718906E-06
     +,   6.3603602E-06,   6.5496879E-06,   6.7396445E-06
     +,   6.9299977E-06,   7.1205163E-06,   7.3109732E-06
     +,   7.5011471E-06,   7.6908218E-06,   7.8797921E-06
     +,   8.0678728E-06,   8.2548786E-06,   8.4406638E-06
     +,   8.6250930E-06,   8.8080569E-06,   8.9894829E-06
     +,   9.1693319E-06,   9.3476010E-06,   9.5243331E-06
     +,   9.6996200E-06,   9.8736064E-06,   1.0046494E-05
     +,   1.0218549E-05,   1.0390105E-05,   1.0561560E-05
     +,   1.0733412E-05,   1.0906211E-05,   1.1080618E-05
     +,   1.1257369E-05,   1.1437296E-05,   1.1621327E-05
     +,   1.1810492E-05,   1.2005911E-05,   1.2208814E-05
     +,   1.2420521E-05,   1.2642451E-05,   1.2876123E-05
     +,   1.3123137E-05,   1.3385185E-05,   1.3664026E-05
     +,   1.3961517E-05,   1.4279532E-05,   1.4620034E-05
     +,   1.4985001E-05,   1.5376441E-05,   1.5796368E-05
     +,   1.6246790E-05,   1.6729689E-05,   1.7247017E-05
     +,   1.7800632E-05,   1.8392353E-05,   1.9023912E-05
     +,   1.9696863E-05,   2.0412726E-05,   2.1172775E-05
     +,   2.1978243E-05,   2.2830080E-05,   2.3729175E-05
     +,   2.4676128E-05,   2.5671479E-05,   2.6715461E-05
     +,   2.7808246E-05,   2.8949842E-05,   3.0140051E-05
     +,   3.1378549E-05,   3.2664979E-05,   3.3998953E-05
     +,   3.5379893E-05,   3.6807418E-05,   3.8281007E-05
     +,   3.9800398E-05,   4.1365296E-05,   4.2975760E-05
     +,   4.4631866E-05,   4.6334160E-05,   4.8083264E-05
     +,   4.9880284E-05,   5.1726707E-05,   5.3624226E-05
     +,   5.5574921E-05,   5.7581346E-05,   5.9646416E-05
     +,   6.1773135E-05,   6.3965032E-05,   6.6225562E-05
     +,   6.8558533E-05,   7.0967515E-05,   7.3456235E-05
     +,   7.6027885E-05,   7.8685618E-05,   8.1431703E-05
     +,   8.4267987E-05,   8.7195505E-05,   9.0214082E-05
     +,   9.3322378E-05,   9.6517950E-05,   9.9796918E-05
     +,   1.0315353E-04,   1.0658082E-04,   1.1006968E-04
     +,   1.1360968E-04,   1.1718817E-04,   1.2079128E-04
     +,   1.2440307E-04,   1.2800645E-04,   1.3158259E-04
     +,   1.3511178E-04,   1.3857345E-04,   1.4194599E-04
     +,   1.4520749E-04,   1.4833618E-04,   1.5131048E-04
     +,   1.5410903E-04,   1.5671189E-04,   1.5909983E-04
     +,   1.6125551E-04,   1.6316315E-04,   1.6480917E-04
     +,   1.6618209E-04,   1.6727290E-04,   1.6807519E-04
     +,   1.6858497E-04,   1.6880107E-04,   1.6872461E-04
     +,   1.6835940E-04,   1.6771149E-04,   1.6678909E-04
     +,   1.6560235E-04,   1.6416320E-04,   1.6248494E-04
     +,   1.6058204E-04,   1.5846995E-04,   1.5616471E-04
     +,   1.5368257E-04,   1.5104013E-04,   1.4825397E-04
     +,   1.4534012E-04,   1.4231430E-04,   1.3919183E-04
     +,   1.3598752E-04,   1.3271533E-04,   1.2938857E-04
     +,   1.2602028E-04,   1.2262292E-04,   1.1920841E-04
     +,   1.1578829E-04,   1.1237432E-04,   1.0897787E-04
     +,   1.0561034E-04,   1.0228363E-04,   9.9009892E-05
     +,   9.5801450E-05,   9.2671085E-05,   8.9632216E-05
     +,   8.6698798E-05,   8.3885003E-05,   8.1205340E-05
     +,   7.8674915E-05,   7.6308846E-05,   7.4122203E-05
     +,   7.2129827E-05,   7.0346461E-05,   6.8786067E-05
     +,   6.7461799E-05,   6.6385954E-05,   6.5569482E-05
     +,   6.5021835E-05,   6.4750820E-05,   6.4762338E-05
     +,   6.5060267E-05,   6.5646185E-05,   6.6519438E-05
     +,   6.7676803E-05,   6.9112539E-05,   7.0818416E-05
     +,   7.2783740E-05,   7.4995027E-05,   7.7436591E-05
     +,   8.0090424E-05,   8.2936167E-05,   8.5951440E-05
     +,   8.9112196E-05,   9.2392875E-05,   9.5766380E-05
     +,   9.9204539E-05,   1.0267864E-04,   1.0615961E-04
     +,   1.0961792E-04,   1.1302428E-04,   1.1635015E-04
     +,   1.1956774E-04,   1.2265010E-04,   1.2557194E-04
     +,   1.2830971E-04,   1.3084148E-04,   1.3314749E-04
     +,   1.3521040E-04,   1.3701539E-04,   1.3854998E-04
     +,   1.3980446E-04,   1.4077182E-04,   1.4144789E-04
     +,   1.4183097E-04,   1.4192208E-04,   1.4172486E-04
     +,   1.4124530E-04,   1.4049171E-04,   1.3947448E-04
     +,   1.3820588E-04,   1.3669999E-04,   1.3497239E-04
     +,   1.3303981E-04,   1.3092000E-04,   1.2863157E-04
     +,   1.2619379E-04,   1.2362607E-04,   1.2094787E-04
     +,   1.1817870E-04,   1.1533786E-04,   1.1244389E-04
     +,   1.0951468E-04,   1.0656766E-04,   1.0361903E-04
     +,   1.0068389E-04,   9.7776494E-05,   9.4909876E-05
     +,   9.2095630E-05,   8.9344081E-05,   8.6664426E-05
     +,   8.4064646E-05,   8.1551210E-05,   7.9129371E-05
     +,   7.6803357E-05,   7.4576215E-05,   7.2449780E-05
     +,   7.0424867E-05,   6.8501533E-05,   6.6678760E-05
     +,   6.4954766E-05,   6.3327192E-05,   6.1792991E-05
     +,   6.0348528E-05,   5.8989692E-05,   5.7712095E-05
     +,   5.6511039E-05,   5.5381508E-05,   5.4318352E-05
     +,   5.3316380E-05,   5.2370422E-05,   5.1475192E-05
     +,   5.0625556E-05,   4.9816532E-05,   4.9043250E-05
     +,   4.8301037E-05,   4.7585490E-05,   4.6892452E-05
     +,   4.6217992E-05,   4.5558470E-05,   4.4910561E-05
     +,   4.4271277E-05,   4.3637836E-05,   4.3007803E-05
     +,   4.2379073E-05,   4.1749747E-05,   4.1118270E-05
     +,   4.0483283E-05,   3.9843781E-05,   3.9198847E-05
     +,   3.8547914E-05,   3.7890521E-05,   3.7226459E-05
     +,   3.6555619E-05,   3.5878118E-05,   3.5194138E-05
     +,   3.4503984E-05,   3.3808115E-05,   3.3106993E-05
     +,   3.2401251E-05,   3.1691481E-05,   3.0978415E-05
     +,   3.0262730E-05,   2.9545228E-05,   2.8826635E-05
     +,   2.8107772E-05,   2.7389386E-05,   2.6672302E-05
     +,   2.5957248E-05,   2.5245041E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_ww_mass = Yx/0.00514682666666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_ashz_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.5849063E-07,   5.0571333E-07
     +,   5.5707648E-07,   6.1286136E-07,   6.7335941E-07
     +,   7.3887276E-07,   8.0971290E-07,   8.8620072E-07
     +,   9.6866381E-07,   1.0574420E-06,   1.1528784E-06
     +,   1.2553235E-06,   1.3651318E-06,   1.4826643E-06
     +,   1.6082843E-06,   1.7423575E-06,   1.8852515E-06
     +,   2.0373350E-06,   2.1989765E-06,   2.3705427E-06
     +,   2.5524000E-06,   2.7449125E-06,   2.9484397E-06
     +,   3.1633504E-06,   3.3899894E-06,   3.6287222E-06
     +,   3.8799003E-06,   4.1438775E-06,   4.4210092E-06
     +,   4.7116523E-06,   5.0161689E-06,   5.3349263E-06
     +,   5.6683002E-06,   6.0166781E-06,   6.3804623E-06
     +,   6.7600704E-06,   7.1559407E-06,   7.5685289E-06
     +,   7.9983447E-06,   8.4458770E-06,   8.9117002E-06
     +,   9.3963945E-06,   9.9005811E-06,   1.0424925E-05
     +,   1.0970126E-05,   1.1536935E-05,   1.2126126E-05
     +,   1.2738526E-05,   1.3374986E-05,   1.4036393E-05
     +,   1.4723657E-05,   1.5437703E-05,   1.6179454E-05
     +,   1.6949878E-05,   1.7749848E-05,   1.8580289E-05
     +,   1.9442035E-05,   2.0335870E-05,   2.1262504E-05
     +,   2.2222546E-05,   2.3216484E-05,   2.4244686E-05
     +,   2.5307290E-05,   2.6404334E-05,   2.7535643E-05
     +,   2.8700721E-05,   2.9898949E-05,   3.1129293E-05
     +,   3.2390599E-05,   3.3681223E-05,   3.4999379E-05
     +,   3.6342775E-05,   3.7708945E-05,   3.9094899E-05
     +,   4.0497434E-05,   4.1912994E-05,   4.3337579E-05
     +,   4.4766864E-05,   4.6196285E-05,   4.7620979E-05
     +,   4.9035665E-05,   5.0434985E-05,   5.1813164E-05
     +,   5.3164425E-05,   5.4482673E-05,   5.5761866E-05
     +,   5.6995726E-05,   5.8178142E-05,   5.9302889E-05
     +,   6.0363924E-05,   6.1355444E-05,   6.2271713E-05
     +,   6.3107393E-05,   6.3857551E-05,   6.4517764E-05
     +,   6.5084088E-05,   6.5553402E-05,   6.5923326E-05
     +,   6.6192501E-05,   6.6360713E-05,   6.6429115E-05
     +,   6.6400455E-05,   6.6279295E-05,   6.6072418E-05
     +,   6.5789092E-05,   6.5441491E-05,   6.5045133E-05
     +,   6.4619395E-05,   6.4187938E-05,   6.3779240E-05
     +,   6.3427186E-05,   6.3171399E-05,   6.3057734E-05
     +,   6.3138483E-05,   6.3472420E-05,   6.4124688E-05
     +,   6.5166198E-05,   6.6672888E-05,   6.8724192E-05
     +,   7.1401599E-05,   7.4786294E-05,   7.8956356E-05
     +,   8.3984029E-05,   8.9932953E-05,   9.6855219E-05
     +,   1.0478814E-04,   1.1375421E-04,   1.2375858E-04
     +,   1.3479216E-04,   1.4683191E-04,   1.5984775E-04
     +,   1.7380541E-04,   1.8867690E-04,   2.0444395E-04
     +,   2.2110835E-04,   2.3869495E-04,   2.5725242E-04
     +,   2.7685126E-04,   2.9757756E-04,   3.1951893E-04
     +,   3.4274498E-04,   3.6728775E-04,   3.9312080E-04
     +,   4.2013789E-04,   4.4813388E-04,   4.7680328E-04
     +,   5.0574023E-04,   5.3445349E-04,   5.6239654E-04
     +,   5.8901019E-04,   6.1376987E-04,   6.3623866E-04
     +,   6.5612042E-04,   6.7330297E-04,   6.8788510E-04
     +,   7.0017937E-04,   7.1069179E-04,   7.2007137E-04
     +,   7.2903285E-04,   7.3825987E-04,   7.4830139E-04
     +,   7.5947389E-04,   7.7178137E-04,   7.8488316E-04
     +,   7.9810538E-04,   8.1051566E-04,   8.2105142E-04
     +,   8.2869286E-04,   8.3265844E-04,   8.3258614E-04
     +,   8.2868128E-04,   8.2178327E-04,   8.1334397E-04
     +,   8.0530567E-04,   7.9989107E-04,   7.9932855E-04
     +,   8.0556032E-04,   8.1996550E-04,   8.4315136E-04
     +,   8.7483978E-04,   9.1385812E-04,   9.5823617E-04
     +,   1.0054021E-03,   1.0524361E-03,   1.0963549E-03
     +,   1.1343913E-03,   1.1642427E-03,   1.1842648E-03
     +,   1.1935760E-03,   1.1920810E-03,   1.1804092E-03
     +,   1.1597713E-03,   1.1317661E-03,   1.0981639E-03
     +,   1.0606926E-03,   1.0208739E-03,   9.7992062E-04
     +,   9.3869754E-04,   8.9774857E-04,   8.5737172E-04
     +,   8.1771490E-04,   7.7886332E-04,   7.4090110E-04
     +,   7.0394471E-04,   6.6815008E-04,   6.3368108E-04
     +,   6.0068187E-04,   5.6925067E-04,   5.3941936E-04
     +,   5.1115209E-04,   4.8436131E-04,   4.5893464E-04
     +,   4.3476064E-04,   4.1175337E-04,   3.8987078E-04
     +,   3.6912074E-04,   3.4955624E-04,   3.3125942E-04
     +,   3.1432509E-04,   2.9884189E-04,   2.8487088E-04
     +,   2.7243470E-04,   2.6151017E-04,   2.5202672E-04
     +,   2.4386990E-04,   2.3689114E-04,   2.3091873E-04
     +,   2.2576901E-04,   2.2125767E-04,   2.1720963E-04
     +,   2.1346693E-04,   2.0989327E-04,   2.0637632E-04
     +,   2.0282860E-04,   1.9918631E-04,   1.9540641E-04
     +,   1.9146383E-04,   1.8734805E-04,   1.8305962E-04
     +,   1.7860667E-04,   1.7400240E-04,   1.6926329E-04
     +,   1.6440710E-04,   1.5945130E-04,   1.5441286E-04
     +,   1.4930787E-04,   1.4415152E-04,   1.3895748E-04
     +,   1.3373874E-04,   1.2850808E-04,   1.2327764E-04
     +,   1.1805935E-04,   1.1286560E-04,   1.0770892E-04
     +,   1.0260167E-04,   9.7556469E-05,   9.2586262E-05
     +,   8.7703847E-05,   8.2921557E-05,   7.8251214E-05
     +,   7.3704352E-05,   6.9291680E-05,   6.5022614E-05
     +,   6.0905488E-05,   5.6947792E-05,   5.3155294E-05
     +,   4.9532413E-05,   4.6082416E-05,   4.2807165E-05
     +,   3.9706967E-05,   3.6780861E-05,   3.4026903E-05
     +,   3.1442039E-05,   2.9022034E-05,   2.6761849E-05
     +,   2.4655936E-05,   2.2697850E-05,   2.0880980E-05
     +,   1.9198093E-05,   1.7641993E-05,   1.6205135E-05
     +,   1.4880173E-05,   1.3659655E-05,   1.2536437E-05
     +,   1.1503441E-05,   1.0553998E-05,   9.6816475E-06
     +,   8.8802717E-06,   8.1441985E-06,   7.4680197E-06
     +,   6.8467989E-06,   6.2758868E-06,   5.7510779E-06
     +,   5.2684422E-06,   4.8244588E-06,   4.4158533E-06
     +,   4.0397090E-06,   3.6933261E-06,   3.3743029E-06
     +,   3.0804263E-06,   2.8097254E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_ashz_zz_mass = Yx/0.017332875
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1254097E-05,   6.3212981E-05
     +,   6.5174376E-05,   6.7137167E-05,   6.9100584E-05
     +,   7.1064263E-05,   7.3028263E-05,   7.4993040E-05
     +,   7.6959506E-05,   7.8929057E-05,   8.0903439E-05
     +,   8.2884748E-05,   8.4875515E-05,   8.6878448E-05
     +,   8.8896537E-05,   9.0932830E-05,   9.2990442E-05
     +,   9.5072370E-05,   9.7181415E-05,   9.9320081E-05
     +,   1.0149033E-04,   1.0369362E-04,   1.0593061E-04
     +,   1.0820131E-04,   1.1050447E-04,   1.1283816E-04
     +,   1.1519913E-04,   1.1758304E-04,   1.1998439E-04
     +,   1.2239652E-04,   1.2481170E-04,   1.2722115E-04
     +,   1.2961519E-04,   1.3198343E-04,   1.3431483E-04
     +,   1.3659814E-04,   1.3882204E-04,   1.4097530E-04
     +,   1.4304735E-04,   1.4502827E-04,   1.4690943E-04
     +,   1.4868358E-04,   1.5034509E-04,   1.5189052E-04
     +,   1.5331857E-04,   1.5463043E-04,   1.5582984E-04
     +,   1.5692328E-04,   1.5792000E-04,   1.5883187E-04
     +,   1.5967345E-04,   1.6046167E-04,   1.6121571E-04
     +,   1.6195654E-04,   1.6270671E-04,   1.6348987E-04
     +,   1.6433028E-04,   1.6525225E-04,   1.6627967E-04
     +,   1.6743552E-04,   1.6874113E-04,   1.7021575E-04
     +,   1.7187605E-04,   1.7373569E-04,   1.7580476E-04
     +,   1.7808941E-04,   1.8059202E-04,   1.8331001E-04
     +,   1.8623703E-04,   1.8936167E-04,   1.9266878E-04
     +,   1.9613841E-04,   1.9974721E-04,   2.0346783E-04
     +,   2.0727026E-04,   2.1112176E-04,   2.1498752E-04
     +,   2.1883105E-04,   2.2261559E-04,   2.2630423E-04
     +,   2.2986006E-04,   2.3324801E-04,   2.3643416E-04
     +,   2.3938733E-04,   2.4207884E-04,   2.4448326E-04
     +,   2.4657857E-04,   2.4834674E-04,   2.4977329E-04
     +,   2.5084816E-04,   2.5156498E-04,   2.5192130E-04
     +,   2.5191865E-04,   2.5156201E-04,   2.5085988E-04
     +,   2.4982376E-04,   2.4846784E-04,   2.4680910E-04
     +,   2.4486636E-04,   2.4266068E-04,   2.4021420E-04
     +,   2.3755076E-04,   2.3469476E-04,   2.3167167E-04
     +,   2.2850710E-04,   2.2522674E-04,   2.2185649E-04
     +,   2.1842201E-04,   2.1494800E-04,   2.1145858E-04
     +,   2.0797717E-04,   2.0452547E-04,   2.0112438E-04
     +,   1.9779266E-04,   1.9454770E-04,   1.9140454E-04
     +,   1.8837659E-04,   1.8547454E-04,   1.8270708E-04
     +,   1.8008040E-04,   1.7759827E-04,   1.7526212E-04
     +,   1.7307130E-04,   1.7102264E-04,   1.6911099E-04
     +,   1.6732968E-04,   1.6566998E-04,   1.6412196E-04
     +,   1.6267457E-04,   1.6131597E-04,   1.6003355E-04
     +,   1.5881457E-04,   1.5764603E-04,   1.5651537E-04
     +,   1.5541018E-04,   1.5431877E-04,   1.5323015E-04
     +,   1.5213432E-04,   1.5102212E-04,   1.4988540E-04
     +,   1.4871721E-04,   1.4751164E-04,   1.4626380E-04
     +,   1.4496980E-04,   1.4362689E-04,   1.4223314E-04
     +,   1.4078747E-04,   1.3928968E-04,   1.3774035E-04
     +,   1.3614062E-04,   1.3449226E-04,   1.3279769E-04
     +,   1.3105980E-04,   1.2928192E-04,   1.2746779E-04
     +,   1.2562150E-04,   1.2374774E-04,   1.2185118E-04
     +,   1.1993678E-04,   1.1801005E-04,   1.1607639E-04
     +,   1.1414138E-04,   1.1221079E-04,   1.1029046E-04
     +,   1.0838608E-04,   1.0650322E-04,   1.0464746E-04
     +,   1.0282413E-04,   1.0103818E-04,   9.9294193E-05
     +,   9.7596479E-05,   9.5948824E-05,   9.4354393E-05
     +,   9.2815775E-05,   9.1335147E-05,   8.9913789E-05
     +,   8.8552450E-05,   8.7251166E-05,   8.6009401E-05
     +,   8.4825842E-05,   8.3698520E-05,   8.2624989E-05
     +,   8.1602208E-05,   8.0626553E-05,   7.9693957E-05
     +,   7.8800025E-05,   7.7940029E-05,   7.7108933E-05
     +,   7.6301498E-05,   7.5512486E-05,   7.4736534E-05
     +,   7.3968265E-05,   7.3202522E-05,   7.2434246E-05
     +,   7.1658578E-05,   7.0870934E-05,   7.0067108E-05
     +,   6.9243222E-05,   6.8395835E-05,   6.7521833E-05
     +,   6.6618661E-05,   6.5684224E-05,   6.4716849E-05
     +,   6.3715335E-05,   6.2679042E-05,   6.1607738E-05
     +,   6.0501585E-05,   5.9361304E-05,   5.8187994E-05
     +,   5.6983081E-05,   5.5748336E-05,   5.4485950E-05
     +,   5.3198375E-05,   5.1888273E-05,   5.0558498E-05
     +,   4.9212165E-05,   4.7852565E-05,   4.6482990E-05
     +,   4.5106783E-05,   4.3727512E-05,   4.2348565E-05
     +,   4.0973333E-05,   3.9605224E-05,   3.8247577E-05
     +,   3.6903522E-05,   3.5576079E-05,   3.4268178E-05
     +,   3.2982600E-05,   3.1721858E-05,   3.0488254E-05
     +,   2.9283996E-05,   2.8111055E-05,   2.6971118E-05
     +,   2.5865655E-05,   2.4796029E-05,   2.3763265E-05
     +,   2.2768185E-05,   2.1811467E-05,   2.0893585E-05
     +,   2.0014746E-05,   1.9174988E-05,   1.8374210E-05
     +,   1.7612161E-05,   1.6888371E-05,   1.6202233E-05
     +,   1.5553065E-05,   1.4940051E-05,   1.4362235E-05
     +,   1.3818563E-05,   1.3307969E-05,   1.2829255E-05
     +,   1.2381168E-05,   1.1962446E-05,   1.1571784E-05
     +,   1.1207828E-05,   1.0869213E-05,   1.0554591E-05
     +,   1.0262611E-05,   9.9919162E-06,   9.7411639E-06
     +,   9.5090591E-06,   9.2943264E-06,   9.0957119E-06
     +,   8.9120031E-06,   8.7420431E-06,   8.5847050E-06
     +,   8.4389094E-06,   8.3036339E-06,   8.1779017E-06
     +,   8.0607870E-06,   7.9514066E-06,   7.8489420E-06
     +,   7.7526229E-06,   7.6617216E-06,   7.5755624E-06
     +,   7.4935247E-06,   7.4150244E-06,   7.3395327E-06
     +,   7.2665553E-06,   7.1956483E-06,   7.1263989E-06
     +,   7.0584406E-06,   6.9914381E-06,   6.9250923E-06
     +,   6.8591326E-06,   6.7933265E-06,   6.7274627E-06
     +,   6.6613552E-06,   6.5948507E-06,   6.5278086E-06
     +,   6.4601195E-06,   6.3916846E-06,   6.3224311E-06
     +,   6.2522936E-06,   6.1812302E-06,   6.1092055E-06
     +,   6.0362031E-06,   5.9622103E-06,   5.8872338E-06
     +,   5.8112792E-06,   5.7343700E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_eez_mass = Yx/0.00778079166666667
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.2411166E-05,   9.6907534E-05
     +,   1.0153772E-04,   1.0629896E-04,   1.1118787E-04
     +,   1.1620032E-04,   1.2133160E-04,   1.2657611E-04
     +,   1.3192753E-04,   1.3737904E-04,   1.4292276E-04
     +,   1.4855019E-04,   1.5425202E-04,   1.6001826E-04
     +,   1.6583821E-04,   1.7170038E-04,   1.7759268E-04
     +,   1.8350239E-04,   1.8941623E-04,   1.9532027E-04
     +,   2.0120030E-04,   2.0704143E-04,   2.1282864E-04
     +,   2.1854677E-04,   2.2417984E-04,   2.2971258E-04
     +,   2.3512915E-04,   2.4041388E-04,   2.4555135E-04
     +,   2.5052630E-04,   2.5532389E-04,   2.5992960E-04
     +,   2.6432949E-04,   2.6851040E-04,   2.7245950E-04
     +,   2.7616508E-04,   2.7961607E-04,   2.8280236E-04
     +,   2.8571495E-04,   2.8834571E-04,   2.9068781E-04
     +,   2.9273529E-04,   2.9448356E-04,   2.9592917E-04
     +,   2.9706984E-04,   2.9790451E-04,   2.9843330E-04
     +,   2.9865757E-04,   2.9857989E-04,   2.9820373E-04
     +,   2.9753396E-04,   2.9657639E-04,   2.9533776E-04
     +,   2.9382575E-04,   2.9204908E-04,   2.9001711E-04
     +,   2.8773997E-04,   2.8522851E-04,   2.8249406E-04
     +,   2.7954861E-04,   2.7640429E-04,   2.7307391E-04
     +,   2.6957036E-04,   2.6590671E-04,   2.6209606E-04
     +,   2.5815194E-04,   2.5408721E-04,   2.4991535E-04
     +,   2.4564902E-04,   2.4130133E-04,   2.3688453E-04
     +,   2.3241118E-04,   2.2789287E-04,   2.2334141E-04
     +,   2.1876795E-04,   2.1418293E-04,   2.0959695E-04
     +,   2.0501994E-04,   2.0046117E-04,   1.9592949E-04
     +,   1.9143363E-04,   1.8698136E-04,   1.8258044E-04
     +,   1.7823784E-04,   1.7396036E-04,   1.6975397E-04
     +,   1.6562473E-04,   1.6157777E-04,   1.5761828E-04
     +,   1.5375066E-04,   1.4997901E-04,   1.4630721E-04
     +,   1.4273883E-04,   1.3927686E-04,   1.3592392E-04
     +,   1.3268263E-04,   1.2955489E-04,   1.2654265E-04
     +,   1.2364717E-04,   1.2086985E-04,   1.1821136E-04
     +,   1.1567245E-04,   1.1325323E-04,   1.1095394E-04
     +,   1.0877424E-04,   1.0671353E-04,   1.0477116E-04
     +,   1.0294611E-04,   1.0123713E-04,   9.9642617E-05
     +,   9.8160956E-05,   9.6790100E-05,   9.5527968E-05
     +,   9.4372124E-05,   9.3320064E-05,   9.2368966E-05
     +,   9.1515962E-05,   9.0757931E-05,   9.0091700E-05
     +,   8.9513858E-05,   8.9020883E-05,   8.8609246E-05
     +,   8.8275236E-05,   8.8015055E-05,   8.7824890E-05
     +,   8.7700842E-05,   8.7639040E-05,   8.7635482E-05
     +,   8.7686269E-05,   8.7787426E-05,   8.7935055E-05
     +,   8.8125278E-05,   8.8354296E-05,   8.8618319E-05
     +,   8.8913665E-05,   8.9236761E-05,   8.9584115E-05
     +,   8.9952351E-05,   9.0338181E-05,   9.0738555E-05
     +,   9.1150476E-05,   9.1571113E-05,   9.1997834E-05
     +,   9.2428170E-05,   9.2859809E-05,   9.3290604E-05
     +,   9.3718721E-05,   9.4142371E-05,   9.4560099E-05
     +,   9.4970565E-05,   9.5372729E-05,   9.5765681E-05
     +,   9.6148811E-05,   9.6521668E-05,   9.6884076E-05
     +,   9.7236065E-05,   9.7577889E-05,   9.7910000E-05
     +,   9.8233162E-05,   9.8548240E-05,   9.8856413E-05
     +,   9.9158999E-05,   9.9457597E-05,   9.9753961E-05
     +,   1.0004998E-04,   1.0034790E-04,   1.0064992E-04
     +,   1.0095855E-04,   1.0127638E-04,   1.0160625E-04
     +,   1.0195091E-04,   1.0231345E-04,   1.0269687E-04
     +,   1.0310433E-04,   1.0353906E-04,   1.0400426E-04
     +,   1.0450320E-04,   1.0503907E-04,   1.0561509E-04
     +,   1.0623442E-04,   1.0690014E-04,   1.0761524E-04
     +,   1.0838258E-04,   1.0920483E-04,   1.1008461E-04
     +,   1.1102426E-04,   1.1202588E-04,   1.1309140E-04
     +,   1.1422252E-04,   1.1542059E-04,   1.1668670E-04
     +,   1.1802170E-04,   1.1942593E-04,   1.2089952E-04
     +,   1.2244224E-04,   1.2405349E-04,   1.2573221E-04
     +,   1.2747705E-04,   1.2928617E-04,   1.3115753E-04
     +,   1.3308847E-04,   1.3507591E-04,   1.3711667E-04
     +,   1.3920694E-04,   1.4134253E-04,   1.4351901E-04
     +,   1.4573158E-04,   1.4797498E-04,   1.5024364E-04
     +,   1.5253178E-04,   1.5483341E-04,   1.5714210E-04
     +,   1.5945119E-04,   1.6175389E-04,   1.6404343E-04
     +,   1.6631254E-04,   1.6855390E-04,   1.7076032E-04
     +,   1.7292450E-04,   1.7503892E-04,   1.7709626E-04
     +,   1.7908930E-04,   1.8101078E-04,   1.8285350E-04
     +,   1.8461063E-04,   1.8627546E-04,   1.8784140E-04
     +,   1.8930215E-04,   1.9065176E-04,   1.9188462E-04
     +,   1.9299537E-04,   1.9397897E-04,   1.9483095E-04
     +,   1.9554711E-04,   1.9612373E-04,   1.9655759E-04
     +,   1.9684579E-04,   1.9698609E-04,   1.9697660E-04
     +,   1.9681602E-04,   1.9650345E-04,   1.9603860E-04
     +,   1.9542161E-04,   1.9465320E-04,   1.9373442E-04
     +,   1.9266702E-04,   1.9145306E-04,   1.9009519E-04
     +,   1.8859634E-04,   1.8696010E-04,   1.8519029E-04
     +,   1.8329108E-04,   1.8126724E-04,   1.7912374E-04
     +,   1.7686587E-04,   1.7449912E-04,   1.7202944E-04
     +,   1.6946296E-04,   1.6680594E-04,   1.6406472E-04
     +,   1.6124600E-04,   1.5835663E-04,   1.5540328E-04
     +,   1.5239276E-04,   1.4933212E-04,   1.4622815E-04
     +,   1.4308759E-04,   1.3991731E-04,   1.3672411E-04
     +,   1.3351449E-04,   1.3029476E-04,   1.2707131E-04
     +,   1.2385036E-04,   1.2063768E-04,   1.1743884E-04
     +,   1.1425951E-04,   1.1110466E-04,   1.0797943E-04
     +,   1.0488825E-04,   1.0183573E-04,   9.8825731E-05
     +,   9.5862233E-05,   9.2948525E-05,   9.0087990E-05
     +,   8.7283304E-05,   8.4537249E-05,   8.1851991E-05
     +,   7.9229438E-05,   7.6671458E-05,   7.4179283E-05
     +,   7.1754213E-05,   6.9396949E-05,   6.7108274E-05
     +,   6.4888380E-05,   6.2737534E-05,   6.0655497E-05
     +,   5.8642105E-05,   5.6696710E-05,   5.4818738E-05
     +,   5.3007210E-05,   5.1261206E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_qq_mass = Yx/0.0115396590909091
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.1339663E-04,   1.2043837E-04
     +,   1.2782715E-04,   1.3556759E-04,   1.4366284E-04
     +,   1.5211468E-04,   1.6092324E-04,   1.7008703E-04
     +,   1.7960281E-04,   1.8946588E-04,   1.9966923E-04
     +,   2.1020426E-04,   2.2106044E-04,   2.3222563E-04
     +,   2.4368541E-04,   2.5542421E-04,   2.6742439E-04
     +,   2.7966686E-04,   2.9213078E-04,   3.0479408E-04
     +,   3.1763344E-04,   3.3062414E-04,   3.4374019E-04
     +,   3.5695513E-04,   3.7024019E-04,   3.8356730E-04
     +,   3.9690640E-04,   4.1022705E-04,   4.2349749E-04
     +,   4.3668572E-04,   4.4975904E-04,   4.6268353E-04
     +,   4.7542530E-04,   4.8794950E-04,   5.0022139E-04
     +,   5.1220582E-04,   5.2386837E-04,   5.3517398E-04
     +,   5.4609083E-04,   5.5658596E-04,   5.6663051E-04
     +,   5.7619764E-04,   5.8526383E-04,   5.9380993E-04
     +,   6.0182199E-04,   6.0929201E-04,   6.1621779E-04
     +,   6.2260439E-04,   6.2846544E-04,   6.3382165E-04
     +,   6.3870254E-04,   6.4314588E-04,   6.4719707E-04
     +,   6.5091037E-04,   6.5434602E-04,   6.5757061E-04
     +,   6.6065619E-04,   6.6367746E-04,   6.6671276E-04
     +,   6.6983997E-04,   6.7313592E-04,   6.7667518E-04
     +,   6.8052771E-04,   6.8475842E-04,   6.8942411E-04
     +,   6.9457461E-04,   7.0025027E-04,   7.0648291E-04
     +,   7.1329490E-04,   7.2069984E-04,   7.2870177E-04
     +,   7.3729764E-04,   7.4647897E-04,   7.5622747E-04
     +,   7.6652481E-04,   7.7734701E-04,   7.8866730E-04
     +,   8.0045633E-04,   8.1268582E-04,   8.2532549E-04
     +,   8.3834212E-04,   8.5170422E-04,   8.6537510E-04
     +,   8.7931717E-04,   8.9348614E-04,   9.0783439E-04
     +,   9.2230400E-04,   9.3683327E-04,   9.5134822E-04
     +,   9.6576754E-04,   9.8000164E-04,   9.9395204E-04
     +,   1.0075128E-03,   1.0205756E-03,   1.0330294E-03
     +,   1.0447629E-03,   1.0556732E-03,   1.0656643E-03
     +,   1.0746524E-03,   1.0825701E-03,   1.0893703E-03
     +,   1.0950265E-03,   1.0995338E-03,   1.1029126E-03
     +,   1.1052057E-03,   1.1064764E-03,   1.1068059E-03
     +,   1.1062897E-03,   1.1050325E-03,   1.1031451E-03
     +,   1.1007333E-03,   1.0979000E-03,   1.0947332E-03
     +,   1.0913052E-03,   1.0876671E-03,   1.0838476E-03
     +,   1.0798501E-03,   1.0756544E-03,   1.0712153E-03
     +,   1.0664692E-03,   1.0613337E-03,   1.0557143E-03
     +,   1.0495114E-03,   1.0426214E-03,   1.0349480E-03
     +,   1.0264042E-03,   1.0169189E-03,   1.0064414E-03
     +,   9.9494366E-04,   9.8242541E-04,   9.6891116E-04
     +,   9.5445453E-04,   9.3913428E-04,   9.2305418E-04
     +,   9.0633740E-04,   8.8912307E-04,   8.7156444E-04
     +,   8.5382035E-04,   8.3605340E-04,   8.1841997E-04
     +,   8.0107228E-04,   7.8414951E-04,   7.6777535E-04
     +,   7.5205357E-04,   7.3706877E-04,   7.2288385E-04
     +,   7.0953573E-04,   6.9704134E-04,   6.8539474E-04
     +,   6.7456899E-04,   6.6451856E-04,   6.5518211E-04
     +,   6.4648589E-04,   6.3834514E-04,   6.3066854E-04
     +,   6.2336121E-04,   6.1632838E-04,   6.0947763E-04
     +,   6.0272205E-04,   5.9598364E-04,   5.8919442E-04
     +,   5.8229780E-04,   5.7525223E-04,   5.6802941E-04
     +,   5.6061684E-04,   5.5301678E-04,   5.4524653E-04
     +,   5.3733727E-04,   5.2933377E-04,   5.2129175E-04
     +,   5.1327812E-04,   5.0536840E-04,   4.9764395E-04
     +,   4.9019157E-04,   4.8310109E-04,   4.7646335E-04
     +,   4.7036755E-04,   4.6490235E-04,   4.6015123E-04
     +,   4.5619244E-04,   4.5309874E-04,   4.5093463E-04
     +,   4.4975747E-04,   4.4961562E-04,   4.5054796E-04
     +,   4.5258467E-04,   4.5574628E-04,   4.6004434E-04
     +,   4.6548047E-04,   4.7204702E-04,   4.7972731E-04
     +,   4.8849685E-04,   4.9831998E-04,   5.0915399E-04
     +,   5.2094809E-04,   5.3364277E-04,   5.4717134E-04
     +,   5.6145823E-04,   5.7642226E-04,   5.9197529E-04
     +,   6.0802209E-04,   6.2446203E-04,   6.4119045E-04
     +,   6.5809878E-04,   6.7507353E-04,   6.9200277E-04
     +,   7.0877100E-04,   7.2526489E-04,   7.4137119E-04
     +,   7.5698289E-04,   7.7199691E-04,   7.8631559E-04
     +,   7.9985010E-04,   8.1251987E-04,   8.2425552E-04
     +,   8.3499833E-04,   8.4470055E-04,   8.5332914E-04
     +,   8.6086296E-04,   8.6729240E-04,   8.7262312E-04
     +,   8.7687169E-04,   8.8006695E-04,   8.8224869E-04
     +,   8.8346546E-04,   8.8377664E-04,   8.8324782E-04
     +,   8.8195037E-04,   8.7996147E-04,   8.7736006E-04
     +,   8.7422843E-04,   8.7064825E-04,   8.6670090E-04
     +,   8.6246588E-04,   8.5801998E-04,   8.5343642E-04
     +,   8.4878248E-04,   8.4412203E-04,   8.3951309E-04
     +,   8.3500688E-04,   8.3064818E-04,   8.2647649E-04
     +,   8.2252361E-04,   8.1881665E-04,   8.1537443E-04
     +,   8.1220974E-04,   8.0932933E-04,   8.0673379E-04
     +,   8.0441724E-04,   8.0236781E-04,   8.0056733E-04
     +,   7.9899206E-04,   7.9761178E-04,   7.9639134E-04
     +,   7.9528836E-04,   7.9425692E-04,   7.9324364E-04
     +,   7.9219230E-04,   7.9103984E-04,   7.8972057E-04
     +,   7.8816537E-04,   7.8630162E-04,   7.8405585E-04
     +,   7.8135269E-04,   7.7811885E-04,   7.7428052E-04
     +,   7.6976838E-04,   7.6451665E-04,   7.5846526E-04
     +,   7.5156079E-04,   7.4375735E-04,   7.3501875E-04
     +,   7.2531920E-04,   7.1464211E-04,   7.0298265E-04
     +,   6.9034874E-04,   6.7675754E-04,   6.6224032E-04
     +,   6.4683706E-04,   6.3059916E-04,   6.1358756E-04
     +,   5.9587212E-04,   5.7752855E-04,   5.5864040E-04
     +,   5.3929415E-04,   5.1958172E-04,   4.9959536E-04
     +,   4.7942705E-04,   4.5917125E-04,   4.3891632E-04
     +,   4.1875118E-04,   3.9875758E-04,   3.7901502E-04
     +,   3.5959471E-04,   3.4056412E-04,   3.2198153E-04
     +,   3.0390109E-04,   2.8636708E-04,   2.6941957E-04
     +,   2.5308903E-04,   2.3740172E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_ww_mass = Yx/0.0493873726315789
      RETURN
      END
      DOUBLE PRECISION FUNCTION A208_tt_hzonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  5.4474829E-05,   5.6337107E-05
     +,   5.8213453E-05,   6.0100992E-05,   6.1996732E-05
     +,   6.3897554E-05,   6.5800246E-05,   6.7701505E-05
     +,   6.9597896E-05,   7.1486007E-05,   7.3362287E-05
     +,   7.5223164E-05,   7.7065029E-05,   7.8884223E-05
     +,   8.0677157E-05,   8.2440180E-05,   8.4169675E-05
     +,   8.5862135E-05,   8.7514018E-05,   8.9121902E-05
     +,   9.0682472E-05,   9.2192473E-05,   9.3648785E-05
     +,   9.5048512E-05,   9.6388758E-05,   9.7666947E-05
     +,   9.8880591E-05,   1.0002746E-04,   1.0110552E-04
     +,   1.0211295E-04,   1.0304818E-04,   1.0390994E-04
     +,   1.0469718E-04,   1.0540913E-04,   1.0604534E-04
     +,   1.0660567E-04,   1.0709024E-04,   1.0749950E-04
     +,   1.0783432E-04,   1.0809573E-04,   1.0828526E-04
     +,   1.0840475E-04,   1.0845628E-04,   1.0844241E-04
     +,   1.0836601E-04,   1.0823034E-04,   1.0803893E-04
     +,   1.0779579E-04,   1.0750524E-04,   1.0717191E-04
     +,   1.0680089E-04,   1.0639755E-04,   1.0596767E-04
     +,   1.0551735E-04,   1.0505301E-04,   1.0458149E-04
     +,   1.0410991E-04,   1.0364571E-04,   1.0319668E-04
     +,   1.0277091E-04,   1.0237675E-04,   1.0202290E-04
     +,   1.0171835E-04,   1.0147227E-04,   1.0129424E-04
     +,   1.0119400E-04,   1.0118159E-04,   1.0126733E-04
     +,   1.0146182E-04,   1.0177587E-04,   1.0222073E-04
     +,   1.0280784E-04,   1.0354908E-04,   1.0445659E-04
     +,   1.0554295E-04,   1.0682129E-04,   1.0830491E-04
     +,   1.1000768E-04,   1.1194398E-04,   1.1412855E-04
     +,   1.1657640E-04,   1.1930321E-04,   1.2232433E-04
     +,   1.2565576E-04,   1.2931296E-04,   1.3331142E-04
     +,   1.3766575E-04,   1.4239004E-04,   1.4749661E-04
     +,   1.5299665E-04,   1.5889929E-04,   1.6521079E-04
     +,   1.7193436E-04,   1.7907024E-04,   1.8661471E-04
     +,   1.9455918E-04,   2.0289114E-04,   2.1159201E-04
     +,   2.2063918E-04,   2.3000310E-04,   2.3965014E-04
     +,   2.4953956E-04,   2.5962677E-04,   2.6986041E-04
     +,   2.8018552E-04,   2.9054272E-04,   3.0086815E-04
     +,   3.1109527E-04,   3.2115594E-04,   3.3098104E-04
     +,   3.4050056E-04,   3.4964757E-04,   3.5835674E-04
     +,   3.6656851E-04,   3.7422904E-04,   3.8129350E-04
     +,   3.8772647E-04,   3.9350608E-04,   3.9862384E-04
     +,   4.0308788E-04,   4.0692350E-04,   4.1017483E-04
     +,   4.1290451E-04,   4.1519525E-04,   4.1714730E-04
     +,   4.1887752E-04,   4.2051668E-04,   4.2220560E-04
     +,   4.2409135E-04,   4.2632248E-04,   4.2904352E-04
     +,   4.3238935E-04,   4.3648152E-04,   4.4142190E-04
     +,   4.4729127E-04,   4.5414671E-04,   4.6202130E-04
     +,   4.7092605E-04,   4.8085430E-04,   4.9178809E-04
     +,   5.0370442E-04,   5.1658670E-04,   5.3043512E-04
     +,   5.4527872E-04,   5.6118425E-04,   5.7826901E-04
     +,   5.9670769E-04,   6.1673712E-04,   6.3865393E-04
     +,   6.6281407E-04,   6.8961654E-04,   7.1948295E-04
     +,   7.5282843E-04,   7.9003029E-04,   8.3138025E-04
     +,   8.7703677E-04,   9.2697865E-04,   9.8096312E-04
     +,   1.0384938E-03,   1.0987944E-03,   1.1608251E-03
     +,   1.2233104E-03,   1.2847944E-03,   1.3437398E-03
     +,   1.3986406E-03,   1.4481504E-03,   1.4912109E-03
     +,   1.5271730E-03,   1.5558937E-03,   1.5777722E-03
     +,   1.5937436E-03,   1.6052084E-03,   1.6139075E-03
     +,   1.6217375E-03,   1.6305523E-03,   1.6419464E-03
     +,   1.6570609E-03,   1.6764373E-03,   1.6999327E-03
     +,   1.7267094E-03,   1.7553081E-03,   1.7837785E-03
     +,   1.8098741E-03,   1.8312656E-03,   1.8457662E-03
     +,   1.8515205E-03,   1.8471655E-03,   1.8319237E-03
     +,   1.8056412E-03,   1.7687696E-03,   1.7222811E-03
     +,   1.6675721E-03,   1.6063274E-03,   1.5403883E-03
     +,   1.4716185E-03,   1.4017971E-03,   1.3325444E-03
     +,   1.2652539E-03,   1.2010603E-03,   1.1408373E-03
     +,   1.0852106E-03,   1.0345755E-03,   9.8912162E-04
     +,   9.4887085E-04,   9.1370469E-04,   8.8339043E-04
     +,   8.5760013E-04,   8.3593675E-04,   8.1794622E-04
     +,   8.0313173E-04,   7.9096865E-04,   7.8091997E-04
     +,   7.7244989E-04,   7.6503720E-04,   7.5818878E-04
     +,   7.5145555E-04,   7.4444019E-04,   7.3680759E-04
     +,   7.2829030E-04,   7.1869441E-04,   7.0789829E-04
     +,   6.9584831E-04,   6.8255840E-04,   6.6810061E-04
     +,   6.5259344E-04,   6.3619530E-04,   6.1909185E-04
     +,   6.0148549E-04,   5.8358215E-04,   5.6558329E-04
     +,   5.4767862E-04,   5.3003756E-04,   5.1280367E-04
     +,   4.9609173E-04,   4.7998977E-04,   4.6455476E-04
     +,   4.4981603E-04,   4.3578044E-04,   4.2243410E-04
     +,   4.0974512E-04,   3.9767008E-04,   3.8615876E-04
     +,   3.7515647E-04,   3.6460787E-04,   3.5446030E-04
     +,   3.4466639E-04,   3.3518544E-04,   3.2598383E-04
     +,   3.1703556E-04,   3.0832342E-04,   2.9983657E-04
     +,   2.9157044E-04,   2.8352605E-04,   2.7570798E-04
     +,   2.6812297E-04,   2.6077862E-04,   2.5368293E-04
     +,   2.4684265E-04,   2.4026186E-04,   2.3394181E-04
     +,   2.2788104E-04,   2.2207470E-04,   2.1651405E-04
     +,   2.1118714E-04,   2.0607973E-04,   2.0117441E-04
     +,   1.9645205E-04,   1.9189260E-04,   1.8747489E-04
     +,   1.8317779E-04,   1.7898018E-04,   1.7486226E-04
     +,   1.7080564E-04,   1.6679318E-04,   1.6280978E-04
     +,   1.5884278E-04,   1.5488124E-04,   1.5091711E-04
     +,   1.4694393E-04,   1.4295807E-04,   1.3895730E-04
     +,   1.3494193E-04,   1.3091329E-04,   1.2687489E-04
     +,   1.2283093E-04,   1.1878722E-04,   1.1475000E-04
     +,   1.1072630E-04,   1.0672385E-04,   1.0275024E-04
     +,   9.8813711E-05,   9.4921939E-05,   9.1082955E-05
     +,   8.7304012E-05,   8.3592517E-05,   7.9954960E-05
     +,   7.6397788E-05,   7.2926421E-05,   6.9546113E-05
     +,   6.6261142E-05,   6.3075473E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A208_tt_hzonly_zz_mass = Yx/0.0339927567567568
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.0319175E-13,   1.6774734E-13
     +,   2.7105014E-13,   4.3533661E-13,   6.9499614E-13
     +,   1.1028640E-12,   1.7395816E-12,   2.7273971E-12
     +,   4.2504130E-12,   6.5841603E-12,   1.0137964E-11
     +,   1.5516139E-11,   2.3604703E-11,   3.5694048E-11
     +,   5.3650664E-11,   8.0156069E-11,   1.1903649E-10
     +,   1.7571378E-10,   2.5781843E-10,   3.7601414E-10
     +,   5.4510030E-10,   7.8547208E-10,   1.1250324E-09
     +,   1.6017191E-09,   2.2666542E-09,   3.1883707E-09
     +,   4.4579473E-09,   6.1955983E-09,   8.5588212E-09
     +,   1.1752412E-08,   1.6040687E-08,   2.1762137E-08
     +,   2.9346969E-08,   3.9337611E-08,   5.2412659E-08
     +,   6.9414128E-08,   9.1378425E-08,   1.1956995E-07
     +,   1.5552115E-07,   2.0106620E-07,   2.5839083E-07
     +,   3.3006756E-07,   4.1910008E-07,   5.2896024E-07
     +,   6.6362190E-07,   8.2758663E-07,   1.0258960E-06
     +,   1.2641374E-06,   1.5484233E-06,   1.8853618E-06
     +,   2.2819961E-06,   2.7457229E-06,   3.2841799E-06
     +,   3.9051620E-06,   4.6163532E-06,   5.4252982E-06
     +,   6.3390949E-06,   7.3642409E-06,   8.5064230E-06
     +,   9.7703241E-06,   1.1159450E-05,   1.2676014E-05
     +,   1.4320714E-05,   1.6092928E-05,   1.7990646E-05
     +,   2.0010364E-05,   2.2147753E-05,   2.4397417E-05
     +,   2.6753813E-05,   2.9211153E-05,   3.1764546E-05
     +,   3.4409935E-05,   3.7145390E-05,   3.9971030E-05
     +,   4.2890275E-05,   4.5910081E-05,   4.9041253E-05
     +,   5.2298907E-05,   5.5702902E-05,   5.9277609E-05
     +,   6.3051390E-05,   6.7056884E-05,   7.1329458E-05
     +,   7.5907265E-05,   8.0828904E-05,   8.6133310E-05
     +,   9.1856709E-05,   9.8032317E-05,   1.0468670E-04
     +,   1.1183929E-04,   1.1949947E-04,   1.2766419E-04
     +,   1.3631626E-04,   1.4542330E-04,   1.5493583E-04
     +,   1.6478520E-04,   1.7488543E-04,   1.8513063E-04
     +,   1.9539862E-04,   2.0554980E-04,   2.1543221E-04
     +,   2.2488199E-04,   2.3373000E-04,   2.4180356E-04
     +,   2.4893373E-04,   2.5495960E-04,   2.5973306E-04
     +,   2.6312488E-04,   2.6502958E-04,   2.6536910E-04
     +,   2.6409634E-04,   2.6119748E-04,   2.5669340E-04
     +,   2.5063884E-04,   2.4312219E-04,   2.3426145E-04
     +,   2.2420226E-04,   2.1311129E-04,   2.0117316E-04
     +,   1.8858266E-04,   1.7553943E-04,   1.6224304E-04
     +,   1.4888677E-04,   1.3565150E-04,   1.2270240E-04
     +,   1.1018675E-04,   9.8228535E-05,   8.6930180E-05
     +,   7.6368924E-05,   6.6600085E-05,   5.7655383E-05
     +,   4.9547292E-05,   4.2268905E-05,   3.5798661E-05
     +,   3.0101390E-05,   2.5131951E-05,   2.0838233E-05
     +,   1.7163275E-05,   1.4047429E-05,   1.1430683E-05
     +,   9.2544651E-06,   7.4627105E-06,   6.0028051E-06
     +,   4.8264251E-06,   3.8900248E-06,   3.1547711E-06
     +,   2.5866632E-06,   2.1563756E-06,   1.8389051E-06
     +,   1.6132097E-06,   1.4618356E-06,   1.3704920E-06
     +,   1.3276134E-06,   1.3239642E-06,   1.3522748E-06
     +,   1.4069003E-06,   1.4835214E-06,   1.5788963E-06
     +,   1.6906387E-06,   1.8170226E-06,   1.9568506E-06
     +,   2.1093242E-06,   2.2739316E-06,   2.4503781E-06
     +,   2.6385342E-06,   2.8383818E-06,   3.0499571E-06
     +,   3.2733369E-06,   3.5086282E-06,   3.7559410E-06
     +,   4.0153545E-06,   4.2869246E-06,   4.5706875E-06
     +,   4.8666434E-06,   5.1747179E-06,   5.4948168E-06
     +,   5.8267883E-06,   6.1704040E-06,   6.5253735E-06
     +,   6.8913664E-06,   7.2679863E-06,   7.6547467E-06
     +,   8.0510927E-06,   8.4564272E-06,   8.8700817E-06
     +,   9.2912960E-06,   9.7192387E-06,   1.0153043E-05
     +,   1.0591777E-05,   1.1034402E-05,   1.1479862E-05
     +,   1.1927053E-05,   1.2374782E-05,   1.2821813E-05
     +,   1.3266896E-05,   1.3708745E-05,   1.4146009E-05
     +,   1.4577321E-05,   1.5001322E-05,   1.5416639E-05
     +,   1.5821870E-05,   1.6215621E-05,   1.6596530E-05
     +,   1.6963260E-05,   1.7314462E-05,   1.7648863E-05
     +,   1.7965223E-05,   1.8262344E-05,   1.8539078E-05
     +,   1.8794370E-05,   1.9027228E-05,   1.9236732E-05
     +,   1.9422039E-05,   1.9582420E-05,   1.9717234E-05
     +,   1.9825931E-05,   1.9908068E-05,   1.9963309E-05
     +,   1.9991438E-05,   1.9992332E-05,   1.9965993E-05
     +,   1.9912522E-05,   1.9832141E-05,   1.9725181E-05
     +,   1.9592073E-05,   1.9433348E-05,   1.9249648E-05
     +,   1.9041718E-05,   1.8810373E-05,   1.8556517E-05
     +,   1.8281151E-05,   1.7985345E-05,   1.7670221E-05
     +,   1.7336959E-05,   1.6986822E-05,   1.6621083E-05
     +,   1.6241052E-05,   1.5848091E-05,   1.5443582E-05
     +,   1.5028898E-05,   1.4605414E-05,   1.4174525E-05
     +,   1.3737621E-05,   1.3296049E-05,   1.2851125E-05
     +,   1.2404169E-05,   1.1956460E-05,   1.1509213E-05
     +,   1.1063588E-05,   1.0620744E-05,   1.0181738E-05
     +,   9.7475659E-06,   9.3191957E-06,   8.8975266E-06
     +,   8.4833655E-06,   8.0774498E-06,   7.6804799E-06
     +,   7.2930839E-06,   6.9157941E-06,   6.5490754E-06
     +,   6.1933547E-06,   5.8489877E-06,   5.5162432E-06
     +,   5.1953311E-06,   4.8864331E-06,   4.5896400E-06
     +,   4.3049927E-06,   4.0324981E-06,   3.7721134E-06
     +,   3.5237358E-06,   3.2872213E-06,   3.0624042E-06
     +,   2.8490829E-06,   2.6470098E-06,   2.4559133E-06
     +,   2.2755146E-06,   2.1054891E-06,   1.9455188E-06
     +,   1.7952489E-06,   1.6543336E-06,   1.5223985E-06
     +,   1.3990810E-06,   1.2839969E-06,   1.1767773E-06
     +,   1.0770390E-06,   9.8441387E-07,   8.9852887E-07
     +,   8.1901720E-07,   7.4552707E-07,   6.7770452E-07
     +,   6.1521462E-07,   5.5772404E-07,   5.0491883E-07
     +,   4.5648892E-07,   4.1214352E-07,   3.7159782E-07
     +,   3.3458556E-07,   3.0084860E-07,   2.7014576E-07
     +,   2.4224497E-07,   2.1693049E-07
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_eez_mass = Yx/0.002534
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.1091067E-19,   5.4122055E-19
     +,   9.3779958E-19,   1.6174944E-18,   2.7769895E-18
     +,   4.7457275E-18,   8.0728775E-18,   1.3669447E-17
     +,   2.3039283E-17,   3.8653300E-17,   6.4551097E-17
     +,   1.0730423E-16,   1.7755302E-16,   2.9243969E-16
     +,   4.7944892E-16,   7.8243160E-16,   1.2710028E-15
     +,   2.0551550E-15,   3.3078159E-15,   5.2995036E-15
     +,   8.4513492E-15,   1.3415719E-14,   2.1198114E-14
     +,   3.3341426E-14,   5.2199022E-14,   8.1346903E-14
     +,   1.2618758E-13,   1.9484575E-13,   2.9947567E-13
     +,   4.5817435E-13,   6.9774416E-13,   1.0576949E-12
     +,   1.5959586E-12,   2.3970656E-12,   3.5837433E-12
     +,   5.3332269E-12,   7.9002560E-12,   1.1648973E-11
     +,   1.7097669E-11,   2.4979163E-11,   3.6326140E-11
     +,   5.2584583E-11,   7.5769543E-11,   1.0867470E-10
     +,   1.5515281E-10,   2.2049008E-10,   3.1189981E-10
     +,   4.3917653E-10,   6.1554611E-10,   8.5877511E-10
     +,   1.1926040E-09,   1.6485802E-09,   2.2683981E-09
     +,   3.1069232E-09,   4.2357962E-09,   5.7482907E-09
     +,   7.7649789E-09,   1.0440933E-08,   1.3974496E-08
     +,   1.8617873E-08,   2.4690044E-08,   3.2592169E-08
     +,   4.2825011E-08,   5.6011835E-08,   7.2922795E-08
     +,   9.4501949E-08,   1.2190435E-07,   1.5652792E-07
     +,   2.0006226E-07,   2.5452644E-07,   3.2233032E-07
     +,   4.0631585E-07,   5.0983215E-07,   6.3677317E-07
     +,   7.9166273E-07,   9.7970656E-07,   1.2068388E-06
     +,   1.4797804E-06,   1.8061033E-06,   2.1942617E-06
     +,   2.6535608E-06,   3.1942557E-06,   3.8274134E-06
     +,   4.5650027E-06,   5.4196562E-06,   6.4047540E-06
     +,   7.5340454E-06,   8.8217303E-06,   1.0281932E-05
     +,   1.1928702E-05,   1.3775622E-05,   1.5835320E-05
     +,   1.8119152E-05,   2.0636997E-05,   2.3396695E-05
     +,   2.6403304E-05,   2.9659319E-05,   3.3163476E-05
     +,   3.6911184E-05,   4.0893276E-05,   4.5096698E-05
     +,   4.9503258E-05,   5.4090564E-05,   5.8830927E-05
     +,   6.3692351E-05,   6.8638488E-05,   7.3628420E-05
     +,   7.8617602E-05,   8.3558713E-05,   8.8402005E-05
     +,   9.3095638E-05,   9.7587654E-05,   1.0182572E-04
     +,   1.0575929E-04,   1.0933948E-04,   1.1252111E-04
     +,   1.1526282E-04,   1.1752865E-04,   1.1928822E-04
     +,   1.2051804E-04,   1.2120169E-04,   1.2133031E-04
     +,   1.2090296E-04,   1.1992664E-04,   1.1841625E-04
     +,   1.1639455E-04,   1.1389142E-04,   1.1094394E-04
     +,   1.0759524E-04,   1.0389458E-04,   9.9895820E-05
     +,   9.5657684E-05,   9.1242058E-05,   8.6714441E-05
     +,   8.2142295E-05,   7.7595025E-05,   7.3143652E-05
     +,   6.8860143E-05,   6.4816741E-05,   6.1085804E-05
     +,   5.7739690E-05,   5.4849974E-05,   5.2486710E-05
     +,   5.0718067E-05,   4.9609589E-05,   4.9222806E-05
     +,   4.9614398E-05,   5.0834649E-05,   5.2925876E-05
     +,   5.5921002E-05,   5.9841856E-05,   6.4697233E-05
     +,   7.0481467E-05,   7.7173674E-05,   8.4736566E-05
     +,   9.3115348E-05,   1.0223823E-04,   1.1201767E-04
     +,   1.2235108E-04,   1.3312163E-04,   1.4420261E-04
     +,   1.5545920E-04,   1.6675104E-04,   1.7793608E-04
     +,   1.8887485E-04,   1.9943270E-04,   2.0948214E-04
     +,   2.1890584E-04,   2.2759920E-04,   2.3547068E-04
     +,   2.4244202E-04,   2.4844881E-04,   2.5344040E-04
     +,   2.5737824E-04,   2.6023475E-04,   2.6199271E-04
     +,   2.6264356E-04,   2.6218675E-04,   2.6062920E-04
     +,   2.5798491E-04,   2.5427478E-04,   2.4952769E-04
     +,   2.4378106E-04,   2.3708089E-04,   2.2948302E-04
     +,   2.2105420E-04,   2.1187199E-04,   2.0202399E-04
     +,   1.9160766E-04,   1.8073028E-04,   1.6950518E-04
     +,   1.5805058E-04,   1.4648774E-04,   1.3493761E-04
     +,   1.2351696E-04,   1.1233647E-04,   1.0149874E-04
     +,   9.1095244E-05,   8.1203769E-05,   7.1887946E-05
     +,   6.3196967E-05,   5.5164750E-05,   4.7809779E-05
     +,   4.1136653E-05,   3.5137833E-05,   2.9793937E-05
     +,   2.5076271E-05,   2.0948961E-05,   1.7370456E-05
     +,   1.4295219E-05,   1.1675730E-05,   9.4641327E-06
     +,   7.6133024E-06,   6.0778234E-06,   4.8149645E-06
     +,   3.7853313E-06,   2.9530900E-06,   2.2861357E-06
     +,   1.7561864E-06,   1.3387065E-06,   1.0126003E-06
     +,   7.6001243E-07,   5.6602283E-07,   4.1829168E-07
     +,   3.0672544E-07,   2.2317174E-07,   1.6111993E-07
     +,   1.1542052E-07,   8.2041744E-08,   5.7862575E-08
     +,   4.0492615E-08,   2.8117253E-08,   1.9372370E-08
     +,   1.3243419E-08,   8.9832639E-09,   6.0461547E-09
     +,   4.0376538E-09,   2.6753992E-09,   1.7589906E-09
     +,   1.1474869E-09,   7.4273554E-10,   4.7701154E-10
     +,   3.0397554E-10,   1.9220124E-10,   1.2057991E-10
     +,   7.5058737E-11,   4.6359867E-11,   2.8411246E-11
     +,   1.7275839E-11,   1.0423202E-11,   6.2398029E-12
     +,   3.7063013E-12,   2.1843246E-12,   1.2773412E-12
     +,   7.4114792E-13,   4.2667887E-13,   2.4372759E-13
     +,   1.3814087E-13,   7.7686758E-14,   4.3348083E-14
     +,   2.3999333E-14,   1.3183902E-14,   7.1861301E-15
     +,   3.8863710E-15,   2.0854936E-15,   1.1104009E-15
     +,   5.8660917E-16,   3.0748508E-16,   1.5992440E-16
     +,   8.2530132E-17,   4.2257782E-17,   2.1468808E-17
     +,   1.0822446E-17,   5.4131386E-18,   2.6863904E-18
     +,   1.3228343E-18,   6.4630811E-19,   3.1332079E-19
     +,   1.5070729E-19,   7.1928014E-20,   3.4060997E-20
     +,   1.6004187E-20,   7.4611433E-21,   3.4513909E-21
     +,   1.5840847E-21,   7.2140868E-22,   3.2597906E-22
     +,   1.4614768E-22,   6.5015126E-23,   2.8696728E-23
     +,   1.2568036E-23,   5.4612821E-24,   2.3547445E-24
     +,   1.0073646E-24,   4.2760891E-25,   1.8009524E-25
     +,   7.5262107E-26,   3.1206564E-26,   1.2838994E-26
     +,   5.2409677E-27,   2.1228155E-27
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_qq_mass = Yx/0.00322
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.9397061E-14,   5.8364399E-14
     +,   8.6129082E-14,   1.2661061E-13,   1.8539890E-13
     +,   2.7043385E-13,   3.9294636E-13,   5.6875132E-13
     +,   8.2002260E-13,   1.1777419E-12,   1.6849665E-12
     +,   2.4013198E-12,   3.4089953E-12,   4.8208139E-12
     +,   6.7909584E-12,   9.5292663E-12,   1.3320027E-11
     +,   1.8546772E-11,   2.5724605E-11,   3.5542434E-11
     +,   4.8917342E-11,   6.7064965E-11,   9.1589077E-11
     +,   1.2459857E-10,   1.6884798E-10,   2.2792837E-10
     +,   3.0649155E-10,   4.1053996E-10,   5.4778526E-10
     +,   7.2808570E-10,   9.6398856E-10,   1.2713901E-09
     +,   1.6703344E-09,   2.1859732E-09,   2.8497313E-09
     +,   3.7006715E-09,   4.7871205E-09,   6.1685603E-09
     +,   7.9179818E-09,   1.0124160E-08,   1.2895035E-08
     +,   1.6360762E-08,   2.0677696E-08,   2.6032614E-08
     +,   3.2647609E-08,   4.0785171E-08,   5.0754043E-08
     +,   6.2915383E-08,   7.7689123E-08,   9.5561205E-08
     +,   1.1709025E-07,   1.4291504E-07,   1.7376088E-07
     +,   2.1044896E-07,   2.5389730E-07,   3.0513340E-07
     +,   3.6529286E-07,   4.3562514E-07,   5.1749493E-07
     +,   6.1238120E-07,   7.2187458E-07,   8.4767390E-07
     +,   9.9156682E-07,   1.1554384E-06,   1.3412485E-06
     +,   1.5509928E-06,   1.7867280E-06,   2.0504963E-06
     +,   2.3443579E-06,   2.6703051E-06,   3.0303097E-06
     +,   3.4262187E-06,   3.8598328E-06,   4.3327886E-06
     +,   4.8466532E-06,   5.4028960E-06,   6.0028765E-06
     +,   6.6478974E-06,   7.3393221E-06,   8.0786031E-06
     +,   8.8673096E-06,   9.7074053E-06,   1.0601183E-05
     +,   1.1551629E-05,   1.2562349E-05,   1.3637988E-05
     +,   1.4784107E-05,   1.6007629E-05,   1.7316639E-05
     +,   1.8720741E-05,   2.0230988E-05,   2.1859752E-05
     +,   2.3620656E-05,   2.5528569E-05,   2.7599226E-05
     +,   2.9848665E-05,   3.2293312E-05,   3.4948938E-05
     +,   3.7830770E-05,   4.0952327E-05,   4.4325694E-05
     +,   4.7960315E-05,   5.1863561E-05,   5.6039706E-05
     +,   6.0490849E-05,   6.5216867E-05,   7.0215683E-05
     +,   7.5484473E-05,   8.1021069E-05,   8.6825232E-05
     +,   9.2899572E-05,   9.9252713E-05,   1.0589943E-04
     +,   1.1286396E-04,   1.2017939E-04,   1.2789025E-04
     +,   1.3605041E-04,   1.4472392E-04,   1.5398036E-04
     +,   1.6389314E-04,   1.7453366E-04,   1.8596399E-04
     +,   1.9823018E-04,   2.1135503E-04,   2.2532948E-04
     +,   2.4010349E-04,   2.5558317E-04,   2.7162308E-04
     +,   2.8802891E-04,   3.0455517E-04,   3.2091528E-04
     +,   3.3678641E-04,   3.5182614E-04,   3.6568337E-04
     +,   3.7801909E-04,   3.8852161E-04,   3.9692339E-04
     +,   4.0301718E-04,   4.0666806E-04,   4.0782141E-04
     +,   4.0650656E-04,   4.0283668E-04,   3.9700241E-04
     +,   3.8926178E-04,   3.7992813E-04,   3.6935188E-04
     +,   3.5790354E-04,   3.4595665E-04,   3.3386910E-04
     +,   3.2196677E-04,   3.1053144E-04,   2.9979201E-04
     +,   2.8991760E-04,   2.8101599E-04,   2.7313709E-04
     +,   2.6627962E-04,   2.6040003E-04,   2.5542450E-04
     +,   2.5126271E-04,   2.4782127E-04,   2.4501575E-04
     +,   2.4278137E-04,   2.4108042E-04,   2.3990562E-04
     +,   2.3927989E-04,   2.3925187E-04,   2.3988819E-04
     +,   2.4126243E-04,   2.4344312E-04,   2.4648086E-04
     +,   2.5039644E-04,   2.5517109E-04,   2.6074125E-04
     +,   2.6699578E-04,   2.7377793E-04,   2.8089352E-04
     +,   2.8812056E-04,   2.9522239E-04,   3.0196353E-04
     +,   3.0812484E-04,   3.1351767E-04,   3.1799456E-04
     +,   3.2145804E-04,   3.2386449E-04,   3.2522297E-04
     +,   3.2559046E-04,   3.2506339E-04,   3.2376638E-04
     +,   3.2183947E-04,   3.1942490E-04,   3.1665523E-04
     +,   3.1364249E-04,   3.1047166E-04,   3.0719591E-04
     +,   3.0383538E-04,   3.0037996E-04,   2.9679420E-04
     +,   2.9302444E-04,   2.8900648E-04,   2.8467423E-04
     +,   2.7996805E-04,   2.7484103E-04,   2.6926375E-04
     +,   2.6322706E-04,   2.5674410E-04,   2.4984727E-04
     +,   2.4258609E-04,   2.3502378E-04,   2.2723178E-04
     +,   2.1928409E-04,   2.1125315E-04,   2.0320619E-04
     +,   1.9520146E-04,   1.8728564E-04,   1.7949333E-04
     +,   1.7184780E-04,   1.6436126E-04,   1.5703618E-04
     +,   1.4986788E-04,   1.4284754E-04,   1.3596326E-04
     +,   1.2920274E-04,   1.2255569E-04,   1.1601460E-04
     +,   1.0957547E-04,   1.0323847E-04,   9.7008618E-05
     +,   9.0894893E-05,   8.4909356E-05,   7.9066638E-05
     +,   7.3383657E-05,   6.7877976E-05,   6.2566825E-05
     +,   5.7466441E-05,   5.2592022E-05,   4.7956077E-05
     +,   4.3568580E-05,   3.9436967E-05,   3.5565739E-05
     +,   3.1956246E-05,   2.8607074E-05,   2.5514497E-05
     +,   2.2672448E-05,   2.0072710E-05,   1.7705419E-05
     +,   1.5559563E-05,   1.3623118E-05,   1.1883220E-05
     +,   1.0326637E-05,   8.9400983E-06,   7.7102486E-06
     +,   6.6239663E-06,   5.6685876E-06,   4.8319257E-06
     +,   4.1023218E-06,   3.4687848E-06,   2.9210587E-06
     +,   2.4495996E-06,   2.0455636E-06,   1.7008440E-06
     +,   1.4080724E-06,   1.1605682E-06,   9.5229609E-07
     +,   7.7785796E-07,   6.3246375E-07,   5.1185935E-07
     +,   4.1230501E-07,   3.3053681E-07,   2.6371566E-07
     +,   2.0938393E-07,   1.6543184E-07,   1.3006137E-07
     +,   1.0174604E-07,   7.9196781E-08,   6.1333779E-08
     +,   4.7259338E-08,   3.6228560E-08,   2.7630348E-08
     +,   2.0964015E-08,   1.5823915E-08,   1.1881936E-08
     +,   8.8755314E-09,   6.5950778E-09,   4.8749005E-09
     +,   3.5843999E-09,   2.6216576E-09,   1.9073672E-09
     +,   1.3803307E-09,   9.9363540E-10,   7.1146433E-10
     +,   5.0671950E-10,   3.5896974E-10,   2.5294847E-10
     +,   1.7728706E-10,   1.2359509E-10,   8.5702320E-11
     +,   5.9109773E-11,   4.0550011E-11,   2.7669129E-11
     +,   1.8778526E-11,   1.2676518E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_ww_mass = Yx/0.00757575
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_asha_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.6891762E-06,   6.8133463E-06
     +,   6.9376333E-06,   7.0620636E-06,   7.1866762E-06
     +,   7.3115152E-06,   7.4366349E-06,   7.5620987E-06
     +,   7.6879778E-06,   7.8143585E-06,   7.9413303E-06
     +,   8.0689933E-06,   8.1974576E-06,   8.3268442E-06
     +,   8.4572821E-06,   8.5889105E-06,   8.7218759E-06
     +,   8.8563365E-06,   8.9924579E-06,   9.1304128E-06
     +,   9.2703867E-06,   9.4125708E-06,   9.5571586E-06
     +,   9.7043685E-06,   9.8544015E-06,   1.0007486E-05
     +,   1.0163847E-05,   1.0323718E-05,   1.0487339E-05
     +,   1.0654954E-05,   1.0826813E-05,   1.1003175E-05
     +,   1.1184298E-05,   1.1370453E-05,   1.1561913E-05
     +,   1.1758961E-05,   1.1961889E-05,   1.2170990E-05
     +,   1.2386592E-05,   1.2609006E-05,   1.2838590E-05
     +,   1.3075711E-05,   1.3320754E-05,   1.3574147E-05
     +,   1.3836353E-05,   1.4107875E-05,   1.4389272E-05
     +,   1.4681162E-05,   1.4984227E-05,   1.5299240E-05
     +,   1.5627049E-05,   1.5968622E-05,   1.6325026E-05
     +,   1.6697477E-05,   1.7087294E-05,   1.7495984E-05
     +,   1.7925200E-05,   1.8376779E-05,   1.8852730E-05
     +,   1.9355262E-05,   1.9886787E-05,   2.0449921E-05
     +,   2.1047455E-05,   2.1682421E-05,   2.2358043E-05
     +,   2.3077664E-05,   2.3844888E-05,   2.4663343E-05
     +,   2.5536898E-05,   2.6469375E-05,   2.7464752E-05
     +,   2.8526874E-05,   2.9659659E-05,   3.0866759E-05
     +,   3.2151755E-05,   3.3517979E-05,   3.4968343E-05
     +,   3.6505342E-05,   3.8131082E-05,   3.9847120E-05
     +,   4.1654177E-05,   4.3552471E-05,   4.5541168E-05
     +,   4.7618822E-05,   4.9782731E-05,   5.2029493E-05
     +,   5.4354365E-05,   5.6751782E-05,   5.9214835E-05
     +,   6.1735642E-05,   6.4305386E-05,   6.6913970E-05
     +,   6.9550391E-05,   7.2202973E-05,   7.4859337E-05
     +,   7.7506360E-05,   8.0130907E-05,   8.2719438E-05
     +,   8.5258951E-05,   8.7736567E-05,   9.0140617E-05
     +,   9.2460177E-05,   9.4686213E-05,   9.6811193E-05
     +,   9.8830002E-05,   1.0074007E-04,   1.0254149E-04
     +,   1.0423743E-04,   1.0583438E-04,   1.0734229E-04
     +,   1.0877426E-04,   1.1014698E-04,   1.1148018E-04
     +,   1.1279674E-04,   1.1412192E-04,   1.1548346E-04
     +,   1.1691052E-04,   1.1843361E-04,   1.2008352E-04
     +,   1.2189110E-04,   1.2388655E-04,   1.2609872E-04
     +,   1.2855465E-04,   1.3127962E-04,   1.3429666E-04
     +,   1.3762615E-04,   1.4128665E-04,   1.4529387E-04
     +,   1.4966185E-04,   1.5440182E-04,   1.5952306E-04
     +,   1.6503119E-04,   1.7092876E-04,   1.7721257E-04
     +,   1.8387374E-04,   1.9089556E-04,   1.9825166E-04
     +,   2.0590532E-04,   2.1381011E-04,   2.2191035E-04
     +,   2.3014405E-04,   2.3844883E-04,   2.4677097E-04
     +,   2.5507659E-04,   2.6336551E-04,   2.7168961E-04
     +,   2.8017047E-04,   2.8901579E-04,   2.9853403E-04
     +,   3.0914249E-04,   3.2136496E-04,   3.3581693E-04
     +,   3.5318069E-04,   3.7417348E-04,   3.9951951E-04
     +,   4.2993960E-04,   4.6618420E-04,   5.0911424E-04
     +,   5.5980560E-04,   6.1962049E-04,   6.9017668E-04
     +,   7.7310292E-04,   8.6957304E-04,   9.7974448E-04
     +,   1.1023624E-03,   1.2348455E-03,   1.3741048E-03
     +,   1.5180459E-03,   1.6672156E-03,   1.8256677E-03
     +,   2.0001656E-03,   2.1973494E-03,   2.4194899E-03
     +,   2.6604407E-03,   2.9038782E-03,   3.1253807E-03
     +,   3.2980640E-03,   3.3999030E-03,   3.4197944E-03
     +,   3.3598568E-03,   3.2333848E-03,   3.0598498E-03
     +,   2.8594048E-03,   2.6488604E-03,   2.4399913E-03
     +,   2.2396403E-03,   2.0507467E-03,   1.8737140E-03
     +,   1.7078515E-03,   1.5526685E-03,   1.4086798E-03
     +,   1.2775429E-03,   1.1614390E-03,   1.0620443E-03
     +,   9.7964203E-04,   9.1278926E-04,   8.5861702E-04
     +,   8.1355049E-04,   7.7411951E-04,   7.3757092E-04
     +,   7.0214539E-04,   6.6703541E-04,   6.3214841E-04
     +,   5.9780700E-04,   5.6448195E-04,   5.3260062E-04
     +,   5.0245773E-04,   4.7419802E-04,   4.4784101E-04
     +,   4.2332127E-04,   4.0052971E-04,   3.7934078E-04
     +,   3.5962285E-04,   3.4123848E-04,   3.2404391E-04
     +,   3.0788739E-04,   2.9261009E-04,   2.7805014E-04
     +,   2.6405201E-04,   2.5047731E-04,   2.3721026E-04
     +,   2.2416443E-04,   2.1128633E-04,   1.9855327E-04
     +,   1.8596851E-04,   1.7355692E-04,   1.6135922E-04
     +,   1.4942483E-04,   1.3780578E-04,   1.2655335E-04
     +,   1.1571563E-04,   1.0533502E-04,   9.5446609E-05
     +,   8.6078689E-05,   7.7253688E-05,   6.8986708E-05
     +,   6.1286657E-05,   5.4157244E-05,   4.7596452E-05
     +,   4.1596508E-05,   3.6144687E-05,   3.1223906E-05
     +,   2.6812728E-05,   2.2885655E-05,   1.9414101E-05
     +,   1.6367263E-05,   1.3712565E-05,   1.1416260E-05
     +,   9.4444085E-06,   7.7636523E-06,   6.3414450E-06
     +,   5.1467614E-06,   4.1505409E-06,   3.3258582E-06
     +,   2.6480759E-06,   2.0950056E-06,   1.6469328E-06
     +,   1.2865059E-06,   9.9861063E-07,   7.7025101E-07
     +,   5.9037916E-07,   4.4968036E-07,   3.4037279E-07
     +,   2.5602765E-07,   1.9138847E-07,   1.4218175E-07
     +,   1.0497202E-07,   7.7021930E-08,   5.6166318E-08
     +,   4.0705974E-08,   2.9319668E-08,   2.0988724E-08
     +,   1.4932928E-08,   1.0559205E-08,   7.4205944E-09
     +,   5.1829381E-09,   3.5977350E-09,   2.4820193E-09
     +,   1.7017210E-09,   1.1595312E-09,   7.8518297E-10
     +,   5.2839166E-10,   3.5336101E-10,   2.3483374E-10
     +,   1.5508185E-10,   1.0177021E-10,   6.6362631E-11
     +,   4.2998383E-11,   2.7682669E-11,   1.7707891E-11
     +,   1.1254607E-11,   7.1067948E-12,   4.4586054E-12
     +,   2.7789630E-12,   1.7207881E-12,   1.0585465E-12
     +,   6.4689541E-13,   3.9271578E-13,   2.3683684E-13
     +,   1.4188208E-13,   8.4435788E-14
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_asha_zz_mass = Yx/0.0236101764705882
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0031508E-05,   2.0352325E-05
     +,   2.0663481E-05,   2.0965801E-05,   2.1260326E-05
     +,   2.1548280E-05,   2.1831111E-05,   2.2110451E-05
     +,   2.2388153E-05,   2.2666267E-05,   2.2947041E-05
     +,   2.3232906E-05,   2.3526487E-05,   2.3830575E-05
     +,   2.4148136E-05,   2.4482284E-05,   2.4836278E-05
     +,   2.5213520E-05,   2.5617510E-05,   2.6051875E-05
     +,   2.6520325E-05,   2.7026663E-05,   2.7574748E-05
     +,   2.8168542E-05,   2.8811988E-05,   2.9509139E-05
     +,   3.0264040E-05,   3.1080763E-05,   3.1963405E-05
     +,   3.2916061E-05,   3.3942812E-05,   3.5047720E-05
     +,   3.6234836E-05,   3.7508133E-05,   3.8871553E-05
     +,   4.0328912E-05,   4.1883945E-05,   4.3540174E-05
     +,   4.5301098E-05,   4.7169735E-05,   4.9149061E-05
     +,   5.1241583E-05,   5.3449428E-05,   5.5774279E-05
     +,   5.8217243E-05,   6.0778802E-05,   6.3458727E-05
     +,   6.6255998E-05,   6.9168644E-05,   7.2193761E-05
     +,   7.5327327E-05,   7.8564182E-05,   8.1897851E-05
     +,   8.5320760E-05,   8.8823595E-05,   9.2396011E-05
     +,   9.6026000E-05,   9.9700163E-05,   1.0340367E-04
     +,   1.0712028E-04,   1.1083246E-04,   1.1452146E-04
     +,   1.1816713E-04,   1.2174869E-04,   1.2524451E-04
     +,   1.2863192E-04,   1.3188834E-04,   1.3499055E-04
     +,   1.3791572E-04,   1.4064100E-04,   1.4314448E-04
     +,   1.4540476E-04,   1.4740186E-04,   1.4911692E-04
     +,   1.5053296E-04,   1.5163478E-04,   1.5240929E-04
     +,   1.5284578E-04,   1.5293602E-04,   1.5267442E-04
     +,   1.5205811E-04,   1.5108704E-04,   1.4976403E-04
     +,   1.4809471E-04,   1.4608754E-04,   1.4375351E-04
     +,   1.4110655E-04,   1.3816250E-04,   1.3493994E-04
     +,   1.3145906E-04,   1.2774183E-04,   1.2381190E-04
     +,   1.1969418E-04,   1.1541419E-04,   1.1099804E-04
     +,   1.0647264E-04,   1.0186424E-04,   9.7199474E-05
     +,   9.2503818E-05,   8.7802568E-05,   8.3119361E-05
     +,   7.8477220E-05,   7.3897143E-05,   6.9399161E-05
     +,   6.5001128E-05,   6.0719132E-05,   5.6567704E-05
     +,   5.2559433E-05,   4.8704736E-05,   4.5012162E-05
     +,   4.1488769E-05,   3.8139347E-05,   3.4967419E-05
     +,   3.1974487E-05,   2.9160930E-05,   2.6525389E-05
     +,   2.4065586E-05,   2.1777818E-05,   1.9657695E-05
     +,   1.7699766E-05,   1.5897895E-05,   1.4245490E-05
     +,   1.2735496E-05,   1.1360425E-05,   1.0112582E-05
     +,   8.9842888E-06,   7.9676784E-06,   7.0550855E-06
     +,   6.2388499E-06,   5.5116170E-06,   4.8661791E-06
     +,   4.2957040E-06,   3.7936036E-06,   3.3537067E-06
     +,   2.9701582E-06,   2.6374851E-06,   2.3506209E-06
     +,   2.1048693E-06,   1.8958947E-06,   1.7197285E-06
     +,   1.5727682E-06,   1.4517432E-06,   1.3536943E-06
     +,   1.2759663E-06,   1.2161920E-06,   1.1722581E-06
     +,   1.1422934E-06,   1.1246506E-06,   1.1178821E-06
     +,   1.1207219E-06,   1.1320705E-06,   1.1509746E-06
     +,   1.1766131E-06,   1.2082825E-06,   1.2453830E-06
     +,   1.2874041E-06,   1.3339139E-06,   1.3845525E-06
     +,   1.4390198E-06,   1.4970620E-06,   1.5584750E-06
     +,   1.6230919E-06,   1.6907741E-06,   1.7614078E-06
     +,   1.8349077E-06,   1.9112060E-06,   1.9902443E-06
     +,   2.0719776E-06,   2.1563735E-06,   2.2434087E-06
     +,   2.3330588E-06,   2.4253043E-06,   2.5201323E-06
     +,   2.6175328E-06,   2.7174867E-06,   2.8199831E-06
     +,   2.9250104E-06,   3.0325496E-06,   3.1425777E-06
     +,   3.2550768E-06,   3.3700253E-06,   3.4873917E-06
     +,   3.6071408E-06,   3.7292400E-06,   3.8536546E-06
     +,   3.9803340E-06,   4.1092285E-06,   4.2402867E-06
     +,   4.3734549E-06,   4.5086636E-06,   4.6458481E-06
     +,   4.7849417E-06,   4.9258624E-06,   5.0685230E-06
     +,   5.2128430E-06,   5.3587328E-06,   5.5060927E-06
     +,   5.6548170E-06,   5.8048040E-06,   5.9559466E-06
     +,   6.1081264E-06,   6.2612171E-06,   6.4151009E-06
     +,   6.5696536E-06,   6.7247338E-06,   6.8802087E-06
     +,   7.0359447E-06,   7.1917925E-06,   7.3475999E-06
     +,   7.5032217E-06,   7.6585111E-06,   7.8133044E-06
     +,   7.9674419E-06,   8.1207645E-06,   8.2731167E-06
     +,   8.4243293E-06,   8.5742313E-06,   8.7226599E-06
     +,   8.8694542E-06,   9.0144358E-06,   9.1574420E-06
     +,   9.2983082E-06,   9.4368625E-06,   9.5729329E-06
     +,   9.7063603E-06,   9.8369810E-06,   9.9646313E-06
     +,   1.0089147E-05,   1.0210370E-05,   1.0328154E-05
     +,   1.0442340E-05,   1.0552776E-05,   1.0659322E-05
     +,   1.0761839E-05,   1.0860184E-05,   1.0954231E-05
     +,   1.1043853E-05,   1.1128926E-05,   1.1209332E-05
     +,   1.1284963E-05,   1.1355717E-05,   1.1421494E-05
     +,   1.1482201E-05,   1.1537755E-05,   1.1588080E-05
     +,   1.1633102E-05,   1.1672760E-05,   1.1706996E-05
     +,   1.1735762E-05,   1.1759020E-05,   1.1776733E-05
     +,   1.1788879E-05,   1.1795439E-05,   1.1796405E-05
     +,   1.1791773E-05,   1.1781552E-05,   1.1765756E-05
     +,   1.1744408E-05,   1.1717538E-05,   1.1685182E-05
     +,   1.1647387E-05,   1.1604208E-05,   1.1555706E-05
     +,   1.1501946E-05,   1.1443007E-05,   1.1378970E-05
     +,   1.1309922E-05,   1.1235959E-05,   1.1157188E-05
     +,   1.1073714E-05,   1.0985646E-05,   1.0893111E-05
     +,   1.0796233E-05,   1.0695141E-05,   1.0589967E-05
     +,   1.0480856E-05,   1.0367946E-05,   1.0251390E-05
     +,   1.0131331E-05,   1.0007934E-05,   9.8813452E-06
     +,   9.7517341E-06,   9.6192543E-06,   9.4840761E-06
     +,   9.3463586E-06,   9.2062746E-06,   9.0639896E-06
     +,   8.9196656E-06,   8.7734807E-06,   8.6255932E-06
     +,   8.4761805E-06,   8.3253999E-06,   8.1734261E-06
     +,   8.0204163E-06,   7.8665425E-06,   7.7119557E-06
     +,   7.5568250E-06,   7.4012969E-06,   7.2455364E-06
     +,   7.0896845E-06,   6.9338994E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_eez_mass = Yx/0.002534
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.3897040E-09,   2.9617762E-09
     +,   3.6626491E-09,   4.5193231E-09,   5.5639862E-09
     +,   6.8349224E-09,   8.3775333E-09,   1.0245494E-08
     +,   1.2502110E-08,   1.5221939E-08,   1.8492328E-08
     +,   2.2415488E-08,   2.7110586E-08,   3.2716333E-08
     +,   3.9393566E-08,   4.7328285E-08,   5.6735015E-08
     +,   6.7860320E-08,   8.0987107E-08,   9.6438434E-08
     +,   1.1458280E-07,   1.3583876E-07,   1.6067976E-07
     +,   1.8964273E-07,   2.2332816E-07,   2.6241386E-07
     +,   3.0765545E-07,   3.5989618E-07,   4.2007323E-07
     +,   4.8922357E-07,   5.6849217E-07,   6.5913798E-07
     +,   7.6254094E-07,   8.8020658E-07,   1.0137736E-06
     +,   1.1650161E-06,   1.3358502E-06,   1.5283310E-06
     +,   1.7446724E-06,   1.9872073E-06,   2.2584372E-06
     +,   2.5609897E-06,   2.8976260E-06,   3.2712353E-06
     +,   3.6848173E-06,   4.1414733E-06,   4.6443897E-06
     +,   5.1968127E-06,   5.8020350E-06,   6.4633623E-06
     +,   7.1840832E-06,   7.9674419E-06,   8.8165925E-06
     +,   9.7346128E-06,   1.0724329E-05,   1.1788460E-05
     +,   1.2929415E-05,   1.4149313E-05,   1.5449938E-05
     +,   1.6832673E-05,   1.8298450E-05,   1.9847730E-05
     +,   2.1480339E-05,   2.3195651E-05,   2.4992400E-05
     +,   2.6868496E-05,   2.8821383E-05,   3.0847532E-05
     +,   3.2942931E-05,   3.5102530E-05,   3.7320799E-05
     +,   3.9591145E-05,   4.1906536E-05,   4.4258890E-05
     +,   4.6639678E-05,   4.9039685E-05,   5.1448955E-05
     +,   5.3856962E-05,   5.6252906E-05,   5.8625523E-05
     +,   6.0963081E-05,   6.3253909E-05,   6.5485947E-05
     +,   6.7647408E-05,   6.9726389E-05,   7.1711453E-05
     +,   7.3591305E-05,   7.5355383E-05,   7.6993456E-05
     +,   7.8496247E-05,   7.9855294E-05,   8.1062986E-05
     +,   8.2112805E-05,   8.2999475E-05,   8.3718944E-05
     +,   8.4268424E-05,   8.4646592E-05,   8.4853520E-05
     +,   8.4890817E-05,   8.4761574E-05,   8.4470412E-05
     +,   8.4023493E-05,   8.3428451E-05,   8.2694423E-05
     +,   8.1831946E-05,   8.0852842E-05,   7.9770311E-05
     +,   7.8598699E-05,   7.7353361E-05,   7.6050579E-05
     +,   7.4707539E-05,   7.3341937E-05,   7.1972099E-05
     +,   7.0616523E-05,   6.9294008E-05,   6.8023110E-05
     +,   6.6822366E-05,   6.5709646E-05,   6.4702399E-05
     +,   6.3817082E-05,   6.3069150E-05,   6.2472878E-05
     +,   6.2041123E-05,   6.1785089E-05,   6.1714272E-05
     +,   6.1836217E-05,   6.2156461E-05,   6.2678351E-05
     +,   6.3403000E-05,   6.4329157E-05,   6.5453292E-05
     +,   6.6769360E-05,   6.8269168E-05,   6.9942020E-05
     +,   7.1775146E-05,   7.3753756E-05,   7.5860975E-05
     +,   7.8078214E-05,   8.0385485E-05,   8.2761588E-05
     +,   8.5184191E-05,   8.7630273E-05,   9.0076624E-05
     +,   9.2500035E-05,   9.4877345E-05,   9.7186334E-05
     +,   9.9405785E-05,   1.0151565E-04,   1.0349757E-04
     +,   1.0533524E-04,   1.0701453E-04,   1.0852366E-04
     +,   1.0985343E-04,   1.1099751E-04,   1.1195241E-04
     +,   1.1271738E-04,   1.1329462E-04,   1.1368914E-04
     +,   1.1390864E-04,   1.1396332E-04,   1.1386566E-04
     +,   1.1363022E-04,   1.1327325E-04,   1.1281251E-04
     +,   1.1226667E-04,   1.1165516E-04,   1.1099768E-04
     +,   1.1031389E-04,   1.0962282E-04,   1.0894272E-04
     +,   1.0829055E-04,   1.0768184E-04,   1.0713008E-04
     +,   1.0664674E-04,   1.0624099E-04,   1.0591944E-04
     +,   1.0568609E-04,   1.0554233E-04,   1.0548683E-04
     +,   1.0551554E-04,   1.0562200E-04,   1.0579725E-04
     +,   1.0603011E-04,   1.0630748E-04,   1.0661449E-04
     +,   1.0693481E-04,   1.0725101E-04,   1.0754490E-04
     +,   1.0779785E-04,   1.0799107E-04,   1.0810606E-04
     +,   1.0812494E-04,   1.0803061E-04,   1.0780730E-04
     +,   1.0744053E-04,   1.0691764E-04,   1.0622780E-04
     +,   1.0536223E-04,   1.0431434E-04,   1.0307976E-04
     +,   1.0165644E-04,   1.0004470E-04,   9.8247030E-05
     +,   9.6268050E-05,   9.4114686E-05,   9.1795591E-05
     +,   8.9321191E-05,   8.6703665E-05,   8.3956569E-05
     +,   8.1094462E-05,   7.8132798E-05,   7.5087948E-05
     +,   7.1976705E-05,   6.8815956E-05,   6.5622517E-05
     +,   6.2413230E-05,   5.9204536E-05,   5.6012082E-05
     +,   5.2850723E-05,   4.9734757E-05,   4.6677156E-05
     +,   4.3689757E-05,   4.0783434E-05,   3.7967780E-05
     +,   3.5250938E-05,   3.2639768E-05,   3.0140032E-05
     +,   2.7756205E-05,   2.5491416E-05,   2.3347622E-05
     +,   2.1325854E-05,   1.9426101E-05,   1.7647304E-05
     +,   1.5987562E-05,   1.4444407E-05,   1.3014533E-05
     +,   1.1694110E-05,   1.0478913E-05,   9.3643412E-06
     +,   8.3454188E-06,   7.4169816E-06,   6.5737863E-06
     +,   5.8105197E-06,   5.1218090E-06,   4.5023467E-06
     +,   3.9469646E-06,   3.4506270E-06,   3.0084402E-06
     +,   2.6157204E-06,   2.2680435E-06,   1.9611912E-06
     +,   1.6911983E-06,   1.4543787E-06,   1.2472990E-06
     +,   1.0667727E-06,   9.0986919E-07,   7.7391644E-07
     +,   6.5647663E-07,   5.5533206E-07,   4.6848064E-07
     +,   3.9412919E-07,   3.3067076E-07,   2.7666934E-07
     +,   2.3085096E-07,   1.9209348E-07,   1.5940489E-07
     +,   1.3191548E-07,   1.0886740E-07,   8.9600562E-08
     +,   7.3541266E-08,   6.0194473E-08,   4.9134901E-08
     +,   3.9997655E-08,   3.2470318E-08,   2.6287134E-08
     +,   2.1223222E-08,   1.7087704E-08,   1.3720407E-08
     +,   1.0986398E-08,   8.7731387E-09,   6.9864821E-09
     +,   5.5484777E-09,   4.3943333E-09,   3.4707544E-09
     +,   2.7337519E-09,   2.1473634E-09,   1.6821304E-09
     +,   1.3140696E-09,   1.0237371E-09,   7.9535761E-10
     +,   6.1623751E-10,   4.7614418E-10,   3.6689329E-10
     +,   2.8193264E-10,   2.1605412E-10,   1.6511394E-10
     +,   1.2583927E-10,   9.5643028E-11,   7.2493893E-11
     +,   5.4796667E-11,   4.1306483E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_qq_mass = Yx/0.00322
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0489883E-06,   2.2606430E-06
     +,   2.4912049E-06,   2.7420388E-06,   3.0145761E-06
     +,   3.3103058E-06,   3.6307813E-06,   3.9776082E-06
     +,   4.3524442E-06,   4.7570111E-06,   5.1930547E-06
     +,   5.6623639E-06,   6.1667574E-06,   6.7080700E-06
     +,   7.2881458E-06,   7.9088277E-06,   8.5719412E-06
     +,   9.2792852E-06,   1.0032610E-05,   1.0833610E-05
     +,   1.1683899E-05,   1.2584997E-05,   1.3538296E-05
     +,   1.4545116E-05,   1.5606513E-05,   1.6723490E-05
     +,   1.7896793E-05,   1.9126968E-05,   2.0414351E-05
     +,   2.1759017E-05,   2.3160797E-05,   2.4619243E-05
     +,   2.6133623E-05,   2.7702921E-05,   2.9325814E-05
     +,   3.1000676E-05,   3.2725591E-05,   3.4498284E-05
     +,   3.6316313E-05,   3.8176768E-05,   4.0076618E-05
     +,   4.2012503E-05,   4.3980825E-05,   4.5977762E-05
     +,   4.7999325E-05,   5.0041312E-05,   5.2099414E-05
     +,   5.4169232E-05,   5.6246256E-05,   5.8325957E-05
     +,   6.0403836E-05,   6.2475374E-05,   6.4536158E-05
     +,   6.6582012E-05,   6.8608642E-05,   7.0612259E-05
     +,   7.2589108E-05,   7.4535783E-05,   7.6449178E-05
     +,   7.8326513E-05,   8.0165417E-05,   8.1963924E-05
     +,   8.3720421E-05,   8.5433923E-05,   8.7103843E-05
     +,   8.8730048E-05,   9.0313100E-05,   9.1853894E-05
     +,   9.3354101E-05,   9.4815754E-05,   9.6241674E-05
     +,   9.7635006E-05,   9.8999648E-05,   1.0033994E-04
     +,   1.0166078E-04,   1.0296764E-04,   1.0426635E-04
     +,   1.0556319E-04,   1.0686496E-04,   1.0817876E-04
     +,   1.0951190E-04,   1.1087208E-04,   1.1226701E-04
     +,   1.1370469E-04,   1.1519299E-04,   1.1673989E-04
     +,   1.1835305E-04,   1.2004015E-04,   1.2180836E-04
     +,   1.2366455E-04,   1.2561520E-04,   1.2766612E-04
     +,   1.2982235E-04,   1.3208835E-04,   1.3446777E-04
     +,   1.3696306E-04,   1.3957599E-04,   1.4230680E-04
     +,   1.4515499E-04,   1.4811830E-04,   1.5119357E-04
     +,   1.5437575E-04,   1.5765871E-04,   1.6103435E-04
     +,   1.6449328E-04,   1.6802434E-04,   1.7161462E-04
     +,   1.7524947E-04,   1.7891264E-04,   1.8258642E-04
     +,   1.8625095E-04,   1.8988553E-04,   1.9346736E-04
     +,   1.9697302E-04,   2.0037749E-04,   2.0365516E-04
     +,   2.0677962E-04,   2.0972439E-04,   2.1246253E-04
     +,   2.1496779E-04,   2.1721447E-04,   2.1917783E-04
     +,   2.2083467E-04,   2.2216360E-04,   2.2314551E-04
     +,   2.2376380E-04,   2.2400494E-04,   2.2385856E-04
     +,   2.2331793E-04,   2.2238003E-04,   2.2104564E-04
     +,   2.1931982E-04,   2.1721133E-04,   2.1473317E-04
     +,   2.1190199E-04,   2.0873797E-04,   2.0526495E-04
     +,   2.0150968E-04,   1.9750146E-04,   1.9327152E-04
     +,   1.8885329E-04,   1.8428121E-04,   1.7959021E-04
     +,   1.7481533E-04,   1.6999175E-04,   1.6515328E-04
     +,   1.6033246E-04,   1.5556048E-04,   1.5086647E-04
     +,   1.4627687E-04,   1.4181553E-04,   1.3750391E-04
     +,   1.3336056E-04,   1.2940084E-04,   1.2563729E-04
     +,   1.2207986E-04,   1.1873578E-04,   1.1560958E-04
     +,   1.1270349E-04,   1.1001791E-04,   1.0755119E-04
     +,   1.0530010E-04,   1.0326027E-04,   1.0142632E-04
     +,   9.9791941E-05,   9.8350356E-05,   9.7094671E-05
     +,   9.6017851E-05,   9.5112926E-05,   9.4373281E-05
     +,   9.3792842E-05,   9.3366063E-05,   9.3088107E-05
     +,   9.2954848E-05,   9.2963011E-05,   9.3110168E-05
     +,   9.3394752E-05,   9.3816081E-05,   9.4374191E-05
     +,   9.5069954E-05,   9.5904950E-05,   9.6881289E-05
     +,   9.8001554E-05,   9.9268735E-05,   1.0068607E-04
     +,   1.0225670E-04,   1.0398370E-04,   1.0586985E-04
     +,   1.0791740E-04,   1.1012769E-04,   1.1250130E-04
     +,   1.1503763E-04,   1.1773457E-04,   1.2058836E-04
     +,   1.2359380E-04,   1.2674369E-04,   1.3002865E-04
     +,   1.3343726E-04,   1.3695598E-04,   1.4056932E-04
     +,   1.4425935E-04,   1.4800603E-04,   1.5178784E-04
     +,   1.5558145E-04,   1.5936173E-04,   1.6310278E-04
     +,   1.6677771E-04,   1.7035900E-04,   1.7381889E-04
     +,   1.7713018E-04,   1.8026622E-04,   1.8320122E-04
     +,   1.8591086E-04,   1.8837268E-04,   1.9056641E-04
     +,   1.9247404E-04,   1.9408014E-04,   1.9537240E-04
     +,   1.9634143E-04,   1.9698078E-04,   1.9728733E-04
     +,   1.9726100E-04,   1.9690466E-04,   1.9622421E-04
     +,   1.9522819E-04,   1.9392747E-04,   1.9233538E-04
     +,   1.9046721E-04,   1.8833966E-04,   1.8597080E-04
     +,   1.8337977E-04,   1.8058649E-04,   1.7761100E-04
     +,   1.7447346E-04,   1.7119406E-04,   1.6779231E-04
     +,   1.6428709E-04,   1.6069663E-04,   1.5703814E-04
     +,   1.5332761E-04,   1.4957978E-04,   1.4580842E-04
     +,   1.4202605E-04,   1.3824376E-04,   1.3447131E-04
     +,   1.3071764E-04,   1.2699050E-04,   1.2329643E-04
     +,   1.1964091E-04,   1.1602904E-04,   1.1246471E-04
     +,   1.0895111E-04,   1.0549113E-04,   1.0208712E-04
     +,   9.8740747E-05,   9.5453346E-05,   9.2226204E-05
     +,   8.9060282E-05,   8.5956272E-05,   8.2914601E-05
     +,   7.9935839E-05,   7.7020493E-05,   7.4168791E-05
     +,   7.1380884E-05,   6.8657217E-05,   6.5997883E-05
     +,   6.3402978E-05,   6.0872720E-05,   5.8407284E-05
     +,   5.6006655E-05,   5.3670767E-05,   5.1399653E-05
     +,   4.9193299E-05,   4.7051457E-05,   4.4973840E-05
     +,   4.2960284E-05,   4.1010251E-05,   3.9123439E-05
     +,   3.7299164E-05,   3.5536923E-05,   3.3835884E-05
     +,   3.2195385E-05,   3.0614439E-05,   2.9092220E-05
     +,   2.7627611E-05,   2.6219637E-05,   2.4867117E-05
     +,   2.3568808E-05,   2.2323558E-05,   2.1130021E-05
     +,   1.9986950E-05,   1.8892923E-05,   1.7846656E-05
     +,   1.6846689E-05,   1.5891699E-05,   1.4980231E-05
     +,   1.4110940E-05,   1.3282383E-05,   1.2493239E-05
     +,   1.1742088E-05,   1.1027628E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_ww_mass = Yx/0.00757575
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_ashz_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.9047436E-05,   2.9672938E-05
     +,   3.0291361E-05,   3.0901778E-05,   3.1503303E-05
     +,   3.2095049E-05,   3.2676151E-05,   3.3245760E-05
     +,   3.3803051E-05,   3.4347253E-05,   3.4877594E-05
     +,   3.5393357E-05,   3.5893856E-05,   3.6378464E-05
     +,   3.6846559E-05,   3.7297643E-05,   3.7731174E-05
     +,   3.8146751E-05,   3.8543989E-05,   3.8922568E-05
     +,   3.9282244E-05,   3.9622835E-05,   3.9944214E-05
     +,   4.0246363E-05,   4.0529289E-05,   4.0793126E-05
     +,   4.1038038E-05,   4.1264313E-05,   4.1472304E-05
     +,   4.1662446E-05,   4.1835261E-05,   4.1991370E-05
     +,   4.2131502E-05,   4.2256437E-05,   4.2367090E-05
     +,   4.2464464E-05,   4.2549673E-05,   4.2623906E-05
     +,   4.2688494E-05,   4.2744872E-05,   4.2794560E-05
     +,   4.2839227E-05,   4.2880642E-05,   4.2920696E-05
     +,   4.2961386E-05,   4.3004868E-05,   4.3053384E-05
     +,   4.3109307E-05,   4.3175158E-05,   4.3253542E-05
     +,   4.3347198E-05,   4.3459000E-05,   4.3591892E-05
     +,   4.3748947E-05,   4.3933320E-05,   4.4148270E-05
     +,   4.4397082E-05,   4.4683147E-05,   4.5009852E-05
     +,   4.5380624E-05,   4.5798879E-05,   4.6268007E-05
     +,   4.6791291E-05,   4.7371988E-05,   4.8013222E-05
     +,   4.8717891E-05,   4.9488797E-05,   5.0328374E-05
     +,   5.1238938E-05,   5.2222316E-05,   5.3280102E-05
     +,   5.4413405E-05,   5.5622982E-05,   5.6908957E-05
     +,   5.8271111E-05,   5.9708622E-05,   6.1220089E-05
     +,   6.2803447E-05,   6.4456181E-05,   6.6175162E-05
     +,   6.7956578E-05,   6.9796224E-05,   7.1689130E-05
     +,   7.3630166E-05,   7.5613447E-05,   7.7633085E-05
     +,   7.9682628E-05,   8.1755752E-05,   8.3845858E-05
     +,   8.5946653E-05,   8.8052060E-05,   9.0156267E-05
     +,   9.2254020E-05,   9.4340874E-05,   9.6413351E-05
     +,   9.8468663E-05,   1.0050553E-04,   1.0252372E-04
     +,   1.0452460E-04,   1.0651083E-04,   1.0848694E-04
     +,   1.1045876E-04,   1.1243402E-04,   1.1442175E-04
     +,   1.1643263E-04,   1.1847879E-04,   1.2057355E-04
     +,   1.2273128E-04,   1.2496740E-04,   1.2729825E-04
     +,   1.2974050E-04,   1.3231160E-04,   1.3502924E-04
     +,   1.3791177E-04,   1.4097769E-04,   1.4424653E-04
     +,   1.4773822E-04,   1.5147438E-04,   1.5547764E-04
     +,   1.5977302E-04,   1.6438792E-04,   1.6935232E-04
     +,   1.7469905E-04,   1.8046425E-04,   1.8668728E-04
     +,   1.9340885E-04,   2.0067228E-04,   2.0852007E-04
     +,   2.1699423E-04,   2.2613241E-04,   2.3596792E-04
     +,   2.4652513E-04,   2.5782059E-04,   2.6985849E-04
     +,   2.8263318E-04,   2.9612920E-04,   3.1032265E-04
     +,   3.2518621E-04,   3.4069727E-04,   3.5684404E-04
     +,   3.7363553E-04,   3.9111165E-04,   4.0935460E-04
     +,   4.2849599E-04,   4.4871951E-04,   4.7026380E-04
     +,   4.9341342E-04,   5.1848148E-04,   5.4578733E-04
     +,   5.7562575E-04,   6.0822716E-04,   6.4371381E-04
     +,   6.8205921E-04,   7.2305492E-04,   7.6628354E-04
     +,   8.1110431E-04,   8.5666688E-04,   9.0194197E-04
     +,   9.4577519E-04,   9.8694768E-04,   1.0242752E-03
     +,   1.0566937E-03,   1.0833467E-03,   1.1036749E-03
     +,   1.1174813E-03,   1.1249681E-03,   1.1267512E-03
     +,   1.1238419E-03,   1.1175931E-03,   1.1096179E-03
     +,   1.1016799E-03,   1.0955766E-03,   1.0929947E-03
     +,   1.0953849E-03,   1.1038353E-03,   1.1189759E-03
     +,   1.1409041E-03,   1.1691578E-03,   1.2027157E-03
     +,   1.2400623E-03,   1.2792721E-03,   1.3181415E-03
     +,   1.3543441E-03,   1.3856080E-03,   1.4098862E-03
     +,   1.4255140E-03,   1.4313413E-03,   1.4268175E-03
     +,   1.4120219E-03,   1.3876398E-03,   1.3548792E-03
     +,   1.3153447E-03,   1.2708834E-03,   1.2234183E-03
     +,   1.1747814E-03,   1.1265851E-03,   1.0801296E-03
     +,   1.0363471E-03,   9.9579140E-04,   9.5867127E-04
     +,   9.2490634E-04,   8.9420046E-04,   8.6611148E-04
     +,   8.4012648E-04,   8.1572228E-04,   7.9240353E-04
     +,   7.6973584E-04,   7.4736209E-04,   7.2500890E-04
     +,   7.0248160E-04,   6.7966391E-04,   6.5651099E-04
     +,   6.3303934E-04,   6.0931768E-04,   5.8545929E-04
     +,   5.6161277E-04,   5.3795049E-04,   5.1465776E-04
     +,   4.9192138E-04,   4.6992290E-04,   4.4882510E-04
     +,   4.2876645E-04,   4.0985851E-04,   3.9218069E-04
     +,   3.7577937E-04,   3.6067097E-04,   3.4684534E-04
     +,   3.3426928E-04,   3.2288968E-04,   3.1263861E-04
     +,   3.0343866E-04,   2.9520408E-04,   2.8784393E-04
     +,   2.8126387E-04,   2.7536845E-04,   2.7006087E-04
     +,   2.6524442E-04,   2.6082361E-04,   2.5670501E-04
     +,   2.5279785E-04,   2.4901578E-04,   2.4527826E-04
     +,   2.4151159E-04,   2.3765017E-04,   2.3363758E-04
     +,   2.2942788E-04,   2.2498578E-04,   2.2028683E-04
     +,   2.1531738E-04,   2.1007458E-04,   2.0456499E-04
     +,   1.9880367E-04,   1.9281375E-04,   1.8662459E-04
     +,   1.8027000E-04,   1.7378737E-04,   1.6721641E-04
     +,   1.6059807E-04,   1.5397226E-04,   1.4737784E-04
     +,   1.4085186E-04,   1.3442863E-04,   1.2813871E-04
     +,   1.2200902E-04,   1.1606312E-04,   1.1032016E-04
     +,   1.0479520E-04,   9.9499979E-05,   9.4442548E-05
     +,   8.9627341E-05,   8.5055784E-05,   8.0726873E-05
     +,   7.6637269E-05,   7.2781360E-05,   6.9151880E-05
     +,   6.5740598E-05,   6.2537794E-05,   5.9533450E-05
     +,   5.6716621E-05,   5.4076518E-05,   5.1601859E-05
     +,   4.9281833E-05,   4.7105514E-05,   4.5062607E-05
     +,   4.3142958E-05,   4.1337189E-05,   3.9636237E-05
     +,   3.8031609E-05,   3.6515572E-05,   3.5080746E-05
     +,   3.3720524E-05,   3.2428685E-05,   3.1199692E-05
     +,   3.0028379E-05,   2.8910197E-05,   2.7840915E-05
     +,   2.6816841E-05,   2.5834539E-05,   2.4891066E-05
     +,   2.3983654E-05,   2.3109955E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_ashz_zz_mass = Yx/0.0236101764705882
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  3.7982950E-13,   5.9724968E-13
     +,   9.3417787E-13,   1.4534796E-12,   2.2495467E-12
     +,   3.4632772E-12,   5.3037813E-12,   8.0796073E-12
     +,   1.2243294E-11,   1.8455069E-11,   2.7671919E-11
     +,   4.1273280E-11,   6.1235753E-11,   9.0374819E-11
     +,   1.3267699E-10,   1.9375387E-10,   2.8145639E-10
     +,   4.0670367E-10,   5.8458993E-10,   8.3585505E-10
     +,   1.1888213E-09,   1.6819317E-09,   2.3670308E-09
     +,   3.3136789E-09,   4.6144324E-09,   6.3919701E-09
     +,   8.8076000E-09,   1.2072195E-08,   1.6459673E-08
     +,   2.2323501E-08,   3.0116816E-08,   4.0416854E-08
     +,   5.3953748E-08,   7.1645182E-08,   9.4636476E-08
     +,   1.2434724E-07,   1.6252488E-07,   2.1130394E-07
     +,   2.7327826E-07,   3.5156469E-07,   4.4989702E-07
     +,   5.7270000E-07,   7.2518213E-07,   9.1342554E-07
     +,   1.1444722E-06,   1.4264059E-06,   1.7684274E-06
     +,   2.1809074E-06,   2.6754283E-06,   3.2647911E-06
     +,   3.9629931E-06,   4.7851690E-06,   5.7474599E-06
     +,   6.8669378E-06,   8.1611961E-06,   9.6483191E-06
     +,   1.1346330E-05,   1.3272881E-05,   1.5444750E-05
     +,   1.7877323E-05,   2.0584010E-05,   2.3575692E-05
     +,   2.6859807E-05,   3.0440182E-05,   3.4316214E-05
     +,   3.8481827E-05,   4.2925916E-05,   4.7630798E-05
     +,   5.2573090E-05,   5.7722315E-05,   6.3042178E-05
     +,   6.8489411E-05,   7.4015530E-05,   7.9565936E-05
     +,   8.5082000E-05,   9.0501395E-05,   9.5758856E-05
     +,   1.0078784E-04,   1.0552219E-04,   1.0989718E-04
     +,   1.1385062E-04,   1.1732528E-04,   1.2026925E-04
     +,   1.2263808E-04,   1.2439523E-04,   1.2551356E-04
     +,   1.2597561E-04,   1.2577440E-04,   1.2491335E-04
     +,   1.2340645E-04,   1.2127759E-04,   1.1856028E-04
     +,   1.1529672E-04,   1.1153652E-04,   1.0733552E-04
     +,   1.0275500E-04,   9.7859214E-05,   9.2715141E-05
     +,   8.7389766E-05,   8.1950035E-05,   7.6460157E-05
     +,   7.0981871E-05,   6.5572036E-05,   6.0283204E-05
     +,   5.5161800E-05,   5.0248171E-05,   4.5576704E-05
     +,   4.1175404E-05,   3.7065667E-05,   3.3262957E-05
     +,   2.9777444E-05,   2.6613665E-05,   2.3771980E-05
     +,   2.1248326E-05,   1.9035597E-05,   1.7123586E-05
     +,   1.5500184E-05,   1.4151425E-05,   1.3062449E-05
     +,   1.2217624E-05,   1.1601110E-05,   1.1197209E-05
     +,   1.0990566E-05,   1.0966350E-05,   1.1110460E-05
     +,   1.1409557E-05,   1.1851146E-05,   1.2423484E-05
     +,   1.3115659E-05,   1.3917374E-05,   1.4819028E-05
     +,   1.5811413E-05,   1.6885844E-05,   1.8033779E-05
     +,   1.9246974E-05,   2.0517267E-05,   2.1836424E-05
     +,   2.3196129E-05,   2.4588016E-05,   2.6003578E-05
     +,   2.7433991E-05,   2.8870254E-05,   3.0303272E-05
     +,   3.1723775E-05,   3.3122251E-05,   3.4489258E-05
     +,   3.5815345E-05,   3.7091060E-05,   3.8307127E-05
     +,   3.9454586E-05,   4.0524836E-05,   4.1509626E-05
     +,   4.2401269E-05,   4.3192758E-05,   4.3877775E-05
     +,   4.4450771E-05,   4.4907058E-05,   4.5242905E-05
     +,   4.5455548E-05,   4.5543205E-05,   4.5505152E-05
     +,   4.5341698E-05,   4.5054181E-05,   4.4644992E-05
     +,   4.4117463E-05,   4.3475873E-05,   4.2725402E-05
     +,   4.1872070E-05,   4.0922569E-05,   3.9884217E-05
     +,   3.8764960E-05,   3.7573202E-05,   3.6317604E-05
     +,   3.5007077E-05,   3.3650773E-05,   3.2257783E-05
     +,   3.0837098E-05,   2.9397639E-05,   2.7948105E-05
     +,   2.6496733E-05,   2.5051382E-05,   2.3619523E-05
     +,   2.2208107E-05,   2.0823421E-05,   1.9471159E-05
     +,   1.8156481E-05,   1.6883894E-05,   1.5657190E-05
     +,   1.4479512E-05,   1.3353508E-05,   1.2281089E-05
     +,   1.1263604E-05,   1.0301915E-05,   9.3963645E-06
     +,   8.5467709E-06,   7.7525201E-06,   7.0126771E-06
     +,   6.3259586E-06,   5.6907452E-06,   5.1051725E-06
     +,   4.5672186E-06,   4.0746927E-06,   3.6252518E-06
     +,   3.2164717E-06,   2.8459244E-06,   2.5111176E-06
     +,   2.2095765E-06,   1.9388810E-06,   1.6966617E-06
     +,   1.4806059E-06,   1.2884923E-06,   1.1182127E-06
     +,   9.6776319E-07,   8.3524503E-07,   7.1888059E-07
     +,   6.1702059E-07,   5.2813465E-07,   4.5080643E-07
     +,   3.8373693E-07,   3.2574599E-07,   2.7575595E-07
     +,   2.3279216E-07,   1.9598009E-07,   1.6453504E-07
     +,   1.3775417E-07,   1.1501342E-07,   9.5761884E-08
     +,   7.9513242E-08,   6.5839501E-08,   5.4366410E-08
     +,   4.4768765E-08,   3.6763968E-08,   3.0107191E-08
     +,   2.4587516E-08,   2.0024553E-08,   1.6263371E-08
     +,   1.3172120E-08,   1.0638995E-08,   8.5693745E-09
     +,   6.8833148E-09,   5.5136988E-09,   4.4044226E-09
     +,   3.5086294E-09,   2.7873188E-09,   2.2081701E-09
     +,   1.7445305E-09,   1.3744472E-09,   1.0798855E-09
     +,   8.4610485E-10,   6.6111050E-10,   5.1513860E-10
     +,   4.0028614E-10,   3.1018238E-10,   2.3969973E-10
     +,   1.8472199E-10,   1.4195983E-10,   1.0879581E-10
     +,   8.3150334E-11,   6.3374458E-11,   4.8168448E-11
     +,   3.6509830E-11,   2.7596942E-11,   2.0802377E-11
     +,   1.5637259E-11,   1.1722303E-11,   8.7632453E-12
     +,   6.5330111E-12,   4.8569274E-12,   3.6009245E-12
     +,   2.6623612E-12,   1.9629786E-12,   1.4433240E-12
     +,   1.0583197E-12,   7.7387418E-13,   5.6431216E-13
     +,   4.1036778E-13,   2.9759292E-13,   2.1521705E-13
     +,   1.5521207E-13,   1.1162971E-13,   8.0062604E-14
     +,   5.7264340E-14,   4.0844505E-14,   2.9052834E-14
     +,   2.0608107E-14,   1.4577840E-14,   1.0283688E-14
     +,   7.2343322E-15,   5.0752046E-15,   3.5506276E-15
     +,   2.4771966E-15,   1.7234974E-15,   1.1958234E-15
     +,   8.2740524E-16,   5.7091863E-16,   3.9284906E-16
     +,   2.6957641E-16,   1.8447300E-16,   1.2588966E-16
     +,   8.5672631E-17,   5.8143068E-17
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_eez_mass = Yx/0.0015204
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  4.3586401E-06,   4.7609310E-06
     +,   5.1933439E-06,   5.6573990E-06,   6.1546179E-06
     +,   6.6865136E-06,   7.2545909E-06,   7.8603252E-06
     +,   8.5051515E-06,   9.1904885E-06,   9.9176705E-06
     +,   1.0687969E-05,   1.1502579E-05,   1.2362598E-05
     +,   1.3269013E-05,   1.4222701E-05,   1.5224391E-05
     +,   1.6274673E-05,   1.7373975E-05,   1.8522534E-05
     +,   1.9720423E-05,   2.0967489E-05,   2.2263364E-05
     +,   2.3607521E-05,   2.4999063E-05,   2.6436981E-05
     +,   2.7919945E-05,   2.9446364E-05,   3.1014395E-05
     +,   3.2621916E-05,   3.4266519E-05,   3.5945544E-05
     +,   3.7656042E-05,   3.9394788E-05,   4.1158299E-05
     +,   4.2942811E-05,   4.4744331E-05,   4.6558605E-05
     +,   4.8381225E-05,   5.0207400E-05,   5.2032356E-05
     +,   5.3851007E-05,   5.5658140E-05,   5.7448429E-05
     +,   5.9216436E-05,   6.0956630E-05,   6.2663450E-05
     +,   6.4331311E-05,   6.5954599E-05,   6.7527799E-05
     +,   6.9045433E-05,   7.0502108E-05,   7.1892573E-05
     +,   7.3211821E-05,   7.4454882E-05,   7.5617172E-05
     +,   7.6694276E-05,   7.7682082E-05,   7.8576777E-05
     +,   7.9374928E-05,   8.0073398E-05,   8.0669495E-05
     +,   8.1160855E-05,   8.1545615E-05,   8.1822276E-05
     +,   8.1989805E-05,   8.2047613E-05,   8.1995553E-05
     +,   8.1833961E-05,   8.1563623E-05,   8.1185746E-05
     +,   8.0702026E-05,   8.0114543E-05,   7.9425881E-05
     +,   7.8638965E-05,   7.7757104E-05,   7.6784032E-05
     +,   7.5723852E-05,   7.4580923E-05,   7.3359915E-05
     +,   7.2065879E-05,   7.0703973E-05,   6.9279726E-05
     +,   6.7798690E-05,   6.6266781E-05,   6.4689826E-05
     +,   6.3074003E-05,   6.1425322E-05,   5.9750051E-05
     +,   5.8054346E-05,   5.6344314E-05,   5.4626173E-05
     +,   5.2906064E-05,   5.1189912E-05,   4.9483602E-05
     +,   4.7792993E-05,   4.6123620E-05,   4.4481050E-05
     +,   4.2870481E-05,   4.1297106E-05,   3.9765735E-05
     +,   3.8281160E-05,   3.6847749E-05,   3.5469846E-05
     +,   3.4151410E-05,   3.2896176E-05,   3.1707721E-05
     +,   3.0589381E-05,   2.9544164E-05,   2.8574850E-05
     +,   2.7684073E-05,   2.6874104E-05,   2.6147090E-05
     +,   2.5504840E-05,   2.4949015E-05,   2.4480976E-05
     +,   2.4101908E-05,   2.3812732E-05,   2.3614170E-05
     +,   2.3506695E-05,   2.3490567E-05,   2.3565839E-05
     +,   2.3732317E-05,   2.3989596E-05,   2.4337054E-05
     +,   2.4773819E-05,   2.5298836E-05,   2.5910760E-05
     +,   2.6608086E-05,   2.7389002E-05,   2.8251547E-05
     +,   2.9193416E-05,   3.0212190E-05,   3.1305073E-05
     +,   3.2469132E-05,   3.3701199E-05,   3.4997789E-05
     +,   3.6355159E-05,   3.7769430E-05,   3.9236489E-05
     +,   4.0751893E-05,   4.2310985E-05,   4.3908971E-05
     +,   4.5540884E-05,   4.7201389E-05,   4.8885115E-05
     +,   5.0586565E-05,   5.2299940E-05,   5.4019329E-05
     +,   5.5738819E-05,   5.7452417E-05,   5.9153914E-05
     +,   6.0837101E-05,   6.2495834E-05,   6.4123989E-05
     +,   6.5715365E-05,   6.7263827E-05,   6.8763446E-05
     +,   7.0208407E-05,   7.1592913E-05,   7.2911491E-05
     +,   7.4158852E-05,   7.5329895E-05,   7.6419783E-05
     +,   7.7424047E-05,   7.8338526E-05,   7.9159356E-05
     +,   7.9883037E-05,   8.0506506E-05,   8.1027101E-05
     +,   8.1442529E-05,   8.1750957E-05,   8.1951024E-05
     +,   8.2041777E-05,   8.2022729E-05,   8.1893872E-05
     +,   8.1655613E-05,   8.1308834E-05,   8.0854879E-05
     +,   8.0295489E-05,   7.9632839E-05,   7.8869511E-05
     +,   7.8008503E-05,   7.7053148E-05,   7.6007069E-05
     +,   7.4874326E-05,   7.3659241E-05,   7.2366354E-05
     +,   7.1000410E-05,   6.9566508E-05,   6.8069799E-05
     +,   6.6515568E-05,   6.4909276E-05,   6.3256535E-05
     +,   6.1562845E-05,   5.9833757E-05,   5.8074900E-05
     +,   5.6291876E-05,   5.4490101E-05,   5.2674877E-05
     +,   5.0851533E-05,   4.9025235E-05,   4.7200854E-05
     +,   4.5383076E-05,   4.3576583E-05,   4.1785621E-05
     +,   4.0014234E-05,   3.8266317E-05,   3.6545505E-05
     +,   3.4855057E-05,   3.3197957E-05,   3.1577038E-05
     +,   2.9994850E-05,   2.8453553E-05,   2.6955044E-05
     +,   2.5501044E-05,   2.4093019E-05,   2.2732067E-05
     +,   2.1419057E-05,   2.0154732E-05,   1.8939490E-05
     +,   1.7773504E-05,   1.6656828E-05,   1.5589310E-05
     +,   1.4570554E-05,   1.3599994E-05,   1.2676981E-05
     +,   1.1800719E-05,   1.0970223E-05,   1.0184413E-05
     +,   9.4421512E-06,   8.7422131E-06,   8.0832579E-06
     +,   7.4638838E-06,   6.8826980E-06,   6.3382190E-06
     +,   5.8289311E-06,   5.3533431E-06,   4.9099490E-06
     +,   4.4972126E-06,   4.1136086E-06,   3.7576556E-06
     +,   3.4278887E-06,   3.1228501E-06,   2.8411123E-06
     +,   2.5813117E-06,   2.3421142E-06,   2.1222197E-06
     +,   1.9203731E-06,   1.7353885E-06,   1.5661105E-06
     +,   1.4114356E-06,   1.2703229E-06,   1.1417821E-06
     +,   1.0248655E-06,   9.1867827E-07,   8.2238341E-07
     +,   7.3519283E-07,   6.5636095E-07,   5.8519038E-07
     +,   5.2103383E-07,   4.6328785E-07,   4.1138685E-07
     +,   3.6480637E-07,   3.2306573E-07,   2.8571543E-07
     +,   2.5234192E-07,   2.2256633E-07,   1.9604039E-07
     +,   1.7244334E-07,   1.5148156E-07,   1.3288863E-07
     +,   1.1642118E-07,   1.0185695E-07,   8.8994227E-08
     +,   7.7651464E-08,   6.7662768E-08,   5.8879795E-08
     +,   5.1167657E-08,   4.4405947E-08,   3.8485673E-08
     +,   3.3309924E-08,   2.8791264E-08,   2.4852177E-08
     +,   2.1422977E-08,   1.8442186E-08,   1.5854749E-08
     +,   1.3611896E-08,   1.1670631E-08,   9.9927071E-09
     +,   8.5445251E-09,   7.2963400E-09,   6.2221281E-09
     +,   5.2988831E-09,   4.5065836E-09,   3.8275632E-09
     +,   3.2464906E-09,   2.7499081E-09,   2.3261550E-09
     +,   1.9650401E-09,   1.6577577E-09
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_qq_mass = Yx/0.00261275
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  6.1804963E-06,   6.5829336E-06
     +,   7.0038263E-06,   7.4434220E-06,   7.9019237E-06
     +,   8.3794921E-06,   8.8762417E-06,   9.3922317E-06
     +,   9.9274630E-06,   1.0481906E-05,   1.1055451E-05
     +,   1.1647933E-05,   1.2259129E-05,   1.2888754E-05
     +,   1.3536460E-05,   1.4201834E-05,   1.4884397E-05
     +,   1.5583613E-05,   1.6298873E-05,   1.7029510E-05
     +,   1.7774792E-05,   1.8533923E-05,   1.9306040E-05
     +,   2.0090269E-05,   2.0885591E-05,   2.1691021E-05
     +,   2.2505481E-05,   2.3327842E-05,   2.4156943E-05
     +,   2.4991581E-05,   2.5830515E-05,   2.6672464E-05
     +,   2.7516124E-05,   2.8360157E-05,   2.9203222E-05
     +,   3.0043944E-05,   3.0880947E-05,   3.1712818E-05
     +,   3.2538206E-05,   3.3355671E-05,   3.4163848E-05
     +,   3.4961351E-05,   3.5746816E-05,   3.6518879E-05
     +,   3.7276208E-05,   3.8017490E-05,   3.8741437E-05
     +,   3.9446793E-05,   4.0132338E-05,   4.0796866E-05
     +,   4.1439227E-05,   4.2058309E-05,   4.2653013E-05
     +,   4.3222335E-05,   4.3765249E-05,   4.4280834E-05
     +,   4.4768174E-05,   4.5226421E-05,   4.5654760E-05
     +,   4.6052450E-05,   4.6418769E-05,   4.6753059E-05
     +,   4.7054717E-05,   4.7323192E-05,   4.7557991E-05
     +,   4.7758658E-05,   4.7924794E-05,   4.8056078E-05
     +,   4.8152211E-05,   4.8212980E-05,   4.8238202E-05
     +,   4.8227779E-05,   4.8181653E-05,   4.8099846E-05
     +,   4.7982423E-05,   4.7829508E-05,   4.7641301E-05
     +,   4.7418082E-05,   4.7160163E-05,   4.6867928E-05
     +,   4.6541856E-05,   4.6182453E-05,   4.5790333E-05
     +,   4.5366134E-05,   4.4910626E-05,   4.4424563E-05
     +,   4.3908847E-05,   4.3364384E-05,   4.2792202E-05
     +,   4.2193355E-05,   4.1568939E-05,   4.0920168E-05
     +,   4.0248313E-05,   3.9554656E-05,   3.8840528E-05
     +,   3.8107384E-05,   3.7356633E-05,   3.6589816E-05
     +,   3.5808422E-05,   3.5014065E-05,   3.4208300E-05
     +,   3.3392796E-05,   3.2569147E-05,   3.1739051E-05
     +,   3.0904157E-05,   3.0066103E-05,   2.9226576E-05
     +,   2.8387263E-05,   2.7549782E-05,   2.6715721E-05
     +,   2.5886739E-05,   2.5064342E-05,   2.4250130E-05
     +,   2.3445533E-05,   2.2652053E-05,   2.1871039E-05
     +,   2.1103891E-05,   2.0351847E-05,   1.9616182E-05
     +,   1.8898039E-05,   1.8198492E-05,   1.7518600E-05
     +,   1.6859341E-05,   1.6221587E-05,   1.5606131E-05
     +,   1.5013753E-05,   1.4445086E-05,   1.3900759E-05
     +,   1.3381256E-05,   1.2887060E-05,   1.2418513E-05
     +,   1.1975949E-05,   1.1559572E-05,   1.1169580E-05
     +,   1.0806060E-05,   1.0469038E-05,   1.0158506E-05
     +,   9.8743903E-06,   9.6165477E-06,   9.3847775E-06
     +,   9.1788515E-06,   8.9984906E-06,   8.8433535E-06
     +,   8.7130657E-06,   8.6072259E-06,   8.5253814E-06
     +,   8.4670473E-06,   8.4317180E-06,   8.4188532E-06
     +,   8.4278881E-06,   8.4582343E-06,   8.5092797E-06
     +,   8.5803968E-06,   8.6709369E-06,   8.7802428E-06
     +,   8.9076357E-06,   9.0524190E-06,   9.2138998E-06
     +,   9.3913750E-06,   9.5841115E-06,   9.7913917E-06
     +,   1.0012485E-05,   1.0246652E-05,   1.0493136E-05
     +,   1.0751197E-05,   1.1020090E-05,   1.1299051E-05
     +,   1.1587312E-05,   1.1884119E-05,   1.2188719E-05
     +,   1.2500335E-05,   1.2818193E-05,   1.3141536E-05
     +,   1.3469607E-05,   1.3801615E-05,   1.4136806E-05
     +,   1.4474430E-05,   1.4813708E-05,   1.5153873E-05
     +,   1.5494179E-05,   1.5833883E-05,   1.6172224E-05
     +,   1.6508451E-05,   1.6841845E-05,   1.7171686E-05
     +,   1.7497241E-05,   1.7817796E-05,   1.8132663E-05
     +,   1.8441166E-05,   1.8742610E-05,   1.9036350E-05
     +,   1.9321757E-05,   1.9598190E-05,   1.9865038E-05
     +,   2.0121723E-05,   2.0367685E-05,   2.0602378E-05
     +,   2.0825271E-05,   2.1035876E-05,   2.1233735E-05
     +,   2.1418396E-05,   2.1589442E-05,   2.1746493E-05
     +,   2.1889204E-05,   2.2017239E-05,   2.2130314E-05
     +,   2.2228180E-05,   2.2310598E-05,   2.2377390E-05
     +,   2.2428394E-05,   2.2463493E-05,   2.2482604E-05
     +,   2.2485678E-05,   2.2472697E-05,   2.2443681E-05
     +,   2.2398690E-05,   2.2337819E-05,   2.2261189E-05
     +,   2.2168957E-05,   2.2061324E-05,   2.1938515E-05
     +,   2.1800777E-05,   2.1648408E-05,   2.1481728E-05
     +,   2.1301079E-05,   2.1106829E-05,   2.0899381E-05
     +,   2.0679172E-05,   2.0446636E-05,   2.0202240E-05
     +,   1.9946474E-05,   1.9679859E-05,   1.9402911E-05
     +,   1.9116160E-05,   1.8820168E-05,   1.8515499E-05
     +,   1.8202712E-05,   1.7882396E-05,   1.7555154E-05
     +,   1.7221559E-05,   1.6882201E-05,   1.6537682E-05
     +,   1.6188604E-05,   1.5835554E-05,   1.5479100E-05
     +,   1.5119837E-05,   1.4758352E-05,   1.4395196E-05
     +,   1.4030912E-05,   1.3666068E-05,   1.3301181E-05
     +,   1.2936757E-05,   1.2573310E-05,   1.2211333E-05
     +,   1.1851291E-05,   1.1493617E-05,   1.1138756E-05
     +,   1.0787136E-05,   1.0439137E-05,   1.0095120E-05
     +,   9.7554503E-06,   9.4204725E-06,   9.0904832E-06
     +,   8.7657627E-06,   8.4466001E-06,   8.1332319E-06
     +,   7.8258718E-06,   7.5247376E-06,   7.2300204E-06
     +,   6.9418716E-06,   6.6604266E-06,   6.3858179E-06
     +,   6.1181554E-06,   5.8575160E-06,   5.6039576E-06
     +,   5.3575436E-06,   5.1182906E-06,   4.8862289E-06
     +,   4.6613422E-06,   4.4436288E-06,   4.2330448E-06
     +,   4.0295595E-06,   3.8331036E-06,   3.6436222E-06
     +,   3.4610205E-06,   3.2852226E-06,   3.1161219E-06
     +,   2.9536038E-06,   2.7975623E-06,   2.6478629E-06
     +,   2.5043848E-06,   2.3669807E-06,   2.2355177E-06
     +,   2.1098408E-06,   1.9898073E-06,   1.8752556E-06
     +,   1.7660371E-06,   1.6619855E-06,   1.5629478E-06
     +,   1.4687563E-06,   1.3792562E-06
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_ww_mass = Yx/0.0014742
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_haonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.6413738E-05,   1.6576347E-05
     +,   1.6734730E-05,   1.6888804E-05,   1.7038488E-05
     +,   1.7183700E-05,   1.7324350E-05,   1.7460354E-05
     +,   1.7591619E-05,   1.7718057E-05,   1.7839571E-05
     +,   1.7956063E-05,   1.8067431E-05,   1.8173567E-05
     +,   1.8274364E-05,   1.8369710E-05,   1.8459477E-05
     +,   1.8543560E-05,   1.8621822E-05,   1.8694138E-05
     +,   1.8760373E-05,   1.8820392E-05,   1.8874063E-05
     +,   1.8921246E-05,   1.8961797E-05,   1.8995574E-05
     +,   1.9022438E-05,   1.9042249E-05,   1.9054867E-05
     +,   1.9060151E-05,   1.9057979E-05,   1.9048213E-05
     +,   1.9030733E-05,   1.9005423E-05,   1.8972178E-05
     +,   1.8930892E-05,   1.8881477E-05,   1.8823863E-05
     +,   1.8757974E-05,   1.8683770E-05,   1.8601206E-05
     +,   1.8510264E-05,   1.8410945E-05,   1.8303264E-05
     +,   1.8187257E-05,   1.8062983E-05,   1.7930521E-05
     +,   1.7789978E-05,   1.7641481E-05,   1.7485188E-05
     +,   1.7321277E-05,   1.7149960E-05,   1.6971477E-05
     +,   1.6786089E-05,   1.6594106E-05,   1.6395852E-05
     +,   1.6191691E-05,   1.5982021E-05,   1.5767273E-05
     +,   1.5547910E-05,   1.5324429E-05,   1.5097365E-05
     +,   1.4867298E-05,   1.4634827E-05,   1.4400584E-05
     +,   1.4165264E-05,   1.3929569E-05,   1.3694258E-05
     +,   1.3460102E-05,   1.3227938E-05,   1.2998603E-05
     +,   1.2772994E-05,   1.2552019E-05,   1.2336638E-05
     +,   1.2127821E-05,   1.1926565E-05,   1.1733905E-05
     +,   1.1550897E-05,   1.1378609E-05,   1.1218121E-05
     +,   1.1070548E-05,   1.0936990E-05,   1.0818575E-05
     +,   1.0716416E-05,   1.0631642E-05,   1.0565362E-05
     +,   1.0518684E-05,   1.0492694E-05,   1.0488462E-05
     +,   1.0507030E-05,   1.0549415E-05,   1.0616591E-05
     +,   1.0709493E-05,   1.0829014E-05,   1.0976000E-05
     +,   1.1151224E-05,   1.1355422E-05,   1.1589238E-05
     +,   1.1853278E-05,   1.2148043E-05,   1.2473992E-05
     +,   1.2831464E-05,   1.3220770E-05,   1.3642077E-05
     +,   1.4095514E-05,   1.4581130E-05,   1.5098854E-05
     +,   1.5648533E-05,   1.6229958E-05,   1.6842860E-05
     +,   1.7486813E-05,   1.8161410E-05,   1.8866087E-05
     +,   1.9600302E-05,   2.0363363E-05,   2.1154610E-05
     +,   2.1973239E-05,   2.2818505E-05,   2.3689516E-05
     +,   2.4585426E-05,   2.5505371E-05,   2.6448402E-05
     +,   2.7413549E-05,   2.8399902E-05,   2.9406538E-05
     +,   3.0432431E-05,   3.1476702E-05,   3.2538323E-05
     +,   3.3616412E-05,   3.4709949E-05,   3.5818077E-05
     +,   3.6939753E-05,   3.8074129E-05,   3.9220162E-05
     +,   4.0376934E-05,   4.1543488E-05,   4.2718781E-05
     +,   4.3901731E-05,   4.5091267E-05,   4.6286299E-05
     +,   4.7485551E-05,   4.8687718E-05,   4.9891431E-05
     +,   5.1095252E-05,   5.2297499E-05,   5.3496478E-05
     +,   5.4690368E-05,   5.5877132E-05,   5.7054556E-05
     +,   5.8220357E-05,   5.9372091E-05,   6.0507056E-05
     +,   6.1622399E-05,   6.2715138E-05,   6.3782165E-05
     +,   6.4820131E-05,   6.5825552E-05,   6.6794841E-05
     +,   6.7724352E-05,   6.8610192E-05,   6.9448521E-05
     +,   7.0235430E-05,   7.0966948E-05,   7.1639108E-05
     +,   7.2248025E-05,   7.2789873E-05,   7.3260919E-05
     +,   7.3657568E-05,   7.3976458E-05,   7.4214389E-05
     +,   7.4368436E-05,   7.4435964E-05,   7.4414660E-05
     +,   7.4302552E-05,   7.4098069E-05,   7.3800053E-05
     +,   7.3407726E-05,   7.2920819E-05,   7.2339513E-05
     +,   7.1664443E-05,   7.0896713E-05,   7.0037931E-05
     +,   6.9090231E-05,   6.8056135E-05,   6.6938570E-05
     +,   6.5741049E-05,   6.4467444E-05,   6.3121966E-05
     +,   6.1709135E-05,   6.0233979E-05,   5.8701633E-05
     +,   5.7117511E-05,   5.5487286E-05,   5.3816831E-05
     +,   5.2112009E-05,   5.0378767E-05,   4.8623166E-05
     +,   4.6851288E-05,   4.5069013E-05,   4.3282133E-05
     +,   4.1496409E-05,   3.9717437E-05,   3.7950471E-05
     +,   3.6200545E-05,   3.4472585E-05,   3.2771059E-05
     +,   3.1100106E-05,   2.9463685E-05,   2.7865366E-05
     +,   2.6308287E-05,   2.4795230E-05,   2.3328717E-05
     +,   2.1910897E-05,   2.0543477E-05,   1.9227831E-05
     +,   1.7965072E-05,   1.6755985E-05,   1.5600968E-05
     +,   1.4500120E-05,   1.3453385E-05,   1.2460334E-05
     +,   1.1520308E-05,   1.0632497E-05,   9.7958864E-06
     +,   9.0092299E-06,   8.2711404E-06,   7.5801445E-06
     +,   6.9346515E-06,   6.3329358E-06,   5.7732050E-06
     +,   5.2536493E-06,   4.7724129E-06,   4.3275909E-06
     +,   3.9172692E-06,   3.5395810E-06,   3.1926386E-06
     +,   2.8745822E-06,   2.5836148E-06,   2.3179800E-06
     +,   2.0759569E-06,   1.8558862E-06,   1.6561878E-06
     +,   1.4753458E-06,   1.3119035E-06,   1.1644769E-06
     +,   1.0317680E-06,   9.1254884E-07,   8.0565729E-07
     +,   7.1000613E-07,   6.2458838E-07,   5.4845776E-07
     +,   4.8073628E-07,   4.2061609E-07,   3.6735091E-07
     +,   3.2025022E-07,   2.7868137E-07,   2.4206801E-07
     +,   2.0988368E-07,   1.8164708E-07,   1.5692204E-07
     +,   1.3531486E-07,   1.1647008E-07,   1.0006605E-07
     +,   8.5814378E-08,   7.3457606E-08,   6.2764492E-08
     +,   5.3528783E-08,   4.5567877E-08,   3.8719428E-08
     +,   3.2839310E-08,   2.7800370E-08,   2.3490907E-08
     +,   1.9812672E-08,   1.6679230E-08,   1.4015083E-08
     +,   1.1754531E-08,   9.8400808E-09,   8.2220462E-09
     +,   6.8571295E-09,   5.7080816E-09,   4.7426076E-09
     +,   3.9330263E-09,   3.2554635E-09,   2.6895490E-09
     +,   2.2177911E-09,   1.8253233E-09,   1.4994558E-09
     +,   1.2294156E-09,   1.0060929E-09,   8.2176260E-10
     +,   6.6992722E-10,   5.4509941E-10,   4.4268456E-10
     +,   3.5882108E-10,   2.9028865E-10,   2.3439278E-10
     +,   1.8889772E-10,   1.5193892E-10,   1.2197662E-10
     +,   9.7733419E-11,   7.8158008E-11
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_haonly_zz_mass = Yx/0.00180973333333333
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_eez_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  7.0495960E-05,   7.3022667E-05
     +,   7.5589247E-05,   7.8195386E-05,   8.0840844E-05
     +,   8.3525338E-05,   8.6248649E-05,   8.9010529E-05
     +,   9.1810631E-05,   9.4648778E-05,   9.7524491E-05
     +,   1.0043724E-04,   1.0338635E-04,   1.0637095E-04
     +,   1.0939000E-04,   1.1244202E-04,   1.1552532E-04
     +,   1.1863775E-04,   1.2177677E-04,   1.2493930E-04
     +,   1.2812174E-04,   1.3131982E-04,   1.3452863E-04
     +,   1.3774284E-04,   1.4095588E-04,   1.4416093E-04
     +,   1.4735019E-04,   1.5051510E-04,   1.5364647E-04
     +,   1.5673430E-04,   1.5976802E-04,   1.6273647E-04
     +,   1.6562802E-04,   1.6843066E-04,   1.7113205E-04
     +,   1.7371991E-04,   1.7618187E-04,   1.7850594E-04
     +,   1.8068055E-04,   1.8269458E-04,   1.8453809E-04
     +,   1.8620203E-04,   1.8767861E-04,   1.8896160E-04
     +,   1.9004641E-04,   1.9093028E-04,   1.9161259E-04
     +,   1.9209467E-04,   1.9238019E-04,   1.9247510E-04
     +,   1.9238766E-04,   1.9212844E-04,   1.9171019E-04
     +,   1.9114785E-04,   1.9045833E-04,   1.8966022E-04
     +,   1.8877380E-04,   1.8782062E-04,   1.8682318E-04
     +,   1.8580462E-04,   1.8478843E-04,   1.8379807E-04
     +,   1.8285660E-04,   1.8198619E-04,   1.8120812E-04
     +,   1.8054195E-04,   1.8000559E-04,   1.7961494E-04
     +,   1.7938350E-04,   1.7932222E-04,   1.7943959E-04
     +,   1.7974104E-04,   1.8022934E-04,   1.8090430E-04
     +,   1.8176300E-04,   1.8279969E-04,   1.8400614E-04
     +,   1.8537146E-04,   1.8688267E-04,   1.8852481E-04
     +,   1.9028095E-04,   1.9213301E-04,   1.9406129E-04
     +,   1.9604547E-04,   1.9806444E-04,   2.0009666E-04
     +,   2.0212060E-04,   2.0411487E-04,   2.0605823E-04
     +,   2.0793022E-04,   2.0971107E-04,   2.1138179E-04
     +,   2.1292454E-04,   2.1432263E-04,   2.1556061E-04
     +,   2.1662418E-04,   2.1750072E-04,   2.1817879E-04
     +,   2.1864857E-04,   2.1890155E-04,   2.1893073E-04
     +,   2.1873078E-04,   2.1829766E-04,   2.1762900E-04
     +,   2.1672378E-04,   2.1558251E-04,   2.1420720E-04
     +,   2.1260150E-04,   2.1077011E-04,   2.0871931E-04
     +,   2.0645691E-04,   2.0399166E-04,   2.0133410E-04
     +,   1.9849524E-04,   1.9548790E-04,   1.9232521E-04
     +,   1.8902178E-04,   1.8559241E-04,   1.8205294E-04
     +,   1.7841934E-04,   1.7470794E-04,   1.7093516E-04
     +,   1.6711775E-04,   1.6327163E-04,   1.5941264E-04
     +,   1.5555610E-04,   1.5171657E-04,   1.4790775E-04
     +,   1.4414232E-04,   1.4043214E-04,   1.3678741E-04
     +,   1.3321769E-04,   1.2973066E-04,   1.2633319E-04
     +,   1.2303049E-04,   1.1982647E-04,   1.1672387E-04
     +,   1.1372443E-04,   1.1082829E-04,   1.0803469E-04
     +,   1.0534207E-04,   1.0274792E-04,   1.0024896E-04
     +,   9.7841155E-05,   9.5520358E-05,   9.3281727E-05
     +,   9.1120230E-05,   8.9030822E-05,   8.7008484E-05
     +,   8.5048123E-05,   8.3144834E-05,   8.1294122E-05
     +,   7.9491816E-05,   7.7734017E-05,   7.6017299E-05
     +,   7.4338881E-05,   7.2696355E-05,   7.1087808E-05
     +,   6.9511872E-05,   6.7967783E-05,   6.6455192E-05
     +,   6.4974120E-05,   6.3525273E-05,   6.2109633E-05
     +,   6.0728522E-05,   5.9383543E-05,   5.8076694E-05
     +,   5.6810168E-05,   5.5586264E-05,   5.4407428E-05
     +,   5.3276228E-05,   5.2195304E-05,   5.1167168E-05
     +,   5.0194332E-05,   4.9279290E-05,   4.8424346E-05
     +,   4.7631638E-05,   4.6903187E-05,   4.6240824E-05
     +,   4.5646084E-05,   4.5120316E-05,   4.4664619E-05
     +,   4.4279856E-05,   4.3966571E-05,   4.3725078E-05
     +,   4.3555425E-05,   4.3457403E-05,   4.3430508E-05
     +,   4.3474018E-05,   4.3586911E-05,   4.3767974E-05
     +,   4.4015749E-05,   4.4328532E-05,   4.4704408E-05
     +,   4.5141296E-05,   4.5636916E-05,   4.6188808E-05
     +,   4.6794288E-05,   4.7450605E-05,   4.8154874E-05
     +,   4.8904021E-05,   4.9694852E-05,   5.0524122E-05
     +,   5.1388513E-05,   5.2284518E-05,   5.3208667E-05
     +,   5.4157430E-05,   5.5127170E-05,   5.6114201E-05
     +,   5.7114881E-05,   5.8125584E-05,   5.9142552E-05
     +,   6.0162114E-05,   6.1180617E-05,   6.2194456E-05
     +,   6.3200008E-05,   6.4193671E-05,   6.5172004E-05
     +,   6.6131593E-05,   6.7069035E-05,   6.7981091E-05
     +,   6.8864625E-05,   6.9716523E-05,   7.0533817E-05
     +,   7.1313683E-05,   7.2053452E-05,   7.2750539E-05
     +,   7.3402509E-05,   7.4007083E-05,   7.4562195E-05
     +,   7.5065866E-05,   7.5516320E-05,   7.5911943E-05
     +,   7.6251366E-05,   7.6533295E-05,   7.6756718E-05
     +,   7.6920755E-05,   7.7024728E-05,   7.7068165E-05
     +,   7.7050769E-05,   7.6972407E-05,   7.6833225E-05
     +,   7.6633449E-05,   7.6373552E-05,   7.6054108E-05
     +,   7.5675991E-05,   7.5240168E-05,   7.4747739E-05
     +,   7.4199976E-05,   7.3598356E-05,   7.2944444E-05
     +,   7.2239905E-05,   7.1486611E-05,   7.0686503E-05
     +,   6.9841590E-05,   6.8954003E-05,   6.8025984E-05
     +,   6.7059838E-05,   6.6057888E-05,   6.5022490E-05
     +,   6.3956148E-05,   6.2861334E-05,   6.1740517E-05
     +,   6.0596150E-05,   5.9430808E-05,   5.8246929E-05
     +,   5.7046953E-05,   5.5833338E-05,   5.4608536E-05
     +,   5.3374853E-05,   5.2134543E-05,   5.0889896E-05
     +,   4.9643113E-05,   4.8396265E-05,   4.7151334E-05
     +,   4.5910343E-05,   4.4675053E-05,   4.3447322E-05
     +,   4.2228741E-05,   4.1020969E-05,   3.9825401E-05
     +,   3.8643513E-05,   3.7476504E-05,   3.6325640E-05
     +,   3.5191933E-05,   3.4076456E-05,   3.2980060E-05
     +,   3.1903528E-05,   3.0847634E-05,   2.9812927E-05
     +,   2.8800016E-05,   2.7809288E-05,   2.6841173E-05
     +,   2.5895906E-05,   2.4973775E-05,   2.4074861E-05
     +,   2.3199320E-05,   2.2347111E-05,   2.1518254E-05
     +,   2.0712612E-05,   1.9930101E-05
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_eez_mass = Yx/0.0081088
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_qq_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  1.2836377E-04,   1.3191151E-04
     +,   1.3546756E-04,   1.3902829E-04,   1.4258995E-04
     +,   1.4614908E-04,   1.4970203E-04,   1.5324539E-04
     +,   1.5677573E-04,   1.6028987E-04,   1.6378470E-04
     +,   1.6725715E-04,   1.7070444E-04,   1.7412382E-04
     +,   1.7751282E-04,   1.8086909E-04,   1.8419052E-04
     +,   1.8747515E-04,   1.9072118E-04,   1.9392703E-04
     +,   1.9709136E-04,   2.0021296E-04,   2.0329074E-04
     +,   2.0632402E-04,   2.0931194E-04,   2.1225405E-04
     +,   2.1515004E-04,   2.1799964E-04,   2.2080261E-04
     +,   2.2355901E-04,   2.2626888E-04,   2.2893229E-04
     +,   2.3154943E-04,   2.3412045E-04,   2.3664559E-04
     +,   2.3912493E-04,   2.4155859E-04,   2.4394678E-04
     +,   2.4628945E-04,   2.4858647E-04,   2.5083768E-04
     +,   2.5304290E-04,   2.5520154E-04,   2.5731305E-04
     +,   2.5937671E-04,   2.6139157E-04,   2.6335649E-04
     +,   2.6527027E-04,   2.6713131E-04,   2.6893799E-04
     +,   2.7068850E-04,   2.7238054E-04,   2.7401198E-04
     +,   2.7558042E-04,   2.7708305E-04,   2.7851714E-04
     +,   2.7987978E-04,   2.8116774E-04,   2.8237767E-04
     +,   2.8350635E-04,   2.8455019E-04,   2.8550564E-04
     +,   2.8636912E-04,   2.8713702E-04,   2.8780557E-04
     +,   2.8837129E-04,   2.8883049E-04,   2.8917979E-04
     +,   2.8941582E-04,   2.8953530E-04,   2.8953524E-04
     +,   2.8941288E-04,   2.8916562E-04,   2.8879117E-04
     +,   2.8828764E-04,   2.8765344E-04,   2.8688723E-04
     +,   2.8598838E-04,   2.8495654E-04,   2.8379174E-04
     +,   2.8249482E-04,   2.8106681E-04,   2.7950961E-04
     +,   2.7782537E-04,   2.7601712E-04,   2.7408823E-04
     +,   2.7204296E-04,   2.6988590E-04,   2.6762247E-04
     +,   2.6525854E-04,   2.6280058E-04,   2.6025571E-04
     +,   2.5763162E-04,   2.5493640E-04,   2.5217867E-04
     +,   2.4936767E-04,   2.4651270E-04,   2.4362392E-04
     +,   2.4071128E-04,   2.3778547E-04,   2.3485694E-04
     +,   2.3193676E-04,   2.2903553E-04,   2.2616438E-04
     +,   2.2333412E-04,   2.2055527E-04,   2.1783847E-04
     +,   2.1519410E-04,   2.1263192E-04,   2.1016136E-04
     +,   2.0779159E-04,   2.0553087E-04,   2.0338735E-04
     +,   2.0136801E-04,   1.9947953E-04,   1.9772752E-04
     +,   1.9611706E-04,   1.9465217E-04,   1.9333616E-04
     +,   1.9217133E-04,   1.9115915E-04,   1.9030012E-04
     +,   1.8959399E-04,   1.8903927E-04,   1.8863389E-04
     +,   1.8837470E-04,   1.8825776E-04,   1.8827824E-04
     +,   1.8843065E-04,   1.8870867E-04,   1.8910518E-04
     +,   1.8961259E-04,   1.9022274E-04,   1.9092670E-04
     +,   1.9171544E-04,   1.9257929E-04,   1.9350840E-04
     +,   1.9449262E-04,   1.9552157E-04,   1.9658507E-04
     +,   1.9767258E-04,   1.9877373E-04,   1.9987847E-04
     +,   2.0097681E-04,   2.0205892E-04,   2.0311533E-04
     +,   2.0413726E-04,   2.0511592E-04,   2.0604332E-04
     +,   2.0691194E-04,   2.0771474E-04,   2.0844536E-04
     +,   2.0909806E-04,   2.0966776E-04,   2.1015000E-04
     +,   2.1054121E-04,   2.1083810E-04,   2.1103839E-04
     +,   2.1114045E-04,   2.1114304E-04,   2.1104589E-04
     +,   2.1084913E-04,   2.1055361E-04,   2.1016058E-04
     +,   2.0967195E-04,   2.0909010E-04,   2.0841777E-04
     +,   2.0765814E-04,   2.0681479E-04,   2.0589154E-04
     +,   2.0489245E-04,   2.0382203E-04,   2.0268459E-04
     +,   2.0148486E-04,   2.0022754E-04,   1.9891745E-04
     +,   1.9755916E-04,   1.9615747E-04,   1.9471714E-04
     +,   1.9324265E-04,   1.9173836E-04,   1.9020859E-04
     +,   1.8865749E-04,   1.8708890E-04,   1.8550639E-04
     +,   1.8391355E-04,   1.8231370E-04,   1.8070974E-04
     +,   1.7910446E-04,   1.7750057E-04,   1.7590036E-04
     +,   1.7430597E-04,   1.7271943E-04,   1.7114262E-04
     +,   1.6957709E-04,   1.6802445E-04,   1.6648612E-04
     +,   1.6496351E-04,   1.6345787E-04,   1.6197038E-04
     +,   1.6050237E-04,   1.5905520E-04,   1.5763003E-04
     +,   1.5622830E-04,   1.5485147E-04,   1.5350110E-04
     +,   1.5217884E-04,   1.5088652E-04,   1.4962627E-04
     +,   1.4840013E-04,   1.4721039E-04,   1.4605967E-04
     +,   1.4495064E-04,   1.4388618E-04,   1.4286935E-04
     +,   1.4190338E-04,   1.4099179E-04,   1.4013803E-04
     +,   1.3934581E-04,   1.3861901E-04,   1.3796147E-04
     +,   1.3737718E-04,   1.3687013E-04,   1.3644448E-04
     +,   1.3610411E-04,   1.3585303E-04,   1.3569515E-04
     +,   1.3563417E-04,   1.3567373E-04,   1.3581722E-04
     +,   1.3606784E-04,   1.3642844E-04,   1.3690168E-04
     +,   1.3748978E-04,   1.3819465E-04,   1.3901778E-04
     +,   1.3996025E-04,   1.4102263E-04,   1.4220491E-04
     +,   1.4350680E-04,   1.4492733E-04,   1.4646498E-04
     +,   1.4811764E-04,   1.4988275E-04,   1.5175708E-04
     +,   1.5373682E-04,   1.5581751E-04,   1.5799428E-04
     +,   1.6026165E-04,   1.6261339E-04,   1.6504298E-04
     +,   1.6754339E-04,   1.7010688E-04,   1.7272527E-04
     +,   1.7539017E-04,   1.7809277E-04,   1.8082363E-04
     +,   1.8357312E-04,   1.8633147E-04,   1.8908865E-04
     +,   1.9183429E-04,   1.9455790E-04,   1.9724896E-04
     +,   1.9989717E-04,   2.0249178E-04,   2.0502237E-04
     +,   2.0747872E-04,   2.0985061E-04,   2.1212800E-04
     +,   2.1430134E-04,   2.1636134E-04,   2.1829891E-04
     +,   2.2010542E-04,   2.2177285E-04,   2.2329364E-04
     +,   2.2466059E-04,   2.2586719E-04,   2.2690756E-04
     +,   2.2777630E-04,   2.2846872E-04,   2.2898089E-04
     +,   2.2930941E-04,   2.2945166E-04,   2.2940562E-04
     +,   2.2917012E-04,   2.2874454E-04,   2.2812908E-04
     +,   2.2732450E-04,   2.2633241E-04,   2.2515490E-04
     +,   2.2379486E-04,   2.2225564E-04,   2.2054138E-04
     +,   2.1865657E-04,   2.1660647E-04,   2.1439666E-04
     +,   2.1203335E-04,   2.0952302E-04,   2.0687266E-04
     +,   2.0408959E-04,   2.0118152E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_qq_mass = Yx/0.01688568
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_ww_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  2.0414652E-04,   2.1193632E-04
     +,   2.1971737E-04,   2.2746844E-04,   2.3516826E-04
     +,   2.4279622E-04,   2.5033197E-04,   2.5775604E-04
     +,   2.6505033E-04,   2.7219820E-04,   2.7918495E-04
     +,   2.8599778E-04,   2.9262685E-04,   2.9906450E-04
     +,   3.0530701E-04,   3.1135342E-04,   3.1720652E-04
     +,   3.2287312E-04,   3.2836382E-04,   3.3369305E-04
     +,   3.3887982E-04,   3.4394648E-04,   3.4891962E-04
     +,   3.5382950E-04,   3.5870928E-04,   3.6359555E-04
     +,   3.6852705E-04,   3.7354478E-04,   3.7869072E-04
     +,   3.8400813E-04,   3.8953958E-04,   3.9532792E-04
     +,   4.0141362E-04,   4.0783585E-04,   4.1463075E-04
     +,   4.2183138E-04,   4.2946666E-04,   4.3756136E-04
     +,   4.4613663E-04,   4.5520769E-04,   4.6478616E-04
     +,   4.7487966E-04,   4.8549089E-04,   4.9662037E-04
     +,   5.0826569E-04,   5.2042276E-04,   5.3308759E-04
     +,   5.4625637E-04,   5.5992662E-04,   5.7409913E-04
     +,   5.8877835E-04,   6.0397212E-04,   6.1969360E-04
     +,   6.3596142E-04,   6.5279723E-04,   6.7022635E-04
     +,   6.8827701E-04,   7.0697715E-04,   7.2635326E-04
     +,   7.4642728E-04,   7.6721539E-04,   7.8872300E-04
     +,   8.1094477E-04,   8.3386141E-04,   8.5743959E-04
     +,   8.8162825E-04,   9.0636330E-04,   9.3156681E-04
     +,   9.5714914E-04,   9.8301214E-04,   1.0090573E-03
     +,   1.0351849E-03,   1.0613066E-03,   1.0873440E-03
     +,   1.1132389E-03,   1.1389562E-03,   1.1644851E-03
     +,   1.1898422E-03,   1.2150725E-03,   1.2402454E-03
     +,   1.2654498E-03,   1.2907921E-03,   1.3163834E-03
     +,   1.3423353E-03,   1.3687436E-03,   1.3956929E-03
     +,   1.4232281E-03,   1.4513651E-03,   1.4800703E-03
     +,   1.5092694E-03,   1.5388356E-03,   1.5685956E-03
     +,   1.5983303E-03,   1.6277868E-03,   1.6566816E-03
     +,   1.6847062E-03,   1.7115457E-03,   1.7368823E-03
     +,   1.7604100E-03,   1.7818365E-03,   1.8008972E-03
     +,   1.8173520E-03,   1.8310014E-03,   1.8416696E-03
     +,   1.8492226E-03,   1.8535544E-03,   1.8545854E-03
     +,   1.8522644E-03,   1.8465598E-03,   1.8374597E-03
     +,   1.8249740E-03,   1.8091282E-03,   1.7899669E-03
     +,   1.7675549E-03,   1.7419889E-03,   1.7133831E-03
     +,   1.6818915E-03,   1.6476993E-03,   1.6110335E-03
     +,   1.5721555E-03,   1.5313665E-03,   1.4890013E-03
     +,   1.4454291E-03,   1.4010401E-03,   1.3562385E-03
     +,   1.3114404E-03,   1.2670528E-03,   1.2234746E-03
     +,   1.1810733E-03,   1.1401910E-03,   1.1011220E-03
     +,   1.0641175E-03,   1.0293751E-03,   9.9703996E-04
     +,   9.6720201E-04,   9.3989784E-04,   9.1511762E-04
     +,   8.9280767E-04,   8.7287236E-04,   8.5518544E-04
     +,   8.3959458E-04,   8.2593050E-04,   8.1400789E-04
     +,   8.0363371E-04,   7.9461519E-04,   7.8675966E-04
     +,   7.7987951E-04,   7.7379541E-04,   7.6833920E-04
     +,   7.6335366E-04,   7.5869501E-04,   7.5423322E-04
     +,   7.4985356E-04,   7.4545480E-04,   7.4095192E-04
     +,   7.3627406E-04,   7.3136593E-04,   7.2618684E-04
     +,   7.2070991E-04,   7.1492267E-04,   7.0882560E-04
     +,   7.0243079E-04,   6.9576257E-04,   6.8885495E-04
     +,   6.8174972E-04,   6.7449705E-04,   6.6715205E-04
     +,   6.5977423E-04,   6.5242487E-04,   6.4516766E-04
     +,   6.3806371E-04,   6.3117454E-04,   6.2455644E-04
     +,   6.1826251E-04,   6.1234168E-04,   6.0683629E-04
     +,   6.0178334E-04,   5.9721299E-04,   5.9315073E-04
     +,   5.8961444E-04,   5.8661692E-04,   5.8416632E-04
     +,   5.8226491E-04,   5.8091216E-04,   5.8010209E-04
     +,   5.7982758E-04,   5.8007793E-04,   5.8084069E-04
     +,   5.8210199E-04,   5.8384700E-04,   5.8605906E-04
     +,   5.8872218E-04,   5.9181766E-04,   5.9532729E-04
     +,   5.9923134E-04,   6.0350809E-04,   6.0813484E-04
     +,   6.1308633E-04,   6.1833527E-04,   6.2385167E-04
     +,   6.2960183E-04,   6.3554873E-04,   6.4165326E-04
     +,   6.4787129E-04,   6.5415597E-04,   6.6045765E-04
     +,   6.6672376E-04,   6.7289884E-04,   6.7892752E-04
     +,   6.8475265E-04,   6.9031789E-04,   6.9556857E-04
     +,   7.0045196E-04,   7.0491951E-04,   7.0892792E-04
     +,   7.1243959E-04,   7.1542268E-04,   7.1785564E-04
     +,   7.1972428E-04,   7.2102301E-04,   7.2175747E-04
     +,   7.2194211E-04,   7.2159985E-04,   7.2076410E-04
     +,   7.1947713E-04,   7.1778666E-04,   7.1574870E-04
     +,   7.1342307E-04,   7.1087322E-04,   7.0816505E-04
     +,   7.0536375E-04,   7.0253439E-04,   6.9973781E-04
     +,   6.9703005E-04,   6.9446192E-04,   6.9207646E-04
     +,   6.8990851E-04,   6.8798347E-04,   6.8631739E-04
     +,   6.8491639E-04,   6.8377634E-04,   6.8288355E-04
     +,   6.8221492E-04,   6.8174017E-04,   6.8142021E-04
     +,   6.8120984E-04,   6.8105920E-04,   6.8091421E-04
     +,   6.8071793E-04,   6.8041298E-04,   6.7994173E-04
     +,   6.7924714E-04,   6.7827565E-04,   6.7697663E-04
     +,   6.7530310E-04,   6.7321397E-04,   6.7067321E-04
     +,   6.6765014E-04,   6.6412095E-04,   6.6006684E-04
     +,   6.5547606E-04,   6.5034191E-04,   6.4466294E-04
     +,   6.3844351E-04,   6.3169235E-04,   6.2442152E-04
     +,   6.1664823E-04,   6.0839090E-04,   5.9967249E-04
     +,   5.9051666E-04,   5.8094854E-04,   5.7099538E-04
     +,   5.6068553E-04,   5.5004662E-04,   5.3910707E-04
     +,   5.2789587E-04,   5.1644078E-04,   5.0477055E-04
     +,   4.9291225E-04,   4.8089414E-04,   4.6874187E-04
     +,   4.5648284E-04,   4.4414197E-04,   4.3174499E-04
     +,   4.1931609E-04,   4.0688019E-04,   3.9446048E-04
     +,   3.8207942E-04,   3.6976030E-04,   3.5752385E-04
     +,   3.4539204E-04,   3.3338429E-04,   3.2152078E-04
     +,   3.0981924E-04,   2.9829773E-04,   2.8697224E-04
     +,   2.7585885E-04,   2.6497067E-04,   2.5432152E-04
     +,   2.4392217E-04,   2.3378359E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_ww_mass = Yx/0.056574
      RETURN
      END
      DOUBLE PRECISION FUNCTION A210_tt_hzonly_zz_mass(V)
      DOUBLE PRECISION V
      DOUBLE PRECISION Yx, LBOUND, UBOUND, RANGE
      DOUBLE PRECISION Y(301 )
      INTEGER NBINS, I
      DATA NBINS  / 300 /
      DATA LBOUND, UBOUND / 50., 120./
      DATA y /  9.6425531E-05,   9.8595658E-05
     +,   1.0070395E-04,   1.0274691E-04,   1.0472148E-04
     +,   1.0662499E-04,   1.0845535E-04,   1.1021097E-04
     +,   1.1189061E-04,   1.1349378E-04,   1.1502033E-04
     +,   1.1647068E-04,   1.1784579E-04,   1.1914710E-04
     +,   1.2037646E-04,   1.2153632E-04,   1.2262940E-04
     +,   1.2365893E-04,   1.2462845E-04,   1.2554185E-04
     +,   1.2640325E-04,   1.2721708E-04,   1.2798792E-04
     +,   1.2872054E-04,   1.2941964E-04,   1.3009021E-04
     +,   1.3073708E-04,   1.3136507E-04,   1.3197894E-04
     +,   1.3258321E-04,   1.3318233E-04,   1.3378053E-04
     +,   1.3438167E-04,   1.3498946E-04,   1.3560725E-04
     +,   1.3623806E-04,   1.3688461E-04,   1.3754920E-04
     +,   1.3823379E-04,   1.3894001E-04,   1.3966915E-04
     +,   1.4042208E-04,   1.4119942E-04,   1.4200131E-04
     +,   1.4282792E-04,   1.4367879E-04,   1.4455350E-04
     +,   1.4545119E-04,   1.4637111E-04,   1.4731215E-04
     +,   1.4827318E-04,   1.4925310E-04,   1.5025066E-04
     +,   1.5126482E-04,   1.5229436E-04,   1.5333842E-04
     +,   1.5439621E-04,   1.5546709E-04,   1.5655064E-04
     +,   1.5764676E-04,   1.5875562E-04,   1.5987773E-04
     +,   1.6101380E-04,   1.6216519E-04,   1.6333343E-04
     +,   1.6452049E-04,   1.6572887E-04,   1.6696124E-04
     +,   1.6822107E-04,   1.6951184E-04,   1.7083788E-04
     +,   1.7220354E-04,   1.7361395E-04,   1.7507424E-04
     +,   1.7659029E-04,   1.7816800E-04,   1.7981394E-04
     +,   1.8153456E-04,   1.8333679E-04,   1.8522789E-04
     +,   1.8721493E-04,   1.8930546E-04,   1.9150677E-04
     +,   1.9382645E-04,   1.9627161E-04,   1.9884971E-04
     +,   2.0156751E-04,   2.0443182E-04,   2.0744874E-04
     +,   2.1062390E-04,   2.1396254E-04,   2.1746875E-04
     +,   2.2114598E-04,   2.2499630E-04,   2.2902137E-04
     +,   2.3322062E-04,   2.3759261E-04,   2.4213402E-04
     +,   2.4684033E-04,   2.5170454E-04,   2.5671843E-04
     +,   2.6187129E-04,   2.6715119E-04,   2.7254355E-04
     +,   2.7803259E-04,   2.8360068E-04,   2.8922863E-04
     +,   2.9489567E-04,   3.0058087E-04,   3.0626214E-04
     +,   3.1191742E-04,   3.1752567E-04,   3.2306611E-04
     +,   3.2852055E-04,   3.3387268E-04,   3.3911044E-04
     +,   3.4422494E-04,   3.4921308E-04,   3.5407770E-04
     +,   3.5882776E-04,   3.6348077E-04,   3.6806069E-04
     +,   3.7260083E-04,   3.7714280E-04,   3.8173611E-04
     +,   3.8643801E-04,   3.9131317E-04,   3.9643105E-04
     +,   4.0186601E-04,   4.0769399E-04,   4.1399157E-04
     +,   4.2083368E-04,   4.2829040E-04,   4.3642696E-04
     +,   4.4530057E-04,   4.5496115E-04,   4.6544912E-04
     +,   4.7679708E-04,   4.8903242E-04,   5.0217833E-04
     +,   5.1625667E-04,   5.3129176E-04,   5.4731639E-04
     +,   5.6437321E-04,   5.8251753E-04,   6.0182193E-04
     +,   6.2237511E-04,   6.4427906E-04,   6.6764659E-04
     +,   6.9259584E-04,   7.1924098E-04,   7.4768154E-04
     +,   7.7798992E-04,   8.1020425E-04,   8.4431370E-04
     +,   8.8025024E-04,   9.1788004E-04,   9.5700752E-04
     +,   9.9737349E-04,   1.0386592E-03,   1.0805052E-03
     +,   1.1225274E-03,   1.1643291E-03,   1.2055277E-03
     +,   1.2457812E-03,   1.2848015E-03,   1.3223671E-03
     +,   1.3583362E-03,   1.3926468E-03,   1.4253121E-03
     +,   1.4563987E-03,   1.4860118E-03,   1.5142707E-03
     +,   1.5412809E-03,   1.5671026E-03,   1.5917460E-03
     +,   1.6151465E-03,   1.6371643E-03,   1.6575905E-03
     +,   1.6761604E-03,   1.6925747E-03,   1.7065160E-03
     +,   1.7176801E-03,   1.7257949E-03,   1.7306345E-03
     +,   1.7320361E-03,   1.7299082E-03,   1.7242194E-03
     +,   1.7150051E-03,   1.7023564E-03,   1.6864064E-03
     +,   1.6673206E-03,   1.6452916E-03,   1.6205261E-03
     +,   1.5932402E-03,   1.5636575E-03,   1.5320054E-03
     +,   1.4985192E-03,   1.4634388E-03,   1.4270138E-03
     +,   1.3895008E-03,   1.3511693E-03,   1.3122866E-03
     +,   1.2731185E-03,   1.2339294E-03,   1.1949585E-03
     +,   1.1564216E-03,   1.1185021E-03,   1.0813432E-03
     +,   1.0450435E-03,   1.0096565E-03,   9.7519957E-04
     +,   9.4165513E-04,   9.0897654E-04,   8.7710068E-04
     +,   8.4595924E-04,   8.1548403E-04,   7.8561518E-04
     +,   7.5630692E-04,   7.2753453E-04,   6.9929042E-04
     +,   6.7158492E-04,   6.4444746E-04,   6.1792153E-04
     +,   5.9205940E-04,   5.6691945E-04,   5.4256507E-04
     +,   5.1905896E-04,   4.9646036E-04,   4.7482297E-04
     +,   4.5419598E-04,   4.3462159E-04,   4.1613195E-04
     +,   3.9875187E-04,   3.8249916E-04,   3.6738091E-04
     +,   3.5339672E-04,   3.4053833E-04,   3.2878885E-04
     +,   3.1812294E-04,   3.0850776E-04,   2.9990345E-04
     +,   2.9226340E-04,   2.8553407E-04,   2.7965673E-04
     +,   2.7456824E-04,   2.7020171E-04,   2.6648701E-04
     +,   2.6335267E-04,   2.6072658E-04,   2.5853686E-04
     +,   2.5671319E-04,   2.5518736E-04,   2.5389457E-04
     +,   2.5277364E-04,   2.5176757E-04,   2.5082490E-04
     +,   2.4989867E-04,   2.4894791E-04,   2.4793661E-04
     +,   2.4683471E-04,   2.4561706E-04,   2.4426391E-04
     +,   2.4275990E-04,   2.4109455E-04,   2.3926119E-04
     +,   2.3725674E-04,   2.3508152E-04,   2.3273850E-04
     +,   2.3023313E-04,   2.2757243E-04,   2.2476536E-04
     +,   2.2182218E-04,   2.1875350E-04,   2.1557073E-04
     +,   2.1228587E-04,   2.0891042E-04,   2.0545619E-04
     +,   2.0193429E-04,   1.9835583E-04,   1.9473091E-04
     +,   1.9106930E-04,   1.8737985E-04,   1.8367088E-04
     +,   1.7994971E-04,   1.7622326E-04,   1.7249736E-04
     +,   1.6877725E-04,   1.6506771E-04,   1.6137265E-04
     +,   1.5769569E-04,   1.5403965E-04,   1.5040726E-04
     +,   1.4680054E-04,   1.4322155E-04,   1.3967177E-04
     +,   1.3615286E-04,   1.3266579E-04,   1.2921212E-04
     +,   1.2579266E-04,   1.2240876E-04
     +/
      If((V.lt.Lbound).or.(V.ge.UBound)) THEN
      Yx = 0.0
      ELSE
      RANGE = UBOUND - LBOUND
      i = 1 + INT(NBINS*(V - LBOUND)/RANGE)
      Xi = (i-1)*RANGE/NBINS + LBOUND
      Yx = (y(i+1) - y(i))*NBINS*(V - Xi)/RANGE + y(i)
      END IF
      A210_tt_hzonly_zz_mass = Yx/0.0361597297297297
      RETURN
      END
      DOUBLE PRECISION FUNCTION A_2000_TT_BACKGROUND_MASS(ROOTS,
     $     RECOMH, IOVERLAP, ITYP, XMIN, XMAX)
C     Background function for ALEPH tau tau channels in 2000.
C     Author: Jason Nielsen                Date: 1 June 2000
C     Inputs: 
C               RootS            the center of mass energy      
C               Recomh           reconstructed Higgs mass
C               Ioverlap         treatment of overlap between hA and hZ
C                                1 = hAonly      2 = ashA
C                                3 = ashZ        4 = hZonly
C               Ityp             background type number
C                                1 = eeZ         2 = qq
C                                3 = WW          4 = ZZ
C               Xmin             /min and max values of recomh 
C               Xmax             \used for interpolation with a_morph
C
      IMPLICIT NONE
      INTEGER IOVERLAP, ITYP
      DOUBLE PRECISION ROOTS, RECOMH, XMIN, XMAX
C
      INTEGER NMORPH_BINS
      PARAMETER (NMORPH_BINS = 100)
      DOUBLE PRECISION LAST_ROOTS_CALLED
      DOUBLE PRECISION XINVALS(NMORPH_BINS), Y1INVALS(NMORPH_BINS),
     $     Y2INVALS(NMORPH_BINS), XMORPHVALS(NMORPH_BINS),
     $     YMORPHVALS(NMORPH_BINS)
C Warning: hard-coded number of overlap branches and background types
      DOUBLE PRECISION XMORPHARRAY(NMORPH_BINS, 4, 4),
     $     YMORPHARRAY(NMORPH_BINS, 4, 4)
      DOUBLE PRECISION INTERP_XVALS(NMORPH_BINS),
     $     INTERP_YVALS(NMORPH_BINS), PAR1, PAR2, DX
      INTEGER ALREADY_MORPHED_BACK(4, 4), I, J
      DOUBLE PRECISION A_INTERP_VECARRAY
C
      DOUBLE PRECISION A_200N_TT_BACKGROUND_MASS,
     $     A_202N_TT_BACKGROUND_MASS, A_204_TT_BACKGROUND_MASS,
     $     A_206_TT_BACKGROUND_MASS, A_208_TT_BACKGROUND_MASS, 
     $     A_210_TT_BACKGROUND_MASS 
C     

c      write(*,*) 'ttbkgmass xl :',xmin
c      write(*,*) 'ttbkgmass xh :',xmax
c      write(*,*) 'ttbkgmass xrec :',recomh
c      write(*,*) 'ttbkgmass ecm :',roots
c      write(*,*) 'ttbkgmass ibranch :',ioverlap
c      write(*,*) 'ttbkgmass ityp :',ityp

      IF (IOVERLAP.GT.4) THEN
         WRITE(*,*) "A_TT_2000: overlap ", IOVERLAP, " does not exist!"
      ENDIF
      IF (ITYP.GT.4) THEN
         WRITE(*,*) "A_TT_2000: background ", ITYP, " does not exist!"
      ENDIF
      DX = (XMAX-XMIN)/(NMORPH_BINS-1)
C
C     Use a hash table to see if the functions have already been
C     interpolated.
C
      IF (ROOTS.NE.LAST_ROOTS_CALLED) THEN
         DO I = 1, 4
            DO J = 1, 4
               ALREADY_MORPHED_BACK(I, J) = 0
            ENDDO
         ENDDO
      ENDIF
      IF (ALREADY_MORPHED_BACK(IOVERLAP, ITYP) .EQ. 0) THEN
         DO I = 1, NMORPH_BINS
            XINVALS(I) = XMIN + DX*(I-1)
         ENDDO
         IF (ROOTS.GE.200. .AND. ROOTS.LT.202.) THEN
            PAR1 = 200.
            PAR2 = 202.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A_200N_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
               Y2INVALS(I) =
     $              A_202N_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
            ENDDO
         ELSEIF (ROOTS.GE.202. .AND. ROOTS.LT.204.) THEN
            PAR1 = 202.
            PAR2 = 204.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A_202N_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
               Y2INVALS(I) =
     $              A_204_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
            ENDDO
         ELSEIF (ROOTS.GE.204. .AND. ROOTS.LT.206.) THEN
            PAR1 = 204.
            PAR2 = 206.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A_204_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
               Y2INVALS(I) =
     $              A_206_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
            ENDDO
         ELSEIF (ROOTS.GE.206. .AND. ROOTS.LT.208.) THEN
            PAR1 = 206.
            PAR2 = 208.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A_206_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
               Y2INVALS(I) =
     $              A_208_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
            ENDDO
         ELSEIF (ROOTS.GE.208. .AND. ROOTS.LE.210.) THEN
            PAR1 = 208.
            PAR2 = 210.
            DO I = 1, NMORPH_BINS
               Y1INVALS(I) =
     $              A_208_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
               Y2INVALS(I) =
     $              A_210_TT_BACKGROUND_MASS(IOVERLAP,ITYP,XINVALS(I))
            ENDDO
         ELSE
           A_2000_TT_BACKGROUND_MASS = 1D-15
           return
         ENDIF
         CALL A_MORPH(NMORPH_BINS, XMIN, XMAX, Y1INVALS, Y2INVALS,
     $        PAR1, PAR2, ROOTS, XMORPHVALS, YMORPHVALS)
         DO I = 1, NMORPH_BINS
            XMORPHARRAY(I, IOVERLAP, ITYP) = XMORPHVALS(I)
            YMORPHARRAY(I, IOVERLAP, ITYP) = YMORPHVALS(I)
         ENDDO
         ALREADY_MORPHED_BACK(IOVERLAP, ITYP) = 1
      ENDIF ! End of the loop if not ALREADY_MORPHED_BACK
C   Otherwise the left-over morphed vectors are used.
      DO I = 1, NMORPH_BINS
         XMORPHVALS(I) = XMORPHARRAY(I, IOVERLAP, ITYP)
         YMORPHVALS(I) = YMORPHARRAY(I, IOVERLAP, ITYP)
      ENDDO
      A_2000_TT_BACKGROUND_MASS = A_INTERP_VECARRAY(NMORPH_BINS,
     $     XMORPHVALS, YMORPHVALS, RECOMH)
C
      LAST_ROOTS_CALLED = ROOTS
      RETURN
      END
C
      DOUBLE PRECISION FUNCTION A_200N_TT_BACKGROUND_MASS(IOVERLAP,
     $     ITYP, X)
C     IOVERLAP = 1=hAonly   2=ashA  3=ashZ  4=hZonly
C     ITYP     = 1=eeZ      2=qq    3=WW    4=ZZ      
      IMPLICIT NONE
      INTEGER IOVERLAP, ITYP
      DOUBLE PRECISION X
C
      DOUBLE PRECISION A200N_TT_HAONLY_EEZ_MASS, A200N_TT_ASHA_EEZ_MASS,
     $     A200N_TT_ASHZ_EEZ_MASS, A200N_TT_HZONLY_EEZ_MASS
      DOUBLE PRECISION A200N_TT_HAONLY_QQ_MASS, A200N_TT_ASHA_QQ_MASS,
     $     A200N_TT_ASHZ_QQ_MASS, A200N_TT_HZONLY_QQ_MASS
      DOUBLE PRECISION A200N_TT_HAONLY_WW_MASS, A200N_TT_ASHA_WW_MASS,
     $     A200N_TT_ASHZ_WW_MASS, A200N_TT_HZONLY_WW_MASS
      DOUBLE PRECISION A200N_TT_HAONLY_ZZ_MASS, A200N_TT_ASHA_ZZ_MASS,
     $     A200N_TT_ASHZ_ZZ_MASS, A200N_TT_HZONLY_ZZ_MASS
C
      IF (IOVERLAP.EQ.1) THEN
         IF (ITYP.EQ.1) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_HAONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_HAONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_HAONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_HAONLY_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.2) THEN
         IF (ITYP.EQ.1) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_ASHA_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_ASHA_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_ASHA_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_ASHA_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.3) THEN
         IF (ITYP.EQ.1) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_ASHZ_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_ASHZ_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_ASHZ_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_ASHZ_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.4) THEN
         IF (ITYP.EQ.1) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_HZONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_HZONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_HZONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_200N_TT_BACKGROUND_MASS = A200N_TT_HZONLY_ZZ_MASS(X)
         ENDIF
      ENDIF
      RETURN
      END

      DOUBLE PRECISION FUNCTION A_202N_TT_BACKGROUND_MASS(IOVERLAP,
     $     ITYP, X)
C     IOVERLAP = 1=hAonly   2=ashA  3=ashZ  4=hZonly
C     ITYP     = 1=eeZ      2=qq    3=WW    4=ZZ      
      IMPLICIT NONE
      INTEGER IOVERLAP, ITYP
      DOUBLE PRECISION X
C
      DOUBLE PRECISION A202N_TT_HAONLY_EEZ_MASS, A202N_TT_ASHA_EEZ_MASS,
     $     A202N_TT_ASHZ_EEZ_MASS, A202N_TT_HZONLY_EEZ_MASS
      DOUBLE PRECISION A202N_TT_HAONLY_QQ_MASS, A202N_TT_ASHA_QQ_MASS,
     $     A202N_TT_ASHZ_QQ_MASS, A202N_TT_HZONLY_QQ_MASS
      DOUBLE PRECISION A202N_TT_HAONLY_WW_MASS, A202N_TT_ASHA_WW_MASS,
     $     A202N_TT_ASHZ_WW_MASS, A202N_TT_HZONLY_WW_MASS
      DOUBLE PRECISION A202N_TT_HAONLY_ZZ_MASS, A202N_TT_ASHA_ZZ_MASS,
     $     A202N_TT_ASHZ_ZZ_MASS, A202N_TT_HZONLY_ZZ_MASS
C
      IF (IOVERLAP.EQ.1) THEN
         IF (ITYP.EQ.1) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_HAONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_HAONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_HAONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_HAONLY_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.2) THEN
         IF (ITYP.EQ.1) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_ASHA_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_ASHA_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_ASHA_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_ASHA_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.3) THEN
         IF (ITYP.EQ.1) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_ASHZ_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_ASHZ_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_ASHZ_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_ASHZ_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.4) THEN
         IF (ITYP.EQ.1) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_HZONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_HZONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_HZONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_202N_TT_BACKGROUND_MASS = A202N_TT_HZONLY_ZZ_MASS(X)
         ENDIF
      ENDIF
      RETURN
      END

      DOUBLE PRECISION FUNCTION A_204_TT_BACKGROUND_MASS(IOVERLAP,
     $     ITYP, X)
C     IOVERLAP = 1=hAonly   2=ashA  3=ashZ  4=hZonly
C     ITYP     = 1=eeZ      2=qq    3=WW    4=ZZ      
      IMPLICIT NONE
      INTEGER IOVERLAP, ITYP
      DOUBLE PRECISION X
C
      DOUBLE PRECISION A204_TT_HAONLY_EEZ_MASS, A204_TT_ASHA_EEZ_MASS,
     $     A204_TT_ASHZ_EEZ_MASS, A204_TT_HZONLY_EEZ_MASS
      DOUBLE PRECISION A204_TT_HAONLY_QQ_MASS, A204_TT_ASHA_QQ_MASS,
     $     A204_TT_ASHZ_QQ_MASS, A204_TT_HZONLY_QQ_MASS
      DOUBLE PRECISION A204_TT_HAONLY_WW_MASS, A204_TT_ASHA_WW_MASS,
     $     A204_TT_ASHZ_WW_MASS, A204_TT_HZONLY_WW_MASS
      DOUBLE PRECISION A204_TT_HAONLY_ZZ_MASS, A204_TT_ASHA_ZZ_MASS,
     $     A204_TT_ASHZ_ZZ_MASS, A204_TT_HZONLY_ZZ_MASS
C
      IF (IOVERLAP.EQ.1) THEN
         IF (ITYP.EQ.1) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_HAONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_HAONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_HAONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_HAONLY_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.2) THEN
         IF (ITYP.EQ.1) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_ASHA_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_ASHA_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_ASHA_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_ASHA_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.3) THEN
         IF (ITYP.EQ.1) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_ASHZ_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_ASHZ_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_ASHZ_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_ASHZ_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.4) THEN
         IF (ITYP.EQ.1) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_HZONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_HZONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_HZONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_204_TT_BACKGROUND_MASS = A204_TT_HZONLY_ZZ_MASS(X)
         ENDIF
      ENDIF
      RETURN
      END

      DOUBLE PRECISION FUNCTION A_206_TT_BACKGROUND_MASS(IOVERLAP,
     $     ITYP, X)
C     IOVERLAP = 1=hAonly   2=ashA  3=ashZ  4=hZonly
C     ITYP     = 1=eeZ      2=qq    3=WW    4=ZZ      
      IMPLICIT NONE
      INTEGER IOVERLAP, ITYP
      DOUBLE PRECISION X
C
      DOUBLE PRECISION A206_TT_HAONLY_EEZ_MASS, A206_TT_ASHA_EEZ_MASS,
     $     A206_TT_ASHZ_EEZ_MASS, A206_TT_HZONLY_EEZ_MASS
      DOUBLE PRECISION A206_TT_HAONLY_QQ_MASS, A206_TT_ASHA_QQ_MASS,
     $     A206_TT_ASHZ_QQ_MASS, A206_TT_HZONLY_QQ_MASS
      DOUBLE PRECISION A206_TT_HAONLY_WW_MASS, A206_TT_ASHA_WW_MASS,
     $     A206_TT_ASHZ_WW_MASS, A206_TT_HZONLY_WW_MASS
      DOUBLE PRECISION A206_TT_HAONLY_ZZ_MASS, A206_TT_ASHA_ZZ_MASS,
     $     A206_TT_ASHZ_ZZ_MASS, A206_TT_HZONLY_ZZ_MASS
C
      IF (IOVERLAP.EQ.1) THEN
         IF (ITYP.EQ.1) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_HAONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_HAONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_HAONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_HAONLY_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.2) THEN
         IF (ITYP.EQ.1) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_ASHA_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_ASHA_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_ASHA_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_ASHA_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.3) THEN
         IF (ITYP.EQ.1) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_ASHZ_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_ASHZ_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_ASHZ_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_ASHZ_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.4) THEN
         IF (ITYP.EQ.1) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_HZONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_HZONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_HZONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_206_TT_BACKGROUND_MASS = A206_TT_HZONLY_ZZ_MASS(X)
         ENDIF
      ENDIF
      RETURN
      END

      DOUBLE PRECISION FUNCTION A_208_TT_BACKGROUND_MASS(IOVERLAP,
     $     ITYP, X)
C     IOVERLAP = 1=hAonly   2=ashA  3=ashZ  4=hZonly
C     ITYP     = 1=eeZ      2=qq    3=WW    4=ZZ      
      IMPLICIT NONE
      INTEGER IOVERLAP, ITYP
      DOUBLE PRECISION X
C
      DOUBLE PRECISION A208_TT_HAONLY_EEZ_MASS, A208_TT_ASHA_EEZ_MASS,
     $     A208_TT_ASHZ_EEZ_MASS, A208_TT_HZONLY_EEZ_MASS
      DOUBLE PRECISION A208_TT_HAONLY_QQ_MASS, A208_TT_ASHA_QQ_MASS,
     $     A208_TT_ASHZ_QQ_MASS, A208_TT_HZONLY_QQ_MASS
      DOUBLE PRECISION A208_TT_HAONLY_WW_MASS, A208_TT_ASHA_WW_MASS,
     $     A208_TT_ASHZ_WW_MASS, A208_TT_HZONLY_WW_MASS
      DOUBLE PRECISION A208_TT_HAONLY_ZZ_MASS, A208_TT_ASHA_ZZ_MASS,
     $     A208_TT_ASHZ_ZZ_MASS, A208_TT_HZONLY_ZZ_MASS
C
      IF (IOVERLAP.EQ.1) THEN
         IF (ITYP.EQ.1) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_HAONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_HAONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_HAONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_HAONLY_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.2) THEN
         IF (ITYP.EQ.1) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_ASHA_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_ASHA_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_ASHA_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_ASHA_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.3) THEN
         IF (ITYP.EQ.1) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_ASHZ_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_ASHZ_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_ASHZ_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_ASHZ_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.4) THEN
         IF (ITYP.EQ.1) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_HZONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_HZONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_HZONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_208_TT_BACKGROUND_MASS = A208_TT_HZONLY_ZZ_MASS(X)
         ENDIF
      ENDIF
      RETURN
      END

      DOUBLE PRECISION FUNCTION A_210_TT_BACKGROUND_MASS(IOVERLAP,
     $     ITYP, X)
C     IOVERLAP = 1=hAonly   2=ashA  3=ashZ  4=hZonly
C     ITYP     = 1=eeZ      2=qq    3=WW    4=ZZ      
      IMPLICIT NONE
      INTEGER IOVERLAP, ITYP
      DOUBLE PRECISION X
C
      DOUBLE PRECISION A210_TT_HAONLY_EEZ_MASS, A210_TT_ASHA_EEZ_MASS,
     $     A210_TT_ASHZ_EEZ_MASS, A210_TT_HZONLY_EEZ_MASS
      DOUBLE PRECISION A210_TT_HAONLY_QQ_MASS, A210_TT_ASHA_QQ_MASS,
     $     A210_TT_ASHZ_QQ_MASS, A210_TT_HZONLY_QQ_MASS
      DOUBLE PRECISION A210_TT_HAONLY_WW_MASS, A210_TT_ASHA_WW_MASS,
     $     A210_TT_ASHZ_WW_MASS, A210_TT_HZONLY_WW_MASS
      DOUBLE PRECISION A210_TT_HAONLY_ZZ_MASS, A210_TT_ASHA_ZZ_MASS,
     $     A210_TT_ASHZ_ZZ_MASS, A210_TT_HZONLY_ZZ_MASS
C
      IF (IOVERLAP.EQ.1) THEN
         IF (ITYP.EQ.1) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_HAONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_HAONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_HAONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_HAONLY_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.2) THEN
         IF (ITYP.EQ.1) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_ASHA_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_ASHA_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_ASHA_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_ASHA_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.3) THEN
         IF (ITYP.EQ.1) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_ASHZ_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_ASHZ_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_ASHZ_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_ASHZ_ZZ_MASS(X)
         ENDIF
      ELSEIF (IOVERLAP.EQ.4) THEN
         IF (ITYP.EQ.1) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_HZONLY_EEZ_MASS(X)
         ELSEIF (ITYP.EQ.2) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_HZONLY_QQ_MASS(X)
         ELSEIF (ITYP.EQ.3) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_HZONLY_WW_MASS(X)
         ELSEIF (ITYP.EQ.4) THEN
            A_210_TT_BACKGROUND_MASS = A210_TT_HZONLY_ZZ_MASS(X)
         ENDIF
      ENDIF
      RETURN
      END

